/*
 * Copyright (c) 2014 - 2016, Freescale Semiconductor, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * o Redistributions of source code must retain the above copyright notice, this list
 *   of conditions and the following disclaimer.
 *
 * o Redistributions in binary form must reproduce the above copyright notice, this
 *   list of conditions and the following disclaimer in the documentation and/or
 *   other materials provided with the distribution.
 *
 * o Neither the name of Freescale Semiconductor, Inc. nor the names of its
 *   contributors may be used to endorse or promote products derived from this
 *   software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/*
 * WARNING! DO NOT EDIT THIS FILE DIRECTLY!
 *
 * This file was generated automatically and any changes may be lost.
 */
#ifndef __HW_iMX7D_REGISTERS_H__
#define __HW_iMX7D_REGISTERS_H__

#include "fsl_bitaccess.h"

/*
 * iMX7D ADC
 *
 * ADC
 *
 * Registers defined in this header file:
 * - HW_ADC_CH_A_CFG1 - Channel A configuration 1
 * - HW_ADC_CH_A_CFG2 - Channel A configuration 2
 * - HW_ADC_CH_B_CFG1 -
 * - HW_ADC_CH_B_CFG2 - Channel B Configuration 2
 * - HW_ADC_CH_C_CFG1 - Channel C Configuration 1
 * - HW_ADC_CH_C_CFG2 - Channel C Configuration 2
 * - HW_ADC_CH_D_CFG1 - Channel D Configuration 1
 * - HW_ADC_CH_D_CFG2 - Channel D Configuration 2
 * - HW_ADC_CH_SW_CFG - Channel Software Configuration
 * - HW_ADC_TIMER_UNIT - Timer Unit
 * - HW_ADC_DMA_FIFO - DMA FIFO
 * - HW_ADC_FIFO_STATUS - FIFO Status
 * - HW_ADC_INT_SIG_EN -
 * - HW_ADC_INT_EN - Interrupt Enable
 * - HW_ADC_INT_STATUS -
 * - HW_ADC_CHA_B_CNV_RSLT - Channel A and B Conversion Result
 * - HW_ADC_CHC_D_CNV_RSLT - Channel C and D Conversion Result
 * - HW_ADC_CH_SW_CNV_RSLT - Channel Software Conversion Result
 * - HW_ADC_DMA_FIFO_DAT - DMA FIFO Data
 * - HW_ADC_ADC_CFG - ADC Configuration
 *
 * - hw_adc_t - Struct containing all module registers.
 */

#define HW_ADC_INSTANCE_COUNT (2U) /*!< Number of instances of the ADC module. */
#define HW_ADC1 (0U) /*!< Instance number for ADC1. */
#define HW_ADC2 (1U) /*!< Instance number for ADC2. */
#define ADC1_BASE             (0x30610000U) /*!< Base address for ADC1. */
#define ADC2_BASE             (0x30620000U) /*!< Base address for ADC2. */
/*! Array initializer of ADC base addresses. */
#define ADC_BASE_ADDRS        { ADC1_BASE, ADC2_BASE }

/*******************************************************************************
 * HW_ADC_CH_A_CFG1 - Channel A configuration 1
 ******************************************************************************/

/*!
 * @brief HW_ADC_CH_A_CFG1 - Channel A configuration 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * CH_A_CFG1 defines the functions of channel A. Channel A has the highest
 * priority of all four channels.
 */
typedef union _hw_adc_ch_a_cfg1
{
    uint32_t U;
    struct _hw_adc_ch_a_cfg1_bitfields
    {
        uint32_t CHA_TIMER : 24;       /*!< [23:0] Channel A Timer */
        uint32_t CHA_SEL : 4;          /*!< [27:24] Channel A Select */
        uint32_t RESERVED0 : 1;        /*!< [28] This field is reserved. */
        uint32_t CHA_AVG_EN : 1;       /*!< [29] Channel A Average Enable */
        uint32_t CHA_SINGLE : 1;       /*!< [30] Channel A Signal Conversion */
        uint32_t CHA_EN : 1;           /*!< [31] Channel A Enable */
    } B;
} hw_adc_ch_a_cfg1_t;

/*!
 * @name Constants and macros for entire ADC_CH_A_CFG1 register
 */
/*@{*/
#define HW_ADC_CH_A_CFG1_ADDR(x) ((uintptr_t)(x) + 0x0U)

#define HW_ADC_CH_A_CFG1(x)      (*(__IO hw_adc_ch_a_cfg1_t *) HW_ADC_CH_A_CFG1_ADDR(x))
#define HW_ADC_CH_A_CFG1_RD(x)   (HW_ADC_CH_A_CFG1(x).U)
#define HW_ADC_CH_A_CFG1_WR(x, v) (HW_ADC_CH_A_CFG1(x).U = (v))
#define HW_ADC_CH_A_CFG1_SET(x, v) (HW_ADC_CH_A_CFG1_WR(x, HW_ADC_CH_A_CFG1_RD(x) |  (v)))
#define HW_ADC_CH_A_CFG1_CLR(x, v) (HW_ADC_CH_A_CFG1_WR(x, HW_ADC_CH_A_CFG1_RD(x) & ~(v)))
#define HW_ADC_CH_A_CFG1_TOG(x, v) (HW_ADC_CH_A_CFG1_WR(x, HW_ADC_CH_A_CFG1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_CH_A_CFG1 bitfields
 */

/*!
 * @name Register ADC_CH_A_CFG1, field CHA_TIMER[23:0] (RW)
 *
 * This timer is for continuous conversion. The conversion rate = (CHA_TIMER +
 * 1) times sample rate. 0x000 to 0xFFF timer value, every CHA_TIMER + 1 times
 * sample rate, the ADC converts one data.
 */
/*@{*/
#define BP_ADC_CH_A_CFG1_CHA_TIMER (0U)    /*!< Bit position for ADC_CH_A_CFG1_CHA_TIMER. */
#define BM_ADC_CH_A_CFG1_CHA_TIMER (0x00FFFFFFU) /*!< Bit mask for ADC_CH_A_CFG1_CHA_TIMER. */
#define BS_ADC_CH_A_CFG1_CHA_TIMER (24U)   /*!< Bit field size in bits for ADC_CH_A_CFG1_CHA_TIMER. */

/*! @brief Read current value of the ADC_CH_A_CFG1_CHA_TIMER field. */
#define BR_ADC_CH_A_CFG1_CHA_TIMER(x) (HW_ADC_CH_A_CFG1(x).B.CHA_TIMER)

/*! @brief Format value for bitfield ADC_CH_A_CFG1_CHA_TIMER. */
#define BF_ADC_CH_A_CFG1_CHA_TIMER(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_A_CFG1_CHA_TIMER) & BM_ADC_CH_A_CFG1_CHA_TIMER)

/*! @brief Set the CHA_TIMER field to a new value. */
#define BW_ADC_CH_A_CFG1_CHA_TIMER(x, v) (HW_ADC_CH_A_CFG1_WR(x, (HW_ADC_CH_A_CFG1_RD(x) & ~BM_ADC_CH_A_CFG1_CHA_TIMER) | BF_ADC_CH_A_CFG1_CHA_TIMER(v)))
/*@}*/

/*!
 * @name Register ADC_CH_A_CFG1, field CHA_SEL[27:24] (RW)
 *
 * Select input channel (from 16 channels) for the logical channel A.
 *
 * Values:
 * - 0000 - Channel 0
 * - 0001 - Channel 1
 * - 0010 - Channel 2
 * - 0011 - Channel 3
 * - 0100 - Channel 4
 * - 0101 - Channel 5
 * - 0110 - Channel 6
 * - 0111 - Channel 7
 * - 1000 - Channel 8
 * - 1001 - Channel 9
 * - 1010 - Channel 10
 * - 1011 - Channel 11
 * - 1100 - Channel 12
 * - 1101 - Channel 13
 * - 1110 - Channel 14
 * - 1111 - Channel 15
 */
/*@{*/
#define BP_ADC_CH_A_CFG1_CHA_SEL (24U)     /*!< Bit position for ADC_CH_A_CFG1_CHA_SEL. */
#define BM_ADC_CH_A_CFG1_CHA_SEL (0x0F000000U) /*!< Bit mask for ADC_CH_A_CFG1_CHA_SEL. */
#define BS_ADC_CH_A_CFG1_CHA_SEL (4U)      /*!< Bit field size in bits for ADC_CH_A_CFG1_CHA_SEL. */

/*! @brief Read current value of the ADC_CH_A_CFG1_CHA_SEL field. */
#define BR_ADC_CH_A_CFG1_CHA_SEL(x) (HW_ADC_CH_A_CFG1(x).B.CHA_SEL)

/*! @brief Format value for bitfield ADC_CH_A_CFG1_CHA_SEL. */
#define BF_ADC_CH_A_CFG1_CHA_SEL(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_A_CFG1_CHA_SEL) & BM_ADC_CH_A_CFG1_CHA_SEL)

/*! @brief Set the CHA_SEL field to a new value. */
#define BW_ADC_CH_A_CFG1_CHA_SEL(x, v) (HW_ADC_CH_A_CFG1_WR(x, (HW_ADC_CH_A_CFG1_RD(x) & ~BM_ADC_CH_A_CFG1_CHA_SEL) | BF_ADC_CH_A_CFG1_CHA_SEL(v)))
/*@}*/

/*!
 * @name Register ADC_CH_A_CFG1, field CHA_AVG_EN[29] (RW)
 *
 * If enable this bit, channel A will do average for each conversion.
 *
 * Values:
 * - 1 - Enable average function.
 * - 0 - Disable average function.
 */
/*@{*/
#define BP_ADC_CH_A_CFG1_CHA_AVG_EN (29U)  /*!< Bit position for ADC_CH_A_CFG1_CHA_AVG_EN. */
#define BM_ADC_CH_A_CFG1_CHA_AVG_EN (0x20000000U) /*!< Bit mask for ADC_CH_A_CFG1_CHA_AVG_EN. */
#define BS_ADC_CH_A_CFG1_CHA_AVG_EN (1U)   /*!< Bit field size in bits for ADC_CH_A_CFG1_CHA_AVG_EN. */

/*! @brief Read current value of the ADC_CH_A_CFG1_CHA_AVG_EN field. */
#define BR_ADC_CH_A_CFG1_CHA_AVG_EN(x) (HW_ADC_CH_A_CFG1(x).B.CHA_AVG_EN)

/*! @brief Format value for bitfield ADC_CH_A_CFG1_CHA_AVG_EN. */
#define BF_ADC_CH_A_CFG1_CHA_AVG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_A_CFG1_CHA_AVG_EN) & BM_ADC_CH_A_CFG1_CHA_AVG_EN)

/*! @brief Set the CHA_AVG_EN field to a new value. */
#define BW_ADC_CH_A_CFG1_CHA_AVG_EN(x, v) (HW_ADC_CH_A_CFG1_WR(x, (HW_ADC_CH_A_CFG1_RD(x) & ~BM_ADC_CH_A_CFG1_CHA_AVG_EN) | BF_ADC_CH_A_CFG1_CHA_AVG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_CH_A_CFG1, field CHA_SINGLE[30] (RW)
 *
 * Start a single conversion from logical channel A. Switch between single and
 * continuous conversion, it must disable CHA_EN first. When both CHA_EN and
 * CHA_SINGLE are enabled, CHA_SIGNAL set CHA_EN to 0 and reset itself to 0.
 *
 * Values:
 * - 1 - Start a single conversion. Continuous conversion must stop.
 * - 0 - No single conversion. Continuous conversion can start.
 */
/*@{*/
#define BP_ADC_CH_A_CFG1_CHA_SINGLE (30U)  /*!< Bit position for ADC_CH_A_CFG1_CHA_SINGLE. */
#define BM_ADC_CH_A_CFG1_CHA_SINGLE (0x40000000U) /*!< Bit mask for ADC_CH_A_CFG1_CHA_SINGLE. */
#define BS_ADC_CH_A_CFG1_CHA_SINGLE (1U)   /*!< Bit field size in bits for ADC_CH_A_CFG1_CHA_SINGLE. */

/*! @brief Read current value of the ADC_CH_A_CFG1_CHA_SINGLE field. */
#define BR_ADC_CH_A_CFG1_CHA_SINGLE(x) (HW_ADC_CH_A_CFG1(x).B.CHA_SINGLE)

/*! @brief Format value for bitfield ADC_CH_A_CFG1_CHA_SINGLE. */
#define BF_ADC_CH_A_CFG1_CHA_SINGLE(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_A_CFG1_CHA_SINGLE) & BM_ADC_CH_A_CFG1_CHA_SINGLE)

/*! @brief Set the CHA_SINGLE field to a new value. */
#define BW_ADC_CH_A_CFG1_CHA_SINGLE(x, v) (HW_ADC_CH_A_CFG1_WR(x, (HW_ADC_CH_A_CFG1_RD(x) & ~BM_ADC_CH_A_CFG1_CHA_SINGLE) | BF_ADC_CH_A_CFG1_CHA_SINGLE(v)))
/*@}*/

/*!
 * @name Register ADC_CH_A_CFG1, field CHA_EN[31] (RW)
 *
 * This bit controls the working mode of logical channel A.
 *
 * Values:
 * - 1 - Enable logical channel A. Logical channel A will work.
 * - 0 - Disable logical channel A. Prevent logical channel A from working.
 */
/*@{*/
#define BP_ADC_CH_A_CFG1_CHA_EN (31U)      /*!< Bit position for ADC_CH_A_CFG1_CHA_EN. */
#define BM_ADC_CH_A_CFG1_CHA_EN (0x80000000U) /*!< Bit mask for ADC_CH_A_CFG1_CHA_EN. */
#define BS_ADC_CH_A_CFG1_CHA_EN (1U)       /*!< Bit field size in bits for ADC_CH_A_CFG1_CHA_EN. */

/*! @brief Read current value of the ADC_CH_A_CFG1_CHA_EN field. */
#define BR_ADC_CH_A_CFG1_CHA_EN(x) (HW_ADC_CH_A_CFG1(x).B.CHA_EN)

/*! @brief Format value for bitfield ADC_CH_A_CFG1_CHA_EN. */
#define BF_ADC_CH_A_CFG1_CHA_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_A_CFG1_CHA_EN) & BM_ADC_CH_A_CFG1_CHA_EN)

/*! @brief Set the CHA_EN field to a new value. */
#define BW_ADC_CH_A_CFG1_CHA_EN(x, v) (HW_ADC_CH_A_CFG1_WR(x, (HW_ADC_CH_A_CFG1_RD(x) & ~BM_ADC_CH_A_CFG1_CHA_EN) | BF_ADC_CH_A_CFG1_CHA_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_CH_A_CFG2 - Channel A configuration 2
 ******************************************************************************/

/*!
 * @brief HW_ADC_CH_A_CFG2 - Channel A configuration 2 (RW)
 *
 * Reset value: 0x00008000U
 *
 * CH_A_CFG2 defines the function of channel A. Channel A has the highest
 * priority of all four channels.
 */
typedef union _hw_adc_ch_a_cfg2
{
    uint32_t U;
    struct _hw_adc_ch_a_cfg2_bitfields
    {
        uint32_t CHA_LOW_THRES : 12;   /*!< [11:0] Channel A Low Threshold
                                        * Value */
        uint32_t CHA_AVG_NUMBER : 2;   /*!< [13:12] Channel A Average Number */
        uint32_t RESERVED0 : 1;        /*!< [14] This field is reserved. */
        uint32_t CHA_AUTO_DIS : 1;     /*!< [15] Channel A Auto Disable */
        uint32_t CHA_HIGH_THRES : 12;  /*!< [27:16] Channel A High Threshold
                                        * Value */
        uint32_t RESERVED1 : 1;        /*!< [28] This field is reserved. */
        uint32_t CHA_CMP_MODE : 3;     /*!< [31:29] Channel A Compare Mode */
    } B;
} hw_adc_ch_a_cfg2_t;

/*!
 * @name Constants and macros for entire ADC_CH_A_CFG2 register
 */
/*@{*/
#define HW_ADC_CH_A_CFG2_ADDR(x) ((uintptr_t)(x) + 0x10U)

#define HW_ADC_CH_A_CFG2(x)      (*(__IO hw_adc_ch_a_cfg2_t *) HW_ADC_CH_A_CFG2_ADDR(x))
#define HW_ADC_CH_A_CFG2_RD(x)   (HW_ADC_CH_A_CFG2(x).U)
#define HW_ADC_CH_A_CFG2_WR(x, v) (HW_ADC_CH_A_CFG2(x).U = (v))
#define HW_ADC_CH_A_CFG2_SET(x, v) (HW_ADC_CH_A_CFG2_WR(x, HW_ADC_CH_A_CFG2_RD(x) |  (v)))
#define HW_ADC_CH_A_CFG2_CLR(x, v) (HW_ADC_CH_A_CFG2_WR(x, HW_ADC_CH_A_CFG2_RD(x) & ~(v)))
#define HW_ADC_CH_A_CFG2_TOG(x, v) (HW_ADC_CH_A_CFG2_WR(x, HW_ADC_CH_A_CFG2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_CH_A_CFG2 bitfields
 */

/*!
 * @name Register ADC_CH_A_CFG2, field CHA_LOW_THRES[11:0] (RW)
 *
 * Contains the lower compare value to compare with the conversion result when a
 * compare mode has been selected.
 */
/*@{*/
#define BP_ADC_CH_A_CFG2_CHA_LOW_THRES (0U) /*!< Bit position for ADC_CH_A_CFG2_CHA_LOW_THRES. */
#define BM_ADC_CH_A_CFG2_CHA_LOW_THRES (0x00000FFFU) /*!< Bit mask for ADC_CH_A_CFG2_CHA_LOW_THRES. */
#define BS_ADC_CH_A_CFG2_CHA_LOW_THRES (12U) /*!< Bit field size in bits for ADC_CH_A_CFG2_CHA_LOW_THRES. */

/*! @brief Read current value of the ADC_CH_A_CFG2_CHA_LOW_THRES field. */
#define BR_ADC_CH_A_CFG2_CHA_LOW_THRES(x) (HW_ADC_CH_A_CFG2(x).B.CHA_LOW_THRES)

/*! @brief Format value for bitfield ADC_CH_A_CFG2_CHA_LOW_THRES. */
#define BF_ADC_CH_A_CFG2_CHA_LOW_THRES(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_A_CFG2_CHA_LOW_THRES) & BM_ADC_CH_A_CFG2_CHA_LOW_THRES)

/*! @brief Set the CHA_LOW_THRES field to a new value. */
#define BW_ADC_CH_A_CFG2_CHA_LOW_THRES(x, v) (HW_ADC_CH_A_CFG2_WR(x, (HW_ADC_CH_A_CFG2_RD(x) & ~BM_ADC_CH_A_CFG2_CHA_LOW_THRES) | BF_ADC_CH_A_CFG2_CHA_LOW_THRES(v)))
/*@}*/

/*!
 * @name Register ADC_CH_A_CFG2, field CHA_AVG_NUMBER[13:12] (RW)
 *
 * If enable average function, this bit contains channel A average number.
 *
 * Values:
 * - 00 - Average number = 4
 * - 01 - Average number = 8
 * - 10 - Average number = 16
 * - 11 - Average number = 32
 */
/*@{*/
#define BP_ADC_CH_A_CFG2_CHA_AVG_NUMBER (12U) /*!< Bit position for ADC_CH_A_CFG2_CHA_AVG_NUMBER. */
#define BM_ADC_CH_A_CFG2_CHA_AVG_NUMBER (0x00003000U) /*!< Bit mask for ADC_CH_A_CFG2_CHA_AVG_NUMBER. */
#define BS_ADC_CH_A_CFG2_CHA_AVG_NUMBER (2U) /*!< Bit field size in bits for ADC_CH_A_CFG2_CHA_AVG_NUMBER. */

/*! @brief Read current value of the ADC_CH_A_CFG2_CHA_AVG_NUMBER field. */
#define BR_ADC_CH_A_CFG2_CHA_AVG_NUMBER(x) (HW_ADC_CH_A_CFG2(x).B.CHA_AVG_NUMBER)

/*! @brief Format value for bitfield ADC_CH_A_CFG2_CHA_AVG_NUMBER. */
#define BF_ADC_CH_A_CFG2_CHA_AVG_NUMBER(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_A_CFG2_CHA_AVG_NUMBER) & BM_ADC_CH_A_CFG2_CHA_AVG_NUMBER)

/*! @brief Set the CHA_AVG_NUMBER field to a new value. */
#define BW_ADC_CH_A_CFG2_CHA_AVG_NUMBER(x, v) (HW_ADC_CH_A_CFG2_WR(x, (HW_ADC_CH_A_CFG2_RD(x) & ~BM_ADC_CH_A_CFG2_CHA_AVG_NUMBER) | BF_ADC_CH_A_CFG2_CHA_AVG_NUMBER(v)))
/*@}*/

/*!
 * @name Register ADC_CH_A_CFG2, field CHA_AUTO_DIS[15] (RW)
 *
 * During continuous conversion, if compare match a converted result, the ADC
 * checks this bit. If CHA_AUTO_DIS = 1, then channel A stops continuous
 * conversion, if CHA_AUTO_DIS = 0, then channel A keeps continuous working, and the
 * conversion result overwrites the result registers. The default value is 1.
 */
/*@{*/
#define BP_ADC_CH_A_CFG2_CHA_AUTO_DIS (15U) /*!< Bit position for ADC_CH_A_CFG2_CHA_AUTO_DIS. */
#define BM_ADC_CH_A_CFG2_CHA_AUTO_DIS (0x00008000U) /*!< Bit mask for ADC_CH_A_CFG2_CHA_AUTO_DIS. */
#define BS_ADC_CH_A_CFG2_CHA_AUTO_DIS (1U) /*!< Bit field size in bits for ADC_CH_A_CFG2_CHA_AUTO_DIS. */

/*! @brief Read current value of the ADC_CH_A_CFG2_CHA_AUTO_DIS field. */
#define BR_ADC_CH_A_CFG2_CHA_AUTO_DIS(x) (HW_ADC_CH_A_CFG2(x).B.CHA_AUTO_DIS)

/*! @brief Format value for bitfield ADC_CH_A_CFG2_CHA_AUTO_DIS. */
#define BF_ADC_CH_A_CFG2_CHA_AUTO_DIS(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_A_CFG2_CHA_AUTO_DIS) & BM_ADC_CH_A_CFG2_CHA_AUTO_DIS)

/*! @brief Set the CHA_AUTO_DIS field to a new value. */
#define BW_ADC_CH_A_CFG2_CHA_AUTO_DIS(x, v) (HW_ADC_CH_A_CFG2_WR(x, (HW_ADC_CH_A_CFG2_RD(x) & ~BM_ADC_CH_A_CFG2_CHA_AUTO_DIS) | BF_ADC_CH_A_CFG2_CHA_AUTO_DIS(v)))
/*@}*/

/*!
 * @name Register ADC_CH_A_CFG2, field CHA_HIGH_THRES[27:16] (RW)
 *
 * Contains the high compare value to compare with the conversion result when a
 * compare mode has been selected.
 */
/*@{*/
#define BP_ADC_CH_A_CFG2_CHA_HIGH_THRES (16U) /*!< Bit position for ADC_CH_A_CFG2_CHA_HIGH_THRES. */
#define BM_ADC_CH_A_CFG2_CHA_HIGH_THRES (0x0FFF0000U) /*!< Bit mask for ADC_CH_A_CFG2_CHA_HIGH_THRES. */
#define BS_ADC_CH_A_CFG2_CHA_HIGH_THRES (12U) /*!< Bit field size in bits for ADC_CH_A_CFG2_CHA_HIGH_THRES. */

/*! @brief Read current value of the ADC_CH_A_CFG2_CHA_HIGH_THRES field. */
#define BR_ADC_CH_A_CFG2_CHA_HIGH_THRES(x) (HW_ADC_CH_A_CFG2(x).B.CHA_HIGH_THRES)

/*! @brief Format value for bitfield ADC_CH_A_CFG2_CHA_HIGH_THRES. */
#define BF_ADC_CH_A_CFG2_CHA_HIGH_THRES(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_A_CFG2_CHA_HIGH_THRES) & BM_ADC_CH_A_CFG2_CHA_HIGH_THRES)

/*! @brief Set the CHA_HIGH_THRES field to a new value. */
#define BW_ADC_CH_A_CFG2_CHA_HIGH_THRES(x, v) (HW_ADC_CH_A_CFG2_WR(x, (HW_ADC_CH_A_CFG2_RD(x) & ~BM_ADC_CH_A_CFG2_CHA_HIGH_THRES) | BF_ADC_CH_A_CFG2_CHA_HIGH_THRES(v)))
/*@}*/

/*!
 * @name Register ADC_CH_A_CFG2, field CHA_CMP_MODE[31:29] (RW)
 *
 * Select which compare mode the conversion result will take for channel A.
 *
 * Values:
 * - 001 - If channel A conversion result is greater than CHA_LOW_THRES, then an
 *     interrupt will be generated and the channel A flag will be set if they
 *     are enabled.
 * - 010 - If channel A conversion result is less than or equal to
 *     CHA_LOW_THRES, then an interrupt will be generated and channel A flag will be set if
 *     they are enabled.
 * - 011 - If channel A conversion result is greater than CHA_LOW_THRES and less
 *     than CHA_HIGH_THRES, then an interrupt will be generated and channel A
 *     flag will be set if they are enabled.
 * - 101 - If channel A conversion result is greater than or equal to
 *     CHA_HIGH_THRES, then an interrupt will be generated and channel A flag will be set
 *     if they are enabled.
 * - 110 - If channel A conversion result is less than CHA_HIGH_THRES, then an
 *     interrupt will be generated and channel A flag will be set if they are
 *     enabled.
 * - 111 - If channel A conversion result is less than or equal to
 *     CHA_LOW_THRES, and at the same time, greater than or equal to CHA_HIGH_THRES, then an
 *     interrupt will be generated and channel A flag will be set if they are
 *     enabled.
 */
/*@{*/
#define BP_ADC_CH_A_CFG2_CHA_CMP_MODE (29U) /*!< Bit position for ADC_CH_A_CFG2_CHA_CMP_MODE. */
#define BM_ADC_CH_A_CFG2_CHA_CMP_MODE (0xE0000000U) /*!< Bit mask for ADC_CH_A_CFG2_CHA_CMP_MODE. */
#define BS_ADC_CH_A_CFG2_CHA_CMP_MODE (3U) /*!< Bit field size in bits for ADC_CH_A_CFG2_CHA_CMP_MODE. */

/*! @brief Read current value of the ADC_CH_A_CFG2_CHA_CMP_MODE field. */
#define BR_ADC_CH_A_CFG2_CHA_CMP_MODE(x) (HW_ADC_CH_A_CFG2(x).B.CHA_CMP_MODE)

/*! @brief Format value for bitfield ADC_CH_A_CFG2_CHA_CMP_MODE. */
#define BF_ADC_CH_A_CFG2_CHA_CMP_MODE(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_A_CFG2_CHA_CMP_MODE) & BM_ADC_CH_A_CFG2_CHA_CMP_MODE)

/*! @brief Set the CHA_CMP_MODE field to a new value. */
#define BW_ADC_CH_A_CFG2_CHA_CMP_MODE(x, v) (HW_ADC_CH_A_CFG2_WR(x, (HW_ADC_CH_A_CFG2_RD(x) & ~BM_ADC_CH_A_CFG2_CHA_CMP_MODE) | BF_ADC_CH_A_CFG2_CHA_CMP_MODE(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_CH_B_CFG1 -
 ******************************************************************************/

/*!
 * @brief HW_ADC_CH_B_CFG1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * CH_B_CFG1 defines the functions of channel B. Channel B has the second
 * highest priority of all four channels.
 */
typedef union _hw_adc_ch_b_cfg1
{
    uint32_t U;
    struct _hw_adc_ch_b_cfg1_bitfields
    {
        uint32_t CHB_TIMER : 24;       /*!< [23:0] Channel B Timer */
        uint32_t CHB_SEL : 4;          /*!< [27:24] Channel B Select */
        uint32_t RESERVED0 : 1;        /*!< [28] This field is reserved. */
        uint32_t CHB_AVG_EN : 1;       /*!< [29] Channel B Average Enable */
        uint32_t CHB_SINGLE : 1;       /*!< [30] Channel B Single Conversion */
        uint32_t CHB_EN : 1;           /*!< [31] Channel B Enable */
    } B;
} hw_adc_ch_b_cfg1_t;

/*!
 * @name Constants and macros for entire ADC_CH_B_CFG1 register
 */
/*@{*/
#define HW_ADC_CH_B_CFG1_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_ADC_CH_B_CFG1(x)      (*(__IO hw_adc_ch_b_cfg1_t *) HW_ADC_CH_B_CFG1_ADDR(x))
#define HW_ADC_CH_B_CFG1_RD(x)   (HW_ADC_CH_B_CFG1(x).U)
#define HW_ADC_CH_B_CFG1_WR(x, v) (HW_ADC_CH_B_CFG1(x).U = (v))
#define HW_ADC_CH_B_CFG1_SET(x, v) (HW_ADC_CH_B_CFG1_WR(x, HW_ADC_CH_B_CFG1_RD(x) |  (v)))
#define HW_ADC_CH_B_CFG1_CLR(x, v) (HW_ADC_CH_B_CFG1_WR(x, HW_ADC_CH_B_CFG1_RD(x) & ~(v)))
#define HW_ADC_CH_B_CFG1_TOG(x, v) (HW_ADC_CH_B_CFG1_WR(x, HW_ADC_CH_B_CFG1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_CH_B_CFG1 bitfields
 */

/*!
 * @name Register ADC_CH_B_CFG1, field CHB_TIMER[23:0] (RW)
 *
 * This timer is for continuous conversion. The conversion rate = (CHB_TIMER +
 * 1) times sample rate + offset. Offset is due to channel B obtains lower
 * priority than channel A. In worst condition, all channel B's conversions are blocked
 * by channel A's. 0x000 to 0xFFF timer value, every CHB_TIMER + 1 times sample
 * rate + offset, the ADC converts one data.
 */
/*@{*/
#define BP_ADC_CH_B_CFG1_CHB_TIMER (0U)    /*!< Bit position for ADC_CH_B_CFG1_CHB_TIMER. */
#define BM_ADC_CH_B_CFG1_CHB_TIMER (0x00FFFFFFU) /*!< Bit mask for ADC_CH_B_CFG1_CHB_TIMER. */
#define BS_ADC_CH_B_CFG1_CHB_TIMER (24U)   /*!< Bit field size in bits for ADC_CH_B_CFG1_CHB_TIMER. */

/*! @brief Read current value of the ADC_CH_B_CFG1_CHB_TIMER field. */
#define BR_ADC_CH_B_CFG1_CHB_TIMER(x) (HW_ADC_CH_B_CFG1(x).B.CHB_TIMER)

/*! @brief Format value for bitfield ADC_CH_B_CFG1_CHB_TIMER. */
#define BF_ADC_CH_B_CFG1_CHB_TIMER(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_B_CFG1_CHB_TIMER) & BM_ADC_CH_B_CFG1_CHB_TIMER)

/*! @brief Set the CHB_TIMER field to a new value. */
#define BW_ADC_CH_B_CFG1_CHB_TIMER(x, v) (HW_ADC_CH_B_CFG1_WR(x, (HW_ADC_CH_B_CFG1_RD(x) & ~BM_ADC_CH_B_CFG1_CHB_TIMER) | BF_ADC_CH_B_CFG1_CHB_TIMER(v)))
/*@}*/

/*!
 * @name Register ADC_CH_B_CFG1, field CHB_SEL[27:24] (RW)
 *
 * Select input channel (from 16 channels) for the logical channel B.
 *
 * Values:
 * - 0000 - Channel 0
 * - 0001 - Channel 1
 * - 0010 - Channel 2
 * - 0011 - Channel 3
 * - 0100 - Channel 4
 * - 0101 - Channel 5
 * - 0110 - Channel 6
 * - 0111 - Channel 7
 * - 1000 - Channel 8
 * - 1001 - Channel 9
 * - 1010 - Channel 10
 * - 1011 - Channel 11
 * - 1100 - Channel 12
 * - 1101 - Channel 13
 * - 1110 - Channel 14
 * - 1111 - Channel 15
 */
/*@{*/
#define BP_ADC_CH_B_CFG1_CHB_SEL (24U)     /*!< Bit position for ADC_CH_B_CFG1_CHB_SEL. */
#define BM_ADC_CH_B_CFG1_CHB_SEL (0x0F000000U) /*!< Bit mask for ADC_CH_B_CFG1_CHB_SEL. */
#define BS_ADC_CH_B_CFG1_CHB_SEL (4U)      /*!< Bit field size in bits for ADC_CH_B_CFG1_CHB_SEL. */

/*! @brief Read current value of the ADC_CH_B_CFG1_CHB_SEL field. */
#define BR_ADC_CH_B_CFG1_CHB_SEL(x) (HW_ADC_CH_B_CFG1(x).B.CHB_SEL)

/*! @brief Format value for bitfield ADC_CH_B_CFG1_CHB_SEL. */
#define BF_ADC_CH_B_CFG1_CHB_SEL(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_B_CFG1_CHB_SEL) & BM_ADC_CH_B_CFG1_CHB_SEL)

/*! @brief Set the CHB_SEL field to a new value. */
#define BW_ADC_CH_B_CFG1_CHB_SEL(x, v) (HW_ADC_CH_B_CFG1_WR(x, (HW_ADC_CH_B_CFG1_RD(x) & ~BM_ADC_CH_B_CFG1_CHB_SEL) | BF_ADC_CH_B_CFG1_CHB_SEL(v)))
/*@}*/

/*!
 * @name Register ADC_CH_B_CFG1, field CHB_AVG_EN[29] (RW)
 *
 * If enable this bit, channel B will do average for each conversion.
 *
 * Values:
 * - 1 - Enable average function.
 * - 0 - Disable average function.
 */
/*@{*/
#define BP_ADC_CH_B_CFG1_CHB_AVG_EN (29U)  /*!< Bit position for ADC_CH_B_CFG1_CHB_AVG_EN. */
#define BM_ADC_CH_B_CFG1_CHB_AVG_EN (0x20000000U) /*!< Bit mask for ADC_CH_B_CFG1_CHB_AVG_EN. */
#define BS_ADC_CH_B_CFG1_CHB_AVG_EN (1U)   /*!< Bit field size in bits for ADC_CH_B_CFG1_CHB_AVG_EN. */

/*! @brief Read current value of the ADC_CH_B_CFG1_CHB_AVG_EN field. */
#define BR_ADC_CH_B_CFG1_CHB_AVG_EN(x) (HW_ADC_CH_B_CFG1(x).B.CHB_AVG_EN)

/*! @brief Format value for bitfield ADC_CH_B_CFG1_CHB_AVG_EN. */
#define BF_ADC_CH_B_CFG1_CHB_AVG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_B_CFG1_CHB_AVG_EN) & BM_ADC_CH_B_CFG1_CHB_AVG_EN)

/*! @brief Set the CHB_AVG_EN field to a new value. */
#define BW_ADC_CH_B_CFG1_CHB_AVG_EN(x, v) (HW_ADC_CH_B_CFG1_WR(x, (HW_ADC_CH_B_CFG1_RD(x) & ~BM_ADC_CH_B_CFG1_CHB_AVG_EN) | BF_ADC_CH_B_CFG1_CHB_AVG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_CH_B_CFG1, field CHB_SINGLE[30] (RW)
 *
 * Start a single conversion from logical channel B. Switch between single and
 * continuous conversion, it must disable CHB_EN first. When both CHB_EN and
 * CHB_SINGLE are enabled, CHB_SIGNAL set CHB_EN to 0 and reset itself to 0.
 *
 * Values:
 * - 1 - Start a single conversion. Continuous conversion must stop.
 * - 0 - No single conversion. Continuous conversion can start.
 */
/*@{*/
#define BP_ADC_CH_B_CFG1_CHB_SINGLE (30U)  /*!< Bit position for ADC_CH_B_CFG1_CHB_SINGLE. */
#define BM_ADC_CH_B_CFG1_CHB_SINGLE (0x40000000U) /*!< Bit mask for ADC_CH_B_CFG1_CHB_SINGLE. */
#define BS_ADC_CH_B_CFG1_CHB_SINGLE (1U)   /*!< Bit field size in bits for ADC_CH_B_CFG1_CHB_SINGLE. */

/*! @brief Read current value of the ADC_CH_B_CFG1_CHB_SINGLE field. */
#define BR_ADC_CH_B_CFG1_CHB_SINGLE(x) (HW_ADC_CH_B_CFG1(x).B.CHB_SINGLE)

/*! @brief Format value for bitfield ADC_CH_B_CFG1_CHB_SINGLE. */
#define BF_ADC_CH_B_CFG1_CHB_SINGLE(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_B_CFG1_CHB_SINGLE) & BM_ADC_CH_B_CFG1_CHB_SINGLE)

/*! @brief Set the CHB_SINGLE field to a new value. */
#define BW_ADC_CH_B_CFG1_CHB_SINGLE(x, v) (HW_ADC_CH_B_CFG1_WR(x, (HW_ADC_CH_B_CFG1_RD(x) & ~BM_ADC_CH_B_CFG1_CHB_SINGLE) | BF_ADC_CH_B_CFG1_CHB_SINGLE(v)))
/*@}*/

/*!
 * @name Register ADC_CH_B_CFG1, field CHB_EN[31] (RW)
 *
 * Controls the usable of logical channel B.
 *
 * Values:
 * - 1 - Enable logical channel B. Logical channel B will work.
 * - 0 - Disable logical channel B. Prevent logical channel B from working.
 */
/*@{*/
#define BP_ADC_CH_B_CFG1_CHB_EN (31U)      /*!< Bit position for ADC_CH_B_CFG1_CHB_EN. */
#define BM_ADC_CH_B_CFG1_CHB_EN (0x80000000U) /*!< Bit mask for ADC_CH_B_CFG1_CHB_EN. */
#define BS_ADC_CH_B_CFG1_CHB_EN (1U)       /*!< Bit field size in bits for ADC_CH_B_CFG1_CHB_EN. */

/*! @brief Read current value of the ADC_CH_B_CFG1_CHB_EN field. */
#define BR_ADC_CH_B_CFG1_CHB_EN(x) (HW_ADC_CH_B_CFG1(x).B.CHB_EN)

/*! @brief Format value for bitfield ADC_CH_B_CFG1_CHB_EN. */
#define BF_ADC_CH_B_CFG1_CHB_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_B_CFG1_CHB_EN) & BM_ADC_CH_B_CFG1_CHB_EN)

/*! @brief Set the CHB_EN field to a new value. */
#define BW_ADC_CH_B_CFG1_CHB_EN(x, v) (HW_ADC_CH_B_CFG1_WR(x, (HW_ADC_CH_B_CFG1_RD(x) & ~BM_ADC_CH_B_CFG1_CHB_EN) | BF_ADC_CH_B_CFG1_CHB_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_CH_B_CFG2 - Channel B Configuration 2
 ******************************************************************************/

/*!
 * @brief HW_ADC_CH_B_CFG2 - Channel B Configuration 2 (RW)
 *
 * Reset value: 0x00008000U
 *
 * CH_B_CFG2 defines the functions of channel B. Channel B has the second
 * highest priority of all four channels.
 */
typedef union _hw_adc_ch_b_cfg2
{
    uint32_t U;
    struct _hw_adc_ch_b_cfg2_bitfields
    {
        uint32_t CHB_LOW_THRES : 12;   /*!< [11:0] Channel B Low Threshold
                                        * Value */
        uint32_t CHB_AVG_NUMBER : 2;   /*!< [13:12] Channel B Average Number */
        uint32_t RESERVED0 : 1;        /*!< [14] This field is reserved. */
        uint32_t CHB_AUTO_DIS : 1;     /*!< [15] Channel B Auto Disable */
        uint32_t CHB_HIGH_THRES : 12;  /*!< [27:16] Channel B High Threshold
                                        * Value */
        uint32_t RESERVED1 : 1;        /*!< [28] This field is reserved. */
        uint32_t CHB_CMP_MODE : 3;     /*!< [31:29] Channel B Compare Mode */
    } B;
} hw_adc_ch_b_cfg2_t;

/*!
 * @name Constants and macros for entire ADC_CH_B_CFG2 register
 */
/*@{*/
#define HW_ADC_CH_B_CFG2_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_ADC_CH_B_CFG2(x)      (*(__IO hw_adc_ch_b_cfg2_t *) HW_ADC_CH_B_CFG2_ADDR(x))
#define HW_ADC_CH_B_CFG2_RD(x)   (HW_ADC_CH_B_CFG2(x).U)
#define HW_ADC_CH_B_CFG2_WR(x, v) (HW_ADC_CH_B_CFG2(x).U = (v))
#define HW_ADC_CH_B_CFG2_SET(x, v) (HW_ADC_CH_B_CFG2_WR(x, HW_ADC_CH_B_CFG2_RD(x) |  (v)))
#define HW_ADC_CH_B_CFG2_CLR(x, v) (HW_ADC_CH_B_CFG2_WR(x, HW_ADC_CH_B_CFG2_RD(x) & ~(v)))
#define HW_ADC_CH_B_CFG2_TOG(x, v) (HW_ADC_CH_B_CFG2_WR(x, HW_ADC_CH_B_CFG2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_CH_B_CFG2 bitfields
 */

/*!
 * @name Register ADC_CH_B_CFG2, field CHB_LOW_THRES[11:0] (RW)
 *
 * Contains the smaller compare value to compare with the conversion result when
 * a compare mode has been selected.
 */
/*@{*/
#define BP_ADC_CH_B_CFG2_CHB_LOW_THRES (0U) /*!< Bit position for ADC_CH_B_CFG2_CHB_LOW_THRES. */
#define BM_ADC_CH_B_CFG2_CHB_LOW_THRES (0x00000FFFU) /*!< Bit mask for ADC_CH_B_CFG2_CHB_LOW_THRES. */
#define BS_ADC_CH_B_CFG2_CHB_LOW_THRES (12U) /*!< Bit field size in bits for ADC_CH_B_CFG2_CHB_LOW_THRES. */

/*! @brief Read current value of the ADC_CH_B_CFG2_CHB_LOW_THRES field. */
#define BR_ADC_CH_B_CFG2_CHB_LOW_THRES(x) (HW_ADC_CH_B_CFG2(x).B.CHB_LOW_THRES)

/*! @brief Format value for bitfield ADC_CH_B_CFG2_CHB_LOW_THRES. */
#define BF_ADC_CH_B_CFG2_CHB_LOW_THRES(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_B_CFG2_CHB_LOW_THRES) & BM_ADC_CH_B_CFG2_CHB_LOW_THRES)

/*! @brief Set the CHB_LOW_THRES field to a new value. */
#define BW_ADC_CH_B_CFG2_CHB_LOW_THRES(x, v) (HW_ADC_CH_B_CFG2_WR(x, (HW_ADC_CH_B_CFG2_RD(x) & ~BM_ADC_CH_B_CFG2_CHB_LOW_THRES) | BF_ADC_CH_B_CFG2_CHB_LOW_THRES(v)))
/*@}*/

/*!
 * @name Register ADC_CH_B_CFG2, field CHB_AVG_NUMBER[13:12] (RW)
 *
 * If enable average function, this bit contains channel B average number.
 *
 * Values:
 * - 00 - Average number = 4
 * - 01 - Average number = 8
 * - 10 - Average number = 16
 * - 11 - Average number = 32
 */
/*@{*/
#define BP_ADC_CH_B_CFG2_CHB_AVG_NUMBER (12U) /*!< Bit position for ADC_CH_B_CFG2_CHB_AVG_NUMBER. */
#define BM_ADC_CH_B_CFG2_CHB_AVG_NUMBER (0x00003000U) /*!< Bit mask for ADC_CH_B_CFG2_CHB_AVG_NUMBER. */
#define BS_ADC_CH_B_CFG2_CHB_AVG_NUMBER (2U) /*!< Bit field size in bits for ADC_CH_B_CFG2_CHB_AVG_NUMBER. */

/*! @brief Read current value of the ADC_CH_B_CFG2_CHB_AVG_NUMBER field. */
#define BR_ADC_CH_B_CFG2_CHB_AVG_NUMBER(x) (HW_ADC_CH_B_CFG2(x).B.CHB_AVG_NUMBER)

/*! @brief Format value for bitfield ADC_CH_B_CFG2_CHB_AVG_NUMBER. */
#define BF_ADC_CH_B_CFG2_CHB_AVG_NUMBER(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_B_CFG2_CHB_AVG_NUMBER) & BM_ADC_CH_B_CFG2_CHB_AVG_NUMBER)

/*! @brief Set the CHB_AVG_NUMBER field to a new value. */
#define BW_ADC_CH_B_CFG2_CHB_AVG_NUMBER(x, v) (HW_ADC_CH_B_CFG2_WR(x, (HW_ADC_CH_B_CFG2_RD(x) & ~BM_ADC_CH_B_CFG2_CHB_AVG_NUMBER) | BF_ADC_CH_B_CFG2_CHB_AVG_NUMBER(v)))
/*@}*/

/*!
 * @name Register ADC_CH_B_CFG2, field CHB_AUTO_DIS[15] (RW)
 *
 * During continuous conversion, if compare match a converted result, the ADC
 * checks this bit. If CHB_AUTO_DIS = 1, then channel B stops continuous
 * conversion, if CHB_AUTO_DIS = 0, then channel B keeps continuous working, and the
 * conversion result overwrites the result registers. The default value is 1.
 */
/*@{*/
#define BP_ADC_CH_B_CFG2_CHB_AUTO_DIS (15U) /*!< Bit position for ADC_CH_B_CFG2_CHB_AUTO_DIS. */
#define BM_ADC_CH_B_CFG2_CHB_AUTO_DIS (0x00008000U) /*!< Bit mask for ADC_CH_B_CFG2_CHB_AUTO_DIS. */
#define BS_ADC_CH_B_CFG2_CHB_AUTO_DIS (1U) /*!< Bit field size in bits for ADC_CH_B_CFG2_CHB_AUTO_DIS. */

/*! @brief Read current value of the ADC_CH_B_CFG2_CHB_AUTO_DIS field. */
#define BR_ADC_CH_B_CFG2_CHB_AUTO_DIS(x) (HW_ADC_CH_B_CFG2(x).B.CHB_AUTO_DIS)

/*! @brief Format value for bitfield ADC_CH_B_CFG2_CHB_AUTO_DIS. */
#define BF_ADC_CH_B_CFG2_CHB_AUTO_DIS(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_B_CFG2_CHB_AUTO_DIS) & BM_ADC_CH_B_CFG2_CHB_AUTO_DIS)

/*! @brief Set the CHB_AUTO_DIS field to a new value. */
#define BW_ADC_CH_B_CFG2_CHB_AUTO_DIS(x, v) (HW_ADC_CH_B_CFG2_WR(x, (HW_ADC_CH_B_CFG2_RD(x) & ~BM_ADC_CH_B_CFG2_CHB_AUTO_DIS) | BF_ADC_CH_B_CFG2_CHB_AUTO_DIS(v)))
/*@}*/

/*!
 * @name Register ADC_CH_B_CFG2, field CHB_HIGH_THRES[27:16] (RW)
 *
 * Contains the bigger compare value to compare with the conversion result when
 * a compare mode has been selected.
 */
/*@{*/
#define BP_ADC_CH_B_CFG2_CHB_HIGH_THRES (16U) /*!< Bit position for ADC_CH_B_CFG2_CHB_HIGH_THRES. */
#define BM_ADC_CH_B_CFG2_CHB_HIGH_THRES (0x0FFF0000U) /*!< Bit mask for ADC_CH_B_CFG2_CHB_HIGH_THRES. */
#define BS_ADC_CH_B_CFG2_CHB_HIGH_THRES (12U) /*!< Bit field size in bits for ADC_CH_B_CFG2_CHB_HIGH_THRES. */

/*! @brief Read current value of the ADC_CH_B_CFG2_CHB_HIGH_THRES field. */
#define BR_ADC_CH_B_CFG2_CHB_HIGH_THRES(x) (HW_ADC_CH_B_CFG2(x).B.CHB_HIGH_THRES)

/*! @brief Format value for bitfield ADC_CH_B_CFG2_CHB_HIGH_THRES. */
#define BF_ADC_CH_B_CFG2_CHB_HIGH_THRES(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_B_CFG2_CHB_HIGH_THRES) & BM_ADC_CH_B_CFG2_CHB_HIGH_THRES)

/*! @brief Set the CHB_HIGH_THRES field to a new value. */
#define BW_ADC_CH_B_CFG2_CHB_HIGH_THRES(x, v) (HW_ADC_CH_B_CFG2_WR(x, (HW_ADC_CH_B_CFG2_RD(x) & ~BM_ADC_CH_B_CFG2_CHB_HIGH_THRES) | BF_ADC_CH_B_CFG2_CHB_HIGH_THRES(v)))
/*@}*/

/*!
 * @name Register ADC_CH_B_CFG2, field CHB_CMP_MODE[31:29] (RW)
 *
 * Select which compare mode the conversion result will take for channel B.
 *
 * Values:
 * - 001 - If channel B conversion result is greater than CHB_LOW_THRES, then an
 *     interrupt will be generated and the channel B flag will be set if they
 *     are enabled.
 * - 010 - If channel B conversion result is less than or equal to
 *     CHB_LOW_THRES, then an interrupt will be generated and channel B flag will be set if
 *     they are enabled.
 * - 011 - If channel B conversion result is greater than CHB_LOW_THRES and less
 *     than CHB_HIGH_THRES, then an interrupt will be generated and channel B
 *     flag will be set if they are enabled.
 * - 101 - If channel B conversion result is greater than or equal to
 *     CHB_HIGH_THRES, then an interrupt will be generated and channel B flag will be set
 *     if they are enabled.
 * - 110 - If channel B conversion result is less than CHB_HIGH_THRES, then an
 *     interrupt will be generated and channel B flag will be set if they are
 *     enabled.
 * - 111 - If channel B conversion result is less than or equal to
 *     CHB_LOW_THRES, and at the same time, is greater than or equal to CHB_HIGH_THRES, then
 *     an interrupt will be generated and channel B flag will be set.
 */
/*@{*/
#define BP_ADC_CH_B_CFG2_CHB_CMP_MODE (29U) /*!< Bit position for ADC_CH_B_CFG2_CHB_CMP_MODE. */
#define BM_ADC_CH_B_CFG2_CHB_CMP_MODE (0xE0000000U) /*!< Bit mask for ADC_CH_B_CFG2_CHB_CMP_MODE. */
#define BS_ADC_CH_B_CFG2_CHB_CMP_MODE (3U) /*!< Bit field size in bits for ADC_CH_B_CFG2_CHB_CMP_MODE. */

/*! @brief Read current value of the ADC_CH_B_CFG2_CHB_CMP_MODE field. */
#define BR_ADC_CH_B_CFG2_CHB_CMP_MODE(x) (HW_ADC_CH_B_CFG2(x).B.CHB_CMP_MODE)

/*! @brief Format value for bitfield ADC_CH_B_CFG2_CHB_CMP_MODE. */
#define BF_ADC_CH_B_CFG2_CHB_CMP_MODE(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_B_CFG2_CHB_CMP_MODE) & BM_ADC_CH_B_CFG2_CHB_CMP_MODE)

/*! @brief Set the CHB_CMP_MODE field to a new value. */
#define BW_ADC_CH_B_CFG2_CHB_CMP_MODE(x, v) (HW_ADC_CH_B_CFG2_WR(x, (HW_ADC_CH_B_CFG2_RD(x) & ~BM_ADC_CH_B_CFG2_CHB_CMP_MODE) | BF_ADC_CH_B_CFG2_CHB_CMP_MODE(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_CH_C_CFG1 - Channel C Configuration 1
 ******************************************************************************/

/*!
 * @brief HW_ADC_CH_C_CFG1 - Channel C Configuration 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_adc_ch_c_cfg1
{
    uint32_t U;
    struct _hw_adc_ch_c_cfg1_bitfields
    {
        uint32_t CHC_TIMER : 24;       /*!< [23:0] Channel C Timer */
        uint32_t CHC_SEL : 4;          /*!< [27:24] Channel C Select */
        uint32_t RESERVED0 : 1;        /*!< [28] This field is reserved. */
        uint32_t CHC_AVG_EN : 1;       /*!< [29] Channel C Average Enable */
        uint32_t CHC_SINGLE : 1;       /*!< [30] Channel C Single Conversion Start
                                        * a single conversion from logical channel C. Switch between single and
                                        * continuous conversion, it must disable CHC_EN. When both CHC_EN and
                                        * CHC_SINGLE are enabled, CHC_SIGNAL set CHC_EN to 0 and reset itself to 0. */
        uint32_t CHC_EN : 1;           /*!< [31] Channel C Enable */
    } B;
} hw_adc_ch_c_cfg1_t;

/*!
 * @name Constants and macros for entire ADC_CH_C_CFG1 register
 */
/*@{*/
#define HW_ADC_CH_C_CFG1_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_ADC_CH_C_CFG1(x)      (*(__IO hw_adc_ch_c_cfg1_t *) HW_ADC_CH_C_CFG1_ADDR(x))
#define HW_ADC_CH_C_CFG1_RD(x)   (HW_ADC_CH_C_CFG1(x).U)
#define HW_ADC_CH_C_CFG1_WR(x, v) (HW_ADC_CH_C_CFG1(x).U = (v))
#define HW_ADC_CH_C_CFG1_SET(x, v) (HW_ADC_CH_C_CFG1_WR(x, HW_ADC_CH_C_CFG1_RD(x) |  (v)))
#define HW_ADC_CH_C_CFG1_CLR(x, v) (HW_ADC_CH_C_CFG1_WR(x, HW_ADC_CH_C_CFG1_RD(x) & ~(v)))
#define HW_ADC_CH_C_CFG1_TOG(x, v) (HW_ADC_CH_C_CFG1_WR(x, HW_ADC_CH_C_CFG1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_CH_C_CFG1 bitfields
 */

/*!
 * @name Register ADC_CH_C_CFG1, field CHC_TIMER[23:0] (RW)
 *
 * This timer is for continuous conversion. The conversion rate = (CHC_TIMER +
 * 1) times sample rate + offset. The offset is due to channel C has lower
 * priority than channel A and channel B. In worst condition, all channel C conversions
 * are blocked by channel A and channel B's. 0x000 to 0xFFF timer value, every
 * CHC_TIMER + 1 times sample rate + offset, the ADC converts one data.
 */
/*@{*/
#define BP_ADC_CH_C_CFG1_CHC_TIMER (0U)    /*!< Bit position for ADC_CH_C_CFG1_CHC_TIMER. */
#define BM_ADC_CH_C_CFG1_CHC_TIMER (0x00FFFFFFU) /*!< Bit mask for ADC_CH_C_CFG1_CHC_TIMER. */
#define BS_ADC_CH_C_CFG1_CHC_TIMER (24U)   /*!< Bit field size in bits for ADC_CH_C_CFG1_CHC_TIMER. */

/*! @brief Read current value of the ADC_CH_C_CFG1_CHC_TIMER field. */
#define BR_ADC_CH_C_CFG1_CHC_TIMER(x) (HW_ADC_CH_C_CFG1(x).B.CHC_TIMER)

/*! @brief Format value for bitfield ADC_CH_C_CFG1_CHC_TIMER. */
#define BF_ADC_CH_C_CFG1_CHC_TIMER(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_C_CFG1_CHC_TIMER) & BM_ADC_CH_C_CFG1_CHC_TIMER)

/*! @brief Set the CHC_TIMER field to a new value. */
#define BW_ADC_CH_C_CFG1_CHC_TIMER(x, v) (HW_ADC_CH_C_CFG1_WR(x, (HW_ADC_CH_C_CFG1_RD(x) & ~BM_ADC_CH_C_CFG1_CHC_TIMER) | BF_ADC_CH_C_CFG1_CHC_TIMER(v)))
/*@}*/

/*!
 * @name Register ADC_CH_C_CFG1, field CHC_SEL[27:24] (RW)
 *
 * Select input channel (from 16 channels) for the logical channel C.
 *
 * Values:
 * - 0000 - Channel 0
 * - 0001 - Channel 1
 * - 0010 - Channel 2
 * - 0011 - Channel 3
 * - 0100 - Channel 4
 * - 0101 - Channel 5
 * - 0110 - Channel 6
 * - 0111 - Channel 7
 * - 1000 - Channel 8
 * - 1001 - Channel 9
 * - 1010 - Channel 10
 * - 1011 - Channel 11
 * - 1100 - Channel 12
 * - 1101 - Channel 13
 * - 1110 - Channel 14
 * - 1111 - Channel 15
 */
/*@{*/
#define BP_ADC_CH_C_CFG1_CHC_SEL (24U)     /*!< Bit position for ADC_CH_C_CFG1_CHC_SEL. */
#define BM_ADC_CH_C_CFG1_CHC_SEL (0x0F000000U) /*!< Bit mask for ADC_CH_C_CFG1_CHC_SEL. */
#define BS_ADC_CH_C_CFG1_CHC_SEL (4U)      /*!< Bit field size in bits for ADC_CH_C_CFG1_CHC_SEL. */

/*! @brief Read current value of the ADC_CH_C_CFG1_CHC_SEL field. */
#define BR_ADC_CH_C_CFG1_CHC_SEL(x) (HW_ADC_CH_C_CFG1(x).B.CHC_SEL)

/*! @brief Format value for bitfield ADC_CH_C_CFG1_CHC_SEL. */
#define BF_ADC_CH_C_CFG1_CHC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_C_CFG1_CHC_SEL) & BM_ADC_CH_C_CFG1_CHC_SEL)

/*! @brief Set the CHC_SEL field to a new value. */
#define BW_ADC_CH_C_CFG1_CHC_SEL(x, v) (HW_ADC_CH_C_CFG1_WR(x, (HW_ADC_CH_C_CFG1_RD(x) & ~BM_ADC_CH_C_CFG1_CHC_SEL) | BF_ADC_CH_C_CFG1_CHC_SEL(v)))
/*@}*/

/*!
 * @name Register ADC_CH_C_CFG1, field CHC_AVG_EN[29] (RW)
 *
 * If enable this bit, channel C will do average for each conversion.
 *
 * Values:
 * - 1 - Enable average function.
 * - 0 - Disable average function.
 */
/*@{*/
#define BP_ADC_CH_C_CFG1_CHC_AVG_EN (29U)  /*!< Bit position for ADC_CH_C_CFG1_CHC_AVG_EN. */
#define BM_ADC_CH_C_CFG1_CHC_AVG_EN (0x20000000U) /*!< Bit mask for ADC_CH_C_CFG1_CHC_AVG_EN. */
#define BS_ADC_CH_C_CFG1_CHC_AVG_EN (1U)   /*!< Bit field size in bits for ADC_CH_C_CFG1_CHC_AVG_EN. */

/*! @brief Read current value of the ADC_CH_C_CFG1_CHC_AVG_EN field. */
#define BR_ADC_CH_C_CFG1_CHC_AVG_EN(x) (HW_ADC_CH_C_CFG1(x).B.CHC_AVG_EN)

/*! @brief Format value for bitfield ADC_CH_C_CFG1_CHC_AVG_EN. */
#define BF_ADC_CH_C_CFG1_CHC_AVG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_C_CFG1_CHC_AVG_EN) & BM_ADC_CH_C_CFG1_CHC_AVG_EN)

/*! @brief Set the CHC_AVG_EN field to a new value. */
#define BW_ADC_CH_C_CFG1_CHC_AVG_EN(x, v) (HW_ADC_CH_C_CFG1_WR(x, (HW_ADC_CH_C_CFG1_RD(x) & ~BM_ADC_CH_C_CFG1_CHC_AVG_EN) | BF_ADC_CH_C_CFG1_CHC_AVG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_CH_C_CFG1, field CHC_SINGLE[30] (RW)
 *
 * Controls the usable of logical channel C.
 *
 * Values:
 * - 1 - Start a single conversion. Continuous conversion must stop.
 * - 0 - No single conversion. Continuous conversion can start.
 */
/*@{*/
#define BP_ADC_CH_C_CFG1_CHC_SINGLE (30U)  /*!< Bit position for ADC_CH_C_CFG1_CHC_SINGLE. */
#define BM_ADC_CH_C_CFG1_CHC_SINGLE (0x40000000U) /*!< Bit mask for ADC_CH_C_CFG1_CHC_SINGLE. */
#define BS_ADC_CH_C_CFG1_CHC_SINGLE (1U)   /*!< Bit field size in bits for ADC_CH_C_CFG1_CHC_SINGLE. */

/*! @brief Read current value of the ADC_CH_C_CFG1_CHC_SINGLE field. */
#define BR_ADC_CH_C_CFG1_CHC_SINGLE(x) (HW_ADC_CH_C_CFG1(x).B.CHC_SINGLE)

/*! @brief Format value for bitfield ADC_CH_C_CFG1_CHC_SINGLE. */
#define BF_ADC_CH_C_CFG1_CHC_SINGLE(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_C_CFG1_CHC_SINGLE) & BM_ADC_CH_C_CFG1_CHC_SINGLE)

/*! @brief Set the CHC_SINGLE field to a new value. */
#define BW_ADC_CH_C_CFG1_CHC_SINGLE(x, v) (HW_ADC_CH_C_CFG1_WR(x, (HW_ADC_CH_C_CFG1_RD(x) & ~BM_ADC_CH_C_CFG1_CHC_SINGLE) | BF_ADC_CH_C_CFG1_CHC_SINGLE(v)))
/*@}*/

/*!
 * @name Register ADC_CH_C_CFG1, field CHC_EN[31] (RW)
 *
 * Controls the usable of logical channel C.
 *
 * Values:
 * - 1 - Enable logical channel C. Logical channel C will work.
 * - 0 - Disable logical channel C. Prevent logical channel C from working.
 */
/*@{*/
#define BP_ADC_CH_C_CFG1_CHC_EN (31U)      /*!< Bit position for ADC_CH_C_CFG1_CHC_EN. */
#define BM_ADC_CH_C_CFG1_CHC_EN (0x80000000U) /*!< Bit mask for ADC_CH_C_CFG1_CHC_EN. */
#define BS_ADC_CH_C_CFG1_CHC_EN (1U)       /*!< Bit field size in bits for ADC_CH_C_CFG1_CHC_EN. */

/*! @brief Read current value of the ADC_CH_C_CFG1_CHC_EN field. */
#define BR_ADC_CH_C_CFG1_CHC_EN(x) (HW_ADC_CH_C_CFG1(x).B.CHC_EN)

/*! @brief Format value for bitfield ADC_CH_C_CFG1_CHC_EN. */
#define BF_ADC_CH_C_CFG1_CHC_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_C_CFG1_CHC_EN) & BM_ADC_CH_C_CFG1_CHC_EN)

/*! @brief Set the CHC_EN field to a new value. */
#define BW_ADC_CH_C_CFG1_CHC_EN(x, v) (HW_ADC_CH_C_CFG1_WR(x, (HW_ADC_CH_C_CFG1_RD(x) & ~BM_ADC_CH_C_CFG1_CHC_EN) | BF_ADC_CH_C_CFG1_CHC_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_CH_C_CFG2 - Channel C Configuration 2
 ******************************************************************************/

/*!
 * @brief HW_ADC_CH_C_CFG2 - Channel C Configuration 2 (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_adc_ch_c_cfg2
{
    uint32_t U;
    struct _hw_adc_ch_c_cfg2_bitfields
    {
        uint32_t CHC_LOW_THRES : 12;   /*!< [11:0] Channel C Low Threshold
                                        * Value */
        uint32_t CHC_AVG_NUMBER : 2;   /*!< [13:12] Channel C Average Number */
        uint32_t RESERVED0 : 1;        /*!< [14] This field is reserved. */
        uint32_t CHC_AUTO_DIS : 1;     /*!< [15] Channel C Auto Disable */
        uint32_t CHC_HIGH_THRES : 12;  /*!< [27:16] Channel C High Threshold
                                        * Value */
        uint32_t RESERVED1 : 1;        /*!< [28] This field is reserved. */
        uint32_t CHC_CMP_MODE : 3;     /*!< [31:29] Channel C Compare Mode */
    } B;
} hw_adc_ch_c_cfg2_t;

/*!
 * @name Constants and macros for entire ADC_CH_C_CFG2 register
 */
/*@{*/
#define HW_ADC_CH_C_CFG2_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_ADC_CH_C_CFG2(x)      (*(__IO hw_adc_ch_c_cfg2_t *) HW_ADC_CH_C_CFG2_ADDR(x))
#define HW_ADC_CH_C_CFG2_RD(x)   (HW_ADC_CH_C_CFG2(x).U)
#define HW_ADC_CH_C_CFG2_WR(x, v) (HW_ADC_CH_C_CFG2(x).U = (v))
#define HW_ADC_CH_C_CFG2_SET(x, v) (HW_ADC_CH_C_CFG2_WR(x, HW_ADC_CH_C_CFG2_RD(x) |  (v)))
#define HW_ADC_CH_C_CFG2_CLR(x, v) (HW_ADC_CH_C_CFG2_WR(x, HW_ADC_CH_C_CFG2_RD(x) & ~(v)))
#define HW_ADC_CH_C_CFG2_TOG(x, v) (HW_ADC_CH_C_CFG2_WR(x, HW_ADC_CH_C_CFG2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_CH_C_CFG2 bitfields
 */

/*!
 * @name Register ADC_CH_C_CFG2, field CHC_LOW_THRES[11:0] (RW)
 *
 * Contains the smaller compare value to compare with the conversion result when
 * a compare mode has been selected.
 */
/*@{*/
#define BP_ADC_CH_C_CFG2_CHC_LOW_THRES (0U) /*!< Bit position for ADC_CH_C_CFG2_CHC_LOW_THRES. */
#define BM_ADC_CH_C_CFG2_CHC_LOW_THRES (0x00000FFFU) /*!< Bit mask for ADC_CH_C_CFG2_CHC_LOW_THRES. */
#define BS_ADC_CH_C_CFG2_CHC_LOW_THRES (12U) /*!< Bit field size in bits for ADC_CH_C_CFG2_CHC_LOW_THRES. */

/*! @brief Read current value of the ADC_CH_C_CFG2_CHC_LOW_THRES field. */
#define BR_ADC_CH_C_CFG2_CHC_LOW_THRES(x) (HW_ADC_CH_C_CFG2(x).B.CHC_LOW_THRES)

/*! @brief Format value for bitfield ADC_CH_C_CFG2_CHC_LOW_THRES. */
#define BF_ADC_CH_C_CFG2_CHC_LOW_THRES(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_C_CFG2_CHC_LOW_THRES) & BM_ADC_CH_C_CFG2_CHC_LOW_THRES)

/*! @brief Set the CHC_LOW_THRES field to a new value. */
#define BW_ADC_CH_C_CFG2_CHC_LOW_THRES(x, v) (HW_ADC_CH_C_CFG2_WR(x, (HW_ADC_CH_C_CFG2_RD(x) & ~BM_ADC_CH_C_CFG2_CHC_LOW_THRES) | BF_ADC_CH_C_CFG2_CHC_LOW_THRES(v)))
/*@}*/

/*!
 * @name Register ADC_CH_C_CFG2, field CHC_AVG_NUMBER[13:12] (RW)
 *
 * If enable average function, this bit contains channel C average number.
 *
 * Values:
 * - 00 - Average number = 4
 * - 01 - Average number = 8
 * - 10 - Average number = 16
 * - 11 - Average number = 32
 */
/*@{*/
#define BP_ADC_CH_C_CFG2_CHC_AVG_NUMBER (12U) /*!< Bit position for ADC_CH_C_CFG2_CHC_AVG_NUMBER. */
#define BM_ADC_CH_C_CFG2_CHC_AVG_NUMBER (0x00003000U) /*!< Bit mask for ADC_CH_C_CFG2_CHC_AVG_NUMBER. */
#define BS_ADC_CH_C_CFG2_CHC_AVG_NUMBER (2U) /*!< Bit field size in bits for ADC_CH_C_CFG2_CHC_AVG_NUMBER. */

/*! @brief Read current value of the ADC_CH_C_CFG2_CHC_AVG_NUMBER field. */
#define BR_ADC_CH_C_CFG2_CHC_AVG_NUMBER(x) (HW_ADC_CH_C_CFG2(x).B.CHC_AVG_NUMBER)

/*! @brief Format value for bitfield ADC_CH_C_CFG2_CHC_AVG_NUMBER. */
#define BF_ADC_CH_C_CFG2_CHC_AVG_NUMBER(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_C_CFG2_CHC_AVG_NUMBER) & BM_ADC_CH_C_CFG2_CHC_AVG_NUMBER)

/*! @brief Set the CHC_AVG_NUMBER field to a new value. */
#define BW_ADC_CH_C_CFG2_CHC_AVG_NUMBER(x, v) (HW_ADC_CH_C_CFG2_WR(x, (HW_ADC_CH_C_CFG2_RD(x) & ~BM_ADC_CH_C_CFG2_CHC_AVG_NUMBER) | BF_ADC_CH_C_CFG2_CHC_AVG_NUMBER(v)))
/*@}*/

/*!
 * @name Register ADC_CH_C_CFG2, field CHC_AUTO_DIS[15] (RW)
 *
 * During continuous conversion, if compare match a converted result, the ADC
 * checks this bit. If CHC_AUTO_DIS = 1, then channel C stops continuous
 * conversion, if CHC_AUTO_DIS = 0, then channel C keeps continuous working, and the
 * conversion result overwrites the result registers. The default value is 1.
 */
/*@{*/
#define BP_ADC_CH_C_CFG2_CHC_AUTO_DIS (15U) /*!< Bit position for ADC_CH_C_CFG2_CHC_AUTO_DIS. */
#define BM_ADC_CH_C_CFG2_CHC_AUTO_DIS (0x00008000U) /*!< Bit mask for ADC_CH_C_CFG2_CHC_AUTO_DIS. */
#define BS_ADC_CH_C_CFG2_CHC_AUTO_DIS (1U) /*!< Bit field size in bits for ADC_CH_C_CFG2_CHC_AUTO_DIS. */

/*! @brief Read current value of the ADC_CH_C_CFG2_CHC_AUTO_DIS field. */
#define BR_ADC_CH_C_CFG2_CHC_AUTO_DIS(x) (HW_ADC_CH_C_CFG2(x).B.CHC_AUTO_DIS)

/*! @brief Format value for bitfield ADC_CH_C_CFG2_CHC_AUTO_DIS. */
#define BF_ADC_CH_C_CFG2_CHC_AUTO_DIS(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_C_CFG2_CHC_AUTO_DIS) & BM_ADC_CH_C_CFG2_CHC_AUTO_DIS)

/*! @brief Set the CHC_AUTO_DIS field to a new value. */
#define BW_ADC_CH_C_CFG2_CHC_AUTO_DIS(x, v) (HW_ADC_CH_C_CFG2_WR(x, (HW_ADC_CH_C_CFG2_RD(x) & ~BM_ADC_CH_C_CFG2_CHC_AUTO_DIS) | BF_ADC_CH_C_CFG2_CHC_AUTO_DIS(v)))
/*@}*/

/*!
 * @name Register ADC_CH_C_CFG2, field CHC_HIGH_THRES[27:16] (RW)
 *
 * Contains the bigger compare value to compare with the conversion result when
 * a compare mode has been selected.
 */
/*@{*/
#define BP_ADC_CH_C_CFG2_CHC_HIGH_THRES (16U) /*!< Bit position for ADC_CH_C_CFG2_CHC_HIGH_THRES. */
#define BM_ADC_CH_C_CFG2_CHC_HIGH_THRES (0x0FFF0000U) /*!< Bit mask for ADC_CH_C_CFG2_CHC_HIGH_THRES. */
#define BS_ADC_CH_C_CFG2_CHC_HIGH_THRES (12U) /*!< Bit field size in bits for ADC_CH_C_CFG2_CHC_HIGH_THRES. */

/*! @brief Read current value of the ADC_CH_C_CFG2_CHC_HIGH_THRES field. */
#define BR_ADC_CH_C_CFG2_CHC_HIGH_THRES(x) (HW_ADC_CH_C_CFG2(x).B.CHC_HIGH_THRES)

/*! @brief Format value for bitfield ADC_CH_C_CFG2_CHC_HIGH_THRES. */
#define BF_ADC_CH_C_CFG2_CHC_HIGH_THRES(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_C_CFG2_CHC_HIGH_THRES) & BM_ADC_CH_C_CFG2_CHC_HIGH_THRES)

/*! @brief Set the CHC_HIGH_THRES field to a new value. */
#define BW_ADC_CH_C_CFG2_CHC_HIGH_THRES(x, v) (HW_ADC_CH_C_CFG2_WR(x, (HW_ADC_CH_C_CFG2_RD(x) & ~BM_ADC_CH_C_CFG2_CHC_HIGH_THRES) | BF_ADC_CH_C_CFG2_CHC_HIGH_THRES(v)))
/*@}*/

/*!
 * @name Register ADC_CH_C_CFG2, field CHC_CMP_MODE[31:29] (RW)
 *
 * Select which compare mode the conversion result will take (for channel C).
 *
 * Values:
 * - 001 - If channel C conversion result bigger than CHC_LOW_THRES, then an
 *     interrupt will be generated and the channel C flag will be set if they are
 *     enabled.
 * - 010 - If channel C conversion result smaller or equal to CHC_LOW_THRES,
 *     then an interrupt will be generated and channel C flag will be set if they
 *     are enabled.
 * - 011 - If channel C conversion result bigger than CHC_LOW_THRES and smaller
 *     than CHC_HIGH_THRES, then an interrupt will be generated and channel C
 *     flag will be set if they are enabled.
 * - 101 - If channel C conversion result bigger or equal to CHC_HIGH_THRES,
 *     then an interrupt will be generated and channel C flag will be set if they
 *     are enabled.
 * - 110 - If channel C conversion result smaller than CHC_HIGH_THRES, then an
 *     interrupt will be generated and channel C flag will be set if they are
 *     enabled.
 * - 111 - If channel C conversion result smaller or equal to CHC_LOW_THRES, and
 *     at the same time, bigger or equal to CHC_HIGH_THRES, then an interrupt
 *     will be generated and channel C flag will be set if they are enabled.
 */
/*@{*/
#define BP_ADC_CH_C_CFG2_CHC_CMP_MODE (29U) /*!< Bit position for ADC_CH_C_CFG2_CHC_CMP_MODE. */
#define BM_ADC_CH_C_CFG2_CHC_CMP_MODE (0xE0000000U) /*!< Bit mask for ADC_CH_C_CFG2_CHC_CMP_MODE. */
#define BS_ADC_CH_C_CFG2_CHC_CMP_MODE (3U) /*!< Bit field size in bits for ADC_CH_C_CFG2_CHC_CMP_MODE. */

/*! @brief Read current value of the ADC_CH_C_CFG2_CHC_CMP_MODE field. */
#define BR_ADC_CH_C_CFG2_CHC_CMP_MODE(x) (HW_ADC_CH_C_CFG2(x).B.CHC_CMP_MODE)

/*! @brief Format value for bitfield ADC_CH_C_CFG2_CHC_CMP_MODE. */
#define BF_ADC_CH_C_CFG2_CHC_CMP_MODE(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_C_CFG2_CHC_CMP_MODE) & BM_ADC_CH_C_CFG2_CHC_CMP_MODE)

/*! @brief Set the CHC_CMP_MODE field to a new value. */
#define BW_ADC_CH_C_CFG2_CHC_CMP_MODE(x, v) (HW_ADC_CH_C_CFG2_WR(x, (HW_ADC_CH_C_CFG2_RD(x) & ~BM_ADC_CH_C_CFG2_CHC_CMP_MODE) | BF_ADC_CH_C_CFG2_CHC_CMP_MODE(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_CH_D_CFG1 - Channel D Configuration 1
 ******************************************************************************/

/*!
 * @brief HW_ADC_CH_D_CFG1 - Channel D Configuration 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_adc_ch_d_cfg1
{
    uint32_t U;
    struct _hw_adc_ch_d_cfg1_bitfields
    {
        uint32_t CHD_TIMER : 24;       /*!< [23:0] Channel D Timer */
        uint32_t CHD_SEL : 4;          /*!< [27:24] Channel D Select */
        uint32_t RESERVED0 : 1;        /*!< [28] This field is reserved. */
        uint32_t CHD_AVG_EN : 1;       /*!< [29] Channel D Average Enable */
        uint32_t CHD_SINGLE : 1;       /*!< [30] Channel D Single Conversion */
        uint32_t CHD_EN : 1;           /*!< [31] Channel D Enable */
    } B;
} hw_adc_ch_d_cfg1_t;

/*!
 * @name Constants and macros for entire ADC_CH_D_CFG1 register
 */
/*@{*/
#define HW_ADC_CH_D_CFG1_ADDR(x) ((uintptr_t)(x) + 0x60U)

#define HW_ADC_CH_D_CFG1(x)      (*(__IO hw_adc_ch_d_cfg1_t *) HW_ADC_CH_D_CFG1_ADDR(x))
#define HW_ADC_CH_D_CFG1_RD(x)   (HW_ADC_CH_D_CFG1(x).U)
#define HW_ADC_CH_D_CFG1_WR(x, v) (HW_ADC_CH_D_CFG1(x).U = (v))
#define HW_ADC_CH_D_CFG1_SET(x, v) (HW_ADC_CH_D_CFG1_WR(x, HW_ADC_CH_D_CFG1_RD(x) |  (v)))
#define HW_ADC_CH_D_CFG1_CLR(x, v) (HW_ADC_CH_D_CFG1_WR(x, HW_ADC_CH_D_CFG1_RD(x) & ~(v)))
#define HW_ADC_CH_D_CFG1_TOG(x, v) (HW_ADC_CH_D_CFG1_WR(x, HW_ADC_CH_D_CFG1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_CH_D_CFG1 bitfields
 */

/*!
 * @name Register ADC_CH_D_CFG1, field CHD_TIMER[23:0] (RW)
 *
 * This timer is for continuous conversion. The conversion rate = (CHD_TIMER +
 * 1) times sample rate + offset. The offset is due to channel D has lower
 * priority than Channel A, B, and C. In worst case, all channel D's conversion are
 * blocked by channel A, channel B and channel C's. 0x000 to 0xFFF timer value, every
 * CHD_TIMER + 1 times sample rate + offset, the ADC converts one data.
 */
/*@{*/
#define BP_ADC_CH_D_CFG1_CHD_TIMER (0U)    /*!< Bit position for ADC_CH_D_CFG1_CHD_TIMER. */
#define BM_ADC_CH_D_CFG1_CHD_TIMER (0x00FFFFFFU) /*!< Bit mask for ADC_CH_D_CFG1_CHD_TIMER. */
#define BS_ADC_CH_D_CFG1_CHD_TIMER (24U)   /*!< Bit field size in bits for ADC_CH_D_CFG1_CHD_TIMER. */

/*! @brief Read current value of the ADC_CH_D_CFG1_CHD_TIMER field. */
#define BR_ADC_CH_D_CFG1_CHD_TIMER(x) (HW_ADC_CH_D_CFG1(x).B.CHD_TIMER)

/*! @brief Format value for bitfield ADC_CH_D_CFG1_CHD_TIMER. */
#define BF_ADC_CH_D_CFG1_CHD_TIMER(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_D_CFG1_CHD_TIMER) & BM_ADC_CH_D_CFG1_CHD_TIMER)

/*! @brief Set the CHD_TIMER field to a new value. */
#define BW_ADC_CH_D_CFG1_CHD_TIMER(x, v) (HW_ADC_CH_D_CFG1_WR(x, (HW_ADC_CH_D_CFG1_RD(x) & ~BM_ADC_CH_D_CFG1_CHD_TIMER) | BF_ADC_CH_D_CFG1_CHD_TIMER(v)))
/*@}*/

/*!
 * @name Register ADC_CH_D_CFG1, field CHD_SEL[27:24] (RW)
 *
 * Select input channel (from 16 channels) for the logical channel D.
 *
 * Values:
 * - 0000 - Channel 0
 * - 0001 - Channel 1
 * - 0010 - Channel 2
 * - 0011 - Channel 3
 * - 0100 - Channel 4
 * - 0101 - Channel 5
 * - 0110 - Channel 6
 * - 0111 - Channel 7
 * - 1000 - Channel 8
 * - 1001 - Channel 9
 * - 1010 - Channel 10
 * - 1011 - Channel 11
 * - 1100 - Channel 12
 * - 1101 - Channel 13
 * - 1110 - Channel 14
 * - 1111 - Channel 15
 */
/*@{*/
#define BP_ADC_CH_D_CFG1_CHD_SEL (24U)     /*!< Bit position for ADC_CH_D_CFG1_CHD_SEL. */
#define BM_ADC_CH_D_CFG1_CHD_SEL (0x0F000000U) /*!< Bit mask for ADC_CH_D_CFG1_CHD_SEL. */
#define BS_ADC_CH_D_CFG1_CHD_SEL (4U)      /*!< Bit field size in bits for ADC_CH_D_CFG1_CHD_SEL. */

/*! @brief Read current value of the ADC_CH_D_CFG1_CHD_SEL field. */
#define BR_ADC_CH_D_CFG1_CHD_SEL(x) (HW_ADC_CH_D_CFG1(x).B.CHD_SEL)

/*! @brief Format value for bitfield ADC_CH_D_CFG1_CHD_SEL. */
#define BF_ADC_CH_D_CFG1_CHD_SEL(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_D_CFG1_CHD_SEL) & BM_ADC_CH_D_CFG1_CHD_SEL)

/*! @brief Set the CHD_SEL field to a new value. */
#define BW_ADC_CH_D_CFG1_CHD_SEL(x, v) (HW_ADC_CH_D_CFG1_WR(x, (HW_ADC_CH_D_CFG1_RD(x) & ~BM_ADC_CH_D_CFG1_CHD_SEL) | BF_ADC_CH_D_CFG1_CHD_SEL(v)))
/*@}*/

/*!
 * @name Register ADC_CH_D_CFG1, field CHD_AVG_EN[29] (RW)
 *
 * If enable this bit, channel D will do average for each conversion.
 *
 * Values:
 * - 1 - Enable average function.
 * - 0 - Disable average function.
 */
/*@{*/
#define BP_ADC_CH_D_CFG1_CHD_AVG_EN (29U)  /*!< Bit position for ADC_CH_D_CFG1_CHD_AVG_EN. */
#define BM_ADC_CH_D_CFG1_CHD_AVG_EN (0x20000000U) /*!< Bit mask for ADC_CH_D_CFG1_CHD_AVG_EN. */
#define BS_ADC_CH_D_CFG1_CHD_AVG_EN (1U)   /*!< Bit field size in bits for ADC_CH_D_CFG1_CHD_AVG_EN. */

/*! @brief Read current value of the ADC_CH_D_CFG1_CHD_AVG_EN field. */
#define BR_ADC_CH_D_CFG1_CHD_AVG_EN(x) (HW_ADC_CH_D_CFG1(x).B.CHD_AVG_EN)

/*! @brief Format value for bitfield ADC_CH_D_CFG1_CHD_AVG_EN. */
#define BF_ADC_CH_D_CFG1_CHD_AVG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_D_CFG1_CHD_AVG_EN) & BM_ADC_CH_D_CFG1_CHD_AVG_EN)

/*! @brief Set the CHD_AVG_EN field to a new value. */
#define BW_ADC_CH_D_CFG1_CHD_AVG_EN(x, v) (HW_ADC_CH_D_CFG1_WR(x, (HW_ADC_CH_D_CFG1_RD(x) & ~BM_ADC_CH_D_CFG1_CHD_AVG_EN) | BF_ADC_CH_D_CFG1_CHD_AVG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_CH_D_CFG1, field CHD_SINGLE[30] (RW)
 *
 * Start a single conversion from logical channel D. Switch between single and
 * continuous conversion, it must disable channel D first. When both CHD_EN and
 * CHD_SINGLE are enabled, CHD_SIGNAL set CHD_EN to 0 and reset itself to 0.
 *
 * Values:
 * - 1 - Start a single conversion. Continuous conversion must stop.
 * - 0 - No single conversion. Continuous conversion can start.
 */
/*@{*/
#define BP_ADC_CH_D_CFG1_CHD_SINGLE (30U)  /*!< Bit position for ADC_CH_D_CFG1_CHD_SINGLE. */
#define BM_ADC_CH_D_CFG1_CHD_SINGLE (0x40000000U) /*!< Bit mask for ADC_CH_D_CFG1_CHD_SINGLE. */
#define BS_ADC_CH_D_CFG1_CHD_SINGLE (1U)   /*!< Bit field size in bits for ADC_CH_D_CFG1_CHD_SINGLE. */

/*! @brief Read current value of the ADC_CH_D_CFG1_CHD_SINGLE field. */
#define BR_ADC_CH_D_CFG1_CHD_SINGLE(x) (HW_ADC_CH_D_CFG1(x).B.CHD_SINGLE)

/*! @brief Format value for bitfield ADC_CH_D_CFG1_CHD_SINGLE. */
#define BF_ADC_CH_D_CFG1_CHD_SINGLE(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_D_CFG1_CHD_SINGLE) & BM_ADC_CH_D_CFG1_CHD_SINGLE)

/*! @brief Set the CHD_SINGLE field to a new value. */
#define BW_ADC_CH_D_CFG1_CHD_SINGLE(x, v) (HW_ADC_CH_D_CFG1_WR(x, (HW_ADC_CH_D_CFG1_RD(x) & ~BM_ADC_CH_D_CFG1_CHD_SINGLE) | BF_ADC_CH_D_CFG1_CHD_SINGLE(v)))
/*@}*/

/*!
 * @name Register ADC_CH_D_CFG1, field CHD_EN[31] (RW)
 *
 * Controls the usable of logical channel D.
 *
 * Values:
 * - 1 - Enable logical channel D. Logical channel D will work.
 * - 0 - Disable logical channel D. Prevent logical channel D from working.
 */
/*@{*/
#define BP_ADC_CH_D_CFG1_CHD_EN (31U)      /*!< Bit position for ADC_CH_D_CFG1_CHD_EN. */
#define BM_ADC_CH_D_CFG1_CHD_EN (0x80000000U) /*!< Bit mask for ADC_CH_D_CFG1_CHD_EN. */
#define BS_ADC_CH_D_CFG1_CHD_EN (1U)       /*!< Bit field size in bits for ADC_CH_D_CFG1_CHD_EN. */

/*! @brief Read current value of the ADC_CH_D_CFG1_CHD_EN field. */
#define BR_ADC_CH_D_CFG1_CHD_EN(x) (HW_ADC_CH_D_CFG1(x).B.CHD_EN)

/*! @brief Format value for bitfield ADC_CH_D_CFG1_CHD_EN. */
#define BF_ADC_CH_D_CFG1_CHD_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_D_CFG1_CHD_EN) & BM_ADC_CH_D_CFG1_CHD_EN)

/*! @brief Set the CHD_EN field to a new value. */
#define BW_ADC_CH_D_CFG1_CHD_EN(x, v) (HW_ADC_CH_D_CFG1_WR(x, (HW_ADC_CH_D_CFG1_RD(x) & ~BM_ADC_CH_D_CFG1_CHD_EN) | BF_ADC_CH_D_CFG1_CHD_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_CH_D_CFG2 - Channel D Configuration 2
 ******************************************************************************/

/*!
 * @brief HW_ADC_CH_D_CFG2 - Channel D Configuration 2 (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_adc_ch_d_cfg2
{
    uint32_t U;
    struct _hw_adc_ch_d_cfg2_bitfields
    {
        uint32_t CHD_LOW_THRES : 12;   /*!< [11:0] Channel D Low Threshold
                                        * Value */
        uint32_t CHD_AVG_NUMBER : 2;   /*!< [13:12] Channel D Average Number */
        uint32_t RESERVED0 : 1;        /*!< [14] This field is reserved. */
        uint32_t CHD_AUTO_DIS : 1;     /*!< [15] Channel D Auto Disable */
        uint32_t CHD_HIGH_THRES : 12;  /*!< [27:16] Channel D High Threshold
                                        * Value */
        uint32_t RESERVED1 : 1;        /*!< [28] This field is reserved. */
        uint32_t CHD_CMP_MODE : 3;     /*!< [31:29] Channel D Compare Mode */
    } B;
} hw_adc_ch_d_cfg2_t;

/*!
 * @name Constants and macros for entire ADC_CH_D_CFG2 register
 */
/*@{*/
#define HW_ADC_CH_D_CFG2_ADDR(x) ((uintptr_t)(x) + 0x70U)

#define HW_ADC_CH_D_CFG2(x)      (*(__IO hw_adc_ch_d_cfg2_t *) HW_ADC_CH_D_CFG2_ADDR(x))
#define HW_ADC_CH_D_CFG2_RD(x)   (HW_ADC_CH_D_CFG2(x).U)
#define HW_ADC_CH_D_CFG2_WR(x, v) (HW_ADC_CH_D_CFG2(x).U = (v))
#define HW_ADC_CH_D_CFG2_SET(x, v) (HW_ADC_CH_D_CFG2_WR(x, HW_ADC_CH_D_CFG2_RD(x) |  (v)))
#define HW_ADC_CH_D_CFG2_CLR(x, v) (HW_ADC_CH_D_CFG2_WR(x, HW_ADC_CH_D_CFG2_RD(x) & ~(v)))
#define HW_ADC_CH_D_CFG2_TOG(x, v) (HW_ADC_CH_D_CFG2_WR(x, HW_ADC_CH_D_CFG2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_CH_D_CFG2 bitfields
 */

/*!
 * @name Register ADC_CH_D_CFG2, field CHD_LOW_THRES[11:0] (RW)
 *
 * Contains the smaller compare value to compare with the conversion result when
 * a compare mode has been selected.
 */
/*@{*/
#define BP_ADC_CH_D_CFG2_CHD_LOW_THRES (0U) /*!< Bit position for ADC_CH_D_CFG2_CHD_LOW_THRES. */
#define BM_ADC_CH_D_CFG2_CHD_LOW_THRES (0x00000FFFU) /*!< Bit mask for ADC_CH_D_CFG2_CHD_LOW_THRES. */
#define BS_ADC_CH_D_CFG2_CHD_LOW_THRES (12U) /*!< Bit field size in bits for ADC_CH_D_CFG2_CHD_LOW_THRES. */

/*! @brief Read current value of the ADC_CH_D_CFG2_CHD_LOW_THRES field. */
#define BR_ADC_CH_D_CFG2_CHD_LOW_THRES(x) (HW_ADC_CH_D_CFG2(x).B.CHD_LOW_THRES)

/*! @brief Format value for bitfield ADC_CH_D_CFG2_CHD_LOW_THRES. */
#define BF_ADC_CH_D_CFG2_CHD_LOW_THRES(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_D_CFG2_CHD_LOW_THRES) & BM_ADC_CH_D_CFG2_CHD_LOW_THRES)

/*! @brief Set the CHD_LOW_THRES field to a new value. */
#define BW_ADC_CH_D_CFG2_CHD_LOW_THRES(x, v) (HW_ADC_CH_D_CFG2_WR(x, (HW_ADC_CH_D_CFG2_RD(x) & ~BM_ADC_CH_D_CFG2_CHD_LOW_THRES) | BF_ADC_CH_D_CFG2_CHD_LOW_THRES(v)))
/*@}*/

/*!
 * @name Register ADC_CH_D_CFG2, field CHD_AVG_NUMBER[13:12] (RW)
 *
 * If enable average function, this bit contains channel D average number.
 *
 * Values:
 * - 00 - Average number = 4
 * - 01 - Average number = 8
 * - 10 - Average number = 16
 * - 11 - Average number = 32
 */
/*@{*/
#define BP_ADC_CH_D_CFG2_CHD_AVG_NUMBER (12U) /*!< Bit position for ADC_CH_D_CFG2_CHD_AVG_NUMBER. */
#define BM_ADC_CH_D_CFG2_CHD_AVG_NUMBER (0x00003000U) /*!< Bit mask for ADC_CH_D_CFG2_CHD_AVG_NUMBER. */
#define BS_ADC_CH_D_CFG2_CHD_AVG_NUMBER (2U) /*!< Bit field size in bits for ADC_CH_D_CFG2_CHD_AVG_NUMBER. */

/*! @brief Read current value of the ADC_CH_D_CFG2_CHD_AVG_NUMBER field. */
#define BR_ADC_CH_D_CFG2_CHD_AVG_NUMBER(x) (HW_ADC_CH_D_CFG2(x).B.CHD_AVG_NUMBER)

/*! @brief Format value for bitfield ADC_CH_D_CFG2_CHD_AVG_NUMBER. */
#define BF_ADC_CH_D_CFG2_CHD_AVG_NUMBER(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_D_CFG2_CHD_AVG_NUMBER) & BM_ADC_CH_D_CFG2_CHD_AVG_NUMBER)

/*! @brief Set the CHD_AVG_NUMBER field to a new value. */
#define BW_ADC_CH_D_CFG2_CHD_AVG_NUMBER(x, v) (HW_ADC_CH_D_CFG2_WR(x, (HW_ADC_CH_D_CFG2_RD(x) & ~BM_ADC_CH_D_CFG2_CHD_AVG_NUMBER) | BF_ADC_CH_D_CFG2_CHD_AVG_NUMBER(v)))
/*@}*/

/*!
 * @name Register ADC_CH_D_CFG2, field CHD_AUTO_DIS[15] (RW)
 *
 * During continuous conversion, if compare match a converted result, the ADC
 * checks this bit. If CHD_AUTO_DIS = 1, then channel D stops continuous
 * conversion, if CHD_AUTO_DIS = 0, then channel D keeps continuous working, and the
 * conversion result overwrites the result registers. The default value is 1.
 */
/*@{*/
#define BP_ADC_CH_D_CFG2_CHD_AUTO_DIS (15U) /*!< Bit position for ADC_CH_D_CFG2_CHD_AUTO_DIS. */
#define BM_ADC_CH_D_CFG2_CHD_AUTO_DIS (0x00008000U) /*!< Bit mask for ADC_CH_D_CFG2_CHD_AUTO_DIS. */
#define BS_ADC_CH_D_CFG2_CHD_AUTO_DIS (1U) /*!< Bit field size in bits for ADC_CH_D_CFG2_CHD_AUTO_DIS. */

/*! @brief Read current value of the ADC_CH_D_CFG2_CHD_AUTO_DIS field. */
#define BR_ADC_CH_D_CFG2_CHD_AUTO_DIS(x) (HW_ADC_CH_D_CFG2(x).B.CHD_AUTO_DIS)

/*! @brief Format value for bitfield ADC_CH_D_CFG2_CHD_AUTO_DIS. */
#define BF_ADC_CH_D_CFG2_CHD_AUTO_DIS(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_D_CFG2_CHD_AUTO_DIS) & BM_ADC_CH_D_CFG2_CHD_AUTO_DIS)

/*! @brief Set the CHD_AUTO_DIS field to a new value. */
#define BW_ADC_CH_D_CFG2_CHD_AUTO_DIS(x, v) (HW_ADC_CH_D_CFG2_WR(x, (HW_ADC_CH_D_CFG2_RD(x) & ~BM_ADC_CH_D_CFG2_CHD_AUTO_DIS) | BF_ADC_CH_D_CFG2_CHD_AUTO_DIS(v)))
/*@}*/

/*!
 * @name Register ADC_CH_D_CFG2, field CHD_HIGH_THRES[27:16] (RW)
 *
 * Contains the bigger compare value to compare with the conversion result when
 * a compare mode has been selected.
 */
/*@{*/
#define BP_ADC_CH_D_CFG2_CHD_HIGH_THRES (16U) /*!< Bit position for ADC_CH_D_CFG2_CHD_HIGH_THRES. */
#define BM_ADC_CH_D_CFG2_CHD_HIGH_THRES (0x0FFF0000U) /*!< Bit mask for ADC_CH_D_CFG2_CHD_HIGH_THRES. */
#define BS_ADC_CH_D_CFG2_CHD_HIGH_THRES (12U) /*!< Bit field size in bits for ADC_CH_D_CFG2_CHD_HIGH_THRES. */

/*! @brief Read current value of the ADC_CH_D_CFG2_CHD_HIGH_THRES field. */
#define BR_ADC_CH_D_CFG2_CHD_HIGH_THRES(x) (HW_ADC_CH_D_CFG2(x).B.CHD_HIGH_THRES)

/*! @brief Format value for bitfield ADC_CH_D_CFG2_CHD_HIGH_THRES. */
#define BF_ADC_CH_D_CFG2_CHD_HIGH_THRES(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_D_CFG2_CHD_HIGH_THRES) & BM_ADC_CH_D_CFG2_CHD_HIGH_THRES)

/*! @brief Set the CHD_HIGH_THRES field to a new value. */
#define BW_ADC_CH_D_CFG2_CHD_HIGH_THRES(x, v) (HW_ADC_CH_D_CFG2_WR(x, (HW_ADC_CH_D_CFG2_RD(x) & ~BM_ADC_CH_D_CFG2_CHD_HIGH_THRES) | BF_ADC_CH_D_CFG2_CHD_HIGH_THRES(v)))
/*@}*/

/*!
 * @name Register ADC_CH_D_CFG2, field CHD_CMP_MODE[31:29] (RW)
 *
 * Select which compare mode the conversion result will take (for channel D).
 *
 * Values:
 * - 001 - If channel D conversion result bigger than CHD_LOW_THRES, then an
 *     interrupt will be generated and the channel D flag will be set if they are
 *     enabled.
 * - 010 - If channel D conversion result smaller or equal to CHD_LOW_THRES,
 *     then an interrupt will be generated and channel D flag will be set if they
 *     are enabled.
 * - 011 - If channel D conversion result bigger than CHD_LOW_THRES and smaller
 *     than CHD_HIGH_THRES, then an interrupt will be generated and channel D
 *     flag will be set if they are enabled.
 * - 101 - If channel D conversion result bigger or equal to CHD_HIGH_THRES,
 *     then an interrupt will be generated and channel D flag will be set if they
 *     are enabled.
 * - 110 - If channel D conversion result smaller than CHD_HIGH_THRES, then an
 *     interrupt will be generated and channel D flag will be set if they are
 *     enabled.
 * - 111 - If channel D conversion result smaller or equal to CHD_LOW_THRES, and
 *     at the same time, bigger or equal to CHD_HIGH_THRES, then an interrupt
 *     will be generated and channel D flag will be set if they are enabled.
 */
/*@{*/
#define BP_ADC_CH_D_CFG2_CHD_CMP_MODE (29U) /*!< Bit position for ADC_CH_D_CFG2_CHD_CMP_MODE. */
#define BM_ADC_CH_D_CFG2_CHD_CMP_MODE (0xE0000000U) /*!< Bit mask for ADC_CH_D_CFG2_CHD_CMP_MODE. */
#define BS_ADC_CH_D_CFG2_CHD_CMP_MODE (3U) /*!< Bit field size in bits for ADC_CH_D_CFG2_CHD_CMP_MODE. */

/*! @brief Read current value of the ADC_CH_D_CFG2_CHD_CMP_MODE field. */
#define BR_ADC_CH_D_CFG2_CHD_CMP_MODE(x) (HW_ADC_CH_D_CFG2(x).B.CHD_CMP_MODE)

/*! @brief Format value for bitfield ADC_CH_D_CFG2_CHD_CMP_MODE. */
#define BF_ADC_CH_D_CFG2_CHD_CMP_MODE(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_D_CFG2_CHD_CMP_MODE) & BM_ADC_CH_D_CFG2_CHD_CMP_MODE)

/*! @brief Set the CHD_CMP_MODE field to a new value. */
#define BW_ADC_CH_D_CFG2_CHD_CMP_MODE(x, v) (HW_ADC_CH_D_CFG2_WR(x, (HW_ADC_CH_D_CFG2_RD(x) & ~BM_ADC_CH_D_CFG2_CHD_CMP_MODE) | BF_ADC_CH_D_CFG2_CHD_CMP_MODE(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_CH_SW_CFG - Channel Software Configuration
 ******************************************************************************/

/*!
 * @brief HW_ADC_CH_SW_CFG - Channel Software Configuration (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_adc_ch_sw_cfg
{
    uint32_t U;
    struct _hw_adc_ch_sw_cfg_bitfields
    {
        uint32_t RESERVED0 : 21;       /*!< [20:0] This field is reserved. */
        uint32_t CH_SW_AVG_NUMBER : 2; /*!< [22:21] Channel Software Average
                                        * Number */
        uint32_t CH_SW_AVG_EN : 1;     /*!< [23] Channel Software Average Enable
                                        * */
        uint32_t CH_SW_SEL : 4;        /*!< [27:24] Software Trigger Channel Select
                                        * */
        uint32_t RESERVED1 : 3;        /*!< [30:28] This field is reserved. */
        uint32_t START_CONV : 1;       /*!< [31] Start Software Trigger Conversion
                                        * */
    } B;
} hw_adc_ch_sw_cfg_t;

/*!
 * @name Constants and macros for entire ADC_CH_SW_CFG register
 */
/*@{*/
#define HW_ADC_CH_SW_CFG_ADDR(x) ((uintptr_t)(x) + 0x80U)

#define HW_ADC_CH_SW_CFG(x)      (*(__IO hw_adc_ch_sw_cfg_t *) HW_ADC_CH_SW_CFG_ADDR(x))
#define HW_ADC_CH_SW_CFG_RD(x)   (HW_ADC_CH_SW_CFG(x).U)
#define HW_ADC_CH_SW_CFG_WR(x, v) (HW_ADC_CH_SW_CFG(x).U = (v))
#define HW_ADC_CH_SW_CFG_SET(x, v) (HW_ADC_CH_SW_CFG_WR(x, HW_ADC_CH_SW_CFG_RD(x) |  (v)))
#define HW_ADC_CH_SW_CFG_CLR(x, v) (HW_ADC_CH_SW_CFG_WR(x, HW_ADC_CH_SW_CFG_RD(x) & ~(v)))
#define HW_ADC_CH_SW_CFG_TOG(x, v) (HW_ADC_CH_SW_CFG_WR(x, HW_ADC_CH_SW_CFG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_CH_SW_CFG bitfields
 */

/*!
 * @name Register ADC_CH_SW_CFG, field CH_SW_AVG_NUMBER[22:21] (RW)
 *
 * If enable average function, this bit contains channel Software average number.
 *
 * Values:
 * - 00 - Average number = 4
 * - 01 - Average number = 8
 * - 10 - Average number = 16
 * - 11 - Average number = 32
 */
/*@{*/
#define BP_ADC_CH_SW_CFG_CH_SW_AVG_NUMBER (21U) /*!< Bit position for ADC_CH_SW_CFG_CH_SW_AVG_NUMBER. */
#define BM_ADC_CH_SW_CFG_CH_SW_AVG_NUMBER (0x00600000U) /*!< Bit mask for ADC_CH_SW_CFG_CH_SW_AVG_NUMBER. */
#define BS_ADC_CH_SW_CFG_CH_SW_AVG_NUMBER (2U) /*!< Bit field size in bits for ADC_CH_SW_CFG_CH_SW_AVG_NUMBER. */

/*! @brief Read current value of the ADC_CH_SW_CFG_CH_SW_AVG_NUMBER field. */
#define BR_ADC_CH_SW_CFG_CH_SW_AVG_NUMBER(x) (HW_ADC_CH_SW_CFG(x).B.CH_SW_AVG_NUMBER)

/*! @brief Format value for bitfield ADC_CH_SW_CFG_CH_SW_AVG_NUMBER. */
#define BF_ADC_CH_SW_CFG_CH_SW_AVG_NUMBER(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_SW_CFG_CH_SW_AVG_NUMBER) & BM_ADC_CH_SW_CFG_CH_SW_AVG_NUMBER)

/*! @brief Set the CH_SW_AVG_NUMBER field to a new value. */
#define BW_ADC_CH_SW_CFG_CH_SW_AVG_NUMBER(x, v) (HW_ADC_CH_SW_CFG_WR(x, (HW_ADC_CH_SW_CFG_RD(x) & ~BM_ADC_CH_SW_CFG_CH_SW_AVG_NUMBER) | BF_ADC_CH_SW_CFG_CH_SW_AVG_NUMBER(v)))
/*@}*/

/*!
 * @name Register ADC_CH_SW_CFG, field CH_SW_AVG_EN[23] (RW)
 *
 * If enable this bit, channel Software will do average for each conversion.
 *
 * Values:
 * - 1 - Enable average function.
 * - 0 - Disable average function.
 */
/*@{*/
#define BP_ADC_CH_SW_CFG_CH_SW_AVG_EN (23U) /*!< Bit position for ADC_CH_SW_CFG_CH_SW_AVG_EN. */
#define BM_ADC_CH_SW_CFG_CH_SW_AVG_EN (0x00800000U) /*!< Bit mask for ADC_CH_SW_CFG_CH_SW_AVG_EN. */
#define BS_ADC_CH_SW_CFG_CH_SW_AVG_EN (1U) /*!< Bit field size in bits for ADC_CH_SW_CFG_CH_SW_AVG_EN. */

/*! @brief Read current value of the ADC_CH_SW_CFG_CH_SW_AVG_EN field. */
#define BR_ADC_CH_SW_CFG_CH_SW_AVG_EN(x) (HW_ADC_CH_SW_CFG(x).B.CH_SW_AVG_EN)

/*! @brief Format value for bitfield ADC_CH_SW_CFG_CH_SW_AVG_EN. */
#define BF_ADC_CH_SW_CFG_CH_SW_AVG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_SW_CFG_CH_SW_AVG_EN) & BM_ADC_CH_SW_CFG_CH_SW_AVG_EN)

/*! @brief Set the CH_SW_AVG_EN field to a new value. */
#define BW_ADC_CH_SW_CFG_CH_SW_AVG_EN(x, v) (HW_ADC_CH_SW_CFG_WR(x, (HW_ADC_CH_SW_CFG_RD(x) & ~BM_ADC_CH_SW_CFG_CH_SW_AVG_EN) | BF_ADC_CH_SW_CFG_CH_SW_AVG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_CH_SW_CFG, field CH_SW_SEL[27:24] (RW)
 *
 * Select 1 from 16 (physical) channels to be the software trigger channel.
 *
 * Values:
 * - 0000 - Channel 0
 * - 0001 - Channel 1
 * - 0010 - Channel 2
 * - 0011 - Channel 3
 * - 0100 - Channel 4
 * - 0101 - Channel 5
 * - 0110 - Channel 6
 * - 0111 - Channel 7
 * - 1000 - Channel 8
 * - 1001 - Channel 9
 * - 1010 - Channel 10
 * - 1011 - Channel 11
 * - 1100 - Channel 12
 * - 1101 - Channel 13
 * - 1110 - Channel 14
 * - 1111 - Channel 15
 */
/*@{*/
#define BP_ADC_CH_SW_CFG_CH_SW_SEL (24U)   /*!< Bit position for ADC_CH_SW_CFG_CH_SW_SEL. */
#define BM_ADC_CH_SW_CFG_CH_SW_SEL (0x0F000000U) /*!< Bit mask for ADC_CH_SW_CFG_CH_SW_SEL. */
#define BS_ADC_CH_SW_CFG_CH_SW_SEL (4U)    /*!< Bit field size in bits for ADC_CH_SW_CFG_CH_SW_SEL. */

/*! @brief Read current value of the ADC_CH_SW_CFG_CH_SW_SEL field. */
#define BR_ADC_CH_SW_CFG_CH_SW_SEL(x) (HW_ADC_CH_SW_CFG(x).B.CH_SW_SEL)

/*! @brief Format value for bitfield ADC_CH_SW_CFG_CH_SW_SEL. */
#define BF_ADC_CH_SW_CFG_CH_SW_SEL(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_SW_CFG_CH_SW_SEL) & BM_ADC_CH_SW_CFG_CH_SW_SEL)

/*! @brief Set the CH_SW_SEL field to a new value. */
#define BW_ADC_CH_SW_CFG_CH_SW_SEL(x, v) (HW_ADC_CH_SW_CFG_WR(x, (HW_ADC_CH_SW_CFG_RD(x) & ~BM_ADC_CH_SW_CFG_CH_SW_SEL) | BF_ADC_CH_SW_CFG_CH_SW_SEL(v)))
/*@}*/

/*!
 * @name Register ADC_CH_SW_CFG, field START_CONV[31] (RW)
 *
 * To start a software trigger, it must wait until the last software trigger
 * finish.
 *
 * Values:
 * - 0 - Not start a new software trigger conversion.
 * - 1 - Start a new software trigger conversion.
 */
/*@{*/
#define BP_ADC_CH_SW_CFG_START_CONV (31U)  /*!< Bit position for ADC_CH_SW_CFG_START_CONV. */
#define BM_ADC_CH_SW_CFG_START_CONV (0x80000000U) /*!< Bit mask for ADC_CH_SW_CFG_START_CONV. */
#define BS_ADC_CH_SW_CFG_START_CONV (1U)   /*!< Bit field size in bits for ADC_CH_SW_CFG_START_CONV. */

/*! @brief Read current value of the ADC_CH_SW_CFG_START_CONV field. */
#define BR_ADC_CH_SW_CFG_START_CONV(x) (HW_ADC_CH_SW_CFG(x).B.START_CONV)

/*! @brief Format value for bitfield ADC_CH_SW_CFG_START_CONV. */
#define BF_ADC_CH_SW_CFG_START_CONV(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_SW_CFG_START_CONV) & BM_ADC_CH_SW_CFG_START_CONV)

/*! @brief Set the START_CONV field to a new value. */
#define BW_ADC_CH_SW_CFG_START_CONV(x, v) (HW_ADC_CH_SW_CFG_WR(x, (HW_ADC_CH_SW_CFG_RD(x) & ~BM_ADC_CH_SW_CFG_START_CONV) | BF_ADC_CH_SW_CFG_START_CONV(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_TIMER_UNIT - Timer Unit
 ******************************************************************************/

/*!
 * @brief HW_ADC_TIMER_UNIT - Timer Unit (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_adc_timer_unit
{
    uint32_t U;
    struct _hw_adc_timer_unit_bitfields
    {
        uint32_t CORE_TIMER_UNIT : 5;  /*!< [4:0] Core_Timer_Unit */
        uint32_t RESERVED0 : 24;       /*!< [28:5] This field is reserved. */
        uint32_t PRE_DIV : 3;          /*!< [31:29] Pre-divide */
    } B;
} hw_adc_timer_unit_t;

/*!
 * @name Constants and macros for entire ADC_TIMER_UNIT register
 */
/*@{*/
#define HW_ADC_TIMER_UNIT_ADDR(x) ((uintptr_t)(x) + 0x90U)

#define HW_ADC_TIMER_UNIT(x)     (*(__IO hw_adc_timer_unit_t *) HW_ADC_TIMER_UNIT_ADDR(x))
#define HW_ADC_TIMER_UNIT_RD(x)  (HW_ADC_TIMER_UNIT(x).U)
#define HW_ADC_TIMER_UNIT_WR(x, v) (HW_ADC_TIMER_UNIT(x).U = (v))
#define HW_ADC_TIMER_UNIT_SET(x, v) (HW_ADC_TIMER_UNIT_WR(x, HW_ADC_TIMER_UNIT_RD(x) |  (v)))
#define HW_ADC_TIMER_UNIT_CLR(x, v) (HW_ADC_TIMER_UNIT_WR(x, HW_ADC_TIMER_UNIT_RD(x) & ~(v)))
#define HW_ADC_TIMER_UNIT_TOG(x, v) (HW_ADC_TIMER_UNIT_WR(x, HW_ADC_TIMER_UNIT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_TIMER_UNIT bitfields
 */

/*!
 * @name Register ADC_TIMER_UNIT, field CORE_TIMER_UNIT[4:0] (RW)
 *
 * This parameter defines sample rate. The maximum sample rate is 1/6 ADC
 * analogue core clock. Sample rate = analogue core clock frequency (MHz) * 1 /(
 * (CORE_TIMER_UNIT + 1) * 6). If changing SAMPLE_RATE, please disable logical channel
 * A, B, C, and D. Otherwise, the first A, B, C, and D conversion after change
 * the sample rate may not follow exact sample rate interval.
 */
/*@{*/
#define BP_ADC_TIMER_UNIT_CORE_TIMER_UNIT (0U) /*!< Bit position for ADC_TIMER_UNIT_CORE_TIMER_UNIT. */
#define BM_ADC_TIMER_UNIT_CORE_TIMER_UNIT (0x0000001FU) /*!< Bit mask for ADC_TIMER_UNIT_CORE_TIMER_UNIT. */
#define BS_ADC_TIMER_UNIT_CORE_TIMER_UNIT (5U) /*!< Bit field size in bits for ADC_TIMER_UNIT_CORE_TIMER_UNIT. */

/*! @brief Read current value of the ADC_TIMER_UNIT_CORE_TIMER_UNIT field. */
#define BR_ADC_TIMER_UNIT_CORE_TIMER_UNIT(x) (HW_ADC_TIMER_UNIT(x).B.CORE_TIMER_UNIT)

/*! @brief Format value for bitfield ADC_TIMER_UNIT_CORE_TIMER_UNIT. */
#define BF_ADC_TIMER_UNIT_CORE_TIMER_UNIT(v) ((uint32_t)((uint32_t)(v) << BP_ADC_TIMER_UNIT_CORE_TIMER_UNIT) & BM_ADC_TIMER_UNIT_CORE_TIMER_UNIT)

/*! @brief Set the CORE_TIMER_UNIT field to a new value. */
#define BW_ADC_TIMER_UNIT_CORE_TIMER_UNIT(x, v) (HW_ADC_TIMER_UNIT_WR(x, (HW_ADC_TIMER_UNIT_RD(x) & ~BM_ADC_TIMER_UNIT_CORE_TIMER_UNIT) | BF_ADC_TIMER_UNIT_CORE_TIMER_UNIT(v)))
/*@}*/

/*!
 * @name Register ADC_TIMER_UNIT, field PRE_DIV[31:29] (RW)
 *
 * The ADC analogue core clock can vary from 300 kHz to 6 MHz. This parameter
 * defines ADC core clock (and sample rate). The ADC analogue clock is default 1/4
 * of ADC digital input clock. All pre-divide is 1/4 ADC digital input clock.
 * Warning: Before set this parameter, make sure analogue clock is from 300 kHz to 6
 * MHz.
 *
 * Values:
 * - 000 - No divide, analogue clock = 1/4 ADC digital input clock
 * - 001 - Divide 2, analogue clock = 1/8 ADC digital input clock
 * - 010 - Divide 4, analogue clock = 1/16 ADC digital input clock
 * - 011 - Divide 8, analogue clock = 1/32 ADC digital input clock
 * - 100 - Divide 16, analogue clock = 1/64 ADC digital input clock
 * - 101 - Divide 32, analogue clock = 1/128 ADC digital input clock
 */
/*@{*/
#define BP_ADC_TIMER_UNIT_PRE_DIV (29U)    /*!< Bit position for ADC_TIMER_UNIT_PRE_DIV. */
#define BM_ADC_TIMER_UNIT_PRE_DIV (0xE0000000U) /*!< Bit mask for ADC_TIMER_UNIT_PRE_DIV. */
#define BS_ADC_TIMER_UNIT_PRE_DIV (3U)     /*!< Bit field size in bits for ADC_TIMER_UNIT_PRE_DIV. */

/*! @brief Read current value of the ADC_TIMER_UNIT_PRE_DIV field. */
#define BR_ADC_TIMER_UNIT_PRE_DIV(x) (HW_ADC_TIMER_UNIT(x).B.PRE_DIV)

/*! @brief Format value for bitfield ADC_TIMER_UNIT_PRE_DIV. */
#define BF_ADC_TIMER_UNIT_PRE_DIV(v) ((uint32_t)((uint32_t)(v) << BP_ADC_TIMER_UNIT_PRE_DIV) & BM_ADC_TIMER_UNIT_PRE_DIV)

/*! @brief Set the PRE_DIV field to a new value. */
#define BW_ADC_TIMER_UNIT_PRE_DIV(x, v) (HW_ADC_TIMER_UNIT_WR(x, (HW_ADC_TIMER_UNIT_RD(x) & ~BM_ADC_TIMER_UNIT_PRE_DIV) | BF_ADC_TIMER_UNIT_PRE_DIV(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_DMA_FIFO - DMA FIFO
 ******************************************************************************/

/*!
 * @brief HW_ADC_DMA_FIFO - DMA FIFO (RW)
 *
 * Reset value: 0x0000010FU
 */
typedef union _hw_adc_dma_fifo
{
    uint32_t U;
    struct _hw_adc_dma_fifo_bitfields
    {
        uint32_t DMA_WM_LVL : 5;       /*!< [4:0] DMA Water Mark Level */
        uint32_t DMA_CH_SEL : 2;       /*!< [6:5] DMA Channel Select */
        uint32_t DMA_EN : 1;           /*!< [7] DMA Enable */
        uint32_t DMA_FIFO_EN : 1;      /*!< [8] DMA FIFO Enable */
        uint32_t DMA_RST : 1;          /*!< [9] DMA Reset */
        uint32_t RESERVED0 : 22;       /*!< [31:10] This field is reserved. */
    } B;
} hw_adc_dma_fifo_t;

/*!
 * @name Constants and macros for entire ADC_DMA_FIFO register
 */
/*@{*/
#define HW_ADC_DMA_FIFO_ADDR(x)  ((uintptr_t)(x) + 0xA0U)

#define HW_ADC_DMA_FIFO(x)       (*(__IO hw_adc_dma_fifo_t *) HW_ADC_DMA_FIFO_ADDR(x))
#define HW_ADC_DMA_FIFO_RD(x)    (HW_ADC_DMA_FIFO(x).U)
#define HW_ADC_DMA_FIFO_WR(x, v) (HW_ADC_DMA_FIFO(x).U = (v))
#define HW_ADC_DMA_FIFO_SET(x, v) (HW_ADC_DMA_FIFO_WR(x, HW_ADC_DMA_FIFO_RD(x) |  (v)))
#define HW_ADC_DMA_FIFO_CLR(x, v) (HW_ADC_DMA_FIFO_WR(x, HW_ADC_DMA_FIFO_RD(x) & ~(v)))
#define HW_ADC_DMA_FIFO_TOG(x, v) (HW_ADC_DMA_FIFO_WR(x, HW_ADC_DMA_FIFO_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_DMA_FIFO bitfields
 */

/*!
 * @name Register ADC_DMA_FIFO, field DMA_WM_LVL[4:0] (RW)
 *
 * Once the DMA FIFO data reach water mark level, a DMA request or interrupt is
 * generated (if enabled), and transfer data through DMA or CPU. 00000-11111
 * represents DMA water mark level value
 */
/*@{*/
#define BP_ADC_DMA_FIFO_DMA_WM_LVL (0U)    /*!< Bit position for ADC_DMA_FIFO_DMA_WM_LVL. */
#define BM_ADC_DMA_FIFO_DMA_WM_LVL (0x0000001FU) /*!< Bit mask for ADC_DMA_FIFO_DMA_WM_LVL. */
#define BS_ADC_DMA_FIFO_DMA_WM_LVL (5U)    /*!< Bit field size in bits for ADC_DMA_FIFO_DMA_WM_LVL. */

/*! @brief Read current value of the ADC_DMA_FIFO_DMA_WM_LVL field. */
#define BR_ADC_DMA_FIFO_DMA_WM_LVL(x) (HW_ADC_DMA_FIFO(x).B.DMA_WM_LVL)

/*! @brief Format value for bitfield ADC_DMA_FIFO_DMA_WM_LVL. */
#define BF_ADC_DMA_FIFO_DMA_WM_LVL(v) ((uint32_t)((uint32_t)(v) << BP_ADC_DMA_FIFO_DMA_WM_LVL) & BM_ADC_DMA_FIFO_DMA_WM_LVL)

/*! @brief Set the DMA_WM_LVL field to a new value. */
#define BW_ADC_DMA_FIFO_DMA_WM_LVL(x, v) (HW_ADC_DMA_FIFO_WR(x, (HW_ADC_DMA_FIFO_RD(x) & ~BM_ADC_DMA_FIFO_DMA_WM_LVL) | BF_ADC_DMA_FIFO_DMA_WM_LVL(v)))
/*@}*/

/*!
 * @name Register ADC_DMA_FIFO, field DMA_CH_SEL[6:5] (RW)
 *
 * Select DMA FIFO source from Channel A, Channel B, Channel C, and Channel D.
 *
 * Values:
 * - 00 - Channel A
 * - 01 - Channel B
 * - 10 - Channel C
 * - 11 - Channel D
 */
/*@{*/
#define BP_ADC_DMA_FIFO_DMA_CH_SEL (5U)    /*!< Bit position for ADC_DMA_FIFO_DMA_CH_SEL. */
#define BM_ADC_DMA_FIFO_DMA_CH_SEL (0x00000060U) /*!< Bit mask for ADC_DMA_FIFO_DMA_CH_SEL. */
#define BS_ADC_DMA_FIFO_DMA_CH_SEL (2U)    /*!< Bit field size in bits for ADC_DMA_FIFO_DMA_CH_SEL. */

/*! @brief Read current value of the ADC_DMA_FIFO_DMA_CH_SEL field. */
#define BR_ADC_DMA_FIFO_DMA_CH_SEL(x) (HW_ADC_DMA_FIFO(x).B.DMA_CH_SEL)

/*! @brief Format value for bitfield ADC_DMA_FIFO_DMA_CH_SEL. */
#define BF_ADC_DMA_FIFO_DMA_CH_SEL(v) ((uint32_t)((uint32_t)(v) << BP_ADC_DMA_FIFO_DMA_CH_SEL) & BM_ADC_DMA_FIFO_DMA_CH_SEL)

/*! @brief Set the DMA_CH_SEL field to a new value. */
#define BW_ADC_DMA_FIFO_DMA_CH_SEL(x, v) (HW_ADC_DMA_FIFO_WR(x, (HW_ADC_DMA_FIFO_RD(x) & ~BM_ADC_DMA_FIFO_DMA_CH_SEL) | BF_ADC_DMA_FIFO_DMA_CH_SEL(v)))
/*@}*/

/*!
 * @name Register ADC_DMA_FIFO, field DMA_EN[7] (RW)
 *
 * This bit defines data in DMA FIFO is moved by SDMA or moved by CPU.
 *
 * Values:
 * - 0 - Disable DMA, the data in DMA FIFO can only move by CPU.
 * - 1 - Enable DMA, the data in DMA FIFO should move by SDMA.
 */
/*@{*/
#define BP_ADC_DMA_FIFO_DMA_EN (7U)        /*!< Bit position for ADC_DMA_FIFO_DMA_EN. */
#define BM_ADC_DMA_FIFO_DMA_EN (0x00000080U) /*!< Bit mask for ADC_DMA_FIFO_DMA_EN. */
#define BS_ADC_DMA_FIFO_DMA_EN (1U)        /*!< Bit field size in bits for ADC_DMA_FIFO_DMA_EN. */

/*! @brief Read current value of the ADC_DMA_FIFO_DMA_EN field. */
#define BR_ADC_DMA_FIFO_DMA_EN(x) (HW_ADC_DMA_FIFO(x).B.DMA_EN)

/*! @brief Format value for bitfield ADC_DMA_FIFO_DMA_EN. */
#define BF_ADC_DMA_FIFO_DMA_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_DMA_FIFO_DMA_EN) & BM_ADC_DMA_FIFO_DMA_EN)

/*! @brief Set the DMA_EN field to a new value. */
#define BW_ADC_DMA_FIFO_DMA_EN(x, v) (HW_ADC_DMA_FIFO_WR(x, (HW_ADC_DMA_FIFO_RD(x) & ~BM_ADC_DMA_FIFO_DMA_EN) | BF_ADC_DMA_FIFO_DMA_EN(v)))
/*@}*/

/*!
 * @name Register ADC_DMA_FIFO, field DMA_FIFO_EN[8] (RW)
 *
 * If enable DMA_FIFO_EN, ADC conversion result can store into DMA FIFO. If
 * disable, no ADC conversion result will store in DMA FIFO.
 *
 * Values:
 * - 0 - Disable DMA FIFO.
 * - 1 - Enable DMA FIFO.
 */
/*@{*/
#define BP_ADC_DMA_FIFO_DMA_FIFO_EN (8U)   /*!< Bit position for ADC_DMA_FIFO_DMA_FIFO_EN. */
#define BM_ADC_DMA_FIFO_DMA_FIFO_EN (0x00000100U) /*!< Bit mask for ADC_DMA_FIFO_DMA_FIFO_EN. */
#define BS_ADC_DMA_FIFO_DMA_FIFO_EN (1U)   /*!< Bit field size in bits for ADC_DMA_FIFO_DMA_FIFO_EN. */

/*! @brief Read current value of the ADC_DMA_FIFO_DMA_FIFO_EN field. */
#define BR_ADC_DMA_FIFO_DMA_FIFO_EN(x) (HW_ADC_DMA_FIFO(x).B.DMA_FIFO_EN)

/*! @brief Format value for bitfield ADC_DMA_FIFO_DMA_FIFO_EN. */
#define BF_ADC_DMA_FIFO_DMA_FIFO_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_DMA_FIFO_DMA_FIFO_EN) & BM_ADC_DMA_FIFO_DMA_FIFO_EN)

/*! @brief Set the DMA_FIFO_EN field to a new value. */
#define BW_ADC_DMA_FIFO_DMA_FIFO_EN(x, v) (HW_ADC_DMA_FIFO_WR(x, (HW_ADC_DMA_FIFO_RD(x) & ~BM_ADC_DMA_FIFO_DMA_FIFO_EN) | BF_ADC_DMA_FIFO_DMA_FIFO_EN(v)))
/*@}*/

/*!
 * @name Register ADC_DMA_FIFO, field DMA_RST[9] (RW)
 *
 * This bit contains reset information. If reset, the DMA and DMA FIFO return to
 * its reset value. The DMA FIFO data is lost.
 *
 * Values:
 * - 0 - Not reset
 * - 1 - Reset
 */
/*@{*/
#define BP_ADC_DMA_FIFO_DMA_RST (9U)       /*!< Bit position for ADC_DMA_FIFO_DMA_RST. */
#define BM_ADC_DMA_FIFO_DMA_RST (0x00000200U) /*!< Bit mask for ADC_DMA_FIFO_DMA_RST. */
#define BS_ADC_DMA_FIFO_DMA_RST (1U)       /*!< Bit field size in bits for ADC_DMA_FIFO_DMA_RST. */

/*! @brief Read current value of the ADC_DMA_FIFO_DMA_RST field. */
#define BR_ADC_DMA_FIFO_DMA_RST(x) (HW_ADC_DMA_FIFO(x).B.DMA_RST)

/*! @brief Format value for bitfield ADC_DMA_FIFO_DMA_RST. */
#define BF_ADC_DMA_FIFO_DMA_RST(v) ((uint32_t)((uint32_t)(v) << BP_ADC_DMA_FIFO_DMA_RST) & BM_ADC_DMA_FIFO_DMA_RST)

/*! @brief Set the DMA_RST field to a new value. */
#define BW_ADC_DMA_FIFO_DMA_RST(x, v) (HW_ADC_DMA_FIFO_WR(x, (HW_ADC_DMA_FIFO_RD(x) & ~BM_ADC_DMA_FIFO_DMA_RST) | BF_ADC_DMA_FIFO_DMA_RST(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_FIFO_STATUS - FIFO Status
 ******************************************************************************/

/*!
 * @brief HW_ADC_FIFO_STATUS - FIFO Status (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_adc_fifo_status
{
    uint32_t U;
    struct _hw_adc_fifo_status_bitfields
    {
        uint32_t FIFO_ENTRIES : 6;     /*!< [5:0] FIFO Entries */
        uint32_t RESERVED0 : 2;        /*!< [7:6] This field is reserved. */
        uint32_t FIFO_EMPTY : 1;       /*!< [8] FIFO Empty */
        uint32_t FIFO_FULL : 1;        /*!< [9]  */
        uint32_t RESERVED1 : 22;       /*!< [31:10] This field is reserved. */
    } B;
} hw_adc_fifo_status_t;

/*!
 * @name Constants and macros for entire ADC_FIFO_STATUS register
 */
/*@{*/
#define HW_ADC_FIFO_STATUS_ADDR(x) ((uintptr_t)(x) + 0xB0U)

#define HW_ADC_FIFO_STATUS(x)    (*(__IO hw_adc_fifo_status_t *) HW_ADC_FIFO_STATUS_ADDR(x))
#define HW_ADC_FIFO_STATUS_RD(x) (HW_ADC_FIFO_STATUS(x).U)
#define HW_ADC_FIFO_STATUS_WR(x, v) (HW_ADC_FIFO_STATUS(x).U = (v))
#define HW_ADC_FIFO_STATUS_SET(x, v) (HW_ADC_FIFO_STATUS_WR(x, HW_ADC_FIFO_STATUS_RD(x) |  (v)))
#define HW_ADC_FIFO_STATUS_CLR(x, v) (HW_ADC_FIFO_STATUS_WR(x, HW_ADC_FIFO_STATUS_RD(x) & ~(v)))
#define HW_ADC_FIFO_STATUS_TOG(x, v) (HW_ADC_FIFO_STATUS_WR(x, HW_ADC_FIFO_STATUS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_FIFO_STATUS bitfields
 */

/*!
 * @name Register ADC_FIFO_STATUS, field FIFO_ENTRIES[5:0] (RW)
 *
 * This read-only bit represents the numbers of data in DMA FIFO. 00000 to 11111
 * The numbers of data stored in DMA FIFO.
 */
/*@{*/
#define BP_ADC_FIFO_STATUS_FIFO_ENTRIES (0U) /*!< Bit position for ADC_FIFO_STATUS_FIFO_ENTRIES. */
#define BM_ADC_FIFO_STATUS_FIFO_ENTRIES (0x0000003FU) /*!< Bit mask for ADC_FIFO_STATUS_FIFO_ENTRIES. */
#define BS_ADC_FIFO_STATUS_FIFO_ENTRIES (6U) /*!< Bit field size in bits for ADC_FIFO_STATUS_FIFO_ENTRIES. */

/*! @brief Read current value of the ADC_FIFO_STATUS_FIFO_ENTRIES field. */
#define BR_ADC_FIFO_STATUS_FIFO_ENTRIES(x) (HW_ADC_FIFO_STATUS(x).B.FIFO_ENTRIES)

/*! @brief Format value for bitfield ADC_FIFO_STATUS_FIFO_ENTRIES. */
#define BF_ADC_FIFO_STATUS_FIFO_ENTRIES(v) ((uint32_t)((uint32_t)(v) << BP_ADC_FIFO_STATUS_FIFO_ENTRIES) & BM_ADC_FIFO_STATUS_FIFO_ENTRIES)

/*! @brief Set the FIFO_ENTRIES field to a new value. */
#define BW_ADC_FIFO_STATUS_FIFO_ENTRIES(x, v) (HW_ADC_FIFO_STATUS_WR(x, (HW_ADC_FIFO_STATUS_RD(x) & ~BM_ADC_FIFO_STATUS_FIFO_ENTRIES) | BF_ADC_FIFO_STATUS_FIFO_ENTRIES(v)))
/*@}*/

/*!
 * @name Register ADC_FIFO_STATUS, field FIFO_EMPTY[8] (RW)
 *
 * This read-only bit represents the status of DMA FIFO. If FIFO is empty, the
 * DMA stops pop data, set this bit, and generates an interrupt.
 *
 * Values:
 * - 0 - FIFO is not empty.
 * - 1 - FIFO is empty.
 */
/*@{*/
#define BP_ADC_FIFO_STATUS_FIFO_EMPTY (8U) /*!< Bit position for ADC_FIFO_STATUS_FIFO_EMPTY. */
#define BM_ADC_FIFO_STATUS_FIFO_EMPTY (0x00000100U) /*!< Bit mask for ADC_FIFO_STATUS_FIFO_EMPTY. */
#define BS_ADC_FIFO_STATUS_FIFO_EMPTY (1U) /*!< Bit field size in bits for ADC_FIFO_STATUS_FIFO_EMPTY. */

/*! @brief Read current value of the ADC_FIFO_STATUS_FIFO_EMPTY field. */
#define BR_ADC_FIFO_STATUS_FIFO_EMPTY(x) (HW_ADC_FIFO_STATUS(x).B.FIFO_EMPTY)

/*! @brief Format value for bitfield ADC_FIFO_STATUS_FIFO_EMPTY. */
#define BF_ADC_FIFO_STATUS_FIFO_EMPTY(v) ((uint32_t)((uint32_t)(v) << BP_ADC_FIFO_STATUS_FIFO_EMPTY) & BM_ADC_FIFO_STATUS_FIFO_EMPTY)

/*! @brief Set the FIFO_EMPTY field to a new value. */
#define BW_ADC_FIFO_STATUS_FIFO_EMPTY(x, v) (HW_ADC_FIFO_STATUS_WR(x, (HW_ADC_FIFO_STATUS_RD(x) & ~BM_ADC_FIFO_STATUS_FIFO_EMPTY) | BF_ADC_FIFO_STATUS_FIFO_EMPTY(v)))
/*@}*/

/*!
 * @name Register ADC_FIFO_STATUS, field FIFO_FULL[9] (RW)
 *
 * This read-only bit represents the status of DMA FIFO. If FIFO is full, the
 * DMA stop pushing data, set this bit, and generates an interrupt.
 *
 * Values:
 * - 0 - FIFO is not full.
 * - 1 - FIFIO is full.
 */
/*@{*/
#define BP_ADC_FIFO_STATUS_FIFO_FULL (9U)  /*!< Bit position for ADC_FIFO_STATUS_FIFO_FULL. */
#define BM_ADC_FIFO_STATUS_FIFO_FULL (0x00000200U) /*!< Bit mask for ADC_FIFO_STATUS_FIFO_FULL. */
#define BS_ADC_FIFO_STATUS_FIFO_FULL (1U)  /*!< Bit field size in bits for ADC_FIFO_STATUS_FIFO_FULL. */

/*! @brief Read current value of the ADC_FIFO_STATUS_FIFO_FULL field. */
#define BR_ADC_FIFO_STATUS_FIFO_FULL(x) (HW_ADC_FIFO_STATUS(x).B.FIFO_FULL)

/*! @brief Format value for bitfield ADC_FIFO_STATUS_FIFO_FULL. */
#define BF_ADC_FIFO_STATUS_FIFO_FULL(v) ((uint32_t)((uint32_t)(v) << BP_ADC_FIFO_STATUS_FIFO_FULL) & BM_ADC_FIFO_STATUS_FIFO_FULL)

/*! @brief Set the FIFO_FULL field to a new value. */
#define BW_ADC_FIFO_STATUS_FIFO_FULL(x, v) (HW_ADC_FIFO_STATUS_WR(x, (HW_ADC_FIFO_STATUS_RD(x) & ~BM_ADC_FIFO_STATUS_FIFO_FULL) | BF_ADC_FIFO_STATUS_FIFO_FULL(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_INT_SIG_EN -
 ******************************************************************************/

/*!
 * @brief HW_ADC_INT_SIG_EN -  (RW)
 *
 * Reset value: 0x001F1FCFU
 */
typedef union _hw_adc_int_sig_en
{
    uint32_t U;
    struct _hw_adc_int_sig_en_bitfields
    {
        uint32_t CHA_CMP_INT_SIG_EN : 1; /*!< [0] Channel A Compare Interrupt
                                        * Signal Enable */
        uint32_t CHB_CMP_INT_SIG_EN : 1; /*!< [1] Channel B Compare Interrupt
                                        * Signal Enable */
        uint32_t CHC_CMP_INT_SIG_EN : 1; /*!< [2] Channel C Compare Interrupt
                                        * Signal Enable */
        uint32_t CHD_CMP_INT_SIG_EN : 1; /*!< [3] Channel D Compare Interrupt
                                        * Signal Enable */
        uint32_t RESERVED0 : 1;        /*!< [4] This field is reserved. */
        uint32_t DMA_REACH_WM_INT_SIG_EN : 1; /*!< [5] DMA Reach Watermark
                                        * Level Interrupt Signal (Flag) Enable */
        uint32_t FIFO_UNDERRUN_INT_SIG_EN : 1; /*!< [6] FIFO Underrrun
                                        * Interrupt Signal Enable */
        uint32_t FIFO_OVRRUN_INT_SIG_EN : 1; /*!< [7] FIFO overrun Interrupt
                                        * Signal Enable */
        uint32_t CHA_COV_INT_SIG_EN : 1; /*!< [8] Channel A Conversion
                                        * Interrupt Signal Enable */
        uint32_t CHB_COV_INT_SIG_EN : 1; /*!< [9] Channel B Conversion
                                        * Interrupt Signal Enable */
        uint32_t CHC_COV_INT_SIG_EN : 1; /*!< [10] Channel C Conversion
                                        * Interrupt Signal Enable */
        uint32_t CHD_COV_INT_SIG_EN : 1; /*!< [11] Channel D Conversion
                                        * Interrupt Signal Enable */
        uint32_t SW_CH_COV_INT_SIG_EN : 1; /*!< [12] Software Channel
                                        * Conversion Interrupt Signal Enable */
        uint32_t RESERVED1 : 3;        /*!< [15:13] This field is reserved. */
        uint32_t CHA_COV_TO_INT_SIG_EN : 1; /*!< [16] Channel A Conversion
                                        * Time Out Interrupt Signal Enable */
        uint32_t CHB_COV_TO_INT_SIG_EN : 1; /*!< [17] Channel B Conversion
                                        * Time Out Interrupt Signal Enable */
        uint32_t CHC_COV_TO_INT_SIG_EN : 1; /*!< [18] Channel C Conversion
                                        * Time Out Interrupt Signal Enable */
        uint32_t CHD_COV_TO_INT_SIG_EN : 1; /*!< [19] Channel D Conversion
                                        * Time Out Interrupt Signal Enable */
        uint32_t SW_CH_COV_TO_INT_SIG_EN : 1; /*!< [20] Software Channel
                                        * Conversion Time Out Interrupt Signal Enable */
        uint32_t LAST_FIFO_DATA_READ_SIG_EN : 1; /*!< [21] Last FIFO Data
                                        * Read Signal Enable */
        uint32_t RESERVED2 : 10;       /*!< [31:22] This field is reserved. */
    } B;
} hw_adc_int_sig_en_t;

/*!
 * @name Constants and macros for entire ADC_INT_SIG_EN register
 */
/*@{*/
#define HW_ADC_INT_SIG_EN_ADDR(x) ((uintptr_t)(x) + 0xC0U)

#define HW_ADC_INT_SIG_EN(x)     (*(__IO hw_adc_int_sig_en_t *) HW_ADC_INT_SIG_EN_ADDR(x))
#define HW_ADC_INT_SIG_EN_RD(x)  (HW_ADC_INT_SIG_EN(x).U)
#define HW_ADC_INT_SIG_EN_WR(x, v) (HW_ADC_INT_SIG_EN(x).U = (v))
#define HW_ADC_INT_SIG_EN_SET(x, v) (HW_ADC_INT_SIG_EN_WR(x, HW_ADC_INT_SIG_EN_RD(x) |  (v)))
#define HW_ADC_INT_SIG_EN_CLR(x, v) (HW_ADC_INT_SIG_EN_WR(x, HW_ADC_INT_SIG_EN_RD(x) & ~(v)))
#define HW_ADC_INT_SIG_EN_TOG(x, v) (HW_ADC_INT_SIG_EN_WR(x, HW_ADC_INT_SIG_EN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_INT_SIG_EN bitfields
 */

/*!
 * @name Register ADC_INT_SIG_EN, field CHA_CMP_INT_SIG_EN[0] (RW)
 *
 * Define whether channel A compare interrupt flag is enabled. If enable the
 * interrupt flag, an interrupt is set once channel A conversion result matches the
 * compare region.
 *
 * Values:
 * - 0 - Disable Channel A Compare Interrupt flag.
 * - 1 - Enable Channel A Compare Interrupt flag.
 */
/*@{*/
#define BP_ADC_INT_SIG_EN_CHA_CMP_INT_SIG_EN (0U) /*!< Bit position for ADC_INT_SIG_EN_CHA_CMP_INT_SIG_EN. */
#define BM_ADC_INT_SIG_EN_CHA_CMP_INT_SIG_EN (0x00000001U) /*!< Bit mask for ADC_INT_SIG_EN_CHA_CMP_INT_SIG_EN. */
#define BS_ADC_INT_SIG_EN_CHA_CMP_INT_SIG_EN (1U) /*!< Bit field size in bits for ADC_INT_SIG_EN_CHA_CMP_INT_SIG_EN. */

/*! @brief Read current value of the ADC_INT_SIG_EN_CHA_CMP_INT_SIG_EN field. */
#define BR_ADC_INT_SIG_EN_CHA_CMP_INT_SIG_EN(x) (HW_ADC_INT_SIG_EN(x).B.CHA_CMP_INT_SIG_EN)

/*! @brief Format value for bitfield ADC_INT_SIG_EN_CHA_CMP_INT_SIG_EN. */
#define BF_ADC_INT_SIG_EN_CHA_CMP_INT_SIG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_SIG_EN_CHA_CMP_INT_SIG_EN) & BM_ADC_INT_SIG_EN_CHA_CMP_INT_SIG_EN)

/*! @brief Set the CHA_CMP_INT_SIG_EN field to a new value. */
#define BW_ADC_INT_SIG_EN_CHA_CMP_INT_SIG_EN(x, v) (HW_ADC_INT_SIG_EN_WR(x, (HW_ADC_INT_SIG_EN_RD(x) & ~BM_ADC_INT_SIG_EN_CHA_CMP_INT_SIG_EN) | BF_ADC_INT_SIG_EN_CHA_CMP_INT_SIG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_SIG_EN, field CHB_CMP_INT_SIG_EN[1] (RW)
 *
 * Define whether channel B compare interrupt flag is enabled. If enable the
 * interrupt flag, an interrupt flag is set once channel B conversion result matches
 * the compare region.
 *
 * Values:
 * - 0 - Disable Channel B Compare Interrupt flag.
 * - 1 - Enable Channel B Compare Interrupt flag.
 */
/*@{*/
#define BP_ADC_INT_SIG_EN_CHB_CMP_INT_SIG_EN (1U) /*!< Bit position for ADC_INT_SIG_EN_CHB_CMP_INT_SIG_EN. */
#define BM_ADC_INT_SIG_EN_CHB_CMP_INT_SIG_EN (0x00000002U) /*!< Bit mask for ADC_INT_SIG_EN_CHB_CMP_INT_SIG_EN. */
#define BS_ADC_INT_SIG_EN_CHB_CMP_INT_SIG_EN (1U) /*!< Bit field size in bits for ADC_INT_SIG_EN_CHB_CMP_INT_SIG_EN. */

/*! @brief Read current value of the ADC_INT_SIG_EN_CHB_CMP_INT_SIG_EN field. */
#define BR_ADC_INT_SIG_EN_CHB_CMP_INT_SIG_EN(x) (HW_ADC_INT_SIG_EN(x).B.CHB_CMP_INT_SIG_EN)

/*! @brief Format value for bitfield ADC_INT_SIG_EN_CHB_CMP_INT_SIG_EN. */
#define BF_ADC_INT_SIG_EN_CHB_CMP_INT_SIG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_SIG_EN_CHB_CMP_INT_SIG_EN) & BM_ADC_INT_SIG_EN_CHB_CMP_INT_SIG_EN)

/*! @brief Set the CHB_CMP_INT_SIG_EN field to a new value. */
#define BW_ADC_INT_SIG_EN_CHB_CMP_INT_SIG_EN(x, v) (HW_ADC_INT_SIG_EN_WR(x, (HW_ADC_INT_SIG_EN_RD(x) & ~BM_ADC_INT_SIG_EN_CHB_CMP_INT_SIG_EN) | BF_ADC_INT_SIG_EN_CHB_CMP_INT_SIG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_SIG_EN, field CHC_CMP_INT_SIG_EN[2] (RW)
 *
 * Define whether channel C compare interrupt flag is enabled. If enable the
 * interrupt flag, an interrupt flag is set once channel C conversion result matches
 * the compare region.
 *
 * Values:
 * - 0 - Disable Channel C Compare Interrupt flag.
 * - 1 - Enable Channel C Compare Interrupt flag.
 */
/*@{*/
#define BP_ADC_INT_SIG_EN_CHC_CMP_INT_SIG_EN (2U) /*!< Bit position for ADC_INT_SIG_EN_CHC_CMP_INT_SIG_EN. */
#define BM_ADC_INT_SIG_EN_CHC_CMP_INT_SIG_EN (0x00000004U) /*!< Bit mask for ADC_INT_SIG_EN_CHC_CMP_INT_SIG_EN. */
#define BS_ADC_INT_SIG_EN_CHC_CMP_INT_SIG_EN (1U) /*!< Bit field size in bits for ADC_INT_SIG_EN_CHC_CMP_INT_SIG_EN. */

/*! @brief Read current value of the ADC_INT_SIG_EN_CHC_CMP_INT_SIG_EN field. */
#define BR_ADC_INT_SIG_EN_CHC_CMP_INT_SIG_EN(x) (HW_ADC_INT_SIG_EN(x).B.CHC_CMP_INT_SIG_EN)

/*! @brief Format value for bitfield ADC_INT_SIG_EN_CHC_CMP_INT_SIG_EN. */
#define BF_ADC_INT_SIG_EN_CHC_CMP_INT_SIG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_SIG_EN_CHC_CMP_INT_SIG_EN) & BM_ADC_INT_SIG_EN_CHC_CMP_INT_SIG_EN)

/*! @brief Set the CHC_CMP_INT_SIG_EN field to a new value. */
#define BW_ADC_INT_SIG_EN_CHC_CMP_INT_SIG_EN(x, v) (HW_ADC_INT_SIG_EN_WR(x, (HW_ADC_INT_SIG_EN_RD(x) & ~BM_ADC_INT_SIG_EN_CHC_CMP_INT_SIG_EN) | BF_ADC_INT_SIG_EN_CHC_CMP_INT_SIG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_SIG_EN, field CHD_CMP_INT_SIG_EN[3] (RW)
 *
 * Define whether channel D compare interrupt flag is enabled. If enable the
 * interrupt flag, an interrupt flag is set once channel D conversion result matches
 * the compare region.
 *
 * Values:
 * - 0 - Disable Channel D Compare Interrupt flag
 * - 1 - Enable Channel D Compare Interrupt flag
 */
/*@{*/
#define BP_ADC_INT_SIG_EN_CHD_CMP_INT_SIG_EN (3U) /*!< Bit position for ADC_INT_SIG_EN_CHD_CMP_INT_SIG_EN. */
#define BM_ADC_INT_SIG_EN_CHD_CMP_INT_SIG_EN (0x00000008U) /*!< Bit mask for ADC_INT_SIG_EN_CHD_CMP_INT_SIG_EN. */
#define BS_ADC_INT_SIG_EN_CHD_CMP_INT_SIG_EN (1U) /*!< Bit field size in bits for ADC_INT_SIG_EN_CHD_CMP_INT_SIG_EN. */

/*! @brief Read current value of the ADC_INT_SIG_EN_CHD_CMP_INT_SIG_EN field. */
#define BR_ADC_INT_SIG_EN_CHD_CMP_INT_SIG_EN(x) (HW_ADC_INT_SIG_EN(x).B.CHD_CMP_INT_SIG_EN)

/*! @brief Format value for bitfield ADC_INT_SIG_EN_CHD_CMP_INT_SIG_EN. */
#define BF_ADC_INT_SIG_EN_CHD_CMP_INT_SIG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_SIG_EN_CHD_CMP_INT_SIG_EN) & BM_ADC_INT_SIG_EN_CHD_CMP_INT_SIG_EN)

/*! @brief Set the CHD_CMP_INT_SIG_EN field to a new value. */
#define BW_ADC_INT_SIG_EN_CHD_CMP_INT_SIG_EN(x, v) (HW_ADC_INT_SIG_EN_WR(x, (HW_ADC_INT_SIG_EN_RD(x) & ~BM_ADC_INT_SIG_EN_CHD_CMP_INT_SIG_EN) | BF_ADC_INT_SIG_EN_CHD_CMP_INT_SIG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_SIG_EN, field DMA_REACH_WM_INT_SIG_EN[5] (RW)
 *
 * Define whether the number of data in DMA FIFO is greater than DMA watermark
 * level. If it is greater, then a flag is set.
 *
 * Values:
 * - 0 - Enable DMA watermark level interrupt signal (flag).
 * - 1 - Disable DMA watermark level interrupt signal (flag).
 */
/*@{*/
#define BP_ADC_INT_SIG_EN_DMA_REACH_WM_INT_SIG_EN (5U) /*!< Bit position for ADC_INT_SIG_EN_DMA_REACH_WM_INT_SIG_EN. */
#define BM_ADC_INT_SIG_EN_DMA_REACH_WM_INT_SIG_EN (0x00000020U) /*!< Bit mask for ADC_INT_SIG_EN_DMA_REACH_WM_INT_SIG_EN. */
#define BS_ADC_INT_SIG_EN_DMA_REACH_WM_INT_SIG_EN (1U) /*!< Bit field size in bits for ADC_INT_SIG_EN_DMA_REACH_WM_INT_SIG_EN. */

/*! @brief Read current value of the ADC_INT_SIG_EN_DMA_REACH_WM_INT_SIG_EN field. */
#define BR_ADC_INT_SIG_EN_DMA_REACH_WM_INT_SIG_EN(x) (HW_ADC_INT_SIG_EN(x).B.DMA_REACH_WM_INT_SIG_EN)

/*! @brief Format value for bitfield ADC_INT_SIG_EN_DMA_REACH_WM_INT_SIG_EN. */
#define BF_ADC_INT_SIG_EN_DMA_REACH_WM_INT_SIG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_SIG_EN_DMA_REACH_WM_INT_SIG_EN) & BM_ADC_INT_SIG_EN_DMA_REACH_WM_INT_SIG_EN)

/*! @brief Set the DMA_REACH_WM_INT_SIG_EN field to a new value. */
#define BW_ADC_INT_SIG_EN_DMA_REACH_WM_INT_SIG_EN(x, v) (HW_ADC_INT_SIG_EN_WR(x, (HW_ADC_INT_SIG_EN_RD(x) & ~BM_ADC_INT_SIG_EN_DMA_REACH_WM_INT_SIG_EN) | BF_ADC_INT_SIG_EN_DMA_REACH_WM_INT_SIG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_SIG_EN, field FIFO_UNDERRUN_INT_SIG_EN[6] (RW)
 *
 * Define whether DMA FIFO underrun interrupt flag is enabled. If DMA FIFO
 * underrun interrupt flag is enabled and DMA FIFO has underrun condition, then an
 * interrupt flag is generated.
 *
 * Values:
 * - 0 - Enable FIFO underrun Interrupt flag
 * - 1 - Disable FIFO underrun Interrupt flag
 */
/*@{*/
#define BP_ADC_INT_SIG_EN_FIFO_UNDERRUN_INT_SIG_EN (6U) /*!< Bit position for ADC_INT_SIG_EN_FIFO_UNDERRUN_INT_SIG_EN. */
#define BM_ADC_INT_SIG_EN_FIFO_UNDERRUN_INT_SIG_EN (0x00000040U) /*!< Bit mask for ADC_INT_SIG_EN_FIFO_UNDERRUN_INT_SIG_EN. */
#define BS_ADC_INT_SIG_EN_FIFO_UNDERRUN_INT_SIG_EN (1U) /*!< Bit field size in bits for ADC_INT_SIG_EN_FIFO_UNDERRUN_INT_SIG_EN. */

/*! @brief Read current value of the ADC_INT_SIG_EN_FIFO_UNDERRUN_INT_SIG_EN field. */
#define BR_ADC_INT_SIG_EN_FIFO_UNDERRUN_INT_SIG_EN(x) (HW_ADC_INT_SIG_EN(x).B.FIFO_UNDERRUN_INT_SIG_EN)

/*! @brief Format value for bitfield ADC_INT_SIG_EN_FIFO_UNDERRUN_INT_SIG_EN. */
#define BF_ADC_INT_SIG_EN_FIFO_UNDERRUN_INT_SIG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_SIG_EN_FIFO_UNDERRUN_INT_SIG_EN) & BM_ADC_INT_SIG_EN_FIFO_UNDERRUN_INT_SIG_EN)

/*! @brief Set the FIFO_UNDERRUN_INT_SIG_EN field to a new value. */
#define BW_ADC_INT_SIG_EN_FIFO_UNDERRUN_INT_SIG_EN(x, v) (HW_ADC_INT_SIG_EN_WR(x, (HW_ADC_INT_SIG_EN_RD(x) & ~BM_ADC_INT_SIG_EN_FIFO_UNDERRUN_INT_SIG_EN) | BF_ADC_INT_SIG_EN_FIFO_UNDERRUN_INT_SIG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_SIG_EN, field FIFO_OVRRUN_INT_SIG_EN[7] (RW)
 *
 * Define whether DMA FIFO overrun interrupt flag is enabled. If DMA FIFO
 * overrun interrupt flag enabled and DMA FIFO has overrun condition, then an interrupt
 * flag is generated.
 *
 * Values:
 * - 0 - Enable FIFO Interrupt flag.
 * - 1 - Disable FIFO Interrupt flag.
 */
/*@{*/
#define BP_ADC_INT_SIG_EN_FIFO_OVRRUN_INT_SIG_EN (7U) /*!< Bit position for ADC_INT_SIG_EN_FIFO_OVRRUN_INT_SIG_EN. */
#define BM_ADC_INT_SIG_EN_FIFO_OVRRUN_INT_SIG_EN (0x00000080U) /*!< Bit mask for ADC_INT_SIG_EN_FIFO_OVRRUN_INT_SIG_EN. */
#define BS_ADC_INT_SIG_EN_FIFO_OVRRUN_INT_SIG_EN (1U) /*!< Bit field size in bits for ADC_INT_SIG_EN_FIFO_OVRRUN_INT_SIG_EN. */

/*! @brief Read current value of the ADC_INT_SIG_EN_FIFO_OVRRUN_INT_SIG_EN field. */
#define BR_ADC_INT_SIG_EN_FIFO_OVRRUN_INT_SIG_EN(x) (HW_ADC_INT_SIG_EN(x).B.FIFO_OVRRUN_INT_SIG_EN)

/*! @brief Format value for bitfield ADC_INT_SIG_EN_FIFO_OVRRUN_INT_SIG_EN. */
#define BF_ADC_INT_SIG_EN_FIFO_OVRRUN_INT_SIG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_SIG_EN_FIFO_OVRRUN_INT_SIG_EN) & BM_ADC_INT_SIG_EN_FIFO_OVRRUN_INT_SIG_EN)

/*! @brief Set the FIFO_OVRRUN_INT_SIG_EN field to a new value. */
#define BW_ADC_INT_SIG_EN_FIFO_OVRRUN_INT_SIG_EN(x, v) (HW_ADC_INT_SIG_EN_WR(x, (HW_ADC_INT_SIG_EN_RD(x) & ~BM_ADC_INT_SIG_EN_FIFO_OVRRUN_INT_SIG_EN) | BF_ADC_INT_SIG_EN_FIFO_OVRRUN_INT_SIG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_SIG_EN, field CHA_COV_INT_SIG_EN[8] (RW)
 *
 * Define whether channel A round conversion interrupt flag enable. If enable
 * interrupt flag, an interrupt flag is generated once Channel A finish a new
 * conversion.
 *
 * Values:
 * - 0 - Disable channel A conversion Interrupt flag.
 * - 1 - Enable channel A conversion Interrupt flag.
 */
/*@{*/
#define BP_ADC_INT_SIG_EN_CHA_COV_INT_SIG_EN (8U) /*!< Bit position for ADC_INT_SIG_EN_CHA_COV_INT_SIG_EN. */
#define BM_ADC_INT_SIG_EN_CHA_COV_INT_SIG_EN (0x00000100U) /*!< Bit mask for ADC_INT_SIG_EN_CHA_COV_INT_SIG_EN. */
#define BS_ADC_INT_SIG_EN_CHA_COV_INT_SIG_EN (1U) /*!< Bit field size in bits for ADC_INT_SIG_EN_CHA_COV_INT_SIG_EN. */

/*! @brief Read current value of the ADC_INT_SIG_EN_CHA_COV_INT_SIG_EN field. */
#define BR_ADC_INT_SIG_EN_CHA_COV_INT_SIG_EN(x) (HW_ADC_INT_SIG_EN(x).B.CHA_COV_INT_SIG_EN)

/*! @brief Format value for bitfield ADC_INT_SIG_EN_CHA_COV_INT_SIG_EN. */
#define BF_ADC_INT_SIG_EN_CHA_COV_INT_SIG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_SIG_EN_CHA_COV_INT_SIG_EN) & BM_ADC_INT_SIG_EN_CHA_COV_INT_SIG_EN)

/*! @brief Set the CHA_COV_INT_SIG_EN field to a new value. */
#define BW_ADC_INT_SIG_EN_CHA_COV_INT_SIG_EN(x, v) (HW_ADC_INT_SIG_EN_WR(x, (HW_ADC_INT_SIG_EN_RD(x) & ~BM_ADC_INT_SIG_EN_CHA_COV_INT_SIG_EN) | BF_ADC_INT_SIG_EN_CHA_COV_INT_SIG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_SIG_EN, field CHB_COV_INT_SIG_EN[9] (RW)
 *
 * Define whether channel B conversion interrupt flag is enabled. If enable
 * interrupt flag, an interrupt flag is generated once Channel B finish a new
 * conversion.
 *
 * Values:
 * - 0 - Disable channel B conversion Interrupt flag.
 * - 1 - Enable channel B conversion Interrupt flag.
 */
/*@{*/
#define BP_ADC_INT_SIG_EN_CHB_COV_INT_SIG_EN (9U) /*!< Bit position for ADC_INT_SIG_EN_CHB_COV_INT_SIG_EN. */
#define BM_ADC_INT_SIG_EN_CHB_COV_INT_SIG_EN (0x00000200U) /*!< Bit mask for ADC_INT_SIG_EN_CHB_COV_INT_SIG_EN. */
#define BS_ADC_INT_SIG_EN_CHB_COV_INT_SIG_EN (1U) /*!< Bit field size in bits for ADC_INT_SIG_EN_CHB_COV_INT_SIG_EN. */

/*! @brief Read current value of the ADC_INT_SIG_EN_CHB_COV_INT_SIG_EN field. */
#define BR_ADC_INT_SIG_EN_CHB_COV_INT_SIG_EN(x) (HW_ADC_INT_SIG_EN(x).B.CHB_COV_INT_SIG_EN)

/*! @brief Format value for bitfield ADC_INT_SIG_EN_CHB_COV_INT_SIG_EN. */
#define BF_ADC_INT_SIG_EN_CHB_COV_INT_SIG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_SIG_EN_CHB_COV_INT_SIG_EN) & BM_ADC_INT_SIG_EN_CHB_COV_INT_SIG_EN)

/*! @brief Set the CHB_COV_INT_SIG_EN field to a new value. */
#define BW_ADC_INT_SIG_EN_CHB_COV_INT_SIG_EN(x, v) (HW_ADC_INT_SIG_EN_WR(x, (HW_ADC_INT_SIG_EN_RD(x) & ~BM_ADC_INT_SIG_EN_CHB_COV_INT_SIG_EN) | BF_ADC_INT_SIG_EN_CHB_COV_INT_SIG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_SIG_EN, field CHC_COV_INT_SIG_EN[10] (RW)
 *
 * Define whether channel C conversion interrupt flag is enabled. If enable
 * interrupt flag, an interrupt flag is set once Channel C finish a new conversion.
 *
 * Values:
 * - 0 - Disable channel C conversion Interrupt flag.
 * - 1 - Enable channel C conversion Interrupt flag.
 */
/*@{*/
#define BP_ADC_INT_SIG_EN_CHC_COV_INT_SIG_EN (10U) /*!< Bit position for ADC_INT_SIG_EN_CHC_COV_INT_SIG_EN. */
#define BM_ADC_INT_SIG_EN_CHC_COV_INT_SIG_EN (0x00000400U) /*!< Bit mask for ADC_INT_SIG_EN_CHC_COV_INT_SIG_EN. */
#define BS_ADC_INT_SIG_EN_CHC_COV_INT_SIG_EN (1U) /*!< Bit field size in bits for ADC_INT_SIG_EN_CHC_COV_INT_SIG_EN. */

/*! @brief Read current value of the ADC_INT_SIG_EN_CHC_COV_INT_SIG_EN field. */
#define BR_ADC_INT_SIG_EN_CHC_COV_INT_SIG_EN(x) (HW_ADC_INT_SIG_EN(x).B.CHC_COV_INT_SIG_EN)

/*! @brief Format value for bitfield ADC_INT_SIG_EN_CHC_COV_INT_SIG_EN. */
#define BF_ADC_INT_SIG_EN_CHC_COV_INT_SIG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_SIG_EN_CHC_COV_INT_SIG_EN) & BM_ADC_INT_SIG_EN_CHC_COV_INT_SIG_EN)

/*! @brief Set the CHC_COV_INT_SIG_EN field to a new value. */
#define BW_ADC_INT_SIG_EN_CHC_COV_INT_SIG_EN(x, v) (HW_ADC_INT_SIG_EN_WR(x, (HW_ADC_INT_SIG_EN_RD(x) & ~BM_ADC_INT_SIG_EN_CHC_COV_INT_SIG_EN) | BF_ADC_INT_SIG_EN_CHC_COV_INT_SIG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_SIG_EN, field CHD_COV_INT_SIG_EN[11] (RW)
 *
 * Define whether channel D conversion interrupt flag is enabled. If enable
 * interrupt flag, an interrupt flag is set once Channel D finish a new conversion.
 *
 * Values:
 * - 0 - Disable channel D conversion Interrupt flag.
 * - 1 - Enable channel D conversion Interrupt flag.
 */
/*@{*/
#define BP_ADC_INT_SIG_EN_CHD_COV_INT_SIG_EN (11U) /*!< Bit position for ADC_INT_SIG_EN_CHD_COV_INT_SIG_EN. */
#define BM_ADC_INT_SIG_EN_CHD_COV_INT_SIG_EN (0x00000800U) /*!< Bit mask for ADC_INT_SIG_EN_CHD_COV_INT_SIG_EN. */
#define BS_ADC_INT_SIG_EN_CHD_COV_INT_SIG_EN (1U) /*!< Bit field size in bits for ADC_INT_SIG_EN_CHD_COV_INT_SIG_EN. */

/*! @brief Read current value of the ADC_INT_SIG_EN_CHD_COV_INT_SIG_EN field. */
#define BR_ADC_INT_SIG_EN_CHD_COV_INT_SIG_EN(x) (HW_ADC_INT_SIG_EN(x).B.CHD_COV_INT_SIG_EN)

/*! @brief Format value for bitfield ADC_INT_SIG_EN_CHD_COV_INT_SIG_EN. */
#define BF_ADC_INT_SIG_EN_CHD_COV_INT_SIG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_SIG_EN_CHD_COV_INT_SIG_EN) & BM_ADC_INT_SIG_EN_CHD_COV_INT_SIG_EN)

/*! @brief Set the CHD_COV_INT_SIG_EN field to a new value. */
#define BW_ADC_INT_SIG_EN_CHD_COV_INT_SIG_EN(x, v) (HW_ADC_INT_SIG_EN_WR(x, (HW_ADC_INT_SIG_EN_RD(x) & ~BM_ADC_INT_SIG_EN_CHD_COV_INT_SIG_EN) | BF_ADC_INT_SIG_EN_CHD_COV_INT_SIG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_SIG_EN, field SW_CH_COV_INT_SIG_EN[12] (RW)
 *
 * Define whether software trigger interrupt flag is enabled.
 *
 * Values:
 * - 0 - Disable software channel conversion signal interrupt flag.
 * - 1 - Enable software channel conversion signal interrupt flag.
 */
/*@{*/
#define BP_ADC_INT_SIG_EN_SW_CH_COV_INT_SIG_EN (12U) /*!< Bit position for ADC_INT_SIG_EN_SW_CH_COV_INT_SIG_EN. */
#define BM_ADC_INT_SIG_EN_SW_CH_COV_INT_SIG_EN (0x00001000U) /*!< Bit mask for ADC_INT_SIG_EN_SW_CH_COV_INT_SIG_EN. */
#define BS_ADC_INT_SIG_EN_SW_CH_COV_INT_SIG_EN (1U) /*!< Bit field size in bits for ADC_INT_SIG_EN_SW_CH_COV_INT_SIG_EN. */

/*! @brief Read current value of the ADC_INT_SIG_EN_SW_CH_COV_INT_SIG_EN field. */
#define BR_ADC_INT_SIG_EN_SW_CH_COV_INT_SIG_EN(x) (HW_ADC_INT_SIG_EN(x).B.SW_CH_COV_INT_SIG_EN)

/*! @brief Format value for bitfield ADC_INT_SIG_EN_SW_CH_COV_INT_SIG_EN. */
#define BF_ADC_INT_SIG_EN_SW_CH_COV_INT_SIG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_SIG_EN_SW_CH_COV_INT_SIG_EN) & BM_ADC_INT_SIG_EN_SW_CH_COV_INT_SIG_EN)

/*! @brief Set the SW_CH_COV_INT_SIG_EN field to a new value. */
#define BW_ADC_INT_SIG_EN_SW_CH_COV_INT_SIG_EN(x, v) (HW_ADC_INT_SIG_EN_WR(x, (HW_ADC_INT_SIG_EN_RD(x) & ~BM_ADC_INT_SIG_EN_SW_CH_COV_INT_SIG_EN) | BF_ADC_INT_SIG_EN_SW_CH_COV_INT_SIG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_SIG_EN, field CHA_COV_TO_INT_SIG_EN[16] (RW)
 *
 * Define whether logical channel A conversion time out interrupt signal is
 * enabled.
 *
 * Values:
 * - 0 - Disable logical channel A conversion time out interrupt signal.
 * - 1 - Enable logical channel A conversion time out interrupt signal.
 */
/*@{*/
#define BP_ADC_INT_SIG_EN_CHA_COV_TO_INT_SIG_EN (16U) /*!< Bit position for ADC_INT_SIG_EN_CHA_COV_TO_INT_SIG_EN. */
#define BM_ADC_INT_SIG_EN_CHA_COV_TO_INT_SIG_EN (0x00010000U) /*!< Bit mask for ADC_INT_SIG_EN_CHA_COV_TO_INT_SIG_EN. */
#define BS_ADC_INT_SIG_EN_CHA_COV_TO_INT_SIG_EN (1U) /*!< Bit field size in bits for ADC_INT_SIG_EN_CHA_COV_TO_INT_SIG_EN. */

/*! @brief Read current value of the ADC_INT_SIG_EN_CHA_COV_TO_INT_SIG_EN field. */
#define BR_ADC_INT_SIG_EN_CHA_COV_TO_INT_SIG_EN(x) (HW_ADC_INT_SIG_EN(x).B.CHA_COV_TO_INT_SIG_EN)

/*! @brief Format value for bitfield ADC_INT_SIG_EN_CHA_COV_TO_INT_SIG_EN. */
#define BF_ADC_INT_SIG_EN_CHA_COV_TO_INT_SIG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_SIG_EN_CHA_COV_TO_INT_SIG_EN) & BM_ADC_INT_SIG_EN_CHA_COV_TO_INT_SIG_EN)

/*! @brief Set the CHA_COV_TO_INT_SIG_EN field to a new value. */
#define BW_ADC_INT_SIG_EN_CHA_COV_TO_INT_SIG_EN(x, v) (HW_ADC_INT_SIG_EN_WR(x, (HW_ADC_INT_SIG_EN_RD(x) & ~BM_ADC_INT_SIG_EN_CHA_COV_TO_INT_SIG_EN) | BF_ADC_INT_SIG_EN_CHA_COV_TO_INT_SIG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_SIG_EN, field CHB_COV_TO_INT_SIG_EN[17] (RW)
 *
 * Define whether logical channel B conversion time out interrupt signal is
 * enabled.
 *
 * Values:
 * - 0 - Disable logical channel B conversion time out interrupt signal.
 * - 1 - Enable logical channel B conversion time out interrupt signal.
 */
/*@{*/
#define BP_ADC_INT_SIG_EN_CHB_COV_TO_INT_SIG_EN (17U) /*!< Bit position for ADC_INT_SIG_EN_CHB_COV_TO_INT_SIG_EN. */
#define BM_ADC_INT_SIG_EN_CHB_COV_TO_INT_SIG_EN (0x00020000U) /*!< Bit mask for ADC_INT_SIG_EN_CHB_COV_TO_INT_SIG_EN. */
#define BS_ADC_INT_SIG_EN_CHB_COV_TO_INT_SIG_EN (1U) /*!< Bit field size in bits for ADC_INT_SIG_EN_CHB_COV_TO_INT_SIG_EN. */

/*! @brief Read current value of the ADC_INT_SIG_EN_CHB_COV_TO_INT_SIG_EN field. */
#define BR_ADC_INT_SIG_EN_CHB_COV_TO_INT_SIG_EN(x) (HW_ADC_INT_SIG_EN(x).B.CHB_COV_TO_INT_SIG_EN)

/*! @brief Format value for bitfield ADC_INT_SIG_EN_CHB_COV_TO_INT_SIG_EN. */
#define BF_ADC_INT_SIG_EN_CHB_COV_TO_INT_SIG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_SIG_EN_CHB_COV_TO_INT_SIG_EN) & BM_ADC_INT_SIG_EN_CHB_COV_TO_INT_SIG_EN)

/*! @brief Set the CHB_COV_TO_INT_SIG_EN field to a new value. */
#define BW_ADC_INT_SIG_EN_CHB_COV_TO_INT_SIG_EN(x, v) (HW_ADC_INT_SIG_EN_WR(x, (HW_ADC_INT_SIG_EN_RD(x) & ~BM_ADC_INT_SIG_EN_CHB_COV_TO_INT_SIG_EN) | BF_ADC_INT_SIG_EN_CHB_COV_TO_INT_SIG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_SIG_EN, field CHC_COV_TO_INT_SIG_EN[18] (RW)
 *
 * Define whether logical channel C conversion time out interrupt signal is
 * enabled.
 *
 * Values:
 * - 0 - Disable logical channel C conversion time out interrupt signal.
 * - 1 - Enable logical channel C conversion time out interrupt signal.
 */
/*@{*/
#define BP_ADC_INT_SIG_EN_CHC_COV_TO_INT_SIG_EN (18U) /*!< Bit position for ADC_INT_SIG_EN_CHC_COV_TO_INT_SIG_EN. */
#define BM_ADC_INT_SIG_EN_CHC_COV_TO_INT_SIG_EN (0x00040000U) /*!< Bit mask for ADC_INT_SIG_EN_CHC_COV_TO_INT_SIG_EN. */
#define BS_ADC_INT_SIG_EN_CHC_COV_TO_INT_SIG_EN (1U) /*!< Bit field size in bits for ADC_INT_SIG_EN_CHC_COV_TO_INT_SIG_EN. */

/*! @brief Read current value of the ADC_INT_SIG_EN_CHC_COV_TO_INT_SIG_EN field. */
#define BR_ADC_INT_SIG_EN_CHC_COV_TO_INT_SIG_EN(x) (HW_ADC_INT_SIG_EN(x).B.CHC_COV_TO_INT_SIG_EN)

/*! @brief Format value for bitfield ADC_INT_SIG_EN_CHC_COV_TO_INT_SIG_EN. */
#define BF_ADC_INT_SIG_EN_CHC_COV_TO_INT_SIG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_SIG_EN_CHC_COV_TO_INT_SIG_EN) & BM_ADC_INT_SIG_EN_CHC_COV_TO_INT_SIG_EN)

/*! @brief Set the CHC_COV_TO_INT_SIG_EN field to a new value. */
#define BW_ADC_INT_SIG_EN_CHC_COV_TO_INT_SIG_EN(x, v) (HW_ADC_INT_SIG_EN_WR(x, (HW_ADC_INT_SIG_EN_RD(x) & ~BM_ADC_INT_SIG_EN_CHC_COV_TO_INT_SIG_EN) | BF_ADC_INT_SIG_EN_CHC_COV_TO_INT_SIG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_SIG_EN, field CHD_COV_TO_INT_SIG_EN[19] (RW)
 *
 * Define whether logical channel D conversion time out interrupt signal is
 * enabled.
 *
 * Values:
 * - 0 - Disable logical channel D conversion time out interrupt signal.
 * - 1 - Enable logical channel D conversion time out interrupt signal.
 */
/*@{*/
#define BP_ADC_INT_SIG_EN_CHD_COV_TO_INT_SIG_EN (19U) /*!< Bit position for ADC_INT_SIG_EN_CHD_COV_TO_INT_SIG_EN. */
#define BM_ADC_INT_SIG_EN_CHD_COV_TO_INT_SIG_EN (0x00080000U) /*!< Bit mask for ADC_INT_SIG_EN_CHD_COV_TO_INT_SIG_EN. */
#define BS_ADC_INT_SIG_EN_CHD_COV_TO_INT_SIG_EN (1U) /*!< Bit field size in bits for ADC_INT_SIG_EN_CHD_COV_TO_INT_SIG_EN. */

/*! @brief Read current value of the ADC_INT_SIG_EN_CHD_COV_TO_INT_SIG_EN field. */
#define BR_ADC_INT_SIG_EN_CHD_COV_TO_INT_SIG_EN(x) (HW_ADC_INT_SIG_EN(x).B.CHD_COV_TO_INT_SIG_EN)

/*! @brief Format value for bitfield ADC_INT_SIG_EN_CHD_COV_TO_INT_SIG_EN. */
#define BF_ADC_INT_SIG_EN_CHD_COV_TO_INT_SIG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_SIG_EN_CHD_COV_TO_INT_SIG_EN) & BM_ADC_INT_SIG_EN_CHD_COV_TO_INT_SIG_EN)

/*! @brief Set the CHD_COV_TO_INT_SIG_EN field to a new value. */
#define BW_ADC_INT_SIG_EN_CHD_COV_TO_INT_SIG_EN(x, v) (HW_ADC_INT_SIG_EN_WR(x, (HW_ADC_INT_SIG_EN_RD(x) & ~BM_ADC_INT_SIG_EN_CHD_COV_TO_INT_SIG_EN) | BF_ADC_INT_SIG_EN_CHD_COV_TO_INT_SIG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_SIG_EN, field SW_CH_COV_TO_INT_SIG_EN[20] (RW)
 *
 * Define whether software channel conversion time out interrupt signal is
 * enabled.
 *
 * Values:
 * - 0 - Disable software channel conversion time out interrupt signal.
 * - 1 - Enable software channel conversion time out interrupt signal.
 */
/*@{*/
#define BP_ADC_INT_SIG_EN_SW_CH_COV_TO_INT_SIG_EN (20U) /*!< Bit position for ADC_INT_SIG_EN_SW_CH_COV_TO_INT_SIG_EN. */
#define BM_ADC_INT_SIG_EN_SW_CH_COV_TO_INT_SIG_EN (0x00100000U) /*!< Bit mask for ADC_INT_SIG_EN_SW_CH_COV_TO_INT_SIG_EN. */
#define BS_ADC_INT_SIG_EN_SW_CH_COV_TO_INT_SIG_EN (1U) /*!< Bit field size in bits for ADC_INT_SIG_EN_SW_CH_COV_TO_INT_SIG_EN. */

/*! @brief Read current value of the ADC_INT_SIG_EN_SW_CH_COV_TO_INT_SIG_EN field. */
#define BR_ADC_INT_SIG_EN_SW_CH_COV_TO_INT_SIG_EN(x) (HW_ADC_INT_SIG_EN(x).B.SW_CH_COV_TO_INT_SIG_EN)

/*! @brief Format value for bitfield ADC_INT_SIG_EN_SW_CH_COV_TO_INT_SIG_EN. */
#define BF_ADC_INT_SIG_EN_SW_CH_COV_TO_INT_SIG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_SIG_EN_SW_CH_COV_TO_INT_SIG_EN) & BM_ADC_INT_SIG_EN_SW_CH_COV_TO_INT_SIG_EN)

/*! @brief Set the SW_CH_COV_TO_INT_SIG_EN field to a new value. */
#define BW_ADC_INT_SIG_EN_SW_CH_COV_TO_INT_SIG_EN(x, v) (HW_ADC_INT_SIG_EN_WR(x, (HW_ADC_INT_SIG_EN_RD(x) & ~BM_ADC_INT_SIG_EN_SW_CH_COV_TO_INT_SIG_EN) | BF_ADC_INT_SIG_EN_SW_CH_COV_TO_INT_SIG_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_SIG_EN, field LAST_FIFO_DATA_READ_SIG_EN[21] (RW)
 *
 * Define whether enable flag when the last data read out of FIFO (the last of
 * whole continuous result)
 *
 * Values:
 * - 0 - Disable last FIFO read signal enable
 * - 1 - Enable last FIFO read signal enable
 */
/*@{*/
#define BP_ADC_INT_SIG_EN_LAST_FIFO_DATA_READ_SIG_EN (21U) /*!< Bit position for ADC_INT_SIG_EN_LAST_FIFO_DATA_READ_SIG_EN. */
#define BM_ADC_INT_SIG_EN_LAST_FIFO_DATA_READ_SIG_EN (0x00200000U) /*!< Bit mask for ADC_INT_SIG_EN_LAST_FIFO_DATA_READ_SIG_EN. */
#define BS_ADC_INT_SIG_EN_LAST_FIFO_DATA_READ_SIG_EN (1U) /*!< Bit field size in bits for ADC_INT_SIG_EN_LAST_FIFO_DATA_READ_SIG_EN. */

/*! @brief Read current value of the ADC_INT_SIG_EN_LAST_FIFO_DATA_READ_SIG_EN field. */
#define BR_ADC_INT_SIG_EN_LAST_FIFO_DATA_READ_SIG_EN(x) (HW_ADC_INT_SIG_EN(x).B.LAST_FIFO_DATA_READ_SIG_EN)

/*! @brief Format value for bitfield ADC_INT_SIG_EN_LAST_FIFO_DATA_READ_SIG_EN. */
#define BF_ADC_INT_SIG_EN_LAST_FIFO_DATA_READ_SIG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_SIG_EN_LAST_FIFO_DATA_READ_SIG_EN) & BM_ADC_INT_SIG_EN_LAST_FIFO_DATA_READ_SIG_EN)

/*! @brief Set the LAST_FIFO_DATA_READ_SIG_EN field to a new value. */
#define BW_ADC_INT_SIG_EN_LAST_FIFO_DATA_READ_SIG_EN(x, v) (HW_ADC_INT_SIG_EN_WR(x, (HW_ADC_INT_SIG_EN_RD(x) & ~BM_ADC_INT_SIG_EN_LAST_FIFO_DATA_READ_SIG_EN) | BF_ADC_INT_SIG_EN_LAST_FIFO_DATA_READ_SIG_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_INT_EN - Interrupt Enable
 ******************************************************************************/

/*!
 * @brief HW_ADC_INT_EN - Interrupt Enable (RW)
 *
 * Reset value: 0x000000F0U
 */
typedef union _hw_adc_int_en
{
    uint32_t U;
    struct _hw_adc_int_en_bitfields
    {
        uint32_t CHA_CMP_INT_EN : 1;   /*!< [0] Channel A Compare Interrupt
                                        * Enable */
        uint32_t CHB_CMP_INT_EN : 1;   /*!< [1] Channel B Compare Interrupt
                                        * Enable */
        uint32_t CHC_CMP_INT_EN : 1;   /*!< [2] Channel C Compare Interrupt
                                        * Enable */
        uint32_t CHD_CMP_INT_EN : 1;   /*!< [3] Channel D Compare Interrupt
                                        * Enable */
        uint32_t RESERVED0 : 1;        /*!< [4] This field is reserved. */
        uint32_t DMA_REACH_WM_INT_EN : 1; /*!< [5] DMA Reach Watermark Level
                                        * Interrupt Enable */
        uint32_t FIFO_UNDERRUN_INT_EN : 1; /*!< [6] FIFO underrun Interrupt
                                        * Enable */
        uint32_t FIFO_OVERRUN_INT_EN : 1; /*!< [7] FIFO overrun Interrupt
                                        * Enable */
        uint32_t CHA_COV_INT_EN : 1;   /*!< [8] Channel A Conversion Interrupt
                                        * Enable */
        uint32_t CHB_COV_INT_EN : 1;   /*!< [9] Channel B Conversion Interrupt
                                        * Enable */
        uint32_t CHC_COV_INT_EN : 1;   /*!< [10] Channel C Conversion Interrupt
                                        * Enable */
        uint32_t CHD_COV_INT_EN : 1;   /*!< [11] Channel D Conversion Interrupt
                                        * Enable */
        uint32_t SW_CH_COV_INT_EN : 1; /*!< [12] Software Channel Conversion
                                        * Interrupt Enable */
        uint32_t RESERVED1 : 3;        /*!< [15:13] This field is reserved. */
        uint32_t CHA_COV_TO_INT_EN : 1; /*!< [16] Channel A Conversion Time
                                        * Out Interrupt Enable */
        uint32_t CHB_COV_TO_INT_EN : 1; /*!< [17] Channel B Conversion Time
                                        * Out Interrupt Enable */
        uint32_t CHC_COV_TO_INT_EN : 1; /*!< [18] Channel C Conversion Time
                                        * Out Interrupt Enable */
        uint32_t CHD_COV_TO_INT_EN : 1; /*!< [19] Channel D Conversion Time
                                        * Out Interrupt Enable */
        uint32_t SW_CH_COV_TO_INT_EN : 1; /*!< [20] Software Channel
                                        * Conversion Time Out Interrupt Enable */
        uint32_t LAST_FIFO_DATA_READ_EN : 1; /*!< [21] Last FIFO Data Read
                                        * Enable */
        uint32_t RESERVED2 : 10;       /*!< [31:22] This field is reserved. */
    } B;
} hw_adc_int_en_t;

/*!
 * @name Constants and macros for entire ADC_INT_EN register
 */
/*@{*/
#define HW_ADC_INT_EN_ADDR(x)    ((uintptr_t)(x) + 0xD0U)

#define HW_ADC_INT_EN(x)         (*(__IO hw_adc_int_en_t *) HW_ADC_INT_EN_ADDR(x))
#define HW_ADC_INT_EN_RD(x)      (HW_ADC_INT_EN(x).U)
#define HW_ADC_INT_EN_WR(x, v)   (HW_ADC_INT_EN(x).U = (v))
#define HW_ADC_INT_EN_SET(x, v)  (HW_ADC_INT_EN_WR(x, HW_ADC_INT_EN_RD(x) |  (v)))
#define HW_ADC_INT_EN_CLR(x, v)  (HW_ADC_INT_EN_WR(x, HW_ADC_INT_EN_RD(x) & ~(v)))
#define HW_ADC_INT_EN_TOG(x, v)  (HW_ADC_INT_EN_WR(x, HW_ADC_INT_EN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_INT_EN bitfields
 */

/*!
 * @name Register ADC_INT_EN, field CHA_CMP_INT_EN[0] (RW)
 *
 * Define whether channel A compare interrupt is enabled. If enable the
 * interrupt, an interrupt is set once channel A conversion result matches the compare
 * region.
 *
 * Values:
 * - 0 - Disable Channel A Compare Interrupt.
 * - 1 - Enable Channel A Compare Interrupt.
 */
/*@{*/
#define BP_ADC_INT_EN_CHA_CMP_INT_EN (0U)  /*!< Bit position for ADC_INT_EN_CHA_CMP_INT_EN. */
#define BM_ADC_INT_EN_CHA_CMP_INT_EN (0x00000001U) /*!< Bit mask for ADC_INT_EN_CHA_CMP_INT_EN. */
#define BS_ADC_INT_EN_CHA_CMP_INT_EN (1U)  /*!< Bit field size in bits for ADC_INT_EN_CHA_CMP_INT_EN. */

/*! @brief Read current value of the ADC_INT_EN_CHA_CMP_INT_EN field. */
#define BR_ADC_INT_EN_CHA_CMP_INT_EN(x) (HW_ADC_INT_EN(x).B.CHA_CMP_INT_EN)

/*! @brief Format value for bitfield ADC_INT_EN_CHA_CMP_INT_EN. */
#define BF_ADC_INT_EN_CHA_CMP_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_EN_CHA_CMP_INT_EN) & BM_ADC_INT_EN_CHA_CMP_INT_EN)

/*! @brief Set the CHA_CMP_INT_EN field to a new value. */
#define BW_ADC_INT_EN_CHA_CMP_INT_EN(x, v) (HW_ADC_INT_EN_WR(x, (HW_ADC_INT_EN_RD(x) & ~BM_ADC_INT_EN_CHA_CMP_INT_EN) | BF_ADC_INT_EN_CHA_CMP_INT_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_EN, field CHB_CMP_INT_EN[1] (RW)
 *
 * Define whether channel B compare interrupt is enabled. If enable the
 * interrupt, an interrupt is set once channel B conversion result matches the compare
 * region.
 *
 * Values:
 * - 0 - Disable Channel B Compare Interrupt.
 * - 1 - Enable Channel B Compare Interrupt.
 */
/*@{*/
#define BP_ADC_INT_EN_CHB_CMP_INT_EN (1U)  /*!< Bit position for ADC_INT_EN_CHB_CMP_INT_EN. */
#define BM_ADC_INT_EN_CHB_CMP_INT_EN (0x00000002U) /*!< Bit mask for ADC_INT_EN_CHB_CMP_INT_EN. */
#define BS_ADC_INT_EN_CHB_CMP_INT_EN (1U)  /*!< Bit field size in bits for ADC_INT_EN_CHB_CMP_INT_EN. */

/*! @brief Read current value of the ADC_INT_EN_CHB_CMP_INT_EN field. */
#define BR_ADC_INT_EN_CHB_CMP_INT_EN(x) (HW_ADC_INT_EN(x).B.CHB_CMP_INT_EN)

/*! @brief Format value for bitfield ADC_INT_EN_CHB_CMP_INT_EN. */
#define BF_ADC_INT_EN_CHB_CMP_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_EN_CHB_CMP_INT_EN) & BM_ADC_INT_EN_CHB_CMP_INT_EN)

/*! @brief Set the CHB_CMP_INT_EN field to a new value. */
#define BW_ADC_INT_EN_CHB_CMP_INT_EN(x, v) (HW_ADC_INT_EN_WR(x, (HW_ADC_INT_EN_RD(x) & ~BM_ADC_INT_EN_CHB_CMP_INT_EN) | BF_ADC_INT_EN_CHB_CMP_INT_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_EN, field CHC_CMP_INT_EN[2] (RW)
 *
 * Define whether channel C compare interrupt is enabled. If enable the
 * interrupt, an interrupt is set once channel C conversion result matches the compare
 * region.
 *
 * Values:
 * - 0 - Disable Channel C Compare Interrupt.
 * - 1 - Enable Channel C Compare Interrupt .
 */
/*@{*/
#define BP_ADC_INT_EN_CHC_CMP_INT_EN (2U)  /*!< Bit position for ADC_INT_EN_CHC_CMP_INT_EN. */
#define BM_ADC_INT_EN_CHC_CMP_INT_EN (0x00000004U) /*!< Bit mask for ADC_INT_EN_CHC_CMP_INT_EN. */
#define BS_ADC_INT_EN_CHC_CMP_INT_EN (1U)  /*!< Bit field size in bits for ADC_INT_EN_CHC_CMP_INT_EN. */

/*! @brief Read current value of the ADC_INT_EN_CHC_CMP_INT_EN field. */
#define BR_ADC_INT_EN_CHC_CMP_INT_EN(x) (HW_ADC_INT_EN(x).B.CHC_CMP_INT_EN)

/*! @brief Format value for bitfield ADC_INT_EN_CHC_CMP_INT_EN. */
#define BF_ADC_INT_EN_CHC_CMP_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_EN_CHC_CMP_INT_EN) & BM_ADC_INT_EN_CHC_CMP_INT_EN)

/*! @brief Set the CHC_CMP_INT_EN field to a new value. */
#define BW_ADC_INT_EN_CHC_CMP_INT_EN(x, v) (HW_ADC_INT_EN_WR(x, (HW_ADC_INT_EN_RD(x) & ~BM_ADC_INT_EN_CHC_CMP_INT_EN) | BF_ADC_INT_EN_CHC_CMP_INT_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_EN, field CHD_CMP_INT_EN[3] (RW)
 *
 * Define whether channel D compare interrupt is enabled. If enable the
 * interrupt, an interrupt is set once channel D conversion result matches the compare
 * region.
 *
 * Values:
 * - 0 - Disable Channel D Compare Interrupt.
 * - 1 - Enable Channel D Compare Interrupt.
 */
/*@{*/
#define BP_ADC_INT_EN_CHD_CMP_INT_EN (3U)  /*!< Bit position for ADC_INT_EN_CHD_CMP_INT_EN. */
#define BM_ADC_INT_EN_CHD_CMP_INT_EN (0x00000008U) /*!< Bit mask for ADC_INT_EN_CHD_CMP_INT_EN. */
#define BS_ADC_INT_EN_CHD_CMP_INT_EN (1U)  /*!< Bit field size in bits for ADC_INT_EN_CHD_CMP_INT_EN. */

/*! @brief Read current value of the ADC_INT_EN_CHD_CMP_INT_EN field. */
#define BR_ADC_INT_EN_CHD_CMP_INT_EN(x) (HW_ADC_INT_EN(x).B.CHD_CMP_INT_EN)

/*! @brief Format value for bitfield ADC_INT_EN_CHD_CMP_INT_EN. */
#define BF_ADC_INT_EN_CHD_CMP_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_EN_CHD_CMP_INT_EN) & BM_ADC_INT_EN_CHD_CMP_INT_EN)

/*! @brief Set the CHD_CMP_INT_EN field to a new value. */
#define BW_ADC_INT_EN_CHD_CMP_INT_EN(x, v) (HW_ADC_INT_EN_WR(x, (HW_ADC_INT_EN_RD(x) & ~BM_ADC_INT_EN_CHD_CMP_INT_EN) | BF_ADC_INT_EN_CHD_CMP_INT_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_EN, field DMA_REACH_WM_INT_EN[5] (RW)
 *
 * Define whether DMA watermark level interrupt is enabled. If enable the
 * interrupt, an interrupt is generated. This signal is for software read DMA FIFO. If
 * SDMA read data, turn off both interrupt enable and signal (flag) enable.
 *
 * Values:
 * - 0 - Enable DMA reach watermark level interrupt.
 * - 1 - Disable DMA reach watermark level interrupt.
 */
/*@{*/
#define BP_ADC_INT_EN_DMA_REACH_WM_INT_EN (5U) /*!< Bit position for ADC_INT_EN_DMA_REACH_WM_INT_EN. */
#define BM_ADC_INT_EN_DMA_REACH_WM_INT_EN (0x00000020U) /*!< Bit mask for ADC_INT_EN_DMA_REACH_WM_INT_EN. */
#define BS_ADC_INT_EN_DMA_REACH_WM_INT_EN (1U) /*!< Bit field size in bits for ADC_INT_EN_DMA_REACH_WM_INT_EN. */

/*! @brief Read current value of the ADC_INT_EN_DMA_REACH_WM_INT_EN field. */
#define BR_ADC_INT_EN_DMA_REACH_WM_INT_EN(x) (HW_ADC_INT_EN(x).B.DMA_REACH_WM_INT_EN)

/*! @brief Format value for bitfield ADC_INT_EN_DMA_REACH_WM_INT_EN. */
#define BF_ADC_INT_EN_DMA_REACH_WM_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_EN_DMA_REACH_WM_INT_EN) & BM_ADC_INT_EN_DMA_REACH_WM_INT_EN)

/*! @brief Set the DMA_REACH_WM_INT_EN field to a new value. */
#define BW_ADC_INT_EN_DMA_REACH_WM_INT_EN(x, v) (HW_ADC_INT_EN_WR(x, (HW_ADC_INT_EN_RD(x) & ~BM_ADC_INT_EN_DMA_REACH_WM_INT_EN) | BF_ADC_INT_EN_DMA_REACH_WM_INT_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_EN, field FIFO_UNDERRUN_INT_EN[6] (RW)
 *
 * Define whether DMA FIFO underrun interrupt is enabled. If DMA FIFO underrun
 * interrupt is enabled and DMA FIFO has underrun condition, then an interrupt is
 * generated.
 *
 * Values:
 * - 0 - Enable FIFO underrun Interrupt.
 * - 1 - Disable FIFO underrun Interrupt.
 */
/*@{*/
#define BP_ADC_INT_EN_FIFO_UNDERRUN_INT_EN (6U) /*!< Bit position for ADC_INT_EN_FIFO_UNDERRUN_INT_EN. */
#define BM_ADC_INT_EN_FIFO_UNDERRUN_INT_EN (0x00000040U) /*!< Bit mask for ADC_INT_EN_FIFO_UNDERRUN_INT_EN. */
#define BS_ADC_INT_EN_FIFO_UNDERRUN_INT_EN (1U) /*!< Bit field size in bits for ADC_INT_EN_FIFO_UNDERRUN_INT_EN. */

/*! @brief Read current value of the ADC_INT_EN_FIFO_UNDERRUN_INT_EN field. */
#define BR_ADC_INT_EN_FIFO_UNDERRUN_INT_EN(x) (HW_ADC_INT_EN(x).B.FIFO_UNDERRUN_INT_EN)

/*! @brief Format value for bitfield ADC_INT_EN_FIFO_UNDERRUN_INT_EN. */
#define BF_ADC_INT_EN_FIFO_UNDERRUN_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_EN_FIFO_UNDERRUN_INT_EN) & BM_ADC_INT_EN_FIFO_UNDERRUN_INT_EN)

/*! @brief Set the FIFO_UNDERRUN_INT_EN field to a new value. */
#define BW_ADC_INT_EN_FIFO_UNDERRUN_INT_EN(x, v) (HW_ADC_INT_EN_WR(x, (HW_ADC_INT_EN_RD(x) & ~BM_ADC_INT_EN_FIFO_UNDERRUN_INT_EN) | BF_ADC_INT_EN_FIFO_UNDERRUN_INT_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_EN, field FIFO_OVERRUN_INT_EN[7] (RW)
 *
 * Define whether DMA FIFO overrun interrupt is enabled. If DMA FIFO overrun
 * interrupt is enabled and DMA FIFO has overrun condition, then an interrupt is
 * generated.
 *
 * Values:
 * - 0 - Enable FIFO Interrupt.
 * - 1 - Disable FIFO Interrupt.
 */
/*@{*/
#define BP_ADC_INT_EN_FIFO_OVERRUN_INT_EN (7U) /*!< Bit position for ADC_INT_EN_FIFO_OVERRUN_INT_EN. */
#define BM_ADC_INT_EN_FIFO_OVERRUN_INT_EN (0x00000080U) /*!< Bit mask for ADC_INT_EN_FIFO_OVERRUN_INT_EN. */
#define BS_ADC_INT_EN_FIFO_OVERRUN_INT_EN (1U) /*!< Bit field size in bits for ADC_INT_EN_FIFO_OVERRUN_INT_EN. */

/*! @brief Read current value of the ADC_INT_EN_FIFO_OVERRUN_INT_EN field. */
#define BR_ADC_INT_EN_FIFO_OVERRUN_INT_EN(x) (HW_ADC_INT_EN(x).B.FIFO_OVERRUN_INT_EN)

/*! @brief Format value for bitfield ADC_INT_EN_FIFO_OVERRUN_INT_EN. */
#define BF_ADC_INT_EN_FIFO_OVERRUN_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_EN_FIFO_OVERRUN_INT_EN) & BM_ADC_INT_EN_FIFO_OVERRUN_INT_EN)

/*! @brief Set the FIFO_OVERRUN_INT_EN field to a new value. */
#define BW_ADC_INT_EN_FIFO_OVERRUN_INT_EN(x, v) (HW_ADC_INT_EN_WR(x, (HW_ADC_INT_EN_RD(x) & ~BM_ADC_INT_EN_FIFO_OVERRUN_INT_EN) | BF_ADC_INT_EN_FIFO_OVERRUN_INT_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_EN, field CHA_COV_INT_EN[8] (RW)
 *
 * Define whether channel A conversion interrupt is enabled. If enable
 * interrupt, an interrupt is generated once Channel A finish a new conversion.
 *
 * Values:
 * - 0 - Disable channel A conversion Interrupt.
 * - 1 - Enable channel A conversion Interrupt.
 */
/*@{*/
#define BP_ADC_INT_EN_CHA_COV_INT_EN (8U)  /*!< Bit position for ADC_INT_EN_CHA_COV_INT_EN. */
#define BM_ADC_INT_EN_CHA_COV_INT_EN (0x00000100U) /*!< Bit mask for ADC_INT_EN_CHA_COV_INT_EN. */
#define BS_ADC_INT_EN_CHA_COV_INT_EN (1U)  /*!< Bit field size in bits for ADC_INT_EN_CHA_COV_INT_EN. */

/*! @brief Read current value of the ADC_INT_EN_CHA_COV_INT_EN field. */
#define BR_ADC_INT_EN_CHA_COV_INT_EN(x) (HW_ADC_INT_EN(x).B.CHA_COV_INT_EN)

/*! @brief Format value for bitfield ADC_INT_EN_CHA_COV_INT_EN. */
#define BF_ADC_INT_EN_CHA_COV_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_EN_CHA_COV_INT_EN) & BM_ADC_INT_EN_CHA_COV_INT_EN)

/*! @brief Set the CHA_COV_INT_EN field to a new value. */
#define BW_ADC_INT_EN_CHA_COV_INT_EN(x, v) (HW_ADC_INT_EN_WR(x, (HW_ADC_INT_EN_RD(x) & ~BM_ADC_INT_EN_CHA_COV_INT_EN) | BF_ADC_INT_EN_CHA_COV_INT_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_EN, field CHB_COV_INT_EN[9] (RW)
 *
 * Define whether channel B conversion interrupt is enabled. If enable
 * interrupt, an interrupt is generated once Channel B finish a new conversion.
 *
 * Values:
 * - 0 - Disable channel B conversion Interrupt.
 * - 1 - Enable channel B conversion Interrupt.
 */
/*@{*/
#define BP_ADC_INT_EN_CHB_COV_INT_EN (9U)  /*!< Bit position for ADC_INT_EN_CHB_COV_INT_EN. */
#define BM_ADC_INT_EN_CHB_COV_INT_EN (0x00000200U) /*!< Bit mask for ADC_INT_EN_CHB_COV_INT_EN. */
#define BS_ADC_INT_EN_CHB_COV_INT_EN (1U)  /*!< Bit field size in bits for ADC_INT_EN_CHB_COV_INT_EN. */

/*! @brief Read current value of the ADC_INT_EN_CHB_COV_INT_EN field. */
#define BR_ADC_INT_EN_CHB_COV_INT_EN(x) (HW_ADC_INT_EN(x).B.CHB_COV_INT_EN)

/*! @brief Format value for bitfield ADC_INT_EN_CHB_COV_INT_EN. */
#define BF_ADC_INT_EN_CHB_COV_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_EN_CHB_COV_INT_EN) & BM_ADC_INT_EN_CHB_COV_INT_EN)

/*! @brief Set the CHB_COV_INT_EN field to a new value. */
#define BW_ADC_INT_EN_CHB_COV_INT_EN(x, v) (HW_ADC_INT_EN_WR(x, (HW_ADC_INT_EN_RD(x) & ~BM_ADC_INT_EN_CHB_COV_INT_EN) | BF_ADC_INT_EN_CHB_COV_INT_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_EN, field CHC_COV_INT_EN[10] (RW)
 *
 * Define whether channel C conversion interrupt is enabled. If enable
 * interrupt, an interrupt is generated once Channel C finish a new conversion.
 *
 * Values:
 * - 0 - Disable channel C conversion Interrupt.
 * - 1 - Enable channel C conversion Interrupt.
 */
/*@{*/
#define BP_ADC_INT_EN_CHC_COV_INT_EN (10U) /*!< Bit position for ADC_INT_EN_CHC_COV_INT_EN. */
#define BM_ADC_INT_EN_CHC_COV_INT_EN (0x00000400U) /*!< Bit mask for ADC_INT_EN_CHC_COV_INT_EN. */
#define BS_ADC_INT_EN_CHC_COV_INT_EN (1U)  /*!< Bit field size in bits for ADC_INT_EN_CHC_COV_INT_EN. */

/*! @brief Read current value of the ADC_INT_EN_CHC_COV_INT_EN field. */
#define BR_ADC_INT_EN_CHC_COV_INT_EN(x) (HW_ADC_INT_EN(x).B.CHC_COV_INT_EN)

/*! @brief Format value for bitfield ADC_INT_EN_CHC_COV_INT_EN. */
#define BF_ADC_INT_EN_CHC_COV_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_EN_CHC_COV_INT_EN) & BM_ADC_INT_EN_CHC_COV_INT_EN)

/*! @brief Set the CHC_COV_INT_EN field to a new value. */
#define BW_ADC_INT_EN_CHC_COV_INT_EN(x, v) (HW_ADC_INT_EN_WR(x, (HW_ADC_INT_EN_RD(x) & ~BM_ADC_INT_EN_CHC_COV_INT_EN) | BF_ADC_INT_EN_CHC_COV_INT_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_EN, field CHD_COV_INT_EN[11] (RW)
 *
 * Define whether channel D conversion interrupt is enabled. If enable
 * interrupt, an interrupt is generated once Channel D finish a new conversion.
 *
 * Values:
 * - 0 - Disable channel D conversion Interrupt.
 * - 1 - Enable channel D conversion Interrupt.
 */
/*@{*/
#define BP_ADC_INT_EN_CHD_COV_INT_EN (11U) /*!< Bit position for ADC_INT_EN_CHD_COV_INT_EN. */
#define BM_ADC_INT_EN_CHD_COV_INT_EN (0x00000800U) /*!< Bit mask for ADC_INT_EN_CHD_COV_INT_EN. */
#define BS_ADC_INT_EN_CHD_COV_INT_EN (1U)  /*!< Bit field size in bits for ADC_INT_EN_CHD_COV_INT_EN. */

/*! @brief Read current value of the ADC_INT_EN_CHD_COV_INT_EN field. */
#define BR_ADC_INT_EN_CHD_COV_INT_EN(x) (HW_ADC_INT_EN(x).B.CHD_COV_INT_EN)

/*! @brief Format value for bitfield ADC_INT_EN_CHD_COV_INT_EN. */
#define BF_ADC_INT_EN_CHD_COV_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_EN_CHD_COV_INT_EN) & BM_ADC_INT_EN_CHD_COV_INT_EN)

/*! @brief Set the CHD_COV_INT_EN field to a new value. */
#define BW_ADC_INT_EN_CHD_COV_INT_EN(x, v) (HW_ADC_INT_EN_WR(x, (HW_ADC_INT_EN_RD(x) & ~BM_ADC_INT_EN_CHD_COV_INT_EN) | BF_ADC_INT_EN_CHD_COV_INT_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_EN, field SW_CH_COV_INT_EN[12] (RW)
 *
 * Define whether software trigger interrupt is enabled.
 *
 * Values:
 * - 0 - Disable software channel conversion interrupt.
 * - 1 - Enable software channel conversion interrupt.
 */
/*@{*/
#define BP_ADC_INT_EN_SW_CH_COV_INT_EN (12U) /*!< Bit position for ADC_INT_EN_SW_CH_COV_INT_EN. */
#define BM_ADC_INT_EN_SW_CH_COV_INT_EN (0x00001000U) /*!< Bit mask for ADC_INT_EN_SW_CH_COV_INT_EN. */
#define BS_ADC_INT_EN_SW_CH_COV_INT_EN (1U) /*!< Bit field size in bits for ADC_INT_EN_SW_CH_COV_INT_EN. */

/*! @brief Read current value of the ADC_INT_EN_SW_CH_COV_INT_EN field. */
#define BR_ADC_INT_EN_SW_CH_COV_INT_EN(x) (HW_ADC_INT_EN(x).B.SW_CH_COV_INT_EN)

/*! @brief Format value for bitfield ADC_INT_EN_SW_CH_COV_INT_EN. */
#define BF_ADC_INT_EN_SW_CH_COV_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_EN_SW_CH_COV_INT_EN) & BM_ADC_INT_EN_SW_CH_COV_INT_EN)

/*! @brief Set the SW_CH_COV_INT_EN field to a new value. */
#define BW_ADC_INT_EN_SW_CH_COV_INT_EN(x, v) (HW_ADC_INT_EN_WR(x, (HW_ADC_INT_EN_RD(x) & ~BM_ADC_INT_EN_SW_CH_COV_INT_EN) | BF_ADC_INT_EN_SW_CH_COV_INT_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_EN, field CHA_COV_TO_INT_EN[16] (RW)
 *
 * Define whether logical channel A conversion time out interrupt is enabled.
 *
 * Values:
 * - 0 - Disable logical channel A conversion time out interrupt.
 * - 1 - Enable logical channel A conversion time out interrupt.
 */
/*@{*/
#define BP_ADC_INT_EN_CHA_COV_TO_INT_EN (16U) /*!< Bit position for ADC_INT_EN_CHA_COV_TO_INT_EN. */
#define BM_ADC_INT_EN_CHA_COV_TO_INT_EN (0x00010000U) /*!< Bit mask for ADC_INT_EN_CHA_COV_TO_INT_EN. */
#define BS_ADC_INT_EN_CHA_COV_TO_INT_EN (1U) /*!< Bit field size in bits for ADC_INT_EN_CHA_COV_TO_INT_EN. */

/*! @brief Read current value of the ADC_INT_EN_CHA_COV_TO_INT_EN field. */
#define BR_ADC_INT_EN_CHA_COV_TO_INT_EN(x) (HW_ADC_INT_EN(x).B.CHA_COV_TO_INT_EN)

/*! @brief Format value for bitfield ADC_INT_EN_CHA_COV_TO_INT_EN. */
#define BF_ADC_INT_EN_CHA_COV_TO_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_EN_CHA_COV_TO_INT_EN) & BM_ADC_INT_EN_CHA_COV_TO_INT_EN)

/*! @brief Set the CHA_COV_TO_INT_EN field to a new value. */
#define BW_ADC_INT_EN_CHA_COV_TO_INT_EN(x, v) (HW_ADC_INT_EN_WR(x, (HW_ADC_INT_EN_RD(x) & ~BM_ADC_INT_EN_CHA_COV_TO_INT_EN) | BF_ADC_INT_EN_CHA_COV_TO_INT_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_EN, field CHB_COV_TO_INT_EN[17] (RW)
 *
 * Define whether logical channel B conversion time out interrupt is enabled.
 *
 * Values:
 * - 0 - Disable logical channel B conversion time out interrupt.
 * - 1 - Enable logical channel B conversion time out interrupt.
 */
/*@{*/
#define BP_ADC_INT_EN_CHB_COV_TO_INT_EN (17U) /*!< Bit position for ADC_INT_EN_CHB_COV_TO_INT_EN. */
#define BM_ADC_INT_EN_CHB_COV_TO_INT_EN (0x00020000U) /*!< Bit mask for ADC_INT_EN_CHB_COV_TO_INT_EN. */
#define BS_ADC_INT_EN_CHB_COV_TO_INT_EN (1U) /*!< Bit field size in bits for ADC_INT_EN_CHB_COV_TO_INT_EN. */

/*! @brief Read current value of the ADC_INT_EN_CHB_COV_TO_INT_EN field. */
#define BR_ADC_INT_EN_CHB_COV_TO_INT_EN(x) (HW_ADC_INT_EN(x).B.CHB_COV_TO_INT_EN)

/*! @brief Format value for bitfield ADC_INT_EN_CHB_COV_TO_INT_EN. */
#define BF_ADC_INT_EN_CHB_COV_TO_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_EN_CHB_COV_TO_INT_EN) & BM_ADC_INT_EN_CHB_COV_TO_INT_EN)

/*! @brief Set the CHB_COV_TO_INT_EN field to a new value. */
#define BW_ADC_INT_EN_CHB_COV_TO_INT_EN(x, v) (HW_ADC_INT_EN_WR(x, (HW_ADC_INT_EN_RD(x) & ~BM_ADC_INT_EN_CHB_COV_TO_INT_EN) | BF_ADC_INT_EN_CHB_COV_TO_INT_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_EN, field CHC_COV_TO_INT_EN[18] (RW)
 *
 * Define whether logical channel C conversion time out interrupt is enabled.
 *
 * Values:
 * - 0 - Disable logical channel C conversion time out interrupt.
 * - 1 - Enable logical channel C conversion time out interrupt.
 */
/*@{*/
#define BP_ADC_INT_EN_CHC_COV_TO_INT_EN (18U) /*!< Bit position for ADC_INT_EN_CHC_COV_TO_INT_EN. */
#define BM_ADC_INT_EN_CHC_COV_TO_INT_EN (0x00040000U) /*!< Bit mask for ADC_INT_EN_CHC_COV_TO_INT_EN. */
#define BS_ADC_INT_EN_CHC_COV_TO_INT_EN (1U) /*!< Bit field size in bits for ADC_INT_EN_CHC_COV_TO_INT_EN. */

/*! @brief Read current value of the ADC_INT_EN_CHC_COV_TO_INT_EN field. */
#define BR_ADC_INT_EN_CHC_COV_TO_INT_EN(x) (HW_ADC_INT_EN(x).B.CHC_COV_TO_INT_EN)

/*! @brief Format value for bitfield ADC_INT_EN_CHC_COV_TO_INT_EN. */
#define BF_ADC_INT_EN_CHC_COV_TO_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_EN_CHC_COV_TO_INT_EN) & BM_ADC_INT_EN_CHC_COV_TO_INT_EN)

/*! @brief Set the CHC_COV_TO_INT_EN field to a new value. */
#define BW_ADC_INT_EN_CHC_COV_TO_INT_EN(x, v) (HW_ADC_INT_EN_WR(x, (HW_ADC_INT_EN_RD(x) & ~BM_ADC_INT_EN_CHC_COV_TO_INT_EN) | BF_ADC_INT_EN_CHC_COV_TO_INT_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_EN, field CHD_COV_TO_INT_EN[19] (RW)
 *
 * Define whether logical channel D conversion time out interrupt is enabled.
 *
 * Values:
 * - 0 - Disable logical channel D conversion time out interrupt.
 * - 1 - Enable logical channel D conversion time out interrupt.
 */
/*@{*/
#define BP_ADC_INT_EN_CHD_COV_TO_INT_EN (19U) /*!< Bit position for ADC_INT_EN_CHD_COV_TO_INT_EN. */
#define BM_ADC_INT_EN_CHD_COV_TO_INT_EN (0x00080000U) /*!< Bit mask for ADC_INT_EN_CHD_COV_TO_INT_EN. */
#define BS_ADC_INT_EN_CHD_COV_TO_INT_EN (1U) /*!< Bit field size in bits for ADC_INT_EN_CHD_COV_TO_INT_EN. */

/*! @brief Read current value of the ADC_INT_EN_CHD_COV_TO_INT_EN field. */
#define BR_ADC_INT_EN_CHD_COV_TO_INT_EN(x) (HW_ADC_INT_EN(x).B.CHD_COV_TO_INT_EN)

/*! @brief Format value for bitfield ADC_INT_EN_CHD_COV_TO_INT_EN. */
#define BF_ADC_INT_EN_CHD_COV_TO_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_EN_CHD_COV_TO_INT_EN) & BM_ADC_INT_EN_CHD_COV_TO_INT_EN)

/*! @brief Set the CHD_COV_TO_INT_EN field to a new value. */
#define BW_ADC_INT_EN_CHD_COV_TO_INT_EN(x, v) (HW_ADC_INT_EN_WR(x, (HW_ADC_INT_EN_RD(x) & ~BM_ADC_INT_EN_CHD_COV_TO_INT_EN) | BF_ADC_INT_EN_CHD_COV_TO_INT_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_EN, field SW_CH_COV_TO_INT_EN[20] (RW)
 *
 * Define whether software channel conversion time out interrupt is enabled.
 *
 * Values:
 * - 0 - Disable software channel conversion time out interrupt.
 * - 1 - Enable software channel conversion time out interrupt.
 */
/*@{*/
#define BP_ADC_INT_EN_SW_CH_COV_TO_INT_EN (20U) /*!< Bit position for ADC_INT_EN_SW_CH_COV_TO_INT_EN. */
#define BM_ADC_INT_EN_SW_CH_COV_TO_INT_EN (0x00100000U) /*!< Bit mask for ADC_INT_EN_SW_CH_COV_TO_INT_EN. */
#define BS_ADC_INT_EN_SW_CH_COV_TO_INT_EN (1U) /*!< Bit field size in bits for ADC_INT_EN_SW_CH_COV_TO_INT_EN. */

/*! @brief Read current value of the ADC_INT_EN_SW_CH_COV_TO_INT_EN field. */
#define BR_ADC_INT_EN_SW_CH_COV_TO_INT_EN(x) (HW_ADC_INT_EN(x).B.SW_CH_COV_TO_INT_EN)

/*! @brief Format value for bitfield ADC_INT_EN_SW_CH_COV_TO_INT_EN. */
#define BF_ADC_INT_EN_SW_CH_COV_TO_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_EN_SW_CH_COV_TO_INT_EN) & BM_ADC_INT_EN_SW_CH_COV_TO_INT_EN)

/*! @brief Set the SW_CH_COV_TO_INT_EN field to a new value. */
#define BW_ADC_INT_EN_SW_CH_COV_TO_INT_EN(x, v) (HW_ADC_INT_EN_WR(x, (HW_ADC_INT_EN_RD(x) & ~BM_ADC_INT_EN_SW_CH_COV_TO_INT_EN) | BF_ADC_INT_EN_SW_CH_COV_TO_INT_EN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_EN, field LAST_FIFO_DATA_READ_EN[21] (RW)
 *
 * Define whether generate an interrupt when the last data read out of FIFO (the
 * last of whole continuous result)
 *
 * Values:
 * - 0 - Disable last FIFO read enable
 * - 1 - Enable last FIFO read enable
 */
/*@{*/
#define BP_ADC_INT_EN_LAST_FIFO_DATA_READ_EN (21U) /*!< Bit position for ADC_INT_EN_LAST_FIFO_DATA_READ_EN. */
#define BM_ADC_INT_EN_LAST_FIFO_DATA_READ_EN (0x00200000U) /*!< Bit mask for ADC_INT_EN_LAST_FIFO_DATA_READ_EN. */
#define BS_ADC_INT_EN_LAST_FIFO_DATA_READ_EN (1U) /*!< Bit field size in bits for ADC_INT_EN_LAST_FIFO_DATA_READ_EN. */

/*! @brief Read current value of the ADC_INT_EN_LAST_FIFO_DATA_READ_EN field. */
#define BR_ADC_INT_EN_LAST_FIFO_DATA_READ_EN(x) (HW_ADC_INT_EN(x).B.LAST_FIFO_DATA_READ_EN)

/*! @brief Format value for bitfield ADC_INT_EN_LAST_FIFO_DATA_READ_EN. */
#define BF_ADC_INT_EN_LAST_FIFO_DATA_READ_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_EN_LAST_FIFO_DATA_READ_EN) & BM_ADC_INT_EN_LAST_FIFO_DATA_READ_EN)

/*! @brief Set the LAST_FIFO_DATA_READ_EN field to a new value. */
#define BW_ADC_INT_EN_LAST_FIFO_DATA_READ_EN(x, v) (HW_ADC_INT_EN_WR(x, (HW_ADC_INT_EN_RD(x) & ~BM_ADC_INT_EN_LAST_FIFO_DATA_READ_EN) | BF_ADC_INT_EN_LAST_FIFO_DATA_READ_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_INT_STATUS -
 ******************************************************************************/

/*!
 * @brief HW_ADC_INT_STATUS -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_adc_int_status
{
    uint32_t U;
    struct _hw_adc_int_status_bitfields
    {
        uint32_t CBA_CMP : 1;          /*!< [0] Channel A Compare (Flag) */
        uint32_t CHB_CMP : 1;          /*!< [1] Channel B Compare (Flag) */
        uint32_t CHC_CMP : 1;          /*!< [2] Channel C Compare (Flag) */
        uint32_t CHD_CMP : 1;          /*!< [3] Channel D Compare (Flag) */
        uint32_t RESERVED0 : 1;        /*!< [4] This field is reserved. */
        uint32_t DMA_REACH_WM : 1;     /*!< [5] DMA Reach Watermark Level (Flag)
                                        * */
        uint32_t FIFO_UNDERRUN : 1;    /*!< [6] FIFO Underrun (Flag) */
        uint32_t FIFO_OVERRUN : 1;     /*!< [7] FIFO Overrun (Flag) */
        uint32_t CHA_COV : 1;          /*!< [8] Channel A Conversion (Flag) */
        uint32_t CHB_COV : 1;          /*!< [9] Channel B Conversion (Flag) */
        uint32_t CHC_COV : 1;          /*!< [10] Channel C Conversion (Flag) */
        uint32_t CHD_COV : 1;          /*!< [11] Channel D Conversion (Flag) */
        uint32_t SW_CH_COV : 1;        /*!< [12] Software Channel Conversion (Flag)
                                        * */
        uint32_t RESERVED1 : 3;        /*!< [15:13] This field is reserved. */
        uint32_t CHA_COV_TO : 1;       /*!< [16] Channel A Conversion Time Out */
        uint32_t CHB_COV_TO : 1;       /*!< [17] Channel B Conversion Time Out */
        uint32_t CHC_COV_TO : 1;       /*!< [18] Channel C Conversion Time Out */
        uint32_t CHD_COV_TO : 1;       /*!< [19] Channel D Conversion Time Out */
        uint32_t SW_CH_COV_TO : 1;     /*!< [20] Software Channel Conversion Time
                                        * Out */
        uint32_t LAST_FIFO_DATA_READ : 1; /*!< [21] Last FIFO Data Read */
        uint32_t RESERVED2 : 10;       /*!< [31:22] This field is reserved. */
    } B;
} hw_adc_int_status_t;

/*!
 * @name Constants and macros for entire ADC_INT_STATUS register
 */
/*@{*/
#define HW_ADC_INT_STATUS_ADDR(x) ((uintptr_t)(x) + 0xE0U)

#define HW_ADC_INT_STATUS(x)     (*(__IO hw_adc_int_status_t *) HW_ADC_INT_STATUS_ADDR(x))
#define HW_ADC_INT_STATUS_RD(x)  (HW_ADC_INT_STATUS(x).U)
#define HW_ADC_INT_STATUS_WR(x, v) (HW_ADC_INT_STATUS(x).U = (v))
#define HW_ADC_INT_STATUS_SET(x, v) (HW_ADC_INT_STATUS_WR(x, HW_ADC_INT_STATUS_RD(x) |  (v)))
#define HW_ADC_INT_STATUS_CLR(x, v) (HW_ADC_INT_STATUS_WR(x, HW_ADC_INT_STATUS_RD(x) & ~(v)))
#define HW_ADC_INT_STATUS_TOG(x, v) (HW_ADC_INT_STATUS_WR(x, HW_ADC_INT_STATUS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_INT_STATUS bitfields
 */

/*!
 * @name Register ADC_INT_STATUS, field CBA_CMP[0] (RW)
 *
 * This is the flag of channel A compare. If CHA_CMP_INT_SIG_EN is enabled and
 * channel A conversion result matches the compare region, the CHA_CMP (Flag) is
 * set.
 *
 * Values:
 * - 0 - Disable Channel A Compare (Flag).
 * - 1 - Enable Channel A Compare (Flag).
 */
/*@{*/
#define BP_ADC_INT_STATUS_CBA_CMP (0U)     /*!< Bit position for ADC_INT_STATUS_CBA_CMP. */
#define BM_ADC_INT_STATUS_CBA_CMP (0x00000001U) /*!< Bit mask for ADC_INT_STATUS_CBA_CMP. */
#define BS_ADC_INT_STATUS_CBA_CMP (1U)     /*!< Bit field size in bits for ADC_INT_STATUS_CBA_CMP. */

/*! @brief Read current value of the ADC_INT_STATUS_CBA_CMP field. */
#define BR_ADC_INT_STATUS_CBA_CMP(x) (HW_ADC_INT_STATUS(x).B.CBA_CMP)

/*! @brief Format value for bitfield ADC_INT_STATUS_CBA_CMP. */
#define BF_ADC_INT_STATUS_CBA_CMP(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_STATUS_CBA_CMP) & BM_ADC_INT_STATUS_CBA_CMP)

/*! @brief Set the CBA_CMP field to a new value. */
#define BW_ADC_INT_STATUS_CBA_CMP(x, v) (HW_ADC_INT_STATUS_WR(x, (HW_ADC_INT_STATUS_RD(x) & ~BM_ADC_INT_STATUS_CBA_CMP) | BF_ADC_INT_STATUS_CBA_CMP(v)))
/*@}*/

/*!
 * @name Register ADC_INT_STATUS, field CHB_CMP[1] (RW)
 *
 * This is the flag of channel B compare. If CHB_CMP_INT_SIG_EN is enabled and
 * channel B conversion result matches the compare region, the CHB_CMP (Flag) is
 * set.
 *
 * Values:
 * - 0 - Disable Channel B Compare (Flag).
 * - 1 - Enable Channel B Compare (Flag).
 */
/*@{*/
#define BP_ADC_INT_STATUS_CHB_CMP (1U)     /*!< Bit position for ADC_INT_STATUS_CHB_CMP. */
#define BM_ADC_INT_STATUS_CHB_CMP (0x00000002U) /*!< Bit mask for ADC_INT_STATUS_CHB_CMP. */
#define BS_ADC_INT_STATUS_CHB_CMP (1U)     /*!< Bit field size in bits for ADC_INT_STATUS_CHB_CMP. */

/*! @brief Read current value of the ADC_INT_STATUS_CHB_CMP field. */
#define BR_ADC_INT_STATUS_CHB_CMP(x) (HW_ADC_INT_STATUS(x).B.CHB_CMP)

/*! @brief Format value for bitfield ADC_INT_STATUS_CHB_CMP. */
#define BF_ADC_INT_STATUS_CHB_CMP(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_STATUS_CHB_CMP) & BM_ADC_INT_STATUS_CHB_CMP)

/*! @brief Set the CHB_CMP field to a new value. */
#define BW_ADC_INT_STATUS_CHB_CMP(x, v) (HW_ADC_INT_STATUS_WR(x, (HW_ADC_INT_STATUS_RD(x) & ~BM_ADC_INT_STATUS_CHB_CMP) | BF_ADC_INT_STATUS_CHB_CMP(v)))
/*@}*/

/*!
 * @name Register ADC_INT_STATUS, field CHC_CMP[2] (RW)
 *
 * This is the flag of channel C compare. If CHC_CMP_INT_SIG_EN is enabled and
 * channel C conversion result matches the compare region, the CHC_CMP (Flag) is
 * set.
 *
 * Values:
 * - 0 - Disable Channel C Compare (Flag).
 * - 1 - Enable Channel C Compare (Flag).
 */
/*@{*/
#define BP_ADC_INT_STATUS_CHC_CMP (2U)     /*!< Bit position for ADC_INT_STATUS_CHC_CMP. */
#define BM_ADC_INT_STATUS_CHC_CMP (0x00000004U) /*!< Bit mask for ADC_INT_STATUS_CHC_CMP. */
#define BS_ADC_INT_STATUS_CHC_CMP (1U)     /*!< Bit field size in bits for ADC_INT_STATUS_CHC_CMP. */

/*! @brief Read current value of the ADC_INT_STATUS_CHC_CMP field. */
#define BR_ADC_INT_STATUS_CHC_CMP(x) (HW_ADC_INT_STATUS(x).B.CHC_CMP)

/*! @brief Format value for bitfield ADC_INT_STATUS_CHC_CMP. */
#define BF_ADC_INT_STATUS_CHC_CMP(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_STATUS_CHC_CMP) & BM_ADC_INT_STATUS_CHC_CMP)

/*! @brief Set the CHC_CMP field to a new value. */
#define BW_ADC_INT_STATUS_CHC_CMP(x, v) (HW_ADC_INT_STATUS_WR(x, (HW_ADC_INT_STATUS_RD(x) & ~BM_ADC_INT_STATUS_CHC_CMP) | BF_ADC_INT_STATUS_CHC_CMP(v)))
/*@}*/

/*!
 * @name Register ADC_INT_STATUS, field CHD_CMP[3] (RW)
 *
 * This is the flag of channel D compare. If CHD_CMP_INT_SIG_EN is enabled and
 * channel D conversion result matches the compare region, the CHD_CMP (Flag) is
 * set.
 *
 * Values:
 * - 0 - Disable Channel D Compare (Flag).
 * - 1 - Enable Channel D Compare (Flag).
 */
/*@{*/
#define BP_ADC_INT_STATUS_CHD_CMP (3U)     /*!< Bit position for ADC_INT_STATUS_CHD_CMP. */
#define BM_ADC_INT_STATUS_CHD_CMP (0x00000008U) /*!< Bit mask for ADC_INT_STATUS_CHD_CMP. */
#define BS_ADC_INT_STATUS_CHD_CMP (1U)     /*!< Bit field size in bits for ADC_INT_STATUS_CHD_CMP. */

/*! @brief Read current value of the ADC_INT_STATUS_CHD_CMP field. */
#define BR_ADC_INT_STATUS_CHD_CMP(x) (HW_ADC_INT_STATUS(x).B.CHD_CMP)

/*! @brief Format value for bitfield ADC_INT_STATUS_CHD_CMP. */
#define BF_ADC_INT_STATUS_CHD_CMP(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_STATUS_CHD_CMP) & BM_ADC_INT_STATUS_CHD_CMP)

/*! @brief Set the CHD_CMP field to a new value. */
#define BW_ADC_INT_STATUS_CHD_CMP(x, v) (HW_ADC_INT_STATUS_WR(x, (HW_ADC_INT_STATUS_RD(x) & ~BM_ADC_INT_STATUS_CHD_CMP) | BF_ADC_INT_STATUS_CHD_CMP(v)))
/*@}*/

/*!
 * @name Register ADC_INT_STATUS, field DMA_REACH_WM[5] (RW)
 *
 * This is the flag of DMA reach watermark level. Setting this flag indicates
 * the number of data in the DMA FIFO reach the watermark level. This bit is for
 * software read DMA FIFO, if SDMA read DMA FIFO, please disable both interrupt and
 * interrupt signal (flag).
 *
 * Values:
 * - 0 - The numbers of data in DMA FIFO has not reach the watermark level.
 * - 1 - The numbers of data in DMA FIFO has reach the watermark level. Software
 *     clear / clear signal enable.
 */
/*@{*/
#define BP_ADC_INT_STATUS_DMA_REACH_WM (5U) /*!< Bit position for ADC_INT_STATUS_DMA_REACH_WM. */
#define BM_ADC_INT_STATUS_DMA_REACH_WM (0x00000020U) /*!< Bit mask for ADC_INT_STATUS_DMA_REACH_WM. */
#define BS_ADC_INT_STATUS_DMA_REACH_WM (1U) /*!< Bit field size in bits for ADC_INT_STATUS_DMA_REACH_WM. */

/*! @brief Read current value of the ADC_INT_STATUS_DMA_REACH_WM field. */
#define BR_ADC_INT_STATUS_DMA_REACH_WM(x) (HW_ADC_INT_STATUS(x).B.DMA_REACH_WM)

/*! @brief Format value for bitfield ADC_INT_STATUS_DMA_REACH_WM. */
#define BF_ADC_INT_STATUS_DMA_REACH_WM(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_STATUS_DMA_REACH_WM) & BM_ADC_INT_STATUS_DMA_REACH_WM)

/*! @brief Set the DMA_REACH_WM field to a new value. */
#define BW_ADC_INT_STATUS_DMA_REACH_WM(x, v) (HW_ADC_INT_STATUS_WR(x, (HW_ADC_INT_STATUS_RD(x) & ~BM_ADC_INT_STATUS_DMA_REACH_WM) | BF_ADC_INT_STATUS_DMA_REACH_WM(v)))
/*@}*/

/*!
 * @name Register ADC_INT_STATUS, field FIFO_UNDERRUN[6] (RW)
 *
 * This is the flag of FIFO underrun. If FIFO_UNDERRUN_INT_SIG_EN is enabled and
 * FIFO underrun happens, the FIFO_UNDERRUN (flag) is set.
 *
 * Values:
 * - 0 - Do not exist FIFO underrun (Flag).
 * - 1 - Exist FIFO underrun (Flag). Software clear / clear signal enable.
 */
/*@{*/
#define BP_ADC_INT_STATUS_FIFO_UNDERRUN (6U) /*!< Bit position for ADC_INT_STATUS_FIFO_UNDERRUN. */
#define BM_ADC_INT_STATUS_FIFO_UNDERRUN (0x00000040U) /*!< Bit mask for ADC_INT_STATUS_FIFO_UNDERRUN. */
#define BS_ADC_INT_STATUS_FIFO_UNDERRUN (1U) /*!< Bit field size in bits for ADC_INT_STATUS_FIFO_UNDERRUN. */

/*! @brief Read current value of the ADC_INT_STATUS_FIFO_UNDERRUN field. */
#define BR_ADC_INT_STATUS_FIFO_UNDERRUN(x) (HW_ADC_INT_STATUS(x).B.FIFO_UNDERRUN)

/*! @brief Format value for bitfield ADC_INT_STATUS_FIFO_UNDERRUN. */
#define BF_ADC_INT_STATUS_FIFO_UNDERRUN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_STATUS_FIFO_UNDERRUN) & BM_ADC_INT_STATUS_FIFO_UNDERRUN)

/*! @brief Set the FIFO_UNDERRUN field to a new value. */
#define BW_ADC_INT_STATUS_FIFO_UNDERRUN(x, v) (HW_ADC_INT_STATUS_WR(x, (HW_ADC_INT_STATUS_RD(x) & ~BM_ADC_INT_STATUS_FIFO_UNDERRUN) | BF_ADC_INT_STATUS_FIFO_UNDERRUN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_STATUS, field FIFO_OVERRUN[7] (RW)
 *
 * This is the flag of FIFO overrun. If FIFO_OVERRUN_INT_SIG_EN is enabled and
 * FIFO overrun happens, the FIFO_OVERRUN (flag) is set.
 *
 * Values:
 * - 0 - Disable FIFO overrun (Flag).
 * - 1 - Enable FIFO overrun (Flag).
 */
/*@{*/
#define BP_ADC_INT_STATUS_FIFO_OVERRUN (7U) /*!< Bit position for ADC_INT_STATUS_FIFO_OVERRUN. */
#define BM_ADC_INT_STATUS_FIFO_OVERRUN (0x00000080U) /*!< Bit mask for ADC_INT_STATUS_FIFO_OVERRUN. */
#define BS_ADC_INT_STATUS_FIFO_OVERRUN (1U) /*!< Bit field size in bits for ADC_INT_STATUS_FIFO_OVERRUN. */

/*! @brief Read current value of the ADC_INT_STATUS_FIFO_OVERRUN field. */
#define BR_ADC_INT_STATUS_FIFO_OVERRUN(x) (HW_ADC_INT_STATUS(x).B.FIFO_OVERRUN)

/*! @brief Format value for bitfield ADC_INT_STATUS_FIFO_OVERRUN. */
#define BF_ADC_INT_STATUS_FIFO_OVERRUN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_STATUS_FIFO_OVERRUN) & BM_ADC_INT_STATUS_FIFO_OVERRUN)

/*! @brief Set the FIFO_OVERRUN field to a new value. */
#define BW_ADC_INT_STATUS_FIFO_OVERRUN(x, v) (HW_ADC_INT_STATUS_WR(x, (HW_ADC_INT_STATUS_RD(x) & ~BM_ADC_INT_STATUS_FIFO_OVERRUN) | BF_ADC_INT_STATUS_FIFO_OVERRUN(v)))
/*@}*/

/*!
 * @name Register ADC_INT_STATUS, field CHA_COV[8] (RW)
 *
 * This is the flag of channel A conversion. If CHA_COV_INT_SIG_EN is enabled
 * and channel A ADC conversion is finished, the CHA_CONV (flag) is set.
 *
 * Values:
 * - 0 - Disable channel A conversion (Flag).
 * - 1 - Enable channel A conversion (Flag).
 */
/*@{*/
#define BP_ADC_INT_STATUS_CHA_COV (8U)     /*!< Bit position for ADC_INT_STATUS_CHA_COV. */
#define BM_ADC_INT_STATUS_CHA_COV (0x00000100U) /*!< Bit mask for ADC_INT_STATUS_CHA_COV. */
#define BS_ADC_INT_STATUS_CHA_COV (1U)     /*!< Bit field size in bits for ADC_INT_STATUS_CHA_COV. */

/*! @brief Read current value of the ADC_INT_STATUS_CHA_COV field. */
#define BR_ADC_INT_STATUS_CHA_COV(x) (HW_ADC_INT_STATUS(x).B.CHA_COV)

/*! @brief Format value for bitfield ADC_INT_STATUS_CHA_COV. */
#define BF_ADC_INT_STATUS_CHA_COV(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_STATUS_CHA_COV) & BM_ADC_INT_STATUS_CHA_COV)

/*! @brief Set the CHA_COV field to a new value. */
#define BW_ADC_INT_STATUS_CHA_COV(x, v) (HW_ADC_INT_STATUS_WR(x, (HW_ADC_INT_STATUS_RD(x) & ~BM_ADC_INT_STATUS_CHA_COV) | BF_ADC_INT_STATUS_CHA_COV(v)))
/*@}*/

/*!
 * @name Register ADC_INT_STATUS, field CHB_COV[9] (RW)
 *
 * This is the flag of channel B conversion. If CHB_COV_INT_SIG_EN is enabled
 * and channel B ADC conversion is finished, the CHB_COV (flag) is set.
 *
 * Values:
 * - 0 - Disable channel B conversion (Flag).
 * - 1 - Enable channel B conversion (Flag).
 */
/*@{*/
#define BP_ADC_INT_STATUS_CHB_COV (9U)     /*!< Bit position for ADC_INT_STATUS_CHB_COV. */
#define BM_ADC_INT_STATUS_CHB_COV (0x00000200U) /*!< Bit mask for ADC_INT_STATUS_CHB_COV. */
#define BS_ADC_INT_STATUS_CHB_COV (1U)     /*!< Bit field size in bits for ADC_INT_STATUS_CHB_COV. */

/*! @brief Read current value of the ADC_INT_STATUS_CHB_COV field. */
#define BR_ADC_INT_STATUS_CHB_COV(x) (HW_ADC_INT_STATUS(x).B.CHB_COV)

/*! @brief Format value for bitfield ADC_INT_STATUS_CHB_COV. */
#define BF_ADC_INT_STATUS_CHB_COV(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_STATUS_CHB_COV) & BM_ADC_INT_STATUS_CHB_COV)

/*! @brief Set the CHB_COV field to a new value. */
#define BW_ADC_INT_STATUS_CHB_COV(x, v) (HW_ADC_INT_STATUS_WR(x, (HW_ADC_INT_STATUS_RD(x) & ~BM_ADC_INT_STATUS_CHB_COV) | BF_ADC_INT_STATUS_CHB_COV(v)))
/*@}*/

/*!
 * @name Register ADC_INT_STATUS, field CHC_COV[10] (RW)
 *
 * This is the flag of channel C conversion. If CHC_COV_INT_SIG_EN is enabled
 * and channel C ADC conversion is finished, the CHC_COV (flag) is set.
 *
 * Values:
 * - 0 - Disable channel C conversion (Flag).
 * - 1 - Enable channel C conversion (Flag).
 */
/*@{*/
#define BP_ADC_INT_STATUS_CHC_COV (10U)    /*!< Bit position for ADC_INT_STATUS_CHC_COV. */
#define BM_ADC_INT_STATUS_CHC_COV (0x00000400U) /*!< Bit mask for ADC_INT_STATUS_CHC_COV. */
#define BS_ADC_INT_STATUS_CHC_COV (1U)     /*!< Bit field size in bits for ADC_INT_STATUS_CHC_COV. */

/*! @brief Read current value of the ADC_INT_STATUS_CHC_COV field. */
#define BR_ADC_INT_STATUS_CHC_COV(x) (HW_ADC_INT_STATUS(x).B.CHC_COV)

/*! @brief Format value for bitfield ADC_INT_STATUS_CHC_COV. */
#define BF_ADC_INT_STATUS_CHC_COV(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_STATUS_CHC_COV) & BM_ADC_INT_STATUS_CHC_COV)

/*! @brief Set the CHC_COV field to a new value. */
#define BW_ADC_INT_STATUS_CHC_COV(x, v) (HW_ADC_INT_STATUS_WR(x, (HW_ADC_INT_STATUS_RD(x) & ~BM_ADC_INT_STATUS_CHC_COV) | BF_ADC_INT_STATUS_CHC_COV(v)))
/*@}*/

/*!
 * @name Register ADC_INT_STATUS, field CHD_COV[11] (RW)
 *
 * This is the flag of channel D conversion. If CHD_COV_INT_SIG_EN is enabled
 * and channel D ADC conversion is finished, the CHD_COV (flag) is set.
 *
 * Values:
 * - 0 - Disable channel D conversion (Flag).
 * - 1 - Enable channel D conversion (Flag).
 */
/*@{*/
#define BP_ADC_INT_STATUS_CHD_COV (11U)    /*!< Bit position for ADC_INT_STATUS_CHD_COV. */
#define BM_ADC_INT_STATUS_CHD_COV (0x00000800U) /*!< Bit mask for ADC_INT_STATUS_CHD_COV. */
#define BS_ADC_INT_STATUS_CHD_COV (1U)     /*!< Bit field size in bits for ADC_INT_STATUS_CHD_COV. */

/*! @brief Read current value of the ADC_INT_STATUS_CHD_COV field. */
#define BR_ADC_INT_STATUS_CHD_COV(x) (HW_ADC_INT_STATUS(x).B.CHD_COV)

/*! @brief Format value for bitfield ADC_INT_STATUS_CHD_COV. */
#define BF_ADC_INT_STATUS_CHD_COV(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_STATUS_CHD_COV) & BM_ADC_INT_STATUS_CHD_COV)

/*! @brief Set the CHD_COV field to a new value. */
#define BW_ADC_INT_STATUS_CHD_COV(x, v) (HW_ADC_INT_STATUS_WR(x, (HW_ADC_INT_STATUS_RD(x) & ~BM_ADC_INT_STATUS_CHD_COV) | BF_ADC_INT_STATUS_CHD_COV(v)))
/*@}*/

/*!
 * @name Register ADC_INT_STATUS, field SW_CH_COV[12] (RW)
 *
 * This is the flag of software trigger. If SW_CH_COV_INT_SIG_EN is enabled and
 * software trigger ADC conversion is finished, the SW_CH_COV (flag) is set.
 *
 * Values:
 * - 0 - Disable software channel conversion (Flag).
 * - 1 - Enable software channel conversion (Flag).
 */
/*@{*/
#define BP_ADC_INT_STATUS_SW_CH_COV (12U)  /*!< Bit position for ADC_INT_STATUS_SW_CH_COV. */
#define BM_ADC_INT_STATUS_SW_CH_COV (0x00001000U) /*!< Bit mask for ADC_INT_STATUS_SW_CH_COV. */
#define BS_ADC_INT_STATUS_SW_CH_COV (1U)   /*!< Bit field size in bits for ADC_INT_STATUS_SW_CH_COV. */

/*! @brief Read current value of the ADC_INT_STATUS_SW_CH_COV field. */
#define BR_ADC_INT_STATUS_SW_CH_COV(x) (HW_ADC_INT_STATUS(x).B.SW_CH_COV)

/*! @brief Format value for bitfield ADC_INT_STATUS_SW_CH_COV. */
#define BF_ADC_INT_STATUS_SW_CH_COV(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_STATUS_SW_CH_COV) & BM_ADC_INT_STATUS_SW_CH_COV)

/*! @brief Set the SW_CH_COV field to a new value. */
#define BW_ADC_INT_STATUS_SW_CH_COV(x, v) (HW_ADC_INT_STATUS_WR(x, (HW_ADC_INT_STATUS_RD(x) & ~BM_ADC_INT_STATUS_SW_CH_COV) | BF_ADC_INT_STATUS_SW_CH_COV(v)))
/*@}*/

/*!
 * @name Register ADC_INT_STATUS, field CHA_COV_TO[16] (RW)
 *
 * Represent whether logical channel A conversion time exist.
 *
 * Values:
 * - 0 - Logical channel A conversion time out does not exist.
 * - 1 - Exist logical channel A conversion time out. Software clear / clear
 *     signal enable.
 */
/*@{*/
#define BP_ADC_INT_STATUS_CHA_COV_TO (16U) /*!< Bit position for ADC_INT_STATUS_CHA_COV_TO. */
#define BM_ADC_INT_STATUS_CHA_COV_TO (0x00010000U) /*!< Bit mask for ADC_INT_STATUS_CHA_COV_TO. */
#define BS_ADC_INT_STATUS_CHA_COV_TO (1U)  /*!< Bit field size in bits for ADC_INT_STATUS_CHA_COV_TO. */

/*! @brief Read current value of the ADC_INT_STATUS_CHA_COV_TO field. */
#define BR_ADC_INT_STATUS_CHA_COV_TO(x) (HW_ADC_INT_STATUS(x).B.CHA_COV_TO)

/*! @brief Format value for bitfield ADC_INT_STATUS_CHA_COV_TO. */
#define BF_ADC_INT_STATUS_CHA_COV_TO(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_STATUS_CHA_COV_TO) & BM_ADC_INT_STATUS_CHA_COV_TO)

/*! @brief Set the CHA_COV_TO field to a new value. */
#define BW_ADC_INT_STATUS_CHA_COV_TO(x, v) (HW_ADC_INT_STATUS_WR(x, (HW_ADC_INT_STATUS_RD(x) & ~BM_ADC_INT_STATUS_CHA_COV_TO) | BF_ADC_INT_STATUS_CHA_COV_TO(v)))
/*@}*/

/*!
 * @name Register ADC_INT_STATUS, field CHB_COV_TO[17] (RW)
 *
 * Represent whether logical channel B conversion time out exist.
 *
 * Values:
 * - 0 - Logical channel B conversion time out exist.
 * - 1 - Exist logical channel B conversion time out. Software clear/clear
 *     signal enable.
 */
/*@{*/
#define BP_ADC_INT_STATUS_CHB_COV_TO (17U) /*!< Bit position for ADC_INT_STATUS_CHB_COV_TO. */
#define BM_ADC_INT_STATUS_CHB_COV_TO (0x00020000U) /*!< Bit mask for ADC_INT_STATUS_CHB_COV_TO. */
#define BS_ADC_INT_STATUS_CHB_COV_TO (1U)  /*!< Bit field size in bits for ADC_INT_STATUS_CHB_COV_TO. */

/*! @brief Read current value of the ADC_INT_STATUS_CHB_COV_TO field. */
#define BR_ADC_INT_STATUS_CHB_COV_TO(x) (HW_ADC_INT_STATUS(x).B.CHB_COV_TO)

/*! @brief Format value for bitfield ADC_INT_STATUS_CHB_COV_TO. */
#define BF_ADC_INT_STATUS_CHB_COV_TO(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_STATUS_CHB_COV_TO) & BM_ADC_INT_STATUS_CHB_COV_TO)

/*! @brief Set the CHB_COV_TO field to a new value. */
#define BW_ADC_INT_STATUS_CHB_COV_TO(x, v) (HW_ADC_INT_STATUS_WR(x, (HW_ADC_INT_STATUS_RD(x) & ~BM_ADC_INT_STATUS_CHB_COV_TO) | BF_ADC_INT_STATUS_CHB_COV_TO(v)))
/*@}*/

/*!
 * @name Register ADC_INT_STATUS, field CHC_COV_TO[18] (RW)
 *
 * Represent whether logical channel C conversion time out exist.
 *
 * Values:
 * - 0 - Logical channel C conversion time out does not exist.
 * - 1 - Exist logical channel C conversion time out. Software clear / clear
 *     signal enable.
 */
/*@{*/
#define BP_ADC_INT_STATUS_CHC_COV_TO (18U) /*!< Bit position for ADC_INT_STATUS_CHC_COV_TO. */
#define BM_ADC_INT_STATUS_CHC_COV_TO (0x00040000U) /*!< Bit mask for ADC_INT_STATUS_CHC_COV_TO. */
#define BS_ADC_INT_STATUS_CHC_COV_TO (1U)  /*!< Bit field size in bits for ADC_INT_STATUS_CHC_COV_TO. */

/*! @brief Read current value of the ADC_INT_STATUS_CHC_COV_TO field. */
#define BR_ADC_INT_STATUS_CHC_COV_TO(x) (HW_ADC_INT_STATUS(x).B.CHC_COV_TO)

/*! @brief Format value for bitfield ADC_INT_STATUS_CHC_COV_TO. */
#define BF_ADC_INT_STATUS_CHC_COV_TO(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_STATUS_CHC_COV_TO) & BM_ADC_INT_STATUS_CHC_COV_TO)

/*! @brief Set the CHC_COV_TO field to a new value. */
#define BW_ADC_INT_STATUS_CHC_COV_TO(x, v) (HW_ADC_INT_STATUS_WR(x, (HW_ADC_INT_STATUS_RD(x) & ~BM_ADC_INT_STATUS_CHC_COV_TO) | BF_ADC_INT_STATUS_CHC_COV_TO(v)))
/*@}*/

/*!
 * @name Register ADC_INT_STATUS, field CHD_COV_TO[19] (RW)
 *
 * Represent whether logical channel D conversion time out exist.
 *
 * Values:
 * - 0 - Logical channel D conversion time out does not exist.
 * - 1 - Exist logical channel D conversion time out. Software clear / clear
 *     signal enable.
 */
/*@{*/
#define BP_ADC_INT_STATUS_CHD_COV_TO (19U) /*!< Bit position for ADC_INT_STATUS_CHD_COV_TO. */
#define BM_ADC_INT_STATUS_CHD_COV_TO (0x00080000U) /*!< Bit mask for ADC_INT_STATUS_CHD_COV_TO. */
#define BS_ADC_INT_STATUS_CHD_COV_TO (1U)  /*!< Bit field size in bits for ADC_INT_STATUS_CHD_COV_TO. */

/*! @brief Read current value of the ADC_INT_STATUS_CHD_COV_TO field. */
#define BR_ADC_INT_STATUS_CHD_COV_TO(x) (HW_ADC_INT_STATUS(x).B.CHD_COV_TO)

/*! @brief Format value for bitfield ADC_INT_STATUS_CHD_COV_TO. */
#define BF_ADC_INT_STATUS_CHD_COV_TO(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_STATUS_CHD_COV_TO) & BM_ADC_INT_STATUS_CHD_COV_TO)

/*! @brief Set the CHD_COV_TO field to a new value. */
#define BW_ADC_INT_STATUS_CHD_COV_TO(x, v) (HW_ADC_INT_STATUS_WR(x, (HW_ADC_INT_STATUS_RD(x) & ~BM_ADC_INT_STATUS_CHD_COV_TO) | BF_ADC_INT_STATUS_CHD_COV_TO(v)))
/*@}*/

/*!
 * @name Register ADC_INT_STATUS, field SW_CH_COV_TO[20] (RW)
 *
 * Represents whether software channel conversion time out exist.
 *
 * Values:
 * - 0 - Software channel conversion time out does not exist.
 * - 1 - Exist software channel conversion time out. Software clear / clear
 *     signal enable.
 */
/*@{*/
#define BP_ADC_INT_STATUS_SW_CH_COV_TO (20U) /*!< Bit position for ADC_INT_STATUS_SW_CH_COV_TO. */
#define BM_ADC_INT_STATUS_SW_CH_COV_TO (0x00100000U) /*!< Bit mask for ADC_INT_STATUS_SW_CH_COV_TO. */
#define BS_ADC_INT_STATUS_SW_CH_COV_TO (1U) /*!< Bit field size in bits for ADC_INT_STATUS_SW_CH_COV_TO. */

/*! @brief Read current value of the ADC_INT_STATUS_SW_CH_COV_TO field. */
#define BR_ADC_INT_STATUS_SW_CH_COV_TO(x) (HW_ADC_INT_STATUS(x).B.SW_CH_COV_TO)

/*! @brief Format value for bitfield ADC_INT_STATUS_SW_CH_COV_TO. */
#define BF_ADC_INT_STATUS_SW_CH_COV_TO(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_STATUS_SW_CH_COV_TO) & BM_ADC_INT_STATUS_SW_CH_COV_TO)

/*! @brief Set the SW_CH_COV_TO field to a new value. */
#define BW_ADC_INT_STATUS_SW_CH_COV_TO(x, v) (HW_ADC_INT_STATUS_WR(x, (HW_ADC_INT_STATUS_RD(x) & ~BM_ADC_INT_STATUS_SW_CH_COV_TO) | BF_ADC_INT_STATUS_SW_CH_COV_TO(v)))
/*@}*/

/*!
 * @name Register ADC_INT_STATUS, field LAST_FIFO_DATA_READ[21] (RW)
 *
 * Represents whether the last data read out of FIFO (the last of whole
 * continuous result)
 *
 * Values:
 * - 0 - Last FIFO data has not been read out
 * - 1 - Last FIFO data has been read out
 */
/*@{*/
#define BP_ADC_INT_STATUS_LAST_FIFO_DATA_READ (21U) /*!< Bit position for ADC_INT_STATUS_LAST_FIFO_DATA_READ. */
#define BM_ADC_INT_STATUS_LAST_FIFO_DATA_READ (0x00200000U) /*!< Bit mask for ADC_INT_STATUS_LAST_FIFO_DATA_READ. */
#define BS_ADC_INT_STATUS_LAST_FIFO_DATA_READ (1U) /*!< Bit field size in bits for ADC_INT_STATUS_LAST_FIFO_DATA_READ. */

/*! @brief Read current value of the ADC_INT_STATUS_LAST_FIFO_DATA_READ field. */
#define BR_ADC_INT_STATUS_LAST_FIFO_DATA_READ(x) (HW_ADC_INT_STATUS(x).B.LAST_FIFO_DATA_READ)

/*! @brief Format value for bitfield ADC_INT_STATUS_LAST_FIFO_DATA_READ. */
#define BF_ADC_INT_STATUS_LAST_FIFO_DATA_READ(v) ((uint32_t)((uint32_t)(v) << BP_ADC_INT_STATUS_LAST_FIFO_DATA_READ) & BM_ADC_INT_STATUS_LAST_FIFO_DATA_READ)

/*! @brief Set the LAST_FIFO_DATA_READ field to a new value. */
#define BW_ADC_INT_STATUS_LAST_FIFO_DATA_READ(x, v) (HW_ADC_INT_STATUS_WR(x, (HW_ADC_INT_STATUS_RD(x) & ~BM_ADC_INT_STATUS_LAST_FIFO_DATA_READ) | BF_ADC_INT_STATUS_LAST_FIFO_DATA_READ(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_CHA_B_CNV_RSLT - Channel A and B Conversion Result
 ******************************************************************************/

/*!
 * @brief HW_ADC_CHA_B_CNV_RSLT - Channel A and B Conversion Result (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_adc_cha_b_cnv_rslt
{
    uint32_t U;
    struct _hw_adc_cha_b_cnv_rslt_bitfields
    {
        uint32_t CHA_CNV_RSLT : 12;    /*!< [11:0] Channel A Conversion Result */
        uint32_t RESERVED0 : 4;        /*!< [15:12] This field is reserved. */
        uint32_t CHB_CNV_RSLT : 12;    /*!< [27:16] Channel B Conversion Result
                                        * */
        uint32_t RESERVED1 : 4;        /*!< [31:28] This field is reserved. */
    } B;
} hw_adc_cha_b_cnv_rslt_t;

/*!
 * @name Constants and macros for entire ADC_CHA_B_CNV_RSLT register
 */
/*@{*/
#define HW_ADC_CHA_B_CNV_RSLT_ADDR(x) ((uintptr_t)(x) + 0xF0U)

#define HW_ADC_CHA_B_CNV_RSLT(x) (*(__IO hw_adc_cha_b_cnv_rslt_t *) HW_ADC_CHA_B_CNV_RSLT_ADDR(x))
#define HW_ADC_CHA_B_CNV_RSLT_RD(x) (HW_ADC_CHA_B_CNV_RSLT(x).U)
#define HW_ADC_CHA_B_CNV_RSLT_WR(x, v) (HW_ADC_CHA_B_CNV_RSLT(x).U = (v))
#define HW_ADC_CHA_B_CNV_RSLT_SET(x, v) (HW_ADC_CHA_B_CNV_RSLT_WR(x, HW_ADC_CHA_B_CNV_RSLT_RD(x) |  (v)))
#define HW_ADC_CHA_B_CNV_RSLT_CLR(x, v) (HW_ADC_CHA_B_CNV_RSLT_WR(x, HW_ADC_CHA_B_CNV_RSLT_RD(x) & ~(v)))
#define HW_ADC_CHA_B_CNV_RSLT_TOG(x, v) (HW_ADC_CHA_B_CNV_RSLT_WR(x, HW_ADC_CHA_B_CNV_RSLT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_CHA_B_CNV_RSLT bitfields
 */

/*!
 * @name Register ADC_CHA_B_CNV_RSLT, field CHA_CNV_RSLT[11:0] (RW)
 *
 * Channel A conversion result stores in this field.
 */
/*@{*/
#define BP_ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT (0U) /*!< Bit position for ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT. */
#define BM_ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT (0x00000FFFU) /*!< Bit mask for ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT. */
#define BS_ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT (12U) /*!< Bit field size in bits for ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT. */

/*! @brief Read current value of the ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT field. */
#define BR_ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT(x) (HW_ADC_CHA_B_CNV_RSLT(x).B.CHA_CNV_RSLT)

/*! @brief Format value for bitfield ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT. */
#define BF_ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT) & BM_ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT)

/*! @brief Set the CHA_CNV_RSLT field to a new value. */
#define BW_ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT(x, v) (HW_ADC_CHA_B_CNV_RSLT_WR(x, (HW_ADC_CHA_B_CNV_RSLT_RD(x) & ~BM_ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT) | BF_ADC_CHA_B_CNV_RSLT_CHA_CNV_RSLT(v)))
/*@}*/

/*!
 * @name Register ADC_CHA_B_CNV_RSLT, field CHB_CNV_RSLT[27:16] (RW)
 *
 * Channel B conversion result stores in this field.
 */
/*@{*/
#define BP_ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT (16U) /*!< Bit position for ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT. */
#define BM_ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT (0x0FFF0000U) /*!< Bit mask for ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT. */
#define BS_ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT (12U) /*!< Bit field size in bits for ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT. */

/*! @brief Read current value of the ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT field. */
#define BR_ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT(x) (HW_ADC_CHA_B_CNV_RSLT(x).B.CHB_CNV_RSLT)

/*! @brief Format value for bitfield ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT. */
#define BF_ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT) & BM_ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT)

/*! @brief Set the CHB_CNV_RSLT field to a new value. */
#define BW_ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT(x, v) (HW_ADC_CHA_B_CNV_RSLT_WR(x, (HW_ADC_CHA_B_CNV_RSLT_RD(x) & ~BM_ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT) | BF_ADC_CHA_B_CNV_RSLT_CHB_CNV_RSLT(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_CHC_D_CNV_RSLT - Channel C and D Conversion Result
 ******************************************************************************/

/*!
 * @brief HW_ADC_CHC_D_CNV_RSLT - Channel C and D Conversion Result (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_adc_chc_d_cnv_rslt
{
    uint32_t U;
    struct _hw_adc_chc_d_cnv_rslt_bitfields
    {
        uint32_t CHC_CNV_RSLT : 12;    /*!< [11:0] Channel C Conversion Result */
        uint32_t RESERVED0 : 4;        /*!< [15:12] This field is reserved. */
        uint32_t CHD_CNV_RSLT : 12;    /*!< [27:16] Channel D Conversion Result
                                        * */
        uint32_t RESERVED1 : 4;        /*!< [31:28] This field is reserved. */
    } B;
} hw_adc_chc_d_cnv_rslt_t;

/*!
 * @name Constants and macros for entire ADC_CHC_D_CNV_RSLT register
 */
/*@{*/
#define HW_ADC_CHC_D_CNV_RSLT_ADDR(x) ((uintptr_t)(x) + 0x100U)

#define HW_ADC_CHC_D_CNV_RSLT(x) (*(__IO hw_adc_chc_d_cnv_rslt_t *) HW_ADC_CHC_D_CNV_RSLT_ADDR(x))
#define HW_ADC_CHC_D_CNV_RSLT_RD(x) (HW_ADC_CHC_D_CNV_RSLT(x).U)
#define HW_ADC_CHC_D_CNV_RSLT_WR(x, v) (HW_ADC_CHC_D_CNV_RSLT(x).U = (v))
#define HW_ADC_CHC_D_CNV_RSLT_SET(x, v) (HW_ADC_CHC_D_CNV_RSLT_WR(x, HW_ADC_CHC_D_CNV_RSLT_RD(x) |  (v)))
#define HW_ADC_CHC_D_CNV_RSLT_CLR(x, v) (HW_ADC_CHC_D_CNV_RSLT_WR(x, HW_ADC_CHC_D_CNV_RSLT_RD(x) & ~(v)))
#define HW_ADC_CHC_D_CNV_RSLT_TOG(x, v) (HW_ADC_CHC_D_CNV_RSLT_WR(x, HW_ADC_CHC_D_CNV_RSLT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_CHC_D_CNV_RSLT bitfields
 */

/*!
 * @name Register ADC_CHC_D_CNV_RSLT, field CHC_CNV_RSLT[11:0] (RW)
 *
 * Channel C conversion result stores in this field.
 */
/*@{*/
#define BP_ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT (0U) /*!< Bit position for ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT. */
#define BM_ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT (0x00000FFFU) /*!< Bit mask for ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT. */
#define BS_ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT (12U) /*!< Bit field size in bits for ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT. */

/*! @brief Read current value of the ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT field. */
#define BR_ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT(x) (HW_ADC_CHC_D_CNV_RSLT(x).B.CHC_CNV_RSLT)

/*! @brief Format value for bitfield ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT. */
#define BF_ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT) & BM_ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT)

/*! @brief Set the CHC_CNV_RSLT field to a new value. */
#define BW_ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT(x, v) (HW_ADC_CHC_D_CNV_RSLT_WR(x, (HW_ADC_CHC_D_CNV_RSLT_RD(x) & ~BM_ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT) | BF_ADC_CHC_D_CNV_RSLT_CHC_CNV_RSLT(v)))
/*@}*/

/*!
 * @name Register ADC_CHC_D_CNV_RSLT, field CHD_CNV_RSLT[27:16] (RW)
 *
 * Channel D conversion result stores in this field.
 */
/*@{*/
#define BP_ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT (16U) /*!< Bit position for ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT. */
#define BM_ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT (0x0FFF0000U) /*!< Bit mask for ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT. */
#define BS_ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT (12U) /*!< Bit field size in bits for ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT. */

/*! @brief Read current value of the ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT field. */
#define BR_ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT(x) (HW_ADC_CHC_D_CNV_RSLT(x).B.CHD_CNV_RSLT)

/*! @brief Format value for bitfield ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT. */
#define BF_ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT) & BM_ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT)

/*! @brief Set the CHD_CNV_RSLT field to a new value. */
#define BW_ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT(x, v) (HW_ADC_CHC_D_CNV_RSLT_WR(x, (HW_ADC_CHC_D_CNV_RSLT_RD(x) & ~BM_ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT) | BF_ADC_CHC_D_CNV_RSLT_CHD_CNV_RSLT(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_CH_SW_CNV_RSLT - Channel Software Conversion Result
 ******************************************************************************/

/*!
 * @brief HW_ADC_CH_SW_CNV_RSLT - Channel Software Conversion Result (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_adc_ch_sw_cnv_rslt
{
    uint32_t U;
    struct _hw_adc_ch_sw_cnv_rslt_bitfields
    {
        uint32_t CH_SW_CNV_RSLT : 12;  /*!< [11:0] Channel Software Conversion
                                        * Result */
        uint32_t RESERVED0 : 20;       /*!< [31:12] This field is reserved. */
    } B;
} hw_adc_ch_sw_cnv_rslt_t;

/*!
 * @name Constants and macros for entire ADC_CH_SW_CNV_RSLT register
 */
/*@{*/
#define HW_ADC_CH_SW_CNV_RSLT_ADDR(x) ((uintptr_t)(x) + 0x110U)

#define HW_ADC_CH_SW_CNV_RSLT(x) (*(__IO hw_adc_ch_sw_cnv_rslt_t *) HW_ADC_CH_SW_CNV_RSLT_ADDR(x))
#define HW_ADC_CH_SW_CNV_RSLT_RD(x) (HW_ADC_CH_SW_CNV_RSLT(x).U)
#define HW_ADC_CH_SW_CNV_RSLT_WR(x, v) (HW_ADC_CH_SW_CNV_RSLT(x).U = (v))
#define HW_ADC_CH_SW_CNV_RSLT_SET(x, v) (HW_ADC_CH_SW_CNV_RSLT_WR(x, HW_ADC_CH_SW_CNV_RSLT_RD(x) |  (v)))
#define HW_ADC_CH_SW_CNV_RSLT_CLR(x, v) (HW_ADC_CH_SW_CNV_RSLT_WR(x, HW_ADC_CH_SW_CNV_RSLT_RD(x) & ~(v)))
#define HW_ADC_CH_SW_CNV_RSLT_TOG(x, v) (HW_ADC_CH_SW_CNV_RSLT_WR(x, HW_ADC_CH_SW_CNV_RSLT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_CH_SW_CNV_RSLT bitfields
 */

/*!
 * @name Register ADC_CH_SW_CNV_RSLT, field CH_SW_CNV_RSLT[11:0] (RW)
 *
 * Channel Software trigger conversion result stores in this field.
 */
/*@{*/
#define BP_ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT (0U) /*!< Bit position for ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT. */
#define BM_ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT (0x00000FFFU) /*!< Bit mask for ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT. */
#define BS_ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT (12U) /*!< Bit field size in bits for ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT. */

/*! @brief Read current value of the ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT field. */
#define BR_ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT(x) (HW_ADC_CH_SW_CNV_RSLT(x).B.CH_SW_CNV_RSLT)

/*! @brief Format value for bitfield ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT. */
#define BF_ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT(v) ((uint32_t)((uint32_t)(v) << BP_ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT) & BM_ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT)

/*! @brief Set the CH_SW_CNV_RSLT field to a new value. */
#define BW_ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT(x, v) (HW_ADC_CH_SW_CNV_RSLT_WR(x, (HW_ADC_CH_SW_CNV_RSLT_RD(x) & ~BM_ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT) | BF_ADC_CH_SW_CNV_RSLT_CH_SW_CNV_RSLT(v)))
/*@}*/

/*******************************************************************************
 * HW_ADC_DMA_FIFO_DAT - DMA FIFO Data
 ******************************************************************************/

/*!
 * @brief HW_ADC_DMA_FIFO_DAT - DMA FIFO Data (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_adc_dma_fifo_dat
{
    uint32_t U;
    struct _hw_adc_dma_fifo_dat_bitfields
    {
        uint32_t DMA_FIFO_0 : 12;      /*!< [11:0]  */
        uint32_t RESERVED0 : 2;        /*!< [13:12] This field is reserved. */
        uint32_t DAT1_FLAG : 2;        /*!< [15:14] Data 1 Flag */
        uint32_t DMA_FIFO_1 : 12;      /*!< [27:16]  */
        uint32_t RESERVED1 : 2;        /*!< [29:28] This field is reserved. */
        uint32_t DAT2_FLAG : 2;        /*!< [31:30] Data 2 Flag */
    } B;
} hw_adc_dma_fifo_dat_t;

/*!
 * @name Constants and macros for entire ADC_DMA_FIFO_DAT register
 */
/*@{*/
#define HW_ADC_DMA_FIFO_DAT_ADDR(x) ((uintptr_t)(x) + 0x120U)

#define HW_ADC_DMA_FIFO_DAT(x)   (*(__I hw_adc_dma_fifo_dat_t *) HW_ADC_DMA_FIFO_DAT_ADDR(x))
#define HW_ADC_DMA_FIFO_DAT_RD(x) (HW_ADC_DMA_FIFO_DAT(x).U)
/*@}*/

/*
 * Constants & macros for individual ADC_DMA_FIFO_DAT bitfields
 */

/*!
 * @name Register ADC_DMA_FIFO_DAT, field DMA_FIFO_0[11:0] (RO)
 *
 * The even number of data is in this field. This field is read-only
 */
/*@{*/
#define BP_ADC_DMA_FIFO_DAT_DMA_FIFO_0 (0U) /*!< Bit position for ADC_DMA_FIFO_DAT_DMA_FIFO_0. */
#define BM_ADC_DMA_FIFO_DAT_DMA_FIFO_0 (0x00000FFFU) /*!< Bit mask for ADC_DMA_FIFO_DAT_DMA_FIFO_0. */
#define BS_ADC_DMA_FIFO_DAT_DMA_FIFO_0 (12U) /*!< Bit field size in bits for ADC_DMA_FIFO_DAT_DMA_FIFO_0. */

/*! @brief Read current value of the ADC_DMA_FIFO_DAT_DMA_FIFO_0 field. */
#define BR_ADC_DMA_FIFO_DAT_DMA_FIFO_0(x) (HW_ADC_DMA_FIFO_DAT(x).B.DMA_FIFO_0)
/*@}*/

/*!
 * @name Register ADC_DMA_FIFO_DAT, field DAT1_FLAG[15:14] (RO)
 *
 * The flag defines the status of data 1.
 *
 * Values:
 * - 00 - Default
 * - 01 - Valid Data. Indicate the data 1 is a valid data.
 * - 10 - Last Data. Indicate the last the data of a continuous batch.
 * - 11 - Invalid Data. Indicate the data 1 is a invalid data.
 */
/*@{*/
#define BP_ADC_DMA_FIFO_DAT_DAT1_FLAG (14U) /*!< Bit position for ADC_DMA_FIFO_DAT_DAT1_FLAG. */
#define BM_ADC_DMA_FIFO_DAT_DAT1_FLAG (0x0000C000U) /*!< Bit mask for ADC_DMA_FIFO_DAT_DAT1_FLAG. */
#define BS_ADC_DMA_FIFO_DAT_DAT1_FLAG (2U) /*!< Bit field size in bits for ADC_DMA_FIFO_DAT_DAT1_FLAG. */

/*! @brief Read current value of the ADC_DMA_FIFO_DAT_DAT1_FLAG field. */
#define BR_ADC_DMA_FIFO_DAT_DAT1_FLAG(x) (HW_ADC_DMA_FIFO_DAT(x).B.DAT1_FLAG)
/*@}*/

/*!
 * @name Register ADC_DMA_FIFO_DAT, field DMA_FIFO_1[27:16] (RO)
 *
 * The even number of data is in this field. This field is read-only
 */
/*@{*/
#define BP_ADC_DMA_FIFO_DAT_DMA_FIFO_1 (16U) /*!< Bit position for ADC_DMA_FIFO_DAT_DMA_FIFO_1. */
#define BM_ADC_DMA_FIFO_DAT_DMA_FIFO_1 (0x0FFF0000U) /*!< Bit mask for ADC_DMA_FIFO_DAT_DMA_FIFO_1. */
#define BS_ADC_DMA_FIFO_DAT_DMA_FIFO_1 (12U) /*!< Bit field size in bits for ADC_DMA_FIFO_DAT_DMA_FIFO_1. */

/*! @brief Read current value of the ADC_DMA_FIFO_DAT_DMA_FIFO_1 field. */
#define BR_ADC_DMA_FIFO_DAT_DMA_FIFO_1(x) (HW_ADC_DMA_FIFO_DAT(x).B.DMA_FIFO_1)
/*@}*/

/*!
 * @name Register ADC_DMA_FIFO_DAT, field DAT2_FLAG[31:30] (RO)
 *
 * The flag defines the status of data 2.
 *
 * Values:
 * - 00 - Default
 * - 01 - Valid Data. Indicate the data 2 is a valid data.
 * - 10 - Last Data. Indicate the last the data of a continuous batch.
 * - 11 - Invalid Data. Indicate the data 2 is a invalid data.
 */
/*@{*/
#define BP_ADC_DMA_FIFO_DAT_DAT2_FLAG (30U) /*!< Bit position for ADC_DMA_FIFO_DAT_DAT2_FLAG. */
#define BM_ADC_DMA_FIFO_DAT_DAT2_FLAG (0xC0000000U) /*!< Bit mask for ADC_DMA_FIFO_DAT_DAT2_FLAG. */
#define BS_ADC_DMA_FIFO_DAT_DAT2_FLAG (2U) /*!< Bit field size in bits for ADC_DMA_FIFO_DAT_DAT2_FLAG. */

/*! @brief Read current value of the ADC_DMA_FIFO_DAT_DAT2_FLAG field. */
#define BR_ADC_DMA_FIFO_DAT_DAT2_FLAG(x) (HW_ADC_DMA_FIFO_DAT(x).B.DAT2_FLAG)
/*@}*/

/*******************************************************************************
 * HW_ADC_ADC_CFG - ADC Configuration
 ******************************************************************************/

/*!
 * @brief HW_ADC_ADC_CFG - ADC Configuration (RW)
 *
 * Reset value: 0x00000001U
 */
typedef union _hw_adc_adc_cfg
{
    uint32_t U;
    struct _hw_adc_adc_cfg_bitfields
    {
        uint32_t ADC_EN : 1;           /*!< [0] ADC Level Shifter Enable */
        uint32_t ADC_PD : 1;           /*!< [1] ADC Power Down */
        uint32_t RESERVED0 : 5;        /*!< [6:2] This field is reserved. */
        uint32_t ADC_PD_OK : 1;        /*!< [7] ADC Power Down OK */
        uint32_t RESERVED1 : 23;       /*!< [30:8] This field is reserved. */
        uint32_t ADC_CLK_DOWN : 1;     /*!< [31] ADC Clock Down */
    } B;
} hw_adc_adc_cfg_t;

/*!
 * @name Constants and macros for entire ADC_ADC_CFG register
 */
/*@{*/
#define HW_ADC_ADC_CFG_ADDR(x)   ((uintptr_t)(x) + 0x130U)

#define HW_ADC_ADC_CFG(x)        (*(__IO hw_adc_adc_cfg_t *) HW_ADC_ADC_CFG_ADDR(x))
#define HW_ADC_ADC_CFG_RD(x)     (HW_ADC_ADC_CFG(x).U)
#define HW_ADC_ADC_CFG_WR(x, v)  (HW_ADC_ADC_CFG(x).U = (v))
#define HW_ADC_ADC_CFG_SET(x, v) (HW_ADC_ADC_CFG_WR(x, HW_ADC_ADC_CFG_RD(x) |  (v)))
#define HW_ADC_ADC_CFG_CLR(x, v) (HW_ADC_ADC_CFG_WR(x, HW_ADC_ADC_CFG_RD(x) & ~(v)))
#define HW_ADC_ADC_CFG_TOG(x, v) (HW_ADC_ADC_CFG_WR(x, HW_ADC_ADC_CFG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ADC_ADC_CFG bitfields
 */

/*!
 * @name Register ADC_ADC_CFG, field ADC_EN[0] (RW)
 *
 * The level shifter provides 1.8 V to 1.1 V converter. The level shifter is
 * embedded in ADC analogue. The ADC analogue ports voltage level must same with ADC
 * digital part ports voltage level. During low power mode, also reset this bit
 * to 1'b0 to save power.
 *
 * Values:
 * - 0 - Disable level shifter, the ADC analogue core ports using 1.8 V voltage
 *     level.
 * - 1 - Enable level shifter, the ADC analogue core ports using 1.1 V voltage
 *     level.
 */
/*@{*/
#define BP_ADC_ADC_CFG_ADC_EN (0U)         /*!< Bit position for ADC_ADC_CFG_ADC_EN. */
#define BM_ADC_ADC_CFG_ADC_EN (0x00000001U) /*!< Bit mask for ADC_ADC_CFG_ADC_EN. */
#define BS_ADC_ADC_CFG_ADC_EN (1U)         /*!< Bit field size in bits for ADC_ADC_CFG_ADC_EN. */

/*! @brief Read current value of the ADC_ADC_CFG_ADC_EN field. */
#define BR_ADC_ADC_CFG_ADC_EN(x) (HW_ADC_ADC_CFG(x).B.ADC_EN)

/*! @brief Format value for bitfield ADC_ADC_CFG_ADC_EN. */
#define BF_ADC_ADC_CFG_ADC_EN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_ADC_CFG_ADC_EN) & BM_ADC_ADC_CFG_ADC_EN)

/*! @brief Set the ADC_EN field to a new value. */
#define BW_ADC_ADC_CFG_ADC_EN(x, v) (HW_ADC_ADC_CFG_WR(x, (HW_ADC_ADC_CFG_RD(x) & ~BM_ADC_ADC_CFG_ADC_EN) | BF_ADC_ADC_CFG_ADC_EN(v)))
/*@}*/

/*!
 * @name Register ADC_ADC_CFG, field ADC_PD[1] (RW)
 *
 * Power Down ADC analogue core. Before entering into stop-mode, power down ADC
 * analogue core first.
 *
 * Values:
 * - 0 - Do not power down the ADC analogue core.
 * - 1 - Power down the ADC analogue core.
 */
/*@{*/
#define BP_ADC_ADC_CFG_ADC_PD (1U)         /*!< Bit position for ADC_ADC_CFG_ADC_PD. */
#define BM_ADC_ADC_CFG_ADC_PD (0x00000002U) /*!< Bit mask for ADC_ADC_CFG_ADC_PD. */
#define BS_ADC_ADC_CFG_ADC_PD (1U)         /*!< Bit field size in bits for ADC_ADC_CFG_ADC_PD. */

/*! @brief Read current value of the ADC_ADC_CFG_ADC_PD field. */
#define BR_ADC_ADC_CFG_ADC_PD(x) (HW_ADC_ADC_CFG(x).B.ADC_PD)

/*! @brief Format value for bitfield ADC_ADC_CFG_ADC_PD. */
#define BF_ADC_ADC_CFG_ADC_PD(v) ((uint32_t)((uint32_t)(v) << BP_ADC_ADC_CFG_ADC_PD) & BM_ADC_ADC_CFG_ADC_PD)

/*! @brief Set the ADC_PD field to a new value. */
#define BW_ADC_ADC_CFG_ADC_PD(x, v) (HW_ADC_ADC_CFG_WR(x, (HW_ADC_ADC_CFG_RD(x) & ~BM_ADC_ADC_CFG_ADC_PD) | BF_ADC_ADC_CFG_ADC_PD(v)))
/*@}*/

/*!
 * @name Register ADC_ADC_CFG, field ADC_PD_OK[7] (RW)
 *
 * This bit represents whether power down or to start conversion. After power up
 * the ADC analogue core, system has to wait ADC_PD_OK = 1 before start a
 * conversion or power down again. If violate this rule, the ADC may enter an unknown
 * state. Clock cannot stop until this bit equals to 0. This bit will
 * automatically set to 1 if ADC_PD = 0 and ADC_EN = 0 for the specific time period.
 *
 * Values:
 * - 0 - ADC has not power up completely. Cannot start a conversion.
 * - 1 - ADC power up completely. Can start a conversion.
 */
/*@{*/
#define BP_ADC_ADC_CFG_ADC_PD_OK (7U)      /*!< Bit position for ADC_ADC_CFG_ADC_PD_OK. */
#define BM_ADC_ADC_CFG_ADC_PD_OK (0x00000080U) /*!< Bit mask for ADC_ADC_CFG_ADC_PD_OK. */
#define BS_ADC_ADC_CFG_ADC_PD_OK (1U)      /*!< Bit field size in bits for ADC_ADC_CFG_ADC_PD_OK. */

/*! @brief Read current value of the ADC_ADC_CFG_ADC_PD_OK field. */
#define BR_ADC_ADC_CFG_ADC_PD_OK(x) (HW_ADC_ADC_CFG(x).B.ADC_PD_OK)

/*! @brief Format value for bitfield ADC_ADC_CFG_ADC_PD_OK. */
#define BF_ADC_ADC_CFG_ADC_PD_OK(v) ((uint32_t)((uint32_t)(v) << BP_ADC_ADC_CFG_ADC_PD_OK) & BM_ADC_ADC_CFG_ADC_PD_OK)

/*! @brief Set the ADC_PD_OK field to a new value. */
#define BW_ADC_ADC_CFG_ADC_PD_OK(x, v) (HW_ADC_ADC_CFG_WR(x, (HW_ADC_ADC_CFG_RD(x) & ~BM_ADC_ADC_CFG_ADC_PD_OK) | BF_ADC_ADC_CFG_ADC_PD_OK(v)))
/*@}*/

/*!
 * @name Register ADC_ADC_CFG, field ADC_CLK_DOWN[31] (RW)
 *
 * This bit is for low power design. Set this bit to stop all digital part
 * power. Warning: Before set this bit, all conversion must be finished.
 *
 * Values:
 * - 0 - Clock running.
 * - 1 - Clock down, no clock.
 */
/*@{*/
#define BP_ADC_ADC_CFG_ADC_CLK_DOWN (31U)  /*!< Bit position for ADC_ADC_CFG_ADC_CLK_DOWN. */
#define BM_ADC_ADC_CFG_ADC_CLK_DOWN (0x80000000U) /*!< Bit mask for ADC_ADC_CFG_ADC_CLK_DOWN. */
#define BS_ADC_ADC_CFG_ADC_CLK_DOWN (1U)   /*!< Bit field size in bits for ADC_ADC_CFG_ADC_CLK_DOWN. */

/*! @brief Read current value of the ADC_ADC_CFG_ADC_CLK_DOWN field. */
#define BR_ADC_ADC_CFG_ADC_CLK_DOWN(x) (HW_ADC_ADC_CFG(x).B.ADC_CLK_DOWN)

/*! @brief Format value for bitfield ADC_ADC_CFG_ADC_CLK_DOWN. */
#define BF_ADC_ADC_CFG_ADC_CLK_DOWN(v) ((uint32_t)((uint32_t)(v) << BP_ADC_ADC_CFG_ADC_CLK_DOWN) & BM_ADC_ADC_CFG_ADC_CLK_DOWN)

/*! @brief Set the ADC_CLK_DOWN field to a new value. */
#define BW_ADC_ADC_CFG_ADC_CLK_DOWN(x, v) (HW_ADC_ADC_CFG_WR(x, (HW_ADC_ADC_CFG_RD(x) & ~BM_ADC_ADC_CFG_ADC_CLK_DOWN) | BF_ADC_ADC_CFG_ADC_CLK_DOWN(v)))
/*@}*/

/*******************************************************************************
 * hw_adc_t - module struct
 ******************************************************************************/
/*!
 * @brief All ADC module registers.
 */
#pragma pack(1)
typedef struct _hw_adc
{
    __IO hw_adc_ch_a_cfg1_t CH_A_CFG1;     /*!< [0x0] Channel A configuration 1 */
    uint8_t _reserved0[12];
    __IO hw_adc_ch_a_cfg2_t CH_A_CFG2;     /*!< [0x10] Channel A configuration 2 */
    uint8_t _reserved1[12];
    __IO hw_adc_ch_b_cfg1_t CH_B_CFG1;     /*!< [0x20]  */
    uint8_t _reserved2[12];
    __IO hw_adc_ch_b_cfg2_t CH_B_CFG2;     /*!< [0x30] Channel B Configuration 2 */
    uint8_t _reserved3[12];
    __IO hw_adc_ch_c_cfg1_t CH_C_CFG1;     /*!< [0x40] Channel C Configuration 1 */
    uint8_t _reserved4[12];
    __IO hw_adc_ch_c_cfg2_t CH_C_CFG2;     /*!< [0x50] Channel C Configuration 2 */
    uint8_t _reserved5[12];
    __IO hw_adc_ch_d_cfg1_t CH_D_CFG1;     /*!< [0x60] Channel D Configuration 1 */
    uint8_t _reserved6[12];
    __IO hw_adc_ch_d_cfg2_t CH_D_CFG2;     /*!< [0x70] Channel D Configuration 2 */
    uint8_t _reserved7[12];
    __IO hw_adc_ch_sw_cfg_t CH_SW_CFG;     /*!< [0x80] Channel Software Configuration */
    uint8_t _reserved8[12];
    __IO hw_adc_timer_unit_t TIMER_UNIT;   /*!< [0x90] Timer Unit */
    uint8_t _reserved9[12];
    __IO hw_adc_dma_fifo_t DMA_FIFO;       /*!< [0xA0] DMA FIFO */
    uint8_t _reserved10[12];
    __IO hw_adc_fifo_status_t FIFO_STATUS; /*!< [0xB0] FIFO Status */
    uint8_t _reserved11[12];
    __IO hw_adc_int_sig_en_t INT_SIG_EN;   /*!< [0xC0]  */
    uint8_t _reserved12[12];
    __IO hw_adc_int_en_t INT_EN;           /*!< [0xD0] Interrupt Enable */
    uint8_t _reserved13[12];
    __IO hw_adc_int_status_t INT_STATUS;   /*!< [0xE0]  */
    uint8_t _reserved14[12];
    __IO hw_adc_cha_b_cnv_rslt_t CHA_B_CNV_RSLT; /*!< [0xF0] Channel A and B Conversion Result */
    uint8_t _reserved15[12];
    __IO hw_adc_chc_d_cnv_rslt_t CHC_D_CNV_RSLT; /*!< [0x100] Channel C and D Conversion Result */
    uint8_t _reserved16[12];
    __IO hw_adc_ch_sw_cnv_rslt_t CH_SW_CNV_RSLT; /*!< [0x110] Channel Software Conversion Result */
    uint8_t _reserved17[12];
    __I hw_adc_dma_fifo_dat_t DMA_FIFO_DAT; /*!< [0x120] DMA FIFO Data */
    uint8_t _reserved18[12];
    __IO hw_adc_adc_cfg_t ADC_CFG;         /*!< [0x130] ADC Configuration */
} hw_adc_t;
#pragma pack()

/*! @brief Macro to access all ADC registers. */
/*! @param x ADC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_ADC_REGS(ADC1_BASE)</code>. */
#define HW_ADC_REGS(x) (*(hw_adc_t *)(x))

/*
 * iMX7D APBH
 *
 * APBH Register Reference Index
 *
 * Registers defined in this header file:
 * - HW_APBH_CTRL0 - AHB to APBH Bridge Control and Status Register 0
 * - HW_APBH_CTRL1 - AHB to APBH Bridge Control and Status Register 1
 * - HW_APBH_CTRL2 - AHB to APBH Bridge Control and Status Register 2
 * - HW_APBH_CHANNEL_CTRL - AHB to APBH Bridge Channel Register
 * - HW_APBH_DEVSEL - AHB to APBH DMA Device Assignment Register
 * - HW_APBH_DMA_BURST_SIZE - AHB to APBH DMA burst size
 * - HW_APBH_DEBUG - AHB to APBH DMA Debug Register
 * - HW_APBH_CHn_CURCMDAR - APBH DMA Channel n Current Command Address Register
 * - HW_APBH_CHn_NXTCMDAR - APBH DMA Channel n Next Command Address Register
 * - HW_APBH_CHn_CMD - APBH DMA Channel n Command Register
 * - HW_APBH_CHn_BAR - APBH DMA Channel n Buffer Address Register
 * - HW_APBH_CHn_SEMA - APBH DMA Channel n Semaphore Register
 * - HW_APBH_CHn_DEBUG1 - AHB to APBH DMA Channel n Debug Information
 * - HW_APBH_CHn_DEBUG2 - AHB to APBH DMA Channel n Debug Information
 * - HW_APBH_VERSION - APBH Bridge Version Register
 *
 * - hw_apbh_t - Struct containing all module registers.
 */

#define HW_APBH_INSTANCE_COUNT (1U) /*!< Number of instances of the APBH module. */
#define HW_APBH (0U) /*!< Instance number for APBH. */
#define APBH_BASE             (0x33000000U) /*!< Base address for APBH. */
/*! Array initializer of APBH base addresses. */
#define APBH_BASE_ADDRS       { APBH_BASE }

/*******************************************************************************
 * HW_APBH_CTRL0 - AHB to APBH Bridge Control and Status Register 0
 ******************************************************************************/

/*!
 * @brief HW_APBH_CTRL0 - AHB to APBH Bridge Control and Status Register 0 (RW)
 *
 * Reset value: 0xE0000000U
 *
 * The APBH CTRL 0 provides overall control of the AHB to APBH bridge and DMA.
 * This register contains module softreset, clock gating, channel clock
 * gating/freeze bits.
 */
typedef union _hw_apbh_ctrl0
{
    uint32_t U;
    struct _hw_apbh_ctrl0_bitfields
    {
        uint32_t CLKGATE_CHANNEL : 16; /*!< [15:0]  */
        uint32_t RSVD0 : 12;           /*!< [27:16]  */
        uint32_t APB_BURST_EN : 1;     /*!< [28]  */
        uint32_t AHB_BURST8_EN : 1;    /*!< [29]  */
        uint32_t CLKGATE : 1;          /*!< [30]  */
        uint32_t SFTRST : 1;           /*!< [31]  */
    } B;
} hw_apbh_ctrl0_t;

/*!
 * @name Constants and macros for entire APBH_CTRL0 register
 */
/*@{*/
#define HW_APBH_CTRL0_ADDR(x)    ((uintptr_t)(x) + 0x0U)
#define HW_APBH_CTRL0_SET_ADDR(x) (HW_APBH_CTRL0_ADDR(x) + 0x4U)
#define HW_APBH_CTRL0_CLR_ADDR(x) (HW_APBH_CTRL0_ADDR(x) + 0x8U)
#define HW_APBH_CTRL0_TOG_ADDR(x) (HW_APBH_CTRL0_ADDR(x) + 0xCU)

#define HW_APBH_CTRL0(x)         (*(__IO hw_apbh_ctrl0_t *) HW_APBH_CTRL0_ADDR(x))
#define HW_APBH_CTRL0_RD(x)      (HW_APBH_CTRL0(x).U)
#define HW_APBH_CTRL0_WR(x, v)   (HW_APBH_CTRL0(x).U = (v))
#define HW_APBH_CTRL0_SET(x, v)  ((*(uint32_t *) HW_APBH_CTRL0_SET_ADDR(x)) = (v))
#define HW_APBH_CTRL0_CLR(x, v)  ((*(uint32_t *) HW_APBH_CTRL0_CLR_ADDR(x)) = (v))
#define HW_APBH_CTRL0_TOG(x, v)  ((*(uint32_t *) HW_APBH_CTRL0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual APBH_CTRL0 bitfields
 */

/*!
 * @name Register APBH_CTRL0, field CLKGATE_CHANNEL[15:0] (RW)
 *
 * These bits must be set to zero for normal operation of each channel. When set
 * to one they gate off the individual clocks to the channels.
 *
 * Values:
 * - 1 -
 * - 10 -
 * - 100 -
 * - 1000 -
 * - 10000 -
 * - 100000 -
 * - 1000000 -
 * - 10000000 -
 * - 100000000 -
 */
/*@{*/
#define BP_APBH_CTRL0_CLKGATE_CHANNEL (0U) /*!< Bit position for APBH_CTRL0_CLKGATE_CHANNEL. */
#define BM_APBH_CTRL0_CLKGATE_CHANNEL (0x0000FFFFU) /*!< Bit mask for APBH_CTRL0_CLKGATE_CHANNEL. */
#define BS_APBH_CTRL0_CLKGATE_CHANNEL (16U) /*!< Bit field size in bits for APBH_CTRL0_CLKGATE_CHANNEL. */

#define BV_APBH_CTRL0_CLKGATE_CHANNEL_NAND0 (0x1U)   /*!< Bit field value for APBH_CTRL0_CLKGATE_CHANNEL:  */
#define BV_APBH_CTRL0_CLKGATE_CHANNEL_NAND1 (0x2U)   /*!< Bit field value for APBH_CTRL0_CLKGATE_CHANNEL:  */
#define BV_APBH_CTRL0_CLKGATE_CHANNEL_NAND2 (0x4U)   /*!< Bit field value for APBH_CTRL0_CLKGATE_CHANNEL:  */
#define BV_APBH_CTRL0_CLKGATE_CHANNEL_NAND3 (0x8U)   /*!< Bit field value for APBH_CTRL0_CLKGATE_CHANNEL:  */
#define BV_APBH_CTRL0_CLKGATE_CHANNEL_NAND4 (0x10U)  /*!< Bit field value for APBH_CTRL0_CLKGATE_CHANNEL:  */
#define BV_APBH_CTRL0_CLKGATE_CHANNEL_NAND5 (0x20U)  /*!< Bit field value for APBH_CTRL0_CLKGATE_CHANNEL:  */
#define BV_APBH_CTRL0_CLKGATE_CHANNEL_NAND6 (0x40U)  /*!< Bit field value for APBH_CTRL0_CLKGATE_CHANNEL:  */
#define BV_APBH_CTRL0_CLKGATE_CHANNEL_NAND7 (0x80U)  /*!< Bit field value for APBH_CTRL0_CLKGATE_CHANNEL:  */
#define BV_APBH_CTRL0_CLKGATE_CHANNEL_SSP (0x100U)   /*!< Bit field value for APBH_CTRL0_CLKGATE_CHANNEL:  */

/*! @brief Read current value of the APBH_CTRL0_CLKGATE_CHANNEL field. */
#define BR_APBH_CTRL0_CLKGATE_CHANNEL(x) (HW_APBH_CTRL0(x).B.CLKGATE_CHANNEL)

/*! @brief Format value for bitfield APBH_CTRL0_CLKGATE_CHANNEL. */
#define BF_APBH_CTRL0_CLKGATE_CHANNEL(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL0_CLKGATE_CHANNEL) & BM_APBH_CTRL0_CLKGATE_CHANNEL)

/*! @brief Set the CLKGATE_CHANNEL field to a new value. */
#define BW_APBH_CTRL0_CLKGATE_CHANNEL(x, v) (HW_APBH_CTRL0_WR(x, (HW_APBH_CTRL0_RD(x) & ~BM_APBH_CTRL0_CLKGATE_CHANNEL) | BF_APBH_CTRL0_CLKGATE_CHANNEL(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL0, field RSVD0[27:16] (RU)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_APBH_CTRL0_RSVD0  (16U)         /*!< Bit position for APBH_CTRL0_RSVD0. */
#define BM_APBH_CTRL0_RSVD0  (0x0FFF0000U) /*!< Bit mask for APBH_CTRL0_RSVD0. */
#define BS_APBH_CTRL0_RSVD0  (12U)         /*!< Bit field size in bits for APBH_CTRL0_RSVD0. */
/*@}*/

/*!
 * @name Register APBH_CTRL0, field APB_BURST_EN[28] (RW)
 *
 * Set this bit to one to enable apb master do a continous transfers when a
 * device request a burst dma. Set to zero will treat a burst dma request as 4/8
 * individual requests.
 */
/*@{*/
#define BP_APBH_CTRL0_APB_BURST_EN (28U)   /*!< Bit position for APBH_CTRL0_APB_BURST_EN. */
#define BM_APBH_CTRL0_APB_BURST_EN (0x10000000U) /*!< Bit mask for APBH_CTRL0_APB_BURST_EN. */
#define BS_APBH_CTRL0_APB_BURST_EN (1U)    /*!< Bit field size in bits for APBH_CTRL0_APB_BURST_EN. */

/*! @brief Read current value of the APBH_CTRL0_APB_BURST_EN field. */
#define BR_APBH_CTRL0_APB_BURST_EN(x) (HW_APBH_CTRL0(x).B.APB_BURST_EN)

/*! @brief Format value for bitfield APBH_CTRL0_APB_BURST_EN. */
#define BF_APBH_CTRL0_APB_BURST_EN(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL0_APB_BURST_EN) & BM_APBH_CTRL0_APB_BURST_EN)

/*! @brief Set the APB_BURST_EN field to a new value. */
#define BW_APBH_CTRL0_APB_BURST_EN(x, v) (HW_APBH_CTRL0_WR(x, (HW_APBH_CTRL0_RD(x) & ~BM_APBH_CTRL0_APB_BURST_EN) | BF_APBH_CTRL0_APB_BURST_EN(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL0, field AHB_BURST8_EN[29] (RW)
 *
 * Set this bit to one (default) to enable AHB 8-beat burst. Set to zero to
 * disable 8-beat burst on AHB interface.
 */
/*@{*/
#define BP_APBH_CTRL0_AHB_BURST8_EN (29U)  /*!< Bit position for APBH_CTRL0_AHB_BURST8_EN. */
#define BM_APBH_CTRL0_AHB_BURST8_EN (0x20000000U) /*!< Bit mask for APBH_CTRL0_AHB_BURST8_EN. */
#define BS_APBH_CTRL0_AHB_BURST8_EN (1U)   /*!< Bit field size in bits for APBH_CTRL0_AHB_BURST8_EN. */

/*! @brief Read current value of the APBH_CTRL0_AHB_BURST8_EN field. */
#define BR_APBH_CTRL0_AHB_BURST8_EN(x) (HW_APBH_CTRL0(x).B.AHB_BURST8_EN)

/*! @brief Format value for bitfield APBH_CTRL0_AHB_BURST8_EN. */
#define BF_APBH_CTRL0_AHB_BURST8_EN(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL0_AHB_BURST8_EN) & BM_APBH_CTRL0_AHB_BURST8_EN)

/*! @brief Set the AHB_BURST8_EN field to a new value. */
#define BW_APBH_CTRL0_AHB_BURST8_EN(x, v) (HW_APBH_CTRL0_WR(x, (HW_APBH_CTRL0_RD(x) & ~BM_APBH_CTRL0_AHB_BURST8_EN) | BF_APBH_CTRL0_AHB_BURST8_EN(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL0, field CLKGATE[30] (RW)
 *
 * This bit must be set to zero for normal operation. When set to one it gates
 * off the clocks to the block.
 */
/*@{*/
#define BP_APBH_CTRL0_CLKGATE (30U)        /*!< Bit position for APBH_CTRL0_CLKGATE. */
#define BM_APBH_CTRL0_CLKGATE (0x40000000U) /*!< Bit mask for APBH_CTRL0_CLKGATE. */
#define BS_APBH_CTRL0_CLKGATE (1U)         /*!< Bit field size in bits for APBH_CTRL0_CLKGATE. */

/*! @brief Read current value of the APBH_CTRL0_CLKGATE field. */
#define BR_APBH_CTRL0_CLKGATE(x) (HW_APBH_CTRL0(x).B.CLKGATE)

/*! @brief Format value for bitfield APBH_CTRL0_CLKGATE. */
#define BF_APBH_CTRL0_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL0_CLKGATE) & BM_APBH_CTRL0_CLKGATE)

/*! @brief Set the CLKGATE field to a new value. */
#define BW_APBH_CTRL0_CLKGATE(x, v) (HW_APBH_CTRL0_WR(x, (HW_APBH_CTRL0_RD(x) & ~BM_APBH_CTRL0_CLKGATE) | BF_APBH_CTRL0_CLKGATE(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL0, field SFTRST[31] (RW)
 *
 * Set this bit to zero to enable normal APBH DMA operation. Set this bit to one
 * (default) to disable clocking with the APBH DMA and hold it in its reset
 * (lowest power) state. This bit can be turned on and then off to reset the APBH DMA
 * block to its default state.
 */
/*@{*/
#define BP_APBH_CTRL0_SFTRST (31U)         /*!< Bit position for APBH_CTRL0_SFTRST. */
#define BM_APBH_CTRL0_SFTRST (0x80000000U) /*!< Bit mask for APBH_CTRL0_SFTRST. */
#define BS_APBH_CTRL0_SFTRST (1U)          /*!< Bit field size in bits for APBH_CTRL0_SFTRST. */

/*! @brief Read current value of the APBH_CTRL0_SFTRST field. */
#define BR_APBH_CTRL0_SFTRST(x) (HW_APBH_CTRL0(x).B.SFTRST)

/*! @brief Format value for bitfield APBH_CTRL0_SFTRST. */
#define BF_APBH_CTRL0_SFTRST(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL0_SFTRST) & BM_APBH_CTRL0_SFTRST)

/*! @brief Set the SFTRST field to a new value. */
#define BW_APBH_CTRL0_SFTRST(x, v) (HW_APBH_CTRL0_WR(x, (HW_APBH_CTRL0_RD(x) & ~BM_APBH_CTRL0_SFTRST) | BF_APBH_CTRL0_SFTRST(v)))
/*@}*/




/*******************************************************************************
 * HW_APBH_CTRL1 - AHB to APBH Bridge Control and Status Register 1
 ******************************************************************************/

/*!
 * @brief HW_APBH_CTRL1 - AHB to APBH Bridge Control and Status Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The APBH CTRL one provides overall control of the interrupts generated by the
 * AHB to APBH DMA. This register contains the per channel interrupt status bits
 * and the per channel interrupt enable bits. Each channel has a dedicated
 * interrupt vector in the vectored interrupt controller. EXAMPLE BF_WR(APBH_CTRL1,
 * CH5_CMDCMPLT_IRQ, 0); // use bitfield write macro BF_APBH_CTRL1.CH5_CMDCMPLT_IRQ
 * = 0; // or, assign to register struct's bitfield
 */
typedef union _hw_apbh_ctrl1
{
    uint32_t U;
    struct _hw_apbh_ctrl1_bitfields
    {
        uint32_t CH0_CMDCMPLT_IRQ : 1; /*!< [0]  */
        uint32_t CH1_CMDCMPLT_IRQ : 1; /*!< [1]  */
        uint32_t CH2_CMDCMPLT_IRQ : 1; /*!< [2]  */
        uint32_t CH3_CMDCMPLT_IRQ : 1; /*!< [3]  */
        uint32_t CH4_CMDCMPLT_IRQ : 1; /*!< [4]  */
        uint32_t CH5_CMDCMPLT_IRQ : 1; /*!< [5]  */
        uint32_t CH6_CMDCMPLT_IRQ : 1; /*!< [6]  */
        uint32_t CH7_CMDCMPLT_IRQ : 1; /*!< [7]  */
        uint32_t CH8_CMDCMPLT_IRQ : 1; /*!< [8]  */
        uint32_t CH9_CMDCMPLT_IRQ : 1; /*!< [9]  */
        uint32_t CH10_CMDCMPLT_IRQ : 1; /*!< [10]  */
        uint32_t CH11_CMDCMPLT_IRQ : 1; /*!< [11]  */
        uint32_t CH12_CMDCMPLT_IRQ : 1; /*!< [12]  */
        uint32_t CH13_CMDCMPLT_IRQ : 1; /*!< [13]  */
        uint32_t CH14_CMDCMPLT_IRQ : 1; /*!< [14]  */
        uint32_t CH15_CMDCMPLT_IRQ : 1; /*!< [15]  */
        uint32_t CH0_CMDCMPLT_IRQ_EN : 1; /*!< [16]  */
        uint32_t CH1_CMDCMPLT_IRQ_EN : 1; /*!< [17]  */
        uint32_t CH2_CMDCMPLT_IRQ_EN : 1; /*!< [18]  */
        uint32_t CH3_CMDCMPLT_IRQ_EN : 1; /*!< [19]  */
        uint32_t CH4_CMDCMPLT_IRQ_EN : 1; /*!< [20]  */
        uint32_t CH5_CMDCMPLT_IRQ_EN : 1; /*!< [21]  */
        uint32_t CH6_CMDCMPLT_IRQ_EN : 1; /*!< [22]  */
        uint32_t CH7_CMDCMPLT_IRQ_EN : 1; /*!< [23]  */
        uint32_t CH8_CMDCMPLT_IRQ_EN : 1; /*!< [24]  */
        uint32_t CH9_CMDCMPLT_IRQ_EN : 1; /*!< [25]  */
        uint32_t CH10_CMDCMPLT_IRQ_EN : 1; /*!< [26]  */
        uint32_t CH11_CMDCMPLT_IRQ_EN : 1; /*!< [27]  */
        uint32_t CH12_CMDCMPLT_IRQ_EN : 1; /*!< [28]  */
        uint32_t CH13_CMDCMPLT_IRQ_EN : 1; /*!< [29]  */
        uint32_t CH14_CMDCMPLT_IRQ_EN : 1; /*!< [30]  */
        uint32_t CH15_CMDCMPLT_IRQ_EN : 1; /*!< [31]  */
    } B;
} hw_apbh_ctrl1_t;

/*!
 * @name Constants and macros for entire APBH_CTRL1 register
 */
/*@{*/
#define HW_APBH_CTRL1_ADDR(x)    ((uintptr_t)(x) + 0x10U)
#define HW_APBH_CTRL1_SET_ADDR(x) (HW_APBH_CTRL1_ADDR(x) + 0x4U)
#define HW_APBH_CTRL1_CLR_ADDR(x) (HW_APBH_CTRL1_ADDR(x) + 0x8U)
#define HW_APBH_CTRL1_TOG_ADDR(x) (HW_APBH_CTRL1_ADDR(x) + 0xCU)

#define HW_APBH_CTRL1(x)         (*(__IO hw_apbh_ctrl1_t *) HW_APBH_CTRL1_ADDR(x))
#define HW_APBH_CTRL1_RD(x)      (HW_APBH_CTRL1(x).U)
#define HW_APBH_CTRL1_WR(x, v)   (HW_APBH_CTRL1(x).U = (v))
#define HW_APBH_CTRL1_SET(x, v)  ((*(uint32_t *) HW_APBH_CTRL1_SET_ADDR(x)) = (v))
#define HW_APBH_CTRL1_CLR(x, v)  ((*(uint32_t *) HW_APBH_CTRL1_CLR_ADDR(x)) = (v))
#define HW_APBH_CTRL1_TOG(x, v)  ((*(uint32_t *) HW_APBH_CTRL1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual APBH_CTRL1 bitfields
 */

/*!
 * @name Register APBH_CTRL1, field CH0_CMDCMPLT_IRQ[0] (RW)
 *
 * Interrupt request status bit for APBH DMA channel 0. This sticky bit is set
 * by DMA hardware and reset by software. It is ANDed with its corresponding
 * enable bit to generate an interrupt.
 */
/*@{*/
#define BP_APBH_CTRL1_CH0_CMDCMPLT_IRQ (0U) /*!< Bit position for APBH_CTRL1_CH0_CMDCMPLT_IRQ. */
#define BM_APBH_CTRL1_CH0_CMDCMPLT_IRQ (0x00000001U) /*!< Bit mask for APBH_CTRL1_CH0_CMDCMPLT_IRQ. */
#define BS_APBH_CTRL1_CH0_CMDCMPLT_IRQ (1U) /*!< Bit field size in bits for APBH_CTRL1_CH0_CMDCMPLT_IRQ. */

/*! @brief Read current value of the APBH_CTRL1_CH0_CMDCMPLT_IRQ field. */
#define BR_APBH_CTRL1_CH0_CMDCMPLT_IRQ(x) (HW_APBH_CTRL1(x).B.CH0_CMDCMPLT_IRQ)

/*! @brief Format value for bitfield APBH_CTRL1_CH0_CMDCMPLT_IRQ. */
#define BF_APBH_CTRL1_CH0_CMDCMPLT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH0_CMDCMPLT_IRQ) & BM_APBH_CTRL1_CH0_CMDCMPLT_IRQ)

/*! @brief Set the CH0_CMDCMPLT_IRQ field to a new value. */
#define BW_APBH_CTRL1_CH0_CMDCMPLT_IRQ(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH0_CMDCMPLT_IRQ) | BF_APBH_CTRL1_CH0_CMDCMPLT_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH1_CMDCMPLT_IRQ[1] (RW)
 *
 * Interrupt request status bit for APBH DMA channel 1. This sticky bit is set
 * by DMA hardware and reset by software. It is ANDed with its corresponding
 * enable bit to generate an interrupt.
 */
/*@{*/
#define BP_APBH_CTRL1_CH1_CMDCMPLT_IRQ (1U) /*!< Bit position for APBH_CTRL1_CH1_CMDCMPLT_IRQ. */
#define BM_APBH_CTRL1_CH1_CMDCMPLT_IRQ (0x00000002U) /*!< Bit mask for APBH_CTRL1_CH1_CMDCMPLT_IRQ. */
#define BS_APBH_CTRL1_CH1_CMDCMPLT_IRQ (1U) /*!< Bit field size in bits for APBH_CTRL1_CH1_CMDCMPLT_IRQ. */

/*! @brief Read current value of the APBH_CTRL1_CH1_CMDCMPLT_IRQ field. */
#define BR_APBH_CTRL1_CH1_CMDCMPLT_IRQ(x) (HW_APBH_CTRL1(x).B.CH1_CMDCMPLT_IRQ)

/*! @brief Format value for bitfield APBH_CTRL1_CH1_CMDCMPLT_IRQ. */
#define BF_APBH_CTRL1_CH1_CMDCMPLT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH1_CMDCMPLT_IRQ) & BM_APBH_CTRL1_CH1_CMDCMPLT_IRQ)

/*! @brief Set the CH1_CMDCMPLT_IRQ field to a new value. */
#define BW_APBH_CTRL1_CH1_CMDCMPLT_IRQ(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH1_CMDCMPLT_IRQ) | BF_APBH_CTRL1_CH1_CMDCMPLT_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH2_CMDCMPLT_IRQ[2] (RW)
 *
 * Interrupt request status bit for APBH DMA channel 2. This sticky bit is set
 * by DMA hardware and reset by software. It is ANDed with its corresponding
 * enable bit to generate an interrupt.
 */
/*@{*/
#define BP_APBH_CTRL1_CH2_CMDCMPLT_IRQ (2U) /*!< Bit position for APBH_CTRL1_CH2_CMDCMPLT_IRQ. */
#define BM_APBH_CTRL1_CH2_CMDCMPLT_IRQ (0x00000004U) /*!< Bit mask for APBH_CTRL1_CH2_CMDCMPLT_IRQ. */
#define BS_APBH_CTRL1_CH2_CMDCMPLT_IRQ (1U) /*!< Bit field size in bits for APBH_CTRL1_CH2_CMDCMPLT_IRQ. */

/*! @brief Read current value of the APBH_CTRL1_CH2_CMDCMPLT_IRQ field. */
#define BR_APBH_CTRL1_CH2_CMDCMPLT_IRQ(x) (HW_APBH_CTRL1(x).B.CH2_CMDCMPLT_IRQ)

/*! @brief Format value for bitfield APBH_CTRL1_CH2_CMDCMPLT_IRQ. */
#define BF_APBH_CTRL1_CH2_CMDCMPLT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH2_CMDCMPLT_IRQ) & BM_APBH_CTRL1_CH2_CMDCMPLT_IRQ)

/*! @brief Set the CH2_CMDCMPLT_IRQ field to a new value. */
#define BW_APBH_CTRL1_CH2_CMDCMPLT_IRQ(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH2_CMDCMPLT_IRQ) | BF_APBH_CTRL1_CH2_CMDCMPLT_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH3_CMDCMPLT_IRQ[3] (RW)
 *
 * Interrupt request status bit for APBH DMA channel 3. This sticky bit is set
 * by DMA hardware and reset by software. It is ANDed with its corresponding
 * enable bit to generate an interrupt.
 */
/*@{*/
#define BP_APBH_CTRL1_CH3_CMDCMPLT_IRQ (3U) /*!< Bit position for APBH_CTRL1_CH3_CMDCMPLT_IRQ. */
#define BM_APBH_CTRL1_CH3_CMDCMPLT_IRQ (0x00000008U) /*!< Bit mask for APBH_CTRL1_CH3_CMDCMPLT_IRQ. */
#define BS_APBH_CTRL1_CH3_CMDCMPLT_IRQ (1U) /*!< Bit field size in bits for APBH_CTRL1_CH3_CMDCMPLT_IRQ. */

/*! @brief Read current value of the APBH_CTRL1_CH3_CMDCMPLT_IRQ field. */
#define BR_APBH_CTRL1_CH3_CMDCMPLT_IRQ(x) (HW_APBH_CTRL1(x).B.CH3_CMDCMPLT_IRQ)

/*! @brief Format value for bitfield APBH_CTRL1_CH3_CMDCMPLT_IRQ. */
#define BF_APBH_CTRL1_CH3_CMDCMPLT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH3_CMDCMPLT_IRQ) & BM_APBH_CTRL1_CH3_CMDCMPLT_IRQ)

/*! @brief Set the CH3_CMDCMPLT_IRQ field to a new value. */
#define BW_APBH_CTRL1_CH3_CMDCMPLT_IRQ(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH3_CMDCMPLT_IRQ) | BF_APBH_CTRL1_CH3_CMDCMPLT_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH4_CMDCMPLT_IRQ[4] (RW)
 *
 * Interrupt request status bit for APBH DMA channel 4. This sticky bit is set
 * by DMA hardware and reset by software. It is ANDed with its corresponding
 * enable bit to generate an interrupt.
 */
/*@{*/
#define BP_APBH_CTRL1_CH4_CMDCMPLT_IRQ (4U) /*!< Bit position for APBH_CTRL1_CH4_CMDCMPLT_IRQ. */
#define BM_APBH_CTRL1_CH4_CMDCMPLT_IRQ (0x00000010U) /*!< Bit mask for APBH_CTRL1_CH4_CMDCMPLT_IRQ. */
#define BS_APBH_CTRL1_CH4_CMDCMPLT_IRQ (1U) /*!< Bit field size in bits for APBH_CTRL1_CH4_CMDCMPLT_IRQ. */

/*! @brief Read current value of the APBH_CTRL1_CH4_CMDCMPLT_IRQ field. */
#define BR_APBH_CTRL1_CH4_CMDCMPLT_IRQ(x) (HW_APBH_CTRL1(x).B.CH4_CMDCMPLT_IRQ)

/*! @brief Format value for bitfield APBH_CTRL1_CH4_CMDCMPLT_IRQ. */
#define BF_APBH_CTRL1_CH4_CMDCMPLT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH4_CMDCMPLT_IRQ) & BM_APBH_CTRL1_CH4_CMDCMPLT_IRQ)

/*! @brief Set the CH4_CMDCMPLT_IRQ field to a new value. */
#define BW_APBH_CTRL1_CH4_CMDCMPLT_IRQ(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH4_CMDCMPLT_IRQ) | BF_APBH_CTRL1_CH4_CMDCMPLT_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH5_CMDCMPLT_IRQ[5] (RW)
 *
 * Interrupt request status bit for APBH DMA channel 5. This sticky bit is set
 * by DMA hardware and reset by software. It is ANDed with its corresponding
 * enable bit to generate an interrupt.
 */
/*@{*/
#define BP_APBH_CTRL1_CH5_CMDCMPLT_IRQ (5U) /*!< Bit position for APBH_CTRL1_CH5_CMDCMPLT_IRQ. */
#define BM_APBH_CTRL1_CH5_CMDCMPLT_IRQ (0x00000020U) /*!< Bit mask for APBH_CTRL1_CH5_CMDCMPLT_IRQ. */
#define BS_APBH_CTRL1_CH5_CMDCMPLT_IRQ (1U) /*!< Bit field size in bits for APBH_CTRL1_CH5_CMDCMPLT_IRQ. */

/*! @brief Read current value of the APBH_CTRL1_CH5_CMDCMPLT_IRQ field. */
#define BR_APBH_CTRL1_CH5_CMDCMPLT_IRQ(x) (HW_APBH_CTRL1(x).B.CH5_CMDCMPLT_IRQ)

/*! @brief Format value for bitfield APBH_CTRL1_CH5_CMDCMPLT_IRQ. */
#define BF_APBH_CTRL1_CH5_CMDCMPLT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH5_CMDCMPLT_IRQ) & BM_APBH_CTRL1_CH5_CMDCMPLT_IRQ)

/*! @brief Set the CH5_CMDCMPLT_IRQ field to a new value. */
#define BW_APBH_CTRL1_CH5_CMDCMPLT_IRQ(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH5_CMDCMPLT_IRQ) | BF_APBH_CTRL1_CH5_CMDCMPLT_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH6_CMDCMPLT_IRQ[6] (RW)
 *
 * Interrupt request status bit for APBH DMA channel 6. This sticky bit is set
 * by DMA hardware and reset by software. It is ANDed with its corresponding
 * enable bit to generate an interrupt.
 */
/*@{*/
#define BP_APBH_CTRL1_CH6_CMDCMPLT_IRQ (6U) /*!< Bit position for APBH_CTRL1_CH6_CMDCMPLT_IRQ. */
#define BM_APBH_CTRL1_CH6_CMDCMPLT_IRQ (0x00000040U) /*!< Bit mask for APBH_CTRL1_CH6_CMDCMPLT_IRQ. */
#define BS_APBH_CTRL1_CH6_CMDCMPLT_IRQ (1U) /*!< Bit field size in bits for APBH_CTRL1_CH6_CMDCMPLT_IRQ. */

/*! @brief Read current value of the APBH_CTRL1_CH6_CMDCMPLT_IRQ field. */
#define BR_APBH_CTRL1_CH6_CMDCMPLT_IRQ(x) (HW_APBH_CTRL1(x).B.CH6_CMDCMPLT_IRQ)

/*! @brief Format value for bitfield APBH_CTRL1_CH6_CMDCMPLT_IRQ. */
#define BF_APBH_CTRL1_CH6_CMDCMPLT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH6_CMDCMPLT_IRQ) & BM_APBH_CTRL1_CH6_CMDCMPLT_IRQ)

/*! @brief Set the CH6_CMDCMPLT_IRQ field to a new value. */
#define BW_APBH_CTRL1_CH6_CMDCMPLT_IRQ(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH6_CMDCMPLT_IRQ) | BF_APBH_CTRL1_CH6_CMDCMPLT_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH7_CMDCMPLT_IRQ[7] (RW)
 *
 * Interrupt request status bit for APBH DMA channel 7. This sticky bit is set
 * by DMA hardware and reset by software. It is ANDed with its corresponding
 * enable bit to generate an interrupt.
 */
/*@{*/
#define BP_APBH_CTRL1_CH7_CMDCMPLT_IRQ (7U) /*!< Bit position for APBH_CTRL1_CH7_CMDCMPLT_IRQ. */
#define BM_APBH_CTRL1_CH7_CMDCMPLT_IRQ (0x00000080U) /*!< Bit mask for APBH_CTRL1_CH7_CMDCMPLT_IRQ. */
#define BS_APBH_CTRL1_CH7_CMDCMPLT_IRQ (1U) /*!< Bit field size in bits for APBH_CTRL1_CH7_CMDCMPLT_IRQ. */

/*! @brief Read current value of the APBH_CTRL1_CH7_CMDCMPLT_IRQ field. */
#define BR_APBH_CTRL1_CH7_CMDCMPLT_IRQ(x) (HW_APBH_CTRL1(x).B.CH7_CMDCMPLT_IRQ)

/*! @brief Format value for bitfield APBH_CTRL1_CH7_CMDCMPLT_IRQ. */
#define BF_APBH_CTRL1_CH7_CMDCMPLT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH7_CMDCMPLT_IRQ) & BM_APBH_CTRL1_CH7_CMDCMPLT_IRQ)

/*! @brief Set the CH7_CMDCMPLT_IRQ field to a new value. */
#define BW_APBH_CTRL1_CH7_CMDCMPLT_IRQ(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH7_CMDCMPLT_IRQ) | BF_APBH_CTRL1_CH7_CMDCMPLT_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH8_CMDCMPLT_IRQ[8] (RW)
 *
 * Interrupt request status bit for APBH DMA Channel 8. This sticky bit is set
 * by DMA hardware and reset by software. It is ANDed with its corresponding
 * enable bit to generate an interrupt.
 */
/*@{*/
#define BP_APBH_CTRL1_CH8_CMDCMPLT_IRQ (8U) /*!< Bit position for APBH_CTRL1_CH8_CMDCMPLT_IRQ. */
#define BM_APBH_CTRL1_CH8_CMDCMPLT_IRQ (0x00000100U) /*!< Bit mask for APBH_CTRL1_CH8_CMDCMPLT_IRQ. */
#define BS_APBH_CTRL1_CH8_CMDCMPLT_IRQ (1U) /*!< Bit field size in bits for APBH_CTRL1_CH8_CMDCMPLT_IRQ. */

/*! @brief Read current value of the APBH_CTRL1_CH8_CMDCMPLT_IRQ field. */
#define BR_APBH_CTRL1_CH8_CMDCMPLT_IRQ(x) (HW_APBH_CTRL1(x).B.CH8_CMDCMPLT_IRQ)

/*! @brief Format value for bitfield APBH_CTRL1_CH8_CMDCMPLT_IRQ. */
#define BF_APBH_CTRL1_CH8_CMDCMPLT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH8_CMDCMPLT_IRQ) & BM_APBH_CTRL1_CH8_CMDCMPLT_IRQ)

/*! @brief Set the CH8_CMDCMPLT_IRQ field to a new value. */
#define BW_APBH_CTRL1_CH8_CMDCMPLT_IRQ(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH8_CMDCMPLT_IRQ) | BF_APBH_CTRL1_CH8_CMDCMPLT_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH9_CMDCMPLT_IRQ[9] (RW)
 *
 * Interrupt request status bit for APBH DMA Channel 9. This sticky bit is set
 * by DMA hardware and reset by software. It is ANDed with its corresponding
 * enable bit to generate an interrupt.
 */
/*@{*/
#define BP_APBH_CTRL1_CH9_CMDCMPLT_IRQ (9U) /*!< Bit position for APBH_CTRL1_CH9_CMDCMPLT_IRQ. */
#define BM_APBH_CTRL1_CH9_CMDCMPLT_IRQ (0x00000200U) /*!< Bit mask for APBH_CTRL1_CH9_CMDCMPLT_IRQ. */
#define BS_APBH_CTRL1_CH9_CMDCMPLT_IRQ (1U) /*!< Bit field size in bits for APBH_CTRL1_CH9_CMDCMPLT_IRQ. */

/*! @brief Read current value of the APBH_CTRL1_CH9_CMDCMPLT_IRQ field. */
#define BR_APBH_CTRL1_CH9_CMDCMPLT_IRQ(x) (HW_APBH_CTRL1(x).B.CH9_CMDCMPLT_IRQ)

/*! @brief Format value for bitfield APBH_CTRL1_CH9_CMDCMPLT_IRQ. */
#define BF_APBH_CTRL1_CH9_CMDCMPLT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH9_CMDCMPLT_IRQ) & BM_APBH_CTRL1_CH9_CMDCMPLT_IRQ)

/*! @brief Set the CH9_CMDCMPLT_IRQ field to a new value. */
#define BW_APBH_CTRL1_CH9_CMDCMPLT_IRQ(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH9_CMDCMPLT_IRQ) | BF_APBH_CTRL1_CH9_CMDCMPLT_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH10_CMDCMPLT_IRQ[10] (RW)
 *
 * Interrupt request status bit for APBH DMA Channel 10. This sticky bit is set
 * by DMA hardware and reset by software. It is ANDed with its corresponding
 * enable bit to generate an interrupt.
 */
/*@{*/
#define BP_APBH_CTRL1_CH10_CMDCMPLT_IRQ (10U) /*!< Bit position for APBH_CTRL1_CH10_CMDCMPLT_IRQ. */
#define BM_APBH_CTRL1_CH10_CMDCMPLT_IRQ (0x00000400U) /*!< Bit mask for APBH_CTRL1_CH10_CMDCMPLT_IRQ. */
#define BS_APBH_CTRL1_CH10_CMDCMPLT_IRQ (1U) /*!< Bit field size in bits for APBH_CTRL1_CH10_CMDCMPLT_IRQ. */

/*! @brief Read current value of the APBH_CTRL1_CH10_CMDCMPLT_IRQ field. */
#define BR_APBH_CTRL1_CH10_CMDCMPLT_IRQ(x) (HW_APBH_CTRL1(x).B.CH10_CMDCMPLT_IRQ)

/*! @brief Format value for bitfield APBH_CTRL1_CH10_CMDCMPLT_IRQ. */
#define BF_APBH_CTRL1_CH10_CMDCMPLT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH10_CMDCMPLT_IRQ) & BM_APBH_CTRL1_CH10_CMDCMPLT_IRQ)

/*! @brief Set the CH10_CMDCMPLT_IRQ field to a new value. */
#define BW_APBH_CTRL1_CH10_CMDCMPLT_IRQ(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH10_CMDCMPLT_IRQ) | BF_APBH_CTRL1_CH10_CMDCMPLT_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH11_CMDCMPLT_IRQ[11] (RW)
 *
 * Interrupt request status bit for APBH DMA Channel 11. This sticky bit is set
 * by DMA hardware and reset by software. It is ANDed with its corresponding
 * enable bit to generate an interrupt.
 */
/*@{*/
#define BP_APBH_CTRL1_CH11_CMDCMPLT_IRQ (11U) /*!< Bit position for APBH_CTRL1_CH11_CMDCMPLT_IRQ. */
#define BM_APBH_CTRL1_CH11_CMDCMPLT_IRQ (0x00000800U) /*!< Bit mask for APBH_CTRL1_CH11_CMDCMPLT_IRQ. */
#define BS_APBH_CTRL1_CH11_CMDCMPLT_IRQ (1U) /*!< Bit field size in bits for APBH_CTRL1_CH11_CMDCMPLT_IRQ. */

/*! @brief Read current value of the APBH_CTRL1_CH11_CMDCMPLT_IRQ field. */
#define BR_APBH_CTRL1_CH11_CMDCMPLT_IRQ(x) (HW_APBH_CTRL1(x).B.CH11_CMDCMPLT_IRQ)

/*! @brief Format value for bitfield APBH_CTRL1_CH11_CMDCMPLT_IRQ. */
#define BF_APBH_CTRL1_CH11_CMDCMPLT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH11_CMDCMPLT_IRQ) & BM_APBH_CTRL1_CH11_CMDCMPLT_IRQ)

/*! @brief Set the CH11_CMDCMPLT_IRQ field to a new value. */
#define BW_APBH_CTRL1_CH11_CMDCMPLT_IRQ(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH11_CMDCMPLT_IRQ) | BF_APBH_CTRL1_CH11_CMDCMPLT_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH12_CMDCMPLT_IRQ[12] (RW)
 *
 * Interrupt request status bit for APBH DMA Channel 12. This sticky bit is set
 * by DMA hardware and reset by software. It is ANDed with its corresponding
 * enable bit to generate an interrupt.
 */
/*@{*/
#define BP_APBH_CTRL1_CH12_CMDCMPLT_IRQ (12U) /*!< Bit position for APBH_CTRL1_CH12_CMDCMPLT_IRQ. */
#define BM_APBH_CTRL1_CH12_CMDCMPLT_IRQ (0x00001000U) /*!< Bit mask for APBH_CTRL1_CH12_CMDCMPLT_IRQ. */
#define BS_APBH_CTRL1_CH12_CMDCMPLT_IRQ (1U) /*!< Bit field size in bits for APBH_CTRL1_CH12_CMDCMPLT_IRQ. */

/*! @brief Read current value of the APBH_CTRL1_CH12_CMDCMPLT_IRQ field. */
#define BR_APBH_CTRL1_CH12_CMDCMPLT_IRQ(x) (HW_APBH_CTRL1(x).B.CH12_CMDCMPLT_IRQ)

/*! @brief Format value for bitfield APBH_CTRL1_CH12_CMDCMPLT_IRQ. */
#define BF_APBH_CTRL1_CH12_CMDCMPLT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH12_CMDCMPLT_IRQ) & BM_APBH_CTRL1_CH12_CMDCMPLT_IRQ)

/*! @brief Set the CH12_CMDCMPLT_IRQ field to a new value. */
#define BW_APBH_CTRL1_CH12_CMDCMPLT_IRQ(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH12_CMDCMPLT_IRQ) | BF_APBH_CTRL1_CH12_CMDCMPLT_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH13_CMDCMPLT_IRQ[13] (RW)
 *
 * Interrupt request status bit for APBH DMA Channel 13. This sticky bit is set
 * by DMA hardware and reset by software. It is ANDed with its corresponding
 * enable bit to generate an interrupt.
 */
/*@{*/
#define BP_APBH_CTRL1_CH13_CMDCMPLT_IRQ (13U) /*!< Bit position for APBH_CTRL1_CH13_CMDCMPLT_IRQ. */
#define BM_APBH_CTRL1_CH13_CMDCMPLT_IRQ (0x00002000U) /*!< Bit mask for APBH_CTRL1_CH13_CMDCMPLT_IRQ. */
#define BS_APBH_CTRL1_CH13_CMDCMPLT_IRQ (1U) /*!< Bit field size in bits for APBH_CTRL1_CH13_CMDCMPLT_IRQ. */

/*! @brief Read current value of the APBH_CTRL1_CH13_CMDCMPLT_IRQ field. */
#define BR_APBH_CTRL1_CH13_CMDCMPLT_IRQ(x) (HW_APBH_CTRL1(x).B.CH13_CMDCMPLT_IRQ)

/*! @brief Format value for bitfield APBH_CTRL1_CH13_CMDCMPLT_IRQ. */
#define BF_APBH_CTRL1_CH13_CMDCMPLT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH13_CMDCMPLT_IRQ) & BM_APBH_CTRL1_CH13_CMDCMPLT_IRQ)

/*! @brief Set the CH13_CMDCMPLT_IRQ field to a new value. */
#define BW_APBH_CTRL1_CH13_CMDCMPLT_IRQ(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH13_CMDCMPLT_IRQ) | BF_APBH_CTRL1_CH13_CMDCMPLT_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH14_CMDCMPLT_IRQ[14] (RW)
 *
 * Interrupt request status bit for APBH DMA Channel 14. This sticky bit is set
 * by DMA hardware and reset by software. It is ANDed with its corresponding
 * enable bit to generate an interrupt.
 */
/*@{*/
#define BP_APBH_CTRL1_CH14_CMDCMPLT_IRQ (14U) /*!< Bit position for APBH_CTRL1_CH14_CMDCMPLT_IRQ. */
#define BM_APBH_CTRL1_CH14_CMDCMPLT_IRQ (0x00004000U) /*!< Bit mask for APBH_CTRL1_CH14_CMDCMPLT_IRQ. */
#define BS_APBH_CTRL1_CH14_CMDCMPLT_IRQ (1U) /*!< Bit field size in bits for APBH_CTRL1_CH14_CMDCMPLT_IRQ. */

/*! @brief Read current value of the APBH_CTRL1_CH14_CMDCMPLT_IRQ field. */
#define BR_APBH_CTRL1_CH14_CMDCMPLT_IRQ(x) (HW_APBH_CTRL1(x).B.CH14_CMDCMPLT_IRQ)

/*! @brief Format value for bitfield APBH_CTRL1_CH14_CMDCMPLT_IRQ. */
#define BF_APBH_CTRL1_CH14_CMDCMPLT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH14_CMDCMPLT_IRQ) & BM_APBH_CTRL1_CH14_CMDCMPLT_IRQ)

/*! @brief Set the CH14_CMDCMPLT_IRQ field to a new value. */
#define BW_APBH_CTRL1_CH14_CMDCMPLT_IRQ(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH14_CMDCMPLT_IRQ) | BF_APBH_CTRL1_CH14_CMDCMPLT_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH15_CMDCMPLT_IRQ[15] (RW)
 *
 * Interrupt request status bit for APBH DMA Channel 15. This sticky bit is set
 * by DMA hardware and reset by software. It is ANDed with its corresponding
 * enable bit to generate an interrupt.
 */
/*@{*/
#define BP_APBH_CTRL1_CH15_CMDCMPLT_IRQ (15U) /*!< Bit position for APBH_CTRL1_CH15_CMDCMPLT_IRQ. */
#define BM_APBH_CTRL1_CH15_CMDCMPLT_IRQ (0x00008000U) /*!< Bit mask for APBH_CTRL1_CH15_CMDCMPLT_IRQ. */
#define BS_APBH_CTRL1_CH15_CMDCMPLT_IRQ (1U) /*!< Bit field size in bits for APBH_CTRL1_CH15_CMDCMPLT_IRQ. */

/*! @brief Read current value of the APBH_CTRL1_CH15_CMDCMPLT_IRQ field. */
#define BR_APBH_CTRL1_CH15_CMDCMPLT_IRQ(x) (HW_APBH_CTRL1(x).B.CH15_CMDCMPLT_IRQ)

/*! @brief Format value for bitfield APBH_CTRL1_CH15_CMDCMPLT_IRQ. */
#define BF_APBH_CTRL1_CH15_CMDCMPLT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH15_CMDCMPLT_IRQ) & BM_APBH_CTRL1_CH15_CMDCMPLT_IRQ)

/*! @brief Set the CH15_CMDCMPLT_IRQ field to a new value. */
#define BW_APBH_CTRL1_CH15_CMDCMPLT_IRQ(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH15_CMDCMPLT_IRQ) | BF_APBH_CTRL1_CH15_CMDCMPLT_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH0_CMDCMPLT_IRQ_EN[16] (RW)
 *
 * Setting this bit enables the generation of an interrupt request for APBH DMA
 * channel 0.
 */
/*@{*/
#define BP_APBH_CTRL1_CH0_CMDCMPLT_IRQ_EN (16U) /*!< Bit position for APBH_CTRL1_CH0_CMDCMPLT_IRQ_EN. */
#define BM_APBH_CTRL1_CH0_CMDCMPLT_IRQ_EN (0x00010000U) /*!< Bit mask for APBH_CTRL1_CH0_CMDCMPLT_IRQ_EN. */
#define BS_APBH_CTRL1_CH0_CMDCMPLT_IRQ_EN (1U) /*!< Bit field size in bits for APBH_CTRL1_CH0_CMDCMPLT_IRQ_EN. */

/*! @brief Read current value of the APBH_CTRL1_CH0_CMDCMPLT_IRQ_EN field. */
#define BR_APBH_CTRL1_CH0_CMDCMPLT_IRQ_EN(x) (HW_APBH_CTRL1(x).B.CH0_CMDCMPLT_IRQ_EN)

/*! @brief Format value for bitfield APBH_CTRL1_CH0_CMDCMPLT_IRQ_EN. */
#define BF_APBH_CTRL1_CH0_CMDCMPLT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH0_CMDCMPLT_IRQ_EN) & BM_APBH_CTRL1_CH0_CMDCMPLT_IRQ_EN)

/*! @brief Set the CH0_CMDCMPLT_IRQ_EN field to a new value. */
#define BW_APBH_CTRL1_CH0_CMDCMPLT_IRQ_EN(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH0_CMDCMPLT_IRQ_EN) | BF_APBH_CTRL1_CH0_CMDCMPLT_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH1_CMDCMPLT_IRQ_EN[17] (RW)
 *
 * Setting this bit enables the generation of an interrupt request for APBH DMA
 * channel 1.
 */
/*@{*/
#define BP_APBH_CTRL1_CH1_CMDCMPLT_IRQ_EN (17U) /*!< Bit position for APBH_CTRL1_CH1_CMDCMPLT_IRQ_EN. */
#define BM_APBH_CTRL1_CH1_CMDCMPLT_IRQ_EN (0x00020000U) /*!< Bit mask for APBH_CTRL1_CH1_CMDCMPLT_IRQ_EN. */
#define BS_APBH_CTRL1_CH1_CMDCMPLT_IRQ_EN (1U) /*!< Bit field size in bits for APBH_CTRL1_CH1_CMDCMPLT_IRQ_EN. */

/*! @brief Read current value of the APBH_CTRL1_CH1_CMDCMPLT_IRQ_EN field. */
#define BR_APBH_CTRL1_CH1_CMDCMPLT_IRQ_EN(x) (HW_APBH_CTRL1(x).B.CH1_CMDCMPLT_IRQ_EN)

/*! @brief Format value for bitfield APBH_CTRL1_CH1_CMDCMPLT_IRQ_EN. */
#define BF_APBH_CTRL1_CH1_CMDCMPLT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH1_CMDCMPLT_IRQ_EN) & BM_APBH_CTRL1_CH1_CMDCMPLT_IRQ_EN)

/*! @brief Set the CH1_CMDCMPLT_IRQ_EN field to a new value. */
#define BW_APBH_CTRL1_CH1_CMDCMPLT_IRQ_EN(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH1_CMDCMPLT_IRQ_EN) | BF_APBH_CTRL1_CH1_CMDCMPLT_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH2_CMDCMPLT_IRQ_EN[18] (RW)
 *
 * Setting this bit enables the generation of an interrupt request for APBH DMA
 * channel 2.
 */
/*@{*/
#define BP_APBH_CTRL1_CH2_CMDCMPLT_IRQ_EN (18U) /*!< Bit position for APBH_CTRL1_CH2_CMDCMPLT_IRQ_EN. */
#define BM_APBH_CTRL1_CH2_CMDCMPLT_IRQ_EN (0x00040000U) /*!< Bit mask for APBH_CTRL1_CH2_CMDCMPLT_IRQ_EN. */
#define BS_APBH_CTRL1_CH2_CMDCMPLT_IRQ_EN (1U) /*!< Bit field size in bits for APBH_CTRL1_CH2_CMDCMPLT_IRQ_EN. */

/*! @brief Read current value of the APBH_CTRL1_CH2_CMDCMPLT_IRQ_EN field. */
#define BR_APBH_CTRL1_CH2_CMDCMPLT_IRQ_EN(x) (HW_APBH_CTRL1(x).B.CH2_CMDCMPLT_IRQ_EN)

/*! @brief Format value for bitfield APBH_CTRL1_CH2_CMDCMPLT_IRQ_EN. */
#define BF_APBH_CTRL1_CH2_CMDCMPLT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH2_CMDCMPLT_IRQ_EN) & BM_APBH_CTRL1_CH2_CMDCMPLT_IRQ_EN)

/*! @brief Set the CH2_CMDCMPLT_IRQ_EN field to a new value. */
#define BW_APBH_CTRL1_CH2_CMDCMPLT_IRQ_EN(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH2_CMDCMPLT_IRQ_EN) | BF_APBH_CTRL1_CH2_CMDCMPLT_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH3_CMDCMPLT_IRQ_EN[19] (RW)
 *
 * Setting this bit enables the generation of an interrupt request for APBH DMA
 * channel 3.
 */
/*@{*/
#define BP_APBH_CTRL1_CH3_CMDCMPLT_IRQ_EN (19U) /*!< Bit position for APBH_CTRL1_CH3_CMDCMPLT_IRQ_EN. */
#define BM_APBH_CTRL1_CH3_CMDCMPLT_IRQ_EN (0x00080000U) /*!< Bit mask for APBH_CTRL1_CH3_CMDCMPLT_IRQ_EN. */
#define BS_APBH_CTRL1_CH3_CMDCMPLT_IRQ_EN (1U) /*!< Bit field size in bits for APBH_CTRL1_CH3_CMDCMPLT_IRQ_EN. */

/*! @brief Read current value of the APBH_CTRL1_CH3_CMDCMPLT_IRQ_EN field. */
#define BR_APBH_CTRL1_CH3_CMDCMPLT_IRQ_EN(x) (HW_APBH_CTRL1(x).B.CH3_CMDCMPLT_IRQ_EN)

/*! @brief Format value for bitfield APBH_CTRL1_CH3_CMDCMPLT_IRQ_EN. */
#define BF_APBH_CTRL1_CH3_CMDCMPLT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH3_CMDCMPLT_IRQ_EN) & BM_APBH_CTRL1_CH3_CMDCMPLT_IRQ_EN)

/*! @brief Set the CH3_CMDCMPLT_IRQ_EN field to a new value. */
#define BW_APBH_CTRL1_CH3_CMDCMPLT_IRQ_EN(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH3_CMDCMPLT_IRQ_EN) | BF_APBH_CTRL1_CH3_CMDCMPLT_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH4_CMDCMPLT_IRQ_EN[20] (RW)
 *
 * Setting this bit enables the generation of an interrupt request for APBH DMA
 * channel 4.
 */
/*@{*/
#define BP_APBH_CTRL1_CH4_CMDCMPLT_IRQ_EN (20U) /*!< Bit position for APBH_CTRL1_CH4_CMDCMPLT_IRQ_EN. */
#define BM_APBH_CTRL1_CH4_CMDCMPLT_IRQ_EN (0x00100000U) /*!< Bit mask for APBH_CTRL1_CH4_CMDCMPLT_IRQ_EN. */
#define BS_APBH_CTRL1_CH4_CMDCMPLT_IRQ_EN (1U) /*!< Bit field size in bits for APBH_CTRL1_CH4_CMDCMPLT_IRQ_EN. */

/*! @brief Read current value of the APBH_CTRL1_CH4_CMDCMPLT_IRQ_EN field. */
#define BR_APBH_CTRL1_CH4_CMDCMPLT_IRQ_EN(x) (HW_APBH_CTRL1(x).B.CH4_CMDCMPLT_IRQ_EN)

/*! @brief Format value for bitfield APBH_CTRL1_CH4_CMDCMPLT_IRQ_EN. */
#define BF_APBH_CTRL1_CH4_CMDCMPLT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH4_CMDCMPLT_IRQ_EN) & BM_APBH_CTRL1_CH4_CMDCMPLT_IRQ_EN)

/*! @brief Set the CH4_CMDCMPLT_IRQ_EN field to a new value. */
#define BW_APBH_CTRL1_CH4_CMDCMPLT_IRQ_EN(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH4_CMDCMPLT_IRQ_EN) | BF_APBH_CTRL1_CH4_CMDCMPLT_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH5_CMDCMPLT_IRQ_EN[21] (RW)
 *
 * Setting this bit enables the generation of an interrupt request for APBH DMA
 * channel 5.
 */
/*@{*/
#define BP_APBH_CTRL1_CH5_CMDCMPLT_IRQ_EN (21U) /*!< Bit position for APBH_CTRL1_CH5_CMDCMPLT_IRQ_EN. */
#define BM_APBH_CTRL1_CH5_CMDCMPLT_IRQ_EN (0x00200000U) /*!< Bit mask for APBH_CTRL1_CH5_CMDCMPLT_IRQ_EN. */
#define BS_APBH_CTRL1_CH5_CMDCMPLT_IRQ_EN (1U) /*!< Bit field size in bits for APBH_CTRL1_CH5_CMDCMPLT_IRQ_EN. */

/*! @brief Read current value of the APBH_CTRL1_CH5_CMDCMPLT_IRQ_EN field. */
#define BR_APBH_CTRL1_CH5_CMDCMPLT_IRQ_EN(x) (HW_APBH_CTRL1(x).B.CH5_CMDCMPLT_IRQ_EN)

/*! @brief Format value for bitfield APBH_CTRL1_CH5_CMDCMPLT_IRQ_EN. */
#define BF_APBH_CTRL1_CH5_CMDCMPLT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH5_CMDCMPLT_IRQ_EN) & BM_APBH_CTRL1_CH5_CMDCMPLT_IRQ_EN)

/*! @brief Set the CH5_CMDCMPLT_IRQ_EN field to a new value. */
#define BW_APBH_CTRL1_CH5_CMDCMPLT_IRQ_EN(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH5_CMDCMPLT_IRQ_EN) | BF_APBH_CTRL1_CH5_CMDCMPLT_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH6_CMDCMPLT_IRQ_EN[22] (RW)
 *
 * Setting this bit enables the generation of an interrupt request for APBH DMA
 * channel 6.
 */
/*@{*/
#define BP_APBH_CTRL1_CH6_CMDCMPLT_IRQ_EN (22U) /*!< Bit position for APBH_CTRL1_CH6_CMDCMPLT_IRQ_EN. */
#define BM_APBH_CTRL1_CH6_CMDCMPLT_IRQ_EN (0x00400000U) /*!< Bit mask for APBH_CTRL1_CH6_CMDCMPLT_IRQ_EN. */
#define BS_APBH_CTRL1_CH6_CMDCMPLT_IRQ_EN (1U) /*!< Bit field size in bits for APBH_CTRL1_CH6_CMDCMPLT_IRQ_EN. */

/*! @brief Read current value of the APBH_CTRL1_CH6_CMDCMPLT_IRQ_EN field. */
#define BR_APBH_CTRL1_CH6_CMDCMPLT_IRQ_EN(x) (HW_APBH_CTRL1(x).B.CH6_CMDCMPLT_IRQ_EN)

/*! @brief Format value for bitfield APBH_CTRL1_CH6_CMDCMPLT_IRQ_EN. */
#define BF_APBH_CTRL1_CH6_CMDCMPLT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH6_CMDCMPLT_IRQ_EN) & BM_APBH_CTRL1_CH6_CMDCMPLT_IRQ_EN)

/*! @brief Set the CH6_CMDCMPLT_IRQ_EN field to a new value. */
#define BW_APBH_CTRL1_CH6_CMDCMPLT_IRQ_EN(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH6_CMDCMPLT_IRQ_EN) | BF_APBH_CTRL1_CH6_CMDCMPLT_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH7_CMDCMPLT_IRQ_EN[23] (RW)
 *
 * Setting this bit enables the generation of an interrupt request for APBH DMA
 * channel 7.
 */
/*@{*/
#define BP_APBH_CTRL1_CH7_CMDCMPLT_IRQ_EN (23U) /*!< Bit position for APBH_CTRL1_CH7_CMDCMPLT_IRQ_EN. */
#define BM_APBH_CTRL1_CH7_CMDCMPLT_IRQ_EN (0x00800000U) /*!< Bit mask for APBH_CTRL1_CH7_CMDCMPLT_IRQ_EN. */
#define BS_APBH_CTRL1_CH7_CMDCMPLT_IRQ_EN (1U) /*!< Bit field size in bits for APBH_CTRL1_CH7_CMDCMPLT_IRQ_EN. */

/*! @brief Read current value of the APBH_CTRL1_CH7_CMDCMPLT_IRQ_EN field. */
#define BR_APBH_CTRL1_CH7_CMDCMPLT_IRQ_EN(x) (HW_APBH_CTRL1(x).B.CH7_CMDCMPLT_IRQ_EN)

/*! @brief Format value for bitfield APBH_CTRL1_CH7_CMDCMPLT_IRQ_EN. */
#define BF_APBH_CTRL1_CH7_CMDCMPLT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH7_CMDCMPLT_IRQ_EN) & BM_APBH_CTRL1_CH7_CMDCMPLT_IRQ_EN)

/*! @brief Set the CH7_CMDCMPLT_IRQ_EN field to a new value. */
#define BW_APBH_CTRL1_CH7_CMDCMPLT_IRQ_EN(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH7_CMDCMPLT_IRQ_EN) | BF_APBH_CTRL1_CH7_CMDCMPLT_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH8_CMDCMPLT_IRQ_EN[24] (RW)
 *
 * Setting this bit enables the generation of an interrupt request for APBH DMA
 * channel 8.
 */
/*@{*/
#define BP_APBH_CTRL1_CH8_CMDCMPLT_IRQ_EN (24U) /*!< Bit position for APBH_CTRL1_CH8_CMDCMPLT_IRQ_EN. */
#define BM_APBH_CTRL1_CH8_CMDCMPLT_IRQ_EN (0x01000000U) /*!< Bit mask for APBH_CTRL1_CH8_CMDCMPLT_IRQ_EN. */
#define BS_APBH_CTRL1_CH8_CMDCMPLT_IRQ_EN (1U) /*!< Bit field size in bits for APBH_CTRL1_CH8_CMDCMPLT_IRQ_EN. */

/*! @brief Read current value of the APBH_CTRL1_CH8_CMDCMPLT_IRQ_EN field. */
#define BR_APBH_CTRL1_CH8_CMDCMPLT_IRQ_EN(x) (HW_APBH_CTRL1(x).B.CH8_CMDCMPLT_IRQ_EN)

/*! @brief Format value for bitfield APBH_CTRL1_CH8_CMDCMPLT_IRQ_EN. */
#define BF_APBH_CTRL1_CH8_CMDCMPLT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH8_CMDCMPLT_IRQ_EN) & BM_APBH_CTRL1_CH8_CMDCMPLT_IRQ_EN)

/*! @brief Set the CH8_CMDCMPLT_IRQ_EN field to a new value. */
#define BW_APBH_CTRL1_CH8_CMDCMPLT_IRQ_EN(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH8_CMDCMPLT_IRQ_EN) | BF_APBH_CTRL1_CH8_CMDCMPLT_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH9_CMDCMPLT_IRQ_EN[25] (RW)
 *
 * Setting this bit enables the generation of an interrupt request for APBH DMA
 * channel 9.
 */
/*@{*/
#define BP_APBH_CTRL1_CH9_CMDCMPLT_IRQ_EN (25U) /*!< Bit position for APBH_CTRL1_CH9_CMDCMPLT_IRQ_EN. */
#define BM_APBH_CTRL1_CH9_CMDCMPLT_IRQ_EN (0x02000000U) /*!< Bit mask for APBH_CTRL1_CH9_CMDCMPLT_IRQ_EN. */
#define BS_APBH_CTRL1_CH9_CMDCMPLT_IRQ_EN (1U) /*!< Bit field size in bits for APBH_CTRL1_CH9_CMDCMPLT_IRQ_EN. */

/*! @brief Read current value of the APBH_CTRL1_CH9_CMDCMPLT_IRQ_EN field. */
#define BR_APBH_CTRL1_CH9_CMDCMPLT_IRQ_EN(x) (HW_APBH_CTRL1(x).B.CH9_CMDCMPLT_IRQ_EN)

/*! @brief Format value for bitfield APBH_CTRL1_CH9_CMDCMPLT_IRQ_EN. */
#define BF_APBH_CTRL1_CH9_CMDCMPLT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH9_CMDCMPLT_IRQ_EN) & BM_APBH_CTRL1_CH9_CMDCMPLT_IRQ_EN)

/*! @brief Set the CH9_CMDCMPLT_IRQ_EN field to a new value. */
#define BW_APBH_CTRL1_CH9_CMDCMPLT_IRQ_EN(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH9_CMDCMPLT_IRQ_EN) | BF_APBH_CTRL1_CH9_CMDCMPLT_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH10_CMDCMPLT_IRQ_EN[26] (RW)
 *
 * Setting this bit enables the generation of an interrupt request for APBH DMA
 * channel 10.
 */
/*@{*/
#define BP_APBH_CTRL1_CH10_CMDCMPLT_IRQ_EN (26U) /*!< Bit position for APBH_CTRL1_CH10_CMDCMPLT_IRQ_EN. */
#define BM_APBH_CTRL1_CH10_CMDCMPLT_IRQ_EN (0x04000000U) /*!< Bit mask for APBH_CTRL1_CH10_CMDCMPLT_IRQ_EN. */
#define BS_APBH_CTRL1_CH10_CMDCMPLT_IRQ_EN (1U) /*!< Bit field size in bits for APBH_CTRL1_CH10_CMDCMPLT_IRQ_EN. */

/*! @brief Read current value of the APBH_CTRL1_CH10_CMDCMPLT_IRQ_EN field. */
#define BR_APBH_CTRL1_CH10_CMDCMPLT_IRQ_EN(x) (HW_APBH_CTRL1(x).B.CH10_CMDCMPLT_IRQ_EN)

/*! @brief Format value for bitfield APBH_CTRL1_CH10_CMDCMPLT_IRQ_EN. */
#define BF_APBH_CTRL1_CH10_CMDCMPLT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH10_CMDCMPLT_IRQ_EN) & BM_APBH_CTRL1_CH10_CMDCMPLT_IRQ_EN)

/*! @brief Set the CH10_CMDCMPLT_IRQ_EN field to a new value. */
#define BW_APBH_CTRL1_CH10_CMDCMPLT_IRQ_EN(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH10_CMDCMPLT_IRQ_EN) | BF_APBH_CTRL1_CH10_CMDCMPLT_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH11_CMDCMPLT_IRQ_EN[27] (RW)
 *
 * Setting this bit enables the generation of an interrupt request for APBH DMA
 * channel 11.
 */
/*@{*/
#define BP_APBH_CTRL1_CH11_CMDCMPLT_IRQ_EN (27U) /*!< Bit position for APBH_CTRL1_CH11_CMDCMPLT_IRQ_EN. */
#define BM_APBH_CTRL1_CH11_CMDCMPLT_IRQ_EN (0x08000000U) /*!< Bit mask for APBH_CTRL1_CH11_CMDCMPLT_IRQ_EN. */
#define BS_APBH_CTRL1_CH11_CMDCMPLT_IRQ_EN (1U) /*!< Bit field size in bits for APBH_CTRL1_CH11_CMDCMPLT_IRQ_EN. */

/*! @brief Read current value of the APBH_CTRL1_CH11_CMDCMPLT_IRQ_EN field. */
#define BR_APBH_CTRL1_CH11_CMDCMPLT_IRQ_EN(x) (HW_APBH_CTRL1(x).B.CH11_CMDCMPLT_IRQ_EN)

/*! @brief Format value for bitfield APBH_CTRL1_CH11_CMDCMPLT_IRQ_EN. */
#define BF_APBH_CTRL1_CH11_CMDCMPLT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH11_CMDCMPLT_IRQ_EN) & BM_APBH_CTRL1_CH11_CMDCMPLT_IRQ_EN)

/*! @brief Set the CH11_CMDCMPLT_IRQ_EN field to a new value. */
#define BW_APBH_CTRL1_CH11_CMDCMPLT_IRQ_EN(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH11_CMDCMPLT_IRQ_EN) | BF_APBH_CTRL1_CH11_CMDCMPLT_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH12_CMDCMPLT_IRQ_EN[28] (RW)
 *
 * Setting this bit enables the generation of an interrupt request for APBH DMA
 * channel 12.
 */
/*@{*/
#define BP_APBH_CTRL1_CH12_CMDCMPLT_IRQ_EN (28U) /*!< Bit position for APBH_CTRL1_CH12_CMDCMPLT_IRQ_EN. */
#define BM_APBH_CTRL1_CH12_CMDCMPLT_IRQ_EN (0x10000000U) /*!< Bit mask for APBH_CTRL1_CH12_CMDCMPLT_IRQ_EN. */
#define BS_APBH_CTRL1_CH12_CMDCMPLT_IRQ_EN (1U) /*!< Bit field size in bits for APBH_CTRL1_CH12_CMDCMPLT_IRQ_EN. */

/*! @brief Read current value of the APBH_CTRL1_CH12_CMDCMPLT_IRQ_EN field. */
#define BR_APBH_CTRL1_CH12_CMDCMPLT_IRQ_EN(x) (HW_APBH_CTRL1(x).B.CH12_CMDCMPLT_IRQ_EN)

/*! @brief Format value for bitfield APBH_CTRL1_CH12_CMDCMPLT_IRQ_EN. */
#define BF_APBH_CTRL1_CH12_CMDCMPLT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH12_CMDCMPLT_IRQ_EN) & BM_APBH_CTRL1_CH12_CMDCMPLT_IRQ_EN)

/*! @brief Set the CH12_CMDCMPLT_IRQ_EN field to a new value. */
#define BW_APBH_CTRL1_CH12_CMDCMPLT_IRQ_EN(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH12_CMDCMPLT_IRQ_EN) | BF_APBH_CTRL1_CH12_CMDCMPLT_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH13_CMDCMPLT_IRQ_EN[29] (RW)
 *
 * Setting this bit enables the generation of an interrupt request for APBH DMA
 * channel 13.
 */
/*@{*/
#define BP_APBH_CTRL1_CH13_CMDCMPLT_IRQ_EN (29U) /*!< Bit position for APBH_CTRL1_CH13_CMDCMPLT_IRQ_EN. */
#define BM_APBH_CTRL1_CH13_CMDCMPLT_IRQ_EN (0x20000000U) /*!< Bit mask for APBH_CTRL1_CH13_CMDCMPLT_IRQ_EN. */
#define BS_APBH_CTRL1_CH13_CMDCMPLT_IRQ_EN (1U) /*!< Bit field size in bits for APBH_CTRL1_CH13_CMDCMPLT_IRQ_EN. */

/*! @brief Read current value of the APBH_CTRL1_CH13_CMDCMPLT_IRQ_EN field. */
#define BR_APBH_CTRL1_CH13_CMDCMPLT_IRQ_EN(x) (HW_APBH_CTRL1(x).B.CH13_CMDCMPLT_IRQ_EN)

/*! @brief Format value for bitfield APBH_CTRL1_CH13_CMDCMPLT_IRQ_EN. */
#define BF_APBH_CTRL1_CH13_CMDCMPLT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH13_CMDCMPLT_IRQ_EN) & BM_APBH_CTRL1_CH13_CMDCMPLT_IRQ_EN)

/*! @brief Set the CH13_CMDCMPLT_IRQ_EN field to a new value. */
#define BW_APBH_CTRL1_CH13_CMDCMPLT_IRQ_EN(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH13_CMDCMPLT_IRQ_EN) | BF_APBH_CTRL1_CH13_CMDCMPLT_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH14_CMDCMPLT_IRQ_EN[30] (RW)
 *
 * Setting this bit enables the generation of an interrupt request for APBH DMA
 * channel 14.
 */
/*@{*/
#define BP_APBH_CTRL1_CH14_CMDCMPLT_IRQ_EN (30U) /*!< Bit position for APBH_CTRL1_CH14_CMDCMPLT_IRQ_EN. */
#define BM_APBH_CTRL1_CH14_CMDCMPLT_IRQ_EN (0x40000000U) /*!< Bit mask for APBH_CTRL1_CH14_CMDCMPLT_IRQ_EN. */
#define BS_APBH_CTRL1_CH14_CMDCMPLT_IRQ_EN (1U) /*!< Bit field size in bits for APBH_CTRL1_CH14_CMDCMPLT_IRQ_EN. */

/*! @brief Read current value of the APBH_CTRL1_CH14_CMDCMPLT_IRQ_EN field. */
#define BR_APBH_CTRL1_CH14_CMDCMPLT_IRQ_EN(x) (HW_APBH_CTRL1(x).B.CH14_CMDCMPLT_IRQ_EN)

/*! @brief Format value for bitfield APBH_CTRL1_CH14_CMDCMPLT_IRQ_EN. */
#define BF_APBH_CTRL1_CH14_CMDCMPLT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH14_CMDCMPLT_IRQ_EN) & BM_APBH_CTRL1_CH14_CMDCMPLT_IRQ_EN)

/*! @brief Set the CH14_CMDCMPLT_IRQ_EN field to a new value. */
#define BW_APBH_CTRL1_CH14_CMDCMPLT_IRQ_EN(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH14_CMDCMPLT_IRQ_EN) | BF_APBH_CTRL1_CH14_CMDCMPLT_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL1, field CH15_CMDCMPLT_IRQ_EN[31] (RW)
 *
 * Setting this bit enables the generation of an interrupt request for APBH DMA
 * channel 15.
 */
/*@{*/
#define BP_APBH_CTRL1_CH15_CMDCMPLT_IRQ_EN (31U) /*!< Bit position for APBH_CTRL1_CH15_CMDCMPLT_IRQ_EN. */
#define BM_APBH_CTRL1_CH15_CMDCMPLT_IRQ_EN (0x80000000U) /*!< Bit mask for APBH_CTRL1_CH15_CMDCMPLT_IRQ_EN. */
#define BS_APBH_CTRL1_CH15_CMDCMPLT_IRQ_EN (1U) /*!< Bit field size in bits for APBH_CTRL1_CH15_CMDCMPLT_IRQ_EN. */

/*! @brief Read current value of the APBH_CTRL1_CH15_CMDCMPLT_IRQ_EN field. */
#define BR_APBH_CTRL1_CH15_CMDCMPLT_IRQ_EN(x) (HW_APBH_CTRL1(x).B.CH15_CMDCMPLT_IRQ_EN)

/*! @brief Format value for bitfield APBH_CTRL1_CH15_CMDCMPLT_IRQ_EN. */
#define BF_APBH_CTRL1_CH15_CMDCMPLT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL1_CH15_CMDCMPLT_IRQ_EN) & BM_APBH_CTRL1_CH15_CMDCMPLT_IRQ_EN)

/*! @brief Set the CH15_CMDCMPLT_IRQ_EN field to a new value. */
#define BW_APBH_CTRL1_CH15_CMDCMPLT_IRQ_EN(x, v) (HW_APBH_CTRL1_WR(x, (HW_APBH_CTRL1_RD(x) & ~BM_APBH_CTRL1_CH15_CMDCMPLT_IRQ_EN) | BF_APBH_CTRL1_CH15_CMDCMPLT_IRQ_EN(v)))
/*@}*/




/*******************************************************************************
 * HW_APBH_CTRL2 - AHB to APBH Bridge Control and Status Register 2
 ******************************************************************************/

/*!
 * @brief HW_APBH_CTRL2 - AHB to APBH Bridge Control and Status Register 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The APBH CTRL 2 provides channel error interrupts generated by the AHB to
 * APBH DMA. This register contains the per channel interrupt status bits and the
 * per channel interrupt enable bits. Each channel has a dedicated interrupt vector
 * in the vectored interrupt controller. EXAMPLE BF_WR(APBH_CTRL1,
 * CH5_CMDCMPLT_IRQ, 0); // use bitfield write macro BF_APBH_CTRL1.CH5_CMDCMPLT_IRQ = 0; //
 * or, assign to register struct's bitfield
 */
typedef union _hw_apbh_ctrl2
{
    uint32_t U;
    struct _hw_apbh_ctrl2_bitfields
    {
        uint32_t CH0_ERROR_IRQ : 1;    /*!< [0]  */
        uint32_t CH1_ERROR_IRQ : 1;    /*!< [1]  */
        uint32_t CH2_ERROR_IRQ : 1;    /*!< [2]  */
        uint32_t CH3_ERROR_IRQ : 1;    /*!< [3]  */
        uint32_t CH4_ERROR_IRQ : 1;    /*!< [4]  */
        uint32_t CH5_ERROR_IRQ : 1;    /*!< [5]  */
        uint32_t CH6_ERROR_IRQ : 1;    /*!< [6]  */
        uint32_t CH7_ERROR_IRQ : 1;    /*!< [7]  */
        uint32_t CH8_ERROR_IRQ : 1;    /*!< [8]  */
        uint32_t CH9_ERROR_IRQ : 1;    /*!< [9]  */
        uint32_t CH10_ERROR_IRQ : 1;   /*!< [10]  */
        uint32_t CH11_ERROR_IRQ : 1;   /*!< [11]  */
        uint32_t CH12_ERROR_IRQ : 1;   /*!< [12]  */
        uint32_t CH13_ERROR_IRQ : 1;   /*!< [13]  */
        uint32_t CH14_ERROR_IRQ : 1;   /*!< [14]  */
        uint32_t CH15_ERROR_IRQ : 1;   /*!< [15]  */
        uint32_t CH0_ERROR_STATUS : 1; /*!< [16]  */
        uint32_t CH1_ERROR_STATUS : 1; /*!< [17]  */
        uint32_t CH2_ERROR_STATUS : 1; /*!< [18]  */
        uint32_t CH3_ERROR_STATUS : 1; /*!< [19]  */
        uint32_t CH4_ERROR_STATUS : 1; /*!< [20]  */
        uint32_t CH5_ERROR_STATUS : 1; /*!< [21]  */
        uint32_t CH6_ERROR_STATUS : 1; /*!< [22]  */
        uint32_t CH7_ERROR_STATUS : 1; /*!< [23]  */
        uint32_t CH8_ERROR_STATUS : 1; /*!< [24]  */
        uint32_t CH9_ERROR_STATUS : 1; /*!< [25]  */
        uint32_t CH10_ERROR_STATUS : 1; /*!< [26]  */
        uint32_t CH11_ERROR_STATUS : 1; /*!< [27]  */
        uint32_t CH12_ERROR_STATUS : 1; /*!< [28]  */
        uint32_t CH13_ERROR_STATUS : 1; /*!< [29]  */
        uint32_t CH14_ERROR_STATUS : 1; /*!< [30]  */
        uint32_t CH15_ERROR_STATUS : 1; /*!< [31]  */
    } B;
} hw_apbh_ctrl2_t;

/*!
 * @name Constants and macros for entire APBH_CTRL2 register
 */
/*@{*/
#define HW_APBH_CTRL2_ADDR(x)    ((uintptr_t)(x) + 0x20U)
#define HW_APBH_CTRL2_SET_ADDR(x) (HW_APBH_CTRL2_ADDR(x) + 0x4U)
#define HW_APBH_CTRL2_CLR_ADDR(x) (HW_APBH_CTRL2_ADDR(x) + 0x8U)
#define HW_APBH_CTRL2_TOG_ADDR(x) (HW_APBH_CTRL2_ADDR(x) + 0xCU)

#define HW_APBH_CTRL2(x)         (*(__IO hw_apbh_ctrl2_t *) HW_APBH_CTRL2_ADDR(x))
#define HW_APBH_CTRL2_RD(x)      (HW_APBH_CTRL2(x).U)
#define HW_APBH_CTRL2_WR(x, v)   (HW_APBH_CTRL2(x).U = (v))
#define HW_APBH_CTRL2_SET(x, v)  ((*(uint32_t *) HW_APBH_CTRL2_SET_ADDR(x)) = (v))
#define HW_APBH_CTRL2_CLR(x, v)  ((*(uint32_t *) HW_APBH_CTRL2_CLR_ADDR(x)) = (v))
#define HW_APBH_CTRL2_TOG(x, v)  ((*(uint32_t *) HW_APBH_CTRL2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual APBH_CTRL2 bitfields
 */

/*!
 * @name Register APBH_CTRL2, field CH0_ERROR_IRQ[0] (RW)
 *
 * Error interrupt status bit for APBX DMA Channel 0. This sticky bit is set by
 * DMA hardware and reset by software. It is ORed with the corresponding cmdcmplt
 * irq to generate an irq to ARM.
 */
/*@{*/
#define BP_APBH_CTRL2_CH0_ERROR_IRQ (0U)   /*!< Bit position for APBH_CTRL2_CH0_ERROR_IRQ. */
#define BM_APBH_CTRL2_CH0_ERROR_IRQ (0x00000001U) /*!< Bit mask for APBH_CTRL2_CH0_ERROR_IRQ. */
#define BS_APBH_CTRL2_CH0_ERROR_IRQ (1U)   /*!< Bit field size in bits for APBH_CTRL2_CH0_ERROR_IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH0_ERROR_IRQ field. */
#define BR_APBH_CTRL2_CH0_ERROR_IRQ(x) (HW_APBH_CTRL2(x).B.CH0_ERROR_IRQ)

/*! @brief Format value for bitfield APBH_CTRL2_CH0_ERROR_IRQ. */
#define BF_APBH_CTRL2_CH0_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL2_CH0_ERROR_IRQ) & BM_APBH_CTRL2_CH0_ERROR_IRQ)

/*! @brief Set the CH0_ERROR_IRQ field to a new value. */
#define BW_APBH_CTRL2_CH0_ERROR_IRQ(x, v) (HW_APBH_CTRL2_WR(x, (HW_APBH_CTRL2_RD(x) & ~BM_APBH_CTRL2_CH0_ERROR_IRQ) | BF_APBH_CTRL2_CH0_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH1_ERROR_IRQ[1] (RW)
 *
 * Error interrupt status bit for APBX DMA Channel 1. This sticky bit is set by
 * DMA hardware and reset by software. It is ORed with the corresponding cmdcmplt
 * irq to generate an irq to ARM.
 */
/*@{*/
#define BP_APBH_CTRL2_CH1_ERROR_IRQ (1U)   /*!< Bit position for APBH_CTRL2_CH1_ERROR_IRQ. */
#define BM_APBH_CTRL2_CH1_ERROR_IRQ (0x00000002U) /*!< Bit mask for APBH_CTRL2_CH1_ERROR_IRQ. */
#define BS_APBH_CTRL2_CH1_ERROR_IRQ (1U)   /*!< Bit field size in bits for APBH_CTRL2_CH1_ERROR_IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH1_ERROR_IRQ field. */
#define BR_APBH_CTRL2_CH1_ERROR_IRQ(x) (HW_APBH_CTRL2(x).B.CH1_ERROR_IRQ)

/*! @brief Format value for bitfield APBH_CTRL2_CH1_ERROR_IRQ. */
#define BF_APBH_CTRL2_CH1_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL2_CH1_ERROR_IRQ) & BM_APBH_CTRL2_CH1_ERROR_IRQ)

/*! @brief Set the CH1_ERROR_IRQ field to a new value. */
#define BW_APBH_CTRL2_CH1_ERROR_IRQ(x, v) (HW_APBH_CTRL2_WR(x, (HW_APBH_CTRL2_RD(x) & ~BM_APBH_CTRL2_CH1_ERROR_IRQ) | BF_APBH_CTRL2_CH1_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH2_ERROR_IRQ[2] (RW)
 *
 * Error interrupt status bit for APBX DMA Channel 2. This sticky bit is set by
 * DMA hardware and reset by software. It is ORed with the corresponding cmdcmplt
 * irq to generate an irq to ARM.
 */
/*@{*/
#define BP_APBH_CTRL2_CH2_ERROR_IRQ (2U)   /*!< Bit position for APBH_CTRL2_CH2_ERROR_IRQ. */
#define BM_APBH_CTRL2_CH2_ERROR_IRQ (0x00000004U) /*!< Bit mask for APBH_CTRL2_CH2_ERROR_IRQ. */
#define BS_APBH_CTRL2_CH2_ERROR_IRQ (1U)   /*!< Bit field size in bits for APBH_CTRL2_CH2_ERROR_IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH2_ERROR_IRQ field. */
#define BR_APBH_CTRL2_CH2_ERROR_IRQ(x) (HW_APBH_CTRL2(x).B.CH2_ERROR_IRQ)

/*! @brief Format value for bitfield APBH_CTRL2_CH2_ERROR_IRQ. */
#define BF_APBH_CTRL2_CH2_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL2_CH2_ERROR_IRQ) & BM_APBH_CTRL2_CH2_ERROR_IRQ)

/*! @brief Set the CH2_ERROR_IRQ field to a new value. */
#define BW_APBH_CTRL2_CH2_ERROR_IRQ(x, v) (HW_APBH_CTRL2_WR(x, (HW_APBH_CTRL2_RD(x) & ~BM_APBH_CTRL2_CH2_ERROR_IRQ) | BF_APBH_CTRL2_CH2_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH3_ERROR_IRQ[3] (RW)
 *
 * Error interrupt status bit for APBX DMA Channel 3. This sticky bit is set by
 * DMA hardware and reset by software. It is ORed with the corresponding cmdcmplt
 * irq to generate an irq to ARM.
 */
/*@{*/
#define BP_APBH_CTRL2_CH3_ERROR_IRQ (3U)   /*!< Bit position for APBH_CTRL2_CH3_ERROR_IRQ. */
#define BM_APBH_CTRL2_CH3_ERROR_IRQ (0x00000008U) /*!< Bit mask for APBH_CTRL2_CH3_ERROR_IRQ. */
#define BS_APBH_CTRL2_CH3_ERROR_IRQ (1U)   /*!< Bit field size in bits for APBH_CTRL2_CH3_ERROR_IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH3_ERROR_IRQ field. */
#define BR_APBH_CTRL2_CH3_ERROR_IRQ(x) (HW_APBH_CTRL2(x).B.CH3_ERROR_IRQ)

/*! @brief Format value for bitfield APBH_CTRL2_CH3_ERROR_IRQ. */
#define BF_APBH_CTRL2_CH3_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL2_CH3_ERROR_IRQ) & BM_APBH_CTRL2_CH3_ERROR_IRQ)

/*! @brief Set the CH3_ERROR_IRQ field to a new value. */
#define BW_APBH_CTRL2_CH3_ERROR_IRQ(x, v) (HW_APBH_CTRL2_WR(x, (HW_APBH_CTRL2_RD(x) & ~BM_APBH_CTRL2_CH3_ERROR_IRQ) | BF_APBH_CTRL2_CH3_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH4_ERROR_IRQ[4] (RW)
 *
 * Error interrupt status bit for APBX DMA Channel 4. This sticky bit is set by
 * DMA hardware and reset by software. It is ORed with the corresponding cmdcmplt
 * irq to generate an irq to ARM.
 */
/*@{*/
#define BP_APBH_CTRL2_CH4_ERROR_IRQ (4U)   /*!< Bit position for APBH_CTRL2_CH4_ERROR_IRQ. */
#define BM_APBH_CTRL2_CH4_ERROR_IRQ (0x00000010U) /*!< Bit mask for APBH_CTRL2_CH4_ERROR_IRQ. */
#define BS_APBH_CTRL2_CH4_ERROR_IRQ (1U)   /*!< Bit field size in bits for APBH_CTRL2_CH4_ERROR_IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH4_ERROR_IRQ field. */
#define BR_APBH_CTRL2_CH4_ERROR_IRQ(x) (HW_APBH_CTRL2(x).B.CH4_ERROR_IRQ)

/*! @brief Format value for bitfield APBH_CTRL2_CH4_ERROR_IRQ. */
#define BF_APBH_CTRL2_CH4_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL2_CH4_ERROR_IRQ) & BM_APBH_CTRL2_CH4_ERROR_IRQ)

/*! @brief Set the CH4_ERROR_IRQ field to a new value. */
#define BW_APBH_CTRL2_CH4_ERROR_IRQ(x, v) (HW_APBH_CTRL2_WR(x, (HW_APBH_CTRL2_RD(x) & ~BM_APBH_CTRL2_CH4_ERROR_IRQ) | BF_APBH_CTRL2_CH4_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH5_ERROR_IRQ[5] (RW)
 *
 * Error interrupt status bit for APBX DMA Channel 5. This sticky bit is set by
 * DMA hardware and reset by software. It is ORed with the corresponding cmdcmplt
 * irq to generate an irq to ARM.
 */
/*@{*/
#define BP_APBH_CTRL2_CH5_ERROR_IRQ (5U)   /*!< Bit position for APBH_CTRL2_CH5_ERROR_IRQ. */
#define BM_APBH_CTRL2_CH5_ERROR_IRQ (0x00000020U) /*!< Bit mask for APBH_CTRL2_CH5_ERROR_IRQ. */
#define BS_APBH_CTRL2_CH5_ERROR_IRQ (1U)   /*!< Bit field size in bits for APBH_CTRL2_CH5_ERROR_IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH5_ERROR_IRQ field. */
#define BR_APBH_CTRL2_CH5_ERROR_IRQ(x) (HW_APBH_CTRL2(x).B.CH5_ERROR_IRQ)

/*! @brief Format value for bitfield APBH_CTRL2_CH5_ERROR_IRQ. */
#define BF_APBH_CTRL2_CH5_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL2_CH5_ERROR_IRQ) & BM_APBH_CTRL2_CH5_ERROR_IRQ)

/*! @brief Set the CH5_ERROR_IRQ field to a new value. */
#define BW_APBH_CTRL2_CH5_ERROR_IRQ(x, v) (HW_APBH_CTRL2_WR(x, (HW_APBH_CTRL2_RD(x) & ~BM_APBH_CTRL2_CH5_ERROR_IRQ) | BF_APBH_CTRL2_CH5_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH6_ERROR_IRQ[6] (RW)
 *
 * Error interrupt status bit for APBX DMA Channel 6. This sticky bit is set by
 * DMA hardware and reset by software. It is ORed with the corresponding cmdcmplt
 * irq to generate an irq to ARM.
 */
/*@{*/
#define BP_APBH_CTRL2_CH6_ERROR_IRQ (6U)   /*!< Bit position for APBH_CTRL2_CH6_ERROR_IRQ. */
#define BM_APBH_CTRL2_CH6_ERROR_IRQ (0x00000040U) /*!< Bit mask for APBH_CTRL2_CH6_ERROR_IRQ. */
#define BS_APBH_CTRL2_CH6_ERROR_IRQ (1U)   /*!< Bit field size in bits for APBH_CTRL2_CH6_ERROR_IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH6_ERROR_IRQ field. */
#define BR_APBH_CTRL2_CH6_ERROR_IRQ(x) (HW_APBH_CTRL2(x).B.CH6_ERROR_IRQ)

/*! @brief Format value for bitfield APBH_CTRL2_CH6_ERROR_IRQ. */
#define BF_APBH_CTRL2_CH6_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL2_CH6_ERROR_IRQ) & BM_APBH_CTRL2_CH6_ERROR_IRQ)

/*! @brief Set the CH6_ERROR_IRQ field to a new value. */
#define BW_APBH_CTRL2_CH6_ERROR_IRQ(x, v) (HW_APBH_CTRL2_WR(x, (HW_APBH_CTRL2_RD(x) & ~BM_APBH_CTRL2_CH6_ERROR_IRQ) | BF_APBH_CTRL2_CH6_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH7_ERROR_IRQ[7] (RW)
 *
 * Error interrupt status bit for APBX DMA Channel 7. This sticky bit is set by
 * DMA hardware and reset by software. It is ORed with the corresponding cmdcmplt
 * irq to generate an irq to ARM.
 */
/*@{*/
#define BP_APBH_CTRL2_CH7_ERROR_IRQ (7U)   /*!< Bit position for APBH_CTRL2_CH7_ERROR_IRQ. */
#define BM_APBH_CTRL2_CH7_ERROR_IRQ (0x00000080U) /*!< Bit mask for APBH_CTRL2_CH7_ERROR_IRQ. */
#define BS_APBH_CTRL2_CH7_ERROR_IRQ (1U)   /*!< Bit field size in bits for APBH_CTRL2_CH7_ERROR_IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH7_ERROR_IRQ field. */
#define BR_APBH_CTRL2_CH7_ERROR_IRQ(x) (HW_APBH_CTRL2(x).B.CH7_ERROR_IRQ)

/*! @brief Format value for bitfield APBH_CTRL2_CH7_ERROR_IRQ. */
#define BF_APBH_CTRL2_CH7_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL2_CH7_ERROR_IRQ) & BM_APBH_CTRL2_CH7_ERROR_IRQ)

/*! @brief Set the CH7_ERROR_IRQ field to a new value. */
#define BW_APBH_CTRL2_CH7_ERROR_IRQ(x, v) (HW_APBH_CTRL2_WR(x, (HW_APBH_CTRL2_RD(x) & ~BM_APBH_CTRL2_CH7_ERROR_IRQ) | BF_APBH_CTRL2_CH7_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH8_ERROR_IRQ[8] (RW)
 *
 * Error interrupt status bit for APBH DMA Channel 8. This sticky bit is set by
 * DMA hardware and reset by software. It is ORed with the corresponding cmdcmplt
 * irq to generate an irq to ARM.
 */
/*@{*/
#define BP_APBH_CTRL2_CH8_ERROR_IRQ (8U)   /*!< Bit position for APBH_CTRL2_CH8_ERROR_IRQ. */
#define BM_APBH_CTRL2_CH8_ERROR_IRQ (0x00000100U) /*!< Bit mask for APBH_CTRL2_CH8_ERROR_IRQ. */
#define BS_APBH_CTRL2_CH8_ERROR_IRQ (1U)   /*!< Bit field size in bits for APBH_CTRL2_CH8_ERROR_IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH8_ERROR_IRQ field. */
#define BR_APBH_CTRL2_CH8_ERROR_IRQ(x) (HW_APBH_CTRL2(x).B.CH8_ERROR_IRQ)

/*! @brief Format value for bitfield APBH_CTRL2_CH8_ERROR_IRQ. */
#define BF_APBH_CTRL2_CH8_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL2_CH8_ERROR_IRQ) & BM_APBH_CTRL2_CH8_ERROR_IRQ)

/*! @brief Set the CH8_ERROR_IRQ field to a new value. */
#define BW_APBH_CTRL2_CH8_ERROR_IRQ(x, v) (HW_APBH_CTRL2_WR(x, (HW_APBH_CTRL2_RD(x) & ~BM_APBH_CTRL2_CH8_ERROR_IRQ) | BF_APBH_CTRL2_CH8_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH9_ERROR_IRQ[9] (RW)
 *
 * Error interrupt status bit for APBH DMA Channel 9. This sticky bit is set by
 * DMA hardware and reset by software. It is ORed with the corresponding cmdcmplt
 * irq to generate an irq to ARM.
 */
/*@{*/
#define BP_APBH_CTRL2_CH9_ERROR_IRQ (9U)   /*!< Bit position for APBH_CTRL2_CH9_ERROR_IRQ. */
#define BM_APBH_CTRL2_CH9_ERROR_IRQ (0x00000200U) /*!< Bit mask for APBH_CTRL2_CH9_ERROR_IRQ. */
#define BS_APBH_CTRL2_CH9_ERROR_IRQ (1U)   /*!< Bit field size in bits for APBH_CTRL2_CH9_ERROR_IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH9_ERROR_IRQ field. */
#define BR_APBH_CTRL2_CH9_ERROR_IRQ(x) (HW_APBH_CTRL2(x).B.CH9_ERROR_IRQ)

/*! @brief Format value for bitfield APBH_CTRL2_CH9_ERROR_IRQ. */
#define BF_APBH_CTRL2_CH9_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL2_CH9_ERROR_IRQ) & BM_APBH_CTRL2_CH9_ERROR_IRQ)

/*! @brief Set the CH9_ERROR_IRQ field to a new value. */
#define BW_APBH_CTRL2_CH9_ERROR_IRQ(x, v) (HW_APBH_CTRL2_WR(x, (HW_APBH_CTRL2_RD(x) & ~BM_APBH_CTRL2_CH9_ERROR_IRQ) | BF_APBH_CTRL2_CH9_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH10_ERROR_IRQ[10] (RW)
 *
 * Error interrupt status bit for APBH DMA Channel 10. This sticky bit is set by
 * DMA hardware and reset by software. It is ORed with the corresponding
 * cmdcmplt irq to generate an irq to ARM.
 */
/*@{*/
#define BP_APBH_CTRL2_CH10_ERROR_IRQ (10U) /*!< Bit position for APBH_CTRL2_CH10_ERROR_IRQ. */
#define BM_APBH_CTRL2_CH10_ERROR_IRQ (0x00000400U) /*!< Bit mask for APBH_CTRL2_CH10_ERROR_IRQ. */
#define BS_APBH_CTRL2_CH10_ERROR_IRQ (1U)  /*!< Bit field size in bits for APBH_CTRL2_CH10_ERROR_IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH10_ERROR_IRQ field. */
#define BR_APBH_CTRL2_CH10_ERROR_IRQ(x) (HW_APBH_CTRL2(x).B.CH10_ERROR_IRQ)

/*! @brief Format value for bitfield APBH_CTRL2_CH10_ERROR_IRQ. */
#define BF_APBH_CTRL2_CH10_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL2_CH10_ERROR_IRQ) & BM_APBH_CTRL2_CH10_ERROR_IRQ)

/*! @brief Set the CH10_ERROR_IRQ field to a new value. */
#define BW_APBH_CTRL2_CH10_ERROR_IRQ(x, v) (HW_APBH_CTRL2_WR(x, (HW_APBH_CTRL2_RD(x) & ~BM_APBH_CTRL2_CH10_ERROR_IRQ) | BF_APBH_CTRL2_CH10_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH11_ERROR_IRQ[11] (RW)
 *
 * Error interrupt status bit for APBH DMA Channel 11. This sticky bit is set by
 * DMA hardware and reset by software. It is ORed with the corresponding
 * cmdcmplt irq to generate an irq to ARM.
 */
/*@{*/
#define BP_APBH_CTRL2_CH11_ERROR_IRQ (11U) /*!< Bit position for APBH_CTRL2_CH11_ERROR_IRQ. */
#define BM_APBH_CTRL2_CH11_ERROR_IRQ (0x00000800U) /*!< Bit mask for APBH_CTRL2_CH11_ERROR_IRQ. */
#define BS_APBH_CTRL2_CH11_ERROR_IRQ (1U)  /*!< Bit field size in bits for APBH_CTRL2_CH11_ERROR_IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH11_ERROR_IRQ field. */
#define BR_APBH_CTRL2_CH11_ERROR_IRQ(x) (HW_APBH_CTRL2(x).B.CH11_ERROR_IRQ)

/*! @brief Format value for bitfield APBH_CTRL2_CH11_ERROR_IRQ. */
#define BF_APBH_CTRL2_CH11_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL2_CH11_ERROR_IRQ) & BM_APBH_CTRL2_CH11_ERROR_IRQ)

/*! @brief Set the CH11_ERROR_IRQ field to a new value. */
#define BW_APBH_CTRL2_CH11_ERROR_IRQ(x, v) (HW_APBH_CTRL2_WR(x, (HW_APBH_CTRL2_RD(x) & ~BM_APBH_CTRL2_CH11_ERROR_IRQ) | BF_APBH_CTRL2_CH11_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH12_ERROR_IRQ[12] (RW)
 *
 * Error interrupt status bit for APBH DMA Channel 12. This sticky bit is set by
 * DMA hardware and reset by software. It is ORed with the corresponding
 * cmdcmplt irq to generate an irq to ARM.
 */
/*@{*/
#define BP_APBH_CTRL2_CH12_ERROR_IRQ (12U) /*!< Bit position for APBH_CTRL2_CH12_ERROR_IRQ. */
#define BM_APBH_CTRL2_CH12_ERROR_IRQ (0x00001000U) /*!< Bit mask for APBH_CTRL2_CH12_ERROR_IRQ. */
#define BS_APBH_CTRL2_CH12_ERROR_IRQ (1U)  /*!< Bit field size in bits for APBH_CTRL2_CH12_ERROR_IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH12_ERROR_IRQ field. */
#define BR_APBH_CTRL2_CH12_ERROR_IRQ(x) (HW_APBH_CTRL2(x).B.CH12_ERROR_IRQ)

/*! @brief Format value for bitfield APBH_CTRL2_CH12_ERROR_IRQ. */
#define BF_APBH_CTRL2_CH12_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL2_CH12_ERROR_IRQ) & BM_APBH_CTRL2_CH12_ERROR_IRQ)

/*! @brief Set the CH12_ERROR_IRQ field to a new value. */
#define BW_APBH_CTRL2_CH12_ERROR_IRQ(x, v) (HW_APBH_CTRL2_WR(x, (HW_APBH_CTRL2_RD(x) & ~BM_APBH_CTRL2_CH12_ERROR_IRQ) | BF_APBH_CTRL2_CH12_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH13_ERROR_IRQ[13] (RW)
 *
 * Error interrupt status bit for APBH DMA Channel 13. This sticky bit is set by
 * DMA hardware and reset by software. It is ORed with the corresponding
 * cmdcmplt irq to generate an irq to ARM.
 */
/*@{*/
#define BP_APBH_CTRL2_CH13_ERROR_IRQ (13U) /*!< Bit position for APBH_CTRL2_CH13_ERROR_IRQ. */
#define BM_APBH_CTRL2_CH13_ERROR_IRQ (0x00002000U) /*!< Bit mask for APBH_CTRL2_CH13_ERROR_IRQ. */
#define BS_APBH_CTRL2_CH13_ERROR_IRQ (1U)  /*!< Bit field size in bits for APBH_CTRL2_CH13_ERROR_IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH13_ERROR_IRQ field. */
#define BR_APBH_CTRL2_CH13_ERROR_IRQ(x) (HW_APBH_CTRL2(x).B.CH13_ERROR_IRQ)

/*! @brief Format value for bitfield APBH_CTRL2_CH13_ERROR_IRQ. */
#define BF_APBH_CTRL2_CH13_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL2_CH13_ERROR_IRQ) & BM_APBH_CTRL2_CH13_ERROR_IRQ)

/*! @brief Set the CH13_ERROR_IRQ field to a new value. */
#define BW_APBH_CTRL2_CH13_ERROR_IRQ(x, v) (HW_APBH_CTRL2_WR(x, (HW_APBH_CTRL2_RD(x) & ~BM_APBH_CTRL2_CH13_ERROR_IRQ) | BF_APBH_CTRL2_CH13_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH14_ERROR_IRQ[14] (RW)
 *
 * Error interrupt status bit for APBH DMA Channel 14. This sticky bit is set by
 * DMA hardware and reset by software. It is ORed with the corresponding
 * cmdcmplt irq to generate an irq to ARM.
 */
/*@{*/
#define BP_APBH_CTRL2_CH14_ERROR_IRQ (14U) /*!< Bit position for APBH_CTRL2_CH14_ERROR_IRQ. */
#define BM_APBH_CTRL2_CH14_ERROR_IRQ (0x00004000U) /*!< Bit mask for APBH_CTRL2_CH14_ERROR_IRQ. */
#define BS_APBH_CTRL2_CH14_ERROR_IRQ (1U)  /*!< Bit field size in bits for APBH_CTRL2_CH14_ERROR_IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH14_ERROR_IRQ field. */
#define BR_APBH_CTRL2_CH14_ERROR_IRQ(x) (HW_APBH_CTRL2(x).B.CH14_ERROR_IRQ)

/*! @brief Format value for bitfield APBH_CTRL2_CH14_ERROR_IRQ. */
#define BF_APBH_CTRL2_CH14_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL2_CH14_ERROR_IRQ) & BM_APBH_CTRL2_CH14_ERROR_IRQ)

/*! @brief Set the CH14_ERROR_IRQ field to a new value. */
#define BW_APBH_CTRL2_CH14_ERROR_IRQ(x, v) (HW_APBH_CTRL2_WR(x, (HW_APBH_CTRL2_RD(x) & ~BM_APBH_CTRL2_CH14_ERROR_IRQ) | BF_APBH_CTRL2_CH14_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH15_ERROR_IRQ[15] (RW)
 *
 * Error interrupt status bit for APBH DMA Channel 15. This sticky bit is set by
 * DMA hardware and reset by software. It is ORed with the corresponding
 * cmdcmplt irq to generate an irq to ARM.
 */
/*@{*/
#define BP_APBH_CTRL2_CH15_ERROR_IRQ (15U) /*!< Bit position for APBH_CTRL2_CH15_ERROR_IRQ. */
#define BM_APBH_CTRL2_CH15_ERROR_IRQ (0x00008000U) /*!< Bit mask for APBH_CTRL2_CH15_ERROR_IRQ. */
#define BS_APBH_CTRL2_CH15_ERROR_IRQ (1U)  /*!< Bit field size in bits for APBH_CTRL2_CH15_ERROR_IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH15_ERROR_IRQ field. */
#define BR_APBH_CTRL2_CH15_ERROR_IRQ(x) (HW_APBH_CTRL2(x).B.CH15_ERROR_IRQ)

/*! @brief Format value for bitfield APBH_CTRL2_CH15_ERROR_IRQ. */
#define BF_APBH_CTRL2_CH15_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CTRL2_CH15_ERROR_IRQ) & BM_APBH_CTRL2_CH15_ERROR_IRQ)

/*! @brief Set the CH15_ERROR_IRQ field to a new value. */
#define BW_APBH_CTRL2_CH15_ERROR_IRQ(x, v) (HW_APBH_CTRL2_WR(x, (HW_APBH_CTRL2_RD(x) & ~BM_APBH_CTRL2_CH15_ERROR_IRQ) | BF_APBH_CTRL2_CH15_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH0_ERROR_STATUS[16] (RO)
 *
 * Error status bit for APBX DMA Channel 0. Valid when corresponding Error IRQ
 * is set. 1 - AHB bus error 0 - channel early termination.
 *
 * Values:
 * - 0 - An early termination from the device causes error IRQ.
 * - 1 - An AHB bus error causes error IRQ.
 */
/*@{*/
#define BP_APBH_CTRL2_CH0_ERROR_STATUS (16U) /*!< Bit position for APBH_CTRL2_CH0_ERROR_STATUS. */
#define BM_APBH_CTRL2_CH0_ERROR_STATUS (0x00010000U) /*!< Bit mask for APBH_CTRL2_CH0_ERROR_STATUS. */
#define BS_APBH_CTRL2_CH0_ERROR_STATUS (1U) /*!< Bit field size in bits for APBH_CTRL2_CH0_ERROR_STATUS. */

#define BV_APBH_CTRL2_CH0_ERROR_STATUS_TERMINATION (0U) /*!< Bit field value for APBH_CTRL2_CH0_ERROR_STATUS: An early termination from the device causes error IRQ. */
#define BV_APBH_CTRL2_CH0_ERROR_STATUS_BUS_ERROR (0x1U) /*!< Bit field value for APBH_CTRL2_CH0_ERROR_STATUS: An AHB bus error causes error IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH0_ERROR_STATUS field. */
#define BR_APBH_CTRL2_CH0_ERROR_STATUS(x) (HW_APBH_CTRL2(x).B.CH0_ERROR_STATUS)
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH1_ERROR_STATUS[17] (RO)
 *
 * Error status bit for APBX DMA Channel 1. Valid when corresponding Error IRQ
 * is set. 1 - AHB bus error 0 - channel early termination.
 *
 * Values:
 * - 0 - An early termination from the device causes error IRQ.
 * - 1 - An AHB bus error causes error IRQ.
 */
/*@{*/
#define BP_APBH_CTRL2_CH1_ERROR_STATUS (17U) /*!< Bit position for APBH_CTRL2_CH1_ERROR_STATUS. */
#define BM_APBH_CTRL2_CH1_ERROR_STATUS (0x00020000U) /*!< Bit mask for APBH_CTRL2_CH1_ERROR_STATUS. */
#define BS_APBH_CTRL2_CH1_ERROR_STATUS (1U) /*!< Bit field size in bits for APBH_CTRL2_CH1_ERROR_STATUS. */

#define BV_APBH_CTRL2_CH1_ERROR_STATUS_TERMINATION (0U) /*!< Bit field value for APBH_CTRL2_CH1_ERROR_STATUS: An early termination from the device causes error IRQ. */
#define BV_APBH_CTRL2_CH1_ERROR_STATUS_BUS_ERROR (0x1U) /*!< Bit field value for APBH_CTRL2_CH1_ERROR_STATUS: An AHB bus error causes error IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH1_ERROR_STATUS field. */
#define BR_APBH_CTRL2_CH1_ERROR_STATUS(x) (HW_APBH_CTRL2(x).B.CH1_ERROR_STATUS)
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH2_ERROR_STATUS[18] (RO)
 *
 * Error status bit for APBX DMA Channel 2. Valid when corresponding Error IRQ
 * is set. 1 - AHB bus error 0 - channel early termination.
 *
 * Values:
 * - 0 - An early termination from the device causes error IRQ.
 * - 1 - An AHB bus error causes error IRQ.
 */
/*@{*/
#define BP_APBH_CTRL2_CH2_ERROR_STATUS (18U) /*!< Bit position for APBH_CTRL2_CH2_ERROR_STATUS. */
#define BM_APBH_CTRL2_CH2_ERROR_STATUS (0x00040000U) /*!< Bit mask for APBH_CTRL2_CH2_ERROR_STATUS. */
#define BS_APBH_CTRL2_CH2_ERROR_STATUS (1U) /*!< Bit field size in bits for APBH_CTRL2_CH2_ERROR_STATUS. */

#define BV_APBH_CTRL2_CH2_ERROR_STATUS_TERMINATION (0U) /*!< Bit field value for APBH_CTRL2_CH2_ERROR_STATUS: An early termination from the device causes error IRQ. */
#define BV_APBH_CTRL2_CH2_ERROR_STATUS_BUS_ERROR (0x1U) /*!< Bit field value for APBH_CTRL2_CH2_ERROR_STATUS: An AHB bus error causes error IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH2_ERROR_STATUS field. */
#define BR_APBH_CTRL2_CH2_ERROR_STATUS(x) (HW_APBH_CTRL2(x).B.CH2_ERROR_STATUS)
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH3_ERROR_STATUS[19] (RO)
 *
 * Error status bit for APBX DMA Channel 3. Valid when corresponding Error IRQ
 * is set. 1 - AHB bus error 0 - channel early termination.
 *
 * Values:
 * - 0 - An early termination from the device causes error IRQ.
 * - 1 - An AHB bus error causes error IRQ.
 */
/*@{*/
#define BP_APBH_CTRL2_CH3_ERROR_STATUS (19U) /*!< Bit position for APBH_CTRL2_CH3_ERROR_STATUS. */
#define BM_APBH_CTRL2_CH3_ERROR_STATUS (0x00080000U) /*!< Bit mask for APBH_CTRL2_CH3_ERROR_STATUS. */
#define BS_APBH_CTRL2_CH3_ERROR_STATUS (1U) /*!< Bit field size in bits for APBH_CTRL2_CH3_ERROR_STATUS. */

#define BV_APBH_CTRL2_CH3_ERROR_STATUS_TERMINATION (0U) /*!< Bit field value for APBH_CTRL2_CH3_ERROR_STATUS: An early termination from the device causes error IRQ. */
#define BV_APBH_CTRL2_CH3_ERROR_STATUS_BUS_ERROR (0x1U) /*!< Bit field value for APBH_CTRL2_CH3_ERROR_STATUS: An AHB bus error causes error IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH3_ERROR_STATUS field. */
#define BR_APBH_CTRL2_CH3_ERROR_STATUS(x) (HW_APBH_CTRL2(x).B.CH3_ERROR_STATUS)
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH4_ERROR_STATUS[20] (RO)
 *
 * Error status bit for APBX DMA Channel 4. Valid when corresponding Error IRQ
 * is set. 1 - AHB bus error 0 - channel early termination.
 *
 * Values:
 * - 0 - An early termination from the device causes error IRQ.
 * - 1 - An AHB bus error causes error IRQ.
 */
/*@{*/
#define BP_APBH_CTRL2_CH4_ERROR_STATUS (20U) /*!< Bit position for APBH_CTRL2_CH4_ERROR_STATUS. */
#define BM_APBH_CTRL2_CH4_ERROR_STATUS (0x00100000U) /*!< Bit mask for APBH_CTRL2_CH4_ERROR_STATUS. */
#define BS_APBH_CTRL2_CH4_ERROR_STATUS (1U) /*!< Bit field size in bits for APBH_CTRL2_CH4_ERROR_STATUS. */

#define BV_APBH_CTRL2_CH4_ERROR_STATUS_TERMINATION (0U) /*!< Bit field value for APBH_CTRL2_CH4_ERROR_STATUS: An early termination from the device causes error IRQ. */
#define BV_APBH_CTRL2_CH4_ERROR_STATUS_BUS_ERROR (0x1U) /*!< Bit field value for APBH_CTRL2_CH4_ERROR_STATUS: An AHB bus error causes error IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH4_ERROR_STATUS field. */
#define BR_APBH_CTRL2_CH4_ERROR_STATUS(x) (HW_APBH_CTRL2(x).B.CH4_ERROR_STATUS)
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH5_ERROR_STATUS[21] (RO)
 *
 * Error status bit for APBX DMA Channel 5. Valid when corresponding Error IRQ
 * is set. 1 - AHB bus error 0 - channel early termination.
 *
 * Values:
 * - 0 - An early termination from the device causes error IRQ.
 * - 1 - An AHB bus error causes error IRQ.
 */
/*@{*/
#define BP_APBH_CTRL2_CH5_ERROR_STATUS (21U) /*!< Bit position for APBH_CTRL2_CH5_ERROR_STATUS. */
#define BM_APBH_CTRL2_CH5_ERROR_STATUS (0x00200000U) /*!< Bit mask for APBH_CTRL2_CH5_ERROR_STATUS. */
#define BS_APBH_CTRL2_CH5_ERROR_STATUS (1U) /*!< Bit field size in bits for APBH_CTRL2_CH5_ERROR_STATUS. */

#define BV_APBH_CTRL2_CH5_ERROR_STATUS_TERMINATION (0U) /*!< Bit field value for APBH_CTRL2_CH5_ERROR_STATUS: An early termination from the device causes error IRQ. */
#define BV_APBH_CTRL2_CH5_ERROR_STATUS_BUS_ERROR (0x1U) /*!< Bit field value for APBH_CTRL2_CH5_ERROR_STATUS: An AHB bus error causes error IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH5_ERROR_STATUS field. */
#define BR_APBH_CTRL2_CH5_ERROR_STATUS(x) (HW_APBH_CTRL2(x).B.CH5_ERROR_STATUS)
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH6_ERROR_STATUS[22] (RO)
 *
 * Error status bit for APBX DMA Channel 6. Valid when corresponding Error IRQ
 * is set. 1 - AHB bus error 0 - channel early termination.
 *
 * Values:
 * - 0 - An early termination from the device causes error IRQ.
 * - 1 - An AHB bus error causes error IRQ.
 */
/*@{*/
#define BP_APBH_CTRL2_CH6_ERROR_STATUS (22U) /*!< Bit position for APBH_CTRL2_CH6_ERROR_STATUS. */
#define BM_APBH_CTRL2_CH6_ERROR_STATUS (0x00400000U) /*!< Bit mask for APBH_CTRL2_CH6_ERROR_STATUS. */
#define BS_APBH_CTRL2_CH6_ERROR_STATUS (1U) /*!< Bit field size in bits for APBH_CTRL2_CH6_ERROR_STATUS. */

#define BV_APBH_CTRL2_CH6_ERROR_STATUS_TERMINATION (0U) /*!< Bit field value for APBH_CTRL2_CH6_ERROR_STATUS: An early termination from the device causes error IRQ. */
#define BV_APBH_CTRL2_CH6_ERROR_STATUS_BUS_ERROR (0x1U) /*!< Bit field value for APBH_CTRL2_CH6_ERROR_STATUS: An AHB bus error causes error IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH6_ERROR_STATUS field. */
#define BR_APBH_CTRL2_CH6_ERROR_STATUS(x) (HW_APBH_CTRL2(x).B.CH6_ERROR_STATUS)
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH7_ERROR_STATUS[23] (RO)
 *
 * Error status bit for APBX DMA Channel 7. Valid when corresponding Error IRQ
 * is set. 1 - AHB bus error 0 - channel early termination.
 *
 * Values:
 * - 0 - An early termination from the device causes error IRQ.
 * - 1 - An AHB bus error causes error IRQ.
 */
/*@{*/
#define BP_APBH_CTRL2_CH7_ERROR_STATUS (23U) /*!< Bit position for APBH_CTRL2_CH7_ERROR_STATUS. */
#define BM_APBH_CTRL2_CH7_ERROR_STATUS (0x00800000U) /*!< Bit mask for APBH_CTRL2_CH7_ERROR_STATUS. */
#define BS_APBH_CTRL2_CH7_ERROR_STATUS (1U) /*!< Bit field size in bits for APBH_CTRL2_CH7_ERROR_STATUS. */

#define BV_APBH_CTRL2_CH7_ERROR_STATUS_TERMINATION (0U) /*!< Bit field value for APBH_CTRL2_CH7_ERROR_STATUS: An early termination from the device causes error IRQ. */
#define BV_APBH_CTRL2_CH7_ERROR_STATUS_BUS_ERROR (0x1U) /*!< Bit field value for APBH_CTRL2_CH7_ERROR_STATUS: An AHB bus error causes error IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH7_ERROR_STATUS field. */
#define BR_APBH_CTRL2_CH7_ERROR_STATUS(x) (HW_APBH_CTRL2(x).B.CH7_ERROR_STATUS)
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH8_ERROR_STATUS[24] (RO)
 *
 * Error status bit for APBH DMA Channel 8. Valid when corresponding Error IRQ
 * is set. 1 - AHB bus error 0 - channel early termination.
 *
 * Values:
 * - 0 - An early termination from the device causes error IRQ.
 * - 1 - An AHB bus error causes error IRQ.
 */
/*@{*/
#define BP_APBH_CTRL2_CH8_ERROR_STATUS (24U) /*!< Bit position for APBH_CTRL2_CH8_ERROR_STATUS. */
#define BM_APBH_CTRL2_CH8_ERROR_STATUS (0x01000000U) /*!< Bit mask for APBH_CTRL2_CH8_ERROR_STATUS. */
#define BS_APBH_CTRL2_CH8_ERROR_STATUS (1U) /*!< Bit field size in bits for APBH_CTRL2_CH8_ERROR_STATUS. */

#define BV_APBH_CTRL2_CH8_ERROR_STATUS_TERMINATION (0U) /*!< Bit field value for APBH_CTRL2_CH8_ERROR_STATUS: An early termination from the device causes error IRQ. */
#define BV_APBH_CTRL2_CH8_ERROR_STATUS_BUS_ERROR (0x1U) /*!< Bit field value for APBH_CTRL2_CH8_ERROR_STATUS: An AHB bus error causes error IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH8_ERROR_STATUS field. */
#define BR_APBH_CTRL2_CH8_ERROR_STATUS(x) (HW_APBH_CTRL2(x).B.CH8_ERROR_STATUS)
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH9_ERROR_STATUS[25] (RO)
 *
 * Error status bit for APBH DMA Channel 9. Valid when corresponding Error IRQ
 * is set. 1 - AHB bus error 0 - channel early termination.
 *
 * Values:
 * - 0 - An early termination from the device causes error IRQ.
 * - 1 - An AHB bus error causes error IRQ.
 */
/*@{*/
#define BP_APBH_CTRL2_CH9_ERROR_STATUS (25U) /*!< Bit position for APBH_CTRL2_CH9_ERROR_STATUS. */
#define BM_APBH_CTRL2_CH9_ERROR_STATUS (0x02000000U) /*!< Bit mask for APBH_CTRL2_CH9_ERROR_STATUS. */
#define BS_APBH_CTRL2_CH9_ERROR_STATUS (1U) /*!< Bit field size in bits for APBH_CTRL2_CH9_ERROR_STATUS. */

#define BV_APBH_CTRL2_CH9_ERROR_STATUS_TERMINATION (0U) /*!< Bit field value for APBH_CTRL2_CH9_ERROR_STATUS: An early termination from the device causes error IRQ. */
#define BV_APBH_CTRL2_CH9_ERROR_STATUS_BUS_ERROR (0x1U) /*!< Bit field value for APBH_CTRL2_CH9_ERROR_STATUS: An AHB bus error causes error IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH9_ERROR_STATUS field. */
#define BR_APBH_CTRL2_CH9_ERROR_STATUS(x) (HW_APBH_CTRL2(x).B.CH9_ERROR_STATUS)
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH10_ERROR_STATUS[26] (RO)
 *
 * Error status bit for APBH DMA Channel 10. Valid when corresponding Error IRQ
 * is set. 1 - AHB bus error 0 - channel early termination.
 *
 * Values:
 * - 0 - An early termination from the device causes error IRQ.
 * - 1 - An AHB bus error causes error IRQ.
 */
/*@{*/
#define BP_APBH_CTRL2_CH10_ERROR_STATUS (26U) /*!< Bit position for APBH_CTRL2_CH10_ERROR_STATUS. */
#define BM_APBH_CTRL2_CH10_ERROR_STATUS (0x04000000U) /*!< Bit mask for APBH_CTRL2_CH10_ERROR_STATUS. */
#define BS_APBH_CTRL2_CH10_ERROR_STATUS (1U) /*!< Bit field size in bits for APBH_CTRL2_CH10_ERROR_STATUS. */

#define BV_APBH_CTRL2_CH10_ERROR_STATUS_TERMINATION (0U) /*!< Bit field value for APBH_CTRL2_CH10_ERROR_STATUS: An early termination from the device causes error IRQ. */
#define BV_APBH_CTRL2_CH10_ERROR_STATUS_BUS_ERROR (0x1U) /*!< Bit field value for APBH_CTRL2_CH10_ERROR_STATUS: An AHB bus error causes error IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH10_ERROR_STATUS field. */
#define BR_APBH_CTRL2_CH10_ERROR_STATUS(x) (HW_APBH_CTRL2(x).B.CH10_ERROR_STATUS)
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH11_ERROR_STATUS[27] (RO)
 *
 * Error status bit for APBH DMA Channel 11. Valid when corresponding Error IRQ
 * is set. 1 - AHB bus error 0 - channel early termination.
 *
 * Values:
 * - 0 - An early termination from the device causes error IRQ.
 * - 1 - An AHB bus error causes error IRQ.
 */
/*@{*/
#define BP_APBH_CTRL2_CH11_ERROR_STATUS (27U) /*!< Bit position for APBH_CTRL2_CH11_ERROR_STATUS. */
#define BM_APBH_CTRL2_CH11_ERROR_STATUS (0x08000000U) /*!< Bit mask for APBH_CTRL2_CH11_ERROR_STATUS. */
#define BS_APBH_CTRL2_CH11_ERROR_STATUS (1U) /*!< Bit field size in bits for APBH_CTRL2_CH11_ERROR_STATUS. */

#define BV_APBH_CTRL2_CH11_ERROR_STATUS_TERMINATION (0U) /*!< Bit field value for APBH_CTRL2_CH11_ERROR_STATUS: An early termination from the device causes error IRQ. */
#define BV_APBH_CTRL2_CH11_ERROR_STATUS_BUS_ERROR (0x1U) /*!< Bit field value for APBH_CTRL2_CH11_ERROR_STATUS: An AHB bus error causes error IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH11_ERROR_STATUS field. */
#define BR_APBH_CTRL2_CH11_ERROR_STATUS(x) (HW_APBH_CTRL2(x).B.CH11_ERROR_STATUS)
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH12_ERROR_STATUS[28] (RO)
 *
 * Error status bit for APBH DMA Channel 12. Valid when corresponding Error IRQ
 * is set. 1 - AHB bus error 0 - channel early termination.
 *
 * Values:
 * - 0 - An early termination from the device causes error IRQ.
 * - 1 - An AHB bus error causes error IRQ.
 */
/*@{*/
#define BP_APBH_CTRL2_CH12_ERROR_STATUS (28U) /*!< Bit position for APBH_CTRL2_CH12_ERROR_STATUS. */
#define BM_APBH_CTRL2_CH12_ERROR_STATUS (0x10000000U) /*!< Bit mask for APBH_CTRL2_CH12_ERROR_STATUS. */
#define BS_APBH_CTRL2_CH12_ERROR_STATUS (1U) /*!< Bit field size in bits for APBH_CTRL2_CH12_ERROR_STATUS. */

#define BV_APBH_CTRL2_CH12_ERROR_STATUS_TERMINATION (0U) /*!< Bit field value for APBH_CTRL2_CH12_ERROR_STATUS: An early termination from the device causes error IRQ. */
#define BV_APBH_CTRL2_CH12_ERROR_STATUS_BUS_ERROR (0x1U) /*!< Bit field value for APBH_CTRL2_CH12_ERROR_STATUS: An AHB bus error causes error IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH12_ERROR_STATUS field. */
#define BR_APBH_CTRL2_CH12_ERROR_STATUS(x) (HW_APBH_CTRL2(x).B.CH12_ERROR_STATUS)
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH13_ERROR_STATUS[29] (RO)
 *
 * Error status bit for APBH DMA Channel 13. Valid when corresponding Error IRQ
 * is set. 1 - AHB bus error 0 - channel early termination.
 *
 * Values:
 * - 0 - An early termination from the device causes error IRQ.
 * - 1 - An AHB bus error causes error IRQ.
 */
/*@{*/
#define BP_APBH_CTRL2_CH13_ERROR_STATUS (29U) /*!< Bit position for APBH_CTRL2_CH13_ERROR_STATUS. */
#define BM_APBH_CTRL2_CH13_ERROR_STATUS (0x20000000U) /*!< Bit mask for APBH_CTRL2_CH13_ERROR_STATUS. */
#define BS_APBH_CTRL2_CH13_ERROR_STATUS (1U) /*!< Bit field size in bits for APBH_CTRL2_CH13_ERROR_STATUS. */

#define BV_APBH_CTRL2_CH13_ERROR_STATUS_TERMINATION (0U) /*!< Bit field value for APBH_CTRL2_CH13_ERROR_STATUS: An early termination from the device causes error IRQ. */
#define BV_APBH_CTRL2_CH13_ERROR_STATUS_BUS_ERROR (0x1U) /*!< Bit field value for APBH_CTRL2_CH13_ERROR_STATUS: An AHB bus error causes error IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH13_ERROR_STATUS field. */
#define BR_APBH_CTRL2_CH13_ERROR_STATUS(x) (HW_APBH_CTRL2(x).B.CH13_ERROR_STATUS)
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH14_ERROR_STATUS[30] (RO)
 *
 * Error status bit for APBH DMA Channel 14. Valid when corresponding Error IRQ
 * is set. 1 - AHB bus error 0 - channel early termination.
 *
 * Values:
 * - 0 - An early termination from the device causes error IRQ.
 * - 1 - An AHB bus error causes error IRQ.
 */
/*@{*/
#define BP_APBH_CTRL2_CH14_ERROR_STATUS (30U) /*!< Bit position for APBH_CTRL2_CH14_ERROR_STATUS. */
#define BM_APBH_CTRL2_CH14_ERROR_STATUS (0x40000000U) /*!< Bit mask for APBH_CTRL2_CH14_ERROR_STATUS. */
#define BS_APBH_CTRL2_CH14_ERROR_STATUS (1U) /*!< Bit field size in bits for APBH_CTRL2_CH14_ERROR_STATUS. */

#define BV_APBH_CTRL2_CH14_ERROR_STATUS_TERMINATION (0U) /*!< Bit field value for APBH_CTRL2_CH14_ERROR_STATUS: An early termination from the device causes error IRQ. */
#define BV_APBH_CTRL2_CH14_ERROR_STATUS_BUS_ERROR (0x1U) /*!< Bit field value for APBH_CTRL2_CH14_ERROR_STATUS: An AHB bus error causes error IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH14_ERROR_STATUS field. */
#define BR_APBH_CTRL2_CH14_ERROR_STATUS(x) (HW_APBH_CTRL2(x).B.CH14_ERROR_STATUS)
/*@}*/

/*!
 * @name Register APBH_CTRL2, field CH15_ERROR_STATUS[31] (RO)
 *
 * Error status bit for APBH DMA Channel 15. Valid when corresponding Error IRQ
 * is set. 1 - AHB bus error 0 - channel early termination.
 *
 * Values:
 * - 0 - An early termination from the device causes error IRQ.
 * - 1 - An AHB bus error causes error IRQ.
 */
/*@{*/
#define BP_APBH_CTRL2_CH15_ERROR_STATUS (31U) /*!< Bit position for APBH_CTRL2_CH15_ERROR_STATUS. */
#define BM_APBH_CTRL2_CH15_ERROR_STATUS (0x80000000U) /*!< Bit mask for APBH_CTRL2_CH15_ERROR_STATUS. */
#define BS_APBH_CTRL2_CH15_ERROR_STATUS (1U) /*!< Bit field size in bits for APBH_CTRL2_CH15_ERROR_STATUS. */

#define BV_APBH_CTRL2_CH15_ERROR_STATUS_TERMINATION (0U) /*!< Bit field value for APBH_CTRL2_CH15_ERROR_STATUS: An early termination from the device causes error IRQ. */
#define BV_APBH_CTRL2_CH15_ERROR_STATUS_BUS_ERROR (0x1U) /*!< Bit field value for APBH_CTRL2_CH15_ERROR_STATUS: An AHB bus error causes error IRQ. */

/*! @brief Read current value of the APBH_CTRL2_CH15_ERROR_STATUS field. */
#define BR_APBH_CTRL2_CH15_ERROR_STATUS(x) (HW_APBH_CTRL2(x).B.CH15_ERROR_STATUS)
/*@}*/




/*******************************************************************************
 * HW_APBH_CHANNEL_CTRL - AHB to APBH Bridge Channel Register
 ******************************************************************************/

/*!
 * @brief HW_APBH_CHANNEL_CTRL - AHB to APBH Bridge Channel Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The APBH CHANNEL CTRL provides reset/freeze control of each DMA channel. This
 * register contains individual channel reset/freeze bits.
 */
typedef union _hw_apbh_channel_ctrl
{
    uint32_t U;
    struct _hw_apbh_channel_ctrl_bitfields
    {
        uint32_t FREEZE_CHANNEL : 16;  /*!< [15:0]  */
        uint32_t RESET_CHANNEL : 16;   /*!< [31:16]  */
    } B;
} hw_apbh_channel_ctrl_t;

/*!
 * @name Constants and macros for entire APBH_CHANNEL_CTRL register
 */
/*@{*/
#define HW_APBH_CHANNEL_CTRL_ADDR(x) ((uintptr_t)(x) + 0x30U)
#define HW_APBH_CHANNEL_CTRL_SET_ADDR(x) (HW_APBH_CHANNEL_CTRL_ADDR(x) + 0x4U)
#define HW_APBH_CHANNEL_CTRL_CLR_ADDR(x) (HW_APBH_CHANNEL_CTRL_ADDR(x) + 0x8U)
#define HW_APBH_CHANNEL_CTRL_TOG_ADDR(x) (HW_APBH_CHANNEL_CTRL_ADDR(x) + 0xCU)

#define HW_APBH_CHANNEL_CTRL(x)  (*(__IO hw_apbh_channel_ctrl_t *) HW_APBH_CHANNEL_CTRL_ADDR(x))
#define HW_APBH_CHANNEL_CTRL_RD(x) (HW_APBH_CHANNEL_CTRL(x).U)
#define HW_APBH_CHANNEL_CTRL_WR(x, v) (HW_APBH_CHANNEL_CTRL(x).U = (v))
#define HW_APBH_CHANNEL_CTRL_SET(x, v) ((*(uint32_t *) HW_APBH_CHANNEL_CTRL_SET_ADDR(x)) = (v))
#define HW_APBH_CHANNEL_CTRL_CLR(x, v) ((*(uint32_t *) HW_APBH_CHANNEL_CTRL_CLR_ADDR(x)) = (v))
#define HW_APBH_CHANNEL_CTRL_TOG(x, v) ((*(uint32_t *) HW_APBH_CHANNEL_CTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual APBH_CHANNEL_CTRL bitfields
 */

/*!
 * @name Register APBH_CHANNEL_CTRL, field FREEZE_CHANNEL[15:0] (RW)
 *
 * Setting a bit in this field will freeze the DMA channel associated with it.
 * This field is a direct input to the DMA channel arbiter. When frozen, the
 * channel is deined access to the central DMA resources.
 *
 * Values:
 * - 1 -
 * - 10 -
 * - 100 -
 * - 1000 -
 * - 10000 -
 * - 100000 -
 * - 1000000 -
 * - 10000000 -
 * - 100000000 -
 */
/*@{*/
#define BP_APBH_CHANNEL_CTRL_FREEZE_CHANNEL (0U) /*!< Bit position for APBH_CHANNEL_CTRL_FREEZE_CHANNEL. */
#define BM_APBH_CHANNEL_CTRL_FREEZE_CHANNEL (0x0000FFFFU) /*!< Bit mask for APBH_CHANNEL_CTRL_FREEZE_CHANNEL. */
#define BS_APBH_CHANNEL_CTRL_FREEZE_CHANNEL (16U) /*!< Bit field size in bits for APBH_CHANNEL_CTRL_FREEZE_CHANNEL. */

#define BV_APBH_CHANNEL_CTRL_FREEZE_CHANNEL_NAND0 (0x1U) /*!< Bit field value for APBH_CHANNEL_CTRL_FREEZE_CHANNEL:  */
#define BV_APBH_CHANNEL_CTRL_FREEZE_CHANNEL_NAND1 (0x2U) /*!< Bit field value for APBH_CHANNEL_CTRL_FREEZE_CHANNEL:  */
#define BV_APBH_CHANNEL_CTRL_FREEZE_CHANNEL_NAND2 (0x4U) /*!< Bit field value for APBH_CHANNEL_CTRL_FREEZE_CHANNEL:  */
#define BV_APBH_CHANNEL_CTRL_FREEZE_CHANNEL_NAND3 (0x8U) /*!< Bit field value for APBH_CHANNEL_CTRL_FREEZE_CHANNEL:  */
#define BV_APBH_CHANNEL_CTRL_FREEZE_CHANNEL_NAND4 (0x10U) /*!< Bit field value for APBH_CHANNEL_CTRL_FREEZE_CHANNEL:  */
#define BV_APBH_CHANNEL_CTRL_FREEZE_CHANNEL_NAND5 (0x20U) /*!< Bit field value for APBH_CHANNEL_CTRL_FREEZE_CHANNEL:  */
#define BV_APBH_CHANNEL_CTRL_FREEZE_CHANNEL_NAND6 (0x40U) /*!< Bit field value for APBH_CHANNEL_CTRL_FREEZE_CHANNEL:  */
#define BV_APBH_CHANNEL_CTRL_FREEZE_CHANNEL_NAND7 (0x80U) /*!< Bit field value for APBH_CHANNEL_CTRL_FREEZE_CHANNEL:  */
#define BV_APBH_CHANNEL_CTRL_FREEZE_CHANNEL_SSP (0x100U) /*!< Bit field value for APBH_CHANNEL_CTRL_FREEZE_CHANNEL:  */

/*! @brief Read current value of the APBH_CHANNEL_CTRL_FREEZE_CHANNEL field. */
#define BR_APBH_CHANNEL_CTRL_FREEZE_CHANNEL(x) (HW_APBH_CHANNEL_CTRL(x).B.FREEZE_CHANNEL)

/*! @brief Format value for bitfield APBH_CHANNEL_CTRL_FREEZE_CHANNEL. */
#define BF_APBH_CHANNEL_CTRL_FREEZE_CHANNEL(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CHANNEL_CTRL_FREEZE_CHANNEL) & BM_APBH_CHANNEL_CTRL_FREEZE_CHANNEL)

/*! @brief Set the FREEZE_CHANNEL field to a new value. */
#define BW_APBH_CHANNEL_CTRL_FREEZE_CHANNEL(x, v) (HW_APBH_CHANNEL_CTRL_WR(x, (HW_APBH_CHANNEL_CTRL_RD(x) & ~BM_APBH_CHANNEL_CTRL_FREEZE_CHANNEL) | BF_APBH_CHANNEL_CTRL_FREEZE_CHANNEL(v)))
/*@}*/

/*!
 * @name Register APBH_CHANNEL_CTRL, field RESET_CHANNEL[31:16] (RW)
 *
 * Setting a bit in this field causes the DMA controller to take the
 * corresponding channel through its reset state. The bit is reset after the channel
 * resources are cleared.
 *
 * Values:
 * - 1 -
 * - 10 -
 * - 100 -
 * - 1000 -
 * - 10000 -
 * - 100000 -
 * - 1000000 -
 * - 10000000 -
 * - 100000000 -
 */
/*@{*/
#define BP_APBH_CHANNEL_CTRL_RESET_CHANNEL (16U) /*!< Bit position for APBH_CHANNEL_CTRL_RESET_CHANNEL. */
#define BM_APBH_CHANNEL_CTRL_RESET_CHANNEL (0xFFFF0000U) /*!< Bit mask for APBH_CHANNEL_CTRL_RESET_CHANNEL. */
#define BS_APBH_CHANNEL_CTRL_RESET_CHANNEL (16U) /*!< Bit field size in bits for APBH_CHANNEL_CTRL_RESET_CHANNEL. */

#define BV_APBH_CHANNEL_CTRL_RESET_CHANNEL_NAND0 (0x1U) /*!< Bit field value for APBH_CHANNEL_CTRL_RESET_CHANNEL:  */
#define BV_APBH_CHANNEL_CTRL_RESET_CHANNEL_NAND1 (0x2U) /*!< Bit field value for APBH_CHANNEL_CTRL_RESET_CHANNEL:  */
#define BV_APBH_CHANNEL_CTRL_RESET_CHANNEL_NAND2 (0x4U) /*!< Bit field value for APBH_CHANNEL_CTRL_RESET_CHANNEL:  */
#define BV_APBH_CHANNEL_CTRL_RESET_CHANNEL_NAND3 (0x8U) /*!< Bit field value for APBH_CHANNEL_CTRL_RESET_CHANNEL:  */
#define BV_APBH_CHANNEL_CTRL_RESET_CHANNEL_NAND4 (0x10U) /*!< Bit field value for APBH_CHANNEL_CTRL_RESET_CHANNEL:  */
#define BV_APBH_CHANNEL_CTRL_RESET_CHANNEL_NAND5 (0x20U) /*!< Bit field value for APBH_CHANNEL_CTRL_RESET_CHANNEL:  */
#define BV_APBH_CHANNEL_CTRL_RESET_CHANNEL_NAND6 (0x40U) /*!< Bit field value for APBH_CHANNEL_CTRL_RESET_CHANNEL:  */
#define BV_APBH_CHANNEL_CTRL_RESET_CHANNEL_NAND7 (0x80U) /*!< Bit field value for APBH_CHANNEL_CTRL_RESET_CHANNEL:  */
#define BV_APBH_CHANNEL_CTRL_RESET_CHANNEL_SSP (0x100U) /*!< Bit field value for APBH_CHANNEL_CTRL_RESET_CHANNEL:  */

/*! @brief Read current value of the APBH_CHANNEL_CTRL_RESET_CHANNEL field. */
#define BR_APBH_CHANNEL_CTRL_RESET_CHANNEL(x) (HW_APBH_CHANNEL_CTRL(x).B.RESET_CHANNEL)

/*! @brief Format value for bitfield APBH_CHANNEL_CTRL_RESET_CHANNEL. */
#define BF_APBH_CHANNEL_CTRL_RESET_CHANNEL(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CHANNEL_CTRL_RESET_CHANNEL) & BM_APBH_CHANNEL_CTRL_RESET_CHANNEL)

/*! @brief Set the RESET_CHANNEL field to a new value. */
#define BW_APBH_CHANNEL_CTRL_RESET_CHANNEL(x, v) (HW_APBH_CHANNEL_CTRL_WR(x, (HW_APBH_CHANNEL_CTRL_RD(x) & ~BM_APBH_CHANNEL_CTRL_RESET_CHANNEL) | BF_APBH_CHANNEL_CTRL_RESET_CHANNEL(v)))
/*@}*/




/*******************************************************************************
 * HW_APBH_DEVSEL - AHB to APBH DMA Device Assignment Register
 ******************************************************************************/

/*!
 * @brief HW_APBH_DEVSEL - AHB to APBH DMA Device Assignment Register (RU)
 *
 * Reset value: 0x00000000U
 *
 * This register allows reassignment of the APBH device connected to the DMA
 * Channels. In this chip, APBH DMA channel resource is enough for high speed
 * peripherals, so this register is of no use and reserved.
 */
typedef union _hw_apbh_devsel
{
    uint32_t U;
    struct _hw_apbh_devsel_bitfields
    {
        uint32_t CH0 : 2;              /*!< [1:0]  */
        uint32_t CH1 : 2;              /*!< [3:2]  */
        uint32_t CH2 : 2;              /*!< [5:4]  */
        uint32_t CH3 : 2;              /*!< [7:6]  */
        uint32_t CH4 : 2;              /*!< [9:8]  */
        uint32_t CH5 : 2;              /*!< [11:10]  */
        uint32_t CH6 : 2;              /*!< [13:12]  */
        uint32_t CH7 : 2;              /*!< [15:14]  */
        uint32_t CH8 : 2;              /*!< [17:16]  */
        uint32_t CH9 : 2;              /*!< [19:18]  */
        uint32_t CH10 : 2;             /*!< [21:20]  */
        uint32_t CH11 : 2;             /*!< [23:22]  */
        uint32_t CH12 : 2;             /*!< [25:24]  */
        uint32_t CH13 : 2;             /*!< [27:26]  */
        uint32_t CH14 : 2;             /*!< [29:28]  */
        uint32_t CH15 : 2;             /*!< [31:30]  */
    } B;
} hw_apbh_devsel_t;

/*!
 * @name Constants and macros for entire APBH_DEVSEL register
 */
/*@{*/
#define HW_APBH_DEVSEL_ADDR(x)   ((uintptr_t)(x) + 0x40U)
#define HW_APBH_DEVSEL(x)        (*(__I hw_apbh_devsel_t *) HW_APBH_DEVSEL_ADDR(x))
/*@}*/

/*
 * Constants & macros for individual APBH_DEVSEL bitfields
 */

/*!
 * @name Register APBH_DEVSEL, field CH0[1:0] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DEVSEL_CH0   (0U)          /*!< Bit position for APBH_DEVSEL_CH0. */
#define BM_APBH_DEVSEL_CH0   (0x00000003U) /*!< Bit mask for APBH_DEVSEL_CH0. */
#define BS_APBH_DEVSEL_CH0   (2U)          /*!< Bit field size in bits for APBH_DEVSEL_CH0. */
/*@}*/

/*!
 * @name Register APBH_DEVSEL, field CH1[3:2] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DEVSEL_CH1   (2U)          /*!< Bit position for APBH_DEVSEL_CH1. */
#define BM_APBH_DEVSEL_CH1   (0x0000000CU) /*!< Bit mask for APBH_DEVSEL_CH1. */
#define BS_APBH_DEVSEL_CH1   (2U)          /*!< Bit field size in bits for APBH_DEVSEL_CH1. */
/*@}*/

/*!
 * @name Register APBH_DEVSEL, field CH2[5:4] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DEVSEL_CH2   (4U)          /*!< Bit position for APBH_DEVSEL_CH2. */
#define BM_APBH_DEVSEL_CH2   (0x00000030U) /*!< Bit mask for APBH_DEVSEL_CH2. */
#define BS_APBH_DEVSEL_CH2   (2U)          /*!< Bit field size in bits for APBH_DEVSEL_CH2. */
/*@}*/

/*!
 * @name Register APBH_DEVSEL, field CH3[7:6] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DEVSEL_CH3   (6U)          /*!< Bit position for APBH_DEVSEL_CH3. */
#define BM_APBH_DEVSEL_CH3   (0x000000C0U) /*!< Bit mask for APBH_DEVSEL_CH3. */
#define BS_APBH_DEVSEL_CH3   (2U)          /*!< Bit field size in bits for APBH_DEVSEL_CH3. */
/*@}*/

/*!
 * @name Register APBH_DEVSEL, field CH4[9:8] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DEVSEL_CH4   (8U)          /*!< Bit position for APBH_DEVSEL_CH4. */
#define BM_APBH_DEVSEL_CH4   (0x00000300U) /*!< Bit mask for APBH_DEVSEL_CH4. */
#define BS_APBH_DEVSEL_CH4   (2U)          /*!< Bit field size in bits for APBH_DEVSEL_CH4. */
/*@}*/

/*!
 * @name Register APBH_DEVSEL, field CH5[11:10] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DEVSEL_CH5   (10U)         /*!< Bit position for APBH_DEVSEL_CH5. */
#define BM_APBH_DEVSEL_CH5   (0x00000C00U) /*!< Bit mask for APBH_DEVSEL_CH5. */
#define BS_APBH_DEVSEL_CH5   (2U)          /*!< Bit field size in bits for APBH_DEVSEL_CH5. */
/*@}*/

/*!
 * @name Register APBH_DEVSEL, field CH6[13:12] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DEVSEL_CH6   (12U)         /*!< Bit position for APBH_DEVSEL_CH6. */
#define BM_APBH_DEVSEL_CH6   (0x00003000U) /*!< Bit mask for APBH_DEVSEL_CH6. */
#define BS_APBH_DEVSEL_CH6   (2U)          /*!< Bit field size in bits for APBH_DEVSEL_CH6. */
/*@}*/

/*!
 * @name Register APBH_DEVSEL, field CH7[15:14] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DEVSEL_CH7   (14U)         /*!< Bit position for APBH_DEVSEL_CH7. */
#define BM_APBH_DEVSEL_CH7   (0x0000C000U) /*!< Bit mask for APBH_DEVSEL_CH7. */
#define BS_APBH_DEVSEL_CH7   (2U)          /*!< Bit field size in bits for APBH_DEVSEL_CH7. */
/*@}*/

/*!
 * @name Register APBH_DEVSEL, field CH8[17:16] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DEVSEL_CH8   (16U)         /*!< Bit position for APBH_DEVSEL_CH8. */
#define BM_APBH_DEVSEL_CH8   (0x00030000U) /*!< Bit mask for APBH_DEVSEL_CH8. */
#define BS_APBH_DEVSEL_CH8   (2U)          /*!< Bit field size in bits for APBH_DEVSEL_CH8. */
/*@}*/

/*!
 * @name Register APBH_DEVSEL, field CH9[19:18] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DEVSEL_CH9   (18U)         /*!< Bit position for APBH_DEVSEL_CH9. */
#define BM_APBH_DEVSEL_CH9   (0x000C0000U) /*!< Bit mask for APBH_DEVSEL_CH9. */
#define BS_APBH_DEVSEL_CH9   (2U)          /*!< Bit field size in bits for APBH_DEVSEL_CH9. */
/*@}*/

/*!
 * @name Register APBH_DEVSEL, field CH10[21:20] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DEVSEL_CH10  (20U)         /*!< Bit position for APBH_DEVSEL_CH10. */
#define BM_APBH_DEVSEL_CH10  (0x00300000U) /*!< Bit mask for APBH_DEVSEL_CH10. */
#define BS_APBH_DEVSEL_CH10  (2U)          /*!< Bit field size in bits for APBH_DEVSEL_CH10. */
/*@}*/

/*!
 * @name Register APBH_DEVSEL, field CH11[23:22] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DEVSEL_CH11  (22U)         /*!< Bit position for APBH_DEVSEL_CH11. */
#define BM_APBH_DEVSEL_CH11  (0x00C00000U) /*!< Bit mask for APBH_DEVSEL_CH11. */
#define BS_APBH_DEVSEL_CH11  (2U)          /*!< Bit field size in bits for APBH_DEVSEL_CH11. */
/*@}*/

/*!
 * @name Register APBH_DEVSEL, field CH12[25:24] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DEVSEL_CH12  (24U)         /*!< Bit position for APBH_DEVSEL_CH12. */
#define BM_APBH_DEVSEL_CH12  (0x03000000U) /*!< Bit mask for APBH_DEVSEL_CH12. */
#define BS_APBH_DEVSEL_CH12  (2U)          /*!< Bit field size in bits for APBH_DEVSEL_CH12. */
/*@}*/

/*!
 * @name Register APBH_DEVSEL, field CH13[27:26] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DEVSEL_CH13  (26U)         /*!< Bit position for APBH_DEVSEL_CH13. */
#define BM_APBH_DEVSEL_CH13  (0x0C000000U) /*!< Bit mask for APBH_DEVSEL_CH13. */
#define BS_APBH_DEVSEL_CH13  (2U)          /*!< Bit field size in bits for APBH_DEVSEL_CH13. */
/*@}*/

/*!
 * @name Register APBH_DEVSEL, field CH14[29:28] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DEVSEL_CH14  (28U)         /*!< Bit position for APBH_DEVSEL_CH14. */
#define BM_APBH_DEVSEL_CH14  (0x30000000U) /*!< Bit mask for APBH_DEVSEL_CH14. */
#define BS_APBH_DEVSEL_CH14  (2U)          /*!< Bit field size in bits for APBH_DEVSEL_CH14. */
/*@}*/

/*!
 * @name Register APBH_DEVSEL, field CH15[31:30] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DEVSEL_CH15  (30U)         /*!< Bit position for APBH_DEVSEL_CH15. */
#define BM_APBH_DEVSEL_CH15  (0xC0000000U) /*!< Bit mask for APBH_DEVSEL_CH15. */
#define BS_APBH_DEVSEL_CH15  (2U)          /*!< Bit field size in bits for APBH_DEVSEL_CH15. */
/*@}*/

/*******************************************************************************
 * HW_APBH_DMA_BURST_SIZE - AHB to APBH DMA burst size
 ******************************************************************************/

/*!
 * @brief HW_APBH_DMA_BURST_SIZE - AHB to APBH DMA burst size (RW)
 *
 * Reset value: 0x00555555U
 *
 * This register programs the apbh burst size of the APBH DMA devices when a DMA
 * burst request is issued. This register provides a mechanism for assigning the
 * device.
 */
typedef union _hw_apbh_dma_burst_size
{
    uint32_t U;
    struct _hw_apbh_dma_burst_size_bitfields
    {
        uint32_t CH0 : 2;              /*!< [1:0]  */
        uint32_t CH1 : 2;              /*!< [3:2]  */
        uint32_t CH2 : 2;              /*!< [5:4]  */
        uint32_t CH3 : 2;              /*!< [7:6]  */
        uint32_t CH4 : 2;              /*!< [9:8]  */
        uint32_t CH5 : 2;              /*!< [11:10]  */
        uint32_t CH6 : 2;              /*!< [13:12]  */
        uint32_t CH7 : 2;              /*!< [15:14]  */
        uint32_t CH8 : 2;              /*!< [17:16]  */
        uint32_t CH9 : 2;              /*!< [19:18]  */
        uint32_t CH10 : 2;             /*!< [21:20]  */
        uint32_t CH11 : 2;             /*!< [23:22]  */
        uint32_t CH12 : 2;             /*!< [25:24]  */
        uint32_t CH13 : 2;             /*!< [27:26]  */
        uint32_t CH14 : 2;             /*!< [29:28]  */
        uint32_t CH15 : 2;             /*!< [31:30]  */
    } B;
} hw_apbh_dma_burst_size_t;

/*!
 * @name Constants and macros for entire APBH_DMA_BURST_SIZE register
 */
/*@{*/
#define HW_APBH_DMA_BURST_SIZE_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_APBH_DMA_BURST_SIZE(x) (*(__IO hw_apbh_dma_burst_size_t *) HW_APBH_DMA_BURST_SIZE_ADDR(x))
#define HW_APBH_DMA_BURST_SIZE_RD(x) (HW_APBH_DMA_BURST_SIZE(x).U)
#define HW_APBH_DMA_BURST_SIZE_WR(x, v) (HW_APBH_DMA_BURST_SIZE(x).U = (v))
#define HW_APBH_DMA_BURST_SIZE_SET(x, v) (HW_APBH_DMA_BURST_SIZE_WR(x, HW_APBH_DMA_BURST_SIZE_RD(x) |  (v)))
#define HW_APBH_DMA_BURST_SIZE_CLR(x, v) (HW_APBH_DMA_BURST_SIZE_WR(x, HW_APBH_DMA_BURST_SIZE_RD(x) & ~(v)))
#define HW_APBH_DMA_BURST_SIZE_TOG(x, v) (HW_APBH_DMA_BURST_SIZE_WR(x, HW_APBH_DMA_BURST_SIZE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual APBH_DMA_BURST_SIZE bitfields
 */

/*!
 * @name Register APBH_DMA_BURST_SIZE, field CH0[1:0] (RW)
 *
 * DMA burst size for GPMI channel 0. Do not change. GPMI only support burst
 * size 4.
 */
/*@{*/
#define BP_APBH_DMA_BURST_SIZE_CH0 (0U)    /*!< Bit position for APBH_DMA_BURST_SIZE_CH0. */
#define BM_APBH_DMA_BURST_SIZE_CH0 (0x00000003U) /*!< Bit mask for APBH_DMA_BURST_SIZE_CH0. */
#define BS_APBH_DMA_BURST_SIZE_CH0 (2U)    /*!< Bit field size in bits for APBH_DMA_BURST_SIZE_CH0. */

/*! @brief Read current value of the APBH_DMA_BURST_SIZE_CH0 field. */
#define BR_APBH_DMA_BURST_SIZE_CH0(x) (HW_APBH_DMA_BURST_SIZE(x).B.CH0)

/*! @brief Format value for bitfield APBH_DMA_BURST_SIZE_CH0. */
#define BF_APBH_DMA_BURST_SIZE_CH0(v) ((uint32_t)((uint32_t)(v) << BP_APBH_DMA_BURST_SIZE_CH0) & BM_APBH_DMA_BURST_SIZE_CH0)

/*! @brief Set the CH0 field to a new value. */
#define BW_APBH_DMA_BURST_SIZE_CH0(x, v) (HW_APBH_DMA_BURST_SIZE_WR(x, (HW_APBH_DMA_BURST_SIZE_RD(x) & ~BM_APBH_DMA_BURST_SIZE_CH0) | BF_APBH_DMA_BURST_SIZE_CH0(v)))
/*@}*/

/*!
 * @name Register APBH_DMA_BURST_SIZE, field CH1[3:2] (RW)
 *
 * DMA burst size for GPMI channel 1. Do not change. GPMI only support burst
 * size 4.
 */
/*@{*/
#define BP_APBH_DMA_BURST_SIZE_CH1 (2U)    /*!< Bit position for APBH_DMA_BURST_SIZE_CH1. */
#define BM_APBH_DMA_BURST_SIZE_CH1 (0x0000000CU) /*!< Bit mask for APBH_DMA_BURST_SIZE_CH1. */
#define BS_APBH_DMA_BURST_SIZE_CH1 (2U)    /*!< Bit field size in bits for APBH_DMA_BURST_SIZE_CH1. */

/*! @brief Read current value of the APBH_DMA_BURST_SIZE_CH1 field. */
#define BR_APBH_DMA_BURST_SIZE_CH1(x) (HW_APBH_DMA_BURST_SIZE(x).B.CH1)

/*! @brief Format value for bitfield APBH_DMA_BURST_SIZE_CH1. */
#define BF_APBH_DMA_BURST_SIZE_CH1(v) ((uint32_t)((uint32_t)(v) << BP_APBH_DMA_BURST_SIZE_CH1) & BM_APBH_DMA_BURST_SIZE_CH1)

/*! @brief Set the CH1 field to a new value. */
#define BW_APBH_DMA_BURST_SIZE_CH1(x, v) (HW_APBH_DMA_BURST_SIZE_WR(x, (HW_APBH_DMA_BURST_SIZE_RD(x) & ~BM_APBH_DMA_BURST_SIZE_CH1) | BF_APBH_DMA_BURST_SIZE_CH1(v)))
/*@}*/

/*!
 * @name Register APBH_DMA_BURST_SIZE, field CH2[5:4] (RW)
 *
 * DMA burst size for GPMI channel 2. Do not change. GPMI only support burst
 * size 4.
 */
/*@{*/
#define BP_APBH_DMA_BURST_SIZE_CH2 (4U)    /*!< Bit position for APBH_DMA_BURST_SIZE_CH2. */
#define BM_APBH_DMA_BURST_SIZE_CH2 (0x00000030U) /*!< Bit mask for APBH_DMA_BURST_SIZE_CH2. */
#define BS_APBH_DMA_BURST_SIZE_CH2 (2U)    /*!< Bit field size in bits for APBH_DMA_BURST_SIZE_CH2. */

/*! @brief Read current value of the APBH_DMA_BURST_SIZE_CH2 field. */
#define BR_APBH_DMA_BURST_SIZE_CH2(x) (HW_APBH_DMA_BURST_SIZE(x).B.CH2)

/*! @brief Format value for bitfield APBH_DMA_BURST_SIZE_CH2. */
#define BF_APBH_DMA_BURST_SIZE_CH2(v) ((uint32_t)((uint32_t)(v) << BP_APBH_DMA_BURST_SIZE_CH2) & BM_APBH_DMA_BURST_SIZE_CH2)

/*! @brief Set the CH2 field to a new value. */
#define BW_APBH_DMA_BURST_SIZE_CH2(x, v) (HW_APBH_DMA_BURST_SIZE_WR(x, (HW_APBH_DMA_BURST_SIZE_RD(x) & ~BM_APBH_DMA_BURST_SIZE_CH2) | BF_APBH_DMA_BURST_SIZE_CH2(v)))
/*@}*/

/*!
 * @name Register APBH_DMA_BURST_SIZE, field CH3[7:6] (RW)
 *
 * DMA burst size for GPMI channel 3. Do not change. GPMI only support burst
 * size 4.
 */
/*@{*/
#define BP_APBH_DMA_BURST_SIZE_CH3 (6U)    /*!< Bit position for APBH_DMA_BURST_SIZE_CH3. */
#define BM_APBH_DMA_BURST_SIZE_CH3 (0x000000C0U) /*!< Bit mask for APBH_DMA_BURST_SIZE_CH3. */
#define BS_APBH_DMA_BURST_SIZE_CH3 (2U)    /*!< Bit field size in bits for APBH_DMA_BURST_SIZE_CH3. */

/*! @brief Read current value of the APBH_DMA_BURST_SIZE_CH3 field. */
#define BR_APBH_DMA_BURST_SIZE_CH3(x) (HW_APBH_DMA_BURST_SIZE(x).B.CH3)

/*! @brief Format value for bitfield APBH_DMA_BURST_SIZE_CH3. */
#define BF_APBH_DMA_BURST_SIZE_CH3(v) ((uint32_t)((uint32_t)(v) << BP_APBH_DMA_BURST_SIZE_CH3) & BM_APBH_DMA_BURST_SIZE_CH3)

/*! @brief Set the CH3 field to a new value. */
#define BW_APBH_DMA_BURST_SIZE_CH3(x, v) (HW_APBH_DMA_BURST_SIZE_WR(x, (HW_APBH_DMA_BURST_SIZE_RD(x) & ~BM_APBH_DMA_BURST_SIZE_CH3) | BF_APBH_DMA_BURST_SIZE_CH3(v)))
/*@}*/

/*!
 * @name Register APBH_DMA_BURST_SIZE, field CH4[9:8] (RW)
 *
 * DMA burst size for GPMI channel 4. Do not change. GPMI only support burst
 * size 4.
 */
/*@{*/
#define BP_APBH_DMA_BURST_SIZE_CH4 (8U)    /*!< Bit position for APBH_DMA_BURST_SIZE_CH4. */
#define BM_APBH_DMA_BURST_SIZE_CH4 (0x00000300U) /*!< Bit mask for APBH_DMA_BURST_SIZE_CH4. */
#define BS_APBH_DMA_BURST_SIZE_CH4 (2U)    /*!< Bit field size in bits for APBH_DMA_BURST_SIZE_CH4. */

/*! @brief Read current value of the APBH_DMA_BURST_SIZE_CH4 field. */
#define BR_APBH_DMA_BURST_SIZE_CH4(x) (HW_APBH_DMA_BURST_SIZE(x).B.CH4)

/*! @brief Format value for bitfield APBH_DMA_BURST_SIZE_CH4. */
#define BF_APBH_DMA_BURST_SIZE_CH4(v) ((uint32_t)((uint32_t)(v) << BP_APBH_DMA_BURST_SIZE_CH4) & BM_APBH_DMA_BURST_SIZE_CH4)

/*! @brief Set the CH4 field to a new value. */
#define BW_APBH_DMA_BURST_SIZE_CH4(x, v) (HW_APBH_DMA_BURST_SIZE_WR(x, (HW_APBH_DMA_BURST_SIZE_RD(x) & ~BM_APBH_DMA_BURST_SIZE_CH4) | BF_APBH_DMA_BURST_SIZE_CH4(v)))
/*@}*/

/*!
 * @name Register APBH_DMA_BURST_SIZE, field CH5[11:10] (RW)
 *
 * DMA burst size for GPMI channel 5. Do not change. GPMI only support burst
 * size 4.
 */
/*@{*/
#define BP_APBH_DMA_BURST_SIZE_CH5 (10U)   /*!< Bit position for APBH_DMA_BURST_SIZE_CH5. */
#define BM_APBH_DMA_BURST_SIZE_CH5 (0x00000C00U) /*!< Bit mask for APBH_DMA_BURST_SIZE_CH5. */
#define BS_APBH_DMA_BURST_SIZE_CH5 (2U)    /*!< Bit field size in bits for APBH_DMA_BURST_SIZE_CH5. */

/*! @brief Read current value of the APBH_DMA_BURST_SIZE_CH5 field. */
#define BR_APBH_DMA_BURST_SIZE_CH5(x) (HW_APBH_DMA_BURST_SIZE(x).B.CH5)

/*! @brief Format value for bitfield APBH_DMA_BURST_SIZE_CH5. */
#define BF_APBH_DMA_BURST_SIZE_CH5(v) ((uint32_t)((uint32_t)(v) << BP_APBH_DMA_BURST_SIZE_CH5) & BM_APBH_DMA_BURST_SIZE_CH5)

/*! @brief Set the CH5 field to a new value. */
#define BW_APBH_DMA_BURST_SIZE_CH5(x, v) (HW_APBH_DMA_BURST_SIZE_WR(x, (HW_APBH_DMA_BURST_SIZE_RD(x) & ~BM_APBH_DMA_BURST_SIZE_CH5) | BF_APBH_DMA_BURST_SIZE_CH5(v)))
/*@}*/

/*!
 * @name Register APBH_DMA_BURST_SIZE, field CH6[13:12] (RW)
 *
 * DMA burst size for GPMI channel 6. Do not change. GPMI only support burst
 * size 4.
 */
/*@{*/
#define BP_APBH_DMA_BURST_SIZE_CH6 (12U)   /*!< Bit position for APBH_DMA_BURST_SIZE_CH6. */
#define BM_APBH_DMA_BURST_SIZE_CH6 (0x00003000U) /*!< Bit mask for APBH_DMA_BURST_SIZE_CH6. */
#define BS_APBH_DMA_BURST_SIZE_CH6 (2U)    /*!< Bit field size in bits for APBH_DMA_BURST_SIZE_CH6. */

/*! @brief Read current value of the APBH_DMA_BURST_SIZE_CH6 field. */
#define BR_APBH_DMA_BURST_SIZE_CH6(x) (HW_APBH_DMA_BURST_SIZE(x).B.CH6)

/*! @brief Format value for bitfield APBH_DMA_BURST_SIZE_CH6. */
#define BF_APBH_DMA_BURST_SIZE_CH6(v) ((uint32_t)((uint32_t)(v) << BP_APBH_DMA_BURST_SIZE_CH6) & BM_APBH_DMA_BURST_SIZE_CH6)

/*! @brief Set the CH6 field to a new value. */
#define BW_APBH_DMA_BURST_SIZE_CH6(x, v) (HW_APBH_DMA_BURST_SIZE_WR(x, (HW_APBH_DMA_BURST_SIZE_RD(x) & ~BM_APBH_DMA_BURST_SIZE_CH6) | BF_APBH_DMA_BURST_SIZE_CH6(v)))
/*@}*/

/*!
 * @name Register APBH_DMA_BURST_SIZE, field CH7[15:14] (RW)
 *
 * DMA burst size for GPMI channel 7. Do not change. GPMI only support burst
 * size 4.
 */
/*@{*/
#define BP_APBH_DMA_BURST_SIZE_CH7 (14U)   /*!< Bit position for APBH_DMA_BURST_SIZE_CH7. */
#define BM_APBH_DMA_BURST_SIZE_CH7 (0x0000C000U) /*!< Bit mask for APBH_DMA_BURST_SIZE_CH7. */
#define BS_APBH_DMA_BURST_SIZE_CH7 (2U)    /*!< Bit field size in bits for APBH_DMA_BURST_SIZE_CH7. */

/*! @brief Read current value of the APBH_DMA_BURST_SIZE_CH7 field. */
#define BR_APBH_DMA_BURST_SIZE_CH7(x) (HW_APBH_DMA_BURST_SIZE(x).B.CH7)

/*! @brief Format value for bitfield APBH_DMA_BURST_SIZE_CH7. */
#define BF_APBH_DMA_BURST_SIZE_CH7(v) ((uint32_t)((uint32_t)(v) << BP_APBH_DMA_BURST_SIZE_CH7) & BM_APBH_DMA_BURST_SIZE_CH7)

/*! @brief Set the CH7 field to a new value. */
#define BW_APBH_DMA_BURST_SIZE_CH7(x, v) (HW_APBH_DMA_BURST_SIZE_WR(x, (HW_APBH_DMA_BURST_SIZE_RD(x) & ~BM_APBH_DMA_BURST_SIZE_CH7) | BF_APBH_DMA_BURST_SIZE_CH7(v)))
/*@}*/

/*!
 * @name Register APBH_DMA_BURST_SIZE, field CH8[17:16] (RW)
 *
 * DMA burst size for SSP.
 *
 * Values:
 * - 0 -
 * - 1 -
 * - 10 -
 */
/*@{*/
#define BP_APBH_DMA_BURST_SIZE_CH8 (16U)   /*!< Bit position for APBH_DMA_BURST_SIZE_CH8. */
#define BM_APBH_DMA_BURST_SIZE_CH8 (0x00030000U) /*!< Bit mask for APBH_DMA_BURST_SIZE_CH8. */
#define BS_APBH_DMA_BURST_SIZE_CH8 (2U)    /*!< Bit field size in bits for APBH_DMA_BURST_SIZE_CH8. */

#define BV_APBH_DMA_BURST_SIZE_CH8_BURST0 (0U)       /*!< Bit field value for APBH_DMA_BURST_SIZE_CH8:  */
#define BV_APBH_DMA_BURST_SIZE_CH8_BURST4 (0x1U)     /*!< Bit field value for APBH_DMA_BURST_SIZE_CH8:  */
#define BV_APBH_DMA_BURST_SIZE_CH8_BURST8 (0x2U)     /*!< Bit field value for APBH_DMA_BURST_SIZE_CH8:  */

/*! @brief Read current value of the APBH_DMA_BURST_SIZE_CH8 field. */
#define BR_APBH_DMA_BURST_SIZE_CH8(x) (HW_APBH_DMA_BURST_SIZE(x).B.CH8)

/*! @brief Format value for bitfield APBH_DMA_BURST_SIZE_CH8. */
#define BF_APBH_DMA_BURST_SIZE_CH8(v) ((uint32_t)((uint32_t)(v) << BP_APBH_DMA_BURST_SIZE_CH8) & BM_APBH_DMA_BURST_SIZE_CH8)

/*! @brief Set the CH8 field to a new value. */
#define BW_APBH_DMA_BURST_SIZE_CH8(x, v) (HW_APBH_DMA_BURST_SIZE_WR(x, (HW_APBH_DMA_BURST_SIZE_RD(x) & ~BM_APBH_DMA_BURST_SIZE_CH8) | BF_APBH_DMA_BURST_SIZE_CH8(v)))
/*@}*/

/*!
 * @name Register APBH_DMA_BURST_SIZE, field CH9[19:18] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DMA_BURST_SIZE_CH9 (18U)   /*!< Bit position for APBH_DMA_BURST_SIZE_CH9. */
#define BM_APBH_DMA_BURST_SIZE_CH9 (0x000C0000U) /*!< Bit mask for APBH_DMA_BURST_SIZE_CH9. */
#define BS_APBH_DMA_BURST_SIZE_CH9 (2U)    /*!< Bit field size in bits for APBH_DMA_BURST_SIZE_CH9. */
/*@}*/

/*!
 * @name Register APBH_DMA_BURST_SIZE, field CH10[21:20] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DMA_BURST_SIZE_CH10 (20U)  /*!< Bit position for APBH_DMA_BURST_SIZE_CH10. */
#define BM_APBH_DMA_BURST_SIZE_CH10 (0x00300000U) /*!< Bit mask for APBH_DMA_BURST_SIZE_CH10. */
#define BS_APBH_DMA_BURST_SIZE_CH10 (2U)   /*!< Bit field size in bits for APBH_DMA_BURST_SIZE_CH10. */
/*@}*/

/*!
 * @name Register APBH_DMA_BURST_SIZE, field CH11[23:22] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DMA_BURST_SIZE_CH11 (22U)  /*!< Bit position for APBH_DMA_BURST_SIZE_CH11. */
#define BM_APBH_DMA_BURST_SIZE_CH11 (0x00C00000U) /*!< Bit mask for APBH_DMA_BURST_SIZE_CH11. */
#define BS_APBH_DMA_BURST_SIZE_CH11 (2U)   /*!< Bit field size in bits for APBH_DMA_BURST_SIZE_CH11. */
/*@}*/

/*!
 * @name Register APBH_DMA_BURST_SIZE, field CH12[25:24] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DMA_BURST_SIZE_CH12 (24U)  /*!< Bit position for APBH_DMA_BURST_SIZE_CH12. */
#define BM_APBH_DMA_BURST_SIZE_CH12 (0x03000000U) /*!< Bit mask for APBH_DMA_BURST_SIZE_CH12. */
#define BS_APBH_DMA_BURST_SIZE_CH12 (2U)   /*!< Bit field size in bits for APBH_DMA_BURST_SIZE_CH12. */
/*@}*/

/*!
 * @name Register APBH_DMA_BURST_SIZE, field CH13[27:26] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DMA_BURST_SIZE_CH13 (26U)  /*!< Bit position for APBH_DMA_BURST_SIZE_CH13. */
#define BM_APBH_DMA_BURST_SIZE_CH13 (0x0C000000U) /*!< Bit mask for APBH_DMA_BURST_SIZE_CH13. */
#define BS_APBH_DMA_BURST_SIZE_CH13 (2U)   /*!< Bit field size in bits for APBH_DMA_BURST_SIZE_CH13. */
/*@}*/

/*!
 * @name Register APBH_DMA_BURST_SIZE, field CH14[29:28] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DMA_BURST_SIZE_CH14 (28U)  /*!< Bit position for APBH_DMA_BURST_SIZE_CH14. */
#define BM_APBH_DMA_BURST_SIZE_CH14 (0x30000000U) /*!< Bit mask for APBH_DMA_BURST_SIZE_CH14. */
#define BS_APBH_DMA_BURST_SIZE_CH14 (2U)   /*!< Bit field size in bits for APBH_DMA_BURST_SIZE_CH14. */
/*@}*/

/*!
 * @name Register APBH_DMA_BURST_SIZE, field CH15[31:30] (RU)
 *
 * Reserved.
 */
/*@{*/
#define BP_APBH_DMA_BURST_SIZE_CH15 (30U)  /*!< Bit position for APBH_DMA_BURST_SIZE_CH15. */
#define BM_APBH_DMA_BURST_SIZE_CH15 (0xC0000000U) /*!< Bit mask for APBH_DMA_BURST_SIZE_CH15. */
#define BS_APBH_DMA_BURST_SIZE_CH15 (2U)   /*!< Bit field size in bits for APBH_DMA_BURST_SIZE_CH15. */
/*@}*/

/*******************************************************************************
 * HW_APBH_DEBUG - AHB to APBH DMA Debug Register
 ******************************************************************************/

/*!
 * @brief HW_APBH_DEBUG - AHB to APBH DMA Debug Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is for debug purpose. The debug register is for internal use
 * only. Not recommend for customer useage.
 */
typedef union _hw_apbh_debug
{
    uint32_t U;
    struct _hw_apbh_debug_bitfields
    {
        uint32_t GPMI_ONE_FIFO : 1;    /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_apbh_debug_t;

/*!
 * @name Constants and macros for entire APBH_DEBUG register
 */
/*@{*/
#define HW_APBH_DEBUG_ADDR(x)    ((uintptr_t)(x) + 0x60U)

#define HW_APBH_DEBUG(x)         (*(__IO hw_apbh_debug_t *) HW_APBH_DEBUG_ADDR(x))
#define HW_APBH_DEBUG_RD(x)      (HW_APBH_DEBUG(x).U)
#define HW_APBH_DEBUG_WR(x, v)   (HW_APBH_DEBUG(x).U = (v))
#define HW_APBH_DEBUG_SET(x, v)  (HW_APBH_DEBUG_WR(x, HW_APBH_DEBUG_RD(x) |  (v)))
#define HW_APBH_DEBUG_CLR(x, v)  (HW_APBH_DEBUG_WR(x, HW_APBH_DEBUG_RD(x) & ~(v)))
#define HW_APBH_DEBUG_TOG(x, v)  (HW_APBH_DEBUG_WR(x, HW_APBH_DEBUG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual APBH_DEBUG bitfields
 */

/*!
 * @name Register APBH_DEBUG, field GPMI_ONE_FIFO[0] (RW)
 *
 * Set to 0ne and the 8 GPMI channels will share the DMA FIFO, and when set to
 * zero, the 8 GPMI channels will use its own DMA FIFO.
 */
/*@{*/
#define BP_APBH_DEBUG_GPMI_ONE_FIFO (0U)   /*!< Bit position for APBH_DEBUG_GPMI_ONE_FIFO. */
#define BM_APBH_DEBUG_GPMI_ONE_FIFO (0x00000001U) /*!< Bit mask for APBH_DEBUG_GPMI_ONE_FIFO. */
#define BS_APBH_DEBUG_GPMI_ONE_FIFO (1U)   /*!< Bit field size in bits for APBH_DEBUG_GPMI_ONE_FIFO. */

/*! @brief Read current value of the APBH_DEBUG_GPMI_ONE_FIFO field. */
#define BR_APBH_DEBUG_GPMI_ONE_FIFO(x) (HW_APBH_DEBUG(x).B.GPMI_ONE_FIFO)

/*! @brief Format value for bitfield APBH_DEBUG_GPMI_ONE_FIFO. */
#define BF_APBH_DEBUG_GPMI_ONE_FIFO(v) ((uint32_t)((uint32_t)(v) << BP_APBH_DEBUG_GPMI_ONE_FIFO) & BM_APBH_DEBUG_GPMI_ONE_FIFO)

/*! @brief Set the GPMI_ONE_FIFO field to a new value. */
#define BW_APBH_DEBUG_GPMI_ONE_FIFO(x, v) (HW_APBH_DEBUG_WR(x, (HW_APBH_DEBUG_RD(x) & ~BM_APBH_DEBUG_GPMI_ONE_FIFO) | BF_APBH_DEBUG_GPMI_ONE_FIFO(v)))
/*@}*/

/*******************************************************************************
 * HW_APBH_CHn_CURCMDAR - APBH DMA Channel n Current Command Address Register
 ******************************************************************************/

/*!
 * @brief HW_APBH_CHn_CURCMDAR - APBH DMA Channel n Current Command Address Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The APBH DMA channel n current command address register points to the
 * multiword command that is currently being executed. Commands are threaded on the
 * command address. APBH DMA Channel n is controlled by a variable sized command
 * structure. This register points to the command structure currently being executed.
 * EXAMPLE pCurCmd = (apbh_chn_cmd_t *) APBH_CHn_CURCMDAR_RD(0); // read the
 * whole register, since there is only one field pCurCmd = (apbh_chn_cmd_t *)
 * BF_RDn(APBH_CHn_CURCMDAR, 0, CMD_ADDR); // or, use multi-register bitfield read
 * macro pCurCmd = (apbh_chn_cmd_t *) APBH_CHn_CURCMDAR(0).CMD_ADDR; // or, assign
 * from bitfield of indexed register's struct
 */
typedef union _hw_apbh_chn_curcmdar
{
    uint32_t U;
    struct _hw_apbh_chn_curcmdar_bitfields
    {
        uint32_t CMD_ADDR : 32;        /*!< [31:0]  */
    } B;
} hw_apbh_chn_curcmdar_t;

/*!
 * @name Constants and macros for entire APBH_CHn_CURCMDAR register
 */
/*@{*/
#define HW_APBH_CHn_CURCMDAR_COUNT (16U)

#define HW_APBH_CHn_CURCMDAR_ADDR(x, n) ((uintptr_t)(x) + 0x100U + (0x70U * (n)))

#define HW_APBH_CHn_CURCMDAR(x, n) (*(__I hw_apbh_chn_curcmdar_t *) HW_APBH_CHn_CURCMDAR_ADDR(x, n))
#define HW_APBH_CHn_CURCMDAR_RD(x, n) (HW_APBH_CHn_CURCMDAR(x, n).U)
/*@}*/

/*
 * Constants & macros for individual APBH_CHn_CURCMDAR bitfields
 */

/*!
 * @name Register APBH_CHn_CURCMDAR, field CMD_ADDR[31:0] (RO)
 *
 * Pointer to command structure currently being processed for channel n.
 */
/*@{*/
#define BP_APBH_CHn_CURCMDAR_CMD_ADDR (0U) /*!< Bit position for APBH_CHn_CURCMDAR_CMD_ADDR. */
#define BM_APBH_CHn_CURCMDAR_CMD_ADDR (0xFFFFFFFFU) /*!< Bit mask for APBH_CHn_CURCMDAR_CMD_ADDR. */
#define BS_APBH_CHn_CURCMDAR_CMD_ADDR (32U) /*!< Bit field size in bits for APBH_CHn_CURCMDAR_CMD_ADDR. */

/*! @brief Read current value of the APBH_CHn_CURCMDAR_CMD_ADDR field. */
#define BR_APBH_CHn_CURCMDAR_CMD_ADDR(x, n) (HW_APBH_CHn_CURCMDAR(x, n).U)
/*@}*/
/*******************************************************************************
 * HW_APBH_CHn_NXTCMDAR - APBH DMA Channel n Next Command Address Register
 ******************************************************************************/

/*!
 * @brief HW_APBH_CHn_NXTCMDAR - APBH DMA Channel n Next Command Address Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The APBH DMA Channel n Next Command Address register contains the address of
 * the next multiword command to be executed. Commands are threaded on the
 * command address. Set CHAIN to 1 in the DMA command word to process command lists.
 * APBH DMA Channel n is controlled by a variable sized command structure. Software
 * loads this register with the address of the first command structure to
 * process and increments the Channel n semaphore to start processing. This register
 * points to the next command structure to be executed when the current command is
 * completed. EXAMPLE APBH_CHn_NXTCMDAR_WR(0, (reg32_t) pCommandTwoStructure); //
 * write the entire register, since there is only one field
 * BF_WRn(APBH_CHn_NXTCMDAR, 0, (reg32_t) pCommandTwoStructure); // or, use multi-register bitfield
 * write macro APBH_CHn_NXTCMDAR(0).CMD_ADDR = (reg32_t) pCommandTwoStructure; //
 * or, assign to bitfield of indexed register's struct
 */
typedef union _hw_apbh_chn_nxtcmdar
{
    uint32_t U;
    struct _hw_apbh_chn_nxtcmdar_bitfields
    {
        uint32_t CMD_ADDR : 32;        /*!< [31:0]  */
    } B;
} hw_apbh_chn_nxtcmdar_t;

/*!
 * @name Constants and macros for entire APBH_CHn_NXTCMDAR register
 */
/*@{*/
#define HW_APBH_CHn_NXTCMDAR_COUNT (16U)

#define HW_APBH_CHn_NXTCMDAR_ADDR(x, n) ((uintptr_t)(x) + 0x110U + (0x70U * (n)))

#define HW_APBH_CHn_NXTCMDAR(x, n) (*(__IO hw_apbh_chn_nxtcmdar_t *) HW_APBH_CHn_NXTCMDAR_ADDR(x, n))
#define HW_APBH_CHn_NXTCMDAR_RD(x, n) (HW_APBH_CHn_NXTCMDAR(x, n).U)
#define HW_APBH_CHn_NXTCMDAR_WR(x, n, v) (HW_APBH_CHn_NXTCMDAR(x, n).U = (v))
#define HW_APBH_CHn_NXTCMDAR_SET(x, n, v) (HW_APBH_CHn_NXTCMDAR_WR(x, n, HW_APBH_CHn_NXTCMDAR_RD(x, n) |  (v)))
#define HW_APBH_CHn_NXTCMDAR_CLR(x, n, v) (HW_APBH_CHn_NXTCMDAR_WR(x, n, HW_APBH_CHn_NXTCMDAR_RD(x, n) & ~(v)))
#define HW_APBH_CHn_NXTCMDAR_TOG(x, n, v) (HW_APBH_CHn_NXTCMDAR_WR(x, n, HW_APBH_CHn_NXTCMDAR_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual APBH_CHn_NXTCMDAR bitfields
 */

/*!
 * @name Register APBH_CHn_NXTCMDAR, field CMD_ADDR[31:0] (RW)
 *
 * Pointer to next command structure for channel n.
 */
/*@{*/
#define BP_APBH_CHn_NXTCMDAR_CMD_ADDR (0U) /*!< Bit position for APBH_CHn_NXTCMDAR_CMD_ADDR. */
#define BM_APBH_CHn_NXTCMDAR_CMD_ADDR (0xFFFFFFFFU) /*!< Bit mask for APBH_CHn_NXTCMDAR_CMD_ADDR. */
#define BS_APBH_CHn_NXTCMDAR_CMD_ADDR (32U) /*!< Bit field size in bits for APBH_CHn_NXTCMDAR_CMD_ADDR. */

/*! @brief Read current value of the APBH_CHn_NXTCMDAR_CMD_ADDR field. */
#define BR_APBH_CHn_NXTCMDAR_CMD_ADDR(x, n) (HW_APBH_CHn_NXTCMDAR(x, n).U)

/*! @brief Format value for bitfield APBH_CHn_NXTCMDAR_CMD_ADDR. */
#define BF_APBH_CHn_NXTCMDAR_CMD_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CHn_NXTCMDAR_CMD_ADDR) & BM_APBH_CHn_NXTCMDAR_CMD_ADDR)

/*! @brief Set the CMD_ADDR field to a new value. */
#define BW_APBH_CHn_NXTCMDAR_CMD_ADDR(x, n, v) (HW_APBH_CHn_NXTCMDAR_WR(x, n, v))
/*@}*/
/*******************************************************************************
 * HW_APBH_CHn_CMD - APBH DMA Channel n Command Register
 ******************************************************************************/

/*!
 * @brief HW_APBH_CHn_CMD - APBH DMA Channel n Command Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The APBH DMA Channel n command register specifies the DMA transaction to
 * perform for the current command chain item. The command register controls the
 * overall operation of each DMA command for this channel. It includes the number of
 * bytes to transfer to or from the device, the number of APB PIO command words
 * included with this command structure, whether to interrupt at command
 * completion, whether to chain an additional command to the end of this one and whether
 * this transfer is a read or write DMA transfer. EXAMPLE apbh_chn_cmd_t dma_cmd;
 * dma_cmd.XFER_COUNT = 512; // transfer 512 bytes dma_cmd.COMMAND =
 * BV_APBH_CHn_CMD_COMMAND__DMA_WRITE; // transfer to system memory from peripheral device
 * dma_cmd.CHAIN = 1; // chain an additional command structure on to the list
 * dma_cmd.IRQONCMPLT = 1; // generate an interrupt on completion of this command
 * structure
 */
typedef union _hw_apbh_chn_cmd
{
    uint32_t U;
    struct _hw_apbh_chn_cmd_bitfields
    {
        uint32_t COMMAND : 2;          /*!< [1:0]  */
        uint32_t CHAIN : 1;            /*!< [2]  */
        uint32_t IRQONCMPLT : 1;       /*!< [3]  */
        uint32_t NANDLOCK : 1;         /*!< [4]  */
        uint32_t NANDWAIT4READY : 1;   /*!< [5]  */
        uint32_t SEMAPHORE : 1;        /*!< [6]  */
        uint32_t WAIT4ENDCMD : 1;      /*!< [7]  */
        uint32_t HALTONTERMINATE : 1;  /*!< [8]  */
        uint32_t RESERVED0 : 3;        /*!< [11:9]  */
        uint32_t CMDWORDS : 4;         /*!< [15:12]  */
        uint32_t XFER_COUNT : 16;      /*!< [31:16]  */
    } B;
} hw_apbh_chn_cmd_t;

/*!
 * @name Constants and macros for entire APBH_CHn_CMD register
 */
/*@{*/
#define HW_APBH_CHn_CMD_COUNT (16U)

#define HW_APBH_CHn_CMD_ADDR(x, n) ((uintptr_t)(x) + 0x120U + (0x70U * (n)))

#define HW_APBH_CHn_CMD(x, n)    (*(__I hw_apbh_chn_cmd_t *) HW_APBH_CHn_CMD_ADDR(x, n))
#define HW_APBH_CHn_CMD_RD(x, n) (HW_APBH_CHn_CMD(x, n).U)
/*@}*/

/*
 * Constants & macros for individual APBH_CHn_CMD bitfields
 */

/*!
 * @name Register APBH_CHn_CMD, field COMMAND[1:0] (RO)
 *
 * This bitfield indicates the type of current command:
 *
 * Values:
 * - 0 - Perform any requested PIO word transfers but terminate command before
 *     any DMA transfer.
 * - 1 - Perform any requested PIO word transfers and then perform a DMA
 *     transfer from the peripheral for the specified number of bytes.
 * - 10 - Perform any requested PIO word transfers and then perform a DMA
 *     transfer to the peripheral for the specified number of bytes.
 * - 11 - Perform any requested PIO word transfers and then perform a
 *     conditional branch to the next chained device. Follow the NEXCMD_ADDR pointer if the
 *     perpheral sense is true. Follow the BUFFER_ADDRESS as a chain pointer if
 *     the peripheral sense line is false.
 */
/*@{*/
#define BP_APBH_CHn_CMD_COMMAND (0U)       /*!< Bit position for APBH_CHn_CMD_COMMAND. */
#define BM_APBH_CHn_CMD_COMMAND (0x00000003U) /*!< Bit mask for APBH_CHn_CMD_COMMAND. */
#define BS_APBH_CHn_CMD_COMMAND (2U)       /*!< Bit field size in bits for APBH_CHn_CMD_COMMAND. */

#define BV_APBH_CHn_CMD_COMMAND_NO_DMA_XFER (0U)     /*!< Bit field value for APBH_CHn_CMD_COMMAND: Perform any requested PIO word transfers but terminate command before any DMA transfer. */
#define BV_APBH_CHn_CMD_COMMAND_DMA_WRITE (0x1U)     /*!< Bit field value for APBH_CHn_CMD_COMMAND: Perform any requested PIO word transfers and then perform a DMA transfer from the peripheral for the specified number of bytes. */
#define BV_APBH_CHn_CMD_COMMAND_DMA_READ (0x2U)      /*!< Bit field value for APBH_CHn_CMD_COMMAND: Perform any requested PIO word transfers and then perform a DMA transfer to the peripheral for the specified number of bytes. */
#define BV_APBH_CHn_CMD_COMMAND_DMA_SENSE (0x3U)     /*!< Bit field value for APBH_CHn_CMD_COMMAND: Perform any requested PIO word transfers and then perform a conditional branch to the next chained device. Follow the NEXCMD_ADDR pointer if the perpheral sense is true. Follow the BUFFER_ADDRESS as a chain pointer if the peripheral sense line is false. */

/*! @brief Read current value of the APBH_CHn_CMD_COMMAND field. */
#define BR_APBH_CHn_CMD_COMMAND(x, n) (HW_APBH_CHn_CMD(x, n).B.COMMAND)
/*@}*/

/*!
 * @name Register APBH_CHn_CMD, field CHAIN[2] (RO)
 *
 * A value of one indicates that another command is chained onto the end of the
 * current command structure. At the completion of the current command, this
 * channel will follow the pointer in APBH_CHn_CMDAR to find the next command.
 */
/*@{*/
#define BP_APBH_CHn_CMD_CHAIN (2U)         /*!< Bit position for APBH_CHn_CMD_CHAIN. */
#define BM_APBH_CHn_CMD_CHAIN (0x00000004U) /*!< Bit mask for APBH_CHn_CMD_CHAIN. */
#define BS_APBH_CHn_CMD_CHAIN (1U)         /*!< Bit field size in bits for APBH_CHn_CMD_CHAIN. */

/*! @brief Read current value of the APBH_CHn_CMD_CHAIN field. */
#define BR_APBH_CHn_CMD_CHAIN(x, n) (HW_APBH_CHn_CMD(x, n).B.CHAIN)
/*@}*/

/*!
 * @name Register APBH_CHn_CMD, field IRQONCMPLT[3] (RO)
 *
 * A value of one indicates that the channel will cause the interrupt status bit
 * to be set upon completion of the current command, i.e. after the DMA transfer
 * is complete.
 */
/*@{*/
#define BP_APBH_CHn_CMD_IRQONCMPLT (3U)    /*!< Bit position for APBH_CHn_CMD_IRQONCMPLT. */
#define BM_APBH_CHn_CMD_IRQONCMPLT (0x00000008U) /*!< Bit mask for APBH_CHn_CMD_IRQONCMPLT. */
#define BS_APBH_CHn_CMD_IRQONCMPLT (1U)    /*!< Bit field size in bits for APBH_CHn_CMD_IRQONCMPLT. */

/*! @brief Read current value of the APBH_CHn_CMD_IRQONCMPLT field. */
#define BR_APBH_CHn_CMD_IRQONCMPLT(x, n) (HW_APBH_CHn_CMD(x, n).B.IRQONCMPLT)
/*@}*/

/*!
 * @name Register APBH_CHn_CMD, field NANDLOCK[4] (RO)
 *
 * A value of one indicates that the NAND DMA channel will remain "locked" in
 * the arbiter at the expense of other NAND DMA channels. It is ignored for
 * non-NAND DMA channels.
 */
/*@{*/
#define BP_APBH_CHn_CMD_NANDLOCK (4U)      /*!< Bit position for APBH_CHn_CMD_NANDLOCK. */
#define BM_APBH_CHn_CMD_NANDLOCK (0x00000010U) /*!< Bit mask for APBH_CHn_CMD_NANDLOCK. */
#define BS_APBH_CHn_CMD_NANDLOCK (1U)      /*!< Bit field size in bits for APBH_CHn_CMD_NANDLOCK. */

/*! @brief Read current value of the APBH_CHn_CMD_NANDLOCK field. */
#define BR_APBH_CHn_CMD_NANDLOCK(x, n) (HW_APBH_CHn_CMD(x, n).B.NANDLOCK)
/*@}*/

/*!
 * @name Register APBH_CHn_CMD, field NANDWAIT4READY[5] (RO)
 *
 * A value of one indicates that the NAND DMA channel will will wait until the
 * NAND device reports "ready" before executing the command. It is ignored for
 * non-NAND DMA channels.
 */
/*@{*/
#define BP_APBH_CHn_CMD_NANDWAIT4READY (5U) /*!< Bit position for APBH_CHn_CMD_NANDWAIT4READY. */
#define BM_APBH_CHn_CMD_NANDWAIT4READY (0x00000020U) /*!< Bit mask for APBH_CHn_CMD_NANDWAIT4READY. */
#define BS_APBH_CHn_CMD_NANDWAIT4READY (1U) /*!< Bit field size in bits for APBH_CHn_CMD_NANDWAIT4READY. */

/*! @brief Read current value of the APBH_CHn_CMD_NANDWAIT4READY field. */
#define BR_APBH_CHn_CMD_NANDWAIT4READY(x, n) (HW_APBH_CHn_CMD(x, n).B.NANDWAIT4READY)
/*@}*/

/*!
 * @name Register APBH_CHn_CMD, field SEMAPHORE[6] (RO)
 *
 * A value of one indicates that the channel will decrement its semaphore at the
 * completion of the current command structure. If the semaphore decrements to
 * zero, then this channel stalls until software increments it again.
 */
/*@{*/
#define BP_APBH_CHn_CMD_SEMAPHORE (6U)     /*!< Bit position for APBH_CHn_CMD_SEMAPHORE. */
#define BM_APBH_CHn_CMD_SEMAPHORE (0x00000040U) /*!< Bit mask for APBH_CHn_CMD_SEMAPHORE. */
#define BS_APBH_CHn_CMD_SEMAPHORE (1U)     /*!< Bit field size in bits for APBH_CHn_CMD_SEMAPHORE. */

/*! @brief Read current value of the APBH_CHn_CMD_SEMAPHORE field. */
#define BR_APBH_CHn_CMD_SEMAPHORE(x, n) (HW_APBH_CHn_CMD(x, n).B.SEMAPHORE)
/*@}*/

/*!
 * @name Register APBH_CHn_CMD, field WAIT4ENDCMD[7] (RO)
 *
 * A value of one indicates that the channel will wait for the end of command
 * signal to be sent from the APBH device to the DMA before starting the next DMA
 * command.
 */
/*@{*/
#define BP_APBH_CHn_CMD_WAIT4ENDCMD (7U)   /*!< Bit position for APBH_CHn_CMD_WAIT4ENDCMD. */
#define BM_APBH_CHn_CMD_WAIT4ENDCMD (0x00000080U) /*!< Bit mask for APBH_CHn_CMD_WAIT4ENDCMD. */
#define BS_APBH_CHn_CMD_WAIT4ENDCMD (1U)   /*!< Bit field size in bits for APBH_CHn_CMD_WAIT4ENDCMD. */

/*! @brief Read current value of the APBH_CHn_CMD_WAIT4ENDCMD field. */
#define BR_APBH_CHn_CMD_WAIT4ENDCMD(x, n) (HW_APBH_CHn_CMD(x, n).B.WAIT4ENDCMD)
/*@}*/

/*!
 * @name Register APBH_CHn_CMD, field HALTONTERMINATE[8] (RO)
 *
 * A value of one indicates that the channel will immeditately terminate the
 * current descriptor and halt the DMA channel if a terminate signal is set. A value
 * of 0 will still cause an immediate terminate of the channel if the terminate
 * signal is set, but the channel will continue as if the count had been
 * exhausted, meaning it will honor IRQONCMPLT, CHAIN, SEMAPHORE, and WAIT4ENDCMD.
 */
/*@{*/
#define BP_APBH_CHn_CMD_HALTONTERMINATE (8U) /*!< Bit position for APBH_CHn_CMD_HALTONTERMINATE. */
#define BM_APBH_CHn_CMD_HALTONTERMINATE (0x00000100U) /*!< Bit mask for APBH_CHn_CMD_HALTONTERMINATE. */
#define BS_APBH_CHn_CMD_HALTONTERMINATE (1U) /*!< Bit field size in bits for APBH_CHn_CMD_HALTONTERMINATE. */

/*! @brief Read current value of the APBH_CHn_CMD_HALTONTERMINATE field. */
#define BR_APBH_CHn_CMD_HALTONTERMINATE(x, n) (HW_APBH_CHn_CMD(x, n).B.HALTONTERMINATE)
/*@}*/

/*!
 * @name Register APBH_CHn_CMD, field CMDWORDS[15:12] (RO)
 *
 * This field indicates the number of command words to send to the GPMI0,
 * starting with the base PIO address of the GPMI0 control register and incrementing
 * from there. Zero means transfer NO command words
 */
/*@{*/
#define BP_APBH_CHn_CMD_CMDWORDS (12U)     /*!< Bit position for APBH_CHn_CMD_CMDWORDS. */
#define BM_APBH_CHn_CMD_CMDWORDS (0x0000F000U) /*!< Bit mask for APBH_CHn_CMD_CMDWORDS. */
#define BS_APBH_CHn_CMD_CMDWORDS (4U)      /*!< Bit field size in bits for APBH_CHn_CMD_CMDWORDS. */

/*! @brief Read current value of the APBH_CHn_CMD_CMDWORDS field. */
#define BR_APBH_CHn_CMD_CMDWORDS(x, n) (HW_APBH_CHn_CMD(x, n).B.CMDWORDS)
/*@}*/

/*!
 * @name Register APBH_CHn_CMD, field XFER_COUNT[31:16] (RO)
 *
 * This field indicates the number of bytes to transfer to or from the
 * appropriate PIO register in the GPMI0 device. A value of 0 indicates a 64 KBytes
 * transfer.
 */
/*@{*/
#define BP_APBH_CHn_CMD_XFER_COUNT (16U)   /*!< Bit position for APBH_CHn_CMD_XFER_COUNT. */
#define BM_APBH_CHn_CMD_XFER_COUNT (0xFFFF0000U) /*!< Bit mask for APBH_CHn_CMD_XFER_COUNT. */
#define BS_APBH_CHn_CMD_XFER_COUNT (16U)   /*!< Bit field size in bits for APBH_CHn_CMD_XFER_COUNT. */

/*! @brief Read current value of the APBH_CHn_CMD_XFER_COUNT field. */
#define BR_APBH_CHn_CMD_XFER_COUNT(x, n) (HW_APBH_CHn_CMD(x, n).B.XFER_COUNT)
/*@}*/
/*******************************************************************************
 * HW_APBH_CHn_BAR - APBH DMA Channel n Buffer Address Register
 ******************************************************************************/

/*!
 * @brief HW_APBH_CHn_BAR - APBH DMA Channel n Buffer Address Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The APBH DMA Channel n buffer address register contains a pointer to the data
 * buffer for the transfer. For immediate forms, the data is taken from this
 * register. This is a byte address which means transfers can start on any byte
 * boundary. This register holds a pointer to the data buffer in system memory. After
 * the command values have been read into the DMA controller and the device
 * controlled by this channel, then the DMA transfer will begin, to or from the
 * buffer pointed to by this register. EXAMPLE apbh_chn_bar_t dma_data;
 * dma_data.ADDRESS = (reg32_t) pDataBuffer;
 */
typedef union _hw_apbh_chn_bar
{
    uint32_t U;
    struct _hw_apbh_chn_bar_bitfields
    {
        uint32_t ADDRESS : 32;         /*!< [31:0]  */
    } B;
} hw_apbh_chn_bar_t;

/*!
 * @name Constants and macros for entire APBH_CHn_BAR register
 */
/*@{*/
#define HW_APBH_CHn_BAR_COUNT (16U)

#define HW_APBH_CHn_BAR_ADDR(x, n) ((uintptr_t)(x) + 0x130U + (0x70U * (n)))

#define HW_APBH_CHn_BAR(x, n)    (*(__I hw_apbh_chn_bar_t *) HW_APBH_CHn_BAR_ADDR(x, n))
#define HW_APBH_CHn_BAR_RD(x, n) (HW_APBH_CHn_BAR(x, n).U)
/*@}*/

/*
 * Constants & macros for individual APBH_CHn_BAR bitfields
 */

/*!
 * @name Register APBH_CHn_BAR, field ADDRESS[31:0] (RO)
 *
 * Address of system memory buffer to be read or written over the AHB bus.
 */
/*@{*/
#define BP_APBH_CHn_BAR_ADDRESS (0U)       /*!< Bit position for APBH_CHn_BAR_ADDRESS. */
#define BM_APBH_CHn_BAR_ADDRESS (0xFFFFFFFFU) /*!< Bit mask for APBH_CHn_BAR_ADDRESS. */
#define BS_APBH_CHn_BAR_ADDRESS (32U)      /*!< Bit field size in bits for APBH_CHn_BAR_ADDRESS. */

/*! @brief Read current value of the APBH_CHn_BAR_ADDRESS field. */
#define BR_APBH_CHn_BAR_ADDRESS(x, n) (HW_APBH_CHn_BAR(x, n).U)
/*@}*/
/*******************************************************************************
 * HW_APBH_CHn_SEMA - APBH DMA Channel n Semaphore Register
 ******************************************************************************/

/*!
 * @brief HW_APBH_CHn_SEMA - APBH DMA Channel n Semaphore Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The APBH DMA Channel n semaphore register is used to synchronize the ARM
 * platform instruction stream and the DMA chain processing state. Each DMA channel
 * has an 8 bit counting semaphore that is used to synchronize between the program
 * stream and and the DMA chain processing. DMA processing continues until the
 * DMA attempts to decrement a semaphore that has already reached a value of zero.
 * When the attempt is made, the DMA channel is stalled until software
 * increments the semaphore count. EXAMPLE BF_WR(APBH_CHn_SEMA, 0, INCREMENT_SEMA, 2); //
 * increment semaphore by two current_sema = BF_RD(APBH_CHn_SEMA, 0, PHORE); //
 * get instantaneous value
 */
typedef union _hw_apbh_chn_sema
{
    uint32_t U;
    struct _hw_apbh_chn_sema_bitfields
    {
        uint32_t INCREMENT_SEMA : 8;   /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t PHORE : 8;            /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_apbh_chn_sema_t;

/*!
 * @name Constants and macros for entire APBH_CHn_SEMA register
 */
/*@{*/
#define HW_APBH_CHn_SEMA_COUNT (16U)

#define HW_APBH_CHn_SEMA_ADDR(x, n) ((uintptr_t)(x) + 0x140U + (0x70U * (n)))

#define HW_APBH_CHn_SEMA(x, n)   (*(__IO hw_apbh_chn_sema_t *) HW_APBH_CHn_SEMA_ADDR(x, n))
#define HW_APBH_CHn_SEMA_RD(x, n) (HW_APBH_CHn_SEMA(x, n).U)
#define HW_APBH_CHn_SEMA_WR(x, n, v) (HW_APBH_CHn_SEMA(x, n).U = (v))
#define HW_APBH_CHn_SEMA_SET(x, n, v) (HW_APBH_CHn_SEMA_WR(x, n, HW_APBH_CHn_SEMA_RD(x, n) |  (v)))
#define HW_APBH_CHn_SEMA_CLR(x, n, v) (HW_APBH_CHn_SEMA_WR(x, n, HW_APBH_CHn_SEMA_RD(x, n) & ~(v)))
#define HW_APBH_CHn_SEMA_TOG(x, n, v) (HW_APBH_CHn_SEMA_WR(x, n, HW_APBH_CHn_SEMA_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual APBH_CHn_SEMA bitfields
 */

/*!
 * @name Register APBH_CHn_SEMA, field INCREMENT_SEMA[7:0] (RW)
 *
 * The value written to this field is added to the semaphore count in an atomic
 * way such that simultaneous software adds and DMA hardware substracts happening
 * on the same clock are protected. This bit field reads back a value of 0x00.
 * Writing a value of 0x02 increments the semaphore count by two, unless the DMA
 * channel decrements the count on the same clock, then the count is incremented
 * by a net one.
 */
/*@{*/
#define BP_APBH_CHn_SEMA_INCREMENT_SEMA (0U) /*!< Bit position for APBH_CHn_SEMA_INCREMENT_SEMA. */
#define BM_APBH_CHn_SEMA_INCREMENT_SEMA (0x000000FFU) /*!< Bit mask for APBH_CHn_SEMA_INCREMENT_SEMA. */
#define BS_APBH_CHn_SEMA_INCREMENT_SEMA (8U) /*!< Bit field size in bits for APBH_CHn_SEMA_INCREMENT_SEMA. */

/*! @brief Read current value of the APBH_CHn_SEMA_INCREMENT_SEMA field. */
#define BR_APBH_CHn_SEMA_INCREMENT_SEMA(x, n) (HW_APBH_CHn_SEMA(x, n).B.INCREMENT_SEMA)

/*! @brief Format value for bitfield APBH_CHn_SEMA_INCREMENT_SEMA. */
#define BF_APBH_CHn_SEMA_INCREMENT_SEMA(v) ((uint32_t)((uint32_t)(v) << BP_APBH_CHn_SEMA_INCREMENT_SEMA) & BM_APBH_CHn_SEMA_INCREMENT_SEMA)

/*! @brief Set the INCREMENT_SEMA field to a new value. */
#define BW_APBH_CHn_SEMA_INCREMENT_SEMA(x, n, v) (HW_APBH_CHn_SEMA_WR(x, n, (HW_APBH_CHn_SEMA_RD(x, n) & ~BM_APBH_CHn_SEMA_INCREMENT_SEMA) | BF_APBH_CHn_SEMA_INCREMENT_SEMA(v)))
/*@}*/

/*!
 * @name Register APBH_CHn_SEMA, field PHORE[23:16] (RO)
 *
 * This read-only field shows the current (instantaneous) value of the semaphore
 * counter.
 */
/*@{*/
#define BP_APBH_CHn_SEMA_PHORE (16U)       /*!< Bit position for APBH_CHn_SEMA_PHORE. */
#define BM_APBH_CHn_SEMA_PHORE (0x00FF0000U) /*!< Bit mask for APBH_CHn_SEMA_PHORE. */
#define BS_APBH_CHn_SEMA_PHORE (8U)        /*!< Bit field size in bits for APBH_CHn_SEMA_PHORE. */

/*! @brief Read current value of the APBH_CHn_SEMA_PHORE field. */
#define BR_APBH_CHn_SEMA_PHORE(x, n) (HW_APBH_CHn_SEMA(x, n).B.PHORE)
/*@}*/
/*******************************************************************************
 * HW_APBH_CHn_DEBUG1 - AHB to APBH DMA Channel n Debug Information
 ******************************************************************************/

/*!
 * @brief HW_APBH_CHn_DEBUG1 - AHB to APBH DMA Channel n Debug Information (RO)
 *
 * Reset value: 0x00A00000U
 *
 * This register gives debug visibility into the APBH DMA Channel n state
 * machine and controls. This register allows debug visibility of the APBH DMA Channel
 * n.
 */
typedef union _hw_apbh_chn_debug1
{
    uint32_t U;
    struct _hw_apbh_chn_debug1_bitfields
    {
        uint32_t STATEMACHINE : 5;     /*!< [4:0]  */
        uint32_t RSVD1 : 15;           /*!< [19:5]  */
        uint32_t WR_FIFO_FULL : 1;     /*!< [20]  */
        uint32_t WR_FIFO_EMPTY : 1;    /*!< [21]  */
        uint32_t RD_FIFO_FULL : 1;     /*!< [22]  */
        uint32_t RD_FIFO_EMPTY : 1;    /*!< [23]  */
        uint32_t NEXTCMDADDRVALID : 1; /*!< [24]  */
        uint32_t LOCK : 1;             /*!< [25]  */
        uint32_t READY : 1;            /*!< [26]  */
        uint32_t SENSE : 1;            /*!< [27]  */
        uint32_t END : 1;              /*!< [28]  */
        uint32_t KICK : 1;             /*!< [29]  */
        uint32_t BURST : 1;            /*!< [30]  */
        uint32_t REQ : 1;              /*!< [31]  */
    } B;
} hw_apbh_chn_debug1_t;

/*!
 * @name Constants and macros for entire APBH_CHn_DEBUG1 register
 */
/*@{*/
#define HW_APBH_CHn_DEBUG1_COUNT (16U)

#define HW_APBH_CHn_DEBUG1_ADDR(x, n) ((uintptr_t)(x) + 0x150U + (0x70U * (n)))

#define HW_APBH_CHn_DEBUG1(x, n) (*(__I hw_apbh_chn_debug1_t *) HW_APBH_CHn_DEBUG1_ADDR(x, n))
#define HW_APBH_CHn_DEBUG1_RD(x, n) (HW_APBH_CHn_DEBUG1(x, n).U)
/*@}*/

/*
 * Constants & macros for individual APBH_CHn_DEBUG1 bitfields
 */

/*!
 * @name Register APBH_CHn_DEBUG1, field STATEMACHINE[4:0] (RO)
 *
 * PIO Display of the DMA Channel n state machine state.
 *
 * Values:
 * - 0 - This is the idle state of the DMA state machine.
 * - 1 - State in which the DMA is waiting to receive the first word of a
 *     command.
 * - 10 - State in which the DMA is waiting to receive the third word of a
 *     command.
 * - 11 - State in which the DMA is waiting to receive the second word of a
 *     command.
 * - 100 - The state machine processes the descriptor command field in this
 *     state and branches accordingly.
 * - 101 - The state machine waits in this state for the PIO APB cycles to
 *     complete.
 * - 110 - State in which the DMA is waiting to receive the fourth word of a
 *     command, or waiting to receive the PIO words when PIO count is greater than 1.
 * - 111 - This state determines whether another PIO cycle needs to occur before
 *     starting DMA transfers.
 * - 1000 - During a read transfers, the state machine enters this state waiting
 *     for the last bytes to be pushed out on the APB.
 * - 1001 - When an AHB read request occurs, the state machine waits in this
 *     state for the AHB transfer to complete.
 * - 1100 - During DMA Write transfers, the state machine waits in this state
 *     until the AHB master arbiter accepts the request from this channel.
 * - 1101 - During DMA Read transfers, the state machine waits in this state
 *     until the AHB master arbiter accepts the request from this channel.
 * - 1110 - Upon completion of the DMA transfers, this state checks the value of
 *     the Chain bit and branches accordingly.
 * - 1111 - The state machine goes to this state after the DMA transfers are
 *     complete, and determines what step to take next.
 * - 10100 - When a terminate signal is set, the state machine enters this state
 *     until the current AHB transfer is completed.
 * - 10101 - When the Wait for Command End bit is set, the state machine enters
 *     this state until the DMA device indicates that the command is complete.
 * - 11100 - During DMA Write transfers, the state machine waits in this state
 *     until the AHB master completes the write to the AHB memory space.
 * - 11101 - If HALTONTERMINATE is set and a terminate signal is set, the state
 *     machine enters this state and effectively halts. A channel reset is
 *     required to exit this state
 * - 11110 - If the Chain bit is a 0, the state machine enters this state and
 *     effectively halts.
 * - 11111 - When the NAND Wait for Ready bit is set, the state machine enters
 *     this state until the GPMI device indicates that the external device is
 *     ready.
 */
/*@{*/
#define BP_APBH_CHn_DEBUG1_STATEMACHINE (0U) /*!< Bit position for APBH_CHn_DEBUG1_STATEMACHINE. */
#define BM_APBH_CHn_DEBUG1_STATEMACHINE (0x0000001FU) /*!< Bit mask for APBH_CHn_DEBUG1_STATEMACHINE. */
#define BS_APBH_CHn_DEBUG1_STATEMACHINE (5U) /*!< Bit field size in bits for APBH_CHn_DEBUG1_STATEMACHINE. */

#define BV_APBH_CHn_DEBUG1_STATEMACHINE_IDLE (0U)    /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: This is the idle state of the DMA state machine. */
#define BV_APBH_CHn_DEBUG1_STATEMACHINE_REQ_CMD1 (0x1U) /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: State in which the DMA is waiting to receive the first word of a command. */
#define BV_APBH_CHn_DEBUG1_STATEMACHINE_REQ_CMD3 (0x2U) /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: State in which the DMA is waiting to receive the third word of a command. */
#define BV_APBH_CHn_DEBUG1_STATEMACHINE_REQ_CMD2 (0x3U) /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: State in which the DMA is waiting to receive the second word of a command. */
#define BV_APBH_CHn_DEBUG1_STATEMACHINE_XFER_DECODE (0x4U) /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: The state machine processes the descriptor command field in this state and branches accordingly. */
#define BV_APBH_CHn_DEBUG1_STATEMACHINE_REQ_WAIT (0x5U) /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: The state machine waits in this state for the PIO APB cycles to complete. */
#define BV_APBH_CHn_DEBUG1_STATEMACHINE_REQ_CMD4 (0x6U) /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: State in which the DMA is waiting to receive the fourth word of a command, or waiting to receive the PIO words when PIO count is greater than 1. */
#define BV_APBH_CHn_DEBUG1_STATEMACHINE_PIO_REQ (0x7U) /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: This state determines whether another PIO cycle needs to occur before starting DMA transfers. */
#define BV_APBH_CHn_DEBUG1_STATEMACHINE_READ_FLUSH (0x8U) /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: During a read transfers, the state machine enters this state waiting for the last bytes to be pushed out on the APB. */
#define BV_APBH_CHn_DEBUG1_STATEMACHINE_READ_WAIT (0x9U) /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: When an AHB read request occurs, the state machine waits in this state for the AHB transfer to complete. */
#define BV_APBH_CHn_DEBUG1_STATEMACHINE_WRITE (0xCU) /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: During DMA Write transfers, the state machine waits in this state until the AHB master arbiter accepts the request from this channel. */
#define BV_APBH_CHn_DEBUG1_STATEMACHINE_READ_REQ (0xDU) /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: During DMA Read transfers, the state machine waits in this state until the AHB master arbiter accepts the request from this channel. */
#define BV_APBH_CHn_DEBUG1_STATEMACHINE_CHECK_CHAIN (0xEU) /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: Upon completion of the DMA transfers, this state checks the value of the Chain bit and branches accordingly. */
#define BV_APBH_CHn_DEBUG1_STATEMACHINE_XFER_COMPLETE (0xFU) /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: The state machine goes to this state after the DMA transfers are complete, and determines what step to take next. */
#define BV_APBH_CHn_DEBUG1_STATEMACHINE_TERMINATE (0x14U) /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: When a terminate signal is set, the state machine enters this state until the current AHB transfer is completed. */
#define BV_APBH_CHn_DEBUG1_STATEMACHINE_WAIT_END (0x15U) /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: When the Wait for Command End bit is set, the state machine enters this state until the DMA device indicates that the command is complete. */
#define BV_APBH_CHn_DEBUG1_STATEMACHINE_WRITE_WAIT (0x1CU) /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: During DMA Write transfers, the state machine waits in this state until the AHB master completes the write to the AHB memory space. */
#define BV_APBH_CHn_DEBUG1_STATEMACHINE_HALT_AFTER_TERM (0x1DU) /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: If HALTONTERMINATE is set and a terminate signal is set, the state machine enters this state and effectively halts. A channel reset is required to exit this state */
#define BV_APBH_CHn_DEBUG1_STATEMACHINE_CHECK_WAIT (0x1EU) /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: If the Chain bit is a 0, the state machine enters this state and effectively halts. */
#define BV_APBH_CHn_DEBUG1_STATEMACHINE_WAIT_READY (0x1FU) /*!< Bit field value for APBH_CHn_DEBUG1_STATEMACHINE: When the NAND Wait for Ready bit is set, the state machine enters this state until the GPMI device indicates that the external device is ready. */

/*! @brief Read current value of the APBH_CHn_DEBUG1_STATEMACHINE field. */
#define BR_APBH_CHn_DEBUG1_STATEMACHINE(x, n) (HW_APBH_CHn_DEBUG1(x, n).B.STATEMACHINE)
/*@}*/

/*!
 * @name Register APBH_CHn_DEBUG1, field RSVD1[19:5] (RU)
 *
 * Reserved
 */
/*@{*/
#define BP_APBH_CHn_DEBUG1_RSVD1 (5U)      /*!< Bit position for APBH_CHn_DEBUG1_RSVD1. */
#define BM_APBH_CHn_DEBUG1_RSVD1 (0x000FFFE0U) /*!< Bit mask for APBH_CHn_DEBUG1_RSVD1. */
#define BS_APBH_CHn_DEBUG1_RSVD1 (15U)     /*!< Bit field size in bits for APBH_CHn_DEBUG1_RSVD1. */
/*@}*/

/*!
 * @name Register APBH_CHn_DEBUG1, field WR_FIFO_FULL[20] (RO)
 *
 * This bit reflects the current state of the DMA Channel's Write FIFO Full
 * signal.
 */
/*@{*/
#define BP_APBH_CHn_DEBUG1_WR_FIFO_FULL (20U) /*!< Bit position for APBH_CHn_DEBUG1_WR_FIFO_FULL. */
#define BM_APBH_CHn_DEBUG1_WR_FIFO_FULL (0x00100000U) /*!< Bit mask for APBH_CHn_DEBUG1_WR_FIFO_FULL. */
#define BS_APBH_CHn_DEBUG1_WR_FIFO_FULL (1U) /*!< Bit field size in bits for APBH_CHn_DEBUG1_WR_FIFO_FULL. */

/*! @brief Read current value of the APBH_CHn_DEBUG1_WR_FIFO_FULL field. */
#define BR_APBH_CHn_DEBUG1_WR_FIFO_FULL(x, n) (HW_APBH_CHn_DEBUG1(x, n).B.WR_FIFO_FULL)
/*@}*/

/*!
 * @name Register APBH_CHn_DEBUG1, field WR_FIFO_EMPTY[21] (RO)
 *
 * This bit reflects the current state of the DMA Channel's Write FIFO Empty
 * signal.
 */
/*@{*/
#define BP_APBH_CHn_DEBUG1_WR_FIFO_EMPTY (21U) /*!< Bit position for APBH_CHn_DEBUG1_WR_FIFO_EMPTY. */
#define BM_APBH_CHn_DEBUG1_WR_FIFO_EMPTY (0x00200000U) /*!< Bit mask for APBH_CHn_DEBUG1_WR_FIFO_EMPTY. */
#define BS_APBH_CHn_DEBUG1_WR_FIFO_EMPTY (1U) /*!< Bit field size in bits for APBH_CHn_DEBUG1_WR_FIFO_EMPTY. */

/*! @brief Read current value of the APBH_CHn_DEBUG1_WR_FIFO_EMPTY field. */
#define BR_APBH_CHn_DEBUG1_WR_FIFO_EMPTY(x, n) (HW_APBH_CHn_DEBUG1(x, n).B.WR_FIFO_EMPTY)
/*@}*/

/*!
 * @name Register APBH_CHn_DEBUG1, field RD_FIFO_FULL[22] (RO)
 *
 * This bit reflects the current state of the DMA Channel's Read FIFO Full
 * signal.
 */
/*@{*/
#define BP_APBH_CHn_DEBUG1_RD_FIFO_FULL (22U) /*!< Bit position for APBH_CHn_DEBUG1_RD_FIFO_FULL. */
#define BM_APBH_CHn_DEBUG1_RD_FIFO_FULL (0x00400000U) /*!< Bit mask for APBH_CHn_DEBUG1_RD_FIFO_FULL. */
#define BS_APBH_CHn_DEBUG1_RD_FIFO_FULL (1U) /*!< Bit field size in bits for APBH_CHn_DEBUG1_RD_FIFO_FULL. */

/*! @brief Read current value of the APBH_CHn_DEBUG1_RD_FIFO_FULL field. */
#define BR_APBH_CHn_DEBUG1_RD_FIFO_FULL(x, n) (HW_APBH_CHn_DEBUG1(x, n).B.RD_FIFO_FULL)
/*@}*/

/*!
 * @name Register APBH_CHn_DEBUG1, field RD_FIFO_EMPTY[23] (RO)
 *
 * This bit reflects the current state of the DMA Channel's Read FIFO Empty
 * signal.
 */
/*@{*/
#define BP_APBH_CHn_DEBUG1_RD_FIFO_EMPTY (23U) /*!< Bit position for APBH_CHn_DEBUG1_RD_FIFO_EMPTY. */
#define BM_APBH_CHn_DEBUG1_RD_FIFO_EMPTY (0x00800000U) /*!< Bit mask for APBH_CHn_DEBUG1_RD_FIFO_EMPTY. */
#define BS_APBH_CHn_DEBUG1_RD_FIFO_EMPTY (1U) /*!< Bit field size in bits for APBH_CHn_DEBUG1_RD_FIFO_EMPTY. */

/*! @brief Read current value of the APBH_CHn_DEBUG1_RD_FIFO_EMPTY field. */
#define BR_APBH_CHn_DEBUG1_RD_FIFO_EMPTY(x, n) (HW_APBH_CHn_DEBUG1(x, n).B.RD_FIFO_EMPTY)
/*@}*/

/*!
 * @name Register APBH_CHn_DEBUG1, field NEXTCMDADDRVALID[24] (RO)
 *
 * This bit reflects the internal bit which indicates whether the channel's next
 * command address is valid.
 */
/*@{*/
#define BP_APBH_CHn_DEBUG1_NEXTCMDADDRVALID (24U) /*!< Bit position for APBH_CHn_DEBUG1_NEXTCMDADDRVALID. */
#define BM_APBH_CHn_DEBUG1_NEXTCMDADDRVALID (0x01000000U) /*!< Bit mask for APBH_CHn_DEBUG1_NEXTCMDADDRVALID. */
#define BS_APBH_CHn_DEBUG1_NEXTCMDADDRVALID (1U) /*!< Bit field size in bits for APBH_CHn_DEBUG1_NEXTCMDADDRVALID. */

/*! @brief Read current value of the APBH_CHn_DEBUG1_NEXTCMDADDRVALID field. */
#define BR_APBH_CHn_DEBUG1_NEXTCMDADDRVALID(x, n) (HW_APBH_CHn_DEBUG1(x, n).B.NEXTCMDADDRVALID)
/*@}*/

/*!
 * @name Register APBH_CHn_DEBUG1, field LOCK[25] (RU)
 *
 * This bit is reserved for this Channel and always reads 0.
 */
/*@{*/
#define BP_APBH_CHn_DEBUG1_LOCK (25U)      /*!< Bit position for APBH_CHn_DEBUG1_LOCK. */
#define BM_APBH_CHn_DEBUG1_LOCK (0x02000000U) /*!< Bit mask for APBH_CHn_DEBUG1_LOCK. */
#define BS_APBH_CHn_DEBUG1_LOCK (1U)       /*!< Bit field size in bits for APBH_CHn_DEBUG1_LOCK. */
/*@}*/

/*!
 * @name Register APBH_CHn_DEBUG1, field READY[26] (RO)
 *
 * This bit is reserved for this DMA Channel and always reads 0.
 */
/*@{*/
#define BP_APBH_CHn_DEBUG1_READY (26U)     /*!< Bit position for APBH_CHn_DEBUG1_READY. */
#define BM_APBH_CHn_DEBUG1_READY (0x04000000U) /*!< Bit mask for APBH_CHn_DEBUG1_READY. */
#define BS_APBH_CHn_DEBUG1_READY (1U)      /*!< Bit field size in bits for APBH_CHn_DEBUG1_READY. */

/*! @brief Read current value of the APBH_CHn_DEBUG1_READY field. */
#define BR_APBH_CHn_DEBUG1_READY(x, n) (HW_APBH_CHn_DEBUG1(x, n).B.READY)
/*@}*/

/*!
 * @name Register APBH_CHn_DEBUG1, field SENSE[27] (RU)
 *
 * This bit is reserved for this DMA Channel and always reads 0.
 */
/*@{*/
#define BP_APBH_CHn_DEBUG1_SENSE (27U)     /*!< Bit position for APBH_CHn_DEBUG1_SENSE. */
#define BM_APBH_CHn_DEBUG1_SENSE (0x08000000U) /*!< Bit mask for APBH_CHn_DEBUG1_SENSE. */
#define BS_APBH_CHn_DEBUG1_SENSE (1U)      /*!< Bit field size in bits for APBH_CHn_DEBUG1_SENSE. */
/*@}*/

/*!
 * @name Register APBH_CHn_DEBUG1, field END[28] (RO)
 *
 * This bit reflects the current state of the DMA End Command Signal sent from
 * the APB Device
 */
/*@{*/
#define BP_APBH_CHn_DEBUG1_END (28U)       /*!< Bit position for APBH_CHn_DEBUG1_END. */
#define BM_APBH_CHn_DEBUG1_END (0x10000000U) /*!< Bit mask for APBH_CHn_DEBUG1_END. */
#define BS_APBH_CHn_DEBUG1_END (1U)        /*!< Bit field size in bits for APBH_CHn_DEBUG1_END. */

/*! @brief Read current value of the APBH_CHn_DEBUG1_END field. */
#define BR_APBH_CHn_DEBUG1_END(x, n) (HW_APBH_CHn_DEBUG1(x, n).B.END)
/*@}*/

/*!
 * @name Register APBH_CHn_DEBUG1, field KICK[29] (RO)
 *
 * This bit reflects the current state of the DMA Kick Signal sent to the APB
 * Device
 */
/*@{*/
#define BP_APBH_CHn_DEBUG1_KICK (29U)      /*!< Bit position for APBH_CHn_DEBUG1_KICK. */
#define BM_APBH_CHn_DEBUG1_KICK (0x20000000U) /*!< Bit mask for APBH_CHn_DEBUG1_KICK. */
#define BS_APBH_CHn_DEBUG1_KICK (1U)       /*!< Bit field size in bits for APBH_CHn_DEBUG1_KICK. */

/*! @brief Read current value of the APBH_CHn_DEBUG1_KICK field. */
#define BR_APBH_CHn_DEBUG1_KICK(x, n) (HW_APBH_CHn_DEBUG1(x, n).B.KICK)
/*@}*/

/*!
 * @name Register APBH_CHn_DEBUG1, field BURST[30] (RO)
 *
 * This bit reflects the current state of the DMA Burst Signal from the APB
 * device
 */
/*@{*/
#define BP_APBH_CHn_DEBUG1_BURST (30U)     /*!< Bit position for APBH_CHn_DEBUG1_BURST. */
#define BM_APBH_CHn_DEBUG1_BURST (0x40000000U) /*!< Bit mask for APBH_CHn_DEBUG1_BURST. */
#define BS_APBH_CHn_DEBUG1_BURST (1U)      /*!< Bit field size in bits for APBH_CHn_DEBUG1_BURST. */

/*! @brief Read current value of the APBH_CHn_DEBUG1_BURST field. */
#define BR_APBH_CHn_DEBUG1_BURST(x, n) (HW_APBH_CHn_DEBUG1(x, n).B.BURST)
/*@}*/

/*!
 * @name Register APBH_CHn_DEBUG1, field REQ[31] (RO)
 *
 * This bit reflects the current state of the DMA Request Signal from the APB
 * device
 */
/*@{*/
#define BP_APBH_CHn_DEBUG1_REQ (31U)       /*!< Bit position for APBH_CHn_DEBUG1_REQ. */
#define BM_APBH_CHn_DEBUG1_REQ (0x80000000U) /*!< Bit mask for APBH_CHn_DEBUG1_REQ. */
#define BS_APBH_CHn_DEBUG1_REQ (1U)        /*!< Bit field size in bits for APBH_CHn_DEBUG1_REQ. */

/*! @brief Read current value of the APBH_CHn_DEBUG1_REQ field. */
#define BR_APBH_CHn_DEBUG1_REQ(x, n) (HW_APBH_CHn_DEBUG1(x, n).B.REQ)
/*@}*/
/*******************************************************************************
 * HW_APBH_CHn_DEBUG2 - AHB to APBH DMA Channel n Debug Information
 ******************************************************************************/

/*!
 * @brief HW_APBH_CHn_DEBUG2 - AHB to APBH DMA Channel n Debug Information (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register gives debug visibility for the APB and AHB byte counts for DMA
 * Channel n. This register allows debug visibility of the APBH DMA Channel n.
 */
typedef union _hw_apbh_chn_debug2
{
    uint32_t U;
    struct _hw_apbh_chn_debug2_bitfields
    {
        uint32_t AHB_BYTES : 16;       /*!< [15:0]  */
        uint32_t APB_BYTES : 16;       /*!< [31:16]  */
    } B;
} hw_apbh_chn_debug2_t;

/*!
 * @name Constants and macros for entire APBH_CHn_DEBUG2 register
 */
/*@{*/
#define HW_APBH_CHn_DEBUG2_COUNT (16U)

#define HW_APBH_CHn_DEBUG2_ADDR(x, n) ((uintptr_t)(x) + 0x160U + (0x70U * (n)))

#define HW_APBH_CHn_DEBUG2(x, n) (*(__I hw_apbh_chn_debug2_t *) HW_APBH_CHn_DEBUG2_ADDR(x, n))
#define HW_APBH_CHn_DEBUG2_RD(x, n) (HW_APBH_CHn_DEBUG2(x, n).U)
/*@}*/

/*
 * Constants & macros for individual APBH_CHn_DEBUG2 bitfields
 */

/*!
 * @name Register APBH_CHn_DEBUG2, field AHB_BYTES[15:0] (RO)
 *
 * This value reflects the current number of AHB bytes remaining to be
 * transfered in the current transfer.
 */
/*@{*/
#define BP_APBH_CHn_DEBUG2_AHB_BYTES (0U)  /*!< Bit position for APBH_CHn_DEBUG2_AHB_BYTES. */
#define BM_APBH_CHn_DEBUG2_AHB_BYTES (0x0000FFFFU) /*!< Bit mask for APBH_CHn_DEBUG2_AHB_BYTES. */
#define BS_APBH_CHn_DEBUG2_AHB_BYTES (16U) /*!< Bit field size in bits for APBH_CHn_DEBUG2_AHB_BYTES. */

/*! @brief Read current value of the APBH_CHn_DEBUG2_AHB_BYTES field. */
#define BR_APBH_CHn_DEBUG2_AHB_BYTES(x, n) (HW_APBH_CHn_DEBUG2(x, n).B.AHB_BYTES)
/*@}*/

/*!
 * @name Register APBH_CHn_DEBUG2, field APB_BYTES[31:16] (RO)
 *
 * This value reflects the current number of APB bytes remaining to be
 * transfered in the current transfer.
 */
/*@{*/
#define BP_APBH_CHn_DEBUG2_APB_BYTES (16U) /*!< Bit position for APBH_CHn_DEBUG2_APB_BYTES. */
#define BM_APBH_CHn_DEBUG2_APB_BYTES (0xFFFF0000U) /*!< Bit mask for APBH_CHn_DEBUG2_APB_BYTES. */
#define BS_APBH_CHn_DEBUG2_APB_BYTES (16U) /*!< Bit field size in bits for APBH_CHn_DEBUG2_APB_BYTES. */

/*! @brief Read current value of the APBH_CHn_DEBUG2_APB_BYTES field. */
#define BR_APBH_CHn_DEBUG2_APB_BYTES(x, n) (HW_APBH_CHn_DEBUG2(x, n).B.APB_BYTES)
/*@}*/

/*******************************************************************************
 * HW_APBH_VERSION - APBH Bridge Version Register
 ******************************************************************************/

/*!
 * @brief HW_APBH_VERSION - APBH Bridge Version Register (RO)
 *
 * Reset value: 0x03010000U
 *
 * This register always returns a known read value for debug purposes it
 * indicates the version of the block. This register indicates the RTL version in use.
 * EXAMPLE if (APBH_VERSION.B.MAJOR != 3) Error();
 */
typedef union _hw_apbh_version
{
    uint32_t U;
    struct _hw_apbh_version_bitfields
    {
        uint32_t STEP : 16;            /*!< [15:0]  */
        uint32_t MINOR : 8;            /*!< [23:16]  */
        uint32_t MAJOR : 8;            /*!< [31:24]  */
    } B;
} hw_apbh_version_t;

/*!
 * @name Constants and macros for entire APBH_VERSION register
 */
/*@{*/
#define HW_APBH_VERSION_ADDR(x)  ((uintptr_t)(x) + 0x800U)

#define HW_APBH_VERSION(x)       (*(__I hw_apbh_version_t *) HW_APBH_VERSION_ADDR(x))
#define HW_APBH_VERSION_RD(x)    (HW_APBH_VERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual APBH_VERSION bitfields
 */

/*!
 * @name Register APBH_VERSION, field STEP[15:0] (RO)
 *
 * Fixed read-only value reflecting the stepping of the RTL version.
 */
/*@{*/
#define BP_APBH_VERSION_STEP (0U)          /*!< Bit position for APBH_VERSION_STEP. */
#define BM_APBH_VERSION_STEP (0x0000FFFFU) /*!< Bit mask for APBH_VERSION_STEP. */
#define BS_APBH_VERSION_STEP (16U)         /*!< Bit field size in bits for APBH_VERSION_STEP. */

/*! @brief Read current value of the APBH_VERSION_STEP field. */
#define BR_APBH_VERSION_STEP(x) (HW_APBH_VERSION(x).B.STEP)
/*@}*/

/*!
 * @name Register APBH_VERSION, field MINOR[23:16] (RO)
 *
 * Fixed read-only value reflecting the MINOR field of the RTL version.
 */
/*@{*/
#define BP_APBH_VERSION_MINOR (16U)        /*!< Bit position for APBH_VERSION_MINOR. */
#define BM_APBH_VERSION_MINOR (0x00FF0000U) /*!< Bit mask for APBH_VERSION_MINOR. */
#define BS_APBH_VERSION_MINOR (8U)         /*!< Bit field size in bits for APBH_VERSION_MINOR. */

/*! @brief Read current value of the APBH_VERSION_MINOR field. */
#define BR_APBH_VERSION_MINOR(x) (HW_APBH_VERSION(x).B.MINOR)
/*@}*/

/*!
 * @name Register APBH_VERSION, field MAJOR[31:24] (RO)
 *
 * Fixed read-only value reflecting the MAJOR field of the RTL version.
 */
/*@{*/
#define BP_APBH_VERSION_MAJOR (24U)        /*!< Bit position for APBH_VERSION_MAJOR. */
#define BM_APBH_VERSION_MAJOR (0xFF000000U) /*!< Bit mask for APBH_VERSION_MAJOR. */
#define BS_APBH_VERSION_MAJOR (8U)         /*!< Bit field size in bits for APBH_VERSION_MAJOR. */

/*! @brief Read current value of the APBH_VERSION_MAJOR field. */
#define BR_APBH_VERSION_MAJOR(x) (HW_APBH_VERSION(x).B.MAJOR)
/*@}*/

/*******************************************************************************
 * hw_apbh_t - module struct
 ******************************************************************************/
/*!
 * @brief All APBH module registers.
 */
#pragma pack(1)
typedef struct _hw_apbh
{
    __IO hw_apbh_ctrl0_t CTRL0;            /*!< [0x0] AHB to APBH Bridge Control and Status Register 0 */
    uint8_t _reserved0[12];
    __IO hw_apbh_ctrl1_t CTRL1;            /*!< [0x10] AHB to APBH Bridge Control and Status Register 1 */
    uint8_t _reserved1[12];
    __IO hw_apbh_ctrl2_t CTRL2;            /*!< [0x20] AHB to APBH Bridge Control and Status Register 2 */
    uint8_t _reserved2[12];
    __IO hw_apbh_channel_ctrl_t CHANNEL_CTRL; /*!< [0x30] AHB to APBH Bridge Channel Register */
    uint8_t _reserved3[12];
    __I hw_apbh_devsel_t DEVSEL;           /*!< [0x40] AHB to APBH DMA Device Assignment Register */
    uint8_t _reserved4[12];
    __IO hw_apbh_dma_burst_size_t DMA_BURST_SIZE; /*!< [0x50] AHB to APBH DMA burst size */
    uint8_t _reserved5[12];
    __IO hw_apbh_debug_t DEBUGr;           /*!< [0x60] AHB to APBH DMA Debug Register */
    uint8_t _reserved6[156];
    struct {
        __I hw_apbh_chn_curcmdar_t CHn_CURCMDAR; /*!< [0x100] APBH DMA Channel n Current Command Address Register */
        uint8_t _reserved0[12];
        __IO hw_apbh_chn_nxtcmdar_t CHn_NXTCMDAR; /*!< [0x110] APBH DMA Channel n Next Command Address Register */
        uint8_t _reserved1[12];
        __I hw_apbh_chn_cmd_t CHn_CMD;     /*!< [0x120] APBH DMA Channel n Command Register */
        uint8_t _reserved2[12];
        __I hw_apbh_chn_bar_t CHn_BAR;     /*!< [0x130] APBH DMA Channel n Buffer Address Register */
        uint8_t _reserved3[12];
        __IO hw_apbh_chn_sema_t CHn_SEMA;  /*!< [0x140] APBH DMA Channel n Semaphore Register */
        uint8_t _reserved4[12];
        __I hw_apbh_chn_debug1_t CHn_DEBUG1; /*!< [0x150] AHB to APBH DMA Channel n Debug Information */
        uint8_t _reserved5[12];
        __I hw_apbh_chn_debug2_t CHn_DEBUG2; /*!< [0x160] AHB to APBH DMA Channel n Debug Information */
        uint8_t _reserved6[12];
    } CH[16];
    __I hw_apbh_version_t VERSION;         /*!< [0x800] APBH Bridge Version Register */
} hw_apbh_t;
#pragma pack()

/*! @brief Macro to access all APBH registers. */
/*! @param x APBH module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_APBH_REGS(APBH_BASE)</code>. */
#define HW_APBH_REGS(x) (*(hw_apbh_t *)(x))

/*
 * iMX7D BCH
 *
 * BCH Register Reference Index
 *
 * Registers defined in this header file:
 * - HW_BCH_CTRL - Hardware BCH ECC Accelerator Control Register
 * - HW_BCH_STATUS0 - Hardware ECC Accelerator Status Register 0
 * - HW_BCH_MODE - Hardware ECC Accelerator Mode Register
 * - HW_BCH_ENCODEPTR - Hardware BCH ECC Loopback Encode Buffer Register
 * - HW_BCH_DATAPTR - Hardware BCH ECC Loopback Data Buffer Register
 * - HW_BCH_METAPTR - Hardware BCH ECC Loopback Metadata Buffer Register
 * - HW_BCH_LAYOUTSELECT - Hardware ECC Accelerator Layout Select Register
 * - HW_BCH_FLASH0LAYOUT0 - Hardware BCH ECC Flash 0 Layout 0 Register
 * - HW_BCH_FLASH0LAYOUT1 - Hardware BCH ECC Flash 0 Layout 1 Register
 * - HW_BCH_FLASH1LAYOUT0 - Hardware BCH ECC Flash 1 Layout 0 Register
 * - HW_BCH_FLASH1LAYOUT1 - Hardware BCH ECC Flash 1 Layout 1 Register
 * - HW_BCH_FLASH2LAYOUT0 - Hardware BCH ECC Flash 2 Layout 0 Register
 * - HW_BCH_FLASH2LAYOUT1 - Hardware BCH ECC Flash 2 Layout 1 Register
 * - HW_BCH_FLASH3LAYOUT0 - Hardware BCH ECC Flash 3 Layout 0 Register
 * - HW_BCH_FLASH3LAYOUT1 - Hardware BCH ECC Flash 3 Layout 1 Register
 * - HW_BCH_DEBUG0 - Hardware BCH ECC Debug Register0
 * - HW_BCH_DBGKESREAD - KES Debug Read Register
 * - HW_BCH_DBGCSFEREAD - Chien Search Debug Read Register
 * - HW_BCH_DBGSYNDGENREAD - Syndrome Generator Debug Read Register
 * - HW_BCH_DBGAHBMREAD - Bus Master and ECC Controller Debug Read Register
 * - HW_BCH_BLOCKNAME - Block Name Register
 * - HW_BCH_VERSION - BCH Version Register
 * - HW_BCH_DEBUG1 - Hardware BCH ECC Debug Register 1
 *
 * - hw_bch_t - Struct containing all module registers.
 */

#define HW_BCH_INSTANCE_COUNT (1U) /*!< Number of instances of the BCH module. */
#define HW_BCH (0U) /*!< Instance number for BCH. */
#define BCH_BASE              (0x33004000U) /*!< Base address for BCH. */
/*! Array initializer of BCH base addresses. */
#define BCH_BASE_ADDRS        { BCH_BASE }

/*******************************************************************************
 * HW_BCH_CTRL - Hardware BCH ECC Accelerator Control Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_CTRL - Hardware BCH ECC Accelerator Control Register (RW)
 *
 * Reset value: 0xC0000000U
 *
 * The BCH CTRL provides overall control of the hardware ECC accelerator
 */
typedef union _hw_bch_ctrl
{
    uint32_t U;
    struct _hw_bch_ctrl_bitfields
    {
        uint32_t COMPLETE_IRQ : 1;     /*!< [0]  */
        uint32_t RSVD0 : 1;            /*!< [1] This field is reserved. */
        uint32_t DEBUG_STALL_IRQ : 1;  /*!< [2]  */
        uint32_t BM_ERROR_IRQ : 1;     /*!< [3]  */
        uint32_t RSVD1 : 4;            /*!< [7:4] This field is reserved. */
        uint32_t COMPLETE_IRQ_EN : 1;  /*!< [8]  */
        uint32_t RSVD2 : 1;            /*!< [9] This field is reserved. */
        uint32_t DEBUG_STALL_IRQ_EN : 1; /*!< [10]  */
        uint32_t RSVD3 : 5;            /*!< [15:11] This field is reserved. */
        uint32_t M2M_ENABLE : 1;       /*!< [16]  */
        uint32_t M2M_ENCODE : 1;       /*!< [17]  */
        uint32_t M2M_LAYOUT : 2;       /*!< [19:18]  */
        uint32_t RSVD4 : 2;            /*!< [21:20] This field is reserved. */
        uint32_t DEBUGSYNDROME : 1;    /*!< [22]  */
        uint32_t RSVD5 : 7;            /*!< [29:23] This field is reserved. */
        uint32_t CLKGATE : 1;          /*!< [30]  */
        uint32_t SFTRST : 1;           /*!< [31]  */
    } B;
} hw_bch_ctrl_t;

/*!
 * @name Constants and macros for entire BCH_CTRL register
 */
/*@{*/
#define HW_BCH_CTRL_ADDR(x)      ((uintptr_t)(x) + 0x0U)
#define HW_BCH_CTRL_SET_ADDR(x)  (HW_BCH_CTRL_ADDR(x) + 0x4U)
#define HW_BCH_CTRL_CLR_ADDR(x)  (HW_BCH_CTRL_ADDR(x) + 0x8U)
#define HW_BCH_CTRL_TOG_ADDR(x)  (HW_BCH_CTRL_ADDR(x) + 0xCU)

#define HW_BCH_CTRL(x)           (*(__IO hw_bch_ctrl_t *) HW_BCH_CTRL_ADDR(x))
#define HW_BCH_CTRL_RD(x)        (HW_BCH_CTRL(x).U)
#define HW_BCH_CTRL_WR(x, v)     (HW_BCH_CTRL(x).U = (v))
#define HW_BCH_CTRL_SET(x, v)    ((*(uint32_t *) HW_BCH_CTRL_SET_ADDR(x)) = (v))
#define HW_BCH_CTRL_CLR(x, v)    ((*(uint32_t *) HW_BCH_CTRL_CLR_ADDR(x)) = (v))
#define HW_BCH_CTRL_TOG(x, v)    ((*(uint32_t *) HW_BCH_CTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_CTRL bitfields
 */

/*!
 * @name Register BCH_CTRL, field COMPLETE_IRQ[0] (RW)
 *
 * This bit indicates the state of the external interrupt line. Write a 1 to the
 * SCT clear address to clear the interrupt status bit. NOTE: subsequent ECC
 * completions will be held off as long as this bit is set. Be sure to read the data
 * from BCH_STATUS0, 1 before clearing this interrupt bit.
 */
/*@{*/
#define BP_BCH_CTRL_COMPLETE_IRQ (0U)      /*!< Bit position for BCH_CTRL_COMPLETE_IRQ. */
#define BM_BCH_CTRL_COMPLETE_IRQ (0x00000001U) /*!< Bit mask for BCH_CTRL_COMPLETE_IRQ. */
#define BS_BCH_CTRL_COMPLETE_IRQ (1U)      /*!< Bit field size in bits for BCH_CTRL_COMPLETE_IRQ. */

/*! @brief Read current value of the BCH_CTRL_COMPLETE_IRQ field. */
#define BR_BCH_CTRL_COMPLETE_IRQ(x) (HW_BCH_CTRL(x).B.COMPLETE_IRQ)

/*! @brief Format value for bitfield BCH_CTRL_COMPLETE_IRQ. */
#define BF_BCH_CTRL_COMPLETE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_COMPLETE_IRQ) & BM_BCH_CTRL_COMPLETE_IRQ)

/*! @brief Set the COMPLETE_IRQ field to a new value. */
#define BW_BCH_CTRL_COMPLETE_IRQ(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_COMPLETE_IRQ) | BF_BCH_CTRL_COMPLETE_IRQ(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field RSVD0[1] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_CTRL_RSVD0    (1U)          /*!< Bit position for BCH_CTRL_RSVD0. */
#define BM_BCH_CTRL_RSVD0    (0x00000002U) /*!< Bit mask for BCH_CTRL_RSVD0. */
#define BS_BCH_CTRL_RSVD0    (1U)          /*!< Bit field size in bits for BCH_CTRL_RSVD0. */

/*! @brief Read current value of the BCH_CTRL_RSVD0 field. */
#define BR_BCH_CTRL_RSVD0(x) (HW_BCH_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register BCH_CTRL, field DEBUG_STALL_IRQ[2] (RW)
 *
 * DEBUG STALL Interrupt Status. Write a 1 to the SCT clear address to clear the
 * interrupt status bit.
 */
/*@{*/
#define BP_BCH_CTRL_DEBUG_STALL_IRQ (2U)   /*!< Bit position for BCH_CTRL_DEBUG_STALL_IRQ. */
#define BM_BCH_CTRL_DEBUG_STALL_IRQ (0x00000004U) /*!< Bit mask for BCH_CTRL_DEBUG_STALL_IRQ. */
#define BS_BCH_CTRL_DEBUG_STALL_IRQ (1U)   /*!< Bit field size in bits for BCH_CTRL_DEBUG_STALL_IRQ. */

/*! @brief Read current value of the BCH_CTRL_DEBUG_STALL_IRQ field. */
#define BR_BCH_CTRL_DEBUG_STALL_IRQ(x) (HW_BCH_CTRL(x).B.DEBUG_STALL_IRQ)

/*! @brief Format value for bitfield BCH_CTRL_DEBUG_STALL_IRQ. */
#define BF_BCH_CTRL_DEBUG_STALL_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_DEBUG_STALL_IRQ) & BM_BCH_CTRL_DEBUG_STALL_IRQ)

/*! @brief Set the DEBUG_STALL_IRQ field to a new value. */
#define BW_BCH_CTRL_DEBUG_STALL_IRQ(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_DEBUG_STALL_IRQ) | BF_BCH_CTRL_DEBUG_STALL_IRQ(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field BM_ERROR_IRQ[3] (RW)
 *
 * AHB Bus interface Error Interrupt Status. Write a 1 to the SCT clear address
 * to clear the interrupt status bit.
 */
/*@{*/
#define BP_BCH_CTRL_BM_ERROR_IRQ (3U)      /*!< Bit position for BCH_CTRL_BM_ERROR_IRQ. */
#define BM_BCH_CTRL_BM_ERROR_IRQ (0x00000008U) /*!< Bit mask for BCH_CTRL_BM_ERROR_IRQ. */
#define BS_BCH_CTRL_BM_ERROR_IRQ (1U)      /*!< Bit field size in bits for BCH_CTRL_BM_ERROR_IRQ. */

/*! @brief Read current value of the BCH_CTRL_BM_ERROR_IRQ field. */
#define BR_BCH_CTRL_BM_ERROR_IRQ(x) (HW_BCH_CTRL(x).B.BM_ERROR_IRQ)

/*! @brief Format value for bitfield BCH_CTRL_BM_ERROR_IRQ. */
#define BF_BCH_CTRL_BM_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_BM_ERROR_IRQ) & BM_BCH_CTRL_BM_ERROR_IRQ)

/*! @brief Set the BM_ERROR_IRQ field to a new value. */
#define BW_BCH_CTRL_BM_ERROR_IRQ(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_BM_ERROR_IRQ) | BF_BCH_CTRL_BM_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field RSVD1[7:4] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_CTRL_RSVD1    (4U)          /*!< Bit position for BCH_CTRL_RSVD1. */
#define BM_BCH_CTRL_RSVD1    (0x000000F0U) /*!< Bit mask for BCH_CTRL_RSVD1. */
#define BS_BCH_CTRL_RSVD1    (4U)          /*!< Bit field size in bits for BCH_CTRL_RSVD1. */

/*! @brief Read current value of the BCH_CTRL_RSVD1 field. */
#define BR_BCH_CTRL_RSVD1(x) (HW_BCH_CTRL(x).B.RSVD1)
/*@}*/

/*!
 * @name Register BCH_CTRL, field COMPLETE_IRQ_EN[8] (RW)
 *
 * 1 = interrupt on completion of correction is enabled.
 */
/*@{*/
#define BP_BCH_CTRL_COMPLETE_IRQ_EN (8U)   /*!< Bit position for BCH_CTRL_COMPLETE_IRQ_EN. */
#define BM_BCH_CTRL_COMPLETE_IRQ_EN (0x00000100U) /*!< Bit mask for BCH_CTRL_COMPLETE_IRQ_EN. */
#define BS_BCH_CTRL_COMPLETE_IRQ_EN (1U)   /*!< Bit field size in bits for BCH_CTRL_COMPLETE_IRQ_EN. */

/*! @brief Read current value of the BCH_CTRL_COMPLETE_IRQ_EN field. */
#define BR_BCH_CTRL_COMPLETE_IRQ_EN(x) (HW_BCH_CTRL(x).B.COMPLETE_IRQ_EN)

/*! @brief Format value for bitfield BCH_CTRL_COMPLETE_IRQ_EN. */
#define BF_BCH_CTRL_COMPLETE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_COMPLETE_IRQ_EN) & BM_BCH_CTRL_COMPLETE_IRQ_EN)

/*! @brief Set the COMPLETE_IRQ_EN field to a new value. */
#define BW_BCH_CTRL_COMPLETE_IRQ_EN(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_COMPLETE_IRQ_EN) | BF_BCH_CTRL_COMPLETE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field RSVD2[9] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_CTRL_RSVD2    (9U)          /*!< Bit position for BCH_CTRL_RSVD2. */
#define BM_BCH_CTRL_RSVD2    (0x00000200U) /*!< Bit mask for BCH_CTRL_RSVD2. */
#define BS_BCH_CTRL_RSVD2    (1U)          /*!< Bit field size in bits for BCH_CTRL_RSVD2. */

/*! @brief Read current value of the BCH_CTRL_RSVD2 field. */
#define BR_BCH_CTRL_RSVD2(x) (HW_BCH_CTRL(x).B.RSVD2)
/*@}*/

/*!
 * @name Register BCH_CTRL, field DEBUG_STALL_IRQ_EN[10] (RW)
 *
 * 1 = interrupt on debug stall mode is enabled. The IRQ is raised on every block
 */
/*@{*/
#define BP_BCH_CTRL_DEBUG_STALL_IRQ_EN (10U) /*!< Bit position for BCH_CTRL_DEBUG_STALL_IRQ_EN. */
#define BM_BCH_CTRL_DEBUG_STALL_IRQ_EN (0x00000400U) /*!< Bit mask for BCH_CTRL_DEBUG_STALL_IRQ_EN. */
#define BS_BCH_CTRL_DEBUG_STALL_IRQ_EN (1U) /*!< Bit field size in bits for BCH_CTRL_DEBUG_STALL_IRQ_EN. */

/*! @brief Read current value of the BCH_CTRL_DEBUG_STALL_IRQ_EN field. */
#define BR_BCH_CTRL_DEBUG_STALL_IRQ_EN(x) (HW_BCH_CTRL(x).B.DEBUG_STALL_IRQ_EN)

/*! @brief Format value for bitfield BCH_CTRL_DEBUG_STALL_IRQ_EN. */
#define BF_BCH_CTRL_DEBUG_STALL_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_DEBUG_STALL_IRQ_EN) & BM_BCH_CTRL_DEBUG_STALL_IRQ_EN)

/*! @brief Set the DEBUG_STALL_IRQ_EN field to a new value. */
#define BW_BCH_CTRL_DEBUG_STALL_IRQ_EN(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_DEBUG_STALL_IRQ_EN) | BF_BCH_CTRL_DEBUG_STALL_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field RSVD3[15:11] (RO)
 *
 * This read-only field is reserved and always has the value 0
 */
/*@{*/
#define BP_BCH_CTRL_RSVD3    (11U)         /*!< Bit position for BCH_CTRL_RSVD3. */
#define BM_BCH_CTRL_RSVD3    (0x0000F800U) /*!< Bit mask for BCH_CTRL_RSVD3. */
#define BS_BCH_CTRL_RSVD3    (5U)          /*!< Bit field size in bits for BCH_CTRL_RSVD3. */

/*! @brief Read current value of the BCH_CTRL_RSVD3 field. */
#define BR_BCH_CTRL_RSVD3(x) (HW_BCH_CTRL(x).B.RSVD3)
/*@}*/

/*!
 * @name Register BCH_CTRL, field M2M_ENABLE[16] (RW)
 *
 * NOTE! WRITING THIS BIT INITIATES A MEMORY-TO-MEMORY OPERATION. The BCH module
 * must be inactive (not processing data from the GPMI) when this bit is set.
 * The M2M_ENCODE and M2M_LAYOUT bits as well as the ENCODEPTR, DATAPTR, and
 * METAPTR registers are used for memory-to-memory operations and must be correctly
 * programmed before writing this bit.
 */
/*@{*/
#define BP_BCH_CTRL_M2M_ENABLE (16U)       /*!< Bit position for BCH_CTRL_M2M_ENABLE. */
#define BM_BCH_CTRL_M2M_ENABLE (0x00010000U) /*!< Bit mask for BCH_CTRL_M2M_ENABLE. */
#define BS_BCH_CTRL_M2M_ENABLE (1U)        /*!< Bit field size in bits for BCH_CTRL_M2M_ENABLE. */

/*! @brief Read current value of the BCH_CTRL_M2M_ENABLE field. */
#define BR_BCH_CTRL_M2M_ENABLE(x) (HW_BCH_CTRL(x).B.M2M_ENABLE)

/*! @brief Format value for bitfield BCH_CTRL_M2M_ENABLE. */
#define BF_BCH_CTRL_M2M_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_M2M_ENABLE) & BM_BCH_CTRL_M2M_ENABLE)

/*! @brief Set the M2M_ENABLE field to a new value. */
#define BW_BCH_CTRL_M2M_ENABLE(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_M2M_ENABLE) | BF_BCH_CTRL_M2M_ENABLE(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field M2M_ENCODE[17] (RW)
 *
 * Selects encode (parity generation) or decode (correction) mode for
 * memory-to-memory operations.
 */
/*@{*/
#define BP_BCH_CTRL_M2M_ENCODE (17U)       /*!< Bit position for BCH_CTRL_M2M_ENCODE. */
#define BM_BCH_CTRL_M2M_ENCODE (0x00020000U) /*!< Bit mask for BCH_CTRL_M2M_ENCODE. */
#define BS_BCH_CTRL_M2M_ENCODE (1U)        /*!< Bit field size in bits for BCH_CTRL_M2M_ENCODE. */

/*! @brief Read current value of the BCH_CTRL_M2M_ENCODE field. */
#define BR_BCH_CTRL_M2M_ENCODE(x) (HW_BCH_CTRL(x).B.M2M_ENCODE)

/*! @brief Format value for bitfield BCH_CTRL_M2M_ENCODE. */
#define BF_BCH_CTRL_M2M_ENCODE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_M2M_ENCODE) & BM_BCH_CTRL_M2M_ENCODE)

/*! @brief Set the M2M_ENCODE field to a new value. */
#define BW_BCH_CTRL_M2M_ENCODE(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_M2M_ENCODE) | BF_BCH_CTRL_M2M_ENCODE(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field M2M_LAYOUT[19:18] (RW)
 *
 * Selects the flash page format for memory-to-memory operations.
 */
/*@{*/
#define BP_BCH_CTRL_M2M_LAYOUT (18U)       /*!< Bit position for BCH_CTRL_M2M_LAYOUT. */
#define BM_BCH_CTRL_M2M_LAYOUT (0x000C0000U) /*!< Bit mask for BCH_CTRL_M2M_LAYOUT. */
#define BS_BCH_CTRL_M2M_LAYOUT (2U)        /*!< Bit field size in bits for BCH_CTRL_M2M_LAYOUT. */

/*! @brief Read current value of the BCH_CTRL_M2M_LAYOUT field. */
#define BR_BCH_CTRL_M2M_LAYOUT(x) (HW_BCH_CTRL(x).B.M2M_LAYOUT)

/*! @brief Format value for bitfield BCH_CTRL_M2M_LAYOUT. */
#define BF_BCH_CTRL_M2M_LAYOUT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_M2M_LAYOUT) & BM_BCH_CTRL_M2M_LAYOUT)

/*! @brief Set the M2M_LAYOUT field to a new value. */
#define BW_BCH_CTRL_M2M_LAYOUT(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_M2M_LAYOUT) | BF_BCH_CTRL_M2M_LAYOUT(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field RSVD4[21:20] (RO)
 *
 * This read-only field is reserved and always has the value 0
 */
/*@{*/
#define BP_BCH_CTRL_RSVD4    (20U)         /*!< Bit position for BCH_CTRL_RSVD4. */
#define BM_BCH_CTRL_RSVD4    (0x00300000U) /*!< Bit mask for BCH_CTRL_RSVD4. */
#define BS_BCH_CTRL_RSVD4    (2U)          /*!< Bit field size in bits for BCH_CTRL_RSVD4. */

/*! @brief Read current value of the BCH_CTRL_RSVD4 field. */
#define BR_BCH_CTRL_RSVD4(x) (HW_BCH_CTRL(x).B.RSVD4)
/*@}*/

/*!
 * @name Register BCH_CTRL, field DEBUGSYNDROME[22] (RW)
 *
 * (For debug purposes only). Enable write of computed syndromes to memory on
 * BCH decode operations. Computed syndromes will be written to the auxiliary
 * buffer after the status block. Syndromes will be written as padded 16-bit values.
 */
/*@{*/
#define BP_BCH_CTRL_DEBUGSYNDROME (22U)    /*!< Bit position for BCH_CTRL_DEBUGSYNDROME. */
#define BM_BCH_CTRL_DEBUGSYNDROME (0x00400000U) /*!< Bit mask for BCH_CTRL_DEBUGSYNDROME. */
#define BS_BCH_CTRL_DEBUGSYNDROME (1U)     /*!< Bit field size in bits for BCH_CTRL_DEBUGSYNDROME. */

/*! @brief Read current value of the BCH_CTRL_DEBUGSYNDROME field. */
#define BR_BCH_CTRL_DEBUGSYNDROME(x) (HW_BCH_CTRL(x).B.DEBUGSYNDROME)

/*! @brief Format value for bitfield BCH_CTRL_DEBUGSYNDROME. */
#define BF_BCH_CTRL_DEBUGSYNDROME(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_DEBUGSYNDROME) & BM_BCH_CTRL_DEBUGSYNDROME)

/*! @brief Set the DEBUGSYNDROME field to a new value. */
#define BW_BCH_CTRL_DEBUGSYNDROME(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_DEBUGSYNDROME) | BF_BCH_CTRL_DEBUGSYNDROME(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field RSVD5[29:23] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_CTRL_RSVD5    (23U)         /*!< Bit position for BCH_CTRL_RSVD5. */
#define BM_BCH_CTRL_RSVD5    (0x3F800000U) /*!< Bit mask for BCH_CTRL_RSVD5. */
#define BS_BCH_CTRL_RSVD5    (7U)          /*!< Bit field size in bits for BCH_CTRL_RSVD5. */

/*! @brief Read current value of the BCH_CTRL_RSVD5 field. */
#define BR_BCH_CTRL_RSVD5(x) (HW_BCH_CTRL(x).B.RSVD5)
/*@}*/

/*!
 * @name Register BCH_CTRL, field CLKGATE[30] (RW)
 *
 * This bit must be set to 0 for normal operation. When set to 1 it gates off
 * the clocks to the block.
 *
 * Values:
 * - 0 - Allow BCH to operate normally.
 * - 1 - Do not clock BCH gates in order to minimize power consumption.
 */
/*@{*/
#define BP_BCH_CTRL_CLKGATE  (30U)         /*!< Bit position for BCH_CTRL_CLKGATE. */
#define BM_BCH_CTRL_CLKGATE  (0x40000000U) /*!< Bit mask for BCH_CTRL_CLKGATE. */
#define BS_BCH_CTRL_CLKGATE  (1U)          /*!< Bit field size in bits for BCH_CTRL_CLKGATE. */

#define BV_BCH_CTRL_CLKGATE_RUN        (0U)          /*!< Bit field value for BCH_CTRL_CLKGATE: Allow BCH to operate normally. */
#define BV_BCH_CTRL_CLKGATE_NO_CLKS    (0x1U)        /*!< Bit field value for BCH_CTRL_CLKGATE: Do not clock BCH gates in order to minimize power consumption. */

/*! @brief Read current value of the BCH_CTRL_CLKGATE field. */
#define BR_BCH_CTRL_CLKGATE(x) (HW_BCH_CTRL(x).B.CLKGATE)

/*! @brief Format value for bitfield BCH_CTRL_CLKGATE. */
#define BF_BCH_CTRL_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_CLKGATE) & BM_BCH_CTRL_CLKGATE)

/*! @brief Set the CLKGATE field to a new value. */
#define BW_BCH_CTRL_CLKGATE(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_CLKGATE) | BF_BCH_CTRL_CLKGATE(v)))
/*@}*/

/*!
 * @name Register BCH_CTRL, field SFTRST[31] (RW)
 *
 * Set this bit to 0 to enable normal BCH operation. Set this bit to 1 (default)
 * to disable clocking with the BCH and hold it in its reset (lowest power)
 * state. This bit can be turned on and then off to reset the BCH block to its
 * default state. This bit resets all state machines except for the AHB master state
 * machine
 *
 * Values:
 * - 0 - Allow BCH to operate normally.
 * - 1 - Hold BCH in reset.
 */
/*@{*/
#define BP_BCH_CTRL_SFTRST   (31U)         /*!< Bit position for BCH_CTRL_SFTRST. */
#define BM_BCH_CTRL_SFTRST   (0x80000000U) /*!< Bit mask for BCH_CTRL_SFTRST. */
#define BS_BCH_CTRL_SFTRST   (1U)          /*!< Bit field size in bits for BCH_CTRL_SFTRST. */

#define BV_BCH_CTRL_SFTRST_RUN         (0U)          /*!< Bit field value for BCH_CTRL_SFTRST: Allow BCH to operate normally. */
#define BV_BCH_CTRL_SFTRST_RESET       (0x1U)        /*!< Bit field value for BCH_CTRL_SFTRST: Hold BCH in reset. */

/*! @brief Read current value of the BCH_CTRL_SFTRST field. */
#define BR_BCH_CTRL_SFTRST(x) (HW_BCH_CTRL(x).B.SFTRST)

/*! @brief Format value for bitfield BCH_CTRL_SFTRST. */
#define BF_BCH_CTRL_SFTRST(v) ((uint32_t)((uint32_t)(v) << BP_BCH_CTRL_SFTRST) & BM_BCH_CTRL_SFTRST)

/*! @brief Set the SFTRST field to a new value. */
#define BW_BCH_CTRL_SFTRST(x, v) (HW_BCH_CTRL_WR(x, (HW_BCH_CTRL_RD(x) & ~BM_BCH_CTRL_SFTRST) | BF_BCH_CTRL_SFTRST(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_STATUS0 - Hardware ECC Accelerator Status Register 0
 ******************************************************************************/

/*!
 * @brief HW_BCH_STATUS0 - Hardware ECC Accelerator Status Register 0 (RO)
 *
 * Reset value: 0x00000010U
 *
 * The BCH STAT register provides visibility into the run-time status of the BCH
 * and status information when processing is complete. It provides overall
 * status of the hardware ECC accelerator.
 */
typedef union _hw_bch_status0
{
    uint32_t U;
    struct _hw_bch_status0_bitfields
    {
        uint32_t RSVD0 : 2;            /*!< [1:0] This field is reserved. */
        uint32_t UNCORRECTABLE : 1;    /*!< [2]  */
        uint32_t CORRECTED : 1;        /*!< [3]  */
        uint32_t ALLONES : 1;          /*!< [4]  */
        uint32_t RSVD1 : 3;            /*!< [7:5] This field is reserved. */
        uint32_t STATUS_BLK0 : 8;      /*!< [15:8]  */
        uint32_t COMPLETED_CE : 4;     /*!< [19:16]  */
        uint32_t HANDLE : 12;          /*!< [31:20]  */
    } B;
} hw_bch_status0_t;

/*!
 * @name Constants and macros for entire BCH_STATUS0 register
 */
/*@{*/
#define HW_BCH_STATUS0_ADDR(x)   ((uintptr_t)(x) + 0x10U)
#define HW_BCH_STATUS0_SET_ADDR(x) (HW_BCH_STATUS0_ADDR(x) + 0x4U)
#define HW_BCH_STATUS0_CLR_ADDR(x) (HW_BCH_STATUS0_ADDR(x) + 0x8U)
#define HW_BCH_STATUS0_TOG_ADDR(x) (HW_BCH_STATUS0_ADDR(x) + 0xCU)

#define HW_BCH_STATUS0(x)        (*(__I hw_bch_status0_t *) HW_BCH_STATUS0_ADDR(x))
#define HW_BCH_STATUS0_RD(x)     (HW_BCH_STATUS0(x).U)
/*@}*/

/*
 * Constants & macros for individual BCH_STATUS0 bitfields
 */

/*!
 * @name Register BCH_STATUS0, field RSVD0[1:0] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_STATUS0_RSVD0 (0U)          /*!< Bit position for BCH_STATUS0_RSVD0. */
#define BM_BCH_STATUS0_RSVD0 (0x00000003U) /*!< Bit mask for BCH_STATUS0_RSVD0. */
#define BS_BCH_STATUS0_RSVD0 (2U)          /*!< Bit field size in bits for BCH_STATUS0_RSVD0. */

/*! @brief Read current value of the BCH_STATUS0_RSVD0 field. */
#define BR_BCH_STATUS0_RSVD0(x) (HW_BCH_STATUS0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register BCH_STATUS0, field UNCORRECTABLE[2] (RO)
 *
 * 1 = Uncorrectable error encountered during last processing cycle.
 */
/*@{*/
#define BP_BCH_STATUS0_UNCORRECTABLE (2U)  /*!< Bit position for BCH_STATUS0_UNCORRECTABLE. */
#define BM_BCH_STATUS0_UNCORRECTABLE (0x00000004U) /*!< Bit mask for BCH_STATUS0_UNCORRECTABLE. */
#define BS_BCH_STATUS0_UNCORRECTABLE (1U)  /*!< Bit field size in bits for BCH_STATUS0_UNCORRECTABLE. */

/*! @brief Read current value of the BCH_STATUS0_UNCORRECTABLE field. */
#define BR_BCH_STATUS0_UNCORRECTABLE(x) (HW_BCH_STATUS0(x).B.UNCORRECTABLE)
/*@}*/

/*!
 * @name Register BCH_STATUS0, field CORRECTED[3] (RO)
 *
 * 1 = At least one correctable error encountered during last processing cycle.
 */
/*@{*/
#define BP_BCH_STATUS0_CORRECTED (3U)      /*!< Bit position for BCH_STATUS0_CORRECTED. */
#define BM_BCH_STATUS0_CORRECTED (0x00000008U) /*!< Bit mask for BCH_STATUS0_CORRECTED. */
#define BS_BCH_STATUS0_CORRECTED (1U)      /*!< Bit field size in bits for BCH_STATUS0_CORRECTED. */

/*! @brief Read current value of the BCH_STATUS0_CORRECTED field. */
#define BR_BCH_STATUS0_CORRECTED(x) (HW_BCH_STATUS0(x).B.CORRECTED)
/*@}*/

/*!
 * @name Register BCH_STATUS0, field ALLONES[4] (RO)
 *
 * 1 = All data bits of this transaction are ONE.
 */
/*@{*/
#define BP_BCH_STATUS0_ALLONES (4U)        /*!< Bit position for BCH_STATUS0_ALLONES. */
#define BM_BCH_STATUS0_ALLONES (0x00000010U) /*!< Bit mask for BCH_STATUS0_ALLONES. */
#define BS_BCH_STATUS0_ALLONES (1U)        /*!< Bit field size in bits for BCH_STATUS0_ALLONES. */

/*! @brief Read current value of the BCH_STATUS0_ALLONES field. */
#define BR_BCH_STATUS0_ALLONES(x) (HW_BCH_STATUS0(x).B.ALLONES)
/*@}*/

/*!
 * @name Register BCH_STATUS0, field RSVD1[7:5] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_STATUS0_RSVD1 (5U)          /*!< Bit position for BCH_STATUS0_RSVD1. */
#define BM_BCH_STATUS0_RSVD1 (0x000000E0U) /*!< Bit mask for BCH_STATUS0_RSVD1. */
#define BS_BCH_STATUS0_RSVD1 (3U)          /*!< Bit field size in bits for BCH_STATUS0_RSVD1. */

/*! @brief Read current value of the BCH_STATUS0_RSVD1 field. */
#define BR_BCH_STATUS0_RSVD1(x) (HW_BCH_STATUS0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register BCH_STATUS0, field STATUS_BLK0[15:8] (RO)
 *
 * Count of symbols in error during processing of first block of flash (metadata
 * block). The number of errors reported will be in the range of 0 to the ECC
 * correction level for block 0.
 *
 * Values:
 * - 0 - No errors found on block.
 * - 1 - One error found on block.
 * - 10 - One errors found on block.
 * - 11 - One errors found on block.
 * - 100 - One errors found on block.
 * - 11111110 - Block exhibited uncorrectable errors.
 * - 11111111 - Page is erased.
 */
/*@{*/
#define BP_BCH_STATUS0_STATUS_BLK0 (8U)    /*!< Bit position for BCH_STATUS0_STATUS_BLK0. */
#define BM_BCH_STATUS0_STATUS_BLK0 (0x0000FF00U) /*!< Bit mask for BCH_STATUS0_STATUS_BLK0. */
#define BS_BCH_STATUS0_STATUS_BLK0 (8U)    /*!< Bit field size in bits for BCH_STATUS0_STATUS_BLK0. */

#define BV_BCH_STATUS0_STATUS_BLK0_ZERO (0U)         /*!< Bit field value for BCH_STATUS0_STATUS_BLK0: No errors found on block. */
#define BV_BCH_STATUS0_STATUS_BLK0_ERROR1 (0x1U)     /*!< Bit field value for BCH_STATUS0_STATUS_BLK0: One error found on block. */
#define BV_BCH_STATUS0_STATUS_BLK0_ERROR2 (0x2U)     /*!< Bit field value for BCH_STATUS0_STATUS_BLK0: One errors found on block. */
#define BV_BCH_STATUS0_STATUS_BLK0_ERROR3 (0x3U)     /*!< Bit field value for BCH_STATUS0_STATUS_BLK0: One errors found on block. */
#define BV_BCH_STATUS0_STATUS_BLK0_ERROR4 (0x4U)     /*!< Bit field value for BCH_STATUS0_STATUS_BLK0: One errors found on block. */
#define BV_BCH_STATUS0_STATUS_BLK0_UNCORRECTABLE (0xFEU) /*!< Bit field value for BCH_STATUS0_STATUS_BLK0: Block exhibited uncorrectable errors. */
#define BV_BCH_STATUS0_STATUS_BLK0_ERASED (0xFFU)    /*!< Bit field value for BCH_STATUS0_STATUS_BLK0: Page is erased. */

/*! @brief Read current value of the BCH_STATUS0_STATUS_BLK0 field. */
#define BR_BCH_STATUS0_STATUS_BLK0(x) (HW_BCH_STATUS0(x).B.STATUS_BLK0)
/*@}*/

/*!
 * @name Register BCH_STATUS0, field COMPLETED_CE[19:16] (RO)
 *
 * This is the chip enable number corresponding to the NAND device from which
 * this data came.
 */
/*@{*/
#define BP_BCH_STATUS0_COMPLETED_CE (16U)  /*!< Bit position for BCH_STATUS0_COMPLETED_CE. */
#define BM_BCH_STATUS0_COMPLETED_CE (0x000F0000U) /*!< Bit mask for BCH_STATUS0_COMPLETED_CE. */
#define BS_BCH_STATUS0_COMPLETED_CE (4U)   /*!< Bit field size in bits for BCH_STATUS0_COMPLETED_CE. */

/*! @brief Read current value of the BCH_STATUS0_COMPLETED_CE field. */
#define BR_BCH_STATUS0_COMPLETED_CE(x) (HW_BCH_STATUS0(x).B.COMPLETED_CE)
/*@}*/

/*!
 * @name Register BCH_STATUS0, field HANDLE[31:20] (RO)
 *
 * Software supplies a 12 bit handle for this transfer as part of the GPMI DMA
 * PIO operation that started the transaction. That handle passes down the
 * pipeline and ends up here at the time the BCH interrupt is signaled.
 */
/*@{*/
#define BP_BCH_STATUS0_HANDLE (20U)        /*!< Bit position for BCH_STATUS0_HANDLE. */
#define BM_BCH_STATUS0_HANDLE (0xFFF00000U) /*!< Bit mask for BCH_STATUS0_HANDLE. */
#define BS_BCH_STATUS0_HANDLE (12U)        /*!< Bit field size in bits for BCH_STATUS0_HANDLE. */

/*! @brief Read current value of the BCH_STATUS0_HANDLE field. */
#define BR_BCH_STATUS0_HANDLE(x) (HW_BCH_STATUS0(x).B.HANDLE)
/*@}*/




/*******************************************************************************
 * HW_BCH_MODE - Hardware ECC Accelerator Mode Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_MODE - Hardware ECC Accelerator Mode Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The BCH MODE register provides additional mode controls. Contains additional
 * global mode controls for the BCH engine.
 */
typedef union _hw_bch_mode
{
    uint32_t U;
    struct _hw_bch_mode_bitfields
    {
        uint32_t ERASE_THRESHOLD : 8;  /*!< [7:0]  */
        uint32_t RSVD : 24;            /*!< [31:8] This field is reserved. */
    } B;
} hw_bch_mode_t;

/*!
 * @name Constants and macros for entire BCH_MODE register
 */
/*@{*/
#define HW_BCH_MODE_ADDR(x)      ((uintptr_t)(x) + 0x20U)
#define HW_BCH_MODE_SET_ADDR(x)  (HW_BCH_MODE_ADDR(x) + 0x4U)
#define HW_BCH_MODE_CLR_ADDR(x)  (HW_BCH_MODE_ADDR(x) + 0x8U)
#define HW_BCH_MODE_TOG_ADDR(x)  (HW_BCH_MODE_ADDR(x) + 0xCU)

#define HW_BCH_MODE(x)           (*(__IO hw_bch_mode_t *) HW_BCH_MODE_ADDR(x))
#define HW_BCH_MODE_RD(x)        (HW_BCH_MODE(x).U)
#define HW_BCH_MODE_WR(x, v)     (HW_BCH_MODE(x).U = (v))
#define HW_BCH_MODE_SET(x, v)    ((*(uint32_t *) HW_BCH_MODE_SET_ADDR(x)) = (v))
#define HW_BCH_MODE_CLR(x, v)    ((*(uint32_t *) HW_BCH_MODE_CLR_ADDR(x)) = (v))
#define HW_BCH_MODE_TOG(x, v)    ((*(uint32_t *) HW_BCH_MODE_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_MODE bitfields
 */

/*!
 * @name Register BCH_MODE, field ERASE_THRESHOLD[7:0] (RW)
 *
 * This value indicates the maximum number of zero bits on a flash subpage for
 * it to be considered erased. For SLC NAND devices, this value should be
 * programmed to 0 (meaning that the entire page should consist of bytes of 0xFF. For MLC
 * NAND devices, bit errors may occur on reads (even on blank pages), so this
 * threshold can be used to tune the erased page checking algorithm.
 */
/*@{*/
#define BP_BCH_MODE_ERASE_THRESHOLD (0U)   /*!< Bit position for BCH_MODE_ERASE_THRESHOLD. */
#define BM_BCH_MODE_ERASE_THRESHOLD (0x000000FFU) /*!< Bit mask for BCH_MODE_ERASE_THRESHOLD. */
#define BS_BCH_MODE_ERASE_THRESHOLD (8U)   /*!< Bit field size in bits for BCH_MODE_ERASE_THRESHOLD. */

/*! @brief Read current value of the BCH_MODE_ERASE_THRESHOLD field. */
#define BR_BCH_MODE_ERASE_THRESHOLD(x) (HW_BCH_MODE(x).B.ERASE_THRESHOLD)

/*! @brief Format value for bitfield BCH_MODE_ERASE_THRESHOLD. */
#define BF_BCH_MODE_ERASE_THRESHOLD(v) ((uint32_t)((uint32_t)(v) << BP_BCH_MODE_ERASE_THRESHOLD) & BM_BCH_MODE_ERASE_THRESHOLD)

/*! @brief Set the ERASE_THRESHOLD field to a new value. */
#define BW_BCH_MODE_ERASE_THRESHOLD(x, v) (HW_BCH_MODE_WR(x, (HW_BCH_MODE_RD(x) & ~BM_BCH_MODE_ERASE_THRESHOLD) | BF_BCH_MODE_ERASE_THRESHOLD(v)))
/*@}*/

/*!
 * @name Register BCH_MODE, field RSVD[31:8] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_MODE_RSVD     (8U)          /*!< Bit position for BCH_MODE_RSVD. */
#define BM_BCH_MODE_RSVD     (0xFFFFFF00U) /*!< Bit mask for BCH_MODE_RSVD. */
#define BS_BCH_MODE_RSVD     (24U)         /*!< Bit field size in bits for BCH_MODE_RSVD. */

/*! @brief Read current value of the BCH_MODE_RSVD field. */
#define BR_BCH_MODE_RSVD(x)  (HW_BCH_MODE(x).B.RSVD)
/*@}*/




/*******************************************************************************
 * HW_BCH_ENCODEPTR - Hardware BCH ECC Loopback Encode Buffer Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_ENCODEPTR - Hardware BCH ECC Loopback Encode Buffer Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * When performing memory to memory operations, indicates the address of the
 * encode buffer. This register should be programmed before writing a 1 to the
 * M2M_ENABLE bit in the CTRL register. For memory to memory operations, this register
 * is used as the pointer to the encoded data, which is an output when encoding
 * and an input while decoding.
 */
typedef union _hw_bch_encodeptr
{
    uint32_t U;
    struct _hw_bch_encodeptr_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_bch_encodeptr_t;

/*!
 * @name Constants and macros for entire BCH_ENCODEPTR register
 */
/*@{*/
#define HW_BCH_ENCODEPTR_ADDR(x) ((uintptr_t)(x) + 0x30U)
#define HW_BCH_ENCODEPTR_SET_ADDR(x) (HW_BCH_ENCODEPTR_ADDR(x) + 0x4U)
#define HW_BCH_ENCODEPTR_CLR_ADDR(x) (HW_BCH_ENCODEPTR_ADDR(x) + 0x8U)
#define HW_BCH_ENCODEPTR_TOG_ADDR(x) (HW_BCH_ENCODEPTR_ADDR(x) + 0xCU)

#define HW_BCH_ENCODEPTR(x)      (*(__IO hw_bch_encodeptr_t *) HW_BCH_ENCODEPTR_ADDR(x))
#define HW_BCH_ENCODEPTR_RD(x)   (HW_BCH_ENCODEPTR(x).U)
#define HW_BCH_ENCODEPTR_WR(x, v) (HW_BCH_ENCODEPTR(x).U = (v))
#define HW_BCH_ENCODEPTR_SET(x, v) ((*(uint32_t *) HW_BCH_ENCODEPTR_SET_ADDR(x)) = (v))
#define HW_BCH_ENCODEPTR_CLR(x, v) ((*(uint32_t *) HW_BCH_ENCODEPTR_CLR_ADDR(x)) = (v))
#define HW_BCH_ENCODEPTR_TOG(x, v) ((*(uint32_t *) HW_BCH_ENCODEPTR_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_ENCODEPTR bitfields
 */

/*!
 * @name Register BCH_ENCODEPTR, field ADDR[31:0] (RW)
 *
 * Address pointer to encode buffer. This is the source for decode operations
 * and the destination for encode operations. This value must be aligned on a 4
 * bytes boundary.
 */
/*@{*/
#define BP_BCH_ENCODEPTR_ADDR (0U)         /*!< Bit position for BCH_ENCODEPTR_ADDR. */
#define BM_BCH_ENCODEPTR_ADDR (0xFFFFFFFFU) /*!< Bit mask for BCH_ENCODEPTR_ADDR. */
#define BS_BCH_ENCODEPTR_ADDR (32U)        /*!< Bit field size in bits for BCH_ENCODEPTR_ADDR. */

/*! @brief Read current value of the BCH_ENCODEPTR_ADDR field. */
#define BR_BCH_ENCODEPTR_ADDR(x) (HW_BCH_ENCODEPTR(x).U)

/*! @brief Format value for bitfield BCH_ENCODEPTR_ADDR. */
#define BF_BCH_ENCODEPTR_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_BCH_ENCODEPTR_ADDR) & BM_BCH_ENCODEPTR_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_BCH_ENCODEPTR_ADDR(x, v) (HW_BCH_ENCODEPTR_WR(x, v))
/*@}*/




/*******************************************************************************
 * HW_BCH_DATAPTR - Hardware BCH ECC Loopback Data Buffer Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_DATAPTR - Hardware BCH ECC Loopback Data Buffer Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * When performing memory to memory operations, indicates the address of the
 * data buffer. For memory to memory operations, this register is used as the
 * pointer to the data to encode or the destination buffer for decode operations.
 */
typedef union _hw_bch_dataptr
{
    uint32_t U;
    struct _hw_bch_dataptr_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_bch_dataptr_t;

/*!
 * @name Constants and macros for entire BCH_DATAPTR register
 */
/*@{*/
#define HW_BCH_DATAPTR_ADDR(x)   ((uintptr_t)(x) + 0x40U)
#define HW_BCH_DATAPTR_SET_ADDR(x) (HW_BCH_DATAPTR_ADDR(x) + 0x4U)
#define HW_BCH_DATAPTR_CLR_ADDR(x) (HW_BCH_DATAPTR_ADDR(x) + 0x8U)
#define HW_BCH_DATAPTR_TOG_ADDR(x) (HW_BCH_DATAPTR_ADDR(x) + 0xCU)

#define HW_BCH_DATAPTR(x)        (*(__IO hw_bch_dataptr_t *) HW_BCH_DATAPTR_ADDR(x))
#define HW_BCH_DATAPTR_RD(x)     (HW_BCH_DATAPTR(x).U)
#define HW_BCH_DATAPTR_WR(x, v)  (HW_BCH_DATAPTR(x).U = (v))
#define HW_BCH_DATAPTR_SET(x, v) ((*(uint32_t *) HW_BCH_DATAPTR_SET_ADDR(x)) = (v))
#define HW_BCH_DATAPTR_CLR(x, v) ((*(uint32_t *) HW_BCH_DATAPTR_CLR_ADDR(x)) = (v))
#define HW_BCH_DATAPTR_TOG(x, v) ((*(uint32_t *) HW_BCH_DATAPTR_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_DATAPTR bitfields
 */

/*!
 * @name Register BCH_DATAPTR, field ADDR[31:0] (RW)
 *
 * Address pointer to data buffer. This is the source for encode operations and
 * the destination for decode operations. This register should be programmed
 * before writing a 1 to the M2M_ENABLE bit in the CTRL register. This value must be
 * aligned on a 4 byte boundary.
 */
/*@{*/
#define BP_BCH_DATAPTR_ADDR  (0U)          /*!< Bit position for BCH_DATAPTR_ADDR. */
#define BM_BCH_DATAPTR_ADDR  (0xFFFFFFFFU) /*!< Bit mask for BCH_DATAPTR_ADDR. */
#define BS_BCH_DATAPTR_ADDR  (32U)         /*!< Bit field size in bits for BCH_DATAPTR_ADDR. */

/*! @brief Read current value of the BCH_DATAPTR_ADDR field. */
#define BR_BCH_DATAPTR_ADDR(x) (HW_BCH_DATAPTR(x).U)

/*! @brief Format value for bitfield BCH_DATAPTR_ADDR. */
#define BF_BCH_DATAPTR_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DATAPTR_ADDR) & BM_BCH_DATAPTR_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_BCH_DATAPTR_ADDR(x, v) (HW_BCH_DATAPTR_WR(x, v))
/*@}*/




/*******************************************************************************
 * HW_BCH_METAPTR - Hardware BCH ECC Loopback Metadata Buffer Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_METAPTR - Hardware BCH ECC Loopback Metadata Buffer Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * When performing memory to memory operations, indicates the address of the
 * metadata buffer. For memory to memory operations, this register is used as the
 * pointer to the metadata to encode or the extracted metadata for decode
 * operations.
 */
typedef union _hw_bch_metaptr
{
    uint32_t U;
    struct _hw_bch_metaptr_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_bch_metaptr_t;

/*!
 * @name Constants and macros for entire BCH_METAPTR register
 */
/*@{*/
#define HW_BCH_METAPTR_ADDR(x)   ((uintptr_t)(x) + 0x50U)
#define HW_BCH_METAPTR_SET_ADDR(x) (HW_BCH_METAPTR_ADDR(x) + 0x4U)
#define HW_BCH_METAPTR_CLR_ADDR(x) (HW_BCH_METAPTR_ADDR(x) + 0x8U)
#define HW_BCH_METAPTR_TOG_ADDR(x) (HW_BCH_METAPTR_ADDR(x) + 0xCU)

#define HW_BCH_METAPTR(x)        (*(__IO hw_bch_metaptr_t *) HW_BCH_METAPTR_ADDR(x))
#define HW_BCH_METAPTR_RD(x)     (HW_BCH_METAPTR(x).U)
#define HW_BCH_METAPTR_WR(x, v)  (HW_BCH_METAPTR(x).U = (v))
#define HW_BCH_METAPTR_SET(x, v) ((*(uint32_t *) HW_BCH_METAPTR_SET_ADDR(x)) = (v))
#define HW_BCH_METAPTR_CLR(x, v) ((*(uint32_t *) HW_BCH_METAPTR_CLR_ADDR(x)) = (v))
#define HW_BCH_METAPTR_TOG(x, v) ((*(uint32_t *) HW_BCH_METAPTR_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_METAPTR bitfields
 */

/*!
 * @name Register BCH_METAPTR, field ADDR[31:0] (RW)
 *
 * Address pointer to metadata buffer. This is the source for encode metadata
 * read operations and the destination for metadata decode operations. This
 * register should be programmed before writing a 1 to the M2M_ENABLE bit in the CTRL
 * register. This value must be aligned on a 4 bytes boundary.
 */
/*@{*/
#define BP_BCH_METAPTR_ADDR  (0U)          /*!< Bit position for BCH_METAPTR_ADDR. */
#define BM_BCH_METAPTR_ADDR  (0xFFFFFFFFU) /*!< Bit mask for BCH_METAPTR_ADDR. */
#define BS_BCH_METAPTR_ADDR  (32U)         /*!< Bit field size in bits for BCH_METAPTR_ADDR. */

/*! @brief Read current value of the BCH_METAPTR_ADDR field. */
#define BR_BCH_METAPTR_ADDR(x) (HW_BCH_METAPTR(x).U)

/*! @brief Format value for bitfield BCH_METAPTR_ADDR. */
#define BF_BCH_METAPTR_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_BCH_METAPTR_ADDR) & BM_BCH_METAPTR_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_BCH_METAPTR_ADDR(x, v) (HW_BCH_METAPTR_WR(x, v))
/*@}*/




/*******************************************************************************
 * HW_BCH_LAYOUTSELECT - Hardware ECC Accelerator Layout Select Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_LAYOUTSELECT - Hardware ECC Accelerator Layout Select Register (RW)
 *
 * Reset value: 0xE4E4E4E4U
 *
 * The BCH LAYOUTSELECT register provides a mapping of chip selects to layout
 * registers. When the BCH engine receives a request to process a data block from
 * the GPMI interface, it will use this register to map the incoming chip select
 * to one of the four possible flash layout registers
 */
typedef union _hw_bch_layoutselect
{
    uint32_t U;
    struct _hw_bch_layoutselect_bitfields
    {
        uint32_t CS0_SELECT : 2;       /*!< [1:0]  */
        uint32_t CS1_SELECT : 2;       /*!< [3:2]  */
        uint32_t CS2_SELECT : 2;       /*!< [5:4]  */
        uint32_t CS3_SELECT : 2;       /*!< [7:6]  */
        uint32_t CS4_SELECT : 2;       /*!< [9:8]  */
        uint32_t CS5_SELECT : 2;       /*!< [11:10]  */
        uint32_t CS6_SELECT : 2;       /*!< [13:12]  */
        uint32_t CS7_SELECT : 2;       /*!< [15:14]  */
        uint32_t CS8_SELECT : 2;       /*!< [17:16]  */
        uint32_t CS9_SELECT : 2;       /*!< [19:18]  */
        uint32_t CS10_SELECT : 2;      /*!< [21:20]  */
        uint32_t CS11_SELECT : 2;      /*!< [23:22]  */
        uint32_t CS12_SELECT : 2;      /*!< [25:24]  */
        uint32_t CS13_SELECT : 2;      /*!< [27:26]  */
        uint32_t CS14_SELECT : 2;      /*!< [29:28]  */
        uint32_t CS15_SELECT : 2;      /*!< [31:30]  */
    } B;
} hw_bch_layoutselect_t;

/*!
 * @name Constants and macros for entire BCH_LAYOUTSELECT register
 */
/*@{*/
#define HW_BCH_LAYOUTSELECT_ADDR(x) ((uintptr_t)(x) + 0x70U)
#define HW_BCH_LAYOUTSELECT_SET_ADDR(x) (HW_BCH_LAYOUTSELECT_ADDR(x) + 0x4U)
#define HW_BCH_LAYOUTSELECT_CLR_ADDR(x) (HW_BCH_LAYOUTSELECT_ADDR(x) + 0x8U)
#define HW_BCH_LAYOUTSELECT_TOG_ADDR(x) (HW_BCH_LAYOUTSELECT_ADDR(x) + 0xCU)

#define HW_BCH_LAYOUTSELECT(x)   (*(__IO hw_bch_layoutselect_t *) HW_BCH_LAYOUTSELECT_ADDR(x))
#define HW_BCH_LAYOUTSELECT_RD(x) (HW_BCH_LAYOUTSELECT(x).U)
#define HW_BCH_LAYOUTSELECT_WR(x, v) (HW_BCH_LAYOUTSELECT(x).U = (v))
#define HW_BCH_LAYOUTSELECT_SET(x, v) ((*(uint32_t *) HW_BCH_LAYOUTSELECT_SET_ADDR(x)) = (v))
#define HW_BCH_LAYOUTSELECT_CLR(x, v) ((*(uint32_t *) HW_BCH_LAYOUTSELECT_CLR_ADDR(x)) = (v))
#define HW_BCH_LAYOUTSELECT_TOG(x, v) ((*(uint32_t *) HW_BCH_LAYOUTSELECT_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_LAYOUTSELECT bitfields
 */

/*!
 * @name Register BCH_LAYOUTSELECT, field CS0_SELECT[1:0] (RW)
 *
 * Selects which layout is used for chip select 0.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS0_SELECT (0U) /*!< Bit position for BCH_LAYOUTSELECT_CS0_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS0_SELECT (0x00000003U) /*!< Bit mask for BCH_LAYOUTSELECT_CS0_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS0_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS0_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS0_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS0_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS0_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS0_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS0_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS0_SELECT) & BM_BCH_LAYOUTSELECT_CS0_SELECT)

/*! @brief Set the CS0_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS0_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS0_SELECT) | BF_BCH_LAYOUTSELECT_CS0_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS1_SELECT[3:2] (RW)
 *
 * Selects which layout is used for chip select 1.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS1_SELECT (2U) /*!< Bit position for BCH_LAYOUTSELECT_CS1_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS1_SELECT (0x0000000CU) /*!< Bit mask for BCH_LAYOUTSELECT_CS1_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS1_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS1_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS1_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS1_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS1_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS1_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS1_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS1_SELECT) & BM_BCH_LAYOUTSELECT_CS1_SELECT)

/*! @brief Set the CS1_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS1_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS1_SELECT) | BF_BCH_LAYOUTSELECT_CS1_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS2_SELECT[5:4] (RW)
 *
 * Selects which layout is used for chip select 2.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS2_SELECT (4U) /*!< Bit position for BCH_LAYOUTSELECT_CS2_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS2_SELECT (0x00000030U) /*!< Bit mask for BCH_LAYOUTSELECT_CS2_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS2_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS2_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS2_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS2_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS2_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS2_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS2_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS2_SELECT) & BM_BCH_LAYOUTSELECT_CS2_SELECT)

/*! @brief Set the CS2_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS2_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS2_SELECT) | BF_BCH_LAYOUTSELECT_CS2_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS3_SELECT[7:6] (RW)
 *
 * Selects which layout is used for chip select 3.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS3_SELECT (6U) /*!< Bit position for BCH_LAYOUTSELECT_CS3_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS3_SELECT (0x000000C0U) /*!< Bit mask for BCH_LAYOUTSELECT_CS3_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS3_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS3_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS3_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS3_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS3_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS3_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS3_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS3_SELECT) & BM_BCH_LAYOUTSELECT_CS3_SELECT)

/*! @brief Set the CS3_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS3_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS3_SELECT) | BF_BCH_LAYOUTSELECT_CS3_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS4_SELECT[9:8] (RW)
 *
 * Selects which layout is used for chip select 4.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS4_SELECT (8U) /*!< Bit position for BCH_LAYOUTSELECT_CS4_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS4_SELECT (0x00000300U) /*!< Bit mask for BCH_LAYOUTSELECT_CS4_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS4_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS4_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS4_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS4_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS4_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS4_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS4_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS4_SELECT) & BM_BCH_LAYOUTSELECT_CS4_SELECT)

/*! @brief Set the CS4_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS4_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS4_SELECT) | BF_BCH_LAYOUTSELECT_CS4_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS5_SELECT[11:10] (RW)
 *
 * Selects which layout is used for chip select 5.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS5_SELECT (10U) /*!< Bit position for BCH_LAYOUTSELECT_CS5_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS5_SELECT (0x00000C00U) /*!< Bit mask for BCH_LAYOUTSELECT_CS5_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS5_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS5_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS5_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS5_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS5_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS5_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS5_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS5_SELECT) & BM_BCH_LAYOUTSELECT_CS5_SELECT)

/*! @brief Set the CS5_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS5_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS5_SELECT) | BF_BCH_LAYOUTSELECT_CS5_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS6_SELECT[13:12] (RW)
 *
 * Selects which layout is used for chip select 6.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS6_SELECT (12U) /*!< Bit position for BCH_LAYOUTSELECT_CS6_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS6_SELECT (0x00003000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS6_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS6_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS6_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS6_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS6_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS6_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS6_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS6_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS6_SELECT) & BM_BCH_LAYOUTSELECT_CS6_SELECT)

/*! @brief Set the CS6_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS6_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS6_SELECT) | BF_BCH_LAYOUTSELECT_CS6_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS7_SELECT[15:14] (RW)
 *
 * Selects which layout is used for chip select 7.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS7_SELECT (14U) /*!< Bit position for BCH_LAYOUTSELECT_CS7_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS7_SELECT (0x0000C000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS7_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS7_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS7_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS7_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS7_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS7_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS7_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS7_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS7_SELECT) & BM_BCH_LAYOUTSELECT_CS7_SELECT)

/*! @brief Set the CS7_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS7_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS7_SELECT) | BF_BCH_LAYOUTSELECT_CS7_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS8_SELECT[17:16] (RW)
 *
 * Selects which layout is used for chip select 8.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS8_SELECT (16U) /*!< Bit position for BCH_LAYOUTSELECT_CS8_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS8_SELECT (0x00030000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS8_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS8_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS8_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS8_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS8_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS8_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS8_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS8_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS8_SELECT) & BM_BCH_LAYOUTSELECT_CS8_SELECT)

/*! @brief Set the CS8_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS8_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS8_SELECT) | BF_BCH_LAYOUTSELECT_CS8_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS9_SELECT[19:18] (RW)
 *
 * Selects which layout is used for chip select 9.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS9_SELECT (18U) /*!< Bit position for BCH_LAYOUTSELECT_CS9_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS9_SELECT (0x000C0000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS9_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS9_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS9_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS9_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS9_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS9_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS9_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS9_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS9_SELECT) & BM_BCH_LAYOUTSELECT_CS9_SELECT)

/*! @brief Set the CS9_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS9_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS9_SELECT) | BF_BCH_LAYOUTSELECT_CS9_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS10_SELECT[21:20] (RW)
 *
 * Selects which layout is used for chip select 10.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS10_SELECT (20U) /*!< Bit position for BCH_LAYOUTSELECT_CS10_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS10_SELECT (0x00300000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS10_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS10_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS10_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS10_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS10_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS10_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS10_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS10_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS10_SELECT) & BM_BCH_LAYOUTSELECT_CS10_SELECT)

/*! @brief Set the CS10_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS10_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS10_SELECT) | BF_BCH_LAYOUTSELECT_CS10_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS11_SELECT[23:22] (RW)
 *
 * Selects which layout is used for chip select 11.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS11_SELECT (22U) /*!< Bit position for BCH_LAYOUTSELECT_CS11_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS11_SELECT (0x00C00000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS11_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS11_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS11_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS11_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS11_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS11_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS11_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS11_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS11_SELECT) & BM_BCH_LAYOUTSELECT_CS11_SELECT)

/*! @brief Set the CS11_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS11_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS11_SELECT) | BF_BCH_LAYOUTSELECT_CS11_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS12_SELECT[25:24] (RW)
 *
 * Selects which layout is used for chip select 12.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS12_SELECT (24U) /*!< Bit position for BCH_LAYOUTSELECT_CS12_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS12_SELECT (0x03000000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS12_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS12_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS12_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS12_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS12_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS12_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS12_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS12_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS12_SELECT) & BM_BCH_LAYOUTSELECT_CS12_SELECT)

/*! @brief Set the CS12_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS12_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS12_SELECT) | BF_BCH_LAYOUTSELECT_CS12_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS13_SELECT[27:26] (RW)
 *
 * Selects which layout is used for chip select 13.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS13_SELECT (26U) /*!< Bit position for BCH_LAYOUTSELECT_CS13_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS13_SELECT (0x0C000000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS13_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS13_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS13_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS13_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS13_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS13_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS13_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS13_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS13_SELECT) & BM_BCH_LAYOUTSELECT_CS13_SELECT)

/*! @brief Set the CS13_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS13_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS13_SELECT) | BF_BCH_LAYOUTSELECT_CS13_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS14_SELECT[29:28] (RW)
 *
 * Selects which layout is used for chip select 14.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS14_SELECT (28U) /*!< Bit position for BCH_LAYOUTSELECT_CS14_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS14_SELECT (0x30000000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS14_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS14_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS14_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS14_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS14_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS14_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS14_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS14_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS14_SELECT) & BM_BCH_LAYOUTSELECT_CS14_SELECT)

/*! @brief Set the CS14_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS14_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS14_SELECT) | BF_BCH_LAYOUTSELECT_CS14_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_LAYOUTSELECT, field CS15_SELECT[31:30] (RW)
 *
 * Selects which layout is used for chip select 15.
 */
/*@{*/
#define BP_BCH_LAYOUTSELECT_CS15_SELECT (30U) /*!< Bit position for BCH_LAYOUTSELECT_CS15_SELECT. */
#define BM_BCH_LAYOUTSELECT_CS15_SELECT (0xC0000000U) /*!< Bit mask for BCH_LAYOUTSELECT_CS15_SELECT. */
#define BS_BCH_LAYOUTSELECT_CS15_SELECT (2U) /*!< Bit field size in bits for BCH_LAYOUTSELECT_CS15_SELECT. */

/*! @brief Read current value of the BCH_LAYOUTSELECT_CS15_SELECT field. */
#define BR_BCH_LAYOUTSELECT_CS15_SELECT(x) (HW_BCH_LAYOUTSELECT(x).B.CS15_SELECT)

/*! @brief Format value for bitfield BCH_LAYOUTSELECT_CS15_SELECT. */
#define BF_BCH_LAYOUTSELECT_CS15_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_LAYOUTSELECT_CS15_SELECT) & BM_BCH_LAYOUTSELECT_CS15_SELECT)

/*! @brief Set the CS15_SELECT field to a new value. */
#define BW_BCH_LAYOUTSELECT_CS15_SELECT(x, v) (HW_BCH_LAYOUTSELECT_WR(x, (HW_BCH_LAYOUTSELECT_RD(x) & ~BM_BCH_LAYOUTSELECT_CS15_SELECT) | BF_BCH_LAYOUTSELECT_CS15_SELECT(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_FLASH0LAYOUT0 - Hardware BCH ECC Flash 0 Layout 0 Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_FLASH0LAYOUT0 - Hardware BCH ECC Flash 0 Layout 0 Register (RW)
 *
 * Reset value: 0x070A4080U
 *
 * The flash format register contains a description of the logical layout of
 * data on the flash device. This register is used in conjunction with the
 * FLASH0LAYOUT1 register to control the format for the devices selecting layout 0 in the
 * LAYOUTSELECT register. Each pair of layout registers describes one of four
 * supported flash configurations. Software should program the LAYOUTSELECT register
 * for each supported GPMI chip select to select from one of the four layout
 * values. Each pair of registers contains settings that are used by the BCH block
 * while reading / writing the flash page to control data, metadata, and flash
 * page sizes as well as the ECC correction level. The first block written to flash
 * can be programmed to have different ECC, metadata, and data sizes from
 * subsequent data blocks on the device. In addition, the number of blocks stored on a
 * page of flash is not fixed, but instead is determined by the number of bytes
 * consumed by the initial (block 0) and subsequent data blocks. See the BCH
 * programming reference manual for more information on setting up the flash layout
 * registers.
 */
typedef union _hw_bch_flash0layout0
{
    uint32_t U;
    struct _hw_bch_flash0layout0_bitfields
    {
        uint32_t DATA0_SIZE : 10;      /*!< [9:0]  */
        uint32_t GF13_0_GF14_1 : 1;    /*!< [10]  */
        uint32_t ECC0 : 5;             /*!< [15:11]  */
        uint32_t META_SIZE : 8;        /*!< [23:16]  */
        uint32_t NBLOCKS : 8;          /*!< [31:24]  */
    } B;
} hw_bch_flash0layout0_t;

/*!
 * @name Constants and macros for entire BCH_FLASH0LAYOUT0 register
 */
/*@{*/
#define HW_BCH_FLASH0LAYOUT0_ADDR(x) ((uintptr_t)(x) + 0x80U)
#define HW_BCH_FLASH0LAYOUT0_SET_ADDR(x) (HW_BCH_FLASH0LAYOUT0_ADDR(x) + 0x4U)
#define HW_BCH_FLASH0LAYOUT0_CLR_ADDR(x) (HW_BCH_FLASH0LAYOUT0_ADDR(x) + 0x8U)
#define HW_BCH_FLASH0LAYOUT0_TOG_ADDR(x) (HW_BCH_FLASH0LAYOUT0_ADDR(x) + 0xCU)

#define HW_BCH_FLASH0LAYOUT0(x)  (*(__IO hw_bch_flash0layout0_t *) HW_BCH_FLASH0LAYOUT0_ADDR(x))
#define HW_BCH_FLASH0LAYOUT0_RD(x) (HW_BCH_FLASH0LAYOUT0(x).U)
#define HW_BCH_FLASH0LAYOUT0_WR(x, v) (HW_BCH_FLASH0LAYOUT0(x).U = (v))
#define HW_BCH_FLASH0LAYOUT0_SET(x, v) ((*(uint32_t *) HW_BCH_FLASH0LAYOUT0_SET_ADDR(x)) = (v))
#define HW_BCH_FLASH0LAYOUT0_CLR(x, v) ((*(uint32_t *) HW_BCH_FLASH0LAYOUT0_CLR_ADDR(x)) = (v))
#define HW_BCH_FLASH0LAYOUT0_TOG(x, v) ((*(uint32_t *) HW_BCH_FLASH0LAYOUT0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_FLASH0LAYOUT0 bitfields
 */

/*!
 * @name Register BCH_FLASH0LAYOUT0, field DATA0_SIZE[9:0] (RW)
 *
 * Indicates the size of the data 0 block (in DWORDS / four bytes) to be stored
 * on the flash page. If set to 0, the first block only contains metadata.
 */
/*@{*/
#define BP_BCH_FLASH0LAYOUT0_DATA0_SIZE (0U) /*!< Bit position for BCH_FLASH0LAYOUT0_DATA0_SIZE. */
#define BM_BCH_FLASH0LAYOUT0_DATA0_SIZE (0x000003FFU) /*!< Bit mask for BCH_FLASH0LAYOUT0_DATA0_SIZE. */
#define BS_BCH_FLASH0LAYOUT0_DATA0_SIZE (10U) /*!< Bit field size in bits for BCH_FLASH0LAYOUT0_DATA0_SIZE. */

/*! @brief Read current value of the BCH_FLASH0LAYOUT0_DATA0_SIZE field. */
#define BR_BCH_FLASH0LAYOUT0_DATA0_SIZE(x) (HW_BCH_FLASH0LAYOUT0(x).B.DATA0_SIZE)

/*! @brief Format value for bitfield BCH_FLASH0LAYOUT0_DATA0_SIZE. */
#define BF_BCH_FLASH0LAYOUT0_DATA0_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH0LAYOUT0_DATA0_SIZE) & BM_BCH_FLASH0LAYOUT0_DATA0_SIZE)

/*! @brief Set the DATA0_SIZE field to a new value. */
#define BW_BCH_FLASH0LAYOUT0_DATA0_SIZE(x, v) (HW_BCH_FLASH0LAYOUT0_WR(x, (HW_BCH_FLASH0LAYOUT0_RD(x) & ~BM_BCH_FLASH0LAYOUT0_DATA0_SIZE) | BF_BCH_FLASH0LAYOUT0_DATA0_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH0LAYOUT0, field GF13_0_GF14_1[10] (RW)
 *
 * Select GF13 or GF14: 0-GF13; 1-GF14
 */
/*@{*/
#define BP_BCH_FLASH0LAYOUT0_GF13_0_GF14_1 (10U) /*!< Bit position for BCH_FLASH0LAYOUT0_GF13_0_GF14_1. */
#define BM_BCH_FLASH0LAYOUT0_GF13_0_GF14_1 (0x00000400U) /*!< Bit mask for BCH_FLASH0LAYOUT0_GF13_0_GF14_1. */
#define BS_BCH_FLASH0LAYOUT0_GF13_0_GF14_1 (1U) /*!< Bit field size in bits for BCH_FLASH0LAYOUT0_GF13_0_GF14_1. */

/*! @brief Read current value of the BCH_FLASH0LAYOUT0_GF13_0_GF14_1 field. */
#define BR_BCH_FLASH0LAYOUT0_GF13_0_GF14_1(x) (HW_BCH_FLASH0LAYOUT0(x).B.GF13_0_GF14_1)

/*! @brief Format value for bitfield BCH_FLASH0LAYOUT0_GF13_0_GF14_1. */
#define BF_BCH_FLASH0LAYOUT0_GF13_0_GF14_1(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH0LAYOUT0_GF13_0_GF14_1) & BM_BCH_FLASH0LAYOUT0_GF13_0_GF14_1)

/*! @brief Set the GF13_0_GF14_1 field to a new value. */
#define BW_BCH_FLASH0LAYOUT0_GF13_0_GF14_1(x, v) (HW_BCH_FLASH0LAYOUT0_WR(x, (HW_BCH_FLASH0LAYOUT0_RD(x) & ~BM_BCH_FLASH0LAYOUT0_GF13_0_GF14_1) | BF_BCH_FLASH0LAYOUT0_GF13_0_GF14_1(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH0LAYOUT0, field ECC0[15:11] (RW)
 *
 * Indicates the ECC level for the first block on the flash page. The first
 * block covers metadata plus the associated data from the DATA0_SIZE field.
 *
 * Values:
 * - 0 - No ECC to be performed
 * - 1 - ECC 2 to be performed
 * - 10 - ECC 4 to be performed
 * - 11110 - ECC 60 to be performed
 * - 11111 - ECC 62 to be performed
 */
/*@{*/
#define BP_BCH_FLASH0LAYOUT0_ECC0 (11U)    /*!< Bit position for BCH_FLASH0LAYOUT0_ECC0. */
#define BM_BCH_FLASH0LAYOUT0_ECC0 (0x0000F800U) /*!< Bit mask for BCH_FLASH0LAYOUT0_ECC0. */
#define BS_BCH_FLASH0LAYOUT0_ECC0 (5U)     /*!< Bit field size in bits for BCH_FLASH0LAYOUT0_ECC0. */

#define BV_BCH_FLASH0LAYOUT0_ECC0_NONE (0U)          /*!< Bit field value for BCH_FLASH0LAYOUT0_ECC0: No ECC to be performed */
#define BV_BCH_FLASH0LAYOUT0_ECC0_ECC2 (0x1U)        /*!< Bit field value for BCH_FLASH0LAYOUT0_ECC0: ECC 2 to be performed */
#define BV_BCH_FLASH0LAYOUT0_ECC0_ECC4 (0x2U)        /*!< Bit field value for BCH_FLASH0LAYOUT0_ECC0: ECC 4 to be performed */
#define BV_BCH_FLASH0LAYOUT0_ECC0_ECC60 (0x1EU)      /*!< Bit field value for BCH_FLASH0LAYOUT0_ECC0: ECC 60 to be performed */
#define BV_BCH_FLASH0LAYOUT0_ECC0_ECC62 (0x1FU)      /*!< Bit field value for BCH_FLASH0LAYOUT0_ECC0: ECC 62 to be performed */

/*! @brief Read current value of the BCH_FLASH0LAYOUT0_ECC0 field. */
#define BR_BCH_FLASH0LAYOUT0_ECC0(x) (HW_BCH_FLASH0LAYOUT0(x).B.ECC0)

/*! @brief Format value for bitfield BCH_FLASH0LAYOUT0_ECC0. */
#define BF_BCH_FLASH0LAYOUT0_ECC0(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH0LAYOUT0_ECC0) & BM_BCH_FLASH0LAYOUT0_ECC0)

/*! @brief Set the ECC0 field to a new value. */
#define BW_BCH_FLASH0LAYOUT0_ECC0(x, v) (HW_BCH_FLASH0LAYOUT0_WR(x, (HW_BCH_FLASH0LAYOUT0_RD(x) & ~BM_BCH_FLASH0LAYOUT0_ECC0) | BF_BCH_FLASH0LAYOUT0_ECC0(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH0LAYOUT0, field META_SIZE[23:16] (RW)
 *
 * Indicates the size of the metadata (in bytes) to be stored on a flash page.
 * The BCH design support from 0 to 255 bytes for metadata-if set to 0, no
 * metadata will be stored. Metadata is stored before the associated data in block 0. If
 * the DATA0_SIZE field is programmed to a 0, then metadata effectively be
 * stored with its own parity. When both the metadata and data0 fields are programmed
 * with non-zero values, the first block will contain both portions of data and
 * covered by a single parity block.
 */
/*@{*/
#define BP_BCH_FLASH0LAYOUT0_META_SIZE (16U) /*!< Bit position for BCH_FLASH0LAYOUT0_META_SIZE. */
#define BM_BCH_FLASH0LAYOUT0_META_SIZE (0x00FF0000U) /*!< Bit mask for BCH_FLASH0LAYOUT0_META_SIZE. */
#define BS_BCH_FLASH0LAYOUT0_META_SIZE (8U) /*!< Bit field size in bits for BCH_FLASH0LAYOUT0_META_SIZE. */

/*! @brief Read current value of the BCH_FLASH0LAYOUT0_META_SIZE field. */
#define BR_BCH_FLASH0LAYOUT0_META_SIZE(x) (HW_BCH_FLASH0LAYOUT0(x).B.META_SIZE)

/*! @brief Format value for bitfield BCH_FLASH0LAYOUT0_META_SIZE. */
#define BF_BCH_FLASH0LAYOUT0_META_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH0LAYOUT0_META_SIZE) & BM_BCH_FLASH0LAYOUT0_META_SIZE)

/*! @brief Set the META_SIZE field to a new value. */
#define BW_BCH_FLASH0LAYOUT0_META_SIZE(x, v) (HW_BCH_FLASH0LAYOUT0_WR(x, (HW_BCH_FLASH0LAYOUT0_RD(x) & ~BM_BCH_FLASH0LAYOUT0_META_SIZE) | BF_BCH_FLASH0LAYOUT0_META_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH0LAYOUT0, field NBLOCKS[31:24] (RW)
 *
 * Number of subsequent blocks on the flash page (excluding the data0 block). A
 * value of 0 indicates that only the DATA0 block is present and a value of 8
 * indicates that 8 subsequent blocks are present for a total of 9 blocks on the
 * flash (including the DATA0 block). Any values from 0 to 255 are supported by the
 * hardware.
 */
/*@{*/
#define BP_BCH_FLASH0LAYOUT0_NBLOCKS (24U) /*!< Bit position for BCH_FLASH0LAYOUT0_NBLOCKS. */
#define BM_BCH_FLASH0LAYOUT0_NBLOCKS (0xFF000000U) /*!< Bit mask for BCH_FLASH0LAYOUT0_NBLOCKS. */
#define BS_BCH_FLASH0LAYOUT0_NBLOCKS (8U)  /*!< Bit field size in bits for BCH_FLASH0LAYOUT0_NBLOCKS. */

/*! @brief Read current value of the BCH_FLASH0LAYOUT0_NBLOCKS field. */
#define BR_BCH_FLASH0LAYOUT0_NBLOCKS(x) (HW_BCH_FLASH0LAYOUT0(x).B.NBLOCKS)

/*! @brief Format value for bitfield BCH_FLASH0LAYOUT0_NBLOCKS. */
#define BF_BCH_FLASH0LAYOUT0_NBLOCKS(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH0LAYOUT0_NBLOCKS) & BM_BCH_FLASH0LAYOUT0_NBLOCKS)

/*! @brief Set the NBLOCKS field to a new value. */
#define BW_BCH_FLASH0LAYOUT0_NBLOCKS(x, v) (HW_BCH_FLASH0LAYOUT0_WR(x, (HW_BCH_FLASH0LAYOUT0_RD(x) & ~BM_BCH_FLASH0LAYOUT0_NBLOCKS) | BF_BCH_FLASH0LAYOUT0_NBLOCKS(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_FLASH0LAYOUT1 - Hardware BCH ECC Flash 0 Layout 1 Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_FLASH0LAYOUT1 - Hardware BCH ECC Flash 0 Layout 1 Register (RW)
 *
 * Reset value: 0x10DA4080U
 *
 * The flash format register contains a description of the logical layout of
 * data on the flash device. This register is used in conjunction with the
 * FLASH0LAYOUT0 register to control the format for the device selecting layout 0 in the
 * LAYOUTSELECT register.
 */
typedef union _hw_bch_flash0layout1
{
    uint32_t U;
    struct _hw_bch_flash0layout1_bitfields
    {
        uint32_t DATAN_SIZE : 10;      /*!< [9:0]  */
        uint32_t GF13_0_GF14_1 : 1;    /*!< [10]  */
        uint32_t ECCN : 5;             /*!< [15:11]  */
        uint32_t PAGE_SIZE : 16;       /*!< [31:16]  */
    } B;
} hw_bch_flash0layout1_t;

/*!
 * @name Constants and macros for entire BCH_FLASH0LAYOUT1 register
 */
/*@{*/
#define HW_BCH_FLASH0LAYOUT1_ADDR(x) ((uintptr_t)(x) + 0x90U)
#define HW_BCH_FLASH0LAYOUT1_SET_ADDR(x) (HW_BCH_FLASH0LAYOUT1_ADDR(x) + 0x4U)
#define HW_BCH_FLASH0LAYOUT1_CLR_ADDR(x) (HW_BCH_FLASH0LAYOUT1_ADDR(x) + 0x8U)
#define HW_BCH_FLASH0LAYOUT1_TOG_ADDR(x) (HW_BCH_FLASH0LAYOUT1_ADDR(x) + 0xCU)

#define HW_BCH_FLASH0LAYOUT1(x)  (*(__IO hw_bch_flash0layout1_t *) HW_BCH_FLASH0LAYOUT1_ADDR(x))
#define HW_BCH_FLASH0LAYOUT1_RD(x) (HW_BCH_FLASH0LAYOUT1(x).U)
#define HW_BCH_FLASH0LAYOUT1_WR(x, v) (HW_BCH_FLASH0LAYOUT1(x).U = (v))
#define HW_BCH_FLASH0LAYOUT1_SET(x, v) ((*(uint32_t *) HW_BCH_FLASH0LAYOUT1_SET_ADDR(x)) = (v))
#define HW_BCH_FLASH0LAYOUT1_CLR(x, v) ((*(uint32_t *) HW_BCH_FLASH0LAYOUT1_CLR_ADDR(x)) = (v))
#define HW_BCH_FLASH0LAYOUT1_TOG(x, v) ((*(uint32_t *) HW_BCH_FLASH0LAYOUT1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_FLASH0LAYOUT1 bitfields
 */

/*!
 * @name Register BCH_FLASH0LAYOUT1, field DATAN_SIZE[9:0] (RW)
 *
 * Indicates the size of the subsequent data blocks (in DWORDS / four bytes) to
 * be stored on the flash page. The size of subsequent data blocks does not have
 * to match the data size for block 0, which is important when metadata is stored
 * separately or for balancing the amount of data stored in each block.
 */
/*@{*/
#define BP_BCH_FLASH0LAYOUT1_DATAN_SIZE (0U) /*!< Bit position for BCH_FLASH0LAYOUT1_DATAN_SIZE. */
#define BM_BCH_FLASH0LAYOUT1_DATAN_SIZE (0x000003FFU) /*!< Bit mask for BCH_FLASH0LAYOUT1_DATAN_SIZE. */
#define BS_BCH_FLASH0LAYOUT1_DATAN_SIZE (10U) /*!< Bit field size in bits for BCH_FLASH0LAYOUT1_DATAN_SIZE. */

/*! @brief Read current value of the BCH_FLASH0LAYOUT1_DATAN_SIZE field. */
#define BR_BCH_FLASH0LAYOUT1_DATAN_SIZE(x) (HW_BCH_FLASH0LAYOUT1(x).B.DATAN_SIZE)

/*! @brief Format value for bitfield BCH_FLASH0LAYOUT1_DATAN_SIZE. */
#define BF_BCH_FLASH0LAYOUT1_DATAN_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH0LAYOUT1_DATAN_SIZE) & BM_BCH_FLASH0LAYOUT1_DATAN_SIZE)

/*! @brief Set the DATAN_SIZE field to a new value. */
#define BW_BCH_FLASH0LAYOUT1_DATAN_SIZE(x, v) (HW_BCH_FLASH0LAYOUT1_WR(x, (HW_BCH_FLASH0LAYOUT1_RD(x) & ~BM_BCH_FLASH0LAYOUT1_DATAN_SIZE) | BF_BCH_FLASH0LAYOUT1_DATAN_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH0LAYOUT1, field GF13_0_GF14_1[10] (RW)
 *
 * Select GF13 or GF14: 0-GF13; 1-GF14
 */
/*@{*/
#define BP_BCH_FLASH0LAYOUT1_GF13_0_GF14_1 (10U) /*!< Bit position for BCH_FLASH0LAYOUT1_GF13_0_GF14_1. */
#define BM_BCH_FLASH0LAYOUT1_GF13_0_GF14_1 (0x00000400U) /*!< Bit mask for BCH_FLASH0LAYOUT1_GF13_0_GF14_1. */
#define BS_BCH_FLASH0LAYOUT1_GF13_0_GF14_1 (1U) /*!< Bit field size in bits for BCH_FLASH0LAYOUT1_GF13_0_GF14_1. */

/*! @brief Read current value of the BCH_FLASH0LAYOUT1_GF13_0_GF14_1 field. */
#define BR_BCH_FLASH0LAYOUT1_GF13_0_GF14_1(x) (HW_BCH_FLASH0LAYOUT1(x).B.GF13_0_GF14_1)

/*! @brief Format value for bitfield BCH_FLASH0LAYOUT1_GF13_0_GF14_1. */
#define BF_BCH_FLASH0LAYOUT1_GF13_0_GF14_1(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH0LAYOUT1_GF13_0_GF14_1) & BM_BCH_FLASH0LAYOUT1_GF13_0_GF14_1)

/*! @brief Set the GF13_0_GF14_1 field to a new value. */
#define BW_BCH_FLASH0LAYOUT1_GF13_0_GF14_1(x, v) (HW_BCH_FLASH0LAYOUT1_WR(x, (HW_BCH_FLASH0LAYOUT1_RD(x) & ~BM_BCH_FLASH0LAYOUT1_GF13_0_GF14_1) | BF_BCH_FLASH0LAYOUT1_GF13_0_GF14_1(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH0LAYOUT1, field ECCN[15:11] (RW)
 *
 * Indicates the ECC level for the subsequent blocks on the flash page (blocks
 * 1-n). Subsequent blocks only contain data (no metadata).
 *
 * Values:
 * - 0 - No ECC to be performed
 * - 1 - ECC 2 to be performed
 * - 10 - ECC 4 to be performed
 * - 11110 - ECC 60 to be performed
 * - 11111 - ECC 62 to be performed
 */
/*@{*/
#define BP_BCH_FLASH0LAYOUT1_ECCN (11U)    /*!< Bit position for BCH_FLASH0LAYOUT1_ECCN. */
#define BM_BCH_FLASH0LAYOUT1_ECCN (0x0000F800U) /*!< Bit mask for BCH_FLASH0LAYOUT1_ECCN. */
#define BS_BCH_FLASH0LAYOUT1_ECCN (5U)     /*!< Bit field size in bits for BCH_FLASH0LAYOUT1_ECCN. */

#define BV_BCH_FLASH0LAYOUT1_ECCN_NONE (0U)          /*!< Bit field value for BCH_FLASH0LAYOUT1_ECCN: No ECC to be performed */
#define BV_BCH_FLASH0LAYOUT1_ECCN_ECC2 (0x1U)        /*!< Bit field value for BCH_FLASH0LAYOUT1_ECCN: ECC 2 to be performed */
#define BV_BCH_FLASH0LAYOUT1_ECCN_ECC4 (0x2U)        /*!< Bit field value for BCH_FLASH0LAYOUT1_ECCN: ECC 4 to be performed */
#define BV_BCH_FLASH0LAYOUT1_ECCN_ECC60 (0x1EU)      /*!< Bit field value for BCH_FLASH0LAYOUT1_ECCN: ECC 60 to be performed */
#define BV_BCH_FLASH0LAYOUT1_ECCN_ECC62 (0x1FU)      /*!< Bit field value for BCH_FLASH0LAYOUT1_ECCN: ECC 62 to be performed */

/*! @brief Read current value of the BCH_FLASH0LAYOUT1_ECCN field. */
#define BR_BCH_FLASH0LAYOUT1_ECCN(x) (HW_BCH_FLASH0LAYOUT1(x).B.ECCN)

/*! @brief Format value for bitfield BCH_FLASH0LAYOUT1_ECCN. */
#define BF_BCH_FLASH0LAYOUT1_ECCN(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH0LAYOUT1_ECCN) & BM_BCH_FLASH0LAYOUT1_ECCN)

/*! @brief Set the ECCN field to a new value. */
#define BW_BCH_FLASH0LAYOUT1_ECCN(x, v) (HW_BCH_FLASH0LAYOUT1_WR(x, (HW_BCH_FLASH0LAYOUT1_RD(x) & ~BM_BCH_FLASH0LAYOUT1_ECCN) | BF_BCH_FLASH0LAYOUT1_ECCN(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH0LAYOUT1, field PAGE_SIZE[31:16] (RW)
 *
 * Indicates the total size of the flash page (in bytes). This should be set to
 * the page size including spare area. The page size is programmable to
 * accomodate different flash configurations that may be available in the future.
 */
/*@{*/
#define BP_BCH_FLASH0LAYOUT1_PAGE_SIZE (16U) /*!< Bit position for BCH_FLASH0LAYOUT1_PAGE_SIZE. */
#define BM_BCH_FLASH0LAYOUT1_PAGE_SIZE (0xFFFF0000U) /*!< Bit mask for BCH_FLASH0LAYOUT1_PAGE_SIZE. */
#define BS_BCH_FLASH0LAYOUT1_PAGE_SIZE (16U) /*!< Bit field size in bits for BCH_FLASH0LAYOUT1_PAGE_SIZE. */

/*! @brief Read current value of the BCH_FLASH0LAYOUT1_PAGE_SIZE field. */
#define BR_BCH_FLASH0LAYOUT1_PAGE_SIZE(x) (HW_BCH_FLASH0LAYOUT1(x).B.PAGE_SIZE)

/*! @brief Format value for bitfield BCH_FLASH0LAYOUT1_PAGE_SIZE. */
#define BF_BCH_FLASH0LAYOUT1_PAGE_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH0LAYOUT1_PAGE_SIZE) & BM_BCH_FLASH0LAYOUT1_PAGE_SIZE)

/*! @brief Set the PAGE_SIZE field to a new value. */
#define BW_BCH_FLASH0LAYOUT1_PAGE_SIZE(x, v) (HW_BCH_FLASH0LAYOUT1_WR(x, (HW_BCH_FLASH0LAYOUT1_RD(x) & ~BM_BCH_FLASH0LAYOUT1_PAGE_SIZE) | BF_BCH_FLASH0LAYOUT1_PAGE_SIZE(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_FLASH1LAYOUT0 - Hardware BCH ECC Flash 1 Layout 0 Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_FLASH1LAYOUT0 - Hardware BCH ECC Flash 1 Layout 0 Register (RW)
 *
 * Reset value: 0x070A4080U
 *
 * The flash format register contains a description of the logical layout of
 * data on the flash device. This register is used in conjunction with the
 * FLASH1LAYOUT1 register to control the format for the devices selecting layout 1 in the
 * LAYOUTSELECT register. Each pair of layout registers describes one of four
 * supported flash configurations. Software should program the LAYOUTSELECT register
 * for each supported GPMI chip select to select from one of the four layout
 * values. Each pair of registers contains settings that are used by the BCH block
 * while reading / writing the flash page to control data, metadata, and flash
 * page sizes as well as the ECC correction level. The first block written to flash
 * can be programmed to have different ECC, metadata, and data sizes from
 * subsequent data blocks on the device. In addition, the number of blocks stored on a
 * page of flash is not fixed, but instead is determined by the number of bytes
 * consumed by the initial (block 0) and subsequent data blocks. See the BCH
 * programming reference manual for more information on setting up the flash layout
 * registers.
 */
typedef union _hw_bch_flash1layout0
{
    uint32_t U;
    struct _hw_bch_flash1layout0_bitfields
    {
        uint32_t DATA0_SIZE : 10;      /*!< [9:0]  */
        uint32_t GF13_0_GF14_1 : 1;    /*!< [10]  */
        uint32_t ECC0 : 5;             /*!< [15:11]  */
        uint32_t META_SIZE : 8;        /*!< [23:16]  */
        uint32_t NBLOCKS : 8;          /*!< [31:24]  */
    } B;
} hw_bch_flash1layout0_t;

/*!
 * @name Constants and macros for entire BCH_FLASH1LAYOUT0 register
 */
/*@{*/
#define HW_BCH_FLASH1LAYOUT0_ADDR(x) ((uintptr_t)(x) + 0xA0U)
#define HW_BCH_FLASH1LAYOUT0_SET_ADDR(x) (HW_BCH_FLASH1LAYOUT0_ADDR(x) + 0x4U)
#define HW_BCH_FLASH1LAYOUT0_CLR_ADDR(x) (HW_BCH_FLASH1LAYOUT0_ADDR(x) + 0x8U)
#define HW_BCH_FLASH1LAYOUT0_TOG_ADDR(x) (HW_BCH_FLASH1LAYOUT0_ADDR(x) + 0xCU)

#define HW_BCH_FLASH1LAYOUT0(x)  (*(__IO hw_bch_flash1layout0_t *) HW_BCH_FLASH1LAYOUT0_ADDR(x))
#define HW_BCH_FLASH1LAYOUT0_RD(x) (HW_BCH_FLASH1LAYOUT0(x).U)
#define HW_BCH_FLASH1LAYOUT0_WR(x, v) (HW_BCH_FLASH1LAYOUT0(x).U = (v))
#define HW_BCH_FLASH1LAYOUT0_SET(x, v) ((*(uint32_t *) HW_BCH_FLASH1LAYOUT0_SET_ADDR(x)) = (v))
#define HW_BCH_FLASH1LAYOUT0_CLR(x, v) ((*(uint32_t *) HW_BCH_FLASH1LAYOUT0_CLR_ADDR(x)) = (v))
#define HW_BCH_FLASH1LAYOUT0_TOG(x, v) ((*(uint32_t *) HW_BCH_FLASH1LAYOUT0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_FLASH1LAYOUT0 bitfields
 */

/*!
 * @name Register BCH_FLASH1LAYOUT0, field DATA0_SIZE[9:0] (RW)
 *
 * Indicates the size of the data 0 block (in DWORDS / four bytes) to be stored
 * on the flash page. If set to 0, the first block will contains metadata.
 */
/*@{*/
#define BP_BCH_FLASH1LAYOUT0_DATA0_SIZE (0U) /*!< Bit position for BCH_FLASH1LAYOUT0_DATA0_SIZE. */
#define BM_BCH_FLASH1LAYOUT0_DATA0_SIZE (0x000003FFU) /*!< Bit mask for BCH_FLASH1LAYOUT0_DATA0_SIZE. */
#define BS_BCH_FLASH1LAYOUT0_DATA0_SIZE (10U) /*!< Bit field size in bits for BCH_FLASH1LAYOUT0_DATA0_SIZE. */

/*! @brief Read current value of the BCH_FLASH1LAYOUT0_DATA0_SIZE field. */
#define BR_BCH_FLASH1LAYOUT0_DATA0_SIZE(x) (HW_BCH_FLASH1LAYOUT0(x).B.DATA0_SIZE)

/*! @brief Format value for bitfield BCH_FLASH1LAYOUT0_DATA0_SIZE. */
#define BF_BCH_FLASH1LAYOUT0_DATA0_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH1LAYOUT0_DATA0_SIZE) & BM_BCH_FLASH1LAYOUT0_DATA0_SIZE)

/*! @brief Set the DATA0_SIZE field to a new value. */
#define BW_BCH_FLASH1LAYOUT0_DATA0_SIZE(x, v) (HW_BCH_FLASH1LAYOUT0_WR(x, (HW_BCH_FLASH1LAYOUT0_RD(x) & ~BM_BCH_FLASH1LAYOUT0_DATA0_SIZE) | BF_BCH_FLASH1LAYOUT0_DATA0_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH1LAYOUT0, field GF13_0_GF14_1[10] (RW)
 *
 * Select GF13 or GF14: 0-GF13; 1-GF14
 */
/*@{*/
#define BP_BCH_FLASH1LAYOUT0_GF13_0_GF14_1 (10U) /*!< Bit position for BCH_FLASH1LAYOUT0_GF13_0_GF14_1. */
#define BM_BCH_FLASH1LAYOUT0_GF13_0_GF14_1 (0x00000400U) /*!< Bit mask for BCH_FLASH1LAYOUT0_GF13_0_GF14_1. */
#define BS_BCH_FLASH1LAYOUT0_GF13_0_GF14_1 (1U) /*!< Bit field size in bits for BCH_FLASH1LAYOUT0_GF13_0_GF14_1. */

/*! @brief Read current value of the BCH_FLASH1LAYOUT0_GF13_0_GF14_1 field. */
#define BR_BCH_FLASH1LAYOUT0_GF13_0_GF14_1(x) (HW_BCH_FLASH1LAYOUT0(x).B.GF13_0_GF14_1)

/*! @brief Format value for bitfield BCH_FLASH1LAYOUT0_GF13_0_GF14_1. */
#define BF_BCH_FLASH1LAYOUT0_GF13_0_GF14_1(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH1LAYOUT0_GF13_0_GF14_1) & BM_BCH_FLASH1LAYOUT0_GF13_0_GF14_1)

/*! @brief Set the GF13_0_GF14_1 field to a new value. */
#define BW_BCH_FLASH1LAYOUT0_GF13_0_GF14_1(x, v) (HW_BCH_FLASH1LAYOUT0_WR(x, (HW_BCH_FLASH1LAYOUT0_RD(x) & ~BM_BCH_FLASH1LAYOUT0_GF13_0_GF14_1) | BF_BCH_FLASH1LAYOUT0_GF13_0_GF14_1(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH1LAYOUT0, field ECC0[15:11] (RW)
 *
 * Indicates the ECC level for the first block on the flash page. The first
 * block covers metadata plus the associated data from the DATA0_SIZE field.
 *
 * Values:
 * - 0 - No ECC to be performed
 * - 1 - ECC 2 to be performed
 * - 10 - ECC 4 to be performed
 * - 11110 - ECC 60 to be performed
 * - 11111 - ECC 62 to be performed
 */
/*@{*/
#define BP_BCH_FLASH1LAYOUT0_ECC0 (11U)    /*!< Bit position for BCH_FLASH1LAYOUT0_ECC0. */
#define BM_BCH_FLASH1LAYOUT0_ECC0 (0x0000F800U) /*!< Bit mask for BCH_FLASH1LAYOUT0_ECC0. */
#define BS_BCH_FLASH1LAYOUT0_ECC0 (5U)     /*!< Bit field size in bits for BCH_FLASH1LAYOUT0_ECC0. */

#define BV_BCH_FLASH1LAYOUT0_ECC0_NONE (0U)          /*!< Bit field value for BCH_FLASH1LAYOUT0_ECC0: No ECC to be performed */
#define BV_BCH_FLASH1LAYOUT0_ECC0_ECC2 (0x1U)        /*!< Bit field value for BCH_FLASH1LAYOUT0_ECC0: ECC 2 to be performed */
#define BV_BCH_FLASH1LAYOUT0_ECC0_ECC4 (0x2U)        /*!< Bit field value for BCH_FLASH1LAYOUT0_ECC0: ECC 4 to be performed */
#define BV_BCH_FLASH1LAYOUT0_ECC0_ECC60 (0x1EU)      /*!< Bit field value for BCH_FLASH1LAYOUT0_ECC0: ECC 60 to be performed */
#define BV_BCH_FLASH1LAYOUT0_ECC0_ECC62 (0x1FU)      /*!< Bit field value for BCH_FLASH1LAYOUT0_ECC0: ECC 62 to be performed */

/*! @brief Read current value of the BCH_FLASH1LAYOUT0_ECC0 field. */
#define BR_BCH_FLASH1LAYOUT0_ECC0(x) (HW_BCH_FLASH1LAYOUT0(x).B.ECC0)

/*! @brief Format value for bitfield BCH_FLASH1LAYOUT0_ECC0. */
#define BF_BCH_FLASH1LAYOUT0_ECC0(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH1LAYOUT0_ECC0) & BM_BCH_FLASH1LAYOUT0_ECC0)

/*! @brief Set the ECC0 field to a new value. */
#define BW_BCH_FLASH1LAYOUT0_ECC0(x, v) (HW_BCH_FLASH1LAYOUT0_WR(x, (HW_BCH_FLASH1LAYOUT0_RD(x) & ~BM_BCH_FLASH1LAYOUT0_ECC0) | BF_BCH_FLASH1LAYOUT0_ECC0(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH1LAYOUT0, field META_SIZE[23:16] (RW)
 *
 * Indicates the size of the metadata (in bytes) to be stored on a flash page.
 * The BCH design supports from 0 to 255 bytes for metadata-if set to 0, no
 * metadata will be stored. Metadata is stored before the associated data is in block
 * 0. If the DATA0_SIZE field is programmed to a 0, then metadata effectively be
 * stored with its own parity. When both the metadata and data0 fields are
 * programmed with non-zero values, the first block will contain both portions of data
 * and covered by a single parity block.
 */
/*@{*/
#define BP_BCH_FLASH1LAYOUT0_META_SIZE (16U) /*!< Bit position for BCH_FLASH1LAYOUT0_META_SIZE. */
#define BM_BCH_FLASH1LAYOUT0_META_SIZE (0x00FF0000U) /*!< Bit mask for BCH_FLASH1LAYOUT0_META_SIZE. */
#define BS_BCH_FLASH1LAYOUT0_META_SIZE (8U) /*!< Bit field size in bits for BCH_FLASH1LAYOUT0_META_SIZE. */

/*! @brief Read current value of the BCH_FLASH1LAYOUT0_META_SIZE field. */
#define BR_BCH_FLASH1LAYOUT0_META_SIZE(x) (HW_BCH_FLASH1LAYOUT0(x).B.META_SIZE)

/*! @brief Format value for bitfield BCH_FLASH1LAYOUT0_META_SIZE. */
#define BF_BCH_FLASH1LAYOUT0_META_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH1LAYOUT0_META_SIZE) & BM_BCH_FLASH1LAYOUT0_META_SIZE)

/*! @brief Set the META_SIZE field to a new value. */
#define BW_BCH_FLASH1LAYOUT0_META_SIZE(x, v) (HW_BCH_FLASH1LAYOUT0_WR(x, (HW_BCH_FLASH1LAYOUT0_RD(x) & ~BM_BCH_FLASH1LAYOUT0_META_SIZE) | BF_BCH_FLASH1LAYOUT0_META_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH1LAYOUT0, field NBLOCKS[31:24] (RW)
 *
 * Number of subsequent blocks on the flash page (excluding the data0 block). A
 * value of 0 indicates that only the DATA0 block is present and a value of 8
 * indicates that 8 subsequent blocks are present for a total of 9 blocks on the
 * flash (including the DATA0 block). Any values from 0 to 255 are supported by the
 * hardware.
 */
/*@{*/
#define BP_BCH_FLASH1LAYOUT0_NBLOCKS (24U) /*!< Bit position for BCH_FLASH1LAYOUT0_NBLOCKS. */
#define BM_BCH_FLASH1LAYOUT0_NBLOCKS (0xFF000000U) /*!< Bit mask for BCH_FLASH1LAYOUT0_NBLOCKS. */
#define BS_BCH_FLASH1LAYOUT0_NBLOCKS (8U)  /*!< Bit field size in bits for BCH_FLASH1LAYOUT0_NBLOCKS. */

/*! @brief Read current value of the BCH_FLASH1LAYOUT0_NBLOCKS field. */
#define BR_BCH_FLASH1LAYOUT0_NBLOCKS(x) (HW_BCH_FLASH1LAYOUT0(x).B.NBLOCKS)

/*! @brief Format value for bitfield BCH_FLASH1LAYOUT0_NBLOCKS. */
#define BF_BCH_FLASH1LAYOUT0_NBLOCKS(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH1LAYOUT0_NBLOCKS) & BM_BCH_FLASH1LAYOUT0_NBLOCKS)

/*! @brief Set the NBLOCKS field to a new value. */
#define BW_BCH_FLASH1LAYOUT0_NBLOCKS(x, v) (HW_BCH_FLASH1LAYOUT0_WR(x, (HW_BCH_FLASH1LAYOUT0_RD(x) & ~BM_BCH_FLASH1LAYOUT0_NBLOCKS) | BF_BCH_FLASH1LAYOUT0_NBLOCKS(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_FLASH1LAYOUT1 - Hardware BCH ECC Flash 1 Layout 1 Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_FLASH1LAYOUT1 - Hardware BCH ECC Flash 1 Layout 1 Register (RW)
 *
 * Reset value: 0x10DA4080U
 *
 * The flash format register contains a description of the logical layout of
 * data on the flash device. This register is used in conjunction with the
 * FLASH1LAYOUT0 register to control the format for the device selecting layout 1 in the
 * LAYOUTSELECT register.
 */
typedef union _hw_bch_flash1layout1
{
    uint32_t U;
    struct _hw_bch_flash1layout1_bitfields
    {
        uint32_t DATAN_SIZE : 10;      /*!< [9:0]  */
        uint32_t GF13_0_GF14_1 : 1;    /*!< [10]  */
        uint32_t ECCN : 5;             /*!< [15:11]  */
        uint32_t PAGE_SIZE : 16;       /*!< [31:16]  */
    } B;
} hw_bch_flash1layout1_t;

/*!
 * @name Constants and macros for entire BCH_FLASH1LAYOUT1 register
 */
/*@{*/
#define HW_BCH_FLASH1LAYOUT1_ADDR(x) ((uintptr_t)(x) + 0xB0U)
#define HW_BCH_FLASH1LAYOUT1_SET_ADDR(x) (HW_BCH_FLASH1LAYOUT1_ADDR(x) + 0x4U)
#define HW_BCH_FLASH1LAYOUT1_CLR_ADDR(x) (HW_BCH_FLASH1LAYOUT1_ADDR(x) + 0x8U)
#define HW_BCH_FLASH1LAYOUT1_TOG_ADDR(x) (HW_BCH_FLASH1LAYOUT1_ADDR(x) + 0xCU)

#define HW_BCH_FLASH1LAYOUT1(x)  (*(__IO hw_bch_flash1layout1_t *) HW_BCH_FLASH1LAYOUT1_ADDR(x))
#define HW_BCH_FLASH1LAYOUT1_RD(x) (HW_BCH_FLASH1LAYOUT1(x).U)
#define HW_BCH_FLASH1LAYOUT1_WR(x, v) (HW_BCH_FLASH1LAYOUT1(x).U = (v))
#define HW_BCH_FLASH1LAYOUT1_SET(x, v) ((*(uint32_t *) HW_BCH_FLASH1LAYOUT1_SET_ADDR(x)) = (v))
#define HW_BCH_FLASH1LAYOUT1_CLR(x, v) ((*(uint32_t *) HW_BCH_FLASH1LAYOUT1_CLR_ADDR(x)) = (v))
#define HW_BCH_FLASH1LAYOUT1_TOG(x, v) ((*(uint32_t *) HW_BCH_FLASH1LAYOUT1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_FLASH1LAYOUT1 bitfields
 */

/*!
 * @name Register BCH_FLASH1LAYOUT1, field DATAN_SIZE[9:0] (RW)
 *
 * Indicates the size of the subsequent data blocks (in DWORDS / four bytes) to
 * be stored on the flash page. The size of subsequent data blocks does not have
 * to match the data size for block 0, which is important when metadata is stored
 * separately or for balancing the amount of data stored in each block.
 */
/*@{*/
#define BP_BCH_FLASH1LAYOUT1_DATAN_SIZE (0U) /*!< Bit position for BCH_FLASH1LAYOUT1_DATAN_SIZE. */
#define BM_BCH_FLASH1LAYOUT1_DATAN_SIZE (0x000003FFU) /*!< Bit mask for BCH_FLASH1LAYOUT1_DATAN_SIZE. */
#define BS_BCH_FLASH1LAYOUT1_DATAN_SIZE (10U) /*!< Bit field size in bits for BCH_FLASH1LAYOUT1_DATAN_SIZE. */

/*! @brief Read current value of the BCH_FLASH1LAYOUT1_DATAN_SIZE field. */
#define BR_BCH_FLASH1LAYOUT1_DATAN_SIZE(x) (HW_BCH_FLASH1LAYOUT1(x).B.DATAN_SIZE)

/*! @brief Format value for bitfield BCH_FLASH1LAYOUT1_DATAN_SIZE. */
#define BF_BCH_FLASH1LAYOUT1_DATAN_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH1LAYOUT1_DATAN_SIZE) & BM_BCH_FLASH1LAYOUT1_DATAN_SIZE)

/*! @brief Set the DATAN_SIZE field to a new value. */
#define BW_BCH_FLASH1LAYOUT1_DATAN_SIZE(x, v) (HW_BCH_FLASH1LAYOUT1_WR(x, (HW_BCH_FLASH1LAYOUT1_RD(x) & ~BM_BCH_FLASH1LAYOUT1_DATAN_SIZE) | BF_BCH_FLASH1LAYOUT1_DATAN_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH1LAYOUT1, field GF13_0_GF14_1[10] (RW)
 *
 * Select GF13 or GF14: 0-GF13; 1-GF14
 */
/*@{*/
#define BP_BCH_FLASH1LAYOUT1_GF13_0_GF14_1 (10U) /*!< Bit position for BCH_FLASH1LAYOUT1_GF13_0_GF14_1. */
#define BM_BCH_FLASH1LAYOUT1_GF13_0_GF14_1 (0x00000400U) /*!< Bit mask for BCH_FLASH1LAYOUT1_GF13_0_GF14_1. */
#define BS_BCH_FLASH1LAYOUT1_GF13_0_GF14_1 (1U) /*!< Bit field size in bits for BCH_FLASH1LAYOUT1_GF13_0_GF14_1. */

/*! @brief Read current value of the BCH_FLASH1LAYOUT1_GF13_0_GF14_1 field. */
#define BR_BCH_FLASH1LAYOUT1_GF13_0_GF14_1(x) (HW_BCH_FLASH1LAYOUT1(x).B.GF13_0_GF14_1)

/*! @brief Format value for bitfield BCH_FLASH1LAYOUT1_GF13_0_GF14_1. */
#define BF_BCH_FLASH1LAYOUT1_GF13_0_GF14_1(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH1LAYOUT1_GF13_0_GF14_1) & BM_BCH_FLASH1LAYOUT1_GF13_0_GF14_1)

/*! @brief Set the GF13_0_GF14_1 field to a new value. */
#define BW_BCH_FLASH1LAYOUT1_GF13_0_GF14_1(x, v) (HW_BCH_FLASH1LAYOUT1_WR(x, (HW_BCH_FLASH1LAYOUT1_RD(x) & ~BM_BCH_FLASH1LAYOUT1_GF13_0_GF14_1) | BF_BCH_FLASH1LAYOUT1_GF13_0_GF14_1(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH1LAYOUT1, field ECCN[15:11] (RW)
 *
 * Indicates the ECC level for the subsequent blocks on the flash page (blocks
 * 1-n). Subsequent blocks only contain data (no metadata).
 *
 * Values:
 * - 0 - No ECC to be performed
 * - 1 - ECC 2 to be performed
 * - 10 - ECC 4 to be performed
 * - 11110 - ECC 60 to be performed
 * - 11111 - ECC 62 to be performed
 */
/*@{*/
#define BP_BCH_FLASH1LAYOUT1_ECCN (11U)    /*!< Bit position for BCH_FLASH1LAYOUT1_ECCN. */
#define BM_BCH_FLASH1LAYOUT1_ECCN (0x0000F800U) /*!< Bit mask for BCH_FLASH1LAYOUT1_ECCN. */
#define BS_BCH_FLASH1LAYOUT1_ECCN (5U)     /*!< Bit field size in bits for BCH_FLASH1LAYOUT1_ECCN. */

#define BV_BCH_FLASH1LAYOUT1_ECCN_NONE (0U)          /*!< Bit field value for BCH_FLASH1LAYOUT1_ECCN: No ECC to be performed */
#define BV_BCH_FLASH1LAYOUT1_ECCN_ECC2 (0x1U)        /*!< Bit field value for BCH_FLASH1LAYOUT1_ECCN: ECC 2 to be performed */
#define BV_BCH_FLASH1LAYOUT1_ECCN_ECC4 (0x2U)        /*!< Bit field value for BCH_FLASH1LAYOUT1_ECCN: ECC 4 to be performed */
#define BV_BCH_FLASH1LAYOUT1_ECCN_ECC60 (0x1EU)      /*!< Bit field value for BCH_FLASH1LAYOUT1_ECCN: ECC 60 to be performed */
#define BV_BCH_FLASH1LAYOUT1_ECCN_ECC62 (0x1FU)      /*!< Bit field value for BCH_FLASH1LAYOUT1_ECCN: ECC 62 to be performed */

/*! @brief Read current value of the BCH_FLASH1LAYOUT1_ECCN field. */
#define BR_BCH_FLASH1LAYOUT1_ECCN(x) (HW_BCH_FLASH1LAYOUT1(x).B.ECCN)

/*! @brief Format value for bitfield BCH_FLASH1LAYOUT1_ECCN. */
#define BF_BCH_FLASH1LAYOUT1_ECCN(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH1LAYOUT1_ECCN) & BM_BCH_FLASH1LAYOUT1_ECCN)

/*! @brief Set the ECCN field to a new value. */
#define BW_BCH_FLASH1LAYOUT1_ECCN(x, v) (HW_BCH_FLASH1LAYOUT1_WR(x, (HW_BCH_FLASH1LAYOUT1_RD(x) & ~BM_BCH_FLASH1LAYOUT1_ECCN) | BF_BCH_FLASH1LAYOUT1_ECCN(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH1LAYOUT1, field PAGE_SIZE[31:16] (RW)
 *
 * Indicates the total size of the flash page (in bytes). This should be set to
 * the page size including spare area. The page size is programmable to
 * accomodate different flash configurations that may be available in the future.
 */
/*@{*/
#define BP_BCH_FLASH1LAYOUT1_PAGE_SIZE (16U) /*!< Bit position for BCH_FLASH1LAYOUT1_PAGE_SIZE. */
#define BM_BCH_FLASH1LAYOUT1_PAGE_SIZE (0xFFFF0000U) /*!< Bit mask for BCH_FLASH1LAYOUT1_PAGE_SIZE. */
#define BS_BCH_FLASH1LAYOUT1_PAGE_SIZE (16U) /*!< Bit field size in bits for BCH_FLASH1LAYOUT1_PAGE_SIZE. */

/*! @brief Read current value of the BCH_FLASH1LAYOUT1_PAGE_SIZE field. */
#define BR_BCH_FLASH1LAYOUT1_PAGE_SIZE(x) (HW_BCH_FLASH1LAYOUT1(x).B.PAGE_SIZE)

/*! @brief Format value for bitfield BCH_FLASH1LAYOUT1_PAGE_SIZE. */
#define BF_BCH_FLASH1LAYOUT1_PAGE_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH1LAYOUT1_PAGE_SIZE) & BM_BCH_FLASH1LAYOUT1_PAGE_SIZE)

/*! @brief Set the PAGE_SIZE field to a new value. */
#define BW_BCH_FLASH1LAYOUT1_PAGE_SIZE(x, v) (HW_BCH_FLASH1LAYOUT1_WR(x, (HW_BCH_FLASH1LAYOUT1_RD(x) & ~BM_BCH_FLASH1LAYOUT1_PAGE_SIZE) | BF_BCH_FLASH1LAYOUT1_PAGE_SIZE(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_FLASH2LAYOUT0 - Hardware BCH ECC Flash 2 Layout 0 Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_FLASH2LAYOUT0 - Hardware BCH ECC Flash 2 Layout 0 Register (RW)
 *
 * Reset value: 0x070A4080U
 *
 * The flash format register contains a description of the logical layout of
 * data on the flash device. This register is used in conjunction with the
 * FLASH2LAYOUT1 register to control the format for the devices selecting layout 2 in the
 * LAYOUTSELECT register. Each pair of layout registers describes one of four
 * supported flash configurations. Software should program the LAYOUTSELECT register
 * for each supported GPMI chip select to select from one of the four layout
 * values. Each pair of registers contains settings that are used by the BCH block
 * while reading / writing the flash page to control data, metadata, and flash
 * page sizes as well as the ECC correction level. The first block written to flash
 * can be programmed to have different ECC, metadata, and data sizes from
 * subsequent data blocks on the device. In addition, the number of blocks stored on a
 * page of flash is not fixed, but instead is determined by the number of bytes
 * consumed by the initial (block 0) and subsequent data blocks. See the BCH
 * programming reference manual for more information on setting up the flash layout
 * registers.
 */
typedef union _hw_bch_flash2layout0
{
    uint32_t U;
    struct _hw_bch_flash2layout0_bitfields
    {
        uint32_t DATA0_SIZE : 10;      /*!< [9:0]  */
        uint32_t GF13_0_GF14_1 : 1;    /*!< [10]  */
        uint32_t ECC0 : 5;             /*!< [15:11]  */
        uint32_t META_SIZE : 8;        /*!< [23:16]  */
        uint32_t NBLOCKS : 8;          /*!< [31:24]  */
    } B;
} hw_bch_flash2layout0_t;

/*!
 * @name Constants and macros for entire BCH_FLASH2LAYOUT0 register
 */
/*@{*/
#define HW_BCH_FLASH2LAYOUT0_ADDR(x) ((uintptr_t)(x) + 0xC0U)
#define HW_BCH_FLASH2LAYOUT0_SET_ADDR(x) (HW_BCH_FLASH2LAYOUT0_ADDR(x) + 0x4U)
#define HW_BCH_FLASH2LAYOUT0_CLR_ADDR(x) (HW_BCH_FLASH2LAYOUT0_ADDR(x) + 0x8U)
#define HW_BCH_FLASH2LAYOUT0_TOG_ADDR(x) (HW_BCH_FLASH2LAYOUT0_ADDR(x) + 0xCU)

#define HW_BCH_FLASH2LAYOUT0(x)  (*(__IO hw_bch_flash2layout0_t *) HW_BCH_FLASH2LAYOUT0_ADDR(x))
#define HW_BCH_FLASH2LAYOUT0_RD(x) (HW_BCH_FLASH2LAYOUT0(x).U)
#define HW_BCH_FLASH2LAYOUT0_WR(x, v) (HW_BCH_FLASH2LAYOUT0(x).U = (v))
#define HW_BCH_FLASH2LAYOUT0_SET(x, v) ((*(uint32_t *) HW_BCH_FLASH2LAYOUT0_SET_ADDR(x)) = (v))
#define HW_BCH_FLASH2LAYOUT0_CLR(x, v) ((*(uint32_t *) HW_BCH_FLASH2LAYOUT0_CLR_ADDR(x)) = (v))
#define HW_BCH_FLASH2LAYOUT0_TOG(x, v) ((*(uint32_t *) HW_BCH_FLASH2LAYOUT0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_FLASH2LAYOUT0 bitfields
 */

/*!
 * @name Register BCH_FLASH2LAYOUT0, field DATA0_SIZE[9:0] (RW)
 *
 * Indicates the size of the data 0 block (in DWORDS / four bytes) to be stored
 * on the flash page. If set to 0, the first block will only contain metadata.
 */
/*@{*/
#define BP_BCH_FLASH2LAYOUT0_DATA0_SIZE (0U) /*!< Bit position for BCH_FLASH2LAYOUT0_DATA0_SIZE. */
#define BM_BCH_FLASH2LAYOUT0_DATA0_SIZE (0x000003FFU) /*!< Bit mask for BCH_FLASH2LAYOUT0_DATA0_SIZE. */
#define BS_BCH_FLASH2LAYOUT0_DATA0_SIZE (10U) /*!< Bit field size in bits for BCH_FLASH2LAYOUT0_DATA0_SIZE. */

/*! @brief Read current value of the BCH_FLASH2LAYOUT0_DATA0_SIZE field. */
#define BR_BCH_FLASH2LAYOUT0_DATA0_SIZE(x) (HW_BCH_FLASH2LAYOUT0(x).B.DATA0_SIZE)

/*! @brief Format value for bitfield BCH_FLASH2LAYOUT0_DATA0_SIZE. */
#define BF_BCH_FLASH2LAYOUT0_DATA0_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH2LAYOUT0_DATA0_SIZE) & BM_BCH_FLASH2LAYOUT0_DATA0_SIZE)

/*! @brief Set the DATA0_SIZE field to a new value. */
#define BW_BCH_FLASH2LAYOUT0_DATA0_SIZE(x, v) (HW_BCH_FLASH2LAYOUT0_WR(x, (HW_BCH_FLASH2LAYOUT0_RD(x) & ~BM_BCH_FLASH2LAYOUT0_DATA0_SIZE) | BF_BCH_FLASH2LAYOUT0_DATA0_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH2LAYOUT0, field GF13_0_GF14_1[10] (RW)
 *
 * Select GF13 or GF14: 0-GF13; 1-GF14
 */
/*@{*/
#define BP_BCH_FLASH2LAYOUT0_GF13_0_GF14_1 (10U) /*!< Bit position for BCH_FLASH2LAYOUT0_GF13_0_GF14_1. */
#define BM_BCH_FLASH2LAYOUT0_GF13_0_GF14_1 (0x00000400U) /*!< Bit mask for BCH_FLASH2LAYOUT0_GF13_0_GF14_1. */
#define BS_BCH_FLASH2LAYOUT0_GF13_0_GF14_1 (1U) /*!< Bit field size in bits for BCH_FLASH2LAYOUT0_GF13_0_GF14_1. */

/*! @brief Read current value of the BCH_FLASH2LAYOUT0_GF13_0_GF14_1 field. */
#define BR_BCH_FLASH2LAYOUT0_GF13_0_GF14_1(x) (HW_BCH_FLASH2LAYOUT0(x).B.GF13_0_GF14_1)

/*! @brief Format value for bitfield BCH_FLASH2LAYOUT0_GF13_0_GF14_1. */
#define BF_BCH_FLASH2LAYOUT0_GF13_0_GF14_1(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH2LAYOUT0_GF13_0_GF14_1) & BM_BCH_FLASH2LAYOUT0_GF13_0_GF14_1)

/*! @brief Set the GF13_0_GF14_1 field to a new value. */
#define BW_BCH_FLASH2LAYOUT0_GF13_0_GF14_1(x, v) (HW_BCH_FLASH2LAYOUT0_WR(x, (HW_BCH_FLASH2LAYOUT0_RD(x) & ~BM_BCH_FLASH2LAYOUT0_GF13_0_GF14_1) | BF_BCH_FLASH2LAYOUT0_GF13_0_GF14_1(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH2LAYOUT0, field ECC0[15:11] (RW)
 *
 * Indicates the ECC level for the first block on the flash page. The first
 * block covers metadata plus the associated data from the DATA0_SIZE field.
 *
 * Values:
 * - 0 - No ECC to be performed
 * - 1 - ECC 2 to be performed
 * - 10 - ECC 4 to be performed
 * - 11110 - ECC 60 to be performed
 * - 11111 - ECC 62 to be performed
 */
/*@{*/
#define BP_BCH_FLASH2LAYOUT0_ECC0 (11U)    /*!< Bit position for BCH_FLASH2LAYOUT0_ECC0. */
#define BM_BCH_FLASH2LAYOUT0_ECC0 (0x0000F800U) /*!< Bit mask for BCH_FLASH2LAYOUT0_ECC0. */
#define BS_BCH_FLASH2LAYOUT0_ECC0 (5U)     /*!< Bit field size in bits for BCH_FLASH2LAYOUT0_ECC0. */

#define BV_BCH_FLASH2LAYOUT0_ECC0_NONE (0U)          /*!< Bit field value for BCH_FLASH2LAYOUT0_ECC0: No ECC to be performed */
#define BV_BCH_FLASH2LAYOUT0_ECC0_ECC2 (0x1U)        /*!< Bit field value for BCH_FLASH2LAYOUT0_ECC0: ECC 2 to be performed */
#define BV_BCH_FLASH2LAYOUT0_ECC0_ECC4 (0x2U)        /*!< Bit field value for BCH_FLASH2LAYOUT0_ECC0: ECC 4 to be performed */
#define BV_BCH_FLASH2LAYOUT0_ECC0_ECC60 (0x1EU)      /*!< Bit field value for BCH_FLASH2LAYOUT0_ECC0: ECC 60 to be performed */
#define BV_BCH_FLASH2LAYOUT0_ECC0_ECC62 (0x1FU)      /*!< Bit field value for BCH_FLASH2LAYOUT0_ECC0: ECC 62 to be performed */

/*! @brief Read current value of the BCH_FLASH2LAYOUT0_ECC0 field. */
#define BR_BCH_FLASH2LAYOUT0_ECC0(x) (HW_BCH_FLASH2LAYOUT0(x).B.ECC0)

/*! @brief Format value for bitfield BCH_FLASH2LAYOUT0_ECC0. */
#define BF_BCH_FLASH2LAYOUT0_ECC0(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH2LAYOUT0_ECC0) & BM_BCH_FLASH2LAYOUT0_ECC0)

/*! @brief Set the ECC0 field to a new value. */
#define BW_BCH_FLASH2LAYOUT0_ECC0(x, v) (HW_BCH_FLASH2LAYOUT0_WR(x, (HW_BCH_FLASH2LAYOUT0_RD(x) & ~BM_BCH_FLASH2LAYOUT0_ECC0) | BF_BCH_FLASH2LAYOUT0_ECC0(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH2LAYOUT0, field META_SIZE[23:16] (RW)
 *
 * Indicates the size of the metadata (in bytes) to be stored on a flash page.
 * The BCH design support from 0 to 255 bytes for metadata-if set to 0, no
 * metadata will be stored. Metadata is stored before the associated data in block 0. If
 * the DATA0_SIZE field is programmed to a 0, then metadata effectively be
 * stored with its own parity. When both the metadata and data0 fields are programmed
 * with non-zero values, the first block will contain both portions of data and
 * will be covered by a single parity block.
 */
/*@{*/
#define BP_BCH_FLASH2LAYOUT0_META_SIZE (16U) /*!< Bit position for BCH_FLASH2LAYOUT0_META_SIZE. */
#define BM_BCH_FLASH2LAYOUT0_META_SIZE (0x00FF0000U) /*!< Bit mask for BCH_FLASH2LAYOUT0_META_SIZE. */
#define BS_BCH_FLASH2LAYOUT0_META_SIZE (8U) /*!< Bit field size in bits for BCH_FLASH2LAYOUT0_META_SIZE. */

/*! @brief Read current value of the BCH_FLASH2LAYOUT0_META_SIZE field. */
#define BR_BCH_FLASH2LAYOUT0_META_SIZE(x) (HW_BCH_FLASH2LAYOUT0(x).B.META_SIZE)

/*! @brief Format value for bitfield BCH_FLASH2LAYOUT0_META_SIZE. */
#define BF_BCH_FLASH2LAYOUT0_META_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH2LAYOUT0_META_SIZE) & BM_BCH_FLASH2LAYOUT0_META_SIZE)

/*! @brief Set the META_SIZE field to a new value. */
#define BW_BCH_FLASH2LAYOUT0_META_SIZE(x, v) (HW_BCH_FLASH2LAYOUT0_WR(x, (HW_BCH_FLASH2LAYOUT0_RD(x) & ~BM_BCH_FLASH2LAYOUT0_META_SIZE) | BF_BCH_FLASH2LAYOUT0_META_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH2LAYOUT0, field NBLOCKS[31:24] (RW)
 *
 * Number of subsequent blocks on the flash page (excluding the data0 block). A
 * value of 0 indicates that only the DATA0 block is present and a value of 8
 * indicates that eight subsequent blocks are present for a total of nine blocks on
 * the flash (including the DATA0 block). Any values from 0 to 255 are supported
 * by the hardware.
 */
/*@{*/
#define BP_BCH_FLASH2LAYOUT0_NBLOCKS (24U) /*!< Bit position for BCH_FLASH2LAYOUT0_NBLOCKS. */
#define BM_BCH_FLASH2LAYOUT0_NBLOCKS (0xFF000000U) /*!< Bit mask for BCH_FLASH2LAYOUT0_NBLOCKS. */
#define BS_BCH_FLASH2LAYOUT0_NBLOCKS (8U)  /*!< Bit field size in bits for BCH_FLASH2LAYOUT0_NBLOCKS. */

/*! @brief Read current value of the BCH_FLASH2LAYOUT0_NBLOCKS field. */
#define BR_BCH_FLASH2LAYOUT0_NBLOCKS(x) (HW_BCH_FLASH2LAYOUT0(x).B.NBLOCKS)

/*! @brief Format value for bitfield BCH_FLASH2LAYOUT0_NBLOCKS. */
#define BF_BCH_FLASH2LAYOUT0_NBLOCKS(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH2LAYOUT0_NBLOCKS) & BM_BCH_FLASH2LAYOUT0_NBLOCKS)

/*! @brief Set the NBLOCKS field to a new value. */
#define BW_BCH_FLASH2LAYOUT0_NBLOCKS(x, v) (HW_BCH_FLASH2LAYOUT0_WR(x, (HW_BCH_FLASH2LAYOUT0_RD(x) & ~BM_BCH_FLASH2LAYOUT0_NBLOCKS) | BF_BCH_FLASH2LAYOUT0_NBLOCKS(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_FLASH2LAYOUT1 - Hardware BCH ECC Flash 2 Layout 1 Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_FLASH2LAYOUT1 - Hardware BCH ECC Flash 2 Layout 1 Register (RW)
 *
 * Reset value: 0x10DA4080U
 *
 * The flash format register contains a description of the logical layout of
 * data on the flash device. This register is used in conjunction with the
 * FLASH2LAYOUT0 register to control the format for the device selecting layout 2 in the
 * LAYOUTSELECT register.
 */
typedef union _hw_bch_flash2layout1
{
    uint32_t U;
    struct _hw_bch_flash2layout1_bitfields
    {
        uint32_t DATAN_SIZE : 10;      /*!< [9:0]  */
        uint32_t GF13_0_GF14_1 : 1;    /*!< [10]  */
        uint32_t ECCN : 5;             /*!< [15:11]  */
        uint32_t PAGE_SIZE : 16;       /*!< [31:16]  */
    } B;
} hw_bch_flash2layout1_t;

/*!
 * @name Constants and macros for entire BCH_FLASH2LAYOUT1 register
 */
/*@{*/
#define HW_BCH_FLASH2LAYOUT1_ADDR(x) ((uintptr_t)(x) + 0xD0U)
#define HW_BCH_FLASH2LAYOUT1_SET_ADDR(x) (HW_BCH_FLASH2LAYOUT1_ADDR(x) + 0x4U)
#define HW_BCH_FLASH2LAYOUT1_CLR_ADDR(x) (HW_BCH_FLASH2LAYOUT1_ADDR(x) + 0x8U)
#define HW_BCH_FLASH2LAYOUT1_TOG_ADDR(x) (HW_BCH_FLASH2LAYOUT1_ADDR(x) + 0xCU)

#define HW_BCH_FLASH2LAYOUT1(x)  (*(__IO hw_bch_flash2layout1_t *) HW_BCH_FLASH2LAYOUT1_ADDR(x))
#define HW_BCH_FLASH2LAYOUT1_RD(x) (HW_BCH_FLASH2LAYOUT1(x).U)
#define HW_BCH_FLASH2LAYOUT1_WR(x, v) (HW_BCH_FLASH2LAYOUT1(x).U = (v))
#define HW_BCH_FLASH2LAYOUT1_SET(x, v) ((*(uint32_t *) HW_BCH_FLASH2LAYOUT1_SET_ADDR(x)) = (v))
#define HW_BCH_FLASH2LAYOUT1_CLR(x, v) ((*(uint32_t *) HW_BCH_FLASH2LAYOUT1_CLR_ADDR(x)) = (v))
#define HW_BCH_FLASH2LAYOUT1_TOG(x, v) ((*(uint32_t *) HW_BCH_FLASH2LAYOUT1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_FLASH2LAYOUT1 bitfields
 */

/*!
 * @name Register BCH_FLASH2LAYOUT1, field DATAN_SIZE[9:0] (RW)
 *
 * Indicates the size of the subsequent data blocks (in DWORDS / four bytes) to
 * be stored on the flash page. The size of subsequent data blocks does not have
 * to match the data size for block 0, which is important when metadata is stored
 * separately or for balancing the amount of data stored in each block.
 */
/*@{*/
#define BP_BCH_FLASH2LAYOUT1_DATAN_SIZE (0U) /*!< Bit position for BCH_FLASH2LAYOUT1_DATAN_SIZE. */
#define BM_BCH_FLASH2LAYOUT1_DATAN_SIZE (0x000003FFU) /*!< Bit mask for BCH_FLASH2LAYOUT1_DATAN_SIZE. */
#define BS_BCH_FLASH2LAYOUT1_DATAN_SIZE (10U) /*!< Bit field size in bits for BCH_FLASH2LAYOUT1_DATAN_SIZE. */

/*! @brief Read current value of the BCH_FLASH2LAYOUT1_DATAN_SIZE field. */
#define BR_BCH_FLASH2LAYOUT1_DATAN_SIZE(x) (HW_BCH_FLASH2LAYOUT1(x).B.DATAN_SIZE)

/*! @brief Format value for bitfield BCH_FLASH2LAYOUT1_DATAN_SIZE. */
#define BF_BCH_FLASH2LAYOUT1_DATAN_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH2LAYOUT1_DATAN_SIZE) & BM_BCH_FLASH2LAYOUT1_DATAN_SIZE)

/*! @brief Set the DATAN_SIZE field to a new value. */
#define BW_BCH_FLASH2LAYOUT1_DATAN_SIZE(x, v) (HW_BCH_FLASH2LAYOUT1_WR(x, (HW_BCH_FLASH2LAYOUT1_RD(x) & ~BM_BCH_FLASH2LAYOUT1_DATAN_SIZE) | BF_BCH_FLASH2LAYOUT1_DATAN_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH2LAYOUT1, field GF13_0_GF14_1[10] (RW)
 *
 * Select GF13 or GF14: 0-GF13; 1-GF14
 */
/*@{*/
#define BP_BCH_FLASH2LAYOUT1_GF13_0_GF14_1 (10U) /*!< Bit position for BCH_FLASH2LAYOUT1_GF13_0_GF14_1. */
#define BM_BCH_FLASH2LAYOUT1_GF13_0_GF14_1 (0x00000400U) /*!< Bit mask for BCH_FLASH2LAYOUT1_GF13_0_GF14_1. */
#define BS_BCH_FLASH2LAYOUT1_GF13_0_GF14_1 (1U) /*!< Bit field size in bits for BCH_FLASH2LAYOUT1_GF13_0_GF14_1. */

/*! @brief Read current value of the BCH_FLASH2LAYOUT1_GF13_0_GF14_1 field. */
#define BR_BCH_FLASH2LAYOUT1_GF13_0_GF14_1(x) (HW_BCH_FLASH2LAYOUT1(x).B.GF13_0_GF14_1)

/*! @brief Format value for bitfield BCH_FLASH2LAYOUT1_GF13_0_GF14_1. */
#define BF_BCH_FLASH2LAYOUT1_GF13_0_GF14_1(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH2LAYOUT1_GF13_0_GF14_1) & BM_BCH_FLASH2LAYOUT1_GF13_0_GF14_1)

/*! @brief Set the GF13_0_GF14_1 field to a new value. */
#define BW_BCH_FLASH2LAYOUT1_GF13_0_GF14_1(x, v) (HW_BCH_FLASH2LAYOUT1_WR(x, (HW_BCH_FLASH2LAYOUT1_RD(x) & ~BM_BCH_FLASH2LAYOUT1_GF13_0_GF14_1) | BF_BCH_FLASH2LAYOUT1_GF13_0_GF14_1(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH2LAYOUT1, field ECCN[15:11] (RW)
 *
 * Indicates the ECC level for the subsequent blocks on the flash page (blocks
 * 1-n). Subsequent blocks only contain data (no metadata).
 *
 * Values:
 * - 0 - No ECC to be performed
 * - 1 - ECC 2 to be performed
 * - 10 - ECC 4 to be performed
 * - 11110 - ECC 60 to be performed
 * - 11111 - ECC 62 to be performed
 */
/*@{*/
#define BP_BCH_FLASH2LAYOUT1_ECCN (11U)    /*!< Bit position for BCH_FLASH2LAYOUT1_ECCN. */
#define BM_BCH_FLASH2LAYOUT1_ECCN (0x0000F800U) /*!< Bit mask for BCH_FLASH2LAYOUT1_ECCN. */
#define BS_BCH_FLASH2LAYOUT1_ECCN (5U)     /*!< Bit field size in bits for BCH_FLASH2LAYOUT1_ECCN. */

#define BV_BCH_FLASH2LAYOUT1_ECCN_NONE (0U)          /*!< Bit field value for BCH_FLASH2LAYOUT1_ECCN: No ECC to be performed */
#define BV_BCH_FLASH2LAYOUT1_ECCN_ECC2 (0x1U)        /*!< Bit field value for BCH_FLASH2LAYOUT1_ECCN: ECC 2 to be performed */
#define BV_BCH_FLASH2LAYOUT1_ECCN_ECC4 (0x2U)        /*!< Bit field value for BCH_FLASH2LAYOUT1_ECCN: ECC 4 to be performed */
#define BV_BCH_FLASH2LAYOUT1_ECCN_ECC60 (0x1EU)      /*!< Bit field value for BCH_FLASH2LAYOUT1_ECCN: ECC 60 to be performed */
#define BV_BCH_FLASH2LAYOUT1_ECCN_ECC62 (0x1FU)      /*!< Bit field value for BCH_FLASH2LAYOUT1_ECCN: ECC 62 to be performed */

/*! @brief Read current value of the BCH_FLASH2LAYOUT1_ECCN field. */
#define BR_BCH_FLASH2LAYOUT1_ECCN(x) (HW_BCH_FLASH2LAYOUT1(x).B.ECCN)

/*! @brief Format value for bitfield BCH_FLASH2LAYOUT1_ECCN. */
#define BF_BCH_FLASH2LAYOUT1_ECCN(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH2LAYOUT1_ECCN) & BM_BCH_FLASH2LAYOUT1_ECCN)

/*! @brief Set the ECCN field to a new value. */
#define BW_BCH_FLASH2LAYOUT1_ECCN(x, v) (HW_BCH_FLASH2LAYOUT1_WR(x, (HW_BCH_FLASH2LAYOUT1_RD(x) & ~BM_BCH_FLASH2LAYOUT1_ECCN) | BF_BCH_FLASH2LAYOUT1_ECCN(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH2LAYOUT1, field PAGE_SIZE[31:16] (RW)
 *
 * Indicates the total size of the flash page (in bytes). This should be set to
 * the page size including spare area. The page size is programmable to
 * accomodate different flash configurations that may be available in the future.
 */
/*@{*/
#define BP_BCH_FLASH2LAYOUT1_PAGE_SIZE (16U) /*!< Bit position for BCH_FLASH2LAYOUT1_PAGE_SIZE. */
#define BM_BCH_FLASH2LAYOUT1_PAGE_SIZE (0xFFFF0000U) /*!< Bit mask for BCH_FLASH2LAYOUT1_PAGE_SIZE. */
#define BS_BCH_FLASH2LAYOUT1_PAGE_SIZE (16U) /*!< Bit field size in bits for BCH_FLASH2LAYOUT1_PAGE_SIZE. */

/*! @brief Read current value of the BCH_FLASH2LAYOUT1_PAGE_SIZE field. */
#define BR_BCH_FLASH2LAYOUT1_PAGE_SIZE(x) (HW_BCH_FLASH2LAYOUT1(x).B.PAGE_SIZE)

/*! @brief Format value for bitfield BCH_FLASH2LAYOUT1_PAGE_SIZE. */
#define BF_BCH_FLASH2LAYOUT1_PAGE_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH2LAYOUT1_PAGE_SIZE) & BM_BCH_FLASH2LAYOUT1_PAGE_SIZE)

/*! @brief Set the PAGE_SIZE field to a new value. */
#define BW_BCH_FLASH2LAYOUT1_PAGE_SIZE(x, v) (HW_BCH_FLASH2LAYOUT1_WR(x, (HW_BCH_FLASH2LAYOUT1_RD(x) & ~BM_BCH_FLASH2LAYOUT1_PAGE_SIZE) | BF_BCH_FLASH2LAYOUT1_PAGE_SIZE(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_FLASH3LAYOUT0 - Hardware BCH ECC Flash 3 Layout 0 Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_FLASH3LAYOUT0 - Hardware BCH ECC Flash 3 Layout 0 Register (RW)
 *
 * Reset value: 0x070A4080U
 *
 * The flash format register contains a description of the logical layout of
 * data on the flash device. This register is used in conjunction with the
 * FLASH3LAYOUT1 register to control the format for the devices selecting layout 3 in the
 * LAYOUTSELECT register. Each pair of layout registers describes one of four
 * supported flash configurations. Software should program the LAYOUTSELECT register
 * for each supported GPMI chip select to select from one of the four layout
 * values. Each pair of registers contains settings that are used by the BCH block
 * while reading / writing the flash page to control data, metadata, and flash
 * page sizes as well as the ECC correction level. The first block written to flash
 * can be programmed to have different ECC, metadata, and data sizes from
 * subsequent data blocks on the device. In addition, the number of blocks stored on a
 * page of flash is not fixed, but instead is determined by the number of bytes
 * consumed by the initial (block 0) and subsequent data blocks. See the BCH
 * programming reference manual for more information on setting up the flash layout
 * registers.
 */
typedef union _hw_bch_flash3layout0
{
    uint32_t U;
    struct _hw_bch_flash3layout0_bitfields
    {
        uint32_t DATA0_SIZE : 10;      /*!< [9:0]  */
        uint32_t GF13_0_GF14_1 : 1;    /*!< [10]  */
        uint32_t ECC0 : 5;             /*!< [15:11]  */
        uint32_t META_SIZE : 8;        /*!< [23:16]  */
        uint32_t NBLOCKS : 8;          /*!< [31:24]  */
    } B;
} hw_bch_flash3layout0_t;

/*!
 * @name Constants and macros for entire BCH_FLASH3LAYOUT0 register
 */
/*@{*/
#define HW_BCH_FLASH3LAYOUT0_ADDR(x) ((uintptr_t)(x) + 0xE0U)
#define HW_BCH_FLASH3LAYOUT0_SET_ADDR(x) (HW_BCH_FLASH3LAYOUT0_ADDR(x) + 0x4U)
#define HW_BCH_FLASH3LAYOUT0_CLR_ADDR(x) (HW_BCH_FLASH3LAYOUT0_ADDR(x) + 0x8U)
#define HW_BCH_FLASH3LAYOUT0_TOG_ADDR(x) (HW_BCH_FLASH3LAYOUT0_ADDR(x) + 0xCU)

#define HW_BCH_FLASH3LAYOUT0(x)  (*(__IO hw_bch_flash3layout0_t *) HW_BCH_FLASH3LAYOUT0_ADDR(x))
#define HW_BCH_FLASH3LAYOUT0_RD(x) (HW_BCH_FLASH3LAYOUT0(x).U)
#define HW_BCH_FLASH3LAYOUT0_WR(x, v) (HW_BCH_FLASH3LAYOUT0(x).U = (v))
#define HW_BCH_FLASH3LAYOUT0_SET(x, v) ((*(uint32_t *) HW_BCH_FLASH3LAYOUT0_SET_ADDR(x)) = (v))
#define HW_BCH_FLASH3LAYOUT0_CLR(x, v) ((*(uint32_t *) HW_BCH_FLASH3LAYOUT0_CLR_ADDR(x)) = (v))
#define HW_BCH_FLASH3LAYOUT0_TOG(x, v) ((*(uint32_t *) HW_BCH_FLASH3LAYOUT0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_FLASH3LAYOUT0 bitfields
 */

/*!
 * @name Register BCH_FLASH3LAYOUT0, field DATA0_SIZE[9:0] (RW)
 *
 * Indicates the size of the data 0 block (in DWORDS / four bytes) to be stored
 * on the flash page. If set to 0, the first block will only contain metadata.
 */
/*@{*/
#define BP_BCH_FLASH3LAYOUT0_DATA0_SIZE (0U) /*!< Bit position for BCH_FLASH3LAYOUT0_DATA0_SIZE. */
#define BM_BCH_FLASH3LAYOUT0_DATA0_SIZE (0x000003FFU) /*!< Bit mask for BCH_FLASH3LAYOUT0_DATA0_SIZE. */
#define BS_BCH_FLASH3LAYOUT0_DATA0_SIZE (10U) /*!< Bit field size in bits for BCH_FLASH3LAYOUT0_DATA0_SIZE. */

/*! @brief Read current value of the BCH_FLASH3LAYOUT0_DATA0_SIZE field. */
#define BR_BCH_FLASH3LAYOUT0_DATA0_SIZE(x) (HW_BCH_FLASH3LAYOUT0(x).B.DATA0_SIZE)

/*! @brief Format value for bitfield BCH_FLASH3LAYOUT0_DATA0_SIZE. */
#define BF_BCH_FLASH3LAYOUT0_DATA0_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH3LAYOUT0_DATA0_SIZE) & BM_BCH_FLASH3LAYOUT0_DATA0_SIZE)

/*! @brief Set the DATA0_SIZE field to a new value. */
#define BW_BCH_FLASH3LAYOUT0_DATA0_SIZE(x, v) (HW_BCH_FLASH3LAYOUT0_WR(x, (HW_BCH_FLASH3LAYOUT0_RD(x) & ~BM_BCH_FLASH3LAYOUT0_DATA0_SIZE) | BF_BCH_FLASH3LAYOUT0_DATA0_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH3LAYOUT0, field GF13_0_GF14_1[10] (RW)
 *
 * Select GF13 or GF14: 0-GF13; 1-GF14
 */
/*@{*/
#define BP_BCH_FLASH3LAYOUT0_GF13_0_GF14_1 (10U) /*!< Bit position for BCH_FLASH3LAYOUT0_GF13_0_GF14_1. */
#define BM_BCH_FLASH3LAYOUT0_GF13_0_GF14_1 (0x00000400U) /*!< Bit mask for BCH_FLASH3LAYOUT0_GF13_0_GF14_1. */
#define BS_BCH_FLASH3LAYOUT0_GF13_0_GF14_1 (1U) /*!< Bit field size in bits for BCH_FLASH3LAYOUT0_GF13_0_GF14_1. */

/*! @brief Read current value of the BCH_FLASH3LAYOUT0_GF13_0_GF14_1 field. */
#define BR_BCH_FLASH3LAYOUT0_GF13_0_GF14_1(x) (HW_BCH_FLASH3LAYOUT0(x).B.GF13_0_GF14_1)

/*! @brief Format value for bitfield BCH_FLASH3LAYOUT0_GF13_0_GF14_1. */
#define BF_BCH_FLASH3LAYOUT0_GF13_0_GF14_1(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH3LAYOUT0_GF13_0_GF14_1) & BM_BCH_FLASH3LAYOUT0_GF13_0_GF14_1)

/*! @brief Set the GF13_0_GF14_1 field to a new value. */
#define BW_BCH_FLASH3LAYOUT0_GF13_0_GF14_1(x, v) (HW_BCH_FLASH3LAYOUT0_WR(x, (HW_BCH_FLASH3LAYOUT0_RD(x) & ~BM_BCH_FLASH3LAYOUT0_GF13_0_GF14_1) | BF_BCH_FLASH3LAYOUT0_GF13_0_GF14_1(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH3LAYOUT0, field ECC0[15:11] (RW)
 *
 * Indicates the ECC level for the first block on the flash page. The first
 * block covers metadata plus the associated data from the DATA0_SIZE field.
 *
 * Values:
 * - 0 - No ECC to be performed
 * - 1 - ECC 2 to be performed
 * - 10 - ECC 4 to be performed
 * - 11110 - ECC 60 to be performed
 * - 11111 - ECC 62 to be performed
 */
/*@{*/
#define BP_BCH_FLASH3LAYOUT0_ECC0 (11U)    /*!< Bit position for BCH_FLASH3LAYOUT0_ECC0. */
#define BM_BCH_FLASH3LAYOUT0_ECC0 (0x0000F800U) /*!< Bit mask for BCH_FLASH3LAYOUT0_ECC0. */
#define BS_BCH_FLASH3LAYOUT0_ECC0 (5U)     /*!< Bit field size in bits for BCH_FLASH3LAYOUT0_ECC0. */

#define BV_BCH_FLASH3LAYOUT0_ECC0_NONE (0U)          /*!< Bit field value for BCH_FLASH3LAYOUT0_ECC0: No ECC to be performed */
#define BV_BCH_FLASH3LAYOUT0_ECC0_ECC2 (0x1U)        /*!< Bit field value for BCH_FLASH3LAYOUT0_ECC0: ECC 2 to be performed */
#define BV_BCH_FLASH3LAYOUT0_ECC0_ECC4 (0x2U)        /*!< Bit field value for BCH_FLASH3LAYOUT0_ECC0: ECC 4 to be performed */
#define BV_BCH_FLASH3LAYOUT0_ECC0_ECC60 (0x1EU)      /*!< Bit field value for BCH_FLASH3LAYOUT0_ECC0: ECC 60 to be performed */
#define BV_BCH_FLASH3LAYOUT0_ECC0_ECC62 (0x1FU)      /*!< Bit field value for BCH_FLASH3LAYOUT0_ECC0: ECC 62 to be performed */

/*! @brief Read current value of the BCH_FLASH3LAYOUT0_ECC0 field. */
#define BR_BCH_FLASH3LAYOUT0_ECC0(x) (HW_BCH_FLASH3LAYOUT0(x).B.ECC0)

/*! @brief Format value for bitfield BCH_FLASH3LAYOUT0_ECC0. */
#define BF_BCH_FLASH3LAYOUT0_ECC0(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH3LAYOUT0_ECC0) & BM_BCH_FLASH3LAYOUT0_ECC0)

/*! @brief Set the ECC0 field to a new value. */
#define BW_BCH_FLASH3LAYOUT0_ECC0(x, v) (HW_BCH_FLASH3LAYOUT0_WR(x, (HW_BCH_FLASH3LAYOUT0_RD(x) & ~BM_BCH_FLASH3LAYOUT0_ECC0) | BF_BCH_FLASH3LAYOUT0_ECC0(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH3LAYOUT0, field META_SIZE[23:16] (RW)
 *
 * Indicates the size of the metadata (in bytes) to be stored on a flash page.
 * The BCH design support from 0 to 255 bytes for metadata-if set to 0, no
 * metadata will be stored. Metadata is stored before the associated data in block 0. If
 * the DATA0_SIZE field is programmed to a 0, then metadata effectively be
 * stored with its own parity. When both the metadata and data0 fields are programmed
 * with non-zero values, the first block will contain both portions of data and
 * will be covered by a single parity block.
 */
/*@{*/
#define BP_BCH_FLASH3LAYOUT0_META_SIZE (16U) /*!< Bit position for BCH_FLASH3LAYOUT0_META_SIZE. */
#define BM_BCH_FLASH3LAYOUT0_META_SIZE (0x00FF0000U) /*!< Bit mask for BCH_FLASH3LAYOUT0_META_SIZE. */
#define BS_BCH_FLASH3LAYOUT0_META_SIZE (8U) /*!< Bit field size in bits for BCH_FLASH3LAYOUT0_META_SIZE. */

/*! @brief Read current value of the BCH_FLASH3LAYOUT0_META_SIZE field. */
#define BR_BCH_FLASH3LAYOUT0_META_SIZE(x) (HW_BCH_FLASH3LAYOUT0(x).B.META_SIZE)

/*! @brief Format value for bitfield BCH_FLASH3LAYOUT0_META_SIZE. */
#define BF_BCH_FLASH3LAYOUT0_META_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH3LAYOUT0_META_SIZE) & BM_BCH_FLASH3LAYOUT0_META_SIZE)

/*! @brief Set the META_SIZE field to a new value. */
#define BW_BCH_FLASH3LAYOUT0_META_SIZE(x, v) (HW_BCH_FLASH3LAYOUT0_WR(x, (HW_BCH_FLASH3LAYOUT0_RD(x) & ~BM_BCH_FLASH3LAYOUT0_META_SIZE) | BF_BCH_FLASH3LAYOUT0_META_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH3LAYOUT0, field NBLOCKS[31:24] (RW)
 *
 * Number of subsequent blocks on the flash page (excluding the data0 block). A
 * value of 0 indicates that only the DATA0 block is present and a value of 8
 * indicates that 8 subsequent blocks are present for a total of 9 blocks on the
 * flash (including the DATA0 block). Any values from 0 to 255 are supported by the
 * hardware.
 */
/*@{*/
#define BP_BCH_FLASH3LAYOUT0_NBLOCKS (24U) /*!< Bit position for BCH_FLASH3LAYOUT0_NBLOCKS. */
#define BM_BCH_FLASH3LAYOUT0_NBLOCKS (0xFF000000U) /*!< Bit mask for BCH_FLASH3LAYOUT0_NBLOCKS. */
#define BS_BCH_FLASH3LAYOUT0_NBLOCKS (8U)  /*!< Bit field size in bits for BCH_FLASH3LAYOUT0_NBLOCKS. */

/*! @brief Read current value of the BCH_FLASH3LAYOUT0_NBLOCKS field. */
#define BR_BCH_FLASH3LAYOUT0_NBLOCKS(x) (HW_BCH_FLASH3LAYOUT0(x).B.NBLOCKS)

/*! @brief Format value for bitfield BCH_FLASH3LAYOUT0_NBLOCKS. */
#define BF_BCH_FLASH3LAYOUT0_NBLOCKS(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH3LAYOUT0_NBLOCKS) & BM_BCH_FLASH3LAYOUT0_NBLOCKS)

/*! @brief Set the NBLOCKS field to a new value. */
#define BW_BCH_FLASH3LAYOUT0_NBLOCKS(x, v) (HW_BCH_FLASH3LAYOUT0_WR(x, (HW_BCH_FLASH3LAYOUT0_RD(x) & ~BM_BCH_FLASH3LAYOUT0_NBLOCKS) | BF_BCH_FLASH3LAYOUT0_NBLOCKS(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_FLASH3LAYOUT1 - Hardware BCH ECC Flash 3 Layout 1 Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_FLASH3LAYOUT1 - Hardware BCH ECC Flash 3 Layout 1 Register (RW)
 *
 * Reset value: 0x10DA4080U
 *
 * The flash format register contains a description of the logical layout of
 * data on the flash device. This register is used in conjunction with the
 * FLASH3LAYOUT0 register to control the format for the device selecting layout 3 in the
 * LAYOUTSELECT register.
 */
typedef union _hw_bch_flash3layout1
{
    uint32_t U;
    struct _hw_bch_flash3layout1_bitfields
    {
        uint32_t DATAN_SIZE : 10;      /*!< [9:0]  */
        uint32_t GF13_0_GF14_1 : 1;    /*!< [10]  */
        uint32_t ECCN : 5;             /*!< [15:11]  */
        uint32_t PAGE_SIZE : 16;       /*!< [31:16]  */
    } B;
} hw_bch_flash3layout1_t;

/*!
 * @name Constants and macros for entire BCH_FLASH3LAYOUT1 register
 */
/*@{*/
#define HW_BCH_FLASH3LAYOUT1_ADDR(x) ((uintptr_t)(x) + 0xF0U)
#define HW_BCH_FLASH3LAYOUT1_SET_ADDR(x) (HW_BCH_FLASH3LAYOUT1_ADDR(x) + 0x4U)
#define HW_BCH_FLASH3LAYOUT1_CLR_ADDR(x) (HW_BCH_FLASH3LAYOUT1_ADDR(x) + 0x8U)
#define HW_BCH_FLASH3LAYOUT1_TOG_ADDR(x) (HW_BCH_FLASH3LAYOUT1_ADDR(x) + 0xCU)

#define HW_BCH_FLASH3LAYOUT1(x)  (*(__IO hw_bch_flash3layout1_t *) HW_BCH_FLASH3LAYOUT1_ADDR(x))
#define HW_BCH_FLASH3LAYOUT1_RD(x) (HW_BCH_FLASH3LAYOUT1(x).U)
#define HW_BCH_FLASH3LAYOUT1_WR(x, v) (HW_BCH_FLASH3LAYOUT1(x).U = (v))
#define HW_BCH_FLASH3LAYOUT1_SET(x, v) ((*(uint32_t *) HW_BCH_FLASH3LAYOUT1_SET_ADDR(x)) = (v))
#define HW_BCH_FLASH3LAYOUT1_CLR(x, v) ((*(uint32_t *) HW_BCH_FLASH3LAYOUT1_CLR_ADDR(x)) = (v))
#define HW_BCH_FLASH3LAYOUT1_TOG(x, v) ((*(uint32_t *) HW_BCH_FLASH3LAYOUT1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_FLASH3LAYOUT1 bitfields
 */

/*!
 * @name Register BCH_FLASH3LAYOUT1, field DATAN_SIZE[9:0] (RW)
 *
 * Indicates the size of the subsequent data blocks (in DWORDS / four bytes) to
 * be stored on the flash page. The size of subsequent data blocks does not have
 * to match the data size for block 0, which is important when metadata is stored
 * separately or for balancing the amount of data stored in each block.
 */
/*@{*/
#define BP_BCH_FLASH3LAYOUT1_DATAN_SIZE (0U) /*!< Bit position for BCH_FLASH3LAYOUT1_DATAN_SIZE. */
#define BM_BCH_FLASH3LAYOUT1_DATAN_SIZE (0x000003FFU) /*!< Bit mask for BCH_FLASH3LAYOUT1_DATAN_SIZE. */
#define BS_BCH_FLASH3LAYOUT1_DATAN_SIZE (10U) /*!< Bit field size in bits for BCH_FLASH3LAYOUT1_DATAN_SIZE. */

/*! @brief Read current value of the BCH_FLASH3LAYOUT1_DATAN_SIZE field. */
#define BR_BCH_FLASH3LAYOUT1_DATAN_SIZE(x) (HW_BCH_FLASH3LAYOUT1(x).B.DATAN_SIZE)

/*! @brief Format value for bitfield BCH_FLASH3LAYOUT1_DATAN_SIZE. */
#define BF_BCH_FLASH3LAYOUT1_DATAN_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH3LAYOUT1_DATAN_SIZE) & BM_BCH_FLASH3LAYOUT1_DATAN_SIZE)

/*! @brief Set the DATAN_SIZE field to a new value. */
#define BW_BCH_FLASH3LAYOUT1_DATAN_SIZE(x, v) (HW_BCH_FLASH3LAYOUT1_WR(x, (HW_BCH_FLASH3LAYOUT1_RD(x) & ~BM_BCH_FLASH3LAYOUT1_DATAN_SIZE) | BF_BCH_FLASH3LAYOUT1_DATAN_SIZE(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH3LAYOUT1, field GF13_0_GF14_1[10] (RW)
 *
 * Select GF13 or GF14: 0-GF13; 1-GF14
 */
/*@{*/
#define BP_BCH_FLASH3LAYOUT1_GF13_0_GF14_1 (10U) /*!< Bit position for BCH_FLASH3LAYOUT1_GF13_0_GF14_1. */
#define BM_BCH_FLASH3LAYOUT1_GF13_0_GF14_1 (0x00000400U) /*!< Bit mask for BCH_FLASH3LAYOUT1_GF13_0_GF14_1. */
#define BS_BCH_FLASH3LAYOUT1_GF13_0_GF14_1 (1U) /*!< Bit field size in bits for BCH_FLASH3LAYOUT1_GF13_0_GF14_1. */

/*! @brief Read current value of the BCH_FLASH3LAYOUT1_GF13_0_GF14_1 field. */
#define BR_BCH_FLASH3LAYOUT1_GF13_0_GF14_1(x) (HW_BCH_FLASH3LAYOUT1(x).B.GF13_0_GF14_1)

/*! @brief Format value for bitfield BCH_FLASH3LAYOUT1_GF13_0_GF14_1. */
#define BF_BCH_FLASH3LAYOUT1_GF13_0_GF14_1(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH3LAYOUT1_GF13_0_GF14_1) & BM_BCH_FLASH3LAYOUT1_GF13_0_GF14_1)

/*! @brief Set the GF13_0_GF14_1 field to a new value. */
#define BW_BCH_FLASH3LAYOUT1_GF13_0_GF14_1(x, v) (HW_BCH_FLASH3LAYOUT1_WR(x, (HW_BCH_FLASH3LAYOUT1_RD(x) & ~BM_BCH_FLASH3LAYOUT1_GF13_0_GF14_1) | BF_BCH_FLASH3LAYOUT1_GF13_0_GF14_1(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH3LAYOUT1, field ECCN[15:11] (RW)
 *
 * Indicates the ECC level for the subsequent blocks on the flash page (blocks
 * 1-n). Subsequent blocks only contain data (no metadata).
 *
 * Values:
 * - 0 - No ECC to be performed
 * - 1 - ECC 2 to be performed
 * - 10 - ECC 4 to be performed
 * - 11110 - ECC 60 to be performed
 * - 11111 - ECC 62 to be performed
 */
/*@{*/
#define BP_BCH_FLASH3LAYOUT1_ECCN (11U)    /*!< Bit position for BCH_FLASH3LAYOUT1_ECCN. */
#define BM_BCH_FLASH3LAYOUT1_ECCN (0x0000F800U) /*!< Bit mask for BCH_FLASH3LAYOUT1_ECCN. */
#define BS_BCH_FLASH3LAYOUT1_ECCN (5U)     /*!< Bit field size in bits for BCH_FLASH3LAYOUT1_ECCN. */

#define BV_BCH_FLASH3LAYOUT1_ECCN_NONE (0U)          /*!< Bit field value for BCH_FLASH3LAYOUT1_ECCN: No ECC to be performed */
#define BV_BCH_FLASH3LAYOUT1_ECCN_ECC2 (0x1U)        /*!< Bit field value for BCH_FLASH3LAYOUT1_ECCN: ECC 2 to be performed */
#define BV_BCH_FLASH3LAYOUT1_ECCN_ECC4 (0x2U)        /*!< Bit field value for BCH_FLASH3LAYOUT1_ECCN: ECC 4 to be performed */
#define BV_BCH_FLASH3LAYOUT1_ECCN_ECC60 (0x1EU)      /*!< Bit field value for BCH_FLASH3LAYOUT1_ECCN: ECC 60 to be performed */
#define BV_BCH_FLASH3LAYOUT1_ECCN_ECC62 (0x1FU)      /*!< Bit field value for BCH_FLASH3LAYOUT1_ECCN: ECC 62 to be performed */

/*! @brief Read current value of the BCH_FLASH3LAYOUT1_ECCN field. */
#define BR_BCH_FLASH3LAYOUT1_ECCN(x) (HW_BCH_FLASH3LAYOUT1(x).B.ECCN)

/*! @brief Format value for bitfield BCH_FLASH3LAYOUT1_ECCN. */
#define BF_BCH_FLASH3LAYOUT1_ECCN(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH3LAYOUT1_ECCN) & BM_BCH_FLASH3LAYOUT1_ECCN)

/*! @brief Set the ECCN field to a new value. */
#define BW_BCH_FLASH3LAYOUT1_ECCN(x, v) (HW_BCH_FLASH3LAYOUT1_WR(x, (HW_BCH_FLASH3LAYOUT1_RD(x) & ~BM_BCH_FLASH3LAYOUT1_ECCN) | BF_BCH_FLASH3LAYOUT1_ECCN(v)))
/*@}*/

/*!
 * @name Register BCH_FLASH3LAYOUT1, field PAGE_SIZE[31:16] (RW)
 *
 * Indicates the total size of the flash page (in bytes). This should be set to
 * the page size including spare area. The page size is programmable to
 * accomodate different flash configurations that may be available in the future.
 */
/*@{*/
#define BP_BCH_FLASH3LAYOUT1_PAGE_SIZE (16U) /*!< Bit position for BCH_FLASH3LAYOUT1_PAGE_SIZE. */
#define BM_BCH_FLASH3LAYOUT1_PAGE_SIZE (0xFFFF0000U) /*!< Bit mask for BCH_FLASH3LAYOUT1_PAGE_SIZE. */
#define BS_BCH_FLASH3LAYOUT1_PAGE_SIZE (16U) /*!< Bit field size in bits for BCH_FLASH3LAYOUT1_PAGE_SIZE. */

/*! @brief Read current value of the BCH_FLASH3LAYOUT1_PAGE_SIZE field. */
#define BR_BCH_FLASH3LAYOUT1_PAGE_SIZE(x) (HW_BCH_FLASH3LAYOUT1(x).B.PAGE_SIZE)

/*! @brief Format value for bitfield BCH_FLASH3LAYOUT1_PAGE_SIZE. */
#define BF_BCH_FLASH3LAYOUT1_PAGE_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_FLASH3LAYOUT1_PAGE_SIZE) & BM_BCH_FLASH3LAYOUT1_PAGE_SIZE)

/*! @brief Set the PAGE_SIZE field to a new value. */
#define BW_BCH_FLASH3LAYOUT1_PAGE_SIZE(x, v) (HW_BCH_FLASH3LAYOUT1_WR(x, (HW_BCH_FLASH3LAYOUT1_RD(x) & ~BM_BCH_FLASH3LAYOUT1_PAGE_SIZE) | BF_BCH_FLASH3LAYOUT1_PAGE_SIZE(v)))
/*@}*/




/*******************************************************************************
 * HW_BCH_DEBUG0 - Hardware BCH ECC Debug Register0
 ******************************************************************************/

/*!
 * @brief HW_BCH_DEBUG0 - Hardware BCH ECC Debug Register0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The hardware BCH accelerator internal state machines and signals can be seen
 * in the ECC debug register. The BCH_DEBUG0 register provides access to various
 * internal state information which might prove useful during hardware debug and
 * validation.
 */
typedef union _hw_bch_debug0
{
    uint32_t U;
    struct _hw_bch_debug0_bitfields
    {
        uint32_t DEBUG_REG_SELECT : 6; /*!< [5:0]  */
        uint32_t RSVD0 : 2;            /*!< [7:6] This field is reserved. */
        uint32_t BM_KES_TEST_BYPASS : 1; /*!< [8]  */
        uint32_t KES_DEBUG_STALL : 1;  /*!< [9]  */
        uint32_t KES_DEBUG_STEP : 1;   /*!< [10]  */
        uint32_t KES_STANDALONE : 1;   /*!< [11]  */
        uint32_t KES_DEBUG_KICK : 1;   /*!< [12]  */
        uint32_t KES_DEBUG_MODE4K : 1; /*!< [13]  */
        uint32_t KES_DEBUG_PAYLOAD_FLAG : 1; /*!< [14]  */
        uint32_t KES_DEBUG_SHIFT_SYND : 1; /*!< [15]  */
        uint32_t KES_DEBUG_SYNDROME_SYMBOL : 9; /*!< [24:16]  */
        uint32_t RSVD1 : 7;            /*!< [31:25] This field is reserved. */
    } B;
} hw_bch_debug0_t;

/*!
 * @name Constants and macros for entire BCH_DEBUG0 register
 */
/*@{*/
#define HW_BCH_DEBUG0_ADDR(x)    ((uintptr_t)(x) + 0x100U)
#define HW_BCH_DEBUG0_SET_ADDR(x) (HW_BCH_DEBUG0_ADDR(x) + 0x4U)
#define HW_BCH_DEBUG0_CLR_ADDR(x) (HW_BCH_DEBUG0_ADDR(x) + 0x8U)
#define HW_BCH_DEBUG0_TOG_ADDR(x) (HW_BCH_DEBUG0_ADDR(x) + 0xCU)

#define HW_BCH_DEBUG0(x)         (*(__IO hw_bch_debug0_t *) HW_BCH_DEBUG0_ADDR(x))
#define HW_BCH_DEBUG0_RD(x)      (HW_BCH_DEBUG0(x).U)
#define HW_BCH_DEBUG0_WR(x, v)   (HW_BCH_DEBUG0(x).U = (v))
#define HW_BCH_DEBUG0_SET(x, v)  ((*(uint32_t *) HW_BCH_DEBUG0_SET_ADDR(x)) = (v))
#define HW_BCH_DEBUG0_CLR(x, v)  ((*(uint32_t *) HW_BCH_DEBUG0_CLR_ADDR(x)) = (v))
#define HW_BCH_DEBUG0_TOG(x, v)  ((*(uint32_t *) HW_BCH_DEBUG0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_DEBUG0 bitfields
 */

/*!
 * @name Register BCH_DEBUG0, field DEBUG_REG_SELECT[5:0] (RW)
 *
 * The value loaded in this bit field is used to select the internal register
 * state view of KES engine or the Chien search engine.
 */
/*@{*/
#define BP_BCH_DEBUG0_DEBUG_REG_SELECT (0U) /*!< Bit position for BCH_DEBUG0_DEBUG_REG_SELECT. */
#define BM_BCH_DEBUG0_DEBUG_REG_SELECT (0x0000003FU) /*!< Bit mask for BCH_DEBUG0_DEBUG_REG_SELECT. */
#define BS_BCH_DEBUG0_DEBUG_REG_SELECT (6U) /*!< Bit field size in bits for BCH_DEBUG0_DEBUG_REG_SELECT. */

/*! @brief Read current value of the BCH_DEBUG0_DEBUG_REG_SELECT field. */
#define BR_BCH_DEBUG0_DEBUG_REG_SELECT(x) (HW_BCH_DEBUG0(x).B.DEBUG_REG_SELECT)

/*! @brief Format value for bitfield BCH_DEBUG0_DEBUG_REG_SELECT. */
#define BF_BCH_DEBUG0_DEBUG_REG_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_DEBUG_REG_SELECT) & BM_BCH_DEBUG0_DEBUG_REG_SELECT)

/*! @brief Set the DEBUG_REG_SELECT field to a new value. */
#define BW_BCH_DEBUG0_DEBUG_REG_SELECT(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_DEBUG_REG_SELECT) | BF_BCH_DEBUG0_DEBUG_REG_SELECT(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field RSVD0[7:6] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_DEBUG0_RSVD0  (6U)          /*!< Bit position for BCH_DEBUG0_RSVD0. */
#define BM_BCH_DEBUG0_RSVD0  (0x000000C0U) /*!< Bit mask for BCH_DEBUG0_RSVD0. */
#define BS_BCH_DEBUG0_RSVD0  (2U)          /*!< Bit field size in bits for BCH_DEBUG0_RSVD0. */

/*! @brief Read current value of the BCH_DEBUG0_RSVD0 field. */
#define BR_BCH_DEBUG0_RSVD0(x) (HW_BCH_DEBUG0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field BM_KES_TEST_BYPASS[8] (RW)
 *
 * 1 = Point all SYND_GEN writes to dummy area at the end of the AUXILLIARY
 * block so that diagnostics can preload all payload, parity bytes and computed
 * syndrome bytes for test the KES engine.
 *
 * Values:
 * - 0 - Bus master address generator for SYND_GEN writes operates normally.
 * - 1 - Bus master address generator always addresses last four bytes in
 *     Auxiliary block.
 */
/*@{*/
#define BP_BCH_DEBUG0_BM_KES_TEST_BYPASS (8U) /*!< Bit position for BCH_DEBUG0_BM_KES_TEST_BYPASS. */
#define BM_BCH_DEBUG0_BM_KES_TEST_BYPASS (0x00000100U) /*!< Bit mask for BCH_DEBUG0_BM_KES_TEST_BYPASS. */
#define BS_BCH_DEBUG0_BM_KES_TEST_BYPASS (1U) /*!< Bit field size in bits for BCH_DEBUG0_BM_KES_TEST_BYPASS. */

#define BV_BCH_DEBUG0_BM_KES_TEST_BYPASS_NORMAL (0U) /*!< Bit field value for BCH_DEBUG0_BM_KES_TEST_BYPASS: Bus master address generator for SYND_GEN writes operates normally. */
#define BV_BCH_DEBUG0_BM_KES_TEST_BYPASS_TEST_MODE (0x1U) /*!< Bit field value for BCH_DEBUG0_BM_KES_TEST_BYPASS: Bus master address generator always addresses last four bytes in Auxiliary block. */

/*! @brief Read current value of the BCH_DEBUG0_BM_KES_TEST_BYPASS field. */
#define BR_BCH_DEBUG0_BM_KES_TEST_BYPASS(x) (HW_BCH_DEBUG0(x).B.BM_KES_TEST_BYPASS)

/*! @brief Format value for bitfield BCH_DEBUG0_BM_KES_TEST_BYPASS. */
#define BF_BCH_DEBUG0_BM_KES_TEST_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_BM_KES_TEST_BYPASS) & BM_BCH_DEBUG0_BM_KES_TEST_BYPASS)

/*! @brief Set the BM_KES_TEST_BYPASS field to a new value. */
#define BW_BCH_DEBUG0_BM_KES_TEST_BYPASS(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_BM_KES_TEST_BYPASS) | BF_BCH_DEBUG0_BM_KES_TEST_BYPASS(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field KES_DEBUG_STALL[9] (RW)
 *
 * Set to one to cause KES FSM to stall after notifying Chien search engine to
 * start processing its block but before notifying the bus master that the KES
 * computation is complete. This allows a diagnostic to stall the FSM after each
 * blocks key equations are solved. This also has the effect of stalling the CSFE
 * search engine so it's state can be examined after it finishes processing the KES
 * stalled block.
 *
 * Values:
 * - 0 - KES FSM proceeds to next block supplied by bus master.
 * - 1 - KES FSM waits after current equations are solved and the search engine
 *     is started.
 */
/*@{*/
#define BP_BCH_DEBUG0_KES_DEBUG_STALL (9U) /*!< Bit position for BCH_DEBUG0_KES_DEBUG_STALL. */
#define BM_BCH_DEBUG0_KES_DEBUG_STALL (0x00000200U) /*!< Bit mask for BCH_DEBUG0_KES_DEBUG_STALL. */
#define BS_BCH_DEBUG0_KES_DEBUG_STALL (1U) /*!< Bit field size in bits for BCH_DEBUG0_KES_DEBUG_STALL. */

#define BV_BCH_DEBUG0_KES_DEBUG_STALL_NORMAL (0U)    /*!< Bit field value for BCH_DEBUG0_KES_DEBUG_STALL: KES FSM proceeds to next block supplied by bus master. */
#define BV_BCH_DEBUG0_KES_DEBUG_STALL_WAIT (0x1U)    /*!< Bit field value for BCH_DEBUG0_KES_DEBUG_STALL: KES FSM waits after current equations are solved and the search engine is started. */

/*! @brief Read current value of the BCH_DEBUG0_KES_DEBUG_STALL field. */
#define BR_BCH_DEBUG0_KES_DEBUG_STALL(x) (HW_BCH_DEBUG0(x).B.KES_DEBUG_STALL)

/*! @brief Format value for bitfield BCH_DEBUG0_KES_DEBUG_STALL. */
#define BF_BCH_DEBUG0_KES_DEBUG_STALL(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_KES_DEBUG_STALL) & BM_BCH_DEBUG0_KES_DEBUG_STALL)

/*! @brief Set the KES_DEBUG_STALL field to a new value. */
#define BW_BCH_DEBUG0_KES_DEBUG_STALL(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_KES_DEBUG_STALL) | BF_BCH_DEBUG0_KES_DEBUG_STALL(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field KES_DEBUG_STEP[10] (RW)
 *
 * Toggling this bit causes the KES FSM to skip passed the stall state if it is
 * in DEBUG_STALL mode and completed processing a block.
 */
/*@{*/
#define BP_BCH_DEBUG0_KES_DEBUG_STEP (10U) /*!< Bit position for BCH_DEBUG0_KES_DEBUG_STEP. */
#define BM_BCH_DEBUG0_KES_DEBUG_STEP (0x00000400U) /*!< Bit mask for BCH_DEBUG0_KES_DEBUG_STEP. */
#define BS_BCH_DEBUG0_KES_DEBUG_STEP (1U)  /*!< Bit field size in bits for BCH_DEBUG0_KES_DEBUG_STEP. */

/*! @brief Read current value of the BCH_DEBUG0_KES_DEBUG_STEP field. */
#define BR_BCH_DEBUG0_KES_DEBUG_STEP(x) (HW_BCH_DEBUG0(x).B.KES_DEBUG_STEP)

/*! @brief Format value for bitfield BCH_DEBUG0_KES_DEBUG_STEP. */
#define BF_BCH_DEBUG0_KES_DEBUG_STEP(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_KES_DEBUG_STEP) & BM_BCH_DEBUG0_KES_DEBUG_STEP)

/*! @brief Set the KES_DEBUG_STEP field to a new value. */
#define BW_BCH_DEBUG0_KES_DEBUG_STEP(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_KES_DEBUG_STEP) | BF_BCH_DEBUG0_KES_DEBUG_STEP(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field KES_STANDALONE[11] (RW)
 *
 * Set to one, cause the KES engine to suppress toggling the KES_BM_DONE signal
 * to the bus master and suppress toggling the CF_BM_DONE signal by the CF engine.
 *
 * Values:
 * - 0 - Bus master address generator for SYND_GEN writes operates normally.
 * - 1 - Bus master address generator always addresses last four bytes in
 *     Auxiliary block.
 */
/*@{*/
#define BP_BCH_DEBUG0_KES_STANDALONE (11U) /*!< Bit position for BCH_DEBUG0_KES_STANDALONE. */
#define BM_BCH_DEBUG0_KES_STANDALONE (0x00000800U) /*!< Bit mask for BCH_DEBUG0_KES_STANDALONE. */
#define BS_BCH_DEBUG0_KES_STANDALONE (1U)  /*!< Bit field size in bits for BCH_DEBUG0_KES_STANDALONE. */

#define BV_BCH_DEBUG0_KES_STANDALONE_NORMAL (0U)     /*!< Bit field value for BCH_DEBUG0_KES_STANDALONE: Bus master address generator for SYND_GEN writes operates normally. */
#define BV_BCH_DEBUG0_KES_STANDALONE_TEST_MODE (0x1U) /*!< Bit field value for BCH_DEBUG0_KES_STANDALONE: Bus master address generator always addresses last four bytes in Auxiliary block. */

/*! @brief Read current value of the BCH_DEBUG0_KES_STANDALONE field. */
#define BR_BCH_DEBUG0_KES_STANDALONE(x) (HW_BCH_DEBUG0(x).B.KES_STANDALONE)

/*! @brief Format value for bitfield BCH_DEBUG0_KES_STANDALONE. */
#define BF_BCH_DEBUG0_KES_STANDALONE(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_KES_STANDALONE) & BM_BCH_DEBUG0_KES_STANDALONE)

/*! @brief Set the KES_STANDALONE field to a new value. */
#define BW_BCH_DEBUG0_KES_STANDALONE(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_KES_STANDALONE) | BF_BCH_DEBUG0_KES_STANDALONE(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field KES_DEBUG_KICK[12] (RW)
 *
 * Toggling causes KES engine FSM to start as if kick by the Bus Master. This
 * allows stand alone testing of the KES and Chien Search engines. Be sure to set
 * KES_BCH_DEBUG0_KES_STANDALONE mode to 1 before kicking.
 */
/*@{*/
#define BP_BCH_DEBUG0_KES_DEBUG_KICK (12U) /*!< Bit position for BCH_DEBUG0_KES_DEBUG_KICK. */
#define BM_BCH_DEBUG0_KES_DEBUG_KICK (0x00001000U) /*!< Bit mask for BCH_DEBUG0_KES_DEBUG_KICK. */
#define BS_BCH_DEBUG0_KES_DEBUG_KICK (1U)  /*!< Bit field size in bits for BCH_DEBUG0_KES_DEBUG_KICK. */

/*! @brief Read current value of the BCH_DEBUG0_KES_DEBUG_KICK field. */
#define BR_BCH_DEBUG0_KES_DEBUG_KICK(x) (HW_BCH_DEBUG0(x).B.KES_DEBUG_KICK)

/*! @brief Format value for bitfield BCH_DEBUG0_KES_DEBUG_KICK. */
#define BF_BCH_DEBUG0_KES_DEBUG_KICK(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_KES_DEBUG_KICK) & BM_BCH_DEBUG0_KES_DEBUG_KICK)

/*! @brief Set the KES_DEBUG_KICK field to a new value. */
#define BW_BCH_DEBUG0_KES_DEBUG_KICK(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_KES_DEBUG_KICK) | BF_BCH_DEBUG0_KES_DEBUG_KICK(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field KES_DEBUG_MODE4K[13] (RW)
 *
 * When running the stand alone debug mode on the error calculator, the state of
 * this bit is presented to the KES engine as the input mode (4K or 2K pages).
 *
 * Values:
 * - 1 - Mode is set for 4K NAND pages.
 * - 1 - Mode is set for 2K NAND pages.
 */
/*@{*/
#define BP_BCH_DEBUG0_KES_DEBUG_MODE4K (13U) /*!< Bit position for BCH_DEBUG0_KES_DEBUG_MODE4K. */
#define BM_BCH_DEBUG0_KES_DEBUG_MODE4K (0x00002000U) /*!< Bit mask for BCH_DEBUG0_KES_DEBUG_MODE4K. */
#define BS_BCH_DEBUG0_KES_DEBUG_MODE4K (1U) /*!< Bit field size in bits for BCH_DEBUG0_KES_DEBUG_MODE4K. */

#define BV_BCH_DEBUG0_KES_DEBUG_MODE4K_4k (0x1U)     /*!< Bit field value for BCH_DEBUG0_KES_DEBUG_MODE4K: Mode is set for 4K NAND pages. */
#define BV_BCH_DEBUG0_KES_DEBUG_MODE4K_2k (0x1U)     /*!< Bit field value for BCH_DEBUG0_KES_DEBUG_MODE4K: Mode is set for 2K NAND pages. */

/*! @brief Read current value of the BCH_DEBUG0_KES_DEBUG_MODE4K field. */
#define BR_BCH_DEBUG0_KES_DEBUG_MODE4K(x) (HW_BCH_DEBUG0(x).B.KES_DEBUG_MODE4K)

/*! @brief Format value for bitfield BCH_DEBUG0_KES_DEBUG_MODE4K. */
#define BF_BCH_DEBUG0_KES_DEBUG_MODE4K(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_KES_DEBUG_MODE4K) & BM_BCH_DEBUG0_KES_DEBUG_MODE4K)

/*! @brief Set the KES_DEBUG_MODE4K field to a new value. */
#define BW_BCH_DEBUG0_KES_DEBUG_MODE4K(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_KES_DEBUG_MODE4K) | BF_BCH_DEBUG0_KES_DEBUG_MODE4K(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field KES_DEBUG_PAYLOAD_FLAG[14] (RW)
 *
 * When running the stand alone debug mode on the error calculator, the state of
 * this bit is presented to the KES engine as the input payload flag.
 *
 * Values:
 * - 1 - Payload is set for 512 bytes data block.
 * - 1 - Payload is set for 65 or 19 bytes auxiliary block.
 */
/*@{*/
#define BP_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG (14U) /*!< Bit position for BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG. */
#define BM_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG (0x00004000U) /*!< Bit mask for BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG. */
#define BS_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG (1U) /*!< Bit field size in bits for BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG. */

#define BV_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG_DATA (0x1U) /*!< Bit field value for BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG: Payload is set for 512 bytes data block. */
#define BV_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG_AUX (0x1U) /*!< Bit field value for BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG: Payload is set for 65 or 19 bytes auxiliary block. */

/*! @brief Read current value of the BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG field. */
#define BR_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG(x) (HW_BCH_DEBUG0(x).B.KES_DEBUG_PAYLOAD_FLAG)

/*! @brief Format value for bitfield BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG. */
#define BF_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG) & BM_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG)

/*! @brief Set the KES_DEBUG_PAYLOAD_FLAG field to a new value. */
#define BW_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG) | BF_BCH_DEBUG0_KES_DEBUG_PAYLOAD_FLAG(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field KES_DEBUG_SHIFT_SYND[15] (RW)
 *
 * Toggling this bit causes the value in BCH_DEBUG0_KES_SYNDROME_SYMBOL to be
 * shift into the syndrome register array at the input to the KES engine. After
 * shifting in 16 symbols, one can kick off both KES and CF cycles by toggling
 * BCH_DEBUG0_KES_DEBUG_KICK. Make sure that set KES_BCH_DEBUG0_KES_STANDALONE mode to
 * 1 before kicking.
 */
/*@{*/
#define BP_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND (15U) /*!< Bit position for BCH_DEBUG0_KES_DEBUG_SHIFT_SYND. */
#define BM_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND (0x00008000U) /*!< Bit mask for BCH_DEBUG0_KES_DEBUG_SHIFT_SYND. */
#define BS_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND (1U) /*!< Bit field size in bits for BCH_DEBUG0_KES_DEBUG_SHIFT_SYND. */

/*! @brief Read current value of the BCH_DEBUG0_KES_DEBUG_SHIFT_SYND field. */
#define BR_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND(x) (HW_BCH_DEBUG0(x).B.KES_DEBUG_SHIFT_SYND)

/*! @brief Format value for bitfield BCH_DEBUG0_KES_DEBUG_SHIFT_SYND. */
#define BF_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND) & BM_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND)

/*! @brief Set the KES_DEBUG_SHIFT_SYND field to a new value. */
#define BW_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND) | BF_BCH_DEBUG0_KES_DEBUG_SHIFT_SYND(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field KES_DEBUG_SYNDROME_SYMBOL[24:16] (RW)
 *
 * The 9 bit value in this bit field shifts into the syndrome register array at
 * the input of the KES engine whenever BCH_DEBUG0_KES_DEBUG_SHIFT_SYND is
 * toggled.
 *
 * Values:
 * - 0 - Bus master address generator for SYND_GEN writes operates normally.
 * - 1 - Bus master address generator always addresses last four bytes in
 *     Auxiliary block.
 */
/*@{*/
#define BP_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL (16U) /*!< Bit position for BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL. */
#define BM_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL (0x01FF0000U) /*!< Bit mask for BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL. */
#define BS_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL (9U) /*!< Bit field size in bits for BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL. */

#define BV_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL_NORMAL (0U) /*!< Bit field value for BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL: Bus master address generator for SYND_GEN writes operates normally. */
#define BV_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL_TEST_MODE (0x1U) /*!< Bit field value for BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL: Bus master address generator always addresses last four bytes in Auxiliary block. */

/*! @brief Read current value of the BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL field. */
#define BR_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL(x) (HW_BCH_DEBUG0(x).B.KES_DEBUG_SYNDROME_SYMBOL)

/*! @brief Format value for bitfield BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL. */
#define BF_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL) & BM_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL)

/*! @brief Set the KES_DEBUG_SYNDROME_SYMBOL field to a new value. */
#define BW_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL(x, v) (HW_BCH_DEBUG0_WR(x, (HW_BCH_DEBUG0_RD(x) & ~BM_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL) | BF_BCH_DEBUG0_KES_DEBUG_SYNDROME_SYMBOL(v)))
/*@}*/

/*!
 * @name Register BCH_DEBUG0, field RSVD1[31:25] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_DEBUG0_RSVD1  (25U)         /*!< Bit position for BCH_DEBUG0_RSVD1. */
#define BM_BCH_DEBUG0_RSVD1  (0xFE000000U) /*!< Bit mask for BCH_DEBUG0_RSVD1. */
#define BS_BCH_DEBUG0_RSVD1  (7U)          /*!< Bit field size in bits for BCH_DEBUG0_RSVD1. */

/*! @brief Read current value of the BCH_DEBUG0_RSVD1 field. */
#define BR_BCH_DEBUG0_RSVD1(x) (HW_BCH_DEBUG0(x).B.RSVD1)
/*@}*/




/*******************************************************************************
 * HW_BCH_DBGKESREAD - KES Debug Read Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_DBGKESREAD - KES Debug Read Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The hardware BCH ECC accelerator key equation solver internal state machines
 * and signals can be seen in the ECC debug registers.
 */
typedef union _hw_bch_dbgkesread
{
    uint32_t U;
    struct _hw_bch_dbgkesread_bitfields
    {
        uint32_t VALUES : 32;          /*!< [31:0]  */
    } B;
} hw_bch_dbgkesread_t;

/*!
 * @name Constants and macros for entire BCH_DBGKESREAD register
 */
/*@{*/
#define HW_BCH_DBGKESREAD_ADDR(x) ((uintptr_t)(x) + 0x110U)
#define HW_BCH_DBGKESREAD_SET_ADDR(x) (HW_BCH_DBGKESREAD_ADDR(x) + 0x4U)
#define HW_BCH_DBGKESREAD_CLR_ADDR(x) (HW_BCH_DBGKESREAD_ADDR(x) + 0x8U)
#define HW_BCH_DBGKESREAD_TOG_ADDR(x) (HW_BCH_DBGKESREAD_ADDR(x) + 0xCU)

#define HW_BCH_DBGKESREAD(x)     (*(__I hw_bch_dbgkesread_t *) HW_BCH_DBGKESREAD_ADDR(x))
#define HW_BCH_DBGKESREAD_RD(x)  (HW_BCH_DBGKESREAD(x).U)
/*@}*/

/*
 * Constants & macros for individual BCH_DBGKESREAD bitfields
 */

/*!
 * @name Register BCH_DBGKESREAD, field VALUES[31:0] (RO)
 *
 * This register returns the ROM BIST CRC value after a BIST test.
 */
/*@{*/
#define BP_BCH_DBGKESREAD_VALUES (0U)      /*!< Bit position for BCH_DBGKESREAD_VALUES. */
#define BM_BCH_DBGKESREAD_VALUES (0xFFFFFFFFU) /*!< Bit mask for BCH_DBGKESREAD_VALUES. */
#define BS_BCH_DBGKESREAD_VALUES (32U)     /*!< Bit field size in bits for BCH_DBGKESREAD_VALUES. */

/*! @brief Read current value of the BCH_DBGKESREAD_VALUES field. */
#define BR_BCH_DBGKESREAD_VALUES(x) (HW_BCH_DBGKESREAD(x).U)
/*@}*/




/*******************************************************************************
 * HW_BCH_DBGCSFEREAD - Chien Search Debug Read Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_DBGCSFEREAD - Chien Search Debug Read Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The hardware BCH ECC accelerator Chien Search internal state machines and
 * signals can be seen in the ECC debug registers.
 */
typedef union _hw_bch_dbgcsferead
{
    uint32_t U;
    struct _hw_bch_dbgcsferead_bitfields
    {
        uint32_t VALUES : 32;          /*!< [31:0]  */
    } B;
} hw_bch_dbgcsferead_t;

/*!
 * @name Constants and macros for entire BCH_DBGCSFEREAD register
 */
/*@{*/
#define HW_BCH_DBGCSFEREAD_ADDR(x) ((uintptr_t)(x) + 0x120U)
#define HW_BCH_DBGCSFEREAD_SET_ADDR(x) (HW_BCH_DBGCSFEREAD_ADDR(x) + 0x4U)
#define HW_BCH_DBGCSFEREAD_CLR_ADDR(x) (HW_BCH_DBGCSFEREAD_ADDR(x) + 0x8U)
#define HW_BCH_DBGCSFEREAD_TOG_ADDR(x) (HW_BCH_DBGCSFEREAD_ADDR(x) + 0xCU)

#define HW_BCH_DBGCSFEREAD(x)    (*(__I hw_bch_dbgcsferead_t *) HW_BCH_DBGCSFEREAD_ADDR(x))
#define HW_BCH_DBGCSFEREAD_RD(x) (HW_BCH_DBGCSFEREAD(x).U)
/*@}*/

/*
 * Constants & macros for individual BCH_DBGCSFEREAD bitfields
 */

/*!
 * @name Register BCH_DBGCSFEREAD, field VALUES[31:0] (RO)
 *
 * Reserved
 */
/*@{*/
#define BP_BCH_DBGCSFEREAD_VALUES (0U)     /*!< Bit position for BCH_DBGCSFEREAD_VALUES. */
#define BM_BCH_DBGCSFEREAD_VALUES (0xFFFFFFFFU) /*!< Bit mask for BCH_DBGCSFEREAD_VALUES. */
#define BS_BCH_DBGCSFEREAD_VALUES (32U)    /*!< Bit field size in bits for BCH_DBGCSFEREAD_VALUES. */

/*! @brief Read current value of the BCH_DBGCSFEREAD_VALUES field. */
#define BR_BCH_DBGCSFEREAD_VALUES(x) (HW_BCH_DBGCSFEREAD(x).U)
/*@}*/




/*******************************************************************************
 * HW_BCH_DBGSYNDGENREAD - Syndrome Generator Debug Read Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_DBGSYNDGENREAD - Syndrome Generator Debug Read Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The hardware BCH ECC accelerator syndrome generator internal state machines
 * and signals can be seen in the ECC debug registers.
 */
typedef union _hw_bch_dbgsyndgenread
{
    uint32_t U;
    struct _hw_bch_dbgsyndgenread_bitfields
    {
        uint32_t VALUES : 32;          /*!< [31:0]  */
    } B;
} hw_bch_dbgsyndgenread_t;

/*!
 * @name Constants and macros for entire BCH_DBGSYNDGENREAD register
 */
/*@{*/
#define HW_BCH_DBGSYNDGENREAD_ADDR(x) ((uintptr_t)(x) + 0x130U)
#define HW_BCH_DBGSYNDGENREAD_SET_ADDR(x) (HW_BCH_DBGSYNDGENREAD_ADDR(x) + 0x4U)
#define HW_BCH_DBGSYNDGENREAD_CLR_ADDR(x) (HW_BCH_DBGSYNDGENREAD_ADDR(x) + 0x8U)
#define HW_BCH_DBGSYNDGENREAD_TOG_ADDR(x) (HW_BCH_DBGSYNDGENREAD_ADDR(x) + 0xCU)

#define HW_BCH_DBGSYNDGENREAD(x) (*(__I hw_bch_dbgsyndgenread_t *) HW_BCH_DBGSYNDGENREAD_ADDR(x))
#define HW_BCH_DBGSYNDGENREAD_RD(x) (HW_BCH_DBGSYNDGENREAD(x).U)
/*@}*/

/*
 * Constants & macros for individual BCH_DBGSYNDGENREAD bitfields
 */

/*!
 * @name Register BCH_DBGSYNDGENREAD, field VALUES[31:0] (RO)
 *
 * Reserved
 */
/*@{*/
#define BP_BCH_DBGSYNDGENREAD_VALUES (0U)  /*!< Bit position for BCH_DBGSYNDGENREAD_VALUES. */
#define BM_BCH_DBGSYNDGENREAD_VALUES (0xFFFFFFFFU) /*!< Bit mask for BCH_DBGSYNDGENREAD_VALUES. */
#define BS_BCH_DBGSYNDGENREAD_VALUES (32U) /*!< Bit field size in bits for BCH_DBGSYNDGENREAD_VALUES. */

/*! @brief Read current value of the BCH_DBGSYNDGENREAD_VALUES field. */
#define BR_BCH_DBGSYNDGENREAD_VALUES(x) (HW_BCH_DBGSYNDGENREAD(x).U)
/*@}*/




/*******************************************************************************
 * HW_BCH_DBGAHBMREAD - Bus Master and ECC Controller Debug Read Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_DBGAHBMREAD - Bus Master and ECC Controller Debug Read Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The hardware BCH ECC accelerator bus master, ECC controller internal state
 * machines, and signals can be seen in the ECC debug registers.
 */
typedef union _hw_bch_dbgahbmread
{
    uint32_t U;
    struct _hw_bch_dbgahbmread_bitfields
    {
        uint32_t VALUES : 32;          /*!< [31:0]  */
    } B;
} hw_bch_dbgahbmread_t;

/*!
 * @name Constants and macros for entire BCH_DBGAHBMREAD register
 */
/*@{*/
#define HW_BCH_DBGAHBMREAD_ADDR(x) ((uintptr_t)(x) + 0x140U)
#define HW_BCH_DBGAHBMREAD_SET_ADDR(x) (HW_BCH_DBGAHBMREAD_ADDR(x) + 0x4U)
#define HW_BCH_DBGAHBMREAD_CLR_ADDR(x) (HW_BCH_DBGAHBMREAD_ADDR(x) + 0x8U)
#define HW_BCH_DBGAHBMREAD_TOG_ADDR(x) (HW_BCH_DBGAHBMREAD_ADDR(x) + 0xCU)

#define HW_BCH_DBGAHBMREAD(x)    (*(__I hw_bch_dbgahbmread_t *) HW_BCH_DBGAHBMREAD_ADDR(x))
#define HW_BCH_DBGAHBMREAD_RD(x) (HW_BCH_DBGAHBMREAD(x).U)
/*@}*/

/*
 * Constants & macros for individual BCH_DBGAHBMREAD bitfields
 */

/*!
 * @name Register BCH_DBGAHBMREAD, field VALUES[31:0] (RO)
 *
 * Reserved
 */
/*@{*/
#define BP_BCH_DBGAHBMREAD_VALUES (0U)     /*!< Bit position for BCH_DBGAHBMREAD_VALUES. */
#define BM_BCH_DBGAHBMREAD_VALUES (0xFFFFFFFFU) /*!< Bit mask for BCH_DBGAHBMREAD_VALUES. */
#define BS_BCH_DBGAHBMREAD_VALUES (32U)    /*!< Bit field size in bits for BCH_DBGAHBMREAD_VALUES. */

/*! @brief Read current value of the BCH_DBGAHBMREAD_VALUES field. */
#define BR_BCH_DBGAHBMREAD_VALUES(x) (HW_BCH_DBGAHBMREAD(x).U)
/*@}*/




/*******************************************************************************
 * HW_BCH_BLOCKNAME - Block Name Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_BLOCKNAME - Block Name Register (RO)
 *
 * Reset value: 0x20484342U
 *
 * Read only view of the block name string BCH. Fixed pattern read only value is
 * for test purposes. It can be read as an ASCII string with the zero
 * termination coming from the first byte of the BLOCKVERSION register.
 */
typedef union _hw_bch_blockname
{
    uint32_t U;
    struct _hw_bch_blockname_bitfields
    {
        uint32_t NAME : 32;            /*!< [31:0]  */
    } B;
} hw_bch_blockname_t;

/*!
 * @name Constants and macros for entire BCH_BLOCKNAME register
 */
/*@{*/
#define HW_BCH_BLOCKNAME_ADDR(x) ((uintptr_t)(x) + 0x150U)
#define HW_BCH_BLOCKNAME_SET_ADDR(x) (HW_BCH_BLOCKNAME_ADDR(x) + 0x4U)
#define HW_BCH_BLOCKNAME_CLR_ADDR(x) (HW_BCH_BLOCKNAME_ADDR(x) + 0x8U)
#define HW_BCH_BLOCKNAME_TOG_ADDR(x) (HW_BCH_BLOCKNAME_ADDR(x) + 0xCU)

#define HW_BCH_BLOCKNAME(x)      (*(__I hw_bch_blockname_t *) HW_BCH_BLOCKNAME_ADDR(x))
#define HW_BCH_BLOCKNAME_RD(x)   (HW_BCH_BLOCKNAME(x).U)
/*@}*/

/*
 * Constants & macros for individual BCH_BLOCKNAME bitfields
 */

/*!
 * @name Register BCH_BLOCKNAME, field NAME[31:0] (RO)
 *
 * The name is in the ASCII characters BCH (0x20, H, C, B).
 */
/*@{*/
#define BP_BCH_BLOCKNAME_NAME (0U)         /*!< Bit position for BCH_BLOCKNAME_NAME. */
#define BM_BCH_BLOCKNAME_NAME (0xFFFFFFFFU) /*!< Bit mask for BCH_BLOCKNAME_NAME. */
#define BS_BCH_BLOCKNAME_NAME (32U)        /*!< Bit field size in bits for BCH_BLOCKNAME_NAME. */

/*! @brief Read current value of the BCH_BLOCKNAME_NAME field. */
#define BR_BCH_BLOCKNAME_NAME(x) (HW_BCH_BLOCKNAME(x).U)
/*@}*/




/*******************************************************************************
 * HW_BCH_VERSION - BCH Version Register
 ******************************************************************************/

/*!
 * @brief HW_BCH_VERSION - BCH Version Register (RO)
 *
 * Reset value: 0x01000000U
 *
 * This register always returns a known read value for debug purposes and
 * indicates the version of the block and RTL version in use.
 */
typedef union _hw_bch_version
{
    uint32_t U;
    struct _hw_bch_version_bitfields
    {
        uint32_t STEP : 16;            /*!< [15:0]  */
        uint32_t MINOR : 8;            /*!< [23:16]  */
        uint32_t MAJOR : 8;            /*!< [31:24]  */
    } B;
} hw_bch_version_t;

/*!
 * @name Constants and macros for entire BCH_VERSION register
 */
/*@{*/
#define HW_BCH_VERSION_ADDR(x)   ((uintptr_t)(x) + 0x160U)
#define HW_BCH_VERSION_SET_ADDR(x) (HW_BCH_VERSION_ADDR(x) + 0x4U)
#define HW_BCH_VERSION_CLR_ADDR(x) (HW_BCH_VERSION_ADDR(x) + 0x8U)
#define HW_BCH_VERSION_TOG_ADDR(x) (HW_BCH_VERSION_ADDR(x) + 0xCU)

#define HW_BCH_VERSION(x)        (*(__I hw_bch_version_t *) HW_BCH_VERSION_ADDR(x))
#define HW_BCH_VERSION_RD(x)     (HW_BCH_VERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual BCH_VERSION bitfields
 */

/*!
 * @name Register BCH_VERSION, field STEP[15:0] (RO)
 *
 * Fixed read-only value reflecting the stepping of the RTL version.
 */
/*@{*/
#define BP_BCH_VERSION_STEP  (0U)          /*!< Bit position for BCH_VERSION_STEP. */
#define BM_BCH_VERSION_STEP  (0x0000FFFFU) /*!< Bit mask for BCH_VERSION_STEP. */
#define BS_BCH_VERSION_STEP  (16U)         /*!< Bit field size in bits for BCH_VERSION_STEP. */

/*! @brief Read current value of the BCH_VERSION_STEP field. */
#define BR_BCH_VERSION_STEP(x) (HW_BCH_VERSION(x).B.STEP)
/*@}*/

/*!
 * @name Register BCH_VERSION, field MINOR[23:16] (RO)
 *
 * Fixed read-only value indicates the MINOR field of the RTL version.
 */
/*@{*/
#define BP_BCH_VERSION_MINOR (16U)         /*!< Bit position for BCH_VERSION_MINOR. */
#define BM_BCH_VERSION_MINOR (0x00FF0000U) /*!< Bit mask for BCH_VERSION_MINOR. */
#define BS_BCH_VERSION_MINOR (8U)          /*!< Bit field size in bits for BCH_VERSION_MINOR. */

/*! @brief Read current value of the BCH_VERSION_MINOR field. */
#define BR_BCH_VERSION_MINOR(x) (HW_BCH_VERSION(x).B.MINOR)
/*@}*/

/*!
 * @name Register BCH_VERSION, field MAJOR[31:24] (RO)
 *
 * Fixed read-only value indicates the MAJOR field of the RTL version.
 */
/*@{*/
#define BP_BCH_VERSION_MAJOR (24U)         /*!< Bit position for BCH_VERSION_MAJOR. */
#define BM_BCH_VERSION_MAJOR (0xFF000000U) /*!< Bit mask for BCH_VERSION_MAJOR. */
#define BS_BCH_VERSION_MAJOR (8U)          /*!< Bit field size in bits for BCH_VERSION_MAJOR. */

/*! @brief Read current value of the BCH_VERSION_MAJOR field. */
#define BR_BCH_VERSION_MAJOR(x) (HW_BCH_VERSION(x).B.MAJOR)
/*@}*/




/*******************************************************************************
 * HW_BCH_DEBUG1 - Hardware BCH ECC Debug Register 1
 ******************************************************************************/

/*!
 * @brief HW_BCH_DEBUG1 - Hardware BCH ECC Debug Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The BCH_DEBUG1 register provides erased zero count information and pre-erase
 * check.
 */
typedef union _hw_bch_debug1
{
    uint32_t U;
    struct _hw_bch_debug1_bitfields
    {
        uint32_t ERASED_ZERO_COUNT : 9; /*!< [8:0]  */
        uint32_t RSVD : 22;            /*!< [30:9] This field is reserved. */
        uint32_t DEBUG1_PREERASECHK : 1; /*!< [31]  */
    } B;
} hw_bch_debug1_t;

/*!
 * @name Constants and macros for entire BCH_DEBUG1 register
 */
/*@{*/
#define HW_BCH_DEBUG1_ADDR(x)    ((uintptr_t)(x) + 0x170U)
#define HW_BCH_DEBUG1_SET_ADDR(x) (HW_BCH_DEBUG1_ADDR(x) + 0x4U)
#define HW_BCH_DEBUG1_CLR_ADDR(x) (HW_BCH_DEBUG1_ADDR(x) + 0x8U)
#define HW_BCH_DEBUG1_TOG_ADDR(x) (HW_BCH_DEBUG1_ADDR(x) + 0xCU)

#define HW_BCH_DEBUG1(x)         (*(__IO hw_bch_debug1_t *) HW_BCH_DEBUG1_ADDR(x))
#define HW_BCH_DEBUG1_RD(x)      (HW_BCH_DEBUG1(x).U)
#define HW_BCH_DEBUG1_WR(x, v)   (HW_BCH_DEBUG1(x).U = (v))
#define HW_BCH_DEBUG1_SET(x, v)  ((*(uint32_t *) HW_BCH_DEBUG1_SET_ADDR(x)) = (v))
#define HW_BCH_DEBUG1_CLR(x, v)  ((*(uint32_t *) HW_BCH_DEBUG1_CLR_ADDR(x)) = (v))
#define HW_BCH_DEBUG1_TOG(x, v)  ((*(uint32_t *) HW_BCH_DEBUG1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual BCH_DEBUG1 bitfields
 */

/*!
 * @name Register BCH_DEBUG1, field ERASED_ZERO_COUNT[8:0] (RO)
 *
 * The zero counts on one page.
 */
/*@{*/
#define BP_BCH_DEBUG1_ERASED_ZERO_COUNT (0U) /*!< Bit position for BCH_DEBUG1_ERASED_ZERO_COUNT. */
#define BM_BCH_DEBUG1_ERASED_ZERO_COUNT (0x000001FFU) /*!< Bit mask for BCH_DEBUG1_ERASED_ZERO_COUNT. */
#define BS_BCH_DEBUG1_ERASED_ZERO_COUNT (9U) /*!< Bit field size in bits for BCH_DEBUG1_ERASED_ZERO_COUNT. */

/*! @brief Read current value of the BCH_DEBUG1_ERASED_ZERO_COUNT field. */
#define BR_BCH_DEBUG1_ERASED_ZERO_COUNT(x) (HW_BCH_DEBUG1(x).B.ERASED_ZERO_COUNT)
/*@}*/

/*!
 * @name Register BCH_DEBUG1, field RSVD[30:9] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_BCH_DEBUG1_RSVD   (9U)          /*!< Bit position for BCH_DEBUG1_RSVD. */
#define BM_BCH_DEBUG1_RSVD   (0x7FFFFE00U) /*!< Bit mask for BCH_DEBUG1_RSVD. */
#define BS_BCH_DEBUG1_RSVD   (22U)         /*!< Bit field size in bits for BCH_DEBUG1_RSVD. */

/*! @brief Read current value of the BCH_DEBUG1_RSVD field. */
#define BR_BCH_DEBUG1_RSVD(x) (HW_BCH_DEBUG1(x).B.RSVD)
/*@}*/

/*!
 * @name Register BCH_DEBUG1, field DEBUG1_PREERASECHK[31] (RW)
 *
 * Blank page enables pre-erase check.
 *
 * Values:
 * - 0 - Turn off pre-erase check
 * - 1 - Turn on pre-erase check
 */
/*@{*/
#define BP_BCH_DEBUG1_DEBUG1_PREERASECHK (31U) /*!< Bit position for BCH_DEBUG1_DEBUG1_PREERASECHK. */
#define BM_BCH_DEBUG1_DEBUG1_PREERASECHK (0x80000000U) /*!< Bit mask for BCH_DEBUG1_DEBUG1_PREERASECHK. */
#define BS_BCH_DEBUG1_DEBUG1_PREERASECHK (1U) /*!< Bit field size in bits for BCH_DEBUG1_DEBUG1_PREERASECHK. */

/*! @brief Read current value of the BCH_DEBUG1_DEBUG1_PREERASECHK field. */
#define BR_BCH_DEBUG1_DEBUG1_PREERASECHK(x) (HW_BCH_DEBUG1(x).B.DEBUG1_PREERASECHK)

/*! @brief Format value for bitfield BCH_DEBUG1_DEBUG1_PREERASECHK. */
#define BF_BCH_DEBUG1_DEBUG1_PREERASECHK(v) ((uint32_t)((uint32_t)(v) << BP_BCH_DEBUG1_DEBUG1_PREERASECHK) & BM_BCH_DEBUG1_DEBUG1_PREERASECHK)

/*! @brief Set the DEBUG1_PREERASECHK field to a new value. */
#define BW_BCH_DEBUG1_DEBUG1_PREERASECHK(x, v) (HW_BCH_DEBUG1_WR(x, (HW_BCH_DEBUG1_RD(x) & ~BM_BCH_DEBUG1_DEBUG1_PREERASECHK) | BF_BCH_DEBUG1_DEBUG1_PREERASECHK(v)))
/*@}*/




/*******************************************************************************
 * hw_bch_t - module struct
 ******************************************************************************/
/*!
 * @brief All BCH module registers.
 */
#pragma pack(1)
typedef struct _hw_bch
{
    __IO hw_bch_ctrl_t CTRL;               /*!< [0x0] Hardware BCH ECC Accelerator Control Register */
    uint8_t _reserved0[12];
    __I hw_bch_status0_t STATUS0;          /*!< [0x10] Hardware ECC Accelerator Status Register 0 */
    uint8_t _reserved1[12];
    __IO hw_bch_mode_t MODE;               /*!< [0x20] Hardware ECC Accelerator Mode Register */
    uint8_t _reserved2[12];
    __IO hw_bch_encodeptr_t ENCODEPTR;     /*!< [0x30] Hardware BCH ECC Loopback Encode Buffer Register */
    uint8_t _reserved3[12];
    __IO hw_bch_dataptr_t DATAPTR;         /*!< [0x40] Hardware BCH ECC Loopback Data Buffer Register */
    uint8_t _reserved4[12];
    __IO hw_bch_metaptr_t METAPTR;         /*!< [0x50] Hardware BCH ECC Loopback Metadata Buffer Register */
    uint8_t _reserved5[28];
    __IO hw_bch_layoutselect_t LAYOUTSELECT; /*!< [0x70] Hardware ECC Accelerator Layout Select Register */
    uint8_t _reserved6[12];
    __IO hw_bch_flash0layout0_t FLASH0LAYOUT0; /*!< [0x80] Hardware BCH ECC Flash 0 Layout 0 Register */
    uint8_t _reserved7[12];
    __IO hw_bch_flash0layout1_t FLASH0LAYOUT1; /*!< [0x90] Hardware BCH ECC Flash 0 Layout 1 Register */
    uint8_t _reserved8[12];
    __IO hw_bch_flash1layout0_t FLASH1LAYOUT0; /*!< [0xA0] Hardware BCH ECC Flash 1 Layout 0 Register */
    uint8_t _reserved9[12];
    __IO hw_bch_flash1layout1_t FLASH1LAYOUT1; /*!< [0xB0] Hardware BCH ECC Flash 1 Layout 1 Register */
    uint8_t _reserved10[12];
    __IO hw_bch_flash2layout0_t FLASH2LAYOUT0; /*!< [0xC0] Hardware BCH ECC Flash 2 Layout 0 Register */
    uint8_t _reserved11[12];
    __IO hw_bch_flash2layout1_t FLASH2LAYOUT1; /*!< [0xD0] Hardware BCH ECC Flash 2 Layout 1 Register */
    uint8_t _reserved12[12];
    __IO hw_bch_flash3layout0_t FLASH3LAYOUT0; /*!< [0xE0] Hardware BCH ECC Flash 3 Layout 0 Register */
    uint8_t _reserved13[12];
    __IO hw_bch_flash3layout1_t FLASH3LAYOUT1; /*!< [0xF0] Hardware BCH ECC Flash 3 Layout 1 Register */
    uint8_t _reserved14[12];
    __IO hw_bch_debug0_t DEBUG0;           /*!< [0x100] Hardware BCH ECC Debug Register0 */
    uint8_t _reserved15[12];
    __I hw_bch_dbgkesread_t DBGKESREAD;    /*!< [0x110] KES Debug Read Register */
    uint8_t _reserved16[12];
    __I hw_bch_dbgcsferead_t DBGCSFEREAD;  /*!< [0x120] Chien Search Debug Read Register */
    uint8_t _reserved17[12];
    __I hw_bch_dbgsyndgenread_t DBGSYNDGENREAD; /*!< [0x130] Syndrome Generator Debug Read Register */
    uint8_t _reserved18[12];
    __I hw_bch_dbgahbmread_t DBGAHBMREAD;  /*!< [0x140] Bus Master and ECC Controller Debug Read Register */
    uint8_t _reserved19[12];
    __I hw_bch_blockname_t BLOCKNAME;      /*!< [0x150] Block Name Register */
    uint8_t _reserved20[12];
    __I hw_bch_version_t VERSION;          /*!< [0x160] BCH Version Register */
    uint8_t _reserved21[12];
    __IO hw_bch_debug1_t DEBUG1;           /*!< [0x170] Hardware BCH ECC Debug Register 1 */
} hw_bch_t;
#pragma pack()

/*! @brief Macro to access all BCH registers. */
/*! @param x BCH module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_BCH_REGS(BCH_BASE)</code>. */
#define HW_BCH_REGS(x) (*(hw_bch_t *)(x))

/*
 * iMX7D CAN
 *
 * FLEXCAN
 *
 * Registers defined in this header file:
 * - HW_CAN_MCR - Module Configuration Register
 * - HW_CAN_CTRL1 - Control 1 Register
 * - HW_CAN_TIMER - Free Running Timer Register
 * - HW_CAN_RXMGMASK - Rx Mailboxes Global Mask Register
 * - HW_CAN_RX14MASK - Rx Buffer 14 Mask Register
 * - HW_CAN_RX15MASK - Rx Buffer 15 Mask Register
 * - HW_CAN_ECR - Error Counter Register
 * - HW_CAN_ESR1 - Error and Status 1 Register
 * - HW_CAN_IMASK2 - Interrupt Masks 2 Register
 * - HW_CAN_IMASK1 - Interrupt Masks 1 Register
 * - HW_CAN_IFLAG2 - Interrupt Flags 2 Register
 * - HW_CAN_IFLAG1 - Interrupt Flags 1 Register
 * - HW_CAN_CTRL2 - Control 2 Register
 * - HW_CAN_ESR2 - Error and Status 2 Register
 * - HW_CAN_CRCR - CRC Register
 * - HW_CAN_RXFGMASK - Rx FIFO Global Mask Register
 * - HW_CAN_RXFIR - Rx FIFO Information Register
 * - HW_CAN_CSn - Message Buffer 0 CS Register
 * - HW_CAN_IDn - Message Buffer 0 ID Register
 * - HW_CAN_WORD0n - Message Buffer 0 WORD0 Register
 * - HW_CAN_WORD1n - Message Buffer 0 WORD1 Register
 * - HW_CAN_RXIMRn - RXIMR
 * - HW_CAN_GFWR - Glitch Filter Width Registers
 *
 * - hw_can_t - Struct containing all module registers.
 */

#define HW_CAN_INSTANCE_COUNT (2U) /*!< Number of instances of the CAN module. */
#define HW_CAN1 (0U) /*!< Instance number for CAN1. */
#define HW_CAN2 (1U) /*!< Instance number for CAN2. */
#define CAN1_BASE             (0x30A00000U) /*!< Base address for CAN1. */
#define CAN2_BASE             (0x30A10000U) /*!< Base address for CAN2. */
/*! Array initializer of CAN base addresses. */
#define CAN_BASE_ADDRS        { CAN1_BASE, CAN2_BASE }

/*******************************************************************************
 * HW_CAN_MCR - Module Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_MCR - Module Configuration Register (RW)
 *
 * Reset value: 0x5980000FU
 *
 * This register defines global system configurations, such as the module
 * operation mode (e.g., low power) and maximum message buffer configuration.
 */
typedef union _hw_can_mcr
{
    uint32_t U;
    struct _hw_can_mcr_bitfields
    {
        uint32_t MAXMB : 7;            /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t IDAM : 2;             /*!< [9:8]  */
        uint32_t RESERVED1 : 2;        /*!< [11:10]  */
        uint32_t AEN : 1;              /*!< [12]  */
        uint32_t LPRIO_EN : 1;         /*!< [13]  */
        uint32_t RESERVED2 : 2;        /*!< [15:14]  */
        uint32_t IRMQ : 1;             /*!< [16]  */
        uint32_t SRX_DIS : 1;          /*!< [17]  */
        uint32_t RESERVED3 : 1;        /*!< [18]  */
        uint32_t WAK_SRC : 1;          /*!< [19]  */
        uint32_t LPM_ACK : 1;          /*!< [20]  */
        uint32_t WRN_EN : 1;           /*!< [21]  */
        uint32_t SLF_WAK : 1;          /*!< [22]  */
        uint32_t SUPV : 1;             /*!< [23]  */
        uint32_t FRZ_ACK : 1;          /*!< [24]  */
        uint32_t SOFT_RST : 1;         /*!< [25]  */
        uint32_t WAK_MSK : 1;          /*!< [26]  */
        uint32_t NOT_RDY : 1;          /*!< [27]  */
        uint32_t HALT : 1;             /*!< [28]  */
        uint32_t RFEN : 1;             /*!< [29]  */
        uint32_t FRZ : 1;              /*!< [30]  */
        uint32_t MDIS : 1;             /*!< [31]  */
    } B;
} hw_can_mcr_t;

/*!
 * @name Constants and macros for entire CAN_MCR register
 */
/*@{*/
#define HW_CAN_MCR_ADDR(x)       ((uintptr_t)(x) + 0x0U)

#define HW_CAN_MCR(x)            (*(__IO hw_can_mcr_t *) HW_CAN_MCR_ADDR(x))
#define HW_CAN_MCR_RD(x)         (HW_CAN_MCR(x).U)
#define HW_CAN_MCR_WR(x, v)      (HW_CAN_MCR(x).U = (v))
#define HW_CAN_MCR_SET(x, v)     (HW_CAN_MCR_WR(x, HW_CAN_MCR_RD(x) |  (v)))
#define HW_CAN_MCR_CLR(x, v)     (HW_CAN_MCR_WR(x, HW_CAN_MCR_RD(x) & ~(v)))
#define HW_CAN_MCR_TOG(x, v)     (HW_CAN_MCR_WR(x, HW_CAN_MCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_MCR bitfields
 */

/*!
 * @name Register CAN_MCR, field MAXMB[6:0] (RW)
 *
 * This 7-bit field defines the number of the last Message Buffers that will
 * take part in the matching and arbitration processes. The reset value (0x0F) is
 * equivalent to 16 MB configuration. This field can only be written in Freeze Mode
 * as it is blocked by hardware in other modes Number of the last MB = MAXMB.
 * Additionally, the value of MAXMB must encompass the FIFO size defined by
 * CTRL2[RFFN] MAXMB also impacts the definition of the minimum number of peripheral
 * clocks per CAN bit as described in (see Arbitration and Matching Timing).
 */
/*@{*/
#define BP_CAN_MCR_MAXMB     (0U)          /*!< Bit position for CAN_MCR_MAXMB. */
#define BM_CAN_MCR_MAXMB     (0x0000007FU) /*!< Bit mask for CAN_MCR_MAXMB. */
#define BS_CAN_MCR_MAXMB     (7U)          /*!< Bit field size in bits for CAN_MCR_MAXMB. */

/*! @brief Read current value of the CAN_MCR_MAXMB field. */
#define BR_CAN_MCR_MAXMB(x)  (HW_CAN_MCR(x).B.MAXMB)

/*! @brief Format value for bitfield CAN_MCR_MAXMB. */
#define BF_CAN_MCR_MAXMB(v)  ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_MAXMB) & BM_CAN_MCR_MAXMB)

/*! @brief Set the MAXMB field to a new value. */
#define BW_CAN_MCR_MAXMB(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_MAXMB) | BF_CAN_MCR_MAXMB(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field IDAM[9:8] (RW)
 *
 * This 2-bit field identifies the format of the elements of the Rx FIFO filter
 * table, as shown below. Note that all elements of the table are configured at
 * the same time by this field (they are all the same format). See Rx FIFO
 * StructureWhen the MCR[RFEN] bit is set, the memory area from $80 to $DC (which is
 * normally occupied by MBs 0 to 5) is used by the reception FIFO engine. . This bit
 * can only be written in Freeze mode as it is blocked by hardware in other
 * modes.
 *
 * Values:
 * - 00 - Format A One full ID (standard or extended) per ID filter Table
 *     element.
 * - 01 - Format B Two full standard IDs or two partial 14-bit extended IDs per
 *     ID filter Table element.
 * - 10 - Format C Four partial 8-bit IDs (standard or extended) per ID filter
 *     Table element.
 * - 11 - Format D All frames rejected.
 */
/*@{*/
#define BP_CAN_MCR_IDAM      (8U)          /*!< Bit position for CAN_MCR_IDAM. */
#define BM_CAN_MCR_IDAM      (0x00000300U) /*!< Bit mask for CAN_MCR_IDAM. */
#define BS_CAN_MCR_IDAM      (2U)          /*!< Bit field size in bits for CAN_MCR_IDAM. */

/*! @brief Read current value of the CAN_MCR_IDAM field. */
#define BR_CAN_MCR_IDAM(x)   (HW_CAN_MCR(x).B.IDAM)

/*! @brief Format value for bitfield CAN_MCR_IDAM. */
#define BF_CAN_MCR_IDAM(v)   ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_IDAM) & BM_CAN_MCR_IDAM)

/*! @brief Set the IDAM field to a new value. */
#define BW_CAN_MCR_IDAM(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_IDAM) | BF_CAN_MCR_IDAM(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field AEN[12] (RW)
 *
 * This bit is supplied for backwards compatibility reasons. When asserted, it
 * enables the Tx abort feature. This feature guarantees a safe procedure for
 * aborting a pending transmission, so that no frame is sent in the CAN bus without
 * notification. This bit can only be written in Freeze mode as it is blocked by
 * hardware in other modes.Write Abort code into Rx Mailboxes can cause
 * unpredictable results when the MCR[AEN] is asserted.
 *
 * Values:
 * - 1 - Abort enabled
 * - 0 - Abort disabled
 */
/*@{*/
#define BP_CAN_MCR_AEN       (12U)         /*!< Bit position for CAN_MCR_AEN. */
#define BM_CAN_MCR_AEN       (0x00001000U) /*!< Bit mask for CAN_MCR_AEN. */
#define BS_CAN_MCR_AEN       (1U)          /*!< Bit field size in bits for CAN_MCR_AEN. */

/*! @brief Read current value of the CAN_MCR_AEN field. */
#define BR_CAN_MCR_AEN(x)    (HW_CAN_MCR(x).B.AEN)

/*! @brief Format value for bitfield CAN_MCR_AEN. */
#define BF_CAN_MCR_AEN(v)    ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_AEN) & BM_CAN_MCR_AEN)

/*! @brief Set the AEN field to a new value. */
#define BW_CAN_MCR_AEN(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_AEN) | BF_CAN_MCR_AEN(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field LPRIO_EN[13] (RW)
 *
 * This bit is provided for backwards compatibility reasons. It controls whether
 * the local priority feature is enabled or not. It is used to extend the ID
 * used during the arbitration process. With this extended ID concept, the
 * arbitration process is done based on the full 32-bit word, but the actual transmitted
 * ID still has 11-bit for standard frames and 29-bit for extended frames.This bit
 * can only be written in Freeze mode as it is blocked by hardware in other
 * modes.
 *
 * Values:
 * - 1 - Local Priority enabled
 * - 0 - Local Priority disabled
 */
/*@{*/
#define BP_CAN_MCR_LPRIO_EN  (13U)         /*!< Bit position for CAN_MCR_LPRIO_EN. */
#define BM_CAN_MCR_LPRIO_EN  (0x00002000U) /*!< Bit mask for CAN_MCR_LPRIO_EN. */
#define BS_CAN_MCR_LPRIO_EN  (1U)          /*!< Bit field size in bits for CAN_MCR_LPRIO_EN. */

/*! @brief Read current value of the CAN_MCR_LPRIO_EN field. */
#define BR_CAN_MCR_LPRIO_EN(x) (HW_CAN_MCR(x).B.LPRIO_EN)

/*! @brief Format value for bitfield CAN_MCR_LPRIO_EN. */
#define BF_CAN_MCR_LPRIO_EN(v) ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_LPRIO_EN) & BM_CAN_MCR_LPRIO_EN)

/*! @brief Set the LPRIO_EN field to a new value. */
#define BW_CAN_MCR_LPRIO_EN(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_LPRIO_EN) | BF_CAN_MCR_LPRIO_EN(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field IRMQ[16] (RW)
 *
 * This bit indicates whether Rx matching process will be based either on
 * individual masking and queue or on masking scheme with RXMGMASK, RX14MASK and
 * RX15MASK, RXFGMASK. This bit can only be written in Freeze mode as it is blocked by
 * hardware in other modes.
 *
 * Values:
 * - 1 - Individual Rx masking and queue feature are enabled.
 * - 0 - Individual Rx masking and queue feature are disabled.For backward
 *     compatibility, the reading of C/S word locks the MB even if it is EMPTY.
 */
/*@{*/
#define BP_CAN_MCR_IRMQ      (16U)         /*!< Bit position for CAN_MCR_IRMQ. */
#define BM_CAN_MCR_IRMQ      (0x00010000U) /*!< Bit mask for CAN_MCR_IRMQ. */
#define BS_CAN_MCR_IRMQ      (1U)          /*!< Bit field size in bits for CAN_MCR_IRMQ. */

/*! @brief Read current value of the CAN_MCR_IRMQ field. */
#define BR_CAN_MCR_IRMQ(x)   (HW_CAN_MCR(x).B.IRMQ)

/*! @brief Format value for bitfield CAN_MCR_IRMQ. */
#define BF_CAN_MCR_IRMQ(v)   ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_IRMQ) & BM_CAN_MCR_IRMQ)

/*! @brief Set the IRMQ field to a new value. */
#define BW_CAN_MCR_IRMQ(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_IRMQ) | BF_CAN_MCR_IRMQ(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field SRX_DIS[17] (RW)
 *
 * This bit defines whether FlexCAN is allowed to receive frames transmitted by
 * itself. If this bit is asserted, frames transmitted by the module will not be
 * stored in any MB, regardless if the MB is programmed with an ID that matches
 * the transmitted frame, and no interrupt flag or interrupt signal will be
 * generated due to the frame reception. This bit can only be written in Freeze mode as
 * it is blocked by hardware in other modes.
 *
 * Values:
 * - 1 - Self reception disabled
 * - 0 - Self reception enabled
 */
/*@{*/
#define BP_CAN_MCR_SRX_DIS   (17U)         /*!< Bit position for CAN_MCR_SRX_DIS. */
#define BM_CAN_MCR_SRX_DIS   (0x00020000U) /*!< Bit mask for CAN_MCR_SRX_DIS. */
#define BS_CAN_MCR_SRX_DIS   (1U)          /*!< Bit field size in bits for CAN_MCR_SRX_DIS. */

/*! @brief Read current value of the CAN_MCR_SRX_DIS field. */
#define BR_CAN_MCR_SRX_DIS(x) (HW_CAN_MCR(x).B.SRX_DIS)

/*! @brief Format value for bitfield CAN_MCR_SRX_DIS. */
#define BF_CAN_MCR_SRX_DIS(v) ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_SRX_DIS) & BM_CAN_MCR_SRX_DIS)

/*! @brief Set the SRX_DIS field to a new value. */
#define BW_CAN_MCR_SRX_DIS(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_SRX_DIS) | BF_CAN_MCR_SRX_DIS(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field WAK_SRC[19] (RW)
 *
 * This bit defines whether the integrated low-pass filter is applied to protect
 * the FLEXCAN_RX input from spurious wake up. See Stop ModeThis is a system low
 * power mode in which system clocks can be stopped for maximum power savings..
 * To enter stop mode, the CPU should manually assert a global Stop Mode request
 * (see the CAN1_STOP_REQ and CAN2_STOP_REQ bit in the register IOMUXC_GPR4)and
 * check the acknowledgement asserted by the FlexCAN (see the CAN1_STOP_ACK and
 * CAN2_STOP_ACK in the register IOMUXC_GPR4) . The CPU must only consider the
 * FlexCAN in Stop Mode when both request and acknowledgement conditions are
 * satisfied. for more information. This bit can only be written in Freeze mode as it is
 * blocked by hardware in other modes.
 *
 * Values:
 * - 1 - FLEXCAN uses the filtered FLEXCAN_RX input to detect recessive to
 *     dominant edges on the CAN bus
 * - 0 - FLEXCAN uses the unfiltered FLEXCAN_RX input to detect recessive to
 *     dominant edges on the CAN bus.
 */
/*@{*/
#define BP_CAN_MCR_WAK_SRC   (19U)         /*!< Bit position for CAN_MCR_WAK_SRC. */
#define BM_CAN_MCR_WAK_SRC   (0x00080000U) /*!< Bit mask for CAN_MCR_WAK_SRC. */
#define BS_CAN_MCR_WAK_SRC   (1U)          /*!< Bit field size in bits for CAN_MCR_WAK_SRC. */

/*! @brief Read current value of the CAN_MCR_WAK_SRC field. */
#define BR_CAN_MCR_WAK_SRC(x) (HW_CAN_MCR(x).B.WAK_SRC)

/*! @brief Format value for bitfield CAN_MCR_WAK_SRC. */
#define BF_CAN_MCR_WAK_SRC(v) ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_WAK_SRC) & BM_CAN_MCR_WAK_SRC)

/*! @brief Set the WAK_SRC field to a new value. */
#define BW_CAN_MCR_WAK_SRC(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_WAK_SRC) | BF_CAN_MCR_WAK_SRC(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field LPM_ACK[20] (RO)
 *
 * This read-only bit indicates that FLEXCAN is either in Disable Mode or Stop
 * Mode. Either of these low power modes can not be entered until all current
 * transmission or reception processes have finished, so the ARM can poll the LPM_ACK
 * bit to know when FLEXCAN has actually entered low power mode. See Module
 * Disable ModeThis low power mode is normally used to temporarily disable a complete
 * FlexCAN block, with no power consumption. It is requested by the ARM through
 * the assertion of the MDIS bit in the MCR Register and the acknowledgement is
 * obtained through the assertion by the FlexCAN of the LPM_ACK bit in the same
 * register. The ARM must only consider the FlexCAN in Disable Mode when both
 * request and acknowledgement conditions are satisfied. , and Stop ModeThis is a
 * system low power mode in which system clocks can be stopped for maximum power
 * savings.. To enter stop mode, the CPU should manually assert a global Stop Mode
 * request (see the CAN1_STOP_REQ and CAN2_STOP_REQ bit in the register
 * IOMUXC_GPR4)and check the acknowledgement asserted by the FlexCAN (see the CAN1_STOP_ACK
 * and CAN2_STOP_ACK in the register IOMUXC_GPR4) . The CPU must only consider
 * the FlexCAN in Stop Mode when both request and acknowledgement conditions are
 * satisfied. for more information
 *
 * Values:
 * - 1 - FLEXCAN is either in Disable Mode, or Stop mode
 * - 0 - FLEXCAN not in any of the low power modes
 */
/*@{*/
#define BP_CAN_MCR_LPM_ACK   (20U)         /*!< Bit position for CAN_MCR_LPM_ACK. */
#define BM_CAN_MCR_LPM_ACK   (0x00100000U) /*!< Bit mask for CAN_MCR_LPM_ACK. */
#define BS_CAN_MCR_LPM_ACK   (1U)          /*!< Bit field size in bits for CAN_MCR_LPM_ACK. */

/*! @brief Read current value of the CAN_MCR_LPM_ACK field. */
#define BR_CAN_MCR_LPM_ACK(x) (HW_CAN_MCR(x).B.LPM_ACK)
/*@}*/

/*!
 * @name Register CAN_MCR, field WRN_EN[21] (RW)
 *
 * When asserted, this bit enables the generation of the TWRN_INT and RWRN_INT
 * flags in the Error and Status Register. If WRN_EN is negated, the TWRN_INT and
 * RWRN_INT flags will always be zero, independent of the values of the error
 * counters, and no warning interrupt will ever be generated.This bit can only be
 * written in Freeze mode as it is blocked by hardware in other modes.
 *
 * Values:
 * - 1 - TWRN_INT and RWRN_INT bits are set when the respective error counter
 *     transition from <96 to >= 96.
 * - 0 - TWRN_INT and RWRN_INT bits are zero, independent of the values in the
 *     error counters.
 */
/*@{*/
#define BP_CAN_MCR_WRN_EN    (21U)         /*!< Bit position for CAN_MCR_WRN_EN. */
#define BM_CAN_MCR_WRN_EN    (0x00200000U) /*!< Bit mask for CAN_MCR_WRN_EN. */
#define BS_CAN_MCR_WRN_EN    (1U)          /*!< Bit field size in bits for CAN_MCR_WRN_EN. */

/*! @brief Read current value of the CAN_MCR_WRN_EN field. */
#define BR_CAN_MCR_WRN_EN(x) (HW_CAN_MCR(x).B.WRN_EN)

/*! @brief Format value for bitfield CAN_MCR_WRN_EN. */
#define BF_CAN_MCR_WRN_EN(v) ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_WRN_EN) & BM_CAN_MCR_WRN_EN)

/*! @brief Set the WRN_EN field to a new value. */
#define BW_CAN_MCR_WRN_EN(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_WRN_EN) | BF_CAN_MCR_WRN_EN(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field SLF_WAK[22] (RW)
 *
 * This bit enables the Self Wake Up feature when FLEXCAN is in Stop Mode. If
 * this bit had been asserted by the time FLEXCAN entered Stop Mode, then FLEXCAN
 * will look for a recessive to dominant transition on the bus during these modes.
 * If a transition from recessive to dominant is detected during Stop Mode, then
 * FLEXCAN generates, if enabled to do so, a Wake Up interrupt to the ARM so
 * that it can resume the clocks globally and FlexCAN can request to resume the
 * clocks. This bit can not be written while the module is in Stop Mode.
 *
 * Values:
 * - 1 - FLEXCAN Self Wake Up feature is enabled
 * - 0 - FLEXCAN Self Wake Up feature is disabled
 */
/*@{*/
#define BP_CAN_MCR_SLF_WAK   (22U)         /*!< Bit position for CAN_MCR_SLF_WAK. */
#define BM_CAN_MCR_SLF_WAK   (0x00400000U) /*!< Bit mask for CAN_MCR_SLF_WAK. */
#define BS_CAN_MCR_SLF_WAK   (1U)          /*!< Bit field size in bits for CAN_MCR_SLF_WAK. */

/*! @brief Read current value of the CAN_MCR_SLF_WAK field. */
#define BR_CAN_MCR_SLF_WAK(x) (HW_CAN_MCR(x).B.SLF_WAK)

/*! @brief Format value for bitfield CAN_MCR_SLF_WAK. */
#define BF_CAN_MCR_SLF_WAK(v) ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_SLF_WAK) & BM_CAN_MCR_SLF_WAK)

/*! @brief Set the SLF_WAK field to a new value. */
#define BW_CAN_MCR_SLF_WAK(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_SLF_WAK) | BF_CAN_MCR_SLF_WAK(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field SUPV[23] (RW)
 *
 * This bit configures some of the FLEXCAN registers to be either in Supervisor
 * or User Mode. Reset value of this bit is '1', so the affected registers start
 * with Supervisor access allowance only. This bit can only be written in Freeze
 * mode as it is blocked by hardware in other modes.
 *
 * Values:
 * - 1 - FlexCAN is in Supervisor Mode. Affected registers allow only Supervisor
 *     access. Unrestricted access behaves as though the access was done to an
 *     unimplemented register location
 * - 0 - FlexCAN is in User Mode. Affected registers allow both Supervisor and
 *     Unrestricted accesses
 */
/*@{*/
#define BP_CAN_MCR_SUPV      (23U)         /*!< Bit position for CAN_MCR_SUPV. */
#define BM_CAN_MCR_SUPV      (0x00800000U) /*!< Bit mask for CAN_MCR_SUPV. */
#define BS_CAN_MCR_SUPV      (1U)          /*!< Bit field size in bits for CAN_MCR_SUPV. */

/*! @brief Read current value of the CAN_MCR_SUPV field. */
#define BR_CAN_MCR_SUPV(x)   (HW_CAN_MCR(x).B.SUPV)

/*! @brief Format value for bitfield CAN_MCR_SUPV. */
#define BF_CAN_MCR_SUPV(v)   ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_SUPV) & BM_CAN_MCR_SUPV)

/*! @brief Set the SUPV field to a new value. */
#define BW_CAN_MCR_SUPV(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_SUPV) | BF_CAN_MCR_SUPV(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field FRZ_ACK[24] (RO)
 *
 * This read-only bit indicates that FLEXCAN is in Freeze Mode and its prescaler
 * is stopped. The Freeze Mode request cannot be granted until current
 * transmission or reception processes have finished. Therefore the software can poll the
 * FRZ_ACK bit to know when FLEXCAN has actually entered Freeze Mode. If Freeze
 * Mode request is negated, then this bit is negated once the FLEXCAN prescaler is
 * running again. If Freeze Mode is requested while FLEXCAN is in any of the low
 * power modes, then the FRZ_ACK bit will only be set when the low power mode is
 * exited. See Freeze ModeThis mode is requested by ARM through the assertion of
 * the HALT bit in the MCR Register or when the MCU is put into Debug Mode . In
 * both cases it is also necessary that the FRZ bit is asserted in the MCR
 * Register and the module is not in any of the low power modes (Disable, Stop). The
 * acknowledgement is obtained through the assertion by the FlexCAN of FRZ_ACK bit
 * in the same register. The ARM must only consider the FlexCAN in Freeze Mode
 * when both request and acknowledgement conditions are satisfied. for more
 * information
 *
 * Values:
 * - 1 - FLEXCAN in Freeze Mode, prescaler stopped
 * - 0 - FLEXCAN not in Freeze Mode, prescaler running
 */
/*@{*/
#define BP_CAN_MCR_FRZ_ACK   (24U)         /*!< Bit position for CAN_MCR_FRZ_ACK. */
#define BM_CAN_MCR_FRZ_ACK   (0x01000000U) /*!< Bit mask for CAN_MCR_FRZ_ACK. */
#define BS_CAN_MCR_FRZ_ACK   (1U)          /*!< Bit field size in bits for CAN_MCR_FRZ_ACK. */

/*! @brief Read current value of the CAN_MCR_FRZ_ACK field. */
#define BR_CAN_MCR_FRZ_ACK(x) (HW_CAN_MCR(x).B.FRZ_ACK)
/*@}*/

/*!
 * @name Register CAN_MCR, field SOFT_RST[25] (RW)
 *
 * When this bit is asserted, FlexCAN resets its internal state machines and
 * some of the memory mapped registers. The following registers are reset: MCR
 * (except the MDIS bit), TIMER, ECR, ESR1, ESR2, IMASK1, IMASK2, IFLAG1, IFLAG2 and
 * CRCR. Configuration registers that control the interface to the CAN bus are not
 * affected by soft reset. The following registers are unaffected: CTRL1, CTRL2,
 * RXIMR0_RXIMR63, RXGMASK, RX14MASK, RX15MASK, RXFGMASK, RXFIR and all Message
 * Buffers The SOFT_RST bit can be asserted directly by the ARM when it writes to
 * the MCR Register. It may take some time to fully propagate its effect. The
 * SOFT_RST bit remains asserted while reset is pending, and is automatically
 * negated when reset completes. Therefore, software can poll this bit to know when
 * the soft reset has completed. Soft reset cannot be applied while clocks are shut
 * down in any of the low power modes. The module should be first removed from
 * low power mode, and then soft reset can be applied.
 *
 * Values:
 * - 1 - Reset the registers
 * - 0 - No reset request
 */
/*@{*/
#define BP_CAN_MCR_SOFT_RST  (25U)         /*!< Bit position for CAN_MCR_SOFT_RST. */
#define BM_CAN_MCR_SOFT_RST  (0x02000000U) /*!< Bit mask for CAN_MCR_SOFT_RST. */
#define BS_CAN_MCR_SOFT_RST  (1U)          /*!< Bit field size in bits for CAN_MCR_SOFT_RST. */

/*! @brief Read current value of the CAN_MCR_SOFT_RST field. */
#define BR_CAN_MCR_SOFT_RST(x) (HW_CAN_MCR(x).B.SOFT_RST)

/*! @brief Format value for bitfield CAN_MCR_SOFT_RST. */
#define BF_CAN_MCR_SOFT_RST(v) ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_SOFT_RST) & BM_CAN_MCR_SOFT_RST)

/*! @brief Set the SOFT_RST field to a new value. */
#define BW_CAN_MCR_SOFT_RST(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_SOFT_RST) | BF_CAN_MCR_SOFT_RST(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field WAK_MSK[26] (RW)
 *
 * This bit enables the Wake Up Interrupt generation.
 *
 * Values:
 * - 1 - Wake Up Interrupt is enabled
 * - 0 - Wake Up Interrupt is disabled
 */
/*@{*/
#define BP_CAN_MCR_WAK_MSK   (26U)         /*!< Bit position for CAN_MCR_WAK_MSK. */
#define BM_CAN_MCR_WAK_MSK   (0x04000000U) /*!< Bit mask for CAN_MCR_WAK_MSK. */
#define BS_CAN_MCR_WAK_MSK   (1U)          /*!< Bit field size in bits for CAN_MCR_WAK_MSK. */

/*! @brief Read current value of the CAN_MCR_WAK_MSK field. */
#define BR_CAN_MCR_WAK_MSK(x) (HW_CAN_MCR(x).B.WAK_MSK)

/*! @brief Format value for bitfield CAN_MCR_WAK_MSK. */
#define BF_CAN_MCR_WAK_MSK(v) ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_WAK_MSK) & BM_CAN_MCR_WAK_MSK)

/*! @brief Set the WAK_MSK field to a new value. */
#define BW_CAN_MCR_WAK_MSK(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_WAK_MSK) | BF_CAN_MCR_WAK_MSK(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field NOT_RDY[27] (RO)
 *
 * This read-only bit indicates that FLEXCAN is either in Disable Mode, Stop
 * Mode or Freeze Mode. It is negated once FLEXCAN has exited these modes.
 *
 * Values:
 * - 1 - FLEXCAN module is either in Disable Mode, Stop Mode or Freeze Mode
 * - 0 - FLEXCAN module is either in Normal Mode, Listen-Only Mode or Loop-Back
 *     Mode
 */
/*@{*/
#define BP_CAN_MCR_NOT_RDY   (27U)         /*!< Bit position for CAN_MCR_NOT_RDY. */
#define BM_CAN_MCR_NOT_RDY   (0x08000000U) /*!< Bit mask for CAN_MCR_NOT_RDY. */
#define BS_CAN_MCR_NOT_RDY   (1U)          /*!< Bit field size in bits for CAN_MCR_NOT_RDY. */

/*! @brief Read current value of the CAN_MCR_NOT_RDY field. */
#define BR_CAN_MCR_NOT_RDY(x) (HW_CAN_MCR(x).B.NOT_RDY)
/*@}*/

/*!
 * @name Register CAN_MCR, field HALT[28] (RW)
 *
 * Assertion of this bit puts the FLEXCAN module into Freeze Mode. The ARM
 * should clear it after initializing the Message Buffers and Control Register. No
 * reception or transmission is performed by FLEXCAN before this bit is cleared.
 * Freeze Mode can not be entered while FLEXCAN is in any of the low power modes.See
 * Freeze ModeThis mode is requested by ARM through the assertion of the HALT
 * bit in the MCR Register or when the MCU is put into Debug Mode . In both cases
 * it is also necessary that the FRZ bit is asserted in the MCR Register and the
 * module is not in any of the low power modes (Disable, Stop). The
 * acknowledgement is obtained through the assertion by the FlexCAN of FRZ_ACK bit in the same
 * register. The ARM must only consider the FlexCAN in Freeze Mode when both
 * request and acknowledgement conditions are satisfied. for more information
 *
 * Values:
 * - 1 - Enters Freeze Mode if the FRZ bit is asserted.
 * - 0 - No Freeze Mode request.
 */
/*@{*/
#define BP_CAN_MCR_HALT      (28U)         /*!< Bit position for CAN_MCR_HALT. */
#define BM_CAN_MCR_HALT      (0x10000000U) /*!< Bit mask for CAN_MCR_HALT. */
#define BS_CAN_MCR_HALT      (1U)          /*!< Bit field size in bits for CAN_MCR_HALT. */

/*! @brief Read current value of the CAN_MCR_HALT field. */
#define BR_CAN_MCR_HALT(x)   (HW_CAN_MCR(x).B.HALT)

/*! @brief Format value for bitfield CAN_MCR_HALT. */
#define BF_CAN_MCR_HALT(v)   ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_HALT) & BM_CAN_MCR_HALT)

/*! @brief Set the HALT field to a new value. */
#define BW_CAN_MCR_HALT(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_HALT) | BF_CAN_MCR_HALT(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field RFEN[29] (RW)
 *
 * This bit controls whether the Rx FIFO feature is enabled or not. When RFEN is
 * set, MBs 0 to 5 cannot be used for normal reception and transmission because
 * the corresponding memory region (0x80-0xDC) is used by the FIFO engine as well
 * as additional MBs (up to 32, depending on CTRL2[RFFN] setting) which are used
 * as Rx FIFO ID Filter Table elements.RFEN also impacts the definition of the
 * minimum number of peripheral clocks per CAN bit as described in (see
 * Arbitration and Matching Timing).This bit can only be written in Freeze mode as it is
 * blocked by hardware in other modes.
 *
 * Values:
 * - 1 - FIFO enabled
 * - 0 - FIFO not enabled
 */
/*@{*/
#define BP_CAN_MCR_RFEN      (29U)         /*!< Bit position for CAN_MCR_RFEN. */
#define BM_CAN_MCR_RFEN      (0x20000000U) /*!< Bit mask for CAN_MCR_RFEN. */
#define BS_CAN_MCR_RFEN      (1U)          /*!< Bit field size in bits for CAN_MCR_RFEN. */

/*! @brief Read current value of the CAN_MCR_RFEN field. */
#define BR_CAN_MCR_RFEN(x)   (HW_CAN_MCR(x).B.RFEN)

/*! @brief Format value for bitfield CAN_MCR_RFEN. */
#define BF_CAN_MCR_RFEN(v)   ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_RFEN) & BM_CAN_MCR_RFEN)

/*! @brief Set the RFEN field to a new value. */
#define BW_CAN_MCR_RFEN(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_RFEN) | BF_CAN_MCR_RFEN(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field FRZ[30] (RW)
 *
 * The FRZ bit specifies the FLEXCAN behavior when the HALT bit in the MCR
 * Register is set or when Debug Mode is requested at ARM level. When FRZ is asserted,
 * FLEXCAN is enabled to enter Freeze Mode. Negation of this bit field causes
 * FLEXCAN to exit from Freeze Mode.
 *
 * Values:
 * - 1 - Enabled to enter Freeze Mode
 * - 0 - Not enabled to enter Freeze Mode
 */
/*@{*/
#define BP_CAN_MCR_FRZ       (30U)         /*!< Bit position for CAN_MCR_FRZ. */
#define BM_CAN_MCR_FRZ       (0x40000000U) /*!< Bit mask for CAN_MCR_FRZ. */
#define BS_CAN_MCR_FRZ       (1U)          /*!< Bit field size in bits for CAN_MCR_FRZ. */

/*! @brief Read current value of the CAN_MCR_FRZ field. */
#define BR_CAN_MCR_FRZ(x)    (HW_CAN_MCR(x).B.FRZ)

/*! @brief Format value for bitfield CAN_MCR_FRZ. */
#define BF_CAN_MCR_FRZ(v)    ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_FRZ) & BM_CAN_MCR_FRZ)

/*! @brief Set the FRZ field to a new value. */
#define BW_CAN_MCR_FRZ(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_FRZ) | BF_CAN_MCR_FRZ(v)))
/*@}*/

/*!
 * @name Register CAN_MCR, field MDIS[31] (RW)
 *
 * This bit controls whether FLEXCAN is enabled or not. When disabled, FLEXCAN
 * shuts down the clocks to the CAN Protocol Interface and Message Buffer
 * Management sub-modules. This is the only bit in MCR not affected by soft reset. See
 * Module Disable ModeThis low power mode is normally used to temporarily disable a
 * complete FlexCAN block, with no power consumption. It is requested by the ARM
 * through the assertion of the MDIS bit in the MCR Register and the
 * acknowledgement is obtained through the assertion by the FlexCAN of the LPM_ACK bit in
 * the same register. The ARM must only consider the FlexCAN in Disable Mode when
 * both request and acknowledgement conditions are satisfied. for more information.
 *
 * Values:
 * - 1 - Disable the FLEXCAN module
 * - 0 - Enable the FLEXCAN module
 */
/*@{*/
#define BP_CAN_MCR_MDIS      (31U)         /*!< Bit position for CAN_MCR_MDIS. */
#define BM_CAN_MCR_MDIS      (0x80000000U) /*!< Bit mask for CAN_MCR_MDIS. */
#define BS_CAN_MCR_MDIS      (1U)          /*!< Bit field size in bits for CAN_MCR_MDIS. */

/*! @brief Read current value of the CAN_MCR_MDIS field. */
#define BR_CAN_MCR_MDIS(x)   (HW_CAN_MCR(x).B.MDIS)

/*! @brief Format value for bitfield CAN_MCR_MDIS. */
#define BF_CAN_MCR_MDIS(v)   ((uint32_t)((uint32_t)(v) << BP_CAN_MCR_MDIS) & BM_CAN_MCR_MDIS)

/*! @brief Set the MDIS field to a new value. */
#define BW_CAN_MCR_MDIS(x, v) (HW_CAN_MCR_WR(x, (HW_CAN_MCR_RD(x) & ~BM_CAN_MCR_MDIS) | BF_CAN_MCR_MDIS(v)))
/*@}*/

/*******************************************************************************
 * HW_CAN_CTRL1 - Control 1 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_CTRL1 - Control 1 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is defined for specific FLEXCAN control features related to the
 * CAN bus, such as bit-rate, programmable sampling point within an Rx bit, Loop
 * Back Mode, Listen Only Mode, Bus Off recovery behavior and interrupt enabling
 * (Bus-Off, Error, Warning). It also determines the Division Factor for the
 * clock prescaler.
 */
typedef union _hw_can_ctrl1
{
    uint32_t U;
    struct _hw_can_ctrl1_bitfields
    {
        uint32_t PROP_SEG : 3;         /*!< [2:0]  */
        uint32_t LOM : 1;              /*!< [3]  */
        uint32_t LBUF : 1;             /*!< [4]  */
        uint32_t TSYN : 1;             /*!< [5]  */
        uint32_t BOFF_REC : 1;         /*!< [6]  */
        uint32_t SMP : 1;              /*!< [7]  */
        uint32_t RESERVED0 : 2;        /*!< [9:8]  */
        uint32_t RWRN_MSK : 1;         /*!< [10]  */
        uint32_t TWRN_MSK : 1;         /*!< [11]  */
        uint32_t LPB : 1;              /*!< [12]  */
        uint32_t RESERVED1 : 1;        /*!< [13]  */
        uint32_t ERR_MSK : 1;          /*!< [14]  */
        uint32_t BOFF_MSK : 1;         /*!< [15]  */
        uint32_t PSEG2 : 3;            /*!< [18:16]  */
        uint32_t PSEG1 : 3;            /*!< [21:19]  */
        uint32_t RJW : 2;              /*!< [23:22]  */
        uint32_t PRESDIV : 8;          /*!< [31:24]  */
    } B;
} hw_can_ctrl1_t;

/*!
 * @name Constants and macros for entire CAN_CTRL1 register
 */
/*@{*/
#define HW_CAN_CTRL1_ADDR(x)     ((uintptr_t)(x) + 0x4U)

#define HW_CAN_CTRL1(x)          (*(__IO hw_can_ctrl1_t *) HW_CAN_CTRL1_ADDR(x))
#define HW_CAN_CTRL1_RD(x)       (HW_CAN_CTRL1(x).U)
#define HW_CAN_CTRL1_WR(x, v)    (HW_CAN_CTRL1(x).U = (v))
#define HW_CAN_CTRL1_SET(x, v)   (HW_CAN_CTRL1_WR(x, HW_CAN_CTRL1_RD(x) |  (v)))
#define HW_CAN_CTRL1_CLR(x, v)   (HW_CAN_CTRL1_WR(x, HW_CAN_CTRL1_RD(x) & ~(v)))
#define HW_CAN_CTRL1_TOG(x, v)   (HW_CAN_CTRL1_WR(x, HW_CAN_CTRL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_CTRL1 bitfields
 */

/*!
 * @name Register CAN_CTRL1, field PROP_SEG[2:0] (RW)
 *
 * This 3-bit field defines the length of the Propagation Segment in the bit
 * time. The valid programmable values are 0-7. This field can only be written in
 * Freeze mode as it is blocked by hardware in other modes Propagation Segment Time
 * = (PROPSEG + 1) * Time-Quanta. Time-Quantum = one Sclock period.
 */
/*@{*/
#define BP_CAN_CTRL1_PROP_SEG (0U)         /*!< Bit position for CAN_CTRL1_PROP_SEG. */
#define BM_CAN_CTRL1_PROP_SEG (0x00000007U) /*!< Bit mask for CAN_CTRL1_PROP_SEG. */
#define BS_CAN_CTRL1_PROP_SEG (3U)         /*!< Bit field size in bits for CAN_CTRL1_PROP_SEG. */

/*! @brief Read current value of the CAN_CTRL1_PROP_SEG field. */
#define BR_CAN_CTRL1_PROP_SEG(x) (HW_CAN_CTRL1(x).B.PROP_SEG)

/*! @brief Format value for bitfield CAN_CTRL1_PROP_SEG. */
#define BF_CAN_CTRL1_PROP_SEG(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_PROP_SEG) & BM_CAN_CTRL1_PROP_SEG)

/*! @brief Set the PROP_SEG field to a new value. */
#define BW_CAN_CTRL1_PROP_SEG(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_PROP_SEG) | BF_CAN_CTRL1_PROP_SEG(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field LOM[3] (RW)
 *
 * This bit configures FLEXCAN to operate in Listen Only Mode. In this mode,
 * transmission is disabled, all error counters are frozen and the module operates
 * in a CAN Error Passive mode. Only messages acknowledged by another CAN station
 * will be received. If FLEXCAN detects a message that has not been acknowledged,
 * it will flag a BIT0 error (without changing the REC), as if it was trying to
 * acknowledge the message. Listen-Only Mode acknowledgement can be obtained by
 * the state of ESR1[FLT_CONF] field which is Passive Error when Listen-Only Mode
 * is entered. There can be some delay between the Listen-Only Mode request and
 * acknowledge. This bit can only be written in Freeze mode as it is blocked by
 * hardware in other modes.
 *
 * Values:
 * - 1 - FLEXCAN module operates in Listen Only Mode
 * - 0 - Listen Only Mode is deactivated
 */
/*@{*/
#define BP_CAN_CTRL1_LOM     (3U)          /*!< Bit position for CAN_CTRL1_LOM. */
#define BM_CAN_CTRL1_LOM     (0x00000008U) /*!< Bit mask for CAN_CTRL1_LOM. */
#define BS_CAN_CTRL1_LOM     (1U)          /*!< Bit field size in bits for CAN_CTRL1_LOM. */

/*! @brief Read current value of the CAN_CTRL1_LOM field. */
#define BR_CAN_CTRL1_LOM(x)  (HW_CAN_CTRL1(x).B.LOM)

/*! @brief Format value for bitfield CAN_CTRL1_LOM. */
#define BF_CAN_CTRL1_LOM(v)  ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_LOM) & BM_CAN_CTRL1_LOM)

/*! @brief Set the LOM field to a new value. */
#define BW_CAN_CTRL1_LOM(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_LOM) | BF_CAN_CTRL1_LOM(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field LBUF[4] (RW)
 *
 * This bit defines the ordering mechanism for Message Buffer transmission. When
 * asserted, the LPRIO_EN bit does not affect the priority arbitration.This bit
 * can only be written in Freeze mode as it is blocked by hardware in other modes.
 *
 * Values:
 * - 1 - Lowest number buffer is transmitted first
 * - 0 - Buffer with highest priority is transmitted first
 */
/*@{*/
#define BP_CAN_CTRL1_LBUF    (4U)          /*!< Bit position for CAN_CTRL1_LBUF. */
#define BM_CAN_CTRL1_LBUF    (0x00000010U) /*!< Bit mask for CAN_CTRL1_LBUF. */
#define BS_CAN_CTRL1_LBUF    (1U)          /*!< Bit field size in bits for CAN_CTRL1_LBUF. */

/*! @brief Read current value of the CAN_CTRL1_LBUF field. */
#define BR_CAN_CTRL1_LBUF(x) (HW_CAN_CTRL1(x).B.LBUF)

/*! @brief Format value for bitfield CAN_CTRL1_LBUF. */
#define BF_CAN_CTRL1_LBUF(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_LBUF) & BM_CAN_CTRL1_LBUF)

/*! @brief Set the LBUF field to a new value. */
#define BW_CAN_CTRL1_LBUF(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_LBUF) | BF_CAN_CTRL1_LBUF(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field TSYN[5] (RW)
 *
 * This bit enables a mechanism that resets the free-running timer each time a
 * message is received in Message Buffer 0. This feature provides means to
 * synchronize multiple FLEXCAN stations with a special "SYNC" message (i.e., global
 * network time). If the RFEN bit in MCR is set (FIFO enabled), the first available
 * Mailbox, according to CTRL2[RFFN] setting, is used for timer synchronization
 * instead of MB0.This bit can only be written in Freeze mode as it is blocked by
 * hardware in other modes.
 *
 * Values:
 * - 1 - Timer Sync feature enabled
 * - 0 - Timer Sync feature disabled
 */
/*@{*/
#define BP_CAN_CTRL1_TSYN    (5U)          /*!< Bit position for CAN_CTRL1_TSYN. */
#define BM_CAN_CTRL1_TSYN    (0x00000020U) /*!< Bit mask for CAN_CTRL1_TSYN. */
#define BS_CAN_CTRL1_TSYN    (1U)          /*!< Bit field size in bits for CAN_CTRL1_TSYN. */

/*! @brief Read current value of the CAN_CTRL1_TSYN field. */
#define BR_CAN_CTRL1_TSYN(x) (HW_CAN_CTRL1(x).B.TSYN)

/*! @brief Format value for bitfield CAN_CTRL1_TSYN. */
#define BF_CAN_CTRL1_TSYN(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_TSYN) & BM_CAN_CTRL1_TSYN)

/*! @brief Set the TSYN field to a new value. */
#define BW_CAN_CTRL1_TSYN(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_TSYN) | BF_CAN_CTRL1_TSYN(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field BOFF_REC[6] (RW)
 *
 * This bit defines how FLEXCAN recovers from Bus Off state. If this bit is
 * negated, automatic recovering from Bus Off state occurs according to the CAN
 * Specification 2.0B. If the bit is asserted, automatic recovering from Bus Off is
 * disabled and the module remains in Bus Off state until the bit is negated by the
 * user. If the negation occurs before 128 sequences of 11 recessive bits are
 * detected on the CAN bus, then Bus Off recovery happens as if the BOFF_REC bit
 * had never been asserted. If the negation occurs after 128 sequences of 11
 * recessive bits occurred, then FLEXCAN will re-synchronize to the bus by waiting for
 * 11 recessive bits before joining the bus. After negation, the BOFF_REC bit can
 * be re-asserted again during Bus Off, but it will only be effective the next
 * time the module enters Bus Off. If BOFF_REC was negated when the module entered
 * Bus Off, asserting it during Bus Off will not be effective for the current
 * Bus Off recovery.
 *
 * Values:
 * - 1 - Automatic recovering from Bus Off state disabled
 * - 0 - Automatic recovering from Bus Off state enabled, according to CAN Spec
 *     2.0 part B
 */
/*@{*/
#define BP_CAN_CTRL1_BOFF_REC (6U)         /*!< Bit position for CAN_CTRL1_BOFF_REC. */
#define BM_CAN_CTRL1_BOFF_REC (0x00000040U) /*!< Bit mask for CAN_CTRL1_BOFF_REC. */
#define BS_CAN_CTRL1_BOFF_REC (1U)         /*!< Bit field size in bits for CAN_CTRL1_BOFF_REC. */

/*! @brief Read current value of the CAN_CTRL1_BOFF_REC field. */
#define BR_CAN_CTRL1_BOFF_REC(x) (HW_CAN_CTRL1(x).B.BOFF_REC)

/*! @brief Format value for bitfield CAN_CTRL1_BOFF_REC. */
#define BF_CAN_CTRL1_BOFF_REC(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_BOFF_REC) & BM_CAN_CTRL1_BOFF_REC)

/*! @brief Set the BOFF_REC field to a new value. */
#define BW_CAN_CTRL1_BOFF_REC(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_BOFF_REC) | BF_CAN_CTRL1_BOFF_REC(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field SMP[7] (RW)
 *
 * This bit defines the sampling mode of CAN bits at the FLEXCAN_RX. This bit
 * can only be written in Freeze mode as it is blocked by hardware in other modes.
 *
 * Values:
 * - 1 - Three samples are used to determine the value of the received bit: the
 *     regular one (sample point) and 2 preceding samples, a majority rule is used
 * - 0 - Just one sample is used to determine the bit value
 */
/*@{*/
#define BP_CAN_CTRL1_SMP     (7U)          /*!< Bit position for CAN_CTRL1_SMP. */
#define BM_CAN_CTRL1_SMP     (0x00000080U) /*!< Bit mask for CAN_CTRL1_SMP. */
#define BS_CAN_CTRL1_SMP     (1U)          /*!< Bit field size in bits for CAN_CTRL1_SMP. */

/*! @brief Read current value of the CAN_CTRL1_SMP field. */
#define BR_CAN_CTRL1_SMP(x)  (HW_CAN_CTRL1(x).B.SMP)

/*! @brief Format value for bitfield CAN_CTRL1_SMP. */
#define BF_CAN_CTRL1_SMP(v)  ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_SMP) & BM_CAN_CTRL1_SMP)

/*! @brief Set the SMP field to a new value. */
#define BW_CAN_CTRL1_SMP(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_SMP) | BF_CAN_CTRL1_SMP(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field RWRN_MSK[10] (RW)
 *
 * This bit provides a mask for the Rx Warning Interrupt associated with the
 * RWRN_INT flag in the Error and Status Register. This bit is read as zero when
 * MCR[WRN_EN] bit is negated. This bit can only be written if MCR[WRN_EN] bit is
 * asserted.
 *
 * Values:
 * - 1 - Rx Warning Interrupt enabled
 * - 0 - Rx Warning Interrupt disabled
 */
/*@{*/
#define BP_CAN_CTRL1_RWRN_MSK (10U)        /*!< Bit position for CAN_CTRL1_RWRN_MSK. */
#define BM_CAN_CTRL1_RWRN_MSK (0x00000400U) /*!< Bit mask for CAN_CTRL1_RWRN_MSK. */
#define BS_CAN_CTRL1_RWRN_MSK (1U)         /*!< Bit field size in bits for CAN_CTRL1_RWRN_MSK. */

/*! @brief Read current value of the CAN_CTRL1_RWRN_MSK field. */
#define BR_CAN_CTRL1_RWRN_MSK(x) (HW_CAN_CTRL1(x).B.RWRN_MSK)

/*! @brief Format value for bitfield CAN_CTRL1_RWRN_MSK. */
#define BF_CAN_CTRL1_RWRN_MSK(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_RWRN_MSK) & BM_CAN_CTRL1_RWRN_MSK)

/*! @brief Set the RWRN_MSK field to a new value. */
#define BW_CAN_CTRL1_RWRN_MSK(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_RWRN_MSK) | BF_CAN_CTRL1_RWRN_MSK(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field TWRN_MSK[11] (RW)
 *
 * This bit provides a mask for the Tx Warning Interrupt associated with the
 * TWRN_INT flag in the Error and Status Register. This bit is read as zero when
 * MCR[WRN_EN] bit is negated. This bit can only be written if MCR[WRN_EN] bit is
 * asserted.
 *
 * Values:
 * - 1 - Tx Warning Interrupt enabled
 * - 0 - Tx Warning Interrupt disabled
 */
/*@{*/
#define BP_CAN_CTRL1_TWRN_MSK (11U)        /*!< Bit position for CAN_CTRL1_TWRN_MSK. */
#define BM_CAN_CTRL1_TWRN_MSK (0x00000800U) /*!< Bit mask for CAN_CTRL1_TWRN_MSK. */
#define BS_CAN_CTRL1_TWRN_MSK (1U)         /*!< Bit field size in bits for CAN_CTRL1_TWRN_MSK. */

/*! @brief Read current value of the CAN_CTRL1_TWRN_MSK field. */
#define BR_CAN_CTRL1_TWRN_MSK(x) (HW_CAN_CTRL1(x).B.TWRN_MSK)

/*! @brief Format value for bitfield CAN_CTRL1_TWRN_MSK. */
#define BF_CAN_CTRL1_TWRN_MSK(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_TWRN_MSK) & BM_CAN_CTRL1_TWRN_MSK)

/*! @brief Set the TWRN_MSK field to a new value. */
#define BW_CAN_CTRL1_TWRN_MSK(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_TWRN_MSK) | BF_CAN_CTRL1_TWRN_MSK(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field LPB[12] (RW)
 *
 * This bit configures FlexCAN to operate in Loop-Back Mode. In this mode,
 * FlexCAN performs an internal loop back that can be used for self test operation.
 * The bit stream output of the transmitter is fed back internally to the receiver
 * input. The FLEXCAN_RX input pin is ignored and the FLEXCAN_TX output goes to
 * the recessive state (logic '1'). FlexCAN behaves as it normally does when
 * transmitting, and treats its own transmitted message as a message received from a
 * remote node. In this mode, FlexCAN ignores the bit sent during the ACK slot in
 * the CAN frame acknowledge field, generating an internal acknowledge bit to
 * ensure proper reception of its own message. Both transmit and receive interrupts
 * are generated. This bit can only be written in Freeze mode as it is blocked by
 * hardware in other modes.
 *
 * Values:
 * - 1 - Loop Back enabled
 * - 0 - Loop Back disabled
 */
/*@{*/
#define BP_CAN_CTRL1_LPB     (12U)         /*!< Bit position for CAN_CTRL1_LPB. */
#define BM_CAN_CTRL1_LPB     (0x00001000U) /*!< Bit mask for CAN_CTRL1_LPB. */
#define BS_CAN_CTRL1_LPB     (1U)          /*!< Bit field size in bits for CAN_CTRL1_LPB. */

/*! @brief Read current value of the CAN_CTRL1_LPB field. */
#define BR_CAN_CTRL1_LPB(x)  (HW_CAN_CTRL1(x).B.LPB)

/*! @brief Format value for bitfield CAN_CTRL1_LPB. */
#define BF_CAN_CTRL1_LPB(v)  ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_LPB) & BM_CAN_CTRL1_LPB)

/*! @brief Set the LPB field to a new value. */
#define BW_CAN_CTRL1_LPB(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_LPB) | BF_CAN_CTRL1_LPB(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field ERR_MSK[14] (RW)
 *
 * This bit provides a mask for the Error Interrupt.
 *
 * Values:
 * - 1 - Error interrupt enabled
 * - 0 - Error interrupt disabled
 */
/*@{*/
#define BP_CAN_CTRL1_ERR_MSK (14U)         /*!< Bit position for CAN_CTRL1_ERR_MSK. */
#define BM_CAN_CTRL1_ERR_MSK (0x00004000U) /*!< Bit mask for CAN_CTRL1_ERR_MSK. */
#define BS_CAN_CTRL1_ERR_MSK (1U)          /*!< Bit field size in bits for CAN_CTRL1_ERR_MSK. */

/*! @brief Read current value of the CAN_CTRL1_ERR_MSK field. */
#define BR_CAN_CTRL1_ERR_MSK(x) (HW_CAN_CTRL1(x).B.ERR_MSK)

/*! @brief Format value for bitfield CAN_CTRL1_ERR_MSK. */
#define BF_CAN_CTRL1_ERR_MSK(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_ERR_MSK) & BM_CAN_CTRL1_ERR_MSK)

/*! @brief Set the ERR_MSK field to a new value. */
#define BW_CAN_CTRL1_ERR_MSK(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_ERR_MSK) | BF_CAN_CTRL1_ERR_MSK(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field BOFF_MSK[15] (RW)
 *
 * This bit provides a mask for the Bus Off Interrupt.
 *
 * Values:
 * - 1 - Bus Off interrupt enabled
 * - 0 - Bus Off interrupt disabled
 */
/*@{*/
#define BP_CAN_CTRL1_BOFF_MSK (15U)        /*!< Bit position for CAN_CTRL1_BOFF_MSK. */
#define BM_CAN_CTRL1_BOFF_MSK (0x00008000U) /*!< Bit mask for CAN_CTRL1_BOFF_MSK. */
#define BS_CAN_CTRL1_BOFF_MSK (1U)         /*!< Bit field size in bits for CAN_CTRL1_BOFF_MSK. */

/*! @brief Read current value of the CAN_CTRL1_BOFF_MSK field. */
#define BR_CAN_CTRL1_BOFF_MSK(x) (HW_CAN_CTRL1(x).B.BOFF_MSK)

/*! @brief Format value for bitfield CAN_CTRL1_BOFF_MSK. */
#define BF_CAN_CTRL1_BOFF_MSK(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_BOFF_MSK) & BM_CAN_CTRL1_BOFF_MSK)

/*! @brief Set the BOFF_MSK field to a new value. */
#define BW_CAN_CTRL1_BOFF_MSK(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_BOFF_MSK) | BF_CAN_CTRL1_BOFF_MSK(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field PSEG2[18:16] (RW)
 *
 * This 3-bit field defines the length of Phase Buffer Segment 2 in the bit
 * time. The valid programmable values are 1-7. This field can only be written in
 * Freeze mode as it is blocked by hardware in other modes Phase Buffer Segment 2 =
 * (PSEG2 + 1) x Time-Quanta.
 */
/*@{*/
#define BP_CAN_CTRL1_PSEG2   (16U)         /*!< Bit position for CAN_CTRL1_PSEG2. */
#define BM_CAN_CTRL1_PSEG2   (0x00070000U) /*!< Bit mask for CAN_CTRL1_PSEG2. */
#define BS_CAN_CTRL1_PSEG2   (3U)          /*!< Bit field size in bits for CAN_CTRL1_PSEG2. */

/*! @brief Read current value of the CAN_CTRL1_PSEG2 field. */
#define BR_CAN_CTRL1_PSEG2(x) (HW_CAN_CTRL1(x).B.PSEG2)

/*! @brief Format value for bitfield CAN_CTRL1_PSEG2. */
#define BF_CAN_CTRL1_PSEG2(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_PSEG2) & BM_CAN_CTRL1_PSEG2)

/*! @brief Set the PSEG2 field to a new value. */
#define BW_CAN_CTRL1_PSEG2(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_PSEG2) | BF_CAN_CTRL1_PSEG2(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field PSEG1[21:19] (RW)
 *
 * This 3-bit field defines the length of Phase Buffer Segment 1 in the bit
 * time. The valid programmable values are 0-7. This field can only be written in
 * Freeze mode as it is blocked by hardware in other modes Phase Buffer Segment 1 =
 * (PSEG1 + 1) x Time-Quanta.
 */
/*@{*/
#define BP_CAN_CTRL1_PSEG1   (19U)         /*!< Bit position for CAN_CTRL1_PSEG1. */
#define BM_CAN_CTRL1_PSEG1   (0x00380000U) /*!< Bit mask for CAN_CTRL1_PSEG1. */
#define BS_CAN_CTRL1_PSEG1   (3U)          /*!< Bit field size in bits for CAN_CTRL1_PSEG1. */

/*! @brief Read current value of the CAN_CTRL1_PSEG1 field. */
#define BR_CAN_CTRL1_PSEG1(x) (HW_CAN_CTRL1(x).B.PSEG1)

/*! @brief Format value for bitfield CAN_CTRL1_PSEG1. */
#define BF_CAN_CTRL1_PSEG1(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_PSEG1) & BM_CAN_CTRL1_PSEG1)

/*! @brief Set the PSEG1 field to a new value. */
#define BW_CAN_CTRL1_PSEG1(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_PSEG1) | BF_CAN_CTRL1_PSEG1(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field RJW[23:22] (RW)
 *
 * This 2-bit field defines the maximum number of time quanta One time quantum
 * is equal to the Sclock period. that a bit time can be changed by one
 * re-synchronization. The valid programmable values are 0-3. This field can only be
 * written in Freeze mode as it is blocked by hardware in other modes Resync Jump Width
 * = RJW + 1.
 */
/*@{*/
#define BP_CAN_CTRL1_RJW     (22U)         /*!< Bit position for CAN_CTRL1_RJW. */
#define BM_CAN_CTRL1_RJW     (0x00C00000U) /*!< Bit mask for CAN_CTRL1_RJW. */
#define BS_CAN_CTRL1_RJW     (2U)          /*!< Bit field size in bits for CAN_CTRL1_RJW. */

/*! @brief Read current value of the CAN_CTRL1_RJW field. */
#define BR_CAN_CTRL1_RJW(x)  (HW_CAN_CTRL1(x).B.RJW)

/*! @brief Format value for bitfield CAN_CTRL1_RJW. */
#define BF_CAN_CTRL1_RJW(v)  ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_RJW) & BM_CAN_CTRL1_RJW)

/*! @brief Set the RJW field to a new value. */
#define BW_CAN_CTRL1_RJW(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_RJW) | BF_CAN_CTRL1_RJW(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL1, field PRESDIV[31:24] (RW)
 *
 * This 8-bit field defines the ratio between the PE clock frequency and the
 * Serial Clock (Sclock) frequency. The Sclock period defines the time quantum of
 * the CAN protocol. For the reset value, the Sclock frequency is equal to the PE
 * clock frequency. The Maximum value of this register is 0xFF, that gives a
 * minimum Sclock frequency equal to the PE clock frequency divided by 256.For more
 * information refer to Protocol Timing. This field can only be written in Freeze
 * mode as it is blocked by hardware in other modes. Sclock frequency = CPI clock
 * frequency / (PRESDIV+1)
 */
/*@{*/
#define BP_CAN_CTRL1_PRESDIV (24U)         /*!< Bit position for CAN_CTRL1_PRESDIV. */
#define BM_CAN_CTRL1_PRESDIV (0xFF000000U) /*!< Bit mask for CAN_CTRL1_PRESDIV. */
#define BS_CAN_CTRL1_PRESDIV (8U)          /*!< Bit field size in bits for CAN_CTRL1_PRESDIV. */

/*! @brief Read current value of the CAN_CTRL1_PRESDIV field. */
#define BR_CAN_CTRL1_PRESDIV(x) (HW_CAN_CTRL1(x).B.PRESDIV)

/*! @brief Format value for bitfield CAN_CTRL1_PRESDIV. */
#define BF_CAN_CTRL1_PRESDIV(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL1_PRESDIV) & BM_CAN_CTRL1_PRESDIV)

/*! @brief Set the PRESDIV field to a new value. */
#define BW_CAN_CTRL1_PRESDIV(x, v) (HW_CAN_CTRL1_WR(x, (HW_CAN_CTRL1_RD(x) & ~BM_CAN_CTRL1_PRESDIV) | BF_CAN_CTRL1_PRESDIV(v)))
/*@}*/

/*******************************************************************************
 * HW_CAN_TIMER - Free Running Timer Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_TIMER - Free Running Timer Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register represents a 16-bit free running counter that can be read and
 * written by the ARM. The timer starts from $0000 after Reset, counts linearly to
 * $FFFF, and wraps around. The timer is clocked by the FLEXCAN bit-clock (which
 * defines the baud rate on the CAN bus). During a message
 * transmission/reception, it increments by one for each bit that is received or transmitted. When
 * there is no message on the bus, it counts using the previously programmed baud
 * rate. During Freeze Mode, disable, and stop mode, the timer is not incremented.
 * The timer value is captured at the beginning of the identifier field of any
 * frame on the CAN bus. This captured value is written into the Time Stamp entry
 * in a message buffer after a successful reception or transmission of a message.
 * If bit CTRL1[TSYN] is asserted the Timer is reset whenever a message is
 * received in the first available Mailbox, according to CTRL2[RFFN] setting. ARM can
 * write to this register anytime. However, if the write occurs at the same time
 * that the Timer is being reset by a reception in the first Mailbox, then the
 * write value is discarded. Reading this register affects the Mailbox Unlocking
 * procedure. For additional details, refer to Message Buffer Lock MechanismBesides
 * MB inactivation, FlexCAN has another data coherence mechanism for the receive
 * process. When ARM reads the Control and Status word of an Rx MB with codes
 * FULL or OVERRUN, FlexCAN assumes that ARM wants to read the whole MB in an atomic
 * operation, and thus it sets an internal lock flag for that MB. The lock is
 * released when ARM reads the Free Running Timer (global unlock operation), or
 * when it reads the Control and Status word of another MB regardless of its code or
 * when ARM writes into C/S word from locked MB. The MB locking is done to
 * prevent a new frame to be written into the MB while ARM is reading it. .
 */
typedef union _hw_can_timer
{
    uint32_t U;
    struct _hw_can_timer_bitfields
    {
        uint32_t TIMER : 16;           /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_can_timer_t;

/*!
 * @name Constants and macros for entire CAN_TIMER register
 */
/*@{*/
#define HW_CAN_TIMER_ADDR(x)     ((uintptr_t)(x) + 0x8U)

#define HW_CAN_TIMER(x)          (*(__IO hw_can_timer_t *) HW_CAN_TIMER_ADDR(x))
#define HW_CAN_TIMER_RD(x)       (HW_CAN_TIMER(x).U)
#define HW_CAN_TIMER_WR(x, v)    (HW_CAN_TIMER(x).U = (v))
#define HW_CAN_TIMER_SET(x, v)   (HW_CAN_TIMER_WR(x, HW_CAN_TIMER_RD(x) |  (v)))
#define HW_CAN_TIMER_CLR(x, v)   (HW_CAN_TIMER_WR(x, HW_CAN_TIMER_RD(x) & ~(v)))
#define HW_CAN_TIMER_TOG(x, v)   (HW_CAN_TIMER_WR(x, HW_CAN_TIMER_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_TIMER bitfields
 */

/*!
 * @name Register CAN_TIMER, field TIMER[15:0] (RW)
 *
 * TIMER
 */
/*@{*/
#define BP_CAN_TIMER_TIMER   (0U)          /*!< Bit position for CAN_TIMER_TIMER. */
#define BM_CAN_TIMER_TIMER   (0x0000FFFFU) /*!< Bit mask for CAN_TIMER_TIMER. */
#define BS_CAN_TIMER_TIMER   (16U)         /*!< Bit field size in bits for CAN_TIMER_TIMER. */

/*! @brief Read current value of the CAN_TIMER_TIMER field. */
#define BR_CAN_TIMER_TIMER(x) (HW_CAN_TIMER(x).B.TIMER)

/*! @brief Format value for bitfield CAN_TIMER_TIMER. */
#define BF_CAN_TIMER_TIMER(v) ((uint32_t)((uint32_t)(v) << BP_CAN_TIMER_TIMER) & BM_CAN_TIMER_TIMER)

/*! @brief Set the TIMER field to a new value. */
#define BW_CAN_TIMER_TIMER(x, v) (HW_CAN_TIMER_WR(x, (HW_CAN_TIMER_RD(x) & ~BM_CAN_TIMER_TIMER) | BF_CAN_TIMER_TIMER(v)))
/*@}*/

/*******************************************************************************
 * HW_CAN_RXMGMASK - Rx Mailboxes Global Mask Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_RXMGMASK - Rx Mailboxes Global Mask Register (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * RXMGMASK is provided for legacy support. Asserting the MCR[IRMQ] bit causes
 * the RXMGMASK Register to have no effect on the module operation. RXMGMASK is
 * used to mask the filter fields of all Rx MBs, excluding MBs 14-15, which have
 * individual mask registers. This register can only be written in Freeze mode as
 * it is blocked by hardware in other modes. Rx Mailboxes Global Mask usage
 * SMB[RTR]RTR bit of the Incoming Frame. It is saved into an auxiliary MB called Rx
 * Serial Message Buffer (Rx SMB). CTRL2[RRS] CTRL2[EACEN] Mailbox filter fields
 * MB[RTR] MB[IDE] MB[ID] reserved 0 - 0 - NoteIf CTRL2[EACEN] bit is negated the
 * RTR bit of Mailbox is never compared with the RTR bit of the Incoming Frame (Rx
 * SMB[RTR]). - NoteIf CTRL2[EACEN] bit is negated the IDE bit of Mailbox is
 * always compared with the IDE bit of the Incoming Frame (Rx SMB[IDE]). MG[28:0]
 * MG[31:29] 0 - 1 MG[31] MG[30] MG[28:0] MG[29] 1 0 - - - - MG[31:0] 1 1 0 - -
 * MG[28:0] MG[31:29] 1 1 1 MG[31] MG[30] MG[28:0] MG[29]
 */
typedef union _hw_can_rxmgmask
{
    uint32_t U;
    struct _hw_can_rxmgmask_bitfields
    {
        uint32_t MG31_MG0 : 32;        /*!< [31:0]  */
    } B;
} hw_can_rxmgmask_t;

/*!
 * @name Constants and macros for entire CAN_RXMGMASK register
 */
/*@{*/
#define HW_CAN_RXMGMASK_ADDR(x)  ((uintptr_t)(x) + 0x10U)

#define HW_CAN_RXMGMASK(x)       (*(__IO hw_can_rxmgmask_t *) HW_CAN_RXMGMASK_ADDR(x))
#define HW_CAN_RXMGMASK_RD(x)    (HW_CAN_RXMGMASK(x).U)
#define HW_CAN_RXMGMASK_WR(x, v) (HW_CAN_RXMGMASK(x).U = (v))
#define HW_CAN_RXMGMASK_SET(x, v) (HW_CAN_RXMGMASK_WR(x, HW_CAN_RXMGMASK_RD(x) |  (v)))
#define HW_CAN_RXMGMASK_CLR(x, v) (HW_CAN_RXMGMASK_WR(x, HW_CAN_RXMGMASK_RD(x) & ~(v)))
#define HW_CAN_RXMGMASK_TOG(x, v) (HW_CAN_RXMGMASK_WR(x, HW_CAN_RXMGMASK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_RXMGMASK bitfields
 */

/*!
 * @name Register CAN_RXMGMASK, field MG31_MG0[31:0] (RW)
 *
 * These bits mask the Mailbox filter bits as shown in the figure above. Note
 * that the alignment with the ID word of the Mailbox is not perfect as the two
 * most significant MG bits affect the fields RTR and IDE which are located in the
 * Control and Status word of the Mailbox. RXMGMASKRx Mailboxes Global Mask
 * Register shows in detail which MG bits mask each Mailbox filter field.
 *
 * Values:
 * - 1 - The corresponding bit in the filter is checked against the one received
 * - 0 - the corresponding bit in the filter is "don't care"
 */
/*@{*/
#define BP_CAN_RXMGMASK_MG31_MG0 (0U)      /*!< Bit position for CAN_RXMGMASK_MG31_MG0. */
#define BM_CAN_RXMGMASK_MG31_MG0 (0xFFFFFFFFU) /*!< Bit mask for CAN_RXMGMASK_MG31_MG0. */
#define BS_CAN_RXMGMASK_MG31_MG0 (32U)     /*!< Bit field size in bits for CAN_RXMGMASK_MG31_MG0. */

/*! @brief Read current value of the CAN_RXMGMASK_MG31_MG0 field. */
#define BR_CAN_RXMGMASK_MG31_MG0(x) (HW_CAN_RXMGMASK(x).U)

/*! @brief Format value for bitfield CAN_RXMGMASK_MG31_MG0. */
#define BF_CAN_RXMGMASK_MG31_MG0(v) ((uint32_t)((uint32_t)(v) << BP_CAN_RXMGMASK_MG31_MG0) & BM_CAN_RXMGMASK_MG31_MG0)

/*! @brief Set the MG31_MG0 field to a new value. */
#define BW_CAN_RXMGMASK_MG31_MG0(x, v) (HW_CAN_RXMGMASK_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_CAN_RX14MASK - Rx Buffer 14 Mask Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_RX14MASK - Rx Buffer 14 Mask Register (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * RX14MASK is provided for legacy support, asserting the MCR[IRMQ] bit causes
 * the RX14MASK to have no effect on the module operation. RX14MASK is used to
 * mask the filter fields of Message Buffer 14. This register can only be programmed
 * while the module is in Freeze Mode as it is blocked by hardware in other
 * modes.
 */
typedef union _hw_can_rx14mask
{
    uint32_t U;
    struct _hw_can_rx14mask_bitfields
    {
        uint32_t RX14M31_RX14M0 : 32;  /*!< [31:0]  */
    } B;
} hw_can_rx14mask_t;

/*!
 * @name Constants and macros for entire CAN_RX14MASK register
 */
/*@{*/
#define HW_CAN_RX14MASK_ADDR(x)  ((uintptr_t)(x) + 0x14U)

#define HW_CAN_RX14MASK(x)       (*(__IO hw_can_rx14mask_t *) HW_CAN_RX14MASK_ADDR(x))
#define HW_CAN_RX14MASK_RD(x)    (HW_CAN_RX14MASK(x).U)
#define HW_CAN_RX14MASK_WR(x, v) (HW_CAN_RX14MASK(x).U = (v))
#define HW_CAN_RX14MASK_SET(x, v) (HW_CAN_RX14MASK_WR(x, HW_CAN_RX14MASK_RD(x) |  (v)))
#define HW_CAN_RX14MASK_CLR(x, v) (HW_CAN_RX14MASK_WR(x, HW_CAN_RX14MASK_RD(x) & ~(v)))
#define HW_CAN_RX14MASK_TOG(x, v) (HW_CAN_RX14MASK_WR(x, HW_CAN_RX14MASK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_RX14MASK bitfields
 */

/*!
 * @name Register CAN_RX14MASK, field RX14M31_RX14M0[31:0] (RW)
 *
 * These bits mask Mailbox 14 filter bits in the same fashion as RXMGMASK masks
 * other Mailboxes filters (see RXMGMASKRx Mailboxes Global Mask Register )
 *
 * Values:
 * - 1 - The corresponding bit in the filter is checked
 * - 0 - the corresponding bit in the filter is "don't care"
 */
/*@{*/
#define BP_CAN_RX14MASK_RX14M31_RX14M0 (0U) /*!< Bit position for CAN_RX14MASK_RX14M31_RX14M0. */
#define BM_CAN_RX14MASK_RX14M31_RX14M0 (0xFFFFFFFFU) /*!< Bit mask for CAN_RX14MASK_RX14M31_RX14M0. */
#define BS_CAN_RX14MASK_RX14M31_RX14M0 (32U) /*!< Bit field size in bits for CAN_RX14MASK_RX14M31_RX14M0. */

/*! @brief Read current value of the CAN_RX14MASK_RX14M31_RX14M0 field. */
#define BR_CAN_RX14MASK_RX14M31_RX14M0(x) (HW_CAN_RX14MASK(x).U)

/*! @brief Format value for bitfield CAN_RX14MASK_RX14M31_RX14M0. */
#define BF_CAN_RX14MASK_RX14M31_RX14M0(v) ((uint32_t)((uint32_t)(v) << BP_CAN_RX14MASK_RX14M31_RX14M0) & BM_CAN_RX14MASK_RX14M31_RX14M0)

/*! @brief Set the RX14M31_RX14M0 field to a new value. */
#define BW_CAN_RX14MASK_RX14M31_RX14M0(x, v) (HW_CAN_RX14MASK_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_CAN_RX15MASK - Rx Buffer 15 Mask Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_RX15MASK - Rx Buffer 15 Mask Register (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * RX15MASK is provided for legacy support, asserting the MCR[IRMQ] bit causes
 * the RX15MASK Register to have no effect on the module operation. RX15MASK is
 * used to mask the filter fields of Message Buffer 15. This register can only be
 * programmed while the module is in Freeze Mode as it is blocked by hardware in
 * other modes.
 */
typedef union _hw_can_rx15mask
{
    uint32_t U;
    struct _hw_can_rx15mask_bitfields
    {
        uint32_t RX15M31_RX15M0 : 32;  /*!< [31:0]  */
    } B;
} hw_can_rx15mask_t;

/*!
 * @name Constants and macros for entire CAN_RX15MASK register
 */
/*@{*/
#define HW_CAN_RX15MASK_ADDR(x)  ((uintptr_t)(x) + 0x18U)

#define HW_CAN_RX15MASK(x)       (*(__IO hw_can_rx15mask_t *) HW_CAN_RX15MASK_ADDR(x))
#define HW_CAN_RX15MASK_RD(x)    (HW_CAN_RX15MASK(x).U)
#define HW_CAN_RX15MASK_WR(x, v) (HW_CAN_RX15MASK(x).U = (v))
#define HW_CAN_RX15MASK_SET(x, v) (HW_CAN_RX15MASK_WR(x, HW_CAN_RX15MASK_RD(x) |  (v)))
#define HW_CAN_RX15MASK_CLR(x, v) (HW_CAN_RX15MASK_WR(x, HW_CAN_RX15MASK_RD(x) & ~(v)))
#define HW_CAN_RX15MASK_TOG(x, v) (HW_CAN_RX15MASK_WR(x, HW_CAN_RX15MASK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_RX15MASK bitfields
 */

/*!
 * @name Register CAN_RX15MASK, field RX15M31_RX15M0[31:0] (RW)
 *
 * These bits mask Mailbox 15 filter bits in the same fashion as RXMGMASK masks
 * other Mailboxes filters (see RXMGMASKRx Mailboxes Global Mask Register ).
 *
 * Values:
 * - 1 - The corresponding bit in the filter is checked
 * - 0 - the corresponding bit in the filter is "don't care"
 */
/*@{*/
#define BP_CAN_RX15MASK_RX15M31_RX15M0 (0U) /*!< Bit position for CAN_RX15MASK_RX15M31_RX15M0. */
#define BM_CAN_RX15MASK_RX15M31_RX15M0 (0xFFFFFFFFU) /*!< Bit mask for CAN_RX15MASK_RX15M31_RX15M0. */
#define BS_CAN_RX15MASK_RX15M31_RX15M0 (32U) /*!< Bit field size in bits for CAN_RX15MASK_RX15M31_RX15M0. */

/*! @brief Read current value of the CAN_RX15MASK_RX15M31_RX15M0 field. */
#define BR_CAN_RX15MASK_RX15M31_RX15M0(x) (HW_CAN_RX15MASK(x).U)

/*! @brief Format value for bitfield CAN_RX15MASK_RX15M31_RX15M0. */
#define BF_CAN_RX15MASK_RX15M31_RX15M0(v) ((uint32_t)((uint32_t)(v) << BP_CAN_RX15MASK_RX15M31_RX15M0) & BM_CAN_RX15MASK_RX15M31_RX15M0)

/*! @brief Set the RX15M31_RX15M0 field to a new value. */
#define BW_CAN_RX15MASK_RX15M31_RX15M0(x, v) (HW_CAN_RX15MASK_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_CAN_ECR - Error Counter Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_ECR - Error Counter Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register has 2 8-bit fields reflecting the value of two FLEXCAN error
 * counters: Transmit Error Counter (Tx_Err_Counter field) and Receive Error
 * Counter (Rx_Err_Counter field). The rules for increasing and decreasing these
 * counters are described in the CAN protocol and are completely implemented in the
 * FLEXCAN module. Both counters are read only except in Freeze Mode, where they can
 * be written by the ARM. FLEXCAN responds to any bus state as described in the
 * protocol, e.g. transmit 'Error Active' or 'Error Passive' flag, delay its
 * transmission start time ('Error Passive') and avoid any influence on the bus when
 * in 'Bus Off' state. The following are the basic rules for FLEXCAN bus state
 * transitions. If the value of Tx_Err_Counter or Rx_Err_Counter increases to be
 * greater than or equal to 128, the FLT_CONF field in the Error and Status
 * Register is updated to reflect 'Error Passive' state. If the FLEXCAN state is 'Error
 * Passive', and either Tx_Err_Counter or Rx_Err_Counter decrements to a value
 * less than or equal to 127 while the other already satisfies this condition, the
 * FLT_CONF field in the Error and Status Register is updated to reflect 'Error
 * Active' state. If the value of Tx_Err_Counter increases to be greater than 255,
 * the FLT_CONF field in the Error and Status Register is updated to reflect
 * 'Bus Off' state, and an interrupt may be issued. The value of Tx_Err_Counter is
 * then reset to zero. If FLEXCAN is in 'Bus Off' state, then Tx_Err_Counter is
 * cascaded together with another internal counter to count the 128th occurrences
 * of 11 consecutive recessive bits on the bus. Hence, Tx_Err_Counter is reset to
 * zero and counts in a manner where the internal counter counts 11 such bits and
 * then wraps around while incrementing the Tx_Err_Counter. When Tx_Err_Counter
 * reaches the value of 128, the FLT_CONF field in the Error and Status Register
 * is updated to be 'Error Active' and both error counters are reset to zero. At
 * any instance of dominant bit following a stream of less than 11 consecutive
 * recessive bits, the internal counter resets itself to zero without affecting the
 * Tx_Err_Counter value. If during system start-up, only one node is operating,
 * then its Tx_Err_Counter increases in each message it is trying to transmit, as
 * a result of acknowledge errors (indicated by the ACK_ERR bit in the Error and
 * Status Register). After the transition to 'Error Passive' state, the
 * Tx_Err_Counter does not increment anymore by acknowledge errors. Therefore the device
 * never goes to the 'Bus Off' state. If the Rx_Err_Counter increases to a value
 * greater than 127, it is not incremented further, even if more errors are
 * detected while being a receiver. At the next successful message reception, the
 * counter is set to a value between 119 and 127 to resume to 'Error Active' state.
 */
typedef union _hw_can_ecr
{
    uint32_t U;
    struct _hw_can_ecr_bitfields
    {
        uint32_t Tx_Err_Counter : 8;   /*!< [7:0]  */
        uint32_t Rx_Err_Counter : 8;   /*!< [15:8]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_can_ecr_t;

/*!
 * @name Constants and macros for entire CAN_ECR register
 */
/*@{*/
#define HW_CAN_ECR_ADDR(x)       ((uintptr_t)(x) + 0x1CU)

#define HW_CAN_ECR(x)            (*(__IO hw_can_ecr_t *) HW_CAN_ECR_ADDR(x))
#define HW_CAN_ECR_RD(x)         (HW_CAN_ECR(x).U)
#define HW_CAN_ECR_WR(x, v)      (HW_CAN_ECR(x).U = (v))
#define HW_CAN_ECR_SET(x, v)     (HW_CAN_ECR_WR(x, HW_CAN_ECR_RD(x) |  (v)))
#define HW_CAN_ECR_CLR(x, v)     (HW_CAN_ECR_WR(x, HW_CAN_ECR_RD(x) & ~(v)))
#define HW_CAN_ECR_TOG(x, v)     (HW_CAN_ECR_WR(x, HW_CAN_ECR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_ECR bitfields
 */

/*!
 * @name Register CAN_ECR, field Tx_Err_Counter[7:0] (RW)
 *
 * Tx_Err_Counter
 */
/*@{*/
#define BP_CAN_ECR_Tx_Err_Counter (0U)     /*!< Bit position for CAN_ECR_Tx_Err_Counter. */
#define BM_CAN_ECR_Tx_Err_Counter (0x000000FFU) /*!< Bit mask for CAN_ECR_Tx_Err_Counter. */
#define BS_CAN_ECR_Tx_Err_Counter (8U)     /*!< Bit field size in bits for CAN_ECR_Tx_Err_Counter. */

/*! @brief Read current value of the CAN_ECR_Tx_Err_Counter field. */
#define BR_CAN_ECR_Tx_Err_Counter(x) (HW_CAN_ECR(x).B.Tx_Err_Counter)

/*! @brief Format value for bitfield CAN_ECR_Tx_Err_Counter. */
#define BF_CAN_ECR_Tx_Err_Counter(v) ((uint32_t)((uint32_t)(v) << BP_CAN_ECR_Tx_Err_Counter) & BM_CAN_ECR_Tx_Err_Counter)

/*! @brief Set the Tx_Err_Counter field to a new value. */
#define BW_CAN_ECR_Tx_Err_Counter(x, v) (HW_CAN_ECR_WR(x, (HW_CAN_ECR_RD(x) & ~BM_CAN_ECR_Tx_Err_Counter) | BF_CAN_ECR_Tx_Err_Counter(v)))
/*@}*/

/*!
 * @name Register CAN_ECR, field Rx_Err_Counter[15:8] (RW)
 *
 * Rx_Err_Counter
 */
/*@{*/
#define BP_CAN_ECR_Rx_Err_Counter (8U)     /*!< Bit position for CAN_ECR_Rx_Err_Counter. */
#define BM_CAN_ECR_Rx_Err_Counter (0x0000FF00U) /*!< Bit mask for CAN_ECR_Rx_Err_Counter. */
#define BS_CAN_ECR_Rx_Err_Counter (8U)     /*!< Bit field size in bits for CAN_ECR_Rx_Err_Counter. */

/*! @brief Read current value of the CAN_ECR_Rx_Err_Counter field. */
#define BR_CAN_ECR_Rx_Err_Counter(x) (HW_CAN_ECR(x).B.Rx_Err_Counter)

/*! @brief Format value for bitfield CAN_ECR_Rx_Err_Counter. */
#define BF_CAN_ECR_Rx_Err_Counter(v) ((uint32_t)((uint32_t)(v) << BP_CAN_ECR_Rx_Err_Counter) & BM_CAN_ECR_Rx_Err_Counter)

/*! @brief Set the Rx_Err_Counter field to a new value. */
#define BW_CAN_ECR_Rx_Err_Counter(x, v) (HW_CAN_ECR_WR(x, (HW_CAN_ECR_RD(x) & ~BM_CAN_ECR_Rx_Err_Counter) | BF_CAN_ECR_Rx_Err_Counter(v)))
/*@}*/

/*******************************************************************************
 * HW_CAN_ESR1 - Error and Status 1 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_ESR1 - Error and Status 1 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register reflects various error conditions, some general status of the
 * device and it is the source of four interrupts to the ARM. The ARM read action
 * clears bits 15-10, therefore the reported error conditions (bits 15-10) are
 * those that occurred since the last time the ARM read this register. Bits 9-3 are
 * status bits. Some bits in this register are read-only and some are not.
 * FlexCAN State SYNCH IDLE TX RX FlexCAN state 0 0 0 0 Not synchronized to CAN bus 1
 * 1 x x Idle 1 0 1 0 Transmitting 1 0 0 1 Receiving other combinations Reserved
 */
typedef union _hw_can_esr1
{
    uint32_t U;
    struct _hw_can_esr1_bitfields
    {
        uint32_t WAK_INT : 1;          /*!< [0]  */
        uint32_t ERR_INT : 1;          /*!< [1]  */
        uint32_t BOFF_INT : 1;         /*!< [2]  */
        uint32_t RX : 1;               /*!< [3]  */
        uint32_t FLT_CONF : 2;         /*!< [5:4]  */
        uint32_t TX : 1;               /*!< [6]  */
        uint32_t IDLE : 1;             /*!< [7]  */
        uint32_t RX_WRN : 1;           /*!< [8]  */
        uint32_t TX_WRN : 1;           /*!< [9]  */
        uint32_t STF_ERR : 1;          /*!< [10]  */
        uint32_t FRM_ERR : 1;          /*!< [11]  */
        uint32_t CRC_ERR : 1;          /*!< [12]  */
        uint32_t ACK_ERR : 1;          /*!< [13]  */
        uint32_t BIT0_ERR : 1;         /*!< [14]  */
        uint32_t BIT1_ERR : 1;         /*!< [15]  */
        uint32_t RWRN_INT : 1;         /*!< [16]  */
        uint32_t TWRN_INT : 1;         /*!< [17]  */
        uint32_t SYNCH : 1;            /*!< [18]  */
        uint32_t RESERVED0 : 13;       /*!< [31:19]  */
    } B;
} hw_can_esr1_t;

/*!
 * @name Constants and macros for entire CAN_ESR1 register
 */
/*@{*/
#define HW_CAN_ESR1_ADDR(x)      ((uintptr_t)(x) + 0x20U)

#define HW_CAN_ESR1(x)           (*(__IO hw_can_esr1_t *) HW_CAN_ESR1_ADDR(x))
#define HW_CAN_ESR1_RD(x)        (HW_CAN_ESR1(x).U)
#define HW_CAN_ESR1_WR(x, v)     (HW_CAN_ESR1(x).U = (v))
#define HW_CAN_ESR1_SET(x, v)    (HW_CAN_ESR1_WR(x, HW_CAN_ESR1_RD(x) |  (v)))
#define HW_CAN_ESR1_CLR(x, v)    (HW_CAN_ESR1_WR(x, HW_CAN_ESR1_RD(x) & ~(v)))
#define HW_CAN_ESR1_TOG(x, v)    (HW_CAN_ESR1_WR(x, HW_CAN_ESR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_ESR1 bitfields
 */

/*!
 * @name Register CAN_ESR1, field WAK_INT[0] (RW)
 *
 * When FLEXCAN is Stop Mode and a recessive to dominant transition is detected
 * on the CAN bus and if the WAK_MSK bit in the MCR Register is set, an interrupt
 * is generated to the ARM. This bit is cleared by writing it to '1'. When
 * SLF_WAK is negated, this flag is masked. ARM must clear this flag before disabling
 * the bit. Otherwise it will be set when the SLF_WAK is set again. Writing '0'
 * has no effect
 *
 * Values:
 * - 1 - Indicates a recessive to dominant transition received on the CAN bus
 *     when the FLEXCAN module is in Stop Mode
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_WAK_INT  (0U)          /*!< Bit position for CAN_ESR1_WAK_INT. */
#define BM_CAN_ESR1_WAK_INT  (0x00000001U) /*!< Bit mask for CAN_ESR1_WAK_INT. */
#define BS_CAN_ESR1_WAK_INT  (1U)          /*!< Bit field size in bits for CAN_ESR1_WAK_INT. */

/*! @brief Read current value of the CAN_ESR1_WAK_INT field. */
#define BR_CAN_ESR1_WAK_INT(x) (HW_CAN_ESR1(x).B.WAK_INT)

/*! @brief Format value for bitfield CAN_ESR1_WAK_INT. */
#define BF_CAN_ESR1_WAK_INT(v) ((uint32_t)((uint32_t)(v) << BP_CAN_ESR1_WAK_INT) & BM_CAN_ESR1_WAK_INT)

/*! @brief Set the WAK_INT field to a new value. */
#define BW_CAN_ESR1_WAK_INT(x, v) (HW_CAN_ESR1_WR(x, (HW_CAN_ESR1_RD(x) & ~BM_CAN_ESR1_WAK_INT) | BF_CAN_ESR1_WAK_INT(v)))
/*@}*/

/*!
 * @name Register CAN_ESR1, field ERR_INT[1] (RW)
 *
 * This bit indicates that at least one of the Error Bits (bits 15-10) is set.
 * If the corresponding mask bit in the Control Register (ERR_MSK) is set, an
 * interrupt is generated to the ARM. This bit is cleared by writing it to
 * '1'.Writing '0' has no effect.
 *
 * Values:
 * - 1 - Indicates setting of any Error Bit in the Error and Status Register
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_ERR_INT  (1U)          /*!< Bit position for CAN_ESR1_ERR_INT. */
#define BM_CAN_ESR1_ERR_INT  (0x00000002U) /*!< Bit mask for CAN_ESR1_ERR_INT. */
#define BS_CAN_ESR1_ERR_INT  (1U)          /*!< Bit field size in bits for CAN_ESR1_ERR_INT. */

/*! @brief Read current value of the CAN_ESR1_ERR_INT field. */
#define BR_CAN_ESR1_ERR_INT(x) (HW_CAN_ESR1(x).B.ERR_INT)

/*! @brief Format value for bitfield CAN_ESR1_ERR_INT. */
#define BF_CAN_ESR1_ERR_INT(v) ((uint32_t)((uint32_t)(v) << BP_CAN_ESR1_ERR_INT) & BM_CAN_ESR1_ERR_INT)

/*! @brief Set the ERR_INT field to a new value. */
#define BW_CAN_ESR1_ERR_INT(x, v) (HW_CAN_ESR1_WR(x, (HW_CAN_ESR1_RD(x) & ~BM_CAN_ESR1_ERR_INT) | BF_CAN_ESR1_ERR_INT(v)))
/*@}*/

/*!
 * @name Register CAN_ESR1, field BOFF_INT[2] (RW)
 *
 * This bit is set when FLEXCAN enters 'Bus Off' state. If the corresponding
 * mask bit in the Control Register (BOFF_MSK) is set, an interrupt is generated to
 * the ARM. This bit is cleared by writing it to '1'. Writing '0' has no effect.
 *
 * Values:
 * - 1 - FLEXCAN module entered 'Bus Off' state
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_BOFF_INT (2U)          /*!< Bit position for CAN_ESR1_BOFF_INT. */
#define BM_CAN_ESR1_BOFF_INT (0x00000004U) /*!< Bit mask for CAN_ESR1_BOFF_INT. */
#define BS_CAN_ESR1_BOFF_INT (1U)          /*!< Bit field size in bits for CAN_ESR1_BOFF_INT. */

/*! @brief Read current value of the CAN_ESR1_BOFF_INT field. */
#define BR_CAN_ESR1_BOFF_INT(x) (HW_CAN_ESR1(x).B.BOFF_INT)

/*! @brief Format value for bitfield CAN_ESR1_BOFF_INT. */
#define BF_CAN_ESR1_BOFF_INT(v) ((uint32_t)((uint32_t)(v) << BP_CAN_ESR1_BOFF_INT) & BM_CAN_ESR1_BOFF_INT)

/*! @brief Set the BOFF_INT field to a new value. */
#define BW_CAN_ESR1_BOFF_INT(x, v) (HW_CAN_ESR1_WR(x, (HW_CAN_ESR1_RD(x) & ~BM_CAN_ESR1_BOFF_INT) | BF_CAN_ESR1_BOFF_INT(v)))
/*@}*/

/*!
 * @name Register CAN_ESR1, field RX[3] (RO)
 *
 * This bit indicates if FlexCAN is receiving a message. Refer to .
 *
 * Values:
 * - 1 - FLEXCAN is transmitting a message
 * - 0 - FLEXCAN is receiving a message
 */
/*@{*/
#define BP_CAN_ESR1_RX       (3U)          /*!< Bit position for CAN_ESR1_RX. */
#define BM_CAN_ESR1_RX       (0x00000008U) /*!< Bit mask for CAN_ESR1_RX. */
#define BS_CAN_ESR1_RX       (1U)          /*!< Bit field size in bits for CAN_ESR1_RX. */

/*! @brief Read current value of the CAN_ESR1_RX field. */
#define BR_CAN_ESR1_RX(x)    (HW_CAN_ESR1(x).B.RX)
/*@}*/

/*!
 * @name Register CAN_ESR1, field FLT_CONF[5:4] (RO)
 *
 * If the LOM bit in the Control Register is asserted, after some delay that
 * depends on the CAN bit timing the FLT_CONF field will indicate "Error Passive".
 * The very same delay affects the way how FLT_CONF reflects an update to ECR
 * register by the ARM. It may be necessary up to one CAN bit time to get them
 * coherent again. Since the Control Register is not affected by soft reset, the
 * FLT_CONF field will not be affected by soft reset if the LOM bit is asserted. This
 * 2-bit field indicates the Confinement State of the FLEXCAN module, as shown in
 * below:
 *
 * Values:
 * - 00 - Error Active
 * - 01 - Error Passive
 * - 1x - Bus off
 */
/*@{*/
#define BP_CAN_ESR1_FLT_CONF (4U)          /*!< Bit position for CAN_ESR1_FLT_CONF. */
#define BM_CAN_ESR1_FLT_CONF (0x00000030U) /*!< Bit mask for CAN_ESR1_FLT_CONF. */
#define BS_CAN_ESR1_FLT_CONF (2U)          /*!< Bit field size in bits for CAN_ESR1_FLT_CONF. */

/*! @brief Read current value of the CAN_ESR1_FLT_CONF field. */
#define BR_CAN_ESR1_FLT_CONF(x) (HW_CAN_ESR1(x).B.FLT_CONF)
/*@}*/

/*!
 * @name Register CAN_ESR1, field TX[6] (RO)
 *
 * This bit indicates if FLEXCAN is transmitting a message.Refer to .
 *
 * Values:
 * - 1 - FLEXCAN is transmitting a message
 * - 0 - FLEXCAN is receiving a message
 */
/*@{*/
#define BP_CAN_ESR1_TX       (6U)          /*!< Bit position for CAN_ESR1_TX. */
#define BM_CAN_ESR1_TX       (0x00000040U) /*!< Bit mask for CAN_ESR1_TX. */
#define BS_CAN_ESR1_TX       (1U)          /*!< Bit field size in bits for CAN_ESR1_TX. */

/*! @brief Read current value of the CAN_ESR1_TX field. */
#define BR_CAN_ESR1_TX(x)    (HW_CAN_ESR1(x).B.TX)
/*@}*/

/*!
 * @name Register CAN_ESR1, field IDLE[7] (RO)
 *
 * This bit indicates when CAN bus is in IDLE state.Refer to .
 *
 * Values:
 * - 1 - CAN bus is now IDLE
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_IDLE     (7U)          /*!< Bit position for CAN_ESR1_IDLE. */
#define BM_CAN_ESR1_IDLE     (0x00000080U) /*!< Bit mask for CAN_ESR1_IDLE. */
#define BS_CAN_ESR1_IDLE     (1U)          /*!< Bit field size in bits for CAN_ESR1_IDLE. */

/*! @brief Read current value of the CAN_ESR1_IDLE field. */
#define BR_CAN_ESR1_IDLE(x)  (HW_CAN_ESR1(x).B.IDLE)
/*@}*/

/*!
 * @name Register CAN_ESR1, field RX_WRN[8] (RO)
 *
 * This bit indicates when repetitive errors are occurring during message
 * reception.
 *
 * Values:
 * - 1 - Rx_Err_Counter >= 96
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_RX_WRN   (8U)          /*!< Bit position for CAN_ESR1_RX_WRN. */
#define BM_CAN_ESR1_RX_WRN   (0x00000100U) /*!< Bit mask for CAN_ESR1_RX_WRN. */
#define BS_CAN_ESR1_RX_WRN   (1U)          /*!< Bit field size in bits for CAN_ESR1_RX_WRN. */

/*! @brief Read current value of the CAN_ESR1_RX_WRN field. */
#define BR_CAN_ESR1_RX_WRN(x) (HW_CAN_ESR1(x).B.RX_WRN)
/*@}*/

/*!
 * @name Register CAN_ESR1, field TX_WRN[9] (RO)
 *
 * This bit indicates when repetitive errors are occurring during message
 * transmission.
 *
 * Values:
 * - 1 - TX_Err_Counter >= 96
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_TX_WRN   (9U)          /*!< Bit position for CAN_ESR1_TX_WRN. */
#define BM_CAN_ESR1_TX_WRN   (0x00000200U) /*!< Bit mask for CAN_ESR1_TX_WRN. */
#define BS_CAN_ESR1_TX_WRN   (1U)          /*!< Bit field size in bits for CAN_ESR1_TX_WRN. */

/*! @brief Read current value of the CAN_ESR1_TX_WRN field. */
#define BR_CAN_ESR1_TX_WRN(x) (HW_CAN_ESR1(x).B.TX_WRN)
/*@}*/

/*!
 * @name Register CAN_ESR1, field STF_ERR[10] (RO)
 *
 * This bit indicates that a Stuffing Error has been detected.
 *
 * Values:
 * - 1 - A Stuffing Error occurred since last read of this register.
 * - 0 - No such occurrence.
 */
/*@{*/
#define BP_CAN_ESR1_STF_ERR  (10U)         /*!< Bit position for CAN_ESR1_STF_ERR. */
#define BM_CAN_ESR1_STF_ERR  (0x00000400U) /*!< Bit mask for CAN_ESR1_STF_ERR. */
#define BS_CAN_ESR1_STF_ERR  (1U)          /*!< Bit field size in bits for CAN_ESR1_STF_ERR. */

/*! @brief Read current value of the CAN_ESR1_STF_ERR field. */
#define BR_CAN_ESR1_STF_ERR(x) (HW_CAN_ESR1(x).B.STF_ERR)
/*@}*/

/*!
 * @name Register CAN_ESR1, field FRM_ERR[11] (RO)
 *
 * This bit indicates that a Form Error has been detected by the receiver node,
 * i.e., a fixed-form bit field contains at least one illegal bit.
 *
 * Values:
 * - 1 - A Form Error occurred since last read of this register
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_FRM_ERR  (11U)         /*!< Bit position for CAN_ESR1_FRM_ERR. */
#define BM_CAN_ESR1_FRM_ERR  (0x00000800U) /*!< Bit mask for CAN_ESR1_FRM_ERR. */
#define BS_CAN_ESR1_FRM_ERR  (1U)          /*!< Bit field size in bits for CAN_ESR1_FRM_ERR. */

/*! @brief Read current value of the CAN_ESR1_FRM_ERR field. */
#define BR_CAN_ESR1_FRM_ERR(x) (HW_CAN_ESR1(x).B.FRM_ERR)
/*@}*/

/*!
 * @name Register CAN_ESR1, field CRC_ERR[12] (RO)
 *
 * This bit indicates that a CRC Error has been detected by the receiver node,
 * i.e., the calculated CRC is different from the received.
 *
 * Values:
 * - 1 - A CRC error occurred since last read of this register.
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_CRC_ERR  (12U)         /*!< Bit position for CAN_ESR1_CRC_ERR. */
#define BM_CAN_ESR1_CRC_ERR  (0x00001000U) /*!< Bit mask for CAN_ESR1_CRC_ERR. */
#define BS_CAN_ESR1_CRC_ERR  (1U)          /*!< Bit field size in bits for CAN_ESR1_CRC_ERR. */

/*! @brief Read current value of the CAN_ESR1_CRC_ERR field. */
#define BR_CAN_ESR1_CRC_ERR(x) (HW_CAN_ESR1(x).B.CRC_ERR)
/*@}*/

/*!
 * @name Register CAN_ESR1, field ACK_ERR[13] (RO)
 *
 * This bit indicates that an Acknowledge Error has been detected by the
 * transmitter node, i.e., a dominant bit has not been detected during the ACK SLOT.
 *
 * Values:
 * - 1 - An ACK error occurred since last read of this register
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_ACK_ERR  (13U)         /*!< Bit position for CAN_ESR1_ACK_ERR. */
#define BM_CAN_ESR1_ACK_ERR  (0x00002000U) /*!< Bit mask for CAN_ESR1_ACK_ERR. */
#define BS_CAN_ESR1_ACK_ERR  (1U)          /*!< Bit field size in bits for CAN_ESR1_ACK_ERR. */

/*! @brief Read current value of the CAN_ESR1_ACK_ERR field. */
#define BR_CAN_ESR1_ACK_ERR(x) (HW_CAN_ESR1(x).B.ACK_ERR)
/*@}*/

/*!
 * @name Register CAN_ESR1, field BIT0_ERR[14] (RO)
 *
 * This bit indicates when an inconsistency occurs between the transmitted and
 * the received bit in a message.
 *
 * Values:
 * - 1 - At least one bit sent as dominant is received as recessive
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_BIT0_ERR (14U)         /*!< Bit position for CAN_ESR1_BIT0_ERR. */
#define BM_CAN_ESR1_BIT0_ERR (0x00004000U) /*!< Bit mask for CAN_ESR1_BIT0_ERR. */
#define BS_CAN_ESR1_BIT0_ERR (1U)          /*!< Bit field size in bits for CAN_ESR1_BIT0_ERR. */

/*! @brief Read current value of the CAN_ESR1_BIT0_ERR field. */
#define BR_CAN_ESR1_BIT0_ERR(x) (HW_CAN_ESR1(x).B.BIT0_ERR)
/*@}*/

/*!
 * @name Register CAN_ESR1, field BIT1_ERR[15] (RO)
 *
 * This bit indicates when an inconsistency occurs between the transmitted and
 * the received bit in a message. This bit is not set by a transmitter in case of
 * arbitration field or ACK slot, or in case of a node sending a passive error
 * flag that detects dominant bits.
 *
 * Values:
 * - 1 - At least one bit sent as recessive is received as dominant
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_BIT1_ERR (15U)         /*!< Bit position for CAN_ESR1_BIT1_ERR. */
#define BM_CAN_ESR1_BIT1_ERR (0x00008000U) /*!< Bit mask for CAN_ESR1_BIT1_ERR. */
#define BS_CAN_ESR1_BIT1_ERR (1U)          /*!< Bit field size in bits for CAN_ESR1_BIT1_ERR. */

/*! @brief Read current value of the CAN_ESR1_BIT1_ERR field. */
#define BR_CAN_ESR1_BIT1_ERR(x) (HW_CAN_ESR1(x).B.BIT1_ERR)
/*@}*/

/*!
 * @name Register CAN_ESR1, field RWRN_INT[16] (RW)
 *
 * If the WRN_EN bit in MCR is asserted, the RWRN_INT bit is set when the RX_WRN
 * flag transition from '0' to '1', meaning that the Rx error counters reached
 * 96. If the corresponding mask bit in the Control Register (RWRN_MSK) is set, an
 * interrupt is generated to the ARM. This bit is cleared by writing it to '1'.
 * When WRN_EN is negated, this flag is masked. ARM must clear this flag before
 * disabling the bit. Otherwise it will be set when the WRN_EN is set again.
 * Writing '0' has no effect. This bit is not updated during Freeze mode.
 *
 * Values:
 * - 1 - The Rx error counter transition from < 96 to >= 96
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_RWRN_INT (16U)         /*!< Bit position for CAN_ESR1_RWRN_INT. */
#define BM_CAN_ESR1_RWRN_INT (0x00010000U) /*!< Bit mask for CAN_ESR1_RWRN_INT. */
#define BS_CAN_ESR1_RWRN_INT (1U)          /*!< Bit field size in bits for CAN_ESR1_RWRN_INT. */

/*! @brief Read current value of the CAN_ESR1_RWRN_INT field. */
#define BR_CAN_ESR1_RWRN_INT(x) (HW_CAN_ESR1(x).B.RWRN_INT)

/*! @brief Format value for bitfield CAN_ESR1_RWRN_INT. */
#define BF_CAN_ESR1_RWRN_INT(v) ((uint32_t)((uint32_t)(v) << BP_CAN_ESR1_RWRN_INT) & BM_CAN_ESR1_RWRN_INT)

/*! @brief Set the RWRN_INT field to a new value. */
#define BW_CAN_ESR1_RWRN_INT(x, v) (HW_CAN_ESR1_WR(x, (HW_CAN_ESR1_RD(x) & ~BM_CAN_ESR1_RWRN_INT) | BF_CAN_ESR1_RWRN_INT(v)))
/*@}*/

/*!
 * @name Register CAN_ESR1, field TWRN_INT[17] (RW)
 *
 * If the WRN_EN bit in MCR is asserted, the TWRN_INT bit is set when the TX_WRN
 * flag transition from '0' to '1', meaning that the Tx error counter reached
 * 96. If the corresponding mask bit in the Control Register (TWRN_MSK) is set, an
 * interrupt is generated to the ARM. This bit is cleared by writing it to '1'.
 * When WRN_EN is negated, this flag is masked. ARM must clear this flag before
 * disabling the bit. Otherwise it will be set when the WRN_EN is set again.
 * Writing '0' has no effect. This flag is not generated during "Bus Off" state. This
 * bit is not updated during Freeze mode.
 *
 * Values:
 * - 1 - The Tx error counter transition from < 96 to >= 96
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_ESR1_TWRN_INT (17U)         /*!< Bit position for CAN_ESR1_TWRN_INT. */
#define BM_CAN_ESR1_TWRN_INT (0x00020000U) /*!< Bit mask for CAN_ESR1_TWRN_INT. */
#define BS_CAN_ESR1_TWRN_INT (1U)          /*!< Bit field size in bits for CAN_ESR1_TWRN_INT. */

/*! @brief Read current value of the CAN_ESR1_TWRN_INT field. */
#define BR_CAN_ESR1_TWRN_INT(x) (HW_CAN_ESR1(x).B.TWRN_INT)

/*! @brief Format value for bitfield CAN_ESR1_TWRN_INT. */
#define BF_CAN_ESR1_TWRN_INT(v) ((uint32_t)((uint32_t)(v) << BP_CAN_ESR1_TWRN_INT) & BM_CAN_ESR1_TWRN_INT)

/*! @brief Set the TWRN_INT field to a new value. */
#define BW_CAN_ESR1_TWRN_INT(x, v) (HW_CAN_ESR1_WR(x, (HW_CAN_ESR1_RD(x) & ~BM_CAN_ESR1_TWRN_INT) | BF_CAN_ESR1_TWRN_INT(v)))
/*@}*/

/*!
 * @name Register CAN_ESR1, field SYNCH[18] (RO)
 *
 * This read-only flag indicates whether the FlexCAN is synchronized to the CAN
 * bus and able to participate in the communication process. It is set and
 * cleared by the FlexCAN. Refer to
 *
 * Values:
 * - 1 - FlexCAN is synchronized to the CAN bus
 * - 0 - FlexCAN is not synchronized to the CAN bus
 */
/*@{*/
#define BP_CAN_ESR1_SYNCH    (18U)         /*!< Bit position for CAN_ESR1_SYNCH. */
#define BM_CAN_ESR1_SYNCH    (0x00040000U) /*!< Bit mask for CAN_ESR1_SYNCH. */
#define BS_CAN_ESR1_SYNCH    (1U)          /*!< Bit field size in bits for CAN_ESR1_SYNCH. */

/*! @brief Read current value of the CAN_ESR1_SYNCH field. */
#define BR_CAN_ESR1_SYNCH(x) (HW_CAN_ESR1(x).B.SYNCH)
/*@}*/

/*******************************************************************************
 * HW_CAN_IMASK2 - Interrupt Masks 2 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_IMASK2 - Interrupt Masks 2 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register allows any number of a range of 32 Message Buffer Interrupts to
 * be enabled or disabled. It contains one interrupt mask bit per buffer,
 * enabling the ARM to determine which buffer generates an interrupt after a successful
 * transmission or reception (i.e. when the corresponding IFLAG2 bit is set).
 */
typedef union _hw_can_imask2
{
    uint32_t U;
    struct _hw_can_imask2_bitfields
    {
        uint32_t BUF63M_BUF32M : 32;   /*!< [31:0]  */
    } B;
} hw_can_imask2_t;

/*!
 * @name Constants and macros for entire CAN_IMASK2 register
 */
/*@{*/
#define HW_CAN_IMASK2_ADDR(x)    ((uintptr_t)(x) + 0x24U)

#define HW_CAN_IMASK2(x)         (*(__IO hw_can_imask2_t *) HW_CAN_IMASK2_ADDR(x))
#define HW_CAN_IMASK2_RD(x)      (HW_CAN_IMASK2(x).U)
#define HW_CAN_IMASK2_WR(x, v)   (HW_CAN_IMASK2(x).U = (v))
#define HW_CAN_IMASK2_SET(x, v)  (HW_CAN_IMASK2_WR(x, HW_CAN_IMASK2_RD(x) |  (v)))
#define HW_CAN_IMASK2_CLR(x, v)  (HW_CAN_IMASK2_WR(x, HW_CAN_IMASK2_RD(x) & ~(v)))
#define HW_CAN_IMASK2_TOG(x, v)  (HW_CAN_IMASK2_WR(x, HW_CAN_IMASK2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_IMASK2 bitfields
 */

/*!
 * @name Register CAN_IMASK2, field BUF63M_BUF32M[31:0] (RW)
 *
 * Each bit enables or disables the respective FLEXCAN Message Buffer (MB32 to
 * MB63) Interrupt. Setting or clearing a bit in the IMASK2 Register can assert or
 * negate an interrupt request, if the corresponding IFLAG2 bit is set.
 *
 * Values:
 * - 1 - The corresponding buffer Interrupt is enabled
 * - 0 - The corresponding buffer Interrupt is disabled
 */
/*@{*/
#define BP_CAN_IMASK2_BUF63M_BUF32M (0U)   /*!< Bit position for CAN_IMASK2_BUF63M_BUF32M. */
#define BM_CAN_IMASK2_BUF63M_BUF32M (0xFFFFFFFFU) /*!< Bit mask for CAN_IMASK2_BUF63M_BUF32M. */
#define BS_CAN_IMASK2_BUF63M_BUF32M (32U)  /*!< Bit field size in bits for CAN_IMASK2_BUF63M_BUF32M. */

/*! @brief Read current value of the CAN_IMASK2_BUF63M_BUF32M field. */
#define BR_CAN_IMASK2_BUF63M_BUF32M(x) (HW_CAN_IMASK2(x).U)

/*! @brief Format value for bitfield CAN_IMASK2_BUF63M_BUF32M. */
#define BF_CAN_IMASK2_BUF63M_BUF32M(v) ((uint32_t)((uint32_t)(v) << BP_CAN_IMASK2_BUF63M_BUF32M) & BM_CAN_IMASK2_BUF63M_BUF32M)

/*! @brief Set the BUF63M_BUF32M field to a new value. */
#define BW_CAN_IMASK2_BUF63M_BUF32M(x, v) (HW_CAN_IMASK2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_CAN_IMASK1 - Interrupt Masks 1 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_IMASK1 - Interrupt Masks 1 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register allows to enable or disable any number of a range of 32 Message
 * Buffer Interrupts. It contains one interrupt mask bit per buffer, enabling
 * the ARM to determine which buffer generates an interrupt after a successful
 * transmission or reception (i.e., when the corresponding IFLAG1 bit is set).
 */
typedef union _hw_can_imask1
{
    uint32_t U;
    struct _hw_can_imask1_bitfields
    {
        uint32_t BUF31M_BUF0M : 32;    /*!< [31:0]  */
    } B;
} hw_can_imask1_t;

/*!
 * @name Constants and macros for entire CAN_IMASK1 register
 */
/*@{*/
#define HW_CAN_IMASK1_ADDR(x)    ((uintptr_t)(x) + 0x28U)

#define HW_CAN_IMASK1(x)         (*(__IO hw_can_imask1_t *) HW_CAN_IMASK1_ADDR(x))
#define HW_CAN_IMASK1_RD(x)      (HW_CAN_IMASK1(x).U)
#define HW_CAN_IMASK1_WR(x, v)   (HW_CAN_IMASK1(x).U = (v))
#define HW_CAN_IMASK1_SET(x, v)  (HW_CAN_IMASK1_WR(x, HW_CAN_IMASK1_RD(x) |  (v)))
#define HW_CAN_IMASK1_CLR(x, v)  (HW_CAN_IMASK1_WR(x, HW_CAN_IMASK1_RD(x) & ~(v)))
#define HW_CAN_IMASK1_TOG(x, v)  (HW_CAN_IMASK1_WR(x, HW_CAN_IMASK1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_IMASK1 bitfields
 */

/*!
 * @name Register CAN_IMASK1, field BUF31M_BUF0M[31:0] (RW)
 *
 * Each bit enables or disables the respective FLEXCAN Message Buffer (MB0 to
 * MB31) Interrupt. Setting or clearing a bit in the IMASK1 Register can assert or
 * negate an interrupt request, if the corresponding IFLAG1 bit is set
 *
 * Values:
 * - 1 - The corresponding buffer Interrupt is enabled
 * - 0 - The corresponding buffer Interrupt is disabled
 */
/*@{*/
#define BP_CAN_IMASK1_BUF31M_BUF0M (0U)    /*!< Bit position for CAN_IMASK1_BUF31M_BUF0M. */
#define BM_CAN_IMASK1_BUF31M_BUF0M (0xFFFFFFFFU) /*!< Bit mask for CAN_IMASK1_BUF31M_BUF0M. */
#define BS_CAN_IMASK1_BUF31M_BUF0M (32U)   /*!< Bit field size in bits for CAN_IMASK1_BUF31M_BUF0M. */

/*! @brief Read current value of the CAN_IMASK1_BUF31M_BUF0M field. */
#define BR_CAN_IMASK1_BUF31M_BUF0M(x) (HW_CAN_IMASK1(x).U)

/*! @brief Format value for bitfield CAN_IMASK1_BUF31M_BUF0M. */
#define BF_CAN_IMASK1_BUF31M_BUF0M(v) ((uint32_t)((uint32_t)(v) << BP_CAN_IMASK1_BUF31M_BUF0M) & BM_CAN_IMASK1_BUF31M_BUF0M)

/*! @brief Set the BUF31M_BUF0M field to a new value. */
#define BW_CAN_IMASK1_BUF31M_BUF0M(x, v) (HW_CAN_IMASK1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_CAN_IFLAG2 - Interrupt Flags 2 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_IFLAG2 - Interrupt Flags 2 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the flags for 32 Message Buffer interrupts. It contains
 * one interrupt flag bit per buffer. Each successful transmission or reception
 * sets the corresponding IFLAG2 bit. If the corresponding IMASK2 bit is set, an
 * interrupt will be generated. The interrupt flag must be cleared by writing it
 * to '1'. Writing '0' has no effect.Before updating MCR[MAXMB] field, ARM must
 * treat the IFLAG2 bits which MB value is greater than the MCR[MAXMB] to be
 * updated, otherwise they will keep set and be inconsistent with the amount of MBs
 * available.
 */
typedef union _hw_can_iflag2
{
    uint32_t U;
    struct _hw_can_iflag2_bitfields
    {
        uint32_t BUF63I_BUF32I : 32;   /*!< [31:0]  */
    } B;
} hw_can_iflag2_t;

/*!
 * @name Constants and macros for entire CAN_IFLAG2 register
 */
/*@{*/
#define HW_CAN_IFLAG2_ADDR(x)    ((uintptr_t)(x) + 0x2CU)

#define HW_CAN_IFLAG2(x)         (*(__IO hw_can_iflag2_t *) HW_CAN_IFLAG2_ADDR(x))
#define HW_CAN_IFLAG2_RD(x)      (HW_CAN_IFLAG2(x).U)
#define HW_CAN_IFLAG2_WR(x, v)   (HW_CAN_IFLAG2(x).U = (v))
#define HW_CAN_IFLAG2_SET(x, v)  (HW_CAN_IFLAG2_WR(x, HW_CAN_IFLAG2_RD(x) |  (v)))
#define HW_CAN_IFLAG2_CLR(x, v)  (HW_CAN_IFLAG2_WR(x, HW_CAN_IFLAG2_RD(x) & ~(v)))
#define HW_CAN_IFLAG2_TOG(x, v)  (HW_CAN_IFLAG2_WR(x, HW_CAN_IFLAG2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_IFLAG2 bitfields
 */

/*!
 * @name Register CAN_IFLAG2, field BUF63I_BUF32I[31:0] (RW)
 *
 * Each bit flags the respective FLEXCAN Message Buffer (MB32 to MB63) interrupt.
 *
 * Values:
 * - 1 - The corresponding buffer has successfully completed transmission or
 *     reception
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_IFLAG2_BUF63I_BUF32I (0U)   /*!< Bit position for CAN_IFLAG2_BUF63I_BUF32I. */
#define BM_CAN_IFLAG2_BUF63I_BUF32I (0xFFFFFFFFU) /*!< Bit mask for CAN_IFLAG2_BUF63I_BUF32I. */
#define BS_CAN_IFLAG2_BUF63I_BUF32I (32U)  /*!< Bit field size in bits for CAN_IFLAG2_BUF63I_BUF32I. */

/*! @brief Read current value of the CAN_IFLAG2_BUF63I_BUF32I field. */
#define BR_CAN_IFLAG2_BUF63I_BUF32I(x) (HW_CAN_IFLAG2(x).U)

/*! @brief Format value for bitfield CAN_IFLAG2_BUF63I_BUF32I. */
#define BF_CAN_IFLAG2_BUF63I_BUF32I(v) ((uint32_t)((uint32_t)(v) << BP_CAN_IFLAG2_BUF63I_BUF32I) & BM_CAN_IFLAG2_BUF63I_BUF32I)

/*! @brief Set the BUF63I_BUF32I field to a new value. */
#define BW_CAN_IFLAG2_BUF63I_BUF32I(x, v) (HW_CAN_IFLAG2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_CAN_IFLAG1 - Interrupt Flags 1 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_IFLAG1 - Interrupt Flags 1 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the flags for 32 Message Buffer interrupts and FIFO
 * interrupts. It contains one interrupt flag bit per buffer. Each successful
 * transmission or reception sets the corresponding IFLAG1 bit. If the corresponding
 * IMASK1 bit is set, an interrupt will be generated. The Interrupt flag must be
 * cleared by writing it to '1'. Writing '0' has no effect. When the RFEN bit in
 * the MCR is set (Rx FIFO enabled), the function of the 8 least significant
 * interrupt flags (BUF7I - BUF0I) is changed to support the FIFO operation. BUF7I,
 * BUF6I and BUF5I indicate operating conditions of the FIFO, while BUF4I to BUF0I
 * are not used. Before enabling the RFEN, ARM must service the IFLAGS asserted in
 * the Rx FIFO region (see Rx FIFOThe receive-only FIFO is enabled by asserting
 * the RFEN bit in the MCR. ). Otherwise, these IFLAGS will mistakenly show the
 * related MBs now belonging to FIFO as having contents to be serviced. When the
 * RFEN is negated, the FIFO flags must be cleared. The same care must be taken
 * when a RFFN value is selected extending Rx FIFO filters beyond MB7 (see
 * CTRL2Control 2 Register ). For example, when RFFN is 0x8, the MB0-23 range is occupied
 * by Rx FIFO filters and related IFLAGS must be cleared. Before updating
 * MCR[MAXMB] field, ARM must service the IFLAG1 which MB value is greater than the
 * MCR[MAXMB] to be updated, otherwise they will keep set and be inconsistent with
 * the amount of MBs available.
 */
typedef union _hw_can_iflag1
{
    uint32_t U;
    struct _hw_can_iflag1_bitfields
    {
        uint32_t BUF4I_BUF0I : 5;      /*!< [4:0]  */
        uint32_t BUF5I : 1;            /*!< [5]  */
        uint32_t BUF6I : 1;            /*!< [6]  */
        uint32_t BUF7I : 1;            /*!< [7]  */
        uint32_t BUF31I_BUF8I : 24;    /*!< [31:8]  */
    } B;
} hw_can_iflag1_t;

/*!
 * @name Constants and macros for entire CAN_IFLAG1 register
 */
/*@{*/
#define HW_CAN_IFLAG1_ADDR(x)    ((uintptr_t)(x) + 0x30U)

#define HW_CAN_IFLAG1(x)         (*(__IO hw_can_iflag1_t *) HW_CAN_IFLAG1_ADDR(x))
#define HW_CAN_IFLAG1_RD(x)      (HW_CAN_IFLAG1(x).U)
#define HW_CAN_IFLAG1_WR(x, v)   (HW_CAN_IFLAG1(x).U = (v))
#define HW_CAN_IFLAG1_SET(x, v)  (HW_CAN_IFLAG1_WR(x, HW_CAN_IFLAG1_RD(x) |  (v)))
#define HW_CAN_IFLAG1_CLR(x, v)  (HW_CAN_IFLAG1_WR(x, HW_CAN_IFLAG1_RD(x) & ~(v)))
#define HW_CAN_IFLAG1_TOG(x, v)  (HW_CAN_IFLAG1_WR(x, HW_CAN_IFLAG1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_IFLAG1 bitfields
 */

/*!
 * @name Register CAN_IFLAG1, field BUF4I_BUF0I[4:0] (RW)
 *
 * If the Rx FIFO is not enabled, these bits flag the interrupts for MB0 to MB4.
 * If the Rx FIFO is enabled, these flags are not used and must be considered as
 * reserved locations. These flags are cleared by the FlexCAN whenever the bit
 * MCR[RFEN] is changed by ARM writes.
 *
 * Values:
 * - 1 - Corresponding MB completed transmission/reception
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_IFLAG1_BUF4I_BUF0I (0U)     /*!< Bit position for CAN_IFLAG1_BUF4I_BUF0I. */
#define BM_CAN_IFLAG1_BUF4I_BUF0I (0x0000001FU) /*!< Bit mask for CAN_IFLAG1_BUF4I_BUF0I. */
#define BS_CAN_IFLAG1_BUF4I_BUF0I (5U)     /*!< Bit field size in bits for CAN_IFLAG1_BUF4I_BUF0I. */

/*! @brief Read current value of the CAN_IFLAG1_BUF4I_BUF0I field. */
#define BR_CAN_IFLAG1_BUF4I_BUF0I(x) (HW_CAN_IFLAG1(x).B.BUF4I_BUF0I)

/*! @brief Format value for bitfield CAN_IFLAG1_BUF4I_BUF0I. */
#define BF_CAN_IFLAG1_BUF4I_BUF0I(v) ((uint32_t)((uint32_t)(v) << BP_CAN_IFLAG1_BUF4I_BUF0I) & BM_CAN_IFLAG1_BUF4I_BUF0I)

/*! @brief Set the BUF4I_BUF0I field to a new value. */
#define BW_CAN_IFLAG1_BUF4I_BUF0I(x, v) (HW_CAN_IFLAG1_WR(x, (HW_CAN_IFLAG1_RD(x) & ~BM_CAN_IFLAG1_BUF4I_BUF0I) | BF_CAN_IFLAG1_BUF4I_BUF0I(v)))
/*@}*/

/*!
 * @name Register CAN_IFLAG1, field BUF5I[5] (RW)
 *
 * If the Rx FIFO is not enabled, this bit flags the interrupt for MB5. If the
 * Rx FIFO is enabled, this flag indicates that at least one frame is available to
 * be read from the Rx FIFO. This flag is cleared by the FlexCAN whenever the
 * bit MCR[RFEN] is changed by ARM writes.
 *
 * Values:
 * - 1 - MB5 completed transmission/reception or frames available in the FIFO
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_IFLAG1_BUF5I  (5U)          /*!< Bit position for CAN_IFLAG1_BUF5I. */
#define BM_CAN_IFLAG1_BUF5I  (0x00000020U) /*!< Bit mask for CAN_IFLAG1_BUF5I. */
#define BS_CAN_IFLAG1_BUF5I  (1U)          /*!< Bit field size in bits for CAN_IFLAG1_BUF5I. */

/*! @brief Read current value of the CAN_IFLAG1_BUF5I field. */
#define BR_CAN_IFLAG1_BUF5I(x) (HW_CAN_IFLAG1(x).B.BUF5I)

/*! @brief Format value for bitfield CAN_IFLAG1_BUF5I. */
#define BF_CAN_IFLAG1_BUF5I(v) ((uint32_t)((uint32_t)(v) << BP_CAN_IFLAG1_BUF5I) & BM_CAN_IFLAG1_BUF5I)

/*! @brief Set the BUF5I field to a new value. */
#define BW_CAN_IFLAG1_BUF5I(x, v) (HW_CAN_IFLAG1_WR(x, (HW_CAN_IFLAG1_RD(x) & ~BM_CAN_IFLAG1_BUF5I) | BF_CAN_IFLAG1_BUF5I(v)))
/*@}*/

/*!
 * @name Register CAN_IFLAG1, field BUF6I[6] (RW)
 *
 * If the Rx FIFO is not enabled, this bit flags the interrupt for MB6. If the
 * MCR[RFEN] bit is asserted, this flag indicates when the number of unread
 * messages within the Rx FIFO is increased to 5 from 4 due to the reception of a new
 * one, meaning that the Rx FIFO is almost full. Note that if the flag is cleared
 * while the number of unread messages is greater than 4 it will not assert again
 * until the number of unread messages within the Rx FIFO is decreased to equal
 * or less than 4. This flag is cleared by the FlexCAN whenever the bit MCR[RFEN]
 * is changed by ARM writes.
 *
 * Values:
 * - 1 - MB6 completed transmission/reception or FIFO almost full
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_IFLAG1_BUF6I  (6U)          /*!< Bit position for CAN_IFLAG1_BUF6I. */
#define BM_CAN_IFLAG1_BUF6I  (0x00000040U) /*!< Bit mask for CAN_IFLAG1_BUF6I. */
#define BS_CAN_IFLAG1_BUF6I  (1U)          /*!< Bit field size in bits for CAN_IFLAG1_BUF6I. */

/*! @brief Read current value of the CAN_IFLAG1_BUF6I field. */
#define BR_CAN_IFLAG1_BUF6I(x) (HW_CAN_IFLAG1(x).B.BUF6I)

/*! @brief Format value for bitfield CAN_IFLAG1_BUF6I. */
#define BF_CAN_IFLAG1_BUF6I(v) ((uint32_t)((uint32_t)(v) << BP_CAN_IFLAG1_BUF6I) & BM_CAN_IFLAG1_BUF6I)

/*! @brief Set the BUF6I field to a new value. */
#define BW_CAN_IFLAG1_BUF6I(x, v) (HW_CAN_IFLAG1_WR(x, (HW_CAN_IFLAG1_RD(x) & ~BM_CAN_IFLAG1_BUF6I) | BF_CAN_IFLAG1_BUF6I(v)))
/*@}*/

/*!
 * @name Register CAN_IFLAG1, field BUF7I[7] (RW)
 *
 * If the Rx FIFO is not enabled, this bit flags the interrupt for MB7. If the
 * MCR[RFEN] bit is asserted, this flag indicates that a message was lost because
 * Rx FIFO is full. Note that the flag will not be asserted when the Rx FIFO is
 * full and the message was captured by a Mailbox. This flag is cleared by the
 * FlexCAN whenever the bit MCR[RFEN] is changed by ARM writes.
 *
 * Values:
 * - 1 - MB7 completed transmission/reception or FIFO overflow
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_IFLAG1_BUF7I  (7U)          /*!< Bit position for CAN_IFLAG1_BUF7I. */
#define BM_CAN_IFLAG1_BUF7I  (0x00000080U) /*!< Bit mask for CAN_IFLAG1_BUF7I. */
#define BS_CAN_IFLAG1_BUF7I  (1U)          /*!< Bit field size in bits for CAN_IFLAG1_BUF7I. */

/*! @brief Read current value of the CAN_IFLAG1_BUF7I field. */
#define BR_CAN_IFLAG1_BUF7I(x) (HW_CAN_IFLAG1(x).B.BUF7I)

/*! @brief Format value for bitfield CAN_IFLAG1_BUF7I. */
#define BF_CAN_IFLAG1_BUF7I(v) ((uint32_t)((uint32_t)(v) << BP_CAN_IFLAG1_BUF7I) & BM_CAN_IFLAG1_BUF7I)

/*! @brief Set the BUF7I field to a new value. */
#define BW_CAN_IFLAG1_BUF7I(x, v) (HW_CAN_IFLAG1_WR(x, (HW_CAN_IFLAG1_RD(x) & ~BM_CAN_IFLAG1_BUF7I) | BF_CAN_IFLAG1_BUF7I(v)))
/*@}*/

/*!
 * @name Register CAN_IFLAG1, field BUF31I_BUF8I[31:8] (RW)
 *
 * Each bit flags the respective FLEXCAN Message Buffer (MB8 to MB31) interrupt.
 *
 * Values:
 * - 1 - The corresponding MB has successfully completed transmission or
 *     reception
 * - 0 - No such occurrence
 */
/*@{*/
#define BP_CAN_IFLAG1_BUF31I_BUF8I (8U)    /*!< Bit position for CAN_IFLAG1_BUF31I_BUF8I. */
#define BM_CAN_IFLAG1_BUF31I_BUF8I (0xFFFFFF00U) /*!< Bit mask for CAN_IFLAG1_BUF31I_BUF8I. */
#define BS_CAN_IFLAG1_BUF31I_BUF8I (24U)   /*!< Bit field size in bits for CAN_IFLAG1_BUF31I_BUF8I. */

/*! @brief Read current value of the CAN_IFLAG1_BUF31I_BUF8I field. */
#define BR_CAN_IFLAG1_BUF31I_BUF8I(x) (HW_CAN_IFLAG1(x).B.BUF31I_BUF8I)

/*! @brief Format value for bitfield CAN_IFLAG1_BUF31I_BUF8I. */
#define BF_CAN_IFLAG1_BUF31I_BUF8I(v) ((uint32_t)((uint32_t)(v) << BP_CAN_IFLAG1_BUF31I_BUF8I) & BM_CAN_IFLAG1_BUF31I_BUF8I)

/*! @brief Set the BUF31I_BUF8I field to a new value. */
#define BW_CAN_IFLAG1_BUF31I_BUF8I(x, v) (HW_CAN_IFLAG1_WR(x, (HW_CAN_IFLAG1_RD(x) & ~BM_CAN_IFLAG1_BUF31I_BUF8I) | BF_CAN_IFLAG1_BUF31I_BUF8I(v)))
/*@}*/

/*******************************************************************************
 * HW_CAN_CTRL2 - Control 2 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_CTRL2 - Control 2 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains control bits for CAN errors, FIFO features and mode
 * selection. Rx FIFO Filters RFFN[3:0] Number of Rx FIFO filters Message Buffers
 * occupied by Rx FIFO and ID Filter Table Remaining Available Mailboxes The
 * number of the last remaining available mailboxes is defined by the MCR[MAXMB]
 * field. Rx FIFO ID Filter Table Elements Affected by Rx Individual Masks If Rx
 * Individual Mask Registers are not enabled then all Rx FIFO filters are affected by
 * the Rx FIFO Global Mask. Rx FIFO ID Filter Table Elements Affected by Rx FIFO
 * Global Mask 0x0 8 MB 0-7 MB 8-63 Elements 0-7 none 0x1 16 MB 0-9 MB 10-63
 * Elements 0-9 Elements 10-15 0x2 24 MB 0-11 MB 12-63 Elements 0-11 Elements 12-23
 * 0x3 32 MB 0-13 MB 14-63 Elements 0-13 Elements 14-31 0x4 40 MB 0-15 MB 16-63
 * Elements 0-15 Elements 16-39 0x5 48 MB 0-17 MB 18-63 Elements 0-17 Elements
 * 18-47 0x6 56 MB 0-19 MB 20-63 Elements 0-19 Elements 20-55 0x7 64 MB 0-21 MB 22-63
 * Elements 0-21 Elements 22-63 0x8 72 MB 0-23 MB 24-63 Elements 0-23 Elements
 * 24-71 0x9 80 MB 0-25 MB 26-63 Elements 0-25 Elements 26-79 0xA 88 MB 0-27 MB
 * 28-63 Elements 0-27 Elements 28-87 0xB 96 MB 0-29 MB 30-63 Elements 0-29
 * Elements 30-95 0xC 104 MB 0-31 MB 32-63 Elements 0-31 Elements 32-103 0xD 112 MB 0-33
 * MB 34-63 Elements 0-31 Elements 32-111 0xE 120 MB 0-35 MB 36-63 Elements 0-31
 * Elements 32-119 0xF 128 MB 0-37 MB 38-63 Elements 0-31 Elements 32-127 Each
 * group of eight filters occupies a memory space equivalent to two Message
 * Buffers which means that the more filters are implemented the less Mailboxes will be
 * available. Considering that the Rx FIFO occupies the memory space originally
 * reserved for MB0-5, RFFN should be programmed with a value corresponding to a
 * number of filters not greater than the number of available memory words which
 * can be calculated as follows: where SETUP_MB is MAXMB. The number of remaining
 * Mailboxes available will be: If the Number of Rx FIFO Filters programmed
 * through RFFN exceeds the SETUP_MB value, the exceeding ones will not be
 * functional.Unshaded regions in indicate the valid combinations of MAXMB, RFEN and RFFN,
 * shaded regions are not functional. Valid Combinations of MAXMB, RFEN and RFFN
 * RFFN 0 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 RFEN 0 1 1 1 1 1 1 1 1 1 1 1 1 1
 * 1 1 1 MAXMB 0 - 6 7 - 8 9 - 10 11 - 12 13 -14 15 - 16 17 -18 19 - 20 21 - 22
 * 23 - 24 25 - 26 27 - 28 29 -30 31 - 32 33 - 34 35 - 36 37 - 63
 */
typedef union _hw_can_ctrl2
{
    uint32_t U;
    struct _hw_can_ctrl2_bitfields
    {
        uint32_t RESERVED0 : 16;       /*!< [15:0]  */
        uint32_t EACEN : 1;            /*!< [16]  */
        uint32_t RRS : 1;              /*!< [17]  */
        uint32_t MRP : 1;              /*!< [18]  */
        uint32_t TASD : 5;             /*!< [23:19]  */
        uint32_t RFFN : 4;             /*!< [27:24]  */
        uint32_t WRMFRZ : 1;           /*!< [28]  */
        uint32_t RESERVED1 : 3;        /*!< [31:29]  */
    } B;
} hw_can_ctrl2_t;

/*!
 * @name Constants and macros for entire CAN_CTRL2 register
 */
/*@{*/
#define HW_CAN_CTRL2_ADDR(x)     ((uintptr_t)(x) + 0x34U)

#define HW_CAN_CTRL2(x)          (*(__IO hw_can_ctrl2_t *) HW_CAN_CTRL2_ADDR(x))
#define HW_CAN_CTRL2_RD(x)       (HW_CAN_CTRL2(x).U)
#define HW_CAN_CTRL2_WR(x, v)    (HW_CAN_CTRL2(x).U = (v))
#define HW_CAN_CTRL2_SET(x, v)   (HW_CAN_CTRL2_WR(x, HW_CAN_CTRL2_RD(x) |  (v)))
#define HW_CAN_CTRL2_CLR(x, v)   (HW_CAN_CTRL2_WR(x, HW_CAN_CTRL2_RD(x) & ~(v)))
#define HW_CAN_CTRL2_TOG(x, v)   (HW_CAN_CTRL2_WR(x, HW_CAN_CTRL2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_CTRL2 bitfields
 */

/*!
 * @name Register CAN_CTRL2, field EACEN[16] (RW)
 *
 * This bit controls the comparison of IDE and RTR bits within Rx Mailboxes
 * filters with their corresponding bits in the incoming frame by the matching
 * process. This bit does not affect matching for Rx FIFO. This bit can only be written
 * in Freeze mode as it is blocked by hardware in other modes.
 *
 * Values:
 * - 1 - Enables the comparison of both Rx Mailbox filter's IDE and RTR bit with
 *     their corresponding bits within the incoming frame. Mask bits do apply.
 * - 0 - Rx Mailbox filter's IDE bit is always compared and RTR is never
 *     compared despite mask bits.
 */
/*@{*/
#define BP_CAN_CTRL2_EACEN   (16U)         /*!< Bit position for CAN_CTRL2_EACEN. */
#define BM_CAN_CTRL2_EACEN   (0x00010000U) /*!< Bit mask for CAN_CTRL2_EACEN. */
#define BS_CAN_CTRL2_EACEN   (1U)          /*!< Bit field size in bits for CAN_CTRL2_EACEN. */

/*! @brief Read current value of the CAN_CTRL2_EACEN field. */
#define BR_CAN_CTRL2_EACEN(x) (HW_CAN_CTRL2(x).B.EACEN)

/*! @brief Format value for bitfield CAN_CTRL2_EACEN. */
#define BF_CAN_CTRL2_EACEN(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL2_EACEN) & BM_CAN_CTRL2_EACEN)

/*! @brief Set the EACEN field to a new value. */
#define BW_CAN_CTRL2_EACEN(x, v) (HW_CAN_CTRL2_WR(x, (HW_CAN_CTRL2_RD(x) & ~BM_CAN_CTRL2_EACEN) | BF_CAN_CTRL2_EACEN(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL2, field RRS[17] (RW)
 *
 * If this bit is asserted Remote Request Frame is submitted to a matching
 * process and stored in the corresponding Message Buffer in the same fashion of a
 * Data Frame. No automatic Remote Response Frame will be generated. If this bit is
 * negated the Remote Request Frame is submitted to a matching process and an
 * automatic Remote Response Frame is generated if a Message Buffer with CODE=0b1010
 * is found with the same ID. This bit can only be written in Freeze mode as it
 * is blocked by hardware in other modes.
 *
 * Values:
 * - 1 - Remote Request Frame is stored
 * - 0 - Remote Response Frame is generated
 */
/*@{*/
#define BP_CAN_CTRL2_RRS     (17U)         /*!< Bit position for CAN_CTRL2_RRS. */
#define BM_CAN_CTRL2_RRS     (0x00020000U) /*!< Bit mask for CAN_CTRL2_RRS. */
#define BS_CAN_CTRL2_RRS     (1U)          /*!< Bit field size in bits for CAN_CTRL2_RRS. */

/*! @brief Read current value of the CAN_CTRL2_RRS field. */
#define BR_CAN_CTRL2_RRS(x)  (HW_CAN_CTRL2(x).B.RRS)

/*! @brief Format value for bitfield CAN_CTRL2_RRS. */
#define BF_CAN_CTRL2_RRS(v)  ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL2_RRS) & BM_CAN_CTRL2_RRS)

/*! @brief Set the RRS field to a new value. */
#define BW_CAN_CTRL2_RRS(x, v) (HW_CAN_CTRL2_WR(x, (HW_CAN_CTRL2_RD(x) & ~BM_CAN_CTRL2_RRS) | BF_CAN_CTRL2_RRS(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL2, field MRP[18] (RW)
 *
 * If this bit is set the matching process starts from the Mailboxes and if no
 * match occurs the matching continues on the Rx FIFO. This bit can only be
 * written in Freeze mode as it is blocked by hardware in other modes.
 *
 * Values:
 * - 1 - Matching starts from Mailboxes and continues on Rx FIFO
 * - 0 - Matching starts from Rx FIFO and continues on Mailboxes
 */
/*@{*/
#define BP_CAN_CTRL2_MRP     (18U)         /*!< Bit position for CAN_CTRL2_MRP. */
#define BM_CAN_CTRL2_MRP     (0x00040000U) /*!< Bit mask for CAN_CTRL2_MRP. */
#define BS_CAN_CTRL2_MRP     (1U)          /*!< Bit field size in bits for CAN_CTRL2_MRP. */

/*! @brief Read current value of the CAN_CTRL2_MRP field. */
#define BR_CAN_CTRL2_MRP(x)  (HW_CAN_CTRL2(x).B.MRP)

/*! @brief Format value for bitfield CAN_CTRL2_MRP. */
#define BF_CAN_CTRL2_MRP(v)  ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL2_MRP) & BM_CAN_CTRL2_MRP)

/*! @brief Set the MRP field to a new value. */
#define BW_CAN_CTRL2_MRP(x, v) (HW_CAN_CTRL2_WR(x, (HW_CAN_CTRL2_RD(x) & ~BM_CAN_CTRL2_MRP) | BF_CAN_CTRL2_MRP(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL2, field TASD[23:19] (RW)
 *
 * This 5-bit field indicates how many CAN bits the Tx arbitration process start
 * point can be delayed from the first bit of CRC field on CAN bus. This field
 * can only be written in Freeze mode as it is blocked by hardware in other modes.
 * This field is useful to optimize the transmit performance based on factors
 * such as: peripheral/serial clock ratio, CAN bit timing and number of MBs. The
 * duration of an arbitration process, in terms of CAN bits, is directly
 * proportional to the number of available MBs and CAN baud rate and inversely proportional
 * to the peripheral clock frequency. The optimal arbitration timing is that in
 * which the last MB is scanned right before the first bit of the Intermission
 * field of a CAN frame. Therefore, if there are few MBs and the system/serial
 * clock ratio is high and the CAN baud rate is low then the arbitration can be
 * delayed and vice-versa. If TASD is 0 then the arbitration start is not delayed,
 * thus ARM has less time to configure a Tx MB for the next arbitration, but more
 * time is reserved for arbitration. In the other hand, if TASD is 24 then ARM can
 * configure a Tx MB later and less time is reserved for arbitration. If too
 * little time is reserved for arbitration the FlexCAN may be not able to find winner
 * MBs in time to compete with other nodes for the CAN bus. If the arbitration
 * ends too much time before the first bit of Intermission field then there is a
 * chance that ARM reconfigure some Tx MBs and the winner MB is not the best to be
 * transmitted. The reset value is different on various platforms, according to
 * their peripheral clock frequency, number of MBs and target CAN baud rate. The
 * optimal configuration for TASD can be calculated as: where: fCANCLK is the
 * Protocol Engine (PE) Clock in Hz; PE clock is derrived from CAN_CLK_ROOT in CCM.
 * See Clock Root GeneratorThe Clock Root Generator (CCM_CLK_ROOT_GEN) sub-module
 * generates the root clocks to be delivered to LPCG. fSYS is the peripheral
 * clock in Hz; MAXMB is the value in CTRL1[MAXMB] field; RFEN is the value in
 * CTRL1[RFEN] bit; RFFN is the value in CTRL2[RFFN] field; PSEG1 is the value in
 * CTRL1[PSEG1] field; PSEG2 is the value in CTRL1[PSEG2] field; PROPSEG is the value
 * in CTRL1[PROPSEG] field; PRESDIV is the value in CTRL1[PRESDIV] field. Please
 * refer to Arbitration processThe arbitration process scans the Mailboxes
 * searching the Tx one that holds the message to be sent in the next opportunity.
 * This Mailbox is called the arbitration winner. and Protocol Timing for more
 * details.
 */
/*@{*/
#define BP_CAN_CTRL2_TASD    (19U)         /*!< Bit position for CAN_CTRL2_TASD. */
#define BM_CAN_CTRL2_TASD    (0x00F80000U) /*!< Bit mask for CAN_CTRL2_TASD. */
#define BS_CAN_CTRL2_TASD    (5U)          /*!< Bit field size in bits for CAN_CTRL2_TASD. */

/*! @brief Read current value of the CAN_CTRL2_TASD field. */
#define BR_CAN_CTRL2_TASD(x) (HW_CAN_CTRL2(x).B.TASD)

/*! @brief Format value for bitfield CAN_CTRL2_TASD. */
#define BF_CAN_CTRL2_TASD(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL2_TASD) & BM_CAN_CTRL2_TASD)

/*! @brief Set the TASD field to a new value. */
#define BW_CAN_CTRL2_TASD(x, v) (HW_CAN_CTRL2_WR(x, (HW_CAN_CTRL2_RD(x) & ~BM_CAN_CTRL2_TASD) | BF_CAN_CTRL2_TASD(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL2, field RFFN[27:24] (RW)
 *
 * This 4-bit field defines the number of Rx FIFO filters according to . The
 * maximum selectable number of filters is determined by the ARM. This field can
 * only be written in Freeze mode as it is blocked by hardware in other modes. RFFN
 * defines a number of Message Buffers occupied by Rx FIFO and ID Filter (see )
 * that may not e xceed the number of available Mailboxes present in module,
 * defined by MCR[MAXMB].Default RFFN value is 0x0, which leads to a total of 8 Rx
 * FIFO filters, occupies the first 8 Message Buffers (MB 0-7) and makes available
 * the next Message Buffers (MB 8-63) for Mailboxes. As a second example, when
 * RFFN is set to 0xD, there will be 112 Rx FIFO filters, located in MB 0-33, and MB
 * 34-63 are available for Mailboxes. Notice that, in this case, individual
 * masks (RXIMR) will just cover Rx FIFO filters in 0-31 range, and filters 32-111
 * will use RXFGMASK. In case of reducing the number of last Message Buffers,
 * MCR[MAXMB] (see MCRModule Configuration Register ) can be adjusted by the
 * application to minimum of 33, in order to give room to the Rx FIFO and its ID Filter
 * Table defined by RFFN. On the contrary, if the application sets MCR[MAXMB] to
 * 16, for instance, the maximum RFFN is limited to 0x4. RFFN also impacts the
 * definition of the minimum number of peripheral clocks per CAN bit as described in
 * (see Arbitration and Matching Timing).
 */
/*@{*/
#define BP_CAN_CTRL2_RFFN    (24U)         /*!< Bit position for CAN_CTRL2_RFFN. */
#define BM_CAN_CTRL2_RFFN    (0x0F000000U) /*!< Bit mask for CAN_CTRL2_RFFN. */
#define BS_CAN_CTRL2_RFFN    (4U)          /*!< Bit field size in bits for CAN_CTRL2_RFFN. */

/*! @brief Read current value of the CAN_CTRL2_RFFN field. */
#define BR_CAN_CTRL2_RFFN(x) (HW_CAN_CTRL2(x).B.RFFN)

/*! @brief Format value for bitfield CAN_CTRL2_RFFN. */
#define BF_CAN_CTRL2_RFFN(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL2_RFFN) & BM_CAN_CTRL2_RFFN)

/*! @brief Set the RFFN field to a new value. */
#define BW_CAN_CTRL2_RFFN(x, v) (HW_CAN_CTRL2_WR(x, (HW_CAN_CTRL2_RD(x) & ~BM_CAN_CTRL2_RFFN) | BF_CAN_CTRL2_RFFN(v)))
/*@}*/

/*!
 * @name Register CAN_CTRL2, field WRMFRZ[28] (RW)
 *
 * Enable unrestricted write access to FlexCAN memory in Freeze mode. This bit
 * can only be written in Freeze mode and has no effect out of Freeze mode.
 *
 * Values:
 * - 1 - Enable unrestricted write access to FlexCAN memory
 * - 0 - Keep the write access restricted in some regions of FlexCAN memory
 */
/*@{*/
#define BP_CAN_CTRL2_WRMFRZ  (28U)         /*!< Bit position for CAN_CTRL2_WRMFRZ. */
#define BM_CAN_CTRL2_WRMFRZ  (0x10000000U) /*!< Bit mask for CAN_CTRL2_WRMFRZ. */
#define BS_CAN_CTRL2_WRMFRZ  (1U)          /*!< Bit field size in bits for CAN_CTRL2_WRMFRZ. */

/*! @brief Read current value of the CAN_CTRL2_WRMFRZ field. */
#define BR_CAN_CTRL2_WRMFRZ(x) (HW_CAN_CTRL2(x).B.WRMFRZ)

/*! @brief Format value for bitfield CAN_CTRL2_WRMFRZ. */
#define BF_CAN_CTRL2_WRMFRZ(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CTRL2_WRMFRZ) & BM_CAN_CTRL2_WRMFRZ)

/*! @brief Set the WRMFRZ field to a new value. */
#define BW_CAN_CTRL2_WRMFRZ(x, v) (HW_CAN_CTRL2_WR(x, (HW_CAN_CTRL2_RD(x) & ~BM_CAN_CTRL2_WRMFRZ) | BF_CAN_CTRL2_WRMFRZ(v)))
/*@}*/

/*******************************************************************************
 * HW_CAN_ESR2 - Error and Status 2 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_ESR2 - Error and Status 2 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register reflects various interrupt flags and some general status.
 */
typedef union _hw_can_esr2
{
    uint32_t U;
    struct _hw_can_esr2_bitfields
    {
        uint32_t RESERVED0 : 13;       /*!< [12:0]  */
        uint32_t IMB : 1;              /*!< [13]  */
        uint32_t VPS : 1;              /*!< [14]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t LPTM : 7;             /*!< [22:16]  */
        uint32_t RESERVED2 : 9;        /*!< [31:23]  */
    } B;
} hw_can_esr2_t;

/*!
 * @name Constants and macros for entire CAN_ESR2 register
 */
/*@{*/
#define HW_CAN_ESR2_ADDR(x)      ((uintptr_t)(x) + 0x38U)

#define HW_CAN_ESR2(x)           (*(__I hw_can_esr2_t *) HW_CAN_ESR2_ADDR(x))
#define HW_CAN_ESR2_RD(x)        (HW_CAN_ESR2(x).U)
/*@}*/

/*
 * Constants & macros for individual CAN_ESR2 bitfields
 */

/*!
 * @name Register CAN_ESR2, field IMB[13] (RO)
 *
 * If ESR2[VPS] is asserted, this bit indicates whether there is any inactive
 * Mailbox (CODE field is either 0b1000 or 0b0000). This bit is asserted in the
 * following cases: (1) During arbitration, if a LPTM is found and it is inactive.
 * (2) If IMB is not asserted and a frame is transmitted successfully. (3) This
 * bit is cleared in all start of arbitration (see Arbitration processThe
 * arbitration process scans the Mailboxes searching the Tx one that holds the message to
 * be sent in the next opportunity. This Mailbox is called the arbitration
 * winner. ). LPTM mechanism have the following behavior: if a MB is successfully
 * transmitted and ESR2[IMB]=0 (no inactive Mailbox), then ESR2[VPS] and ESR2[IMB] are
 * asserted and the index related to the MB just transmitted is loaded into
 * ESR2[LPTM].
 *
 * Values:
 * - 1 - If ESR2[VPS] is asserted, there is at least one inactive Mailbox. LPTM
 *     content is the number of the first one.
 * - 0 - If ESR2[VPS] is asserted, the ESR2[LPTM] is not an inactive Mailbox.
 */
/*@{*/
#define BP_CAN_ESR2_IMB      (13U)         /*!< Bit position for CAN_ESR2_IMB. */
#define BM_CAN_ESR2_IMB      (0x00002000U) /*!< Bit mask for CAN_ESR2_IMB. */
#define BS_CAN_ESR2_IMB      (1U)          /*!< Bit field size in bits for CAN_ESR2_IMB. */

/*! @brief Read current value of the CAN_ESR2_IMB field. */
#define BR_CAN_ESR2_IMB(x)   (HW_CAN_ESR2(x).B.IMB)
/*@}*/

/*!
 * @name Register CAN_ESR2, field VPS[14] (RO)
 *
 * This bit indicates whether IMB and LPTM contents are currently valid or not.
 * VPS is asserted upon every complete Tx arbitration process unless the ARM
 * writes to Control and Status word of a Mailbox that has already been scanned (i.e.
 * it is behind Tx Arbitration Pointer) during the Tx arbitration process. If
 * there is no inactive Mailbox and only one Tx Mailbox which is being transmitted
 * then VPS is not asserted. VPS is negated upon the start of every Tx
 * arbitration process or upon a write to Control and Status word of any Mailbox.ESR2[VPS]
 * is not affected by any ARM write into Control Status (C/S) of a MB which is
 * blocked by abort mechanism. When MCR[AEN] is asserted, the abort code write in
 * C/S of a MB that is been transmitted (pending abort), or any write attempt into
 * a Tx MB with IFLAG set is blocked.
 *
 * Values:
 * - 1 - Contents of IMB and LPTM are valid
 * - 0 - Contents of IMB and LPTM are invalid
 */
/*@{*/
#define BP_CAN_ESR2_VPS      (14U)         /*!< Bit position for CAN_ESR2_VPS. */
#define BM_CAN_ESR2_VPS      (0x00004000U) /*!< Bit mask for CAN_ESR2_VPS. */
#define BS_CAN_ESR2_VPS      (1U)          /*!< Bit field size in bits for CAN_ESR2_VPS. */

/*! @brief Read current value of the CAN_ESR2_VPS field. */
#define BR_CAN_ESR2_VPS(x)   (HW_CAN_ESR2(x).B.VPS)
/*@}*/

/*!
 * @name Register CAN_ESR2, field LPTM[22:16] (RO)
 *
 * If ESR2[VPS] is asserted, his 7-bit field indicates the lowest number
 * inactive Mailbox (refer to IMB bit description). If there is no inactive Mailbox then
 * the Mailbox indicated depends on CTRL1[LBUF] bit value. If CTRL1[LBUF] bit is
 * negated then the Mailbox indicated is the one which has the greatest
 * arbitration value (see Highest Mailbox priority firstIf CTRL1[LBUF] bit is negated
 * then the arbitration process searches the active Tx Mailbox with the highest
 * priority, and this Mailbox would have a higher probability to win the arbitration
 * on CAN bus. ). If CTRL1[LBUF] bit is asserted then the Mailbox indicated is
 * the highest number active Tx Mailbox. If a Tx Mailbox is being transmitted it is
 * not considered in LPTM calculation. If ESR2[IMB] is not asserted and a frame
 * is transmitted successfully, LPTM is updated with its Mailbox number.
 */
/*@{*/
#define BP_CAN_ESR2_LPTM     (16U)         /*!< Bit position for CAN_ESR2_LPTM. */
#define BM_CAN_ESR2_LPTM     (0x007F0000U) /*!< Bit mask for CAN_ESR2_LPTM. */
#define BS_CAN_ESR2_LPTM     (7U)          /*!< Bit field size in bits for CAN_ESR2_LPTM. */

/*! @brief Read current value of the CAN_ESR2_LPTM field. */
#define BR_CAN_ESR2_LPTM(x)  (HW_CAN_ESR2(x).B.LPTM)
/*@}*/

/*******************************************************************************
 * HW_CAN_CRCR - CRC Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_CRCR - CRC Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register provides information about the CRC of transmitted messages
 */
typedef union _hw_can_crcr
{
    uint32_t U;
    struct _hw_can_crcr_bitfields
    {
        uint32_t TXCRC : 15;           /*!< [14:0]  */
        uint32_t RESERVED0 : 1;        /*!< [15]  */
        uint32_t MBCRC : 7;            /*!< [22:16]  */
        uint32_t RESERVED1 : 9;        /*!< [31:23]  */
    } B;
} hw_can_crcr_t;

/*!
 * @name Constants and macros for entire CAN_CRCR register
 */
/*@{*/
#define HW_CAN_CRCR_ADDR(x)      ((uintptr_t)(x) + 0x44U)

#define HW_CAN_CRCR(x)           (*(__I hw_can_crcr_t *) HW_CAN_CRCR_ADDR(x))
#define HW_CAN_CRCR_RD(x)        (HW_CAN_CRCR(x).U)
/*@}*/

/*
 * Constants & macros for individual CAN_CRCR bitfields
 */

/*!
 * @name Register CAN_CRCR, field TXCRC[14:0] (RO)
 *
 * This field indicates the CRC value of the last message transmitted. This
 * field is updated at the same time the Tx Interrupt Flag is asserted.
 */
/*@{*/
#define BP_CAN_CRCR_TXCRC    (0U)          /*!< Bit position for CAN_CRCR_TXCRC. */
#define BM_CAN_CRCR_TXCRC    (0x00007FFFU) /*!< Bit mask for CAN_CRCR_TXCRC. */
#define BS_CAN_CRCR_TXCRC    (15U)         /*!< Bit field size in bits for CAN_CRCR_TXCRC. */

/*! @brief Read current value of the CAN_CRCR_TXCRC field. */
#define BR_CAN_CRCR_TXCRC(x) (HW_CAN_CRCR(x).B.TXCRC)
/*@}*/

/*!
 * @name Register CAN_CRCR, field MBCRC[22:16] (RO)
 *
 * This field indicates the number of the Mailbox corresponding to the value in
 * TXCRC field.
 */
/*@{*/
#define BP_CAN_CRCR_MBCRC    (16U)         /*!< Bit position for CAN_CRCR_MBCRC. */
#define BM_CAN_CRCR_MBCRC    (0x007F0000U) /*!< Bit mask for CAN_CRCR_MBCRC. */
#define BS_CAN_CRCR_MBCRC    (7U)          /*!< Bit field size in bits for CAN_CRCR_MBCRC. */

/*! @brief Read current value of the CAN_CRCR_MBCRC field. */
#define BR_CAN_CRCR_MBCRC(x) (HW_CAN_CRCR(x).B.MBCRC)
/*@}*/

/*******************************************************************************
 * HW_CAN_RXFGMASK - Rx FIFO Global Mask Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_RXFGMASK - Rx FIFO Global Mask Register (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * If Rx FIFO is enabled RXFGMASK is used to mask the Rx FIFO ID Filter Table
 * elements that do not have a corresponding RXIMR according to CTRL2[RFFN] field
 * setting. This register can only be written in Freeze Mode as it is blocked by
 * hardware in other modes. Rx FIFO Global Mask usage Rx FIFO ID Filter Table
 * Elements Format (MCR[IDAM]) Identifier Acceptance Filter fields RTR IDE RXIDA
 * RXIDB RXIDC reserved A FGM[31] FGM[30] FGM[29:1] - - FGM[0] B FGM[31] FGM[15]
 * FGM[30] FGM[14] - FGM[29:16] FGM[13:0] If MCR[IDAM] field is equivalent to the
 * format B only the fourteen most significant bits of the Identifier of the
 * incoming frame are compared with the Rx FIFO filter. - C - - - FGM[31:24] FGM[23:16]
 * FGM[15:8] FGM[7:0] If MCR[IDAM] field is equivalent to the format C only the
 * eight most significant bits of the Identifier of the incoming frame are
 * compared with the Rx FIFO filter.
 */
typedef union _hw_can_rxfgmask
{
    uint32_t U;
    struct _hw_can_rxfgmask_bitfields
    {
        uint32_t FGM31_FGM0 : 32;      /*!< [31:0]  */
    } B;
} hw_can_rxfgmask_t;

/*!
 * @name Constants and macros for entire CAN_RXFGMASK register
 */
/*@{*/
#define HW_CAN_RXFGMASK_ADDR(x)  ((uintptr_t)(x) + 0x48U)

#define HW_CAN_RXFGMASK(x)       (*(__IO hw_can_rxfgmask_t *) HW_CAN_RXFGMASK_ADDR(x))
#define HW_CAN_RXFGMASK_RD(x)    (HW_CAN_RXFGMASK(x).U)
#define HW_CAN_RXFGMASK_WR(x, v) (HW_CAN_RXFGMASK(x).U = (v))
#define HW_CAN_RXFGMASK_SET(x, v) (HW_CAN_RXFGMASK_WR(x, HW_CAN_RXFGMASK_RD(x) |  (v)))
#define HW_CAN_RXFGMASK_CLR(x, v) (HW_CAN_RXFGMASK_WR(x, HW_CAN_RXFGMASK_RD(x) & ~(v)))
#define HW_CAN_RXFGMASK_TOG(x, v) (HW_CAN_RXFGMASK_WR(x, HW_CAN_RXFGMASK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_RXFGMASK bitfields
 */

/*!
 * @name Register CAN_RXFGMASK, field FGM31_FGM0[31:0] (RW)
 *
 * These bits mask the ID Filter Table elements bits in a perfect
 * alignment.RXFGMASKRx FIFO Global Mask Register shows in detail which FGM bits mask each IDAF
 * field. Clear this register has the effect of disabling the ID Filter.
 *
 * Values:
 * - 1 - The corresponding bit in the filter is checked
 * - 0 - The corresponding bit in the filter is "don't care"
 */
/*@{*/
#define BP_CAN_RXFGMASK_FGM31_FGM0 (0U)    /*!< Bit position for CAN_RXFGMASK_FGM31_FGM0. */
#define BM_CAN_RXFGMASK_FGM31_FGM0 (0xFFFFFFFFU) /*!< Bit mask for CAN_RXFGMASK_FGM31_FGM0. */
#define BS_CAN_RXFGMASK_FGM31_FGM0 (32U)   /*!< Bit field size in bits for CAN_RXFGMASK_FGM31_FGM0. */

/*! @brief Read current value of the CAN_RXFGMASK_FGM31_FGM0 field. */
#define BR_CAN_RXFGMASK_FGM31_FGM0(x) (HW_CAN_RXFGMASK(x).U)

/*! @brief Format value for bitfield CAN_RXFGMASK_FGM31_FGM0. */
#define BF_CAN_RXFGMASK_FGM31_FGM0(v) ((uint32_t)((uint32_t)(v) << BP_CAN_RXFGMASK_FGM31_FGM0) & BM_CAN_RXFGMASK_FGM31_FGM0)

/*! @brief Set the FGM31_FGM0 field to a new value. */
#define BW_CAN_RXFGMASK_FGM31_FGM0(x, v) (HW_CAN_RXFGMASK_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_CAN_RXFIR - Rx FIFO Information Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_RXFIR - Rx FIFO Information Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * RXFIR provides information on Rx FIFO. This register is the port through
 * which ARM accesses the output of the RXFIR FIFO located in RAM. The RXFIR FIFO is
 * written by the FlexCAN whenever a new message is moved into the Rx FIFO as
 * well as its output is updated whenever the output of the Rx FIFO is updated with
 * the next message. Refer to Rx FIFOThe receive-only FIFO is enabled by
 * asserting the RFEN bit in the MCR. to find instructions on reading this register.
 */
typedef union _hw_can_rxfir
{
    uint32_t U;
    struct _hw_can_rxfir_bitfields
    {
        uint32_t IDHIT : 9;            /*!< [8:0]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_can_rxfir_t;

/*!
 * @name Constants and macros for entire CAN_RXFIR register
 */
/*@{*/
#define HW_CAN_RXFIR_ADDR(x)     ((uintptr_t)(x) + 0x4CU)

#define HW_CAN_RXFIR(x)          (*(__I hw_can_rxfir_t *) HW_CAN_RXFIR_ADDR(x))
#define HW_CAN_RXFIR_RD(x)       (HW_CAN_RXFIR(x).U)
/*@}*/

/*
 * Constants & macros for individual CAN_RXFIR bitfields
 */

/*!
 * @name Register CAN_RXFIR, field IDHIT[8:0] (RO)
 *
 * This 9-bit field indicates which Identifier Acceptance Filter (see Rx FIFO
 * StructureWhen the MCR[RFEN] bit is set, the memory area from $80 to $DC (which
 * is normally occupied by MBs 0 to 5) is used by the reception FIFO engine. ) was
 * hit by the received message that is in the output of the Rx FIFO. (refer to
 * Rx FIFOThe receive-only FIFO is enabled by asserting the RFEN bit in the MCR.
 * for details) If multiple filters match the incoming message ID then the first
 * matching IDAF found (lowest number) by the matching process is indicated. This
 * field is valid only while the IFLAG[BUF5I] is asserted.
 */
/*@{*/
#define BP_CAN_RXFIR_IDHIT   (0U)          /*!< Bit position for CAN_RXFIR_IDHIT. */
#define BM_CAN_RXFIR_IDHIT   (0x000001FFU) /*!< Bit mask for CAN_RXFIR_IDHIT. */
#define BS_CAN_RXFIR_IDHIT   (9U)          /*!< Bit field size in bits for CAN_RXFIR_IDHIT. */

/*! @brief Read current value of the CAN_RXFIR_IDHIT field. */
#define BR_CAN_RXFIR_IDHIT(x) (HW_CAN_RXFIR(x).B.IDHIT)
/*@}*/

/*******************************************************************************
 * HW_CAN_CSn - Message Buffer 0 CS Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_CSn - Message Buffer 0 CS Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_can_csn
{
    uint32_t U;
    struct _hw_can_csn_bitfields
    {
        uint32_t TIME_STAMP : 16;      /*!< [15:0] Free-Running Counter Time
                                        * stamp. This 16-bit field is a copy of the Free-Running Timer, captured for Tx
                                        * and Rx frames at the time when the beginning of the Identifier field
                                        * appears on the CAN bus. */
        uint32_t DLC : 4;              /*!< [19:16] Length of the data to be
                                        * stored/transmitted. */
        uint32_t RTR : 1;              /*!< [20] Remote Transmission Request. One/zero for
                                        * remote/data frame. */
        uint32_t IDE : 1;              /*!< [21] ID Extended. One/zero for
                                        * extended/standard format frame. */
        uint32_t SRR : 1;              /*!< [22] Substitute Remote Request. Contains a
                                        * fixed recessive bit. */
        uint32_t RESERVED0 : 1;        /*!< [23] Reserved */
        uint32_t CODE : 4;             /*!< [27:24] Reserved */
        uint32_t RESERVED1 : 4;        /*!< [31:28] Reserved */
    } B;
} hw_can_csn_t;

/*!
 * @name Constants and macros for entire CAN_CSn register
 */
/*@{*/
#define HW_CAN_CSn_COUNT (64U)

#define HW_CAN_CSn_ADDR(x, n)    ((uintptr_t)(x) + 0x80U + (0x10U * (n)))

#define HW_CAN_CSn(x, n)         (*(__IO hw_can_csn_t *) HW_CAN_CSn_ADDR(x, n))
#define HW_CAN_CSn_RD(x, n)      (HW_CAN_CSn(x, n).U)
#define HW_CAN_CSn_WR(x, n, v)   (HW_CAN_CSn(x, n).U = (v))
#define HW_CAN_CSn_SET(x, n, v)  (HW_CAN_CSn_WR(x, n, HW_CAN_CSn_RD(x, n) |  (v)))
#define HW_CAN_CSn_CLR(x, n, v)  (HW_CAN_CSn_WR(x, n, HW_CAN_CSn_RD(x, n) & ~(v)))
#define HW_CAN_CSn_TOG(x, n, v)  (HW_CAN_CSn_WR(x, n, HW_CAN_CSn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_CSn bitfields
 */

/*!
 * @name Register CAN_CSn, field TIME_STAMP[15:0] (RW)
 */
/*@{*/
#define BP_CAN_CSn_TIME_STAMP (0U)         /*!< Bit position for CAN_CSn_TIME_STAMP. */
#define BM_CAN_CSn_TIME_STAMP (0x0000FFFFU) /*!< Bit mask for CAN_CSn_TIME_STAMP. */
#define BS_CAN_CSn_TIME_STAMP (16U)        /*!< Bit field size in bits for CAN_CSn_TIME_STAMP. */

/*! @brief Read current value of the CAN_CSn_TIME_STAMP field. */
#define BR_CAN_CSn_TIME_STAMP(x, n) (HW_CAN_CSn(x, n).B.TIME_STAMP)

/*! @brief Format value for bitfield CAN_CSn_TIME_STAMP. */
#define BF_CAN_CSn_TIME_STAMP(v) ((uint32_t)((uint32_t)(v) << BP_CAN_CSn_TIME_STAMP) & BM_CAN_CSn_TIME_STAMP)

/*! @brief Set the TIME_STAMP field to a new value. */
#define BW_CAN_CSn_TIME_STAMP(x, n, v) (HW_CAN_CSn_WR(x, n, (HW_CAN_CSn_RD(x, n) & ~BM_CAN_CSn_TIME_STAMP) | BF_CAN_CSn_TIME_STAMP(v)))
/*@}*/

/*!
 * @name Register CAN_CSn, field DLC[19:16] (RW)
 */
/*@{*/
#define BP_CAN_CSn_DLC       (16U)         /*!< Bit position for CAN_CSn_DLC. */
#define BM_CAN_CSn_DLC       (0x000F0000U) /*!< Bit mask for CAN_CSn_DLC. */
#define BS_CAN_CSn_DLC       (4U)          /*!< Bit field size in bits for CAN_CSn_DLC. */

/*! @brief Read current value of the CAN_CSn_DLC field. */
#define BR_CAN_CSn_DLC(x, n) (HW_CAN_CSn(x, n).B.DLC)

/*! @brief Format value for bitfield CAN_CSn_DLC. */
#define BF_CAN_CSn_DLC(v)    ((uint32_t)((uint32_t)(v) << BP_CAN_CSn_DLC) & BM_CAN_CSn_DLC)

/*! @brief Set the DLC field to a new value. */
#define BW_CAN_CSn_DLC(x, n, v) (HW_CAN_CSn_WR(x, n, (HW_CAN_CSn_RD(x, n) & ~BM_CAN_CSn_DLC) | BF_CAN_CSn_DLC(v)))
/*@}*/

/*!
 * @name Register CAN_CSn, field RTR[20] (RW)
 */
/*@{*/
#define BP_CAN_CSn_RTR       (20U)         /*!< Bit position for CAN_CSn_RTR. */
#define BM_CAN_CSn_RTR       (0x00100000U) /*!< Bit mask for CAN_CSn_RTR. */
#define BS_CAN_CSn_RTR       (1U)          /*!< Bit field size in bits for CAN_CSn_RTR. */

/*! @brief Read current value of the CAN_CSn_RTR field. */
#define BR_CAN_CSn_RTR(x, n) (HW_CAN_CSn(x, n).B.RTR)

/*! @brief Format value for bitfield CAN_CSn_RTR. */
#define BF_CAN_CSn_RTR(v)    ((uint32_t)((uint32_t)(v) << BP_CAN_CSn_RTR) & BM_CAN_CSn_RTR)

/*! @brief Set the RTR field to a new value. */
#define BW_CAN_CSn_RTR(x, n, v) (HW_CAN_CSn_WR(x, n, (HW_CAN_CSn_RD(x, n) & ~BM_CAN_CSn_RTR) | BF_CAN_CSn_RTR(v)))
/*@}*/

/*!
 * @name Register CAN_CSn, field IDE[21] (RW)
 */
/*@{*/
#define BP_CAN_CSn_IDE       (21U)         /*!< Bit position for CAN_CSn_IDE. */
#define BM_CAN_CSn_IDE       (0x00200000U) /*!< Bit mask for CAN_CSn_IDE. */
#define BS_CAN_CSn_IDE       (1U)          /*!< Bit field size in bits for CAN_CSn_IDE. */

/*! @brief Read current value of the CAN_CSn_IDE field. */
#define BR_CAN_CSn_IDE(x, n) (HW_CAN_CSn(x, n).B.IDE)

/*! @brief Format value for bitfield CAN_CSn_IDE. */
#define BF_CAN_CSn_IDE(v)    ((uint32_t)((uint32_t)(v) << BP_CAN_CSn_IDE) & BM_CAN_CSn_IDE)

/*! @brief Set the IDE field to a new value. */
#define BW_CAN_CSn_IDE(x, n, v) (HW_CAN_CSn_WR(x, n, (HW_CAN_CSn_RD(x, n) & ~BM_CAN_CSn_IDE) | BF_CAN_CSn_IDE(v)))
/*@}*/

/*!
 * @name Register CAN_CSn, field SRR[22] (RW)
 */
/*@{*/
#define BP_CAN_CSn_SRR       (22U)         /*!< Bit position for CAN_CSn_SRR. */
#define BM_CAN_CSn_SRR       (0x00400000U) /*!< Bit mask for CAN_CSn_SRR. */
#define BS_CAN_CSn_SRR       (1U)          /*!< Bit field size in bits for CAN_CSn_SRR. */

/*! @brief Read current value of the CAN_CSn_SRR field. */
#define BR_CAN_CSn_SRR(x, n) (HW_CAN_CSn(x, n).B.SRR)

/*! @brief Format value for bitfield CAN_CSn_SRR. */
#define BF_CAN_CSn_SRR(v)    ((uint32_t)((uint32_t)(v) << BP_CAN_CSn_SRR) & BM_CAN_CSn_SRR)

/*! @brief Set the SRR field to a new value. */
#define BW_CAN_CSn_SRR(x, n, v) (HW_CAN_CSn_WR(x, n, (HW_CAN_CSn_RD(x, n) & ~BM_CAN_CSn_SRR) | BF_CAN_CSn_SRR(v)))
/*@}*/

/*!
 * @name Register CAN_CSn, field CODE[27:24] (RW)
 */
/*@{*/
#define BP_CAN_CSn_CODE      (24U)         /*!< Bit position for CAN_CSn_CODE. */
#define BM_CAN_CSn_CODE      (0x0F000000U) /*!< Bit mask for CAN_CSn_CODE. */
#define BS_CAN_CSn_CODE      (4U)          /*!< Bit field size in bits for CAN_CSn_CODE. */

/*! @brief Read current value of the CAN_CSn_CODE field. */
#define BR_CAN_CSn_CODE(x, n) (HW_CAN_CSn(x, n).B.CODE)

/*! @brief Format value for bitfield CAN_CSn_CODE. */
#define BF_CAN_CSn_CODE(v)   ((uint32_t)((uint32_t)(v) << BP_CAN_CSn_CODE) & BM_CAN_CSn_CODE)

/*! @brief Set the CODE field to a new value. */
#define BW_CAN_CSn_CODE(x, n, v) (HW_CAN_CSn_WR(x, n, (HW_CAN_CSn_RD(x, n) & ~BM_CAN_CSn_CODE) | BF_CAN_CSn_CODE(v)))
/*@}*/
/*******************************************************************************
 * HW_CAN_IDn - Message Buffer 0 ID Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_IDn - Message Buffer 0 ID Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_can_idn
{
    uint32_t U;
    struct _hw_can_idn_bitfields
    {
        uint32_t EXT : 18;             /*!< [17:0] Contains extended (LOW word)
                                        * identifier of message buffer. */
        uint32_t STD : 11;             /*!< [28:18] Contains standard/extended (HIGH
                                        * word) identifier of message buffer. */
        uint32_t PRIO : 3;             /*!< [31:29] Local priority. This 3-bit fieldis
                                        * only used when LPRIO_EN bit is set in MCR and it only makes sense for Tx
                                        * buffers. These bits are not transmitted. They are appended to the regular
                                        * ID to define the transmission priority. */
    } B;
} hw_can_idn_t;

/*!
 * @name Constants and macros for entire CAN_IDn register
 */
/*@{*/
#define HW_CAN_IDn_COUNT (64U)

#define HW_CAN_IDn_ADDR(x, n)    ((uintptr_t)(x) + 0x84U + (0x10U * (n)))

#define HW_CAN_IDn(x, n)         (*(__IO hw_can_idn_t *) HW_CAN_IDn_ADDR(x, n))
#define HW_CAN_IDn_RD(x, n)      (HW_CAN_IDn(x, n).U)
#define HW_CAN_IDn_WR(x, n, v)   (HW_CAN_IDn(x, n).U = (v))
#define HW_CAN_IDn_SET(x, n, v)  (HW_CAN_IDn_WR(x, n, HW_CAN_IDn_RD(x, n) |  (v)))
#define HW_CAN_IDn_CLR(x, n, v)  (HW_CAN_IDn_WR(x, n, HW_CAN_IDn_RD(x, n) & ~(v)))
#define HW_CAN_IDn_TOG(x, n, v)  (HW_CAN_IDn_WR(x, n, HW_CAN_IDn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_IDn bitfields
 */

/*!
 * @name Register CAN_IDn, field EXT[17:0] (RW)
 */
/*@{*/
#define BP_CAN_IDn_EXT       (0U)          /*!< Bit position for CAN_IDn_EXT. */
#define BM_CAN_IDn_EXT       (0x0003FFFFU) /*!< Bit mask for CAN_IDn_EXT. */
#define BS_CAN_IDn_EXT       (18U)         /*!< Bit field size in bits for CAN_IDn_EXT. */

/*! @brief Read current value of the CAN_IDn_EXT field. */
#define BR_CAN_IDn_EXT(x, n) (HW_CAN_IDn(x, n).B.EXT)

/*! @brief Format value for bitfield CAN_IDn_EXT. */
#define BF_CAN_IDn_EXT(v)    ((uint32_t)((uint32_t)(v) << BP_CAN_IDn_EXT) & BM_CAN_IDn_EXT)

/*! @brief Set the EXT field to a new value. */
#define BW_CAN_IDn_EXT(x, n, v) (HW_CAN_IDn_WR(x, n, (HW_CAN_IDn_RD(x, n) & ~BM_CAN_IDn_EXT) | BF_CAN_IDn_EXT(v)))
/*@}*/

/*!
 * @name Register CAN_IDn, field STD[28:18] (RW)
 */
/*@{*/
#define BP_CAN_IDn_STD       (18U)         /*!< Bit position for CAN_IDn_STD. */
#define BM_CAN_IDn_STD       (0x1FFC0000U) /*!< Bit mask for CAN_IDn_STD. */
#define BS_CAN_IDn_STD       (11U)         /*!< Bit field size in bits for CAN_IDn_STD. */

/*! @brief Read current value of the CAN_IDn_STD field. */
#define BR_CAN_IDn_STD(x, n) (HW_CAN_IDn(x, n).B.STD)

/*! @brief Format value for bitfield CAN_IDn_STD. */
#define BF_CAN_IDn_STD(v)    ((uint32_t)((uint32_t)(v) << BP_CAN_IDn_STD) & BM_CAN_IDn_STD)

/*! @brief Set the STD field to a new value. */
#define BW_CAN_IDn_STD(x, n, v) (HW_CAN_IDn_WR(x, n, (HW_CAN_IDn_RD(x, n) & ~BM_CAN_IDn_STD) | BF_CAN_IDn_STD(v)))
/*@}*/

/*!
 * @name Register CAN_IDn, field PRIO[31:29] (RW)
 */
/*@{*/
#define BP_CAN_IDn_PRIO      (29U)         /*!< Bit position for CAN_IDn_PRIO. */
#define BM_CAN_IDn_PRIO      (0xE0000000U) /*!< Bit mask for CAN_IDn_PRIO. */
#define BS_CAN_IDn_PRIO      (3U)          /*!< Bit field size in bits for CAN_IDn_PRIO. */

/*! @brief Read current value of the CAN_IDn_PRIO field. */
#define BR_CAN_IDn_PRIO(x, n) (HW_CAN_IDn(x, n).B.PRIO)

/*! @brief Format value for bitfield CAN_IDn_PRIO. */
#define BF_CAN_IDn_PRIO(v)   ((uint32_t)((uint32_t)(v) << BP_CAN_IDn_PRIO) & BM_CAN_IDn_PRIO)

/*! @brief Set the PRIO field to a new value. */
#define BW_CAN_IDn_PRIO(x, n, v) (HW_CAN_IDn_WR(x, n, (HW_CAN_IDn_RD(x, n) & ~BM_CAN_IDn_PRIO) | BF_CAN_IDn_PRIO(v)))
/*@}*/
/*******************************************************************************
 * HW_CAN_WORD0n - Message Buffer 0 WORD0 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_WORD0n - Message Buffer 0 WORD0 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_can_word0n
{
    uint32_t U;
    struct _hw_can_word0n_bitfields
    {
        uint32_t DATA_BYTE_3 : 8;      /*!< [7:0] Data byte 3 of Rx/Tx frame. */
        uint32_t DATA_BYTE_2 : 8;      /*!< [15:8] Data byte 2 of Rx/Tx frame. */
        uint32_t DATA_BYTE_1 : 8;      /*!< [23:16] Data byte 1 of Rx/Tx frame. */
        uint32_t DATA_BYTE_0 : 8;      /*!< [31:24] Data byte 0 of Rx/Tx frame. */
    } B;
} hw_can_word0n_t;

/*!
 * @name Constants and macros for entire CAN_WORD0n register
 */
/*@{*/
#define HW_CAN_WORD0n_COUNT (64U)

#define HW_CAN_WORD0n_ADDR(x, n) ((uintptr_t)(x) + 0x88U + (0x10U * (n)))

#define HW_CAN_WORD0n(x, n)      (*(__IO hw_can_word0n_t *) HW_CAN_WORD0n_ADDR(x, n))
#define HW_CAN_WORD0n_RD(x, n)   (HW_CAN_WORD0n(x, n).U)
#define HW_CAN_WORD0n_WR(x, n, v) (HW_CAN_WORD0n(x, n).U = (v))
#define HW_CAN_WORD0n_SET(x, n, v) (HW_CAN_WORD0n_WR(x, n, HW_CAN_WORD0n_RD(x, n) |  (v)))
#define HW_CAN_WORD0n_CLR(x, n, v) (HW_CAN_WORD0n_WR(x, n, HW_CAN_WORD0n_RD(x, n) & ~(v)))
#define HW_CAN_WORD0n_TOG(x, n, v) (HW_CAN_WORD0n_WR(x, n, HW_CAN_WORD0n_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_WORD0n bitfields
 */

/*!
 * @name Register CAN_WORD0n, field DATA_BYTE_3[7:0] (RW)
 */
/*@{*/
#define BP_CAN_WORD0n_DATA_BYTE_3 (0U)     /*!< Bit position for CAN_WORD0n_DATA_BYTE_3. */
#define BM_CAN_WORD0n_DATA_BYTE_3 (0x000000FFU) /*!< Bit mask for CAN_WORD0n_DATA_BYTE_3. */
#define BS_CAN_WORD0n_DATA_BYTE_3 (8U)     /*!< Bit field size in bits for CAN_WORD0n_DATA_BYTE_3. */

/*! @brief Read current value of the CAN_WORD0n_DATA_BYTE_3 field. */
#define BR_CAN_WORD0n_DATA_BYTE_3(x, n) (HW_CAN_WORD0n(x, n).B.DATA_BYTE_3)

/*! @brief Format value for bitfield CAN_WORD0n_DATA_BYTE_3. */
#define BF_CAN_WORD0n_DATA_BYTE_3(v) ((uint32_t)((uint32_t)(v) << BP_CAN_WORD0n_DATA_BYTE_3) & BM_CAN_WORD0n_DATA_BYTE_3)

/*! @brief Set the DATA_BYTE_3 field to a new value. */
#define BW_CAN_WORD0n_DATA_BYTE_3(x, n, v) (HW_CAN_WORD0n_WR(x, n, (HW_CAN_WORD0n_RD(x, n) & ~BM_CAN_WORD0n_DATA_BYTE_3) | BF_CAN_WORD0n_DATA_BYTE_3(v)))
/*@}*/

/*!
 * @name Register CAN_WORD0n, field DATA_BYTE_2[15:8] (RW)
 */
/*@{*/
#define BP_CAN_WORD0n_DATA_BYTE_2 (8U)     /*!< Bit position for CAN_WORD0n_DATA_BYTE_2. */
#define BM_CAN_WORD0n_DATA_BYTE_2 (0x0000FF00U) /*!< Bit mask for CAN_WORD0n_DATA_BYTE_2. */
#define BS_CAN_WORD0n_DATA_BYTE_2 (8U)     /*!< Bit field size in bits for CAN_WORD0n_DATA_BYTE_2. */

/*! @brief Read current value of the CAN_WORD0n_DATA_BYTE_2 field. */
#define BR_CAN_WORD0n_DATA_BYTE_2(x, n) (HW_CAN_WORD0n(x, n).B.DATA_BYTE_2)

/*! @brief Format value for bitfield CAN_WORD0n_DATA_BYTE_2. */
#define BF_CAN_WORD0n_DATA_BYTE_2(v) ((uint32_t)((uint32_t)(v) << BP_CAN_WORD0n_DATA_BYTE_2) & BM_CAN_WORD0n_DATA_BYTE_2)

/*! @brief Set the DATA_BYTE_2 field to a new value. */
#define BW_CAN_WORD0n_DATA_BYTE_2(x, n, v) (HW_CAN_WORD0n_WR(x, n, (HW_CAN_WORD0n_RD(x, n) & ~BM_CAN_WORD0n_DATA_BYTE_2) | BF_CAN_WORD0n_DATA_BYTE_2(v)))
/*@}*/

/*!
 * @name Register CAN_WORD0n, field DATA_BYTE_1[23:16] (RW)
 */
/*@{*/
#define BP_CAN_WORD0n_DATA_BYTE_1 (16U)    /*!< Bit position for CAN_WORD0n_DATA_BYTE_1. */
#define BM_CAN_WORD0n_DATA_BYTE_1 (0x00FF0000U) /*!< Bit mask for CAN_WORD0n_DATA_BYTE_1. */
#define BS_CAN_WORD0n_DATA_BYTE_1 (8U)     /*!< Bit field size in bits for CAN_WORD0n_DATA_BYTE_1. */

/*! @brief Read current value of the CAN_WORD0n_DATA_BYTE_1 field. */
#define BR_CAN_WORD0n_DATA_BYTE_1(x, n) (HW_CAN_WORD0n(x, n).B.DATA_BYTE_1)

/*! @brief Format value for bitfield CAN_WORD0n_DATA_BYTE_1. */
#define BF_CAN_WORD0n_DATA_BYTE_1(v) ((uint32_t)((uint32_t)(v) << BP_CAN_WORD0n_DATA_BYTE_1) & BM_CAN_WORD0n_DATA_BYTE_1)

/*! @brief Set the DATA_BYTE_1 field to a new value. */
#define BW_CAN_WORD0n_DATA_BYTE_1(x, n, v) (HW_CAN_WORD0n_WR(x, n, (HW_CAN_WORD0n_RD(x, n) & ~BM_CAN_WORD0n_DATA_BYTE_1) | BF_CAN_WORD0n_DATA_BYTE_1(v)))
/*@}*/

/*!
 * @name Register CAN_WORD0n, field DATA_BYTE_0[31:24] (RW)
 */
/*@{*/
#define BP_CAN_WORD0n_DATA_BYTE_0 (24U)    /*!< Bit position for CAN_WORD0n_DATA_BYTE_0. */
#define BM_CAN_WORD0n_DATA_BYTE_0 (0xFF000000U) /*!< Bit mask for CAN_WORD0n_DATA_BYTE_0. */
#define BS_CAN_WORD0n_DATA_BYTE_0 (8U)     /*!< Bit field size in bits for CAN_WORD0n_DATA_BYTE_0. */

/*! @brief Read current value of the CAN_WORD0n_DATA_BYTE_0 field. */
#define BR_CAN_WORD0n_DATA_BYTE_0(x, n) (HW_CAN_WORD0n(x, n).B.DATA_BYTE_0)

/*! @brief Format value for bitfield CAN_WORD0n_DATA_BYTE_0. */
#define BF_CAN_WORD0n_DATA_BYTE_0(v) ((uint32_t)((uint32_t)(v) << BP_CAN_WORD0n_DATA_BYTE_0) & BM_CAN_WORD0n_DATA_BYTE_0)

/*! @brief Set the DATA_BYTE_0 field to a new value. */
#define BW_CAN_WORD0n_DATA_BYTE_0(x, n, v) (HW_CAN_WORD0n_WR(x, n, (HW_CAN_WORD0n_RD(x, n) & ~BM_CAN_WORD0n_DATA_BYTE_0) | BF_CAN_WORD0n_DATA_BYTE_0(v)))
/*@}*/
/*******************************************************************************
 * HW_CAN_WORD1n - Message Buffer 0 WORD1 Register
 ******************************************************************************/

/*!
 * @brief HW_CAN_WORD1n - Message Buffer 0 WORD1 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_can_word1n
{
    uint32_t U;
    struct _hw_can_word1n_bitfields
    {
        uint32_t DATA_BYTE_7 : 8;      /*!< [7:0] Data byte 7 of Rx/Tx frame. */
        uint32_t DATA_BYTE_6 : 8;      /*!< [15:8] Data byte 6 of Rx/Tx frame. */
        uint32_t DATA_BYTE_5 : 8;      /*!< [23:16] Data byte 5 of Rx/Tx frame. */
        uint32_t DATA_BYTE_4 : 8;      /*!< [31:24] Data byte 4 of Rx/Tx frame. */
    } B;
} hw_can_word1n_t;

/*!
 * @name Constants and macros for entire CAN_WORD1n register
 */
/*@{*/
#define HW_CAN_WORD1n_COUNT (64U)

#define HW_CAN_WORD1n_ADDR(x, n) ((uintptr_t)(x) + 0x8CU + (0x10U * (n)))

#define HW_CAN_WORD1n(x, n)      (*(__IO hw_can_word1n_t *) HW_CAN_WORD1n_ADDR(x, n))
#define HW_CAN_WORD1n_RD(x, n)   (HW_CAN_WORD1n(x, n).U)
#define HW_CAN_WORD1n_WR(x, n, v) (HW_CAN_WORD1n(x, n).U = (v))
#define HW_CAN_WORD1n_SET(x, n, v) (HW_CAN_WORD1n_WR(x, n, HW_CAN_WORD1n_RD(x, n) |  (v)))
#define HW_CAN_WORD1n_CLR(x, n, v) (HW_CAN_WORD1n_WR(x, n, HW_CAN_WORD1n_RD(x, n) & ~(v)))
#define HW_CAN_WORD1n_TOG(x, n, v) (HW_CAN_WORD1n_WR(x, n, HW_CAN_WORD1n_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_WORD1n bitfields
 */

/*!
 * @name Register CAN_WORD1n, field DATA_BYTE_7[7:0] (RW)
 */
/*@{*/
#define BP_CAN_WORD1n_DATA_BYTE_7 (0U)     /*!< Bit position for CAN_WORD1n_DATA_BYTE_7. */
#define BM_CAN_WORD1n_DATA_BYTE_7 (0x000000FFU) /*!< Bit mask for CAN_WORD1n_DATA_BYTE_7. */
#define BS_CAN_WORD1n_DATA_BYTE_7 (8U)     /*!< Bit field size in bits for CAN_WORD1n_DATA_BYTE_7. */

/*! @brief Read current value of the CAN_WORD1n_DATA_BYTE_7 field. */
#define BR_CAN_WORD1n_DATA_BYTE_7(x, n) (HW_CAN_WORD1n(x, n).B.DATA_BYTE_7)

/*! @brief Format value for bitfield CAN_WORD1n_DATA_BYTE_7. */
#define BF_CAN_WORD1n_DATA_BYTE_7(v) ((uint32_t)((uint32_t)(v) << BP_CAN_WORD1n_DATA_BYTE_7) & BM_CAN_WORD1n_DATA_BYTE_7)

/*! @brief Set the DATA_BYTE_7 field to a new value. */
#define BW_CAN_WORD1n_DATA_BYTE_7(x, n, v) (HW_CAN_WORD1n_WR(x, n, (HW_CAN_WORD1n_RD(x, n) & ~BM_CAN_WORD1n_DATA_BYTE_7) | BF_CAN_WORD1n_DATA_BYTE_7(v)))
/*@}*/

/*!
 * @name Register CAN_WORD1n, field DATA_BYTE_6[15:8] (RW)
 */
/*@{*/
#define BP_CAN_WORD1n_DATA_BYTE_6 (8U)     /*!< Bit position for CAN_WORD1n_DATA_BYTE_6. */
#define BM_CAN_WORD1n_DATA_BYTE_6 (0x0000FF00U) /*!< Bit mask for CAN_WORD1n_DATA_BYTE_6. */
#define BS_CAN_WORD1n_DATA_BYTE_6 (8U)     /*!< Bit field size in bits for CAN_WORD1n_DATA_BYTE_6. */

/*! @brief Read current value of the CAN_WORD1n_DATA_BYTE_6 field. */
#define BR_CAN_WORD1n_DATA_BYTE_6(x, n) (HW_CAN_WORD1n(x, n).B.DATA_BYTE_6)

/*! @brief Format value for bitfield CAN_WORD1n_DATA_BYTE_6. */
#define BF_CAN_WORD1n_DATA_BYTE_6(v) ((uint32_t)((uint32_t)(v) << BP_CAN_WORD1n_DATA_BYTE_6) & BM_CAN_WORD1n_DATA_BYTE_6)

/*! @brief Set the DATA_BYTE_6 field to a new value. */
#define BW_CAN_WORD1n_DATA_BYTE_6(x, n, v) (HW_CAN_WORD1n_WR(x, n, (HW_CAN_WORD1n_RD(x, n) & ~BM_CAN_WORD1n_DATA_BYTE_6) | BF_CAN_WORD1n_DATA_BYTE_6(v)))
/*@}*/

/*!
 * @name Register CAN_WORD1n, field DATA_BYTE_5[23:16] (RW)
 */
/*@{*/
#define BP_CAN_WORD1n_DATA_BYTE_5 (16U)    /*!< Bit position for CAN_WORD1n_DATA_BYTE_5. */
#define BM_CAN_WORD1n_DATA_BYTE_5 (0x00FF0000U) /*!< Bit mask for CAN_WORD1n_DATA_BYTE_5. */
#define BS_CAN_WORD1n_DATA_BYTE_5 (8U)     /*!< Bit field size in bits for CAN_WORD1n_DATA_BYTE_5. */

/*! @brief Read current value of the CAN_WORD1n_DATA_BYTE_5 field. */
#define BR_CAN_WORD1n_DATA_BYTE_5(x, n) (HW_CAN_WORD1n(x, n).B.DATA_BYTE_5)

/*! @brief Format value for bitfield CAN_WORD1n_DATA_BYTE_5. */
#define BF_CAN_WORD1n_DATA_BYTE_5(v) ((uint32_t)((uint32_t)(v) << BP_CAN_WORD1n_DATA_BYTE_5) & BM_CAN_WORD1n_DATA_BYTE_5)

/*! @brief Set the DATA_BYTE_5 field to a new value. */
#define BW_CAN_WORD1n_DATA_BYTE_5(x, n, v) (HW_CAN_WORD1n_WR(x, n, (HW_CAN_WORD1n_RD(x, n) & ~BM_CAN_WORD1n_DATA_BYTE_5) | BF_CAN_WORD1n_DATA_BYTE_5(v)))
/*@}*/

/*!
 * @name Register CAN_WORD1n, field DATA_BYTE_4[31:24] (RW)
 */
/*@{*/
#define BP_CAN_WORD1n_DATA_BYTE_4 (24U)    /*!< Bit position for CAN_WORD1n_DATA_BYTE_4. */
#define BM_CAN_WORD1n_DATA_BYTE_4 (0xFF000000U) /*!< Bit mask for CAN_WORD1n_DATA_BYTE_4. */
#define BS_CAN_WORD1n_DATA_BYTE_4 (8U)     /*!< Bit field size in bits for CAN_WORD1n_DATA_BYTE_4. */

/*! @brief Read current value of the CAN_WORD1n_DATA_BYTE_4 field. */
#define BR_CAN_WORD1n_DATA_BYTE_4(x, n) (HW_CAN_WORD1n(x, n).B.DATA_BYTE_4)

/*! @brief Format value for bitfield CAN_WORD1n_DATA_BYTE_4. */
#define BF_CAN_WORD1n_DATA_BYTE_4(v) ((uint32_t)((uint32_t)(v) << BP_CAN_WORD1n_DATA_BYTE_4) & BM_CAN_WORD1n_DATA_BYTE_4)

/*! @brief Set the DATA_BYTE_4 field to a new value. */
#define BW_CAN_WORD1n_DATA_BYTE_4(x, n, v) (HW_CAN_WORD1n_WR(x, n, (HW_CAN_WORD1n_RD(x, n) & ~BM_CAN_WORD1n_DATA_BYTE_4) | BF_CAN_WORD1n_DATA_BYTE_4(v)))
/*@}*/

/*******************************************************************************
 * HW_CAN_RXIMRn - RXIMR
 ******************************************************************************/

/*!
 * @brief HW_CAN_RXIMRn - RXIMR (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_can_rximrn
{
    uint32_t U;
    struct _hw_can_rximrn_bitfields
    {
        uint32_t MI : 32;              /*!< [31:0] MI */
    } B;
} hw_can_rximrn_t;

/*!
 * @name Constants and macros for entire CAN_RXIMRn register
 */
/*@{*/
#define HW_CAN_RXIMRn_COUNT (64U)

#define HW_CAN_RXIMRn_ADDR(x, n) ((uintptr_t)(x) + 0x880U + (0x4U * (n)))

#define HW_CAN_RXIMRn(x, n)      (*(__IO hw_can_rximrn_t *) HW_CAN_RXIMRn_ADDR(x, n))
#define HW_CAN_RXIMRn_RD(x, n)   (HW_CAN_RXIMRn(x, n).U)
#define HW_CAN_RXIMRn_WR(x, n, v) (HW_CAN_RXIMRn(x, n).U = (v))
#define HW_CAN_RXIMRn_SET(x, n, v) (HW_CAN_RXIMRn_WR(x, n, HW_CAN_RXIMRn_RD(x, n) |  (v)))
#define HW_CAN_RXIMRn_CLR(x, n, v) (HW_CAN_RXIMRn_WR(x, n, HW_CAN_RXIMRn_RD(x, n) & ~(v)))
#define HW_CAN_RXIMRn_TOG(x, n, v) (HW_CAN_RXIMRn_WR(x, n, HW_CAN_RXIMRn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_RXIMRn bitfields
 */

/*!
 * @name Register CAN_RXIMRn, field MI[31:0] (RW)
 */
/*@{*/
#define BP_CAN_RXIMRn_MI     (0U)          /*!< Bit position for CAN_RXIMRn_MI. */
#define BM_CAN_RXIMRn_MI     (0xFFFFFFFFU) /*!< Bit mask for CAN_RXIMRn_MI. */
#define BS_CAN_RXIMRn_MI     (32U)         /*!< Bit field size in bits for CAN_RXIMRn_MI. */

/*! @brief Read current value of the CAN_RXIMRn_MI field. */
#define BR_CAN_RXIMRn_MI(x, n) (HW_CAN_RXIMRn(x, n).U)

/*! @brief Format value for bitfield CAN_RXIMRn_MI. */
#define BF_CAN_RXIMRn_MI(v)  ((uint32_t)((uint32_t)(v) << BP_CAN_RXIMRn_MI) & BM_CAN_RXIMRn_MI)

/*! @brief Set the MI field to a new value. */
#define BW_CAN_RXIMRn_MI(x, n, v) (HW_CAN_RXIMRn_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_CAN_GFWR - Glitch Filter Width Registers
 ******************************************************************************/

/*!
 * @brief HW_CAN_GFWR - Glitch Filter Width Registers (RW)
 *
 * Reset value: 0x0000007FU
 *
 * The Glitch Filter just takes effects when FLEXCAN enters the STOP mode.
 */
typedef union _hw_can_gfwr
{
    uint32_t U;
    struct _hw_can_gfwr_bitfields
    {
        uint32_t GFWR : 8;             /*!< [7:0]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_can_gfwr_t;

/*!
 * @name Constants and macros for entire CAN_GFWR register
 */
/*@{*/
#define HW_CAN_GFWR_ADDR(x)      ((uintptr_t)(x) + 0x9E0U)

#define HW_CAN_GFWR(x)           (*(__IO hw_can_gfwr_t *) HW_CAN_GFWR_ADDR(x))
#define HW_CAN_GFWR_RD(x)        (HW_CAN_GFWR(x).U)
#define HW_CAN_GFWR_WR(x, v)     (HW_CAN_GFWR(x).U = (v))
#define HW_CAN_GFWR_SET(x, v)    (HW_CAN_GFWR_WR(x, HW_CAN_GFWR_RD(x) |  (v)))
#define HW_CAN_GFWR_CLR(x, v)    (HW_CAN_GFWR_WR(x, HW_CAN_GFWR_RD(x) & ~(v)))
#define HW_CAN_GFWR_TOG(x, v)    (HW_CAN_GFWR_WR(x, HW_CAN_GFWR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAN_GFWR bitfields
 */

/*!
 * @name Register CAN_GFWR, field GFWR[7:0] (RW)
 *
 * It determines the Glitch Filter Width. The width will be divided from
 * Oscillator clock by GFWR values. By default, it is 5.33 us when the oscillator is 24
 * MHz. Filter Pulse Width = [(GFWR FIELD + 1) x (1 / Osc. Frequency)]
 */
/*@{*/
#define BP_CAN_GFWR_GFWR     (0U)          /*!< Bit position for CAN_GFWR_GFWR. */
#define BM_CAN_GFWR_GFWR     (0x000000FFU) /*!< Bit mask for CAN_GFWR_GFWR. */
#define BS_CAN_GFWR_GFWR     (8U)          /*!< Bit field size in bits for CAN_GFWR_GFWR. */

/*! @brief Read current value of the CAN_GFWR_GFWR field. */
#define BR_CAN_GFWR_GFWR(x)  (HW_CAN_GFWR(x).B.GFWR)

/*! @brief Format value for bitfield CAN_GFWR_GFWR. */
#define BF_CAN_GFWR_GFWR(v)  ((uint32_t)((uint32_t)(v) << BP_CAN_GFWR_GFWR) & BM_CAN_GFWR_GFWR)

/*! @brief Set the GFWR field to a new value. */
#define BW_CAN_GFWR_GFWR(x, v) (HW_CAN_GFWR_WR(x, (HW_CAN_GFWR_RD(x) & ~BM_CAN_GFWR_GFWR) | BF_CAN_GFWR_GFWR(v)))
/*@}*/

/*******************************************************************************
 * hw_can_t - module struct
 ******************************************************************************/
/*!
 * @brief All CAN module registers.
 */
#pragma pack(1)
typedef struct _hw_can
{
    __IO hw_can_mcr_t MCR;                 /*!< [0x0] Module Configuration Register */
    __IO hw_can_ctrl1_t CTRL1;             /*!< [0x4] Control 1 Register */
    __IO hw_can_timer_t TIMER;             /*!< [0x8] Free Running Timer Register */
    uint8_t _reserved0[4];
    __IO hw_can_rxmgmask_t RXMGMASK;       /*!< [0x10] Rx Mailboxes Global Mask Register */
    __IO hw_can_rx14mask_t RX14MASK;       /*!< [0x14] Rx Buffer 14 Mask Register */
    __IO hw_can_rx15mask_t RX15MASK;       /*!< [0x18] Rx Buffer 15 Mask Register */
    __IO hw_can_ecr_t ECR;                 /*!< [0x1C] Error Counter Register */
    __IO hw_can_esr1_t ESR1;               /*!< [0x20] Error and Status 1 Register */
    __IO hw_can_imask2_t IMASK2;           /*!< [0x24] Interrupt Masks 2 Register */
    __IO hw_can_imask1_t IMASK1;           /*!< [0x28] Interrupt Masks 1 Register */
    __IO hw_can_iflag2_t IFLAG2;           /*!< [0x2C] Interrupt Flags 2 Register */
    __IO hw_can_iflag1_t IFLAG1;           /*!< [0x30] Interrupt Flags 1 Register */
    __IO hw_can_ctrl2_t CTRL2;             /*!< [0x34] Control 2 Register */
    __I hw_can_esr2_t ESR2;                /*!< [0x38] Error and Status 2 Register */
    uint8_t _reserved1[8];
    __I hw_can_crcr_t CRCR;                /*!< [0x44] CRC Register */
    __IO hw_can_rxfgmask_t RXFGMASK;       /*!< [0x48] Rx FIFO Global Mask Register */
    __I hw_can_rxfir_t RXFIR;              /*!< [0x4C] Rx FIFO Information Register */
    uint8_t _reserved2[48];
    struct {
        __IO hw_can_csn_t CSn;             /*!< [0x80] Message Buffer 0 CS Register */
        __IO hw_can_idn_t IDn;             /*!< [0x84] Message Buffer 0 ID Register */
        __IO hw_can_word0n_t WORD0n;       /*!< [0x88] Message Buffer 0 WORD0 Register */
        __IO hw_can_word1n_t WORD1n;       /*!< [0x8C] Message Buffer 0 WORD1 Register */
    } MB[64];
    uint8_t _reserved3[1024];
    __IO hw_can_rximrn_t RXIMRn[64];       /*!< [0x880] RXIMR */
    uint8_t _reserved4[96];
    __IO hw_can_gfwr_t GFWR;               /*!< [0x9E0] Glitch Filter Width Registers */
} hw_can_t;
#pragma pack()

/*! @brief Macro to access all CAN registers. */
/*! @param x CAN module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_CAN_REGS(CAN1_BASE)</code>. */
#define HW_CAN_REGS(x) (*(hw_can_t *)(x))

/*
 * iMX7D CCM
 *
 * CCM_UNIFIED
 *
 * Registers defined in this header file:
 * - HW_CCM_GPR0 - General Purpose Register
 * - HW_CCM_PLL_CTRL0 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL1 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL2 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL3 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL4 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL5 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL6 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL7 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL8 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL9 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL10 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL11 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL12 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL13 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL14 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL15 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL16 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL17 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL18 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL19 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL20 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL21 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL22 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL23 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL24 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL25 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL26 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL27 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL28 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL29 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL30 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL31 - CCM PLL Control Register
 * - HW_CCM_PLL_CTRL32 - CCM PLL Control Register
 * - HW_CCM_CCGR0 - CCM Clock Gating Register
 * - HW_CCM_CCGR1 - CCM Clock Gating Register
 * - HW_CCM_CCGR2 - CCM Clock Gating Register
 * - HW_CCM_CCGR3 - CCM Clock Gating Register
 * - HW_CCM_CCGR4 - CCM Clock Gating Register
 * - HW_CCM_CCGR5 - CCM Clock Gating Register
 * - HW_CCM_CCGR6 - CCM Clock Gating Register
 * - HW_CCM_CCGR7 - CCM Clock Gating Register
 * - HW_CCM_CCGR8 - CCM Clock Gating Register
 * - HW_CCM_CCGR9 - CCM Clock Gating Register
 * - HW_CCM_CCGR10 - CCM Clock Gating Register
 * - HW_CCM_CCGR11 - CCM Clock Gating Register
 * - HW_CCM_CCGR12 - CCM Clock Gating Register
 * - HW_CCM_CCGR13 - CCM Clock Gating Register
 * - HW_CCM_CCGR14 - CCM Clock Gating Register
 * - HW_CCM_CCGR15 - CCM Clock Gating Register
 * - HW_CCM_CCGR16 - CCM Clock Gating Register
 * - HW_CCM_CCGR17 - CCM Clock Gating Register
 * - HW_CCM_CCGR18 - CCM Clock Gating Register
 * - HW_CCM_CCGR19 - CCM Clock Gating Register
 * - HW_CCM_CCGR20 - CCM Clock Gating Register
 * - HW_CCM_CCGR21 - CCM Clock Gating Register
 * - HW_CCM_CCGR22 - CCM Clock Gating Register
 * - HW_CCM_CCGR23 - CCM Clock Gating Register
 * - HW_CCM_CCGR24 - CCM Clock Gating Register
 * - HW_CCM_CCGR25 - CCM Clock Gating Register
 * - HW_CCM_CCGR26 - CCM Clock Gating Register
 * - HW_CCM_CCGR27 - CCM Clock Gating Register
 * - HW_CCM_CCGR28 - CCM Clock Gating Register
 * - HW_CCM_CCGR29 - CCM Clock Gating Register
 * - HW_CCM_CCGR30 - CCM Clock Gating Register
 * - HW_CCM_CCGR31 - CCM Clock Gating Register
 * - HW_CCM_CCGR32 - CCM Clock Gating Register
 * - HW_CCM_CCGR33 - CCM Clock Gating Register
 * - HW_CCM_CCGR34 - CCM Clock Gating Register
 * - HW_CCM_CCGR35 - CCM Clock Gating Register
 * - HW_CCM_CCGR36 - CCM Clock Gating Register
 * - HW_CCM_CCGR37 - CCM Clock Gating Register
 * - HW_CCM_CCGR38 - CCM Clock Gating Register
 * - HW_CCM_CCGR39 - CCM Clock Gating Register
 * - HW_CCM_CCGR40 - CCM Clock Gating Register
 * - HW_CCM_CCGR41 - CCM Clock Gating Register
 * - HW_CCM_CCGR42 - CCM Clock Gating Register
 * - HW_CCM_CCGR43 - CCM Clock Gating Register
 * - HW_CCM_CCGR44 - CCM Clock Gating Register
 * - HW_CCM_CCGR45 - CCM Clock Gating Register
 * - HW_CCM_CCGR46 - CCM Clock Gating Register
 * - HW_CCM_CCGR47 - CCM Clock Gating Register
 * - HW_CCM_CCGR48 - CCM Clock Gating Register
 * - HW_CCM_CCGR49 - CCM Clock Gating Register
 * - HW_CCM_CCGR50 - CCM Clock Gating Register
 * - HW_CCM_CCGR51 - CCM Clock Gating Register
 * - HW_CCM_CCGR52 - CCM Clock Gating Register
 * - HW_CCM_CCGR53 - CCM Clock Gating Register
 * - HW_CCM_CCGR54 - CCM Clock Gating Register
 * - HW_CCM_CCGR55 - CCM Clock Gating Register
 * - HW_CCM_CCGR56 - CCM Clock Gating Register
 * - HW_CCM_CCGR57 - CCM Clock Gating Register
 * - HW_CCM_CCGR58 - CCM Clock Gating Register
 * - HW_CCM_CCGR59 - CCM Clock Gating Register
 * - HW_CCM_CCGR60 - CCM Clock Gating Register
 * - HW_CCM_CCGR61 - CCM Clock Gating Register
 * - HW_CCM_CCGR62 - CCM Clock Gating Register
 * - HW_CCM_CCGR63 - CCM Clock Gating Register
 * - HW_CCM_CCGR64 - CCM Clock Gating Register
 * - HW_CCM_CCGR65 - CCM Clock Gating Register
 * - HW_CCM_CCGR66 - CCM Clock Gating Register
 * - HW_CCM_CCGR67 - CCM Clock Gating Register
 * - HW_CCM_CCGR68 - CCM Clock Gating Register
 * - HW_CCM_CCGR69 - CCM Clock Gating Register
 * - HW_CCM_CCGR70 - CCM Clock Gating Register
 * - HW_CCM_CCGR71 - CCM Clock Gating Register
 * - HW_CCM_CCGR72 - CCM Clock Gating Register
 * - HW_CCM_CCGR73 - CCM Clock Gating Register
 * - HW_CCM_CCGR74 - CCM Clock Gating Register
 * - HW_CCM_CCGR75 - CCM Clock Gating Register
 * - HW_CCM_CCGR76 - CCM Clock Gating Register
 * - HW_CCM_CCGR77 - CCM Clock Gating Register
 * - HW_CCM_CCGR78 - CCM Clock Gating Register
 * - HW_CCM_CCGR79 - CCM Clock Gating Register
 * - HW_CCM_CCGR80 - CCM Clock Gating Register
 * - HW_CCM_CCGR81 - CCM Clock Gating Register
 * - HW_CCM_CCGR82 - CCM Clock Gating Register
 * - HW_CCM_CCGR83 - CCM Clock Gating Register
 * - HW_CCM_CCGR84 - CCM Clock Gating Register
 * - HW_CCM_CCGR85 - CCM Clock Gating Register
 * - HW_CCM_CCGR86 - CCM Clock Gating Register
 * - HW_CCM_CCGR87 - CCM Clock Gating Register
 * - HW_CCM_CCGR88 - CCM Clock Gating Register
 * - HW_CCM_CCGR89 - CCM Clock Gating Register
 * - HW_CCM_CCGR90 - CCM Clock Gating Register
 * - HW_CCM_CCGR91 - CCM Clock Gating Register
 * - HW_CCM_CCGR92 - CCM Clock Gating Register
 * - HW_CCM_CCGR93 - CCM Clock Gating Register
 * - HW_CCM_CCGR94 - CCM Clock Gating Register
 * - HW_CCM_CCGR95 - CCM Clock Gating Register
 * - HW_CCM_CCGR96 - CCM Clock Gating Register
 * - HW_CCM_CCGR97 - CCM Clock Gating Register
 * - HW_CCM_CCGR98 - CCM Clock Gating Register
 * - HW_CCM_CCGR99 - CCM Clock Gating Register
 * - HW_CCM_CCGR100 - CCM Clock Gating Register
 * - HW_CCM_CCGR101 - CCM Clock Gating Register
 * - HW_CCM_CCGR102 - CCM Clock Gating Register
 * - HW_CCM_CCGR103 - CCM Clock Gating Register
 * - HW_CCM_CCGR104 - CCM Clock Gating Register
 * - HW_CCM_CCGR105 - CCM Clock Gating Register
 * - HW_CCM_CCGR106 - CCM Clock Gating Register
 * - HW_CCM_CCGR107 - CCM Clock Gating Register
 * - HW_CCM_CCGR108 - CCM Clock Gating Register
 * - HW_CCM_CCGR109 - CCM Clock Gating Register
 * - HW_CCM_CCGR110 - CCM Clock Gating Register
 * - HW_CCM_CCGR111 - CCM Clock Gating Register
 * - HW_CCM_CCGR112 - CCM Clock Gating Register
 * - HW_CCM_CCGR113 - CCM Clock Gating Register
 * - HW_CCM_CCGR114 - CCM Clock Gating Register
 * - HW_CCM_CCGR115 - CCM Clock Gating Register
 * - HW_CCM_CCGR116 - CCM Clock Gating Register
 * - HW_CCM_CCGR117 - CCM Clock Gating Register
 * - HW_CCM_CCGR118 - CCM Clock Gating Register
 * - HW_CCM_CCGR119 - CCM Clock Gating Register
 * - HW_CCM_CCGR120 - CCM Clock Gating Register
 * - HW_CCM_CCGR121 - CCM Clock Gating Register
 * - HW_CCM_CCGR122 - CCM Clock Gating Register
 * - HW_CCM_CCGR123 - CCM Clock Gating Register
 * - HW_CCM_CCGR124 - CCM Clock Gating Register
 * - HW_CCM_CCGR125 - CCM Clock Gating Register
 * - HW_CCM_CCGR126 - CCM Clock Gating Register
 * - HW_CCM_CCGR127 - CCM Clock Gating Register
 * - HW_CCM_CCGR128 - CCM Clock Gating Register
 * - HW_CCM_CCGR129 - CCM Clock Gating Register
 * - HW_CCM_CCGR130 - CCM Clock Gating Register
 * - HW_CCM_CCGR131 - CCM Clock Gating Register
 * - HW_CCM_CCGR132 - CCM Clock Gating Register
 * - HW_CCM_CCGR133 - CCM Clock Gating Register
 * - HW_CCM_CCGR134 - CCM Clock Gating Register
 * - HW_CCM_CCGR135 - CCM Clock Gating Register
 * - HW_CCM_CCGR136 - CCM Clock Gating Register
 * - HW_CCM_CCGR137 - CCM Clock Gating Register
 * - HW_CCM_CCGR138 - CCM Clock Gating Register
 * - HW_CCM_CCGR139 - CCM Clock Gating Register
 * - HW_CCM_CCGR140 - CCM Clock Gating Register
 * - HW_CCM_CCGR141 - CCM Clock Gating Register
 * - HW_CCM_CCGR142 - CCM Clock Gating Register
 * - HW_CCM_CCGR143 - CCM Clock Gating Register
 * - HW_CCM_CCGR144 - CCM Clock Gating Register
 * - HW_CCM_CCGR145 - CCM Clock Gating Register
 * - HW_CCM_CCGR146 - CCM Clock Gating Register
 * - HW_CCM_CCGR147 - CCM Clock Gating Register
 * - HW_CCM_CCGR148 - CCM Clock Gating Register
 * - HW_CCM_CCGR149 - CCM Clock Gating Register
 * - HW_CCM_CCGR150 - CCM Clock Gating Register
 * - HW_CCM_CCGR151 - CCM Clock Gating Register
 * - HW_CCM_CCGR152 - CCM Clock Gating Register
 * - HW_CCM_CCGR153 - CCM Clock Gating Register
 * - HW_CCM_CCGR154 - CCM Clock Gating Register
 * - HW_CCM_CCGR155 - CCM Clock Gating Register
 * - HW_CCM_CCGR156 - CCM Clock Gating Register
 * - HW_CCM_CCGR157 - CCM Clock Gating Register
 * - HW_CCM_CCGR158 - CCM Clock Gating Register
 * - HW_CCM_CCGR159 - CCM Clock Gating Register
 * - HW_CCM_CCGR160 - CCM Clock Gating Register
 * - HW_CCM_CCGR161 - CCM Clock Gating Register
 * - HW_CCM_CCGR162 - CCM Clock Gating Register
 * - HW_CCM_CCGR163 - CCM Clock Gating Register
 * - HW_CCM_CCGR164 - CCM Clock Gating Register
 * - HW_CCM_CCGR165 - CCM Clock Gating Register
 * - HW_CCM_CCGR166 - CCM Clock Gating Register
 * - HW_CCM_CCGR167 - CCM Clock Gating Register
 * - HW_CCM_CCGR168 - CCM Clock Gating Register
 * - HW_CCM_CCGR169 - CCM Clock Gating Register
 * - HW_CCM_CCGR170 - CCM Clock Gating Register
 * - HW_CCM_CCGR171 - CCM Clock Gating Register
 * - HW_CCM_CCGR172 - CCM Clock Gating Register
 * - HW_CCM_CCGR173 - CCM Clock Gating Register
 * - HW_CCM_CCGR174 - CCM Clock Gating Register
 * - HW_CCM_CCGR175 - CCM Clock Gating Register
 * - HW_CCM_CCGR176 - CCM Clock Gating Register
 * - HW_CCM_CCGR177 - CCM Clock Gating Register
 * - HW_CCM_CCGR178 - CCM Clock Gating Register
 * - HW_CCM_CCGR179 - CCM Clock Gating Register
 * - HW_CCM_CCGR180 - CCM Clock Gating Register
 * - HW_CCM_CCGR181 - CCM Clock Gating Register
 * - HW_CCM_CCGR182 - CCM Clock Gating Register
 * - HW_CCM_CCGR183 - CCM Clock Gating Register
 * - HW_CCM_CCGR184 - CCM Clock Gating Register
 * - HW_CCM_CCGR185 - CCM Clock Gating Register
 * - HW_CCM_CCGR186 - CCM Clock Gating Register
 * - HW_CCM_CCGR187 - CCM Clock Gating Register
 * - HW_CCM_CCGR188 - CCM Clock Gating Register
 * - HW_CCM_CCGR189 - CCM Clock Gating Register
 * - HW_CCM_CCGR190 - CCM Clock Gating Register
 * - HW_CCM_TARGET_ROOTn - Target Register
 * - HW_CCM_MISCn - Miscellaneous Register
 * - HW_CCM_POSTn - Post Divider Register
 * - HW_CCM_PREn - Pre Divider Register
 * - HW_CCM_ACCESS_CTRLn - Access Control Register
 *
 * - hw_ccm_t - Struct containing all module registers.
 */

#define HW_CCM_INSTANCE_COUNT (1U) /*!< Number of instances of the CCM module. */
#define HW_CCM (0U) /*!< Instance number for CCM. */
#define CCM_BASE              (0x30380000U) /*!< Base address for CCM. */
/*! Array initializer of CCM base addresses. */
#define CCM_BASE_ADDRS        { CCM_BASE }

/*******************************************************************************
 * HW_CCM_GPR0 - General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_GPR0 - General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR0
 */
typedef union _hw_ccm_gpr0
{
    uint32_t U;
    struct _hw_ccm_gpr0_bitfields
    {
        uint32_t GP0 : 32;             /*!< [31:0]  */
    } B;
} hw_ccm_gpr0_t;

/*!
 * @name Constants and macros for entire CCM_GPR0 register
 */
/*@{*/
#define HW_CCM_GPR0_ADDR(x)      ((uintptr_t)(x) + 0x0U)
#define HW_CCM_GPR0_SET_ADDR(x)  (HW_CCM_GPR0_ADDR(x) + 0x4U)
#define HW_CCM_GPR0_CLR_ADDR(x)  (HW_CCM_GPR0_ADDR(x) + 0x8U)
#define HW_CCM_GPR0_TOG_ADDR(x)  (HW_CCM_GPR0_ADDR(x) + 0xCU)

#define HW_CCM_GPR0(x)           (*(__IO hw_ccm_gpr0_t *) HW_CCM_GPR0_ADDR(x))
#define HW_CCM_GPR0_RD(x)        (HW_CCM_GPR0(x).U)
#define HW_CCM_GPR0_WR(x, v)     (HW_CCM_GPR0(x).U = (v))
#define HW_CCM_GPR0_SET(x, v)    ((*(uint32_t *) HW_CCM_GPR0_SET_ADDR(x)) = (v))
#define HW_CCM_GPR0_CLR(x, v)    ((*(uint32_t *) HW_CCM_GPR0_CLR_ADDR(x)) = (v))
#define HW_CCM_GPR0_TOG(x, v)    ((*(uint32_t *) HW_CCM_GPR0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_GPR0 bitfields
 */

/*!
 * @name Register CCM_GPR0, field GP0[31:0] (RW)
 *
 * Timeout cycle count of ipg_clk, when perform read and write.
 */
/*@{*/
#define BP_CCM_GPR0_GP0      (0U)          /*!< Bit position for CCM_GPR0_GP0. */
#define BM_CCM_GPR0_GP0      (0xFFFFFFFFU) /*!< Bit mask for CCM_GPR0_GP0. */
#define BS_CCM_GPR0_GP0      (32U)         /*!< Bit field size in bits for CCM_GPR0_GP0. */

/*! @brief Read current value of the CCM_GPR0_GP0 field. */
#define BR_CCM_GPR0_GP0(x)   (HW_CCM_GPR0(x).U)

/*! @brief Format value for bitfield CCM_GPR0_GP0. */
#define BF_CCM_GPR0_GP0(v)   ((uint32_t)((uint32_t)(v) << BP_CCM_GPR0_GP0) & BM_CCM_GPR0_GP0)

/*! @brief Set the GP0 field to a new value. */
#define BW_CCM_GPR0_GP0(x, v) (HW_CCM_GPR0_WR(x, v))
/*@}*/




/*******************************************************************************
 * HW_CCM_PLL_CTRL0 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL0 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl0
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl0_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl0_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL0 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL0_ADDR(x) ((uintptr_t)(x) + 0x800U)
#define HW_CCM_PLL_CTRL0_SET_ADDR(x) (HW_CCM_PLL_CTRL0_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL0_CLR_ADDR(x) (HW_CCM_PLL_CTRL0_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL0_TOG_ADDR(x) (HW_CCM_PLL_CTRL0_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL0(x)      (*(__IO hw_ccm_pll_ctrl0_t *) HW_CCM_PLL_CTRL0_ADDR(x))
#define HW_CCM_PLL_CTRL0_RD(x)   (HW_CCM_PLL_CTRL0(x).U)
#define HW_CCM_PLL_CTRL0_WR(x, v) (HW_CCM_PLL_CTRL0(x).U = (v))
#define HW_CCM_PLL_CTRL0_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL0_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL0_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL0_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL0_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL0 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL0, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL0_SETTING0 (0U)     /*!< Bit position for CCM_PLL_CTRL0_SETTING0. */
#define BM_CCM_PLL_CTRL0_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL0_SETTING0. */
#define BS_CCM_PLL_CTRL0_SETTING0 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL0_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL0_SETTING0 field. */
#define BR_CCM_PLL_CTRL0_SETTING0(x) (HW_CCM_PLL_CTRL0(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL0_SETTING0. */
#define BF_CCM_PLL_CTRL0_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL0_SETTING0) & BM_CCM_PLL_CTRL0_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL0_SETTING0(x, v) (HW_CCM_PLL_CTRL0_WR(x, (HW_CCM_PLL_CTRL0_RD(x) & ~BM_CCM_PLL_CTRL0_SETTING0) | BF_CCM_PLL_CTRL0_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL0, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL0_SETTING1 (4U)     /*!< Bit position for CCM_PLL_CTRL0_SETTING1. */
#define BM_CCM_PLL_CTRL0_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL0_SETTING1. */
#define BS_CCM_PLL_CTRL0_SETTING1 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL0_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL0_SETTING1 field. */
#define BR_CCM_PLL_CTRL0_SETTING1(x) (HW_CCM_PLL_CTRL0(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL0_SETTING1. */
#define BF_CCM_PLL_CTRL0_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL0_SETTING1) & BM_CCM_PLL_CTRL0_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL0_SETTING1(x, v) (HW_CCM_PLL_CTRL0_WR(x, (HW_CCM_PLL_CTRL0_RD(x) & ~BM_CCM_PLL_CTRL0_SETTING1) | BF_CCM_PLL_CTRL0_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL0, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL0_SETTING2 (8U)     /*!< Bit position for CCM_PLL_CTRL0_SETTING2. */
#define BM_CCM_PLL_CTRL0_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL0_SETTING2. */
#define BS_CCM_PLL_CTRL0_SETTING2 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL0_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL0_SETTING2 field. */
#define BR_CCM_PLL_CTRL0_SETTING2(x) (HW_CCM_PLL_CTRL0(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL0_SETTING2. */
#define BF_CCM_PLL_CTRL0_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL0_SETTING2) & BM_CCM_PLL_CTRL0_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL0_SETTING2(x, v) (HW_CCM_PLL_CTRL0_WR(x, (HW_CCM_PLL_CTRL0_RD(x) & ~BM_CCM_PLL_CTRL0_SETTING2) | BF_CCM_PLL_CTRL0_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL0, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL0_SETTING3 (12U)    /*!< Bit position for CCM_PLL_CTRL0_SETTING3. */
#define BM_CCM_PLL_CTRL0_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL0_SETTING3. */
#define BS_CCM_PLL_CTRL0_SETTING3 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL0_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL0_SETTING3 field. */
#define BR_CCM_PLL_CTRL0_SETTING3(x) (HW_CCM_PLL_CTRL0(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL0_SETTING3. */
#define BF_CCM_PLL_CTRL0_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL0_SETTING3) & BM_CCM_PLL_CTRL0_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL0_SETTING3(x, v) (HW_CCM_PLL_CTRL0_WR(x, (HW_CCM_PLL_CTRL0_RD(x) & ~BM_CCM_PLL_CTRL0_SETTING3) | BF_CCM_PLL_CTRL0_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL1 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL1 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl1
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl1_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl1_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL1 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL1_ADDR(x) ((uintptr_t)(x) + 0x810U)
#define HW_CCM_PLL_CTRL1_SET_ADDR(x) (HW_CCM_PLL_CTRL1_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL1_CLR_ADDR(x) (HW_CCM_PLL_CTRL1_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL1_TOG_ADDR(x) (HW_CCM_PLL_CTRL1_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL1(x)      (*(__IO hw_ccm_pll_ctrl1_t *) HW_CCM_PLL_CTRL1_ADDR(x))
#define HW_CCM_PLL_CTRL1_RD(x)   (HW_CCM_PLL_CTRL1(x).U)
#define HW_CCM_PLL_CTRL1_WR(x, v) (HW_CCM_PLL_CTRL1(x).U = (v))
#define HW_CCM_PLL_CTRL1_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL1_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL1_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL1_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL1_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL1 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL1, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL1_SETTING0 (0U)     /*!< Bit position for CCM_PLL_CTRL1_SETTING0. */
#define BM_CCM_PLL_CTRL1_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL1_SETTING0. */
#define BS_CCM_PLL_CTRL1_SETTING0 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL1_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL1_SETTING0 field. */
#define BR_CCM_PLL_CTRL1_SETTING0(x) (HW_CCM_PLL_CTRL1(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL1_SETTING0. */
#define BF_CCM_PLL_CTRL1_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL1_SETTING0) & BM_CCM_PLL_CTRL1_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL1_SETTING0(x, v) (HW_CCM_PLL_CTRL1_WR(x, (HW_CCM_PLL_CTRL1_RD(x) & ~BM_CCM_PLL_CTRL1_SETTING0) | BF_CCM_PLL_CTRL1_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL1, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL1_SETTING1 (4U)     /*!< Bit position for CCM_PLL_CTRL1_SETTING1. */
#define BM_CCM_PLL_CTRL1_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL1_SETTING1. */
#define BS_CCM_PLL_CTRL1_SETTING1 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL1_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL1_SETTING1 field. */
#define BR_CCM_PLL_CTRL1_SETTING1(x) (HW_CCM_PLL_CTRL1(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL1_SETTING1. */
#define BF_CCM_PLL_CTRL1_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL1_SETTING1) & BM_CCM_PLL_CTRL1_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL1_SETTING1(x, v) (HW_CCM_PLL_CTRL1_WR(x, (HW_CCM_PLL_CTRL1_RD(x) & ~BM_CCM_PLL_CTRL1_SETTING1) | BF_CCM_PLL_CTRL1_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL1, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL1_SETTING2 (8U)     /*!< Bit position for CCM_PLL_CTRL1_SETTING2. */
#define BM_CCM_PLL_CTRL1_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL1_SETTING2. */
#define BS_CCM_PLL_CTRL1_SETTING2 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL1_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL1_SETTING2 field. */
#define BR_CCM_PLL_CTRL1_SETTING2(x) (HW_CCM_PLL_CTRL1(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL1_SETTING2. */
#define BF_CCM_PLL_CTRL1_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL1_SETTING2) & BM_CCM_PLL_CTRL1_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL1_SETTING2(x, v) (HW_CCM_PLL_CTRL1_WR(x, (HW_CCM_PLL_CTRL1_RD(x) & ~BM_CCM_PLL_CTRL1_SETTING2) | BF_CCM_PLL_CTRL1_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL1, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL1_SETTING3 (12U)    /*!< Bit position for CCM_PLL_CTRL1_SETTING3. */
#define BM_CCM_PLL_CTRL1_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL1_SETTING3. */
#define BS_CCM_PLL_CTRL1_SETTING3 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL1_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL1_SETTING3 field. */
#define BR_CCM_PLL_CTRL1_SETTING3(x) (HW_CCM_PLL_CTRL1(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL1_SETTING3. */
#define BF_CCM_PLL_CTRL1_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL1_SETTING3) & BM_CCM_PLL_CTRL1_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL1_SETTING3(x, v) (HW_CCM_PLL_CTRL1_WR(x, (HW_CCM_PLL_CTRL1_RD(x) & ~BM_CCM_PLL_CTRL1_SETTING3) | BF_CCM_PLL_CTRL1_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL2 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL2 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl2
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl2_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl2_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL2 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL2_ADDR(x) ((uintptr_t)(x) + 0x820U)
#define HW_CCM_PLL_CTRL2_SET_ADDR(x) (HW_CCM_PLL_CTRL2_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL2_CLR_ADDR(x) (HW_CCM_PLL_CTRL2_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL2_TOG_ADDR(x) (HW_CCM_PLL_CTRL2_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL2(x)      (*(__IO hw_ccm_pll_ctrl2_t *) HW_CCM_PLL_CTRL2_ADDR(x))
#define HW_CCM_PLL_CTRL2_RD(x)   (HW_CCM_PLL_CTRL2(x).U)
#define HW_CCM_PLL_CTRL2_WR(x, v) (HW_CCM_PLL_CTRL2(x).U = (v))
#define HW_CCM_PLL_CTRL2_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL2_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL2_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL2_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL2_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL2 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL2, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL2_SETTING0 (0U)     /*!< Bit position for CCM_PLL_CTRL2_SETTING0. */
#define BM_CCM_PLL_CTRL2_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL2_SETTING0. */
#define BS_CCM_PLL_CTRL2_SETTING0 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL2_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL2_SETTING0 field. */
#define BR_CCM_PLL_CTRL2_SETTING0(x) (HW_CCM_PLL_CTRL2(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL2_SETTING0. */
#define BF_CCM_PLL_CTRL2_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL2_SETTING0) & BM_CCM_PLL_CTRL2_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL2_SETTING0(x, v) (HW_CCM_PLL_CTRL2_WR(x, (HW_CCM_PLL_CTRL2_RD(x) & ~BM_CCM_PLL_CTRL2_SETTING0) | BF_CCM_PLL_CTRL2_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL2, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL2_SETTING1 (4U)     /*!< Bit position for CCM_PLL_CTRL2_SETTING1. */
#define BM_CCM_PLL_CTRL2_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL2_SETTING1. */
#define BS_CCM_PLL_CTRL2_SETTING1 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL2_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL2_SETTING1 field. */
#define BR_CCM_PLL_CTRL2_SETTING1(x) (HW_CCM_PLL_CTRL2(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL2_SETTING1. */
#define BF_CCM_PLL_CTRL2_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL2_SETTING1) & BM_CCM_PLL_CTRL2_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL2_SETTING1(x, v) (HW_CCM_PLL_CTRL2_WR(x, (HW_CCM_PLL_CTRL2_RD(x) & ~BM_CCM_PLL_CTRL2_SETTING1) | BF_CCM_PLL_CTRL2_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL2, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL2_SETTING2 (8U)     /*!< Bit position for CCM_PLL_CTRL2_SETTING2. */
#define BM_CCM_PLL_CTRL2_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL2_SETTING2. */
#define BS_CCM_PLL_CTRL2_SETTING2 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL2_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL2_SETTING2 field. */
#define BR_CCM_PLL_CTRL2_SETTING2(x) (HW_CCM_PLL_CTRL2(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL2_SETTING2. */
#define BF_CCM_PLL_CTRL2_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL2_SETTING2) & BM_CCM_PLL_CTRL2_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL2_SETTING2(x, v) (HW_CCM_PLL_CTRL2_WR(x, (HW_CCM_PLL_CTRL2_RD(x) & ~BM_CCM_PLL_CTRL2_SETTING2) | BF_CCM_PLL_CTRL2_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL2, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL2_SETTING3 (12U)    /*!< Bit position for CCM_PLL_CTRL2_SETTING3. */
#define BM_CCM_PLL_CTRL2_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL2_SETTING3. */
#define BS_CCM_PLL_CTRL2_SETTING3 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL2_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL2_SETTING3 field. */
#define BR_CCM_PLL_CTRL2_SETTING3(x) (HW_CCM_PLL_CTRL2(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL2_SETTING3. */
#define BF_CCM_PLL_CTRL2_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL2_SETTING3) & BM_CCM_PLL_CTRL2_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL2_SETTING3(x, v) (HW_CCM_PLL_CTRL2_WR(x, (HW_CCM_PLL_CTRL2_RD(x) & ~BM_CCM_PLL_CTRL2_SETTING3) | BF_CCM_PLL_CTRL2_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL3 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL3 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl3
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl3_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl3_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL3 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL3_ADDR(x) ((uintptr_t)(x) + 0x830U)
#define HW_CCM_PLL_CTRL3_SET_ADDR(x) (HW_CCM_PLL_CTRL3_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL3_CLR_ADDR(x) (HW_CCM_PLL_CTRL3_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL3_TOG_ADDR(x) (HW_CCM_PLL_CTRL3_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL3(x)      (*(__IO hw_ccm_pll_ctrl3_t *) HW_CCM_PLL_CTRL3_ADDR(x))
#define HW_CCM_PLL_CTRL3_RD(x)   (HW_CCM_PLL_CTRL3(x).U)
#define HW_CCM_PLL_CTRL3_WR(x, v) (HW_CCM_PLL_CTRL3(x).U = (v))
#define HW_CCM_PLL_CTRL3_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL3_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL3_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL3_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL3_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL3_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL3 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL3, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL3_SETTING0 (0U)     /*!< Bit position for CCM_PLL_CTRL3_SETTING0. */
#define BM_CCM_PLL_CTRL3_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL3_SETTING0. */
#define BS_CCM_PLL_CTRL3_SETTING0 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL3_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL3_SETTING0 field. */
#define BR_CCM_PLL_CTRL3_SETTING0(x) (HW_CCM_PLL_CTRL3(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL3_SETTING0. */
#define BF_CCM_PLL_CTRL3_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL3_SETTING0) & BM_CCM_PLL_CTRL3_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL3_SETTING0(x, v) (HW_CCM_PLL_CTRL3_WR(x, (HW_CCM_PLL_CTRL3_RD(x) & ~BM_CCM_PLL_CTRL3_SETTING0) | BF_CCM_PLL_CTRL3_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL3, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL3_SETTING1 (4U)     /*!< Bit position for CCM_PLL_CTRL3_SETTING1. */
#define BM_CCM_PLL_CTRL3_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL3_SETTING1. */
#define BS_CCM_PLL_CTRL3_SETTING1 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL3_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL3_SETTING1 field. */
#define BR_CCM_PLL_CTRL3_SETTING1(x) (HW_CCM_PLL_CTRL3(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL3_SETTING1. */
#define BF_CCM_PLL_CTRL3_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL3_SETTING1) & BM_CCM_PLL_CTRL3_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL3_SETTING1(x, v) (HW_CCM_PLL_CTRL3_WR(x, (HW_CCM_PLL_CTRL3_RD(x) & ~BM_CCM_PLL_CTRL3_SETTING1) | BF_CCM_PLL_CTRL3_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL3, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL3_SETTING2 (8U)     /*!< Bit position for CCM_PLL_CTRL3_SETTING2. */
#define BM_CCM_PLL_CTRL3_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL3_SETTING2. */
#define BS_CCM_PLL_CTRL3_SETTING2 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL3_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL3_SETTING2 field. */
#define BR_CCM_PLL_CTRL3_SETTING2(x) (HW_CCM_PLL_CTRL3(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL3_SETTING2. */
#define BF_CCM_PLL_CTRL3_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL3_SETTING2) & BM_CCM_PLL_CTRL3_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL3_SETTING2(x, v) (HW_CCM_PLL_CTRL3_WR(x, (HW_CCM_PLL_CTRL3_RD(x) & ~BM_CCM_PLL_CTRL3_SETTING2) | BF_CCM_PLL_CTRL3_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL3, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL3_SETTING3 (12U)    /*!< Bit position for CCM_PLL_CTRL3_SETTING3. */
#define BM_CCM_PLL_CTRL3_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL3_SETTING3. */
#define BS_CCM_PLL_CTRL3_SETTING3 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL3_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL3_SETTING3 field. */
#define BR_CCM_PLL_CTRL3_SETTING3(x) (HW_CCM_PLL_CTRL3(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL3_SETTING3. */
#define BF_CCM_PLL_CTRL3_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL3_SETTING3) & BM_CCM_PLL_CTRL3_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL3_SETTING3(x, v) (HW_CCM_PLL_CTRL3_WR(x, (HW_CCM_PLL_CTRL3_RD(x) & ~BM_CCM_PLL_CTRL3_SETTING3) | BF_CCM_PLL_CTRL3_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL4 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL4 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl4
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl4_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl4_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL4 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL4_ADDR(x) ((uintptr_t)(x) + 0x840U)
#define HW_CCM_PLL_CTRL4_SET_ADDR(x) (HW_CCM_PLL_CTRL4_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL4_CLR_ADDR(x) (HW_CCM_PLL_CTRL4_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL4_TOG_ADDR(x) (HW_CCM_PLL_CTRL4_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL4(x)      (*(__IO hw_ccm_pll_ctrl4_t *) HW_CCM_PLL_CTRL4_ADDR(x))
#define HW_CCM_PLL_CTRL4_RD(x)   (HW_CCM_PLL_CTRL4(x).U)
#define HW_CCM_PLL_CTRL4_WR(x, v) (HW_CCM_PLL_CTRL4(x).U = (v))
#define HW_CCM_PLL_CTRL4_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL4_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL4_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL4_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL4_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL4_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL4 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL4, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL4_SETTING0 (0U)     /*!< Bit position for CCM_PLL_CTRL4_SETTING0. */
#define BM_CCM_PLL_CTRL4_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL4_SETTING0. */
#define BS_CCM_PLL_CTRL4_SETTING0 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL4_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL4_SETTING0 field. */
#define BR_CCM_PLL_CTRL4_SETTING0(x) (HW_CCM_PLL_CTRL4(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL4_SETTING0. */
#define BF_CCM_PLL_CTRL4_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL4_SETTING0) & BM_CCM_PLL_CTRL4_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL4_SETTING0(x, v) (HW_CCM_PLL_CTRL4_WR(x, (HW_CCM_PLL_CTRL4_RD(x) & ~BM_CCM_PLL_CTRL4_SETTING0) | BF_CCM_PLL_CTRL4_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL4, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL4_SETTING1 (4U)     /*!< Bit position for CCM_PLL_CTRL4_SETTING1. */
#define BM_CCM_PLL_CTRL4_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL4_SETTING1. */
#define BS_CCM_PLL_CTRL4_SETTING1 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL4_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL4_SETTING1 field. */
#define BR_CCM_PLL_CTRL4_SETTING1(x) (HW_CCM_PLL_CTRL4(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL4_SETTING1. */
#define BF_CCM_PLL_CTRL4_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL4_SETTING1) & BM_CCM_PLL_CTRL4_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL4_SETTING1(x, v) (HW_CCM_PLL_CTRL4_WR(x, (HW_CCM_PLL_CTRL4_RD(x) & ~BM_CCM_PLL_CTRL4_SETTING1) | BF_CCM_PLL_CTRL4_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL4, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL4_SETTING2 (8U)     /*!< Bit position for CCM_PLL_CTRL4_SETTING2. */
#define BM_CCM_PLL_CTRL4_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL4_SETTING2. */
#define BS_CCM_PLL_CTRL4_SETTING2 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL4_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL4_SETTING2 field. */
#define BR_CCM_PLL_CTRL4_SETTING2(x) (HW_CCM_PLL_CTRL4(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL4_SETTING2. */
#define BF_CCM_PLL_CTRL4_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL4_SETTING2) & BM_CCM_PLL_CTRL4_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL4_SETTING2(x, v) (HW_CCM_PLL_CTRL4_WR(x, (HW_CCM_PLL_CTRL4_RD(x) & ~BM_CCM_PLL_CTRL4_SETTING2) | BF_CCM_PLL_CTRL4_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL4, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL4_SETTING3 (12U)    /*!< Bit position for CCM_PLL_CTRL4_SETTING3. */
#define BM_CCM_PLL_CTRL4_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL4_SETTING3. */
#define BS_CCM_PLL_CTRL4_SETTING3 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL4_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL4_SETTING3 field. */
#define BR_CCM_PLL_CTRL4_SETTING3(x) (HW_CCM_PLL_CTRL4(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL4_SETTING3. */
#define BF_CCM_PLL_CTRL4_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL4_SETTING3) & BM_CCM_PLL_CTRL4_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL4_SETTING3(x, v) (HW_CCM_PLL_CTRL4_WR(x, (HW_CCM_PLL_CTRL4_RD(x) & ~BM_CCM_PLL_CTRL4_SETTING3) | BF_CCM_PLL_CTRL4_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL5 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL5 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl5
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl5_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl5_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL5 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL5_ADDR(x) ((uintptr_t)(x) + 0x850U)
#define HW_CCM_PLL_CTRL5_SET_ADDR(x) (HW_CCM_PLL_CTRL5_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL5_CLR_ADDR(x) (HW_CCM_PLL_CTRL5_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL5_TOG_ADDR(x) (HW_CCM_PLL_CTRL5_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL5(x)      (*(__IO hw_ccm_pll_ctrl5_t *) HW_CCM_PLL_CTRL5_ADDR(x))
#define HW_CCM_PLL_CTRL5_RD(x)   (HW_CCM_PLL_CTRL5(x).U)
#define HW_CCM_PLL_CTRL5_WR(x, v) (HW_CCM_PLL_CTRL5(x).U = (v))
#define HW_CCM_PLL_CTRL5_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL5_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL5_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL5_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL5_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL5_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL5 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL5, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL5_SETTING0 (0U)     /*!< Bit position for CCM_PLL_CTRL5_SETTING0. */
#define BM_CCM_PLL_CTRL5_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL5_SETTING0. */
#define BS_CCM_PLL_CTRL5_SETTING0 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL5_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL5_SETTING0 field. */
#define BR_CCM_PLL_CTRL5_SETTING0(x) (HW_CCM_PLL_CTRL5(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL5_SETTING0. */
#define BF_CCM_PLL_CTRL5_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL5_SETTING0) & BM_CCM_PLL_CTRL5_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL5_SETTING0(x, v) (HW_CCM_PLL_CTRL5_WR(x, (HW_CCM_PLL_CTRL5_RD(x) & ~BM_CCM_PLL_CTRL5_SETTING0) | BF_CCM_PLL_CTRL5_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL5, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL5_SETTING1 (4U)     /*!< Bit position for CCM_PLL_CTRL5_SETTING1. */
#define BM_CCM_PLL_CTRL5_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL5_SETTING1. */
#define BS_CCM_PLL_CTRL5_SETTING1 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL5_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL5_SETTING1 field. */
#define BR_CCM_PLL_CTRL5_SETTING1(x) (HW_CCM_PLL_CTRL5(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL5_SETTING1. */
#define BF_CCM_PLL_CTRL5_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL5_SETTING1) & BM_CCM_PLL_CTRL5_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL5_SETTING1(x, v) (HW_CCM_PLL_CTRL5_WR(x, (HW_CCM_PLL_CTRL5_RD(x) & ~BM_CCM_PLL_CTRL5_SETTING1) | BF_CCM_PLL_CTRL5_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL5, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL5_SETTING2 (8U)     /*!< Bit position for CCM_PLL_CTRL5_SETTING2. */
#define BM_CCM_PLL_CTRL5_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL5_SETTING2. */
#define BS_CCM_PLL_CTRL5_SETTING2 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL5_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL5_SETTING2 field. */
#define BR_CCM_PLL_CTRL5_SETTING2(x) (HW_CCM_PLL_CTRL5(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL5_SETTING2. */
#define BF_CCM_PLL_CTRL5_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL5_SETTING2) & BM_CCM_PLL_CTRL5_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL5_SETTING2(x, v) (HW_CCM_PLL_CTRL5_WR(x, (HW_CCM_PLL_CTRL5_RD(x) & ~BM_CCM_PLL_CTRL5_SETTING2) | BF_CCM_PLL_CTRL5_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL5, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL5_SETTING3 (12U)    /*!< Bit position for CCM_PLL_CTRL5_SETTING3. */
#define BM_CCM_PLL_CTRL5_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL5_SETTING3. */
#define BS_CCM_PLL_CTRL5_SETTING3 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL5_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL5_SETTING3 field. */
#define BR_CCM_PLL_CTRL5_SETTING3(x) (HW_CCM_PLL_CTRL5(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL5_SETTING3. */
#define BF_CCM_PLL_CTRL5_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL5_SETTING3) & BM_CCM_PLL_CTRL5_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL5_SETTING3(x, v) (HW_CCM_PLL_CTRL5_WR(x, (HW_CCM_PLL_CTRL5_RD(x) & ~BM_CCM_PLL_CTRL5_SETTING3) | BF_CCM_PLL_CTRL5_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL6 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL6 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl6
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl6_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl6_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL6 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL6_ADDR(x) ((uintptr_t)(x) + 0x860U)
#define HW_CCM_PLL_CTRL6_SET_ADDR(x) (HW_CCM_PLL_CTRL6_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL6_CLR_ADDR(x) (HW_CCM_PLL_CTRL6_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL6_TOG_ADDR(x) (HW_CCM_PLL_CTRL6_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL6(x)      (*(__IO hw_ccm_pll_ctrl6_t *) HW_CCM_PLL_CTRL6_ADDR(x))
#define HW_CCM_PLL_CTRL6_RD(x)   (HW_CCM_PLL_CTRL6(x).U)
#define HW_CCM_PLL_CTRL6_WR(x, v) (HW_CCM_PLL_CTRL6(x).U = (v))
#define HW_CCM_PLL_CTRL6_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL6_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL6_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL6_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL6_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL6_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL6 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL6, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL6_SETTING0 (0U)     /*!< Bit position for CCM_PLL_CTRL6_SETTING0. */
#define BM_CCM_PLL_CTRL6_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL6_SETTING0. */
#define BS_CCM_PLL_CTRL6_SETTING0 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL6_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL6_SETTING0 field. */
#define BR_CCM_PLL_CTRL6_SETTING0(x) (HW_CCM_PLL_CTRL6(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL6_SETTING0. */
#define BF_CCM_PLL_CTRL6_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL6_SETTING0) & BM_CCM_PLL_CTRL6_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL6_SETTING0(x, v) (HW_CCM_PLL_CTRL6_WR(x, (HW_CCM_PLL_CTRL6_RD(x) & ~BM_CCM_PLL_CTRL6_SETTING0) | BF_CCM_PLL_CTRL6_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL6, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL6_SETTING1 (4U)     /*!< Bit position for CCM_PLL_CTRL6_SETTING1. */
#define BM_CCM_PLL_CTRL6_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL6_SETTING1. */
#define BS_CCM_PLL_CTRL6_SETTING1 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL6_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL6_SETTING1 field. */
#define BR_CCM_PLL_CTRL6_SETTING1(x) (HW_CCM_PLL_CTRL6(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL6_SETTING1. */
#define BF_CCM_PLL_CTRL6_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL6_SETTING1) & BM_CCM_PLL_CTRL6_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL6_SETTING1(x, v) (HW_CCM_PLL_CTRL6_WR(x, (HW_CCM_PLL_CTRL6_RD(x) & ~BM_CCM_PLL_CTRL6_SETTING1) | BF_CCM_PLL_CTRL6_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL6, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL6_SETTING2 (8U)     /*!< Bit position for CCM_PLL_CTRL6_SETTING2. */
#define BM_CCM_PLL_CTRL6_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL6_SETTING2. */
#define BS_CCM_PLL_CTRL6_SETTING2 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL6_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL6_SETTING2 field. */
#define BR_CCM_PLL_CTRL6_SETTING2(x) (HW_CCM_PLL_CTRL6(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL6_SETTING2. */
#define BF_CCM_PLL_CTRL6_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL6_SETTING2) & BM_CCM_PLL_CTRL6_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL6_SETTING2(x, v) (HW_CCM_PLL_CTRL6_WR(x, (HW_CCM_PLL_CTRL6_RD(x) & ~BM_CCM_PLL_CTRL6_SETTING2) | BF_CCM_PLL_CTRL6_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL6, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL6_SETTING3 (12U)    /*!< Bit position for CCM_PLL_CTRL6_SETTING3. */
#define BM_CCM_PLL_CTRL6_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL6_SETTING3. */
#define BS_CCM_PLL_CTRL6_SETTING3 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL6_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL6_SETTING3 field. */
#define BR_CCM_PLL_CTRL6_SETTING3(x) (HW_CCM_PLL_CTRL6(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL6_SETTING3. */
#define BF_CCM_PLL_CTRL6_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL6_SETTING3) & BM_CCM_PLL_CTRL6_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL6_SETTING3(x, v) (HW_CCM_PLL_CTRL6_WR(x, (HW_CCM_PLL_CTRL6_RD(x) & ~BM_CCM_PLL_CTRL6_SETTING3) | BF_CCM_PLL_CTRL6_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL7 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL7 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl7
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl7_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl7_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL7 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL7_ADDR(x) ((uintptr_t)(x) + 0x870U)
#define HW_CCM_PLL_CTRL7_SET_ADDR(x) (HW_CCM_PLL_CTRL7_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL7_CLR_ADDR(x) (HW_CCM_PLL_CTRL7_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL7_TOG_ADDR(x) (HW_CCM_PLL_CTRL7_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL7(x)      (*(__IO hw_ccm_pll_ctrl7_t *) HW_CCM_PLL_CTRL7_ADDR(x))
#define HW_CCM_PLL_CTRL7_RD(x)   (HW_CCM_PLL_CTRL7(x).U)
#define HW_CCM_PLL_CTRL7_WR(x, v) (HW_CCM_PLL_CTRL7(x).U = (v))
#define HW_CCM_PLL_CTRL7_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL7_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL7_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL7_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL7_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL7_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL7 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL7, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL7_SETTING0 (0U)     /*!< Bit position for CCM_PLL_CTRL7_SETTING0. */
#define BM_CCM_PLL_CTRL7_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL7_SETTING0. */
#define BS_CCM_PLL_CTRL7_SETTING0 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL7_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL7_SETTING0 field. */
#define BR_CCM_PLL_CTRL7_SETTING0(x) (HW_CCM_PLL_CTRL7(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL7_SETTING0. */
#define BF_CCM_PLL_CTRL7_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL7_SETTING0) & BM_CCM_PLL_CTRL7_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL7_SETTING0(x, v) (HW_CCM_PLL_CTRL7_WR(x, (HW_CCM_PLL_CTRL7_RD(x) & ~BM_CCM_PLL_CTRL7_SETTING0) | BF_CCM_PLL_CTRL7_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL7, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL7_SETTING1 (4U)     /*!< Bit position for CCM_PLL_CTRL7_SETTING1. */
#define BM_CCM_PLL_CTRL7_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL7_SETTING1. */
#define BS_CCM_PLL_CTRL7_SETTING1 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL7_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL7_SETTING1 field. */
#define BR_CCM_PLL_CTRL7_SETTING1(x) (HW_CCM_PLL_CTRL7(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL7_SETTING1. */
#define BF_CCM_PLL_CTRL7_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL7_SETTING1) & BM_CCM_PLL_CTRL7_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL7_SETTING1(x, v) (HW_CCM_PLL_CTRL7_WR(x, (HW_CCM_PLL_CTRL7_RD(x) & ~BM_CCM_PLL_CTRL7_SETTING1) | BF_CCM_PLL_CTRL7_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL7, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL7_SETTING2 (8U)     /*!< Bit position for CCM_PLL_CTRL7_SETTING2. */
#define BM_CCM_PLL_CTRL7_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL7_SETTING2. */
#define BS_CCM_PLL_CTRL7_SETTING2 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL7_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL7_SETTING2 field. */
#define BR_CCM_PLL_CTRL7_SETTING2(x) (HW_CCM_PLL_CTRL7(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL7_SETTING2. */
#define BF_CCM_PLL_CTRL7_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL7_SETTING2) & BM_CCM_PLL_CTRL7_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL7_SETTING2(x, v) (HW_CCM_PLL_CTRL7_WR(x, (HW_CCM_PLL_CTRL7_RD(x) & ~BM_CCM_PLL_CTRL7_SETTING2) | BF_CCM_PLL_CTRL7_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL7, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL7_SETTING3 (12U)    /*!< Bit position for CCM_PLL_CTRL7_SETTING3. */
#define BM_CCM_PLL_CTRL7_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL7_SETTING3. */
#define BS_CCM_PLL_CTRL7_SETTING3 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL7_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL7_SETTING3 field. */
#define BR_CCM_PLL_CTRL7_SETTING3(x) (HW_CCM_PLL_CTRL7(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL7_SETTING3. */
#define BF_CCM_PLL_CTRL7_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL7_SETTING3) & BM_CCM_PLL_CTRL7_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL7_SETTING3(x, v) (HW_CCM_PLL_CTRL7_WR(x, (HW_CCM_PLL_CTRL7_RD(x) & ~BM_CCM_PLL_CTRL7_SETTING3) | BF_CCM_PLL_CTRL7_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL8 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL8 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl8
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl8_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl8_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL8 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL8_ADDR(x) ((uintptr_t)(x) + 0x880U)
#define HW_CCM_PLL_CTRL8_SET_ADDR(x) (HW_CCM_PLL_CTRL8_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL8_CLR_ADDR(x) (HW_CCM_PLL_CTRL8_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL8_TOG_ADDR(x) (HW_CCM_PLL_CTRL8_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL8(x)      (*(__IO hw_ccm_pll_ctrl8_t *) HW_CCM_PLL_CTRL8_ADDR(x))
#define HW_CCM_PLL_CTRL8_RD(x)   (HW_CCM_PLL_CTRL8(x).U)
#define HW_CCM_PLL_CTRL8_WR(x, v) (HW_CCM_PLL_CTRL8(x).U = (v))
#define HW_CCM_PLL_CTRL8_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL8_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL8_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL8_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL8_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL8_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL8 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL8, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL8_SETTING0 (0U)     /*!< Bit position for CCM_PLL_CTRL8_SETTING0. */
#define BM_CCM_PLL_CTRL8_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL8_SETTING0. */
#define BS_CCM_PLL_CTRL8_SETTING0 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL8_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL8_SETTING0 field. */
#define BR_CCM_PLL_CTRL8_SETTING0(x) (HW_CCM_PLL_CTRL8(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL8_SETTING0. */
#define BF_CCM_PLL_CTRL8_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL8_SETTING0) & BM_CCM_PLL_CTRL8_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL8_SETTING0(x, v) (HW_CCM_PLL_CTRL8_WR(x, (HW_CCM_PLL_CTRL8_RD(x) & ~BM_CCM_PLL_CTRL8_SETTING0) | BF_CCM_PLL_CTRL8_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL8, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL8_SETTING1 (4U)     /*!< Bit position for CCM_PLL_CTRL8_SETTING1. */
#define BM_CCM_PLL_CTRL8_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL8_SETTING1. */
#define BS_CCM_PLL_CTRL8_SETTING1 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL8_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL8_SETTING1 field. */
#define BR_CCM_PLL_CTRL8_SETTING1(x) (HW_CCM_PLL_CTRL8(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL8_SETTING1. */
#define BF_CCM_PLL_CTRL8_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL8_SETTING1) & BM_CCM_PLL_CTRL8_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL8_SETTING1(x, v) (HW_CCM_PLL_CTRL8_WR(x, (HW_CCM_PLL_CTRL8_RD(x) & ~BM_CCM_PLL_CTRL8_SETTING1) | BF_CCM_PLL_CTRL8_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL8, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL8_SETTING2 (8U)     /*!< Bit position for CCM_PLL_CTRL8_SETTING2. */
#define BM_CCM_PLL_CTRL8_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL8_SETTING2. */
#define BS_CCM_PLL_CTRL8_SETTING2 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL8_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL8_SETTING2 field. */
#define BR_CCM_PLL_CTRL8_SETTING2(x) (HW_CCM_PLL_CTRL8(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL8_SETTING2. */
#define BF_CCM_PLL_CTRL8_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL8_SETTING2) & BM_CCM_PLL_CTRL8_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL8_SETTING2(x, v) (HW_CCM_PLL_CTRL8_WR(x, (HW_CCM_PLL_CTRL8_RD(x) & ~BM_CCM_PLL_CTRL8_SETTING2) | BF_CCM_PLL_CTRL8_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL8, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL8_SETTING3 (12U)    /*!< Bit position for CCM_PLL_CTRL8_SETTING3. */
#define BM_CCM_PLL_CTRL8_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL8_SETTING3. */
#define BS_CCM_PLL_CTRL8_SETTING3 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL8_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL8_SETTING3 field. */
#define BR_CCM_PLL_CTRL8_SETTING3(x) (HW_CCM_PLL_CTRL8(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL8_SETTING3. */
#define BF_CCM_PLL_CTRL8_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL8_SETTING3) & BM_CCM_PLL_CTRL8_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL8_SETTING3(x, v) (HW_CCM_PLL_CTRL8_WR(x, (HW_CCM_PLL_CTRL8_RD(x) & ~BM_CCM_PLL_CTRL8_SETTING3) | BF_CCM_PLL_CTRL8_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL9 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL9 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl9
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl9_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl9_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL9 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL9_ADDR(x) ((uintptr_t)(x) + 0x890U)
#define HW_CCM_PLL_CTRL9_SET_ADDR(x) (HW_CCM_PLL_CTRL9_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL9_CLR_ADDR(x) (HW_CCM_PLL_CTRL9_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL9_TOG_ADDR(x) (HW_CCM_PLL_CTRL9_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL9(x)      (*(__IO hw_ccm_pll_ctrl9_t *) HW_CCM_PLL_CTRL9_ADDR(x))
#define HW_CCM_PLL_CTRL9_RD(x)   (HW_CCM_PLL_CTRL9(x).U)
#define HW_CCM_PLL_CTRL9_WR(x, v) (HW_CCM_PLL_CTRL9(x).U = (v))
#define HW_CCM_PLL_CTRL9_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL9_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL9_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL9_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL9_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL9_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL9 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL9, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL9_SETTING0 (0U)     /*!< Bit position for CCM_PLL_CTRL9_SETTING0. */
#define BM_CCM_PLL_CTRL9_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL9_SETTING0. */
#define BS_CCM_PLL_CTRL9_SETTING0 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL9_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL9_SETTING0 field. */
#define BR_CCM_PLL_CTRL9_SETTING0(x) (HW_CCM_PLL_CTRL9(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL9_SETTING0. */
#define BF_CCM_PLL_CTRL9_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL9_SETTING0) & BM_CCM_PLL_CTRL9_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL9_SETTING0(x, v) (HW_CCM_PLL_CTRL9_WR(x, (HW_CCM_PLL_CTRL9_RD(x) & ~BM_CCM_PLL_CTRL9_SETTING0) | BF_CCM_PLL_CTRL9_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL9, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL9_SETTING1 (4U)     /*!< Bit position for CCM_PLL_CTRL9_SETTING1. */
#define BM_CCM_PLL_CTRL9_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL9_SETTING1. */
#define BS_CCM_PLL_CTRL9_SETTING1 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL9_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL9_SETTING1 field. */
#define BR_CCM_PLL_CTRL9_SETTING1(x) (HW_CCM_PLL_CTRL9(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL9_SETTING1. */
#define BF_CCM_PLL_CTRL9_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL9_SETTING1) & BM_CCM_PLL_CTRL9_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL9_SETTING1(x, v) (HW_CCM_PLL_CTRL9_WR(x, (HW_CCM_PLL_CTRL9_RD(x) & ~BM_CCM_PLL_CTRL9_SETTING1) | BF_CCM_PLL_CTRL9_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL9, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL9_SETTING2 (8U)     /*!< Bit position for CCM_PLL_CTRL9_SETTING2. */
#define BM_CCM_PLL_CTRL9_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL9_SETTING2. */
#define BS_CCM_PLL_CTRL9_SETTING2 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL9_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL9_SETTING2 field. */
#define BR_CCM_PLL_CTRL9_SETTING2(x) (HW_CCM_PLL_CTRL9(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL9_SETTING2. */
#define BF_CCM_PLL_CTRL9_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL9_SETTING2) & BM_CCM_PLL_CTRL9_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL9_SETTING2(x, v) (HW_CCM_PLL_CTRL9_WR(x, (HW_CCM_PLL_CTRL9_RD(x) & ~BM_CCM_PLL_CTRL9_SETTING2) | BF_CCM_PLL_CTRL9_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL9, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL9_SETTING3 (12U)    /*!< Bit position for CCM_PLL_CTRL9_SETTING3. */
#define BM_CCM_PLL_CTRL9_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL9_SETTING3. */
#define BS_CCM_PLL_CTRL9_SETTING3 (2U)     /*!< Bit field size in bits for CCM_PLL_CTRL9_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL9_SETTING3 field. */
#define BR_CCM_PLL_CTRL9_SETTING3(x) (HW_CCM_PLL_CTRL9(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL9_SETTING3. */
#define BF_CCM_PLL_CTRL9_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL9_SETTING3) & BM_CCM_PLL_CTRL9_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL9_SETTING3(x, v) (HW_CCM_PLL_CTRL9_WR(x, (HW_CCM_PLL_CTRL9_RD(x) & ~BM_CCM_PLL_CTRL9_SETTING3) | BF_CCM_PLL_CTRL9_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL10 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL10 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl10
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl10_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl10_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL10 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL10_ADDR(x) ((uintptr_t)(x) + 0x8A0U)
#define HW_CCM_PLL_CTRL10_SET_ADDR(x) (HW_CCM_PLL_CTRL10_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL10_CLR_ADDR(x) (HW_CCM_PLL_CTRL10_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL10_TOG_ADDR(x) (HW_CCM_PLL_CTRL10_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL10(x)     (*(__IO hw_ccm_pll_ctrl10_t *) HW_CCM_PLL_CTRL10_ADDR(x))
#define HW_CCM_PLL_CTRL10_RD(x)  (HW_CCM_PLL_CTRL10(x).U)
#define HW_CCM_PLL_CTRL10_WR(x, v) (HW_CCM_PLL_CTRL10(x).U = (v))
#define HW_CCM_PLL_CTRL10_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL10_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL10_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL10_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL10_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL10_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL10 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL10, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL10_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL10_SETTING0. */
#define BM_CCM_PLL_CTRL10_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL10_SETTING0. */
#define BS_CCM_PLL_CTRL10_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL10_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL10_SETTING0 field. */
#define BR_CCM_PLL_CTRL10_SETTING0(x) (HW_CCM_PLL_CTRL10(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL10_SETTING0. */
#define BF_CCM_PLL_CTRL10_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL10_SETTING0) & BM_CCM_PLL_CTRL10_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL10_SETTING0(x, v) (HW_CCM_PLL_CTRL10_WR(x, (HW_CCM_PLL_CTRL10_RD(x) & ~BM_CCM_PLL_CTRL10_SETTING0) | BF_CCM_PLL_CTRL10_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL10, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL10_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL10_SETTING1. */
#define BM_CCM_PLL_CTRL10_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL10_SETTING1. */
#define BS_CCM_PLL_CTRL10_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL10_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL10_SETTING1 field. */
#define BR_CCM_PLL_CTRL10_SETTING1(x) (HW_CCM_PLL_CTRL10(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL10_SETTING1. */
#define BF_CCM_PLL_CTRL10_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL10_SETTING1) & BM_CCM_PLL_CTRL10_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL10_SETTING1(x, v) (HW_CCM_PLL_CTRL10_WR(x, (HW_CCM_PLL_CTRL10_RD(x) & ~BM_CCM_PLL_CTRL10_SETTING1) | BF_CCM_PLL_CTRL10_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL10, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL10_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL10_SETTING2. */
#define BM_CCM_PLL_CTRL10_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL10_SETTING2. */
#define BS_CCM_PLL_CTRL10_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL10_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL10_SETTING2 field. */
#define BR_CCM_PLL_CTRL10_SETTING2(x) (HW_CCM_PLL_CTRL10(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL10_SETTING2. */
#define BF_CCM_PLL_CTRL10_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL10_SETTING2) & BM_CCM_PLL_CTRL10_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL10_SETTING2(x, v) (HW_CCM_PLL_CTRL10_WR(x, (HW_CCM_PLL_CTRL10_RD(x) & ~BM_CCM_PLL_CTRL10_SETTING2) | BF_CCM_PLL_CTRL10_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL10, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL10_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL10_SETTING3. */
#define BM_CCM_PLL_CTRL10_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL10_SETTING3. */
#define BS_CCM_PLL_CTRL10_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL10_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL10_SETTING3 field. */
#define BR_CCM_PLL_CTRL10_SETTING3(x) (HW_CCM_PLL_CTRL10(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL10_SETTING3. */
#define BF_CCM_PLL_CTRL10_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL10_SETTING3) & BM_CCM_PLL_CTRL10_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL10_SETTING3(x, v) (HW_CCM_PLL_CTRL10_WR(x, (HW_CCM_PLL_CTRL10_RD(x) & ~BM_CCM_PLL_CTRL10_SETTING3) | BF_CCM_PLL_CTRL10_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL11 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL11 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl11
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl11_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl11_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL11 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL11_ADDR(x) ((uintptr_t)(x) + 0x8B0U)
#define HW_CCM_PLL_CTRL11_SET_ADDR(x) (HW_CCM_PLL_CTRL11_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL11_CLR_ADDR(x) (HW_CCM_PLL_CTRL11_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL11_TOG_ADDR(x) (HW_CCM_PLL_CTRL11_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL11(x)     (*(__IO hw_ccm_pll_ctrl11_t *) HW_CCM_PLL_CTRL11_ADDR(x))
#define HW_CCM_PLL_CTRL11_RD(x)  (HW_CCM_PLL_CTRL11(x).U)
#define HW_CCM_PLL_CTRL11_WR(x, v) (HW_CCM_PLL_CTRL11(x).U = (v))
#define HW_CCM_PLL_CTRL11_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL11_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL11_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL11_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL11_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL11_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL11 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL11, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL11_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL11_SETTING0. */
#define BM_CCM_PLL_CTRL11_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL11_SETTING0. */
#define BS_CCM_PLL_CTRL11_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL11_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL11_SETTING0 field. */
#define BR_CCM_PLL_CTRL11_SETTING0(x) (HW_CCM_PLL_CTRL11(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL11_SETTING0. */
#define BF_CCM_PLL_CTRL11_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL11_SETTING0) & BM_CCM_PLL_CTRL11_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL11_SETTING0(x, v) (HW_CCM_PLL_CTRL11_WR(x, (HW_CCM_PLL_CTRL11_RD(x) & ~BM_CCM_PLL_CTRL11_SETTING0) | BF_CCM_PLL_CTRL11_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL11, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL11_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL11_SETTING1. */
#define BM_CCM_PLL_CTRL11_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL11_SETTING1. */
#define BS_CCM_PLL_CTRL11_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL11_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL11_SETTING1 field. */
#define BR_CCM_PLL_CTRL11_SETTING1(x) (HW_CCM_PLL_CTRL11(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL11_SETTING1. */
#define BF_CCM_PLL_CTRL11_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL11_SETTING1) & BM_CCM_PLL_CTRL11_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL11_SETTING1(x, v) (HW_CCM_PLL_CTRL11_WR(x, (HW_CCM_PLL_CTRL11_RD(x) & ~BM_CCM_PLL_CTRL11_SETTING1) | BF_CCM_PLL_CTRL11_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL11, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL11_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL11_SETTING2. */
#define BM_CCM_PLL_CTRL11_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL11_SETTING2. */
#define BS_CCM_PLL_CTRL11_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL11_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL11_SETTING2 field. */
#define BR_CCM_PLL_CTRL11_SETTING2(x) (HW_CCM_PLL_CTRL11(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL11_SETTING2. */
#define BF_CCM_PLL_CTRL11_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL11_SETTING2) & BM_CCM_PLL_CTRL11_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL11_SETTING2(x, v) (HW_CCM_PLL_CTRL11_WR(x, (HW_CCM_PLL_CTRL11_RD(x) & ~BM_CCM_PLL_CTRL11_SETTING2) | BF_CCM_PLL_CTRL11_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL11, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL11_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL11_SETTING3. */
#define BM_CCM_PLL_CTRL11_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL11_SETTING3. */
#define BS_CCM_PLL_CTRL11_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL11_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL11_SETTING3 field. */
#define BR_CCM_PLL_CTRL11_SETTING3(x) (HW_CCM_PLL_CTRL11(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL11_SETTING3. */
#define BF_CCM_PLL_CTRL11_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL11_SETTING3) & BM_CCM_PLL_CTRL11_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL11_SETTING3(x, v) (HW_CCM_PLL_CTRL11_WR(x, (HW_CCM_PLL_CTRL11_RD(x) & ~BM_CCM_PLL_CTRL11_SETTING3) | BF_CCM_PLL_CTRL11_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL12 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL12 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl12
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl12_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl12_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL12 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL12_ADDR(x) ((uintptr_t)(x) + 0x8C0U)
#define HW_CCM_PLL_CTRL12_SET_ADDR(x) (HW_CCM_PLL_CTRL12_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL12_CLR_ADDR(x) (HW_CCM_PLL_CTRL12_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL12_TOG_ADDR(x) (HW_CCM_PLL_CTRL12_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL12(x)     (*(__IO hw_ccm_pll_ctrl12_t *) HW_CCM_PLL_CTRL12_ADDR(x))
#define HW_CCM_PLL_CTRL12_RD(x)  (HW_CCM_PLL_CTRL12(x).U)
#define HW_CCM_PLL_CTRL12_WR(x, v) (HW_CCM_PLL_CTRL12(x).U = (v))
#define HW_CCM_PLL_CTRL12_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL12_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL12_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL12_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL12_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL12_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL12 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL12, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL12_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL12_SETTING0. */
#define BM_CCM_PLL_CTRL12_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL12_SETTING0. */
#define BS_CCM_PLL_CTRL12_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL12_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL12_SETTING0 field. */
#define BR_CCM_PLL_CTRL12_SETTING0(x) (HW_CCM_PLL_CTRL12(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL12_SETTING0. */
#define BF_CCM_PLL_CTRL12_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL12_SETTING0) & BM_CCM_PLL_CTRL12_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL12_SETTING0(x, v) (HW_CCM_PLL_CTRL12_WR(x, (HW_CCM_PLL_CTRL12_RD(x) & ~BM_CCM_PLL_CTRL12_SETTING0) | BF_CCM_PLL_CTRL12_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL12, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL12_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL12_SETTING1. */
#define BM_CCM_PLL_CTRL12_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL12_SETTING1. */
#define BS_CCM_PLL_CTRL12_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL12_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL12_SETTING1 field. */
#define BR_CCM_PLL_CTRL12_SETTING1(x) (HW_CCM_PLL_CTRL12(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL12_SETTING1. */
#define BF_CCM_PLL_CTRL12_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL12_SETTING1) & BM_CCM_PLL_CTRL12_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL12_SETTING1(x, v) (HW_CCM_PLL_CTRL12_WR(x, (HW_CCM_PLL_CTRL12_RD(x) & ~BM_CCM_PLL_CTRL12_SETTING1) | BF_CCM_PLL_CTRL12_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL12, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL12_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL12_SETTING2. */
#define BM_CCM_PLL_CTRL12_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL12_SETTING2. */
#define BS_CCM_PLL_CTRL12_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL12_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL12_SETTING2 field. */
#define BR_CCM_PLL_CTRL12_SETTING2(x) (HW_CCM_PLL_CTRL12(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL12_SETTING2. */
#define BF_CCM_PLL_CTRL12_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL12_SETTING2) & BM_CCM_PLL_CTRL12_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL12_SETTING2(x, v) (HW_CCM_PLL_CTRL12_WR(x, (HW_CCM_PLL_CTRL12_RD(x) & ~BM_CCM_PLL_CTRL12_SETTING2) | BF_CCM_PLL_CTRL12_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL12, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL12_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL12_SETTING3. */
#define BM_CCM_PLL_CTRL12_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL12_SETTING3. */
#define BS_CCM_PLL_CTRL12_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL12_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL12_SETTING3 field. */
#define BR_CCM_PLL_CTRL12_SETTING3(x) (HW_CCM_PLL_CTRL12(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL12_SETTING3. */
#define BF_CCM_PLL_CTRL12_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL12_SETTING3) & BM_CCM_PLL_CTRL12_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL12_SETTING3(x, v) (HW_CCM_PLL_CTRL12_WR(x, (HW_CCM_PLL_CTRL12_RD(x) & ~BM_CCM_PLL_CTRL12_SETTING3) | BF_CCM_PLL_CTRL12_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL13 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL13 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl13
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl13_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl13_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL13 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL13_ADDR(x) ((uintptr_t)(x) + 0x8D0U)
#define HW_CCM_PLL_CTRL13_SET_ADDR(x) (HW_CCM_PLL_CTRL13_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL13_CLR_ADDR(x) (HW_CCM_PLL_CTRL13_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL13_TOG_ADDR(x) (HW_CCM_PLL_CTRL13_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL13(x)     (*(__IO hw_ccm_pll_ctrl13_t *) HW_CCM_PLL_CTRL13_ADDR(x))
#define HW_CCM_PLL_CTRL13_RD(x)  (HW_CCM_PLL_CTRL13(x).U)
#define HW_CCM_PLL_CTRL13_WR(x, v) (HW_CCM_PLL_CTRL13(x).U = (v))
#define HW_CCM_PLL_CTRL13_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL13_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL13_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL13_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL13_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL13_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL13 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL13, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL13_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL13_SETTING0. */
#define BM_CCM_PLL_CTRL13_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL13_SETTING0. */
#define BS_CCM_PLL_CTRL13_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL13_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL13_SETTING0 field. */
#define BR_CCM_PLL_CTRL13_SETTING0(x) (HW_CCM_PLL_CTRL13(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL13_SETTING0. */
#define BF_CCM_PLL_CTRL13_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL13_SETTING0) & BM_CCM_PLL_CTRL13_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL13_SETTING0(x, v) (HW_CCM_PLL_CTRL13_WR(x, (HW_CCM_PLL_CTRL13_RD(x) & ~BM_CCM_PLL_CTRL13_SETTING0) | BF_CCM_PLL_CTRL13_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL13, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL13_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL13_SETTING1. */
#define BM_CCM_PLL_CTRL13_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL13_SETTING1. */
#define BS_CCM_PLL_CTRL13_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL13_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL13_SETTING1 field. */
#define BR_CCM_PLL_CTRL13_SETTING1(x) (HW_CCM_PLL_CTRL13(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL13_SETTING1. */
#define BF_CCM_PLL_CTRL13_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL13_SETTING1) & BM_CCM_PLL_CTRL13_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL13_SETTING1(x, v) (HW_CCM_PLL_CTRL13_WR(x, (HW_CCM_PLL_CTRL13_RD(x) & ~BM_CCM_PLL_CTRL13_SETTING1) | BF_CCM_PLL_CTRL13_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL13, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL13_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL13_SETTING2. */
#define BM_CCM_PLL_CTRL13_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL13_SETTING2. */
#define BS_CCM_PLL_CTRL13_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL13_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL13_SETTING2 field. */
#define BR_CCM_PLL_CTRL13_SETTING2(x) (HW_CCM_PLL_CTRL13(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL13_SETTING2. */
#define BF_CCM_PLL_CTRL13_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL13_SETTING2) & BM_CCM_PLL_CTRL13_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL13_SETTING2(x, v) (HW_CCM_PLL_CTRL13_WR(x, (HW_CCM_PLL_CTRL13_RD(x) & ~BM_CCM_PLL_CTRL13_SETTING2) | BF_CCM_PLL_CTRL13_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL13, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL13_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL13_SETTING3. */
#define BM_CCM_PLL_CTRL13_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL13_SETTING3. */
#define BS_CCM_PLL_CTRL13_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL13_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL13_SETTING3 field. */
#define BR_CCM_PLL_CTRL13_SETTING3(x) (HW_CCM_PLL_CTRL13(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL13_SETTING3. */
#define BF_CCM_PLL_CTRL13_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL13_SETTING3) & BM_CCM_PLL_CTRL13_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL13_SETTING3(x, v) (HW_CCM_PLL_CTRL13_WR(x, (HW_CCM_PLL_CTRL13_RD(x) & ~BM_CCM_PLL_CTRL13_SETTING3) | BF_CCM_PLL_CTRL13_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL14 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL14 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl14
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl14_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl14_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL14 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL14_ADDR(x) ((uintptr_t)(x) + 0x8E0U)
#define HW_CCM_PLL_CTRL14_SET_ADDR(x) (HW_CCM_PLL_CTRL14_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL14_CLR_ADDR(x) (HW_CCM_PLL_CTRL14_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL14_TOG_ADDR(x) (HW_CCM_PLL_CTRL14_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL14(x)     (*(__IO hw_ccm_pll_ctrl14_t *) HW_CCM_PLL_CTRL14_ADDR(x))
#define HW_CCM_PLL_CTRL14_RD(x)  (HW_CCM_PLL_CTRL14(x).U)
#define HW_CCM_PLL_CTRL14_WR(x, v) (HW_CCM_PLL_CTRL14(x).U = (v))
#define HW_CCM_PLL_CTRL14_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL14_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL14_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL14_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL14_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL14_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL14 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL14, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL14_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL14_SETTING0. */
#define BM_CCM_PLL_CTRL14_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL14_SETTING0. */
#define BS_CCM_PLL_CTRL14_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL14_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL14_SETTING0 field. */
#define BR_CCM_PLL_CTRL14_SETTING0(x) (HW_CCM_PLL_CTRL14(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL14_SETTING0. */
#define BF_CCM_PLL_CTRL14_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL14_SETTING0) & BM_CCM_PLL_CTRL14_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL14_SETTING0(x, v) (HW_CCM_PLL_CTRL14_WR(x, (HW_CCM_PLL_CTRL14_RD(x) & ~BM_CCM_PLL_CTRL14_SETTING0) | BF_CCM_PLL_CTRL14_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL14, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL14_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL14_SETTING1. */
#define BM_CCM_PLL_CTRL14_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL14_SETTING1. */
#define BS_CCM_PLL_CTRL14_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL14_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL14_SETTING1 field. */
#define BR_CCM_PLL_CTRL14_SETTING1(x) (HW_CCM_PLL_CTRL14(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL14_SETTING1. */
#define BF_CCM_PLL_CTRL14_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL14_SETTING1) & BM_CCM_PLL_CTRL14_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL14_SETTING1(x, v) (HW_CCM_PLL_CTRL14_WR(x, (HW_CCM_PLL_CTRL14_RD(x) & ~BM_CCM_PLL_CTRL14_SETTING1) | BF_CCM_PLL_CTRL14_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL14, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL14_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL14_SETTING2. */
#define BM_CCM_PLL_CTRL14_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL14_SETTING2. */
#define BS_CCM_PLL_CTRL14_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL14_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL14_SETTING2 field. */
#define BR_CCM_PLL_CTRL14_SETTING2(x) (HW_CCM_PLL_CTRL14(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL14_SETTING2. */
#define BF_CCM_PLL_CTRL14_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL14_SETTING2) & BM_CCM_PLL_CTRL14_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL14_SETTING2(x, v) (HW_CCM_PLL_CTRL14_WR(x, (HW_CCM_PLL_CTRL14_RD(x) & ~BM_CCM_PLL_CTRL14_SETTING2) | BF_CCM_PLL_CTRL14_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL14, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL14_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL14_SETTING3. */
#define BM_CCM_PLL_CTRL14_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL14_SETTING3. */
#define BS_CCM_PLL_CTRL14_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL14_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL14_SETTING3 field. */
#define BR_CCM_PLL_CTRL14_SETTING3(x) (HW_CCM_PLL_CTRL14(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL14_SETTING3. */
#define BF_CCM_PLL_CTRL14_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL14_SETTING3) & BM_CCM_PLL_CTRL14_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL14_SETTING3(x, v) (HW_CCM_PLL_CTRL14_WR(x, (HW_CCM_PLL_CTRL14_RD(x) & ~BM_CCM_PLL_CTRL14_SETTING3) | BF_CCM_PLL_CTRL14_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL15 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL15 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl15
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl15_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl15_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL15 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL15_ADDR(x) ((uintptr_t)(x) + 0x8F0U)
#define HW_CCM_PLL_CTRL15_SET_ADDR(x) (HW_CCM_PLL_CTRL15_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL15_CLR_ADDR(x) (HW_CCM_PLL_CTRL15_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL15_TOG_ADDR(x) (HW_CCM_PLL_CTRL15_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL15(x)     (*(__IO hw_ccm_pll_ctrl15_t *) HW_CCM_PLL_CTRL15_ADDR(x))
#define HW_CCM_PLL_CTRL15_RD(x)  (HW_CCM_PLL_CTRL15(x).U)
#define HW_CCM_PLL_CTRL15_WR(x, v) (HW_CCM_PLL_CTRL15(x).U = (v))
#define HW_CCM_PLL_CTRL15_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL15_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL15_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL15_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL15_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL15_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL15 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL15, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL15_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL15_SETTING0. */
#define BM_CCM_PLL_CTRL15_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL15_SETTING0. */
#define BS_CCM_PLL_CTRL15_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL15_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL15_SETTING0 field. */
#define BR_CCM_PLL_CTRL15_SETTING0(x) (HW_CCM_PLL_CTRL15(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL15_SETTING0. */
#define BF_CCM_PLL_CTRL15_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL15_SETTING0) & BM_CCM_PLL_CTRL15_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL15_SETTING0(x, v) (HW_CCM_PLL_CTRL15_WR(x, (HW_CCM_PLL_CTRL15_RD(x) & ~BM_CCM_PLL_CTRL15_SETTING0) | BF_CCM_PLL_CTRL15_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL15, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL15_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL15_SETTING1. */
#define BM_CCM_PLL_CTRL15_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL15_SETTING1. */
#define BS_CCM_PLL_CTRL15_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL15_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL15_SETTING1 field. */
#define BR_CCM_PLL_CTRL15_SETTING1(x) (HW_CCM_PLL_CTRL15(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL15_SETTING1. */
#define BF_CCM_PLL_CTRL15_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL15_SETTING1) & BM_CCM_PLL_CTRL15_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL15_SETTING1(x, v) (HW_CCM_PLL_CTRL15_WR(x, (HW_CCM_PLL_CTRL15_RD(x) & ~BM_CCM_PLL_CTRL15_SETTING1) | BF_CCM_PLL_CTRL15_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL15, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL15_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL15_SETTING2. */
#define BM_CCM_PLL_CTRL15_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL15_SETTING2. */
#define BS_CCM_PLL_CTRL15_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL15_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL15_SETTING2 field. */
#define BR_CCM_PLL_CTRL15_SETTING2(x) (HW_CCM_PLL_CTRL15(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL15_SETTING2. */
#define BF_CCM_PLL_CTRL15_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL15_SETTING2) & BM_CCM_PLL_CTRL15_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL15_SETTING2(x, v) (HW_CCM_PLL_CTRL15_WR(x, (HW_CCM_PLL_CTRL15_RD(x) & ~BM_CCM_PLL_CTRL15_SETTING2) | BF_CCM_PLL_CTRL15_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL15, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL15_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL15_SETTING3. */
#define BM_CCM_PLL_CTRL15_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL15_SETTING3. */
#define BS_CCM_PLL_CTRL15_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL15_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL15_SETTING3 field. */
#define BR_CCM_PLL_CTRL15_SETTING3(x) (HW_CCM_PLL_CTRL15(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL15_SETTING3. */
#define BF_CCM_PLL_CTRL15_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL15_SETTING3) & BM_CCM_PLL_CTRL15_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL15_SETTING3(x, v) (HW_CCM_PLL_CTRL15_WR(x, (HW_CCM_PLL_CTRL15_RD(x) & ~BM_CCM_PLL_CTRL15_SETTING3) | BF_CCM_PLL_CTRL15_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL16 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL16 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl16
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl16_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl16_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL16 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL16_ADDR(x) ((uintptr_t)(x) + 0x900U)
#define HW_CCM_PLL_CTRL16_SET_ADDR(x) (HW_CCM_PLL_CTRL16_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL16_CLR_ADDR(x) (HW_CCM_PLL_CTRL16_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL16_TOG_ADDR(x) (HW_CCM_PLL_CTRL16_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL16(x)     (*(__IO hw_ccm_pll_ctrl16_t *) HW_CCM_PLL_CTRL16_ADDR(x))
#define HW_CCM_PLL_CTRL16_RD(x)  (HW_CCM_PLL_CTRL16(x).U)
#define HW_CCM_PLL_CTRL16_WR(x, v) (HW_CCM_PLL_CTRL16(x).U = (v))
#define HW_CCM_PLL_CTRL16_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL16_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL16_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL16_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL16_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL16_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL16 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL16, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL16_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL16_SETTING0. */
#define BM_CCM_PLL_CTRL16_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL16_SETTING0. */
#define BS_CCM_PLL_CTRL16_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL16_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL16_SETTING0 field. */
#define BR_CCM_PLL_CTRL16_SETTING0(x) (HW_CCM_PLL_CTRL16(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL16_SETTING0. */
#define BF_CCM_PLL_CTRL16_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL16_SETTING0) & BM_CCM_PLL_CTRL16_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL16_SETTING0(x, v) (HW_CCM_PLL_CTRL16_WR(x, (HW_CCM_PLL_CTRL16_RD(x) & ~BM_CCM_PLL_CTRL16_SETTING0) | BF_CCM_PLL_CTRL16_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL16, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL16_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL16_SETTING1. */
#define BM_CCM_PLL_CTRL16_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL16_SETTING1. */
#define BS_CCM_PLL_CTRL16_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL16_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL16_SETTING1 field. */
#define BR_CCM_PLL_CTRL16_SETTING1(x) (HW_CCM_PLL_CTRL16(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL16_SETTING1. */
#define BF_CCM_PLL_CTRL16_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL16_SETTING1) & BM_CCM_PLL_CTRL16_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL16_SETTING1(x, v) (HW_CCM_PLL_CTRL16_WR(x, (HW_CCM_PLL_CTRL16_RD(x) & ~BM_CCM_PLL_CTRL16_SETTING1) | BF_CCM_PLL_CTRL16_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL16, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL16_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL16_SETTING2. */
#define BM_CCM_PLL_CTRL16_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL16_SETTING2. */
#define BS_CCM_PLL_CTRL16_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL16_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL16_SETTING2 field. */
#define BR_CCM_PLL_CTRL16_SETTING2(x) (HW_CCM_PLL_CTRL16(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL16_SETTING2. */
#define BF_CCM_PLL_CTRL16_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL16_SETTING2) & BM_CCM_PLL_CTRL16_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL16_SETTING2(x, v) (HW_CCM_PLL_CTRL16_WR(x, (HW_CCM_PLL_CTRL16_RD(x) & ~BM_CCM_PLL_CTRL16_SETTING2) | BF_CCM_PLL_CTRL16_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL16, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL16_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL16_SETTING3. */
#define BM_CCM_PLL_CTRL16_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL16_SETTING3. */
#define BS_CCM_PLL_CTRL16_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL16_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL16_SETTING3 field. */
#define BR_CCM_PLL_CTRL16_SETTING3(x) (HW_CCM_PLL_CTRL16(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL16_SETTING3. */
#define BF_CCM_PLL_CTRL16_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL16_SETTING3) & BM_CCM_PLL_CTRL16_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL16_SETTING3(x, v) (HW_CCM_PLL_CTRL16_WR(x, (HW_CCM_PLL_CTRL16_RD(x) & ~BM_CCM_PLL_CTRL16_SETTING3) | BF_CCM_PLL_CTRL16_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL17 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL17 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl17
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl17_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl17_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL17 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL17_ADDR(x) ((uintptr_t)(x) + 0x910U)
#define HW_CCM_PLL_CTRL17_SET_ADDR(x) (HW_CCM_PLL_CTRL17_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL17_CLR_ADDR(x) (HW_CCM_PLL_CTRL17_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL17_TOG_ADDR(x) (HW_CCM_PLL_CTRL17_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL17(x)     (*(__IO hw_ccm_pll_ctrl17_t *) HW_CCM_PLL_CTRL17_ADDR(x))
#define HW_CCM_PLL_CTRL17_RD(x)  (HW_CCM_PLL_CTRL17(x).U)
#define HW_CCM_PLL_CTRL17_WR(x, v) (HW_CCM_PLL_CTRL17(x).U = (v))
#define HW_CCM_PLL_CTRL17_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL17_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL17_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL17_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL17_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL17_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL17 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL17, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL17_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL17_SETTING0. */
#define BM_CCM_PLL_CTRL17_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL17_SETTING0. */
#define BS_CCM_PLL_CTRL17_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL17_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL17_SETTING0 field. */
#define BR_CCM_PLL_CTRL17_SETTING0(x) (HW_CCM_PLL_CTRL17(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL17_SETTING0. */
#define BF_CCM_PLL_CTRL17_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL17_SETTING0) & BM_CCM_PLL_CTRL17_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL17_SETTING0(x, v) (HW_CCM_PLL_CTRL17_WR(x, (HW_CCM_PLL_CTRL17_RD(x) & ~BM_CCM_PLL_CTRL17_SETTING0) | BF_CCM_PLL_CTRL17_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL17, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL17_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL17_SETTING1. */
#define BM_CCM_PLL_CTRL17_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL17_SETTING1. */
#define BS_CCM_PLL_CTRL17_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL17_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL17_SETTING1 field. */
#define BR_CCM_PLL_CTRL17_SETTING1(x) (HW_CCM_PLL_CTRL17(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL17_SETTING1. */
#define BF_CCM_PLL_CTRL17_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL17_SETTING1) & BM_CCM_PLL_CTRL17_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL17_SETTING1(x, v) (HW_CCM_PLL_CTRL17_WR(x, (HW_CCM_PLL_CTRL17_RD(x) & ~BM_CCM_PLL_CTRL17_SETTING1) | BF_CCM_PLL_CTRL17_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL17, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL17_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL17_SETTING2. */
#define BM_CCM_PLL_CTRL17_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL17_SETTING2. */
#define BS_CCM_PLL_CTRL17_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL17_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL17_SETTING2 field. */
#define BR_CCM_PLL_CTRL17_SETTING2(x) (HW_CCM_PLL_CTRL17(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL17_SETTING2. */
#define BF_CCM_PLL_CTRL17_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL17_SETTING2) & BM_CCM_PLL_CTRL17_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL17_SETTING2(x, v) (HW_CCM_PLL_CTRL17_WR(x, (HW_CCM_PLL_CTRL17_RD(x) & ~BM_CCM_PLL_CTRL17_SETTING2) | BF_CCM_PLL_CTRL17_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL17, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL17_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL17_SETTING3. */
#define BM_CCM_PLL_CTRL17_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL17_SETTING3. */
#define BS_CCM_PLL_CTRL17_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL17_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL17_SETTING3 field. */
#define BR_CCM_PLL_CTRL17_SETTING3(x) (HW_CCM_PLL_CTRL17(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL17_SETTING3. */
#define BF_CCM_PLL_CTRL17_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL17_SETTING3) & BM_CCM_PLL_CTRL17_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL17_SETTING3(x, v) (HW_CCM_PLL_CTRL17_WR(x, (HW_CCM_PLL_CTRL17_RD(x) & ~BM_CCM_PLL_CTRL17_SETTING3) | BF_CCM_PLL_CTRL17_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL18 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL18 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl18
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl18_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl18_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL18 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL18_ADDR(x) ((uintptr_t)(x) + 0x920U)
#define HW_CCM_PLL_CTRL18_SET_ADDR(x) (HW_CCM_PLL_CTRL18_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL18_CLR_ADDR(x) (HW_CCM_PLL_CTRL18_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL18_TOG_ADDR(x) (HW_CCM_PLL_CTRL18_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL18(x)     (*(__IO hw_ccm_pll_ctrl18_t *) HW_CCM_PLL_CTRL18_ADDR(x))
#define HW_CCM_PLL_CTRL18_RD(x)  (HW_CCM_PLL_CTRL18(x).U)
#define HW_CCM_PLL_CTRL18_WR(x, v) (HW_CCM_PLL_CTRL18(x).U = (v))
#define HW_CCM_PLL_CTRL18_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL18_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL18_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL18_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL18_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL18_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL18 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL18, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL18_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL18_SETTING0. */
#define BM_CCM_PLL_CTRL18_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL18_SETTING0. */
#define BS_CCM_PLL_CTRL18_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL18_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL18_SETTING0 field. */
#define BR_CCM_PLL_CTRL18_SETTING0(x) (HW_CCM_PLL_CTRL18(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL18_SETTING0. */
#define BF_CCM_PLL_CTRL18_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL18_SETTING0) & BM_CCM_PLL_CTRL18_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL18_SETTING0(x, v) (HW_CCM_PLL_CTRL18_WR(x, (HW_CCM_PLL_CTRL18_RD(x) & ~BM_CCM_PLL_CTRL18_SETTING0) | BF_CCM_PLL_CTRL18_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL18, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL18_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL18_SETTING1. */
#define BM_CCM_PLL_CTRL18_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL18_SETTING1. */
#define BS_CCM_PLL_CTRL18_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL18_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL18_SETTING1 field. */
#define BR_CCM_PLL_CTRL18_SETTING1(x) (HW_CCM_PLL_CTRL18(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL18_SETTING1. */
#define BF_CCM_PLL_CTRL18_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL18_SETTING1) & BM_CCM_PLL_CTRL18_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL18_SETTING1(x, v) (HW_CCM_PLL_CTRL18_WR(x, (HW_CCM_PLL_CTRL18_RD(x) & ~BM_CCM_PLL_CTRL18_SETTING1) | BF_CCM_PLL_CTRL18_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL18, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL18_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL18_SETTING2. */
#define BM_CCM_PLL_CTRL18_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL18_SETTING2. */
#define BS_CCM_PLL_CTRL18_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL18_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL18_SETTING2 field. */
#define BR_CCM_PLL_CTRL18_SETTING2(x) (HW_CCM_PLL_CTRL18(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL18_SETTING2. */
#define BF_CCM_PLL_CTRL18_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL18_SETTING2) & BM_CCM_PLL_CTRL18_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL18_SETTING2(x, v) (HW_CCM_PLL_CTRL18_WR(x, (HW_CCM_PLL_CTRL18_RD(x) & ~BM_CCM_PLL_CTRL18_SETTING2) | BF_CCM_PLL_CTRL18_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL18, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL18_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL18_SETTING3. */
#define BM_CCM_PLL_CTRL18_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL18_SETTING3. */
#define BS_CCM_PLL_CTRL18_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL18_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL18_SETTING3 field. */
#define BR_CCM_PLL_CTRL18_SETTING3(x) (HW_CCM_PLL_CTRL18(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL18_SETTING3. */
#define BF_CCM_PLL_CTRL18_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL18_SETTING3) & BM_CCM_PLL_CTRL18_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL18_SETTING3(x, v) (HW_CCM_PLL_CTRL18_WR(x, (HW_CCM_PLL_CTRL18_RD(x) & ~BM_CCM_PLL_CTRL18_SETTING3) | BF_CCM_PLL_CTRL18_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL19 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL19 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl19
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl19_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl19_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL19 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL19_ADDR(x) ((uintptr_t)(x) + 0x930U)
#define HW_CCM_PLL_CTRL19_SET_ADDR(x) (HW_CCM_PLL_CTRL19_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL19_CLR_ADDR(x) (HW_CCM_PLL_CTRL19_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL19_TOG_ADDR(x) (HW_CCM_PLL_CTRL19_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL19(x)     (*(__IO hw_ccm_pll_ctrl19_t *) HW_CCM_PLL_CTRL19_ADDR(x))
#define HW_CCM_PLL_CTRL19_RD(x)  (HW_CCM_PLL_CTRL19(x).U)
#define HW_CCM_PLL_CTRL19_WR(x, v) (HW_CCM_PLL_CTRL19(x).U = (v))
#define HW_CCM_PLL_CTRL19_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL19_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL19_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL19_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL19_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL19_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL19 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL19, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL19_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL19_SETTING0. */
#define BM_CCM_PLL_CTRL19_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL19_SETTING0. */
#define BS_CCM_PLL_CTRL19_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL19_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL19_SETTING0 field. */
#define BR_CCM_PLL_CTRL19_SETTING0(x) (HW_CCM_PLL_CTRL19(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL19_SETTING0. */
#define BF_CCM_PLL_CTRL19_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL19_SETTING0) & BM_CCM_PLL_CTRL19_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL19_SETTING0(x, v) (HW_CCM_PLL_CTRL19_WR(x, (HW_CCM_PLL_CTRL19_RD(x) & ~BM_CCM_PLL_CTRL19_SETTING0) | BF_CCM_PLL_CTRL19_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL19, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL19_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL19_SETTING1. */
#define BM_CCM_PLL_CTRL19_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL19_SETTING1. */
#define BS_CCM_PLL_CTRL19_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL19_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL19_SETTING1 field. */
#define BR_CCM_PLL_CTRL19_SETTING1(x) (HW_CCM_PLL_CTRL19(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL19_SETTING1. */
#define BF_CCM_PLL_CTRL19_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL19_SETTING1) & BM_CCM_PLL_CTRL19_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL19_SETTING1(x, v) (HW_CCM_PLL_CTRL19_WR(x, (HW_CCM_PLL_CTRL19_RD(x) & ~BM_CCM_PLL_CTRL19_SETTING1) | BF_CCM_PLL_CTRL19_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL19, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL19_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL19_SETTING2. */
#define BM_CCM_PLL_CTRL19_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL19_SETTING2. */
#define BS_CCM_PLL_CTRL19_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL19_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL19_SETTING2 field. */
#define BR_CCM_PLL_CTRL19_SETTING2(x) (HW_CCM_PLL_CTRL19(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL19_SETTING2. */
#define BF_CCM_PLL_CTRL19_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL19_SETTING2) & BM_CCM_PLL_CTRL19_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL19_SETTING2(x, v) (HW_CCM_PLL_CTRL19_WR(x, (HW_CCM_PLL_CTRL19_RD(x) & ~BM_CCM_PLL_CTRL19_SETTING2) | BF_CCM_PLL_CTRL19_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL19, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL19_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL19_SETTING3. */
#define BM_CCM_PLL_CTRL19_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL19_SETTING3. */
#define BS_CCM_PLL_CTRL19_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL19_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL19_SETTING3 field. */
#define BR_CCM_PLL_CTRL19_SETTING3(x) (HW_CCM_PLL_CTRL19(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL19_SETTING3. */
#define BF_CCM_PLL_CTRL19_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL19_SETTING3) & BM_CCM_PLL_CTRL19_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL19_SETTING3(x, v) (HW_CCM_PLL_CTRL19_WR(x, (HW_CCM_PLL_CTRL19_RD(x) & ~BM_CCM_PLL_CTRL19_SETTING3) | BF_CCM_PLL_CTRL19_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL20 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL20 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl20
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl20_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl20_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL20 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL20_ADDR(x) ((uintptr_t)(x) + 0x940U)
#define HW_CCM_PLL_CTRL20_SET_ADDR(x) (HW_CCM_PLL_CTRL20_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL20_CLR_ADDR(x) (HW_CCM_PLL_CTRL20_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL20_TOG_ADDR(x) (HW_CCM_PLL_CTRL20_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL20(x)     (*(__IO hw_ccm_pll_ctrl20_t *) HW_CCM_PLL_CTRL20_ADDR(x))
#define HW_CCM_PLL_CTRL20_RD(x)  (HW_CCM_PLL_CTRL20(x).U)
#define HW_CCM_PLL_CTRL20_WR(x, v) (HW_CCM_PLL_CTRL20(x).U = (v))
#define HW_CCM_PLL_CTRL20_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL20_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL20_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL20_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL20_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL20_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL20 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL20, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL20_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL20_SETTING0. */
#define BM_CCM_PLL_CTRL20_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL20_SETTING0. */
#define BS_CCM_PLL_CTRL20_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL20_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL20_SETTING0 field. */
#define BR_CCM_PLL_CTRL20_SETTING0(x) (HW_CCM_PLL_CTRL20(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL20_SETTING0. */
#define BF_CCM_PLL_CTRL20_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL20_SETTING0) & BM_CCM_PLL_CTRL20_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL20_SETTING0(x, v) (HW_CCM_PLL_CTRL20_WR(x, (HW_CCM_PLL_CTRL20_RD(x) & ~BM_CCM_PLL_CTRL20_SETTING0) | BF_CCM_PLL_CTRL20_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL20, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL20_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL20_SETTING1. */
#define BM_CCM_PLL_CTRL20_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL20_SETTING1. */
#define BS_CCM_PLL_CTRL20_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL20_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL20_SETTING1 field. */
#define BR_CCM_PLL_CTRL20_SETTING1(x) (HW_CCM_PLL_CTRL20(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL20_SETTING1. */
#define BF_CCM_PLL_CTRL20_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL20_SETTING1) & BM_CCM_PLL_CTRL20_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL20_SETTING1(x, v) (HW_CCM_PLL_CTRL20_WR(x, (HW_CCM_PLL_CTRL20_RD(x) & ~BM_CCM_PLL_CTRL20_SETTING1) | BF_CCM_PLL_CTRL20_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL20, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL20_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL20_SETTING2. */
#define BM_CCM_PLL_CTRL20_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL20_SETTING2. */
#define BS_CCM_PLL_CTRL20_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL20_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL20_SETTING2 field. */
#define BR_CCM_PLL_CTRL20_SETTING2(x) (HW_CCM_PLL_CTRL20(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL20_SETTING2. */
#define BF_CCM_PLL_CTRL20_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL20_SETTING2) & BM_CCM_PLL_CTRL20_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL20_SETTING2(x, v) (HW_CCM_PLL_CTRL20_WR(x, (HW_CCM_PLL_CTRL20_RD(x) & ~BM_CCM_PLL_CTRL20_SETTING2) | BF_CCM_PLL_CTRL20_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL20, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL20_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL20_SETTING3. */
#define BM_CCM_PLL_CTRL20_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL20_SETTING3. */
#define BS_CCM_PLL_CTRL20_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL20_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL20_SETTING3 field. */
#define BR_CCM_PLL_CTRL20_SETTING3(x) (HW_CCM_PLL_CTRL20(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL20_SETTING3. */
#define BF_CCM_PLL_CTRL20_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL20_SETTING3) & BM_CCM_PLL_CTRL20_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL20_SETTING3(x, v) (HW_CCM_PLL_CTRL20_WR(x, (HW_CCM_PLL_CTRL20_RD(x) & ~BM_CCM_PLL_CTRL20_SETTING3) | BF_CCM_PLL_CTRL20_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL21 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL21 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl21
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl21_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl21_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL21 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL21_ADDR(x) ((uintptr_t)(x) + 0x950U)
#define HW_CCM_PLL_CTRL21_SET_ADDR(x) (HW_CCM_PLL_CTRL21_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL21_CLR_ADDR(x) (HW_CCM_PLL_CTRL21_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL21_TOG_ADDR(x) (HW_CCM_PLL_CTRL21_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL21(x)     (*(__IO hw_ccm_pll_ctrl21_t *) HW_CCM_PLL_CTRL21_ADDR(x))
#define HW_CCM_PLL_CTRL21_RD(x)  (HW_CCM_PLL_CTRL21(x).U)
#define HW_CCM_PLL_CTRL21_WR(x, v) (HW_CCM_PLL_CTRL21(x).U = (v))
#define HW_CCM_PLL_CTRL21_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL21_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL21_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL21_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL21_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL21_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL21 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL21, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL21_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL21_SETTING0. */
#define BM_CCM_PLL_CTRL21_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL21_SETTING0. */
#define BS_CCM_PLL_CTRL21_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL21_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL21_SETTING0 field. */
#define BR_CCM_PLL_CTRL21_SETTING0(x) (HW_CCM_PLL_CTRL21(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL21_SETTING0. */
#define BF_CCM_PLL_CTRL21_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL21_SETTING0) & BM_CCM_PLL_CTRL21_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL21_SETTING0(x, v) (HW_CCM_PLL_CTRL21_WR(x, (HW_CCM_PLL_CTRL21_RD(x) & ~BM_CCM_PLL_CTRL21_SETTING0) | BF_CCM_PLL_CTRL21_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL21, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL21_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL21_SETTING1. */
#define BM_CCM_PLL_CTRL21_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL21_SETTING1. */
#define BS_CCM_PLL_CTRL21_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL21_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL21_SETTING1 field. */
#define BR_CCM_PLL_CTRL21_SETTING1(x) (HW_CCM_PLL_CTRL21(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL21_SETTING1. */
#define BF_CCM_PLL_CTRL21_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL21_SETTING1) & BM_CCM_PLL_CTRL21_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL21_SETTING1(x, v) (HW_CCM_PLL_CTRL21_WR(x, (HW_CCM_PLL_CTRL21_RD(x) & ~BM_CCM_PLL_CTRL21_SETTING1) | BF_CCM_PLL_CTRL21_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL21, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL21_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL21_SETTING2. */
#define BM_CCM_PLL_CTRL21_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL21_SETTING2. */
#define BS_CCM_PLL_CTRL21_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL21_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL21_SETTING2 field. */
#define BR_CCM_PLL_CTRL21_SETTING2(x) (HW_CCM_PLL_CTRL21(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL21_SETTING2. */
#define BF_CCM_PLL_CTRL21_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL21_SETTING2) & BM_CCM_PLL_CTRL21_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL21_SETTING2(x, v) (HW_CCM_PLL_CTRL21_WR(x, (HW_CCM_PLL_CTRL21_RD(x) & ~BM_CCM_PLL_CTRL21_SETTING2) | BF_CCM_PLL_CTRL21_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL21, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL21_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL21_SETTING3. */
#define BM_CCM_PLL_CTRL21_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL21_SETTING3. */
#define BS_CCM_PLL_CTRL21_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL21_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL21_SETTING3 field. */
#define BR_CCM_PLL_CTRL21_SETTING3(x) (HW_CCM_PLL_CTRL21(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL21_SETTING3. */
#define BF_CCM_PLL_CTRL21_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL21_SETTING3) & BM_CCM_PLL_CTRL21_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL21_SETTING3(x, v) (HW_CCM_PLL_CTRL21_WR(x, (HW_CCM_PLL_CTRL21_RD(x) & ~BM_CCM_PLL_CTRL21_SETTING3) | BF_CCM_PLL_CTRL21_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL22 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL22 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl22
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl22_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl22_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL22 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL22_ADDR(x) ((uintptr_t)(x) + 0x960U)
#define HW_CCM_PLL_CTRL22_SET_ADDR(x) (HW_CCM_PLL_CTRL22_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL22_CLR_ADDR(x) (HW_CCM_PLL_CTRL22_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL22_TOG_ADDR(x) (HW_CCM_PLL_CTRL22_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL22(x)     (*(__IO hw_ccm_pll_ctrl22_t *) HW_CCM_PLL_CTRL22_ADDR(x))
#define HW_CCM_PLL_CTRL22_RD(x)  (HW_CCM_PLL_CTRL22(x).U)
#define HW_CCM_PLL_CTRL22_WR(x, v) (HW_CCM_PLL_CTRL22(x).U = (v))
#define HW_CCM_PLL_CTRL22_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL22_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL22_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL22_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL22_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL22_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL22 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL22, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL22_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL22_SETTING0. */
#define BM_CCM_PLL_CTRL22_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL22_SETTING0. */
#define BS_CCM_PLL_CTRL22_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL22_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL22_SETTING0 field. */
#define BR_CCM_PLL_CTRL22_SETTING0(x) (HW_CCM_PLL_CTRL22(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL22_SETTING0. */
#define BF_CCM_PLL_CTRL22_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL22_SETTING0) & BM_CCM_PLL_CTRL22_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL22_SETTING0(x, v) (HW_CCM_PLL_CTRL22_WR(x, (HW_CCM_PLL_CTRL22_RD(x) & ~BM_CCM_PLL_CTRL22_SETTING0) | BF_CCM_PLL_CTRL22_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL22, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL22_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL22_SETTING1. */
#define BM_CCM_PLL_CTRL22_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL22_SETTING1. */
#define BS_CCM_PLL_CTRL22_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL22_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL22_SETTING1 field. */
#define BR_CCM_PLL_CTRL22_SETTING1(x) (HW_CCM_PLL_CTRL22(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL22_SETTING1. */
#define BF_CCM_PLL_CTRL22_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL22_SETTING1) & BM_CCM_PLL_CTRL22_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL22_SETTING1(x, v) (HW_CCM_PLL_CTRL22_WR(x, (HW_CCM_PLL_CTRL22_RD(x) & ~BM_CCM_PLL_CTRL22_SETTING1) | BF_CCM_PLL_CTRL22_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL22, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL22_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL22_SETTING2. */
#define BM_CCM_PLL_CTRL22_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL22_SETTING2. */
#define BS_CCM_PLL_CTRL22_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL22_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL22_SETTING2 field. */
#define BR_CCM_PLL_CTRL22_SETTING2(x) (HW_CCM_PLL_CTRL22(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL22_SETTING2. */
#define BF_CCM_PLL_CTRL22_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL22_SETTING2) & BM_CCM_PLL_CTRL22_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL22_SETTING2(x, v) (HW_CCM_PLL_CTRL22_WR(x, (HW_CCM_PLL_CTRL22_RD(x) & ~BM_CCM_PLL_CTRL22_SETTING2) | BF_CCM_PLL_CTRL22_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL22, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL22_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL22_SETTING3. */
#define BM_CCM_PLL_CTRL22_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL22_SETTING3. */
#define BS_CCM_PLL_CTRL22_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL22_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL22_SETTING3 field. */
#define BR_CCM_PLL_CTRL22_SETTING3(x) (HW_CCM_PLL_CTRL22(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL22_SETTING3. */
#define BF_CCM_PLL_CTRL22_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL22_SETTING3) & BM_CCM_PLL_CTRL22_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL22_SETTING3(x, v) (HW_CCM_PLL_CTRL22_WR(x, (HW_CCM_PLL_CTRL22_RD(x) & ~BM_CCM_PLL_CTRL22_SETTING3) | BF_CCM_PLL_CTRL22_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL23 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL23 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl23
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl23_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl23_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL23 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL23_ADDR(x) ((uintptr_t)(x) + 0x970U)
#define HW_CCM_PLL_CTRL23_SET_ADDR(x) (HW_CCM_PLL_CTRL23_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL23_CLR_ADDR(x) (HW_CCM_PLL_CTRL23_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL23_TOG_ADDR(x) (HW_CCM_PLL_CTRL23_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL23(x)     (*(__IO hw_ccm_pll_ctrl23_t *) HW_CCM_PLL_CTRL23_ADDR(x))
#define HW_CCM_PLL_CTRL23_RD(x)  (HW_CCM_PLL_CTRL23(x).U)
#define HW_CCM_PLL_CTRL23_WR(x, v) (HW_CCM_PLL_CTRL23(x).U = (v))
#define HW_CCM_PLL_CTRL23_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL23_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL23_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL23_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL23_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL23_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL23 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL23, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL23_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL23_SETTING0. */
#define BM_CCM_PLL_CTRL23_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL23_SETTING0. */
#define BS_CCM_PLL_CTRL23_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL23_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL23_SETTING0 field. */
#define BR_CCM_PLL_CTRL23_SETTING0(x) (HW_CCM_PLL_CTRL23(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL23_SETTING0. */
#define BF_CCM_PLL_CTRL23_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL23_SETTING0) & BM_CCM_PLL_CTRL23_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL23_SETTING0(x, v) (HW_CCM_PLL_CTRL23_WR(x, (HW_CCM_PLL_CTRL23_RD(x) & ~BM_CCM_PLL_CTRL23_SETTING0) | BF_CCM_PLL_CTRL23_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL23, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL23_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL23_SETTING1. */
#define BM_CCM_PLL_CTRL23_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL23_SETTING1. */
#define BS_CCM_PLL_CTRL23_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL23_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL23_SETTING1 field. */
#define BR_CCM_PLL_CTRL23_SETTING1(x) (HW_CCM_PLL_CTRL23(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL23_SETTING1. */
#define BF_CCM_PLL_CTRL23_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL23_SETTING1) & BM_CCM_PLL_CTRL23_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL23_SETTING1(x, v) (HW_CCM_PLL_CTRL23_WR(x, (HW_CCM_PLL_CTRL23_RD(x) & ~BM_CCM_PLL_CTRL23_SETTING1) | BF_CCM_PLL_CTRL23_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL23, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL23_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL23_SETTING2. */
#define BM_CCM_PLL_CTRL23_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL23_SETTING2. */
#define BS_CCM_PLL_CTRL23_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL23_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL23_SETTING2 field. */
#define BR_CCM_PLL_CTRL23_SETTING2(x) (HW_CCM_PLL_CTRL23(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL23_SETTING2. */
#define BF_CCM_PLL_CTRL23_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL23_SETTING2) & BM_CCM_PLL_CTRL23_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL23_SETTING2(x, v) (HW_CCM_PLL_CTRL23_WR(x, (HW_CCM_PLL_CTRL23_RD(x) & ~BM_CCM_PLL_CTRL23_SETTING2) | BF_CCM_PLL_CTRL23_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL23, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL23_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL23_SETTING3. */
#define BM_CCM_PLL_CTRL23_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL23_SETTING3. */
#define BS_CCM_PLL_CTRL23_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL23_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL23_SETTING3 field. */
#define BR_CCM_PLL_CTRL23_SETTING3(x) (HW_CCM_PLL_CTRL23(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL23_SETTING3. */
#define BF_CCM_PLL_CTRL23_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL23_SETTING3) & BM_CCM_PLL_CTRL23_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL23_SETTING3(x, v) (HW_CCM_PLL_CTRL23_WR(x, (HW_CCM_PLL_CTRL23_RD(x) & ~BM_CCM_PLL_CTRL23_SETTING3) | BF_CCM_PLL_CTRL23_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL24 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL24 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl24
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl24_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl24_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL24 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL24_ADDR(x) ((uintptr_t)(x) + 0x980U)
#define HW_CCM_PLL_CTRL24_SET_ADDR(x) (HW_CCM_PLL_CTRL24_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL24_CLR_ADDR(x) (HW_CCM_PLL_CTRL24_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL24_TOG_ADDR(x) (HW_CCM_PLL_CTRL24_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL24(x)     (*(__IO hw_ccm_pll_ctrl24_t *) HW_CCM_PLL_CTRL24_ADDR(x))
#define HW_CCM_PLL_CTRL24_RD(x)  (HW_CCM_PLL_CTRL24(x).U)
#define HW_CCM_PLL_CTRL24_WR(x, v) (HW_CCM_PLL_CTRL24(x).U = (v))
#define HW_CCM_PLL_CTRL24_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL24_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL24_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL24_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL24_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL24_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL24 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL24, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL24_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL24_SETTING0. */
#define BM_CCM_PLL_CTRL24_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL24_SETTING0. */
#define BS_CCM_PLL_CTRL24_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL24_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL24_SETTING0 field. */
#define BR_CCM_PLL_CTRL24_SETTING0(x) (HW_CCM_PLL_CTRL24(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL24_SETTING0. */
#define BF_CCM_PLL_CTRL24_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL24_SETTING0) & BM_CCM_PLL_CTRL24_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL24_SETTING0(x, v) (HW_CCM_PLL_CTRL24_WR(x, (HW_CCM_PLL_CTRL24_RD(x) & ~BM_CCM_PLL_CTRL24_SETTING0) | BF_CCM_PLL_CTRL24_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL24, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL24_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL24_SETTING1. */
#define BM_CCM_PLL_CTRL24_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL24_SETTING1. */
#define BS_CCM_PLL_CTRL24_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL24_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL24_SETTING1 field. */
#define BR_CCM_PLL_CTRL24_SETTING1(x) (HW_CCM_PLL_CTRL24(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL24_SETTING1. */
#define BF_CCM_PLL_CTRL24_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL24_SETTING1) & BM_CCM_PLL_CTRL24_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL24_SETTING1(x, v) (HW_CCM_PLL_CTRL24_WR(x, (HW_CCM_PLL_CTRL24_RD(x) & ~BM_CCM_PLL_CTRL24_SETTING1) | BF_CCM_PLL_CTRL24_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL24, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL24_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL24_SETTING2. */
#define BM_CCM_PLL_CTRL24_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL24_SETTING2. */
#define BS_CCM_PLL_CTRL24_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL24_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL24_SETTING2 field. */
#define BR_CCM_PLL_CTRL24_SETTING2(x) (HW_CCM_PLL_CTRL24(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL24_SETTING2. */
#define BF_CCM_PLL_CTRL24_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL24_SETTING2) & BM_CCM_PLL_CTRL24_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL24_SETTING2(x, v) (HW_CCM_PLL_CTRL24_WR(x, (HW_CCM_PLL_CTRL24_RD(x) & ~BM_CCM_PLL_CTRL24_SETTING2) | BF_CCM_PLL_CTRL24_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL24, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL24_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL24_SETTING3. */
#define BM_CCM_PLL_CTRL24_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL24_SETTING3. */
#define BS_CCM_PLL_CTRL24_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL24_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL24_SETTING3 field. */
#define BR_CCM_PLL_CTRL24_SETTING3(x) (HW_CCM_PLL_CTRL24(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL24_SETTING3. */
#define BF_CCM_PLL_CTRL24_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL24_SETTING3) & BM_CCM_PLL_CTRL24_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL24_SETTING3(x, v) (HW_CCM_PLL_CTRL24_WR(x, (HW_CCM_PLL_CTRL24_RD(x) & ~BM_CCM_PLL_CTRL24_SETTING3) | BF_CCM_PLL_CTRL24_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL25 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL25 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl25
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl25_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl25_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL25 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL25_ADDR(x) ((uintptr_t)(x) + 0x990U)
#define HW_CCM_PLL_CTRL25_SET_ADDR(x) (HW_CCM_PLL_CTRL25_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL25_CLR_ADDR(x) (HW_CCM_PLL_CTRL25_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL25_TOG_ADDR(x) (HW_CCM_PLL_CTRL25_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL25(x)     (*(__IO hw_ccm_pll_ctrl25_t *) HW_CCM_PLL_CTRL25_ADDR(x))
#define HW_CCM_PLL_CTRL25_RD(x)  (HW_CCM_PLL_CTRL25(x).U)
#define HW_CCM_PLL_CTRL25_WR(x, v) (HW_CCM_PLL_CTRL25(x).U = (v))
#define HW_CCM_PLL_CTRL25_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL25_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL25_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL25_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL25_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL25_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL25 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL25, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL25_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL25_SETTING0. */
#define BM_CCM_PLL_CTRL25_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL25_SETTING0. */
#define BS_CCM_PLL_CTRL25_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL25_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL25_SETTING0 field. */
#define BR_CCM_PLL_CTRL25_SETTING0(x) (HW_CCM_PLL_CTRL25(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL25_SETTING0. */
#define BF_CCM_PLL_CTRL25_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL25_SETTING0) & BM_CCM_PLL_CTRL25_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL25_SETTING0(x, v) (HW_CCM_PLL_CTRL25_WR(x, (HW_CCM_PLL_CTRL25_RD(x) & ~BM_CCM_PLL_CTRL25_SETTING0) | BF_CCM_PLL_CTRL25_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL25, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL25_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL25_SETTING1. */
#define BM_CCM_PLL_CTRL25_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL25_SETTING1. */
#define BS_CCM_PLL_CTRL25_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL25_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL25_SETTING1 field. */
#define BR_CCM_PLL_CTRL25_SETTING1(x) (HW_CCM_PLL_CTRL25(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL25_SETTING1. */
#define BF_CCM_PLL_CTRL25_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL25_SETTING1) & BM_CCM_PLL_CTRL25_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL25_SETTING1(x, v) (HW_CCM_PLL_CTRL25_WR(x, (HW_CCM_PLL_CTRL25_RD(x) & ~BM_CCM_PLL_CTRL25_SETTING1) | BF_CCM_PLL_CTRL25_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL25, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL25_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL25_SETTING2. */
#define BM_CCM_PLL_CTRL25_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL25_SETTING2. */
#define BS_CCM_PLL_CTRL25_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL25_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL25_SETTING2 field. */
#define BR_CCM_PLL_CTRL25_SETTING2(x) (HW_CCM_PLL_CTRL25(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL25_SETTING2. */
#define BF_CCM_PLL_CTRL25_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL25_SETTING2) & BM_CCM_PLL_CTRL25_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL25_SETTING2(x, v) (HW_CCM_PLL_CTRL25_WR(x, (HW_CCM_PLL_CTRL25_RD(x) & ~BM_CCM_PLL_CTRL25_SETTING2) | BF_CCM_PLL_CTRL25_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL25, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL25_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL25_SETTING3. */
#define BM_CCM_PLL_CTRL25_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL25_SETTING3. */
#define BS_CCM_PLL_CTRL25_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL25_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL25_SETTING3 field. */
#define BR_CCM_PLL_CTRL25_SETTING3(x) (HW_CCM_PLL_CTRL25(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL25_SETTING3. */
#define BF_CCM_PLL_CTRL25_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL25_SETTING3) & BM_CCM_PLL_CTRL25_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL25_SETTING3(x, v) (HW_CCM_PLL_CTRL25_WR(x, (HW_CCM_PLL_CTRL25_RD(x) & ~BM_CCM_PLL_CTRL25_SETTING3) | BF_CCM_PLL_CTRL25_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL26 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL26 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl26
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl26_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl26_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL26 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL26_ADDR(x) ((uintptr_t)(x) + 0x9A0U)
#define HW_CCM_PLL_CTRL26_SET_ADDR(x) (HW_CCM_PLL_CTRL26_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL26_CLR_ADDR(x) (HW_CCM_PLL_CTRL26_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL26_TOG_ADDR(x) (HW_CCM_PLL_CTRL26_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL26(x)     (*(__IO hw_ccm_pll_ctrl26_t *) HW_CCM_PLL_CTRL26_ADDR(x))
#define HW_CCM_PLL_CTRL26_RD(x)  (HW_CCM_PLL_CTRL26(x).U)
#define HW_CCM_PLL_CTRL26_WR(x, v) (HW_CCM_PLL_CTRL26(x).U = (v))
#define HW_CCM_PLL_CTRL26_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL26_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL26_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL26_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL26_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL26_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL26 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL26, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL26_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL26_SETTING0. */
#define BM_CCM_PLL_CTRL26_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL26_SETTING0. */
#define BS_CCM_PLL_CTRL26_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL26_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL26_SETTING0 field. */
#define BR_CCM_PLL_CTRL26_SETTING0(x) (HW_CCM_PLL_CTRL26(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL26_SETTING0. */
#define BF_CCM_PLL_CTRL26_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL26_SETTING0) & BM_CCM_PLL_CTRL26_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL26_SETTING0(x, v) (HW_CCM_PLL_CTRL26_WR(x, (HW_CCM_PLL_CTRL26_RD(x) & ~BM_CCM_PLL_CTRL26_SETTING0) | BF_CCM_PLL_CTRL26_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL26, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL26_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL26_SETTING1. */
#define BM_CCM_PLL_CTRL26_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL26_SETTING1. */
#define BS_CCM_PLL_CTRL26_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL26_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL26_SETTING1 field. */
#define BR_CCM_PLL_CTRL26_SETTING1(x) (HW_CCM_PLL_CTRL26(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL26_SETTING1. */
#define BF_CCM_PLL_CTRL26_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL26_SETTING1) & BM_CCM_PLL_CTRL26_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL26_SETTING1(x, v) (HW_CCM_PLL_CTRL26_WR(x, (HW_CCM_PLL_CTRL26_RD(x) & ~BM_CCM_PLL_CTRL26_SETTING1) | BF_CCM_PLL_CTRL26_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL26, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL26_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL26_SETTING2. */
#define BM_CCM_PLL_CTRL26_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL26_SETTING2. */
#define BS_CCM_PLL_CTRL26_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL26_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL26_SETTING2 field. */
#define BR_CCM_PLL_CTRL26_SETTING2(x) (HW_CCM_PLL_CTRL26(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL26_SETTING2. */
#define BF_CCM_PLL_CTRL26_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL26_SETTING2) & BM_CCM_PLL_CTRL26_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL26_SETTING2(x, v) (HW_CCM_PLL_CTRL26_WR(x, (HW_CCM_PLL_CTRL26_RD(x) & ~BM_CCM_PLL_CTRL26_SETTING2) | BF_CCM_PLL_CTRL26_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL26, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL26_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL26_SETTING3. */
#define BM_CCM_PLL_CTRL26_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL26_SETTING3. */
#define BS_CCM_PLL_CTRL26_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL26_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL26_SETTING3 field. */
#define BR_CCM_PLL_CTRL26_SETTING3(x) (HW_CCM_PLL_CTRL26(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL26_SETTING3. */
#define BF_CCM_PLL_CTRL26_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL26_SETTING3) & BM_CCM_PLL_CTRL26_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL26_SETTING3(x, v) (HW_CCM_PLL_CTRL26_WR(x, (HW_CCM_PLL_CTRL26_RD(x) & ~BM_CCM_PLL_CTRL26_SETTING3) | BF_CCM_PLL_CTRL26_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL27 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL27 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl27
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl27_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl27_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL27 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL27_ADDR(x) ((uintptr_t)(x) + 0x9B0U)
#define HW_CCM_PLL_CTRL27_SET_ADDR(x) (HW_CCM_PLL_CTRL27_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL27_CLR_ADDR(x) (HW_CCM_PLL_CTRL27_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL27_TOG_ADDR(x) (HW_CCM_PLL_CTRL27_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL27(x)     (*(__IO hw_ccm_pll_ctrl27_t *) HW_CCM_PLL_CTRL27_ADDR(x))
#define HW_CCM_PLL_CTRL27_RD(x)  (HW_CCM_PLL_CTRL27(x).U)
#define HW_CCM_PLL_CTRL27_WR(x, v) (HW_CCM_PLL_CTRL27(x).U = (v))
#define HW_CCM_PLL_CTRL27_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL27_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL27_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL27_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL27_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL27_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL27 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL27, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL27_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL27_SETTING0. */
#define BM_CCM_PLL_CTRL27_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL27_SETTING0. */
#define BS_CCM_PLL_CTRL27_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL27_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL27_SETTING0 field. */
#define BR_CCM_PLL_CTRL27_SETTING0(x) (HW_CCM_PLL_CTRL27(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL27_SETTING0. */
#define BF_CCM_PLL_CTRL27_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL27_SETTING0) & BM_CCM_PLL_CTRL27_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL27_SETTING0(x, v) (HW_CCM_PLL_CTRL27_WR(x, (HW_CCM_PLL_CTRL27_RD(x) & ~BM_CCM_PLL_CTRL27_SETTING0) | BF_CCM_PLL_CTRL27_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL27, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL27_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL27_SETTING1. */
#define BM_CCM_PLL_CTRL27_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL27_SETTING1. */
#define BS_CCM_PLL_CTRL27_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL27_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL27_SETTING1 field. */
#define BR_CCM_PLL_CTRL27_SETTING1(x) (HW_CCM_PLL_CTRL27(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL27_SETTING1. */
#define BF_CCM_PLL_CTRL27_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL27_SETTING1) & BM_CCM_PLL_CTRL27_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL27_SETTING1(x, v) (HW_CCM_PLL_CTRL27_WR(x, (HW_CCM_PLL_CTRL27_RD(x) & ~BM_CCM_PLL_CTRL27_SETTING1) | BF_CCM_PLL_CTRL27_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL27, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL27_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL27_SETTING2. */
#define BM_CCM_PLL_CTRL27_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL27_SETTING2. */
#define BS_CCM_PLL_CTRL27_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL27_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL27_SETTING2 field. */
#define BR_CCM_PLL_CTRL27_SETTING2(x) (HW_CCM_PLL_CTRL27(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL27_SETTING2. */
#define BF_CCM_PLL_CTRL27_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL27_SETTING2) & BM_CCM_PLL_CTRL27_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL27_SETTING2(x, v) (HW_CCM_PLL_CTRL27_WR(x, (HW_CCM_PLL_CTRL27_RD(x) & ~BM_CCM_PLL_CTRL27_SETTING2) | BF_CCM_PLL_CTRL27_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL27, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL27_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL27_SETTING3. */
#define BM_CCM_PLL_CTRL27_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL27_SETTING3. */
#define BS_CCM_PLL_CTRL27_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL27_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL27_SETTING3 field. */
#define BR_CCM_PLL_CTRL27_SETTING3(x) (HW_CCM_PLL_CTRL27(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL27_SETTING3. */
#define BF_CCM_PLL_CTRL27_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL27_SETTING3) & BM_CCM_PLL_CTRL27_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL27_SETTING3(x, v) (HW_CCM_PLL_CTRL27_WR(x, (HW_CCM_PLL_CTRL27_RD(x) & ~BM_CCM_PLL_CTRL27_SETTING3) | BF_CCM_PLL_CTRL27_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL28 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL28 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl28
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl28_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl28_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL28 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL28_ADDR(x) ((uintptr_t)(x) + 0x9C0U)
#define HW_CCM_PLL_CTRL28_SET_ADDR(x) (HW_CCM_PLL_CTRL28_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL28_CLR_ADDR(x) (HW_CCM_PLL_CTRL28_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL28_TOG_ADDR(x) (HW_CCM_PLL_CTRL28_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL28(x)     (*(__IO hw_ccm_pll_ctrl28_t *) HW_CCM_PLL_CTRL28_ADDR(x))
#define HW_CCM_PLL_CTRL28_RD(x)  (HW_CCM_PLL_CTRL28(x).U)
#define HW_CCM_PLL_CTRL28_WR(x, v) (HW_CCM_PLL_CTRL28(x).U = (v))
#define HW_CCM_PLL_CTRL28_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL28_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL28_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL28_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL28_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL28_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL28 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL28, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL28_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL28_SETTING0. */
#define BM_CCM_PLL_CTRL28_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL28_SETTING0. */
#define BS_CCM_PLL_CTRL28_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL28_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL28_SETTING0 field. */
#define BR_CCM_PLL_CTRL28_SETTING0(x) (HW_CCM_PLL_CTRL28(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL28_SETTING0. */
#define BF_CCM_PLL_CTRL28_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL28_SETTING0) & BM_CCM_PLL_CTRL28_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL28_SETTING0(x, v) (HW_CCM_PLL_CTRL28_WR(x, (HW_CCM_PLL_CTRL28_RD(x) & ~BM_CCM_PLL_CTRL28_SETTING0) | BF_CCM_PLL_CTRL28_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL28, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL28_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL28_SETTING1. */
#define BM_CCM_PLL_CTRL28_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL28_SETTING1. */
#define BS_CCM_PLL_CTRL28_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL28_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL28_SETTING1 field. */
#define BR_CCM_PLL_CTRL28_SETTING1(x) (HW_CCM_PLL_CTRL28(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL28_SETTING1. */
#define BF_CCM_PLL_CTRL28_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL28_SETTING1) & BM_CCM_PLL_CTRL28_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL28_SETTING1(x, v) (HW_CCM_PLL_CTRL28_WR(x, (HW_CCM_PLL_CTRL28_RD(x) & ~BM_CCM_PLL_CTRL28_SETTING1) | BF_CCM_PLL_CTRL28_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL28, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL28_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL28_SETTING2. */
#define BM_CCM_PLL_CTRL28_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL28_SETTING2. */
#define BS_CCM_PLL_CTRL28_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL28_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL28_SETTING2 field. */
#define BR_CCM_PLL_CTRL28_SETTING2(x) (HW_CCM_PLL_CTRL28(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL28_SETTING2. */
#define BF_CCM_PLL_CTRL28_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL28_SETTING2) & BM_CCM_PLL_CTRL28_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL28_SETTING2(x, v) (HW_CCM_PLL_CTRL28_WR(x, (HW_CCM_PLL_CTRL28_RD(x) & ~BM_CCM_PLL_CTRL28_SETTING2) | BF_CCM_PLL_CTRL28_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL28, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL28_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL28_SETTING3. */
#define BM_CCM_PLL_CTRL28_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL28_SETTING3. */
#define BS_CCM_PLL_CTRL28_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL28_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL28_SETTING3 field. */
#define BR_CCM_PLL_CTRL28_SETTING3(x) (HW_CCM_PLL_CTRL28(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL28_SETTING3. */
#define BF_CCM_PLL_CTRL28_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL28_SETTING3) & BM_CCM_PLL_CTRL28_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL28_SETTING3(x, v) (HW_CCM_PLL_CTRL28_WR(x, (HW_CCM_PLL_CTRL28_RD(x) & ~BM_CCM_PLL_CTRL28_SETTING3) | BF_CCM_PLL_CTRL28_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL29 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL29 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl29
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl29_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl29_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL29 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL29_ADDR(x) ((uintptr_t)(x) + 0x9D0U)
#define HW_CCM_PLL_CTRL29_SET_ADDR(x) (HW_CCM_PLL_CTRL29_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL29_CLR_ADDR(x) (HW_CCM_PLL_CTRL29_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL29_TOG_ADDR(x) (HW_CCM_PLL_CTRL29_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL29(x)     (*(__IO hw_ccm_pll_ctrl29_t *) HW_CCM_PLL_CTRL29_ADDR(x))
#define HW_CCM_PLL_CTRL29_RD(x)  (HW_CCM_PLL_CTRL29(x).U)
#define HW_CCM_PLL_CTRL29_WR(x, v) (HW_CCM_PLL_CTRL29(x).U = (v))
#define HW_CCM_PLL_CTRL29_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL29_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL29_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL29_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL29_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL29_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL29 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL29, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL29_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL29_SETTING0. */
#define BM_CCM_PLL_CTRL29_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL29_SETTING0. */
#define BS_CCM_PLL_CTRL29_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL29_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL29_SETTING0 field. */
#define BR_CCM_PLL_CTRL29_SETTING0(x) (HW_CCM_PLL_CTRL29(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL29_SETTING0. */
#define BF_CCM_PLL_CTRL29_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL29_SETTING0) & BM_CCM_PLL_CTRL29_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL29_SETTING0(x, v) (HW_CCM_PLL_CTRL29_WR(x, (HW_CCM_PLL_CTRL29_RD(x) & ~BM_CCM_PLL_CTRL29_SETTING0) | BF_CCM_PLL_CTRL29_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL29, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL29_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL29_SETTING1. */
#define BM_CCM_PLL_CTRL29_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL29_SETTING1. */
#define BS_CCM_PLL_CTRL29_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL29_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL29_SETTING1 field. */
#define BR_CCM_PLL_CTRL29_SETTING1(x) (HW_CCM_PLL_CTRL29(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL29_SETTING1. */
#define BF_CCM_PLL_CTRL29_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL29_SETTING1) & BM_CCM_PLL_CTRL29_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL29_SETTING1(x, v) (HW_CCM_PLL_CTRL29_WR(x, (HW_CCM_PLL_CTRL29_RD(x) & ~BM_CCM_PLL_CTRL29_SETTING1) | BF_CCM_PLL_CTRL29_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL29, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL29_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL29_SETTING2. */
#define BM_CCM_PLL_CTRL29_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL29_SETTING2. */
#define BS_CCM_PLL_CTRL29_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL29_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL29_SETTING2 field. */
#define BR_CCM_PLL_CTRL29_SETTING2(x) (HW_CCM_PLL_CTRL29(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL29_SETTING2. */
#define BF_CCM_PLL_CTRL29_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL29_SETTING2) & BM_CCM_PLL_CTRL29_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL29_SETTING2(x, v) (HW_CCM_PLL_CTRL29_WR(x, (HW_CCM_PLL_CTRL29_RD(x) & ~BM_CCM_PLL_CTRL29_SETTING2) | BF_CCM_PLL_CTRL29_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL29, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL29_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL29_SETTING3. */
#define BM_CCM_PLL_CTRL29_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL29_SETTING3. */
#define BS_CCM_PLL_CTRL29_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL29_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL29_SETTING3 field. */
#define BR_CCM_PLL_CTRL29_SETTING3(x) (HW_CCM_PLL_CTRL29(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL29_SETTING3. */
#define BF_CCM_PLL_CTRL29_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL29_SETTING3) & BM_CCM_PLL_CTRL29_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL29_SETTING3(x, v) (HW_CCM_PLL_CTRL29_WR(x, (HW_CCM_PLL_CTRL29_RD(x) & ~BM_CCM_PLL_CTRL29_SETTING3) | BF_CCM_PLL_CTRL29_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL30 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL30 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl30
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl30_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl30_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL30 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL30_ADDR(x) ((uintptr_t)(x) + 0x9E0U)
#define HW_CCM_PLL_CTRL30_SET_ADDR(x) (HW_CCM_PLL_CTRL30_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL30_CLR_ADDR(x) (HW_CCM_PLL_CTRL30_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL30_TOG_ADDR(x) (HW_CCM_PLL_CTRL30_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL30(x)     (*(__IO hw_ccm_pll_ctrl30_t *) HW_CCM_PLL_CTRL30_ADDR(x))
#define HW_CCM_PLL_CTRL30_RD(x)  (HW_CCM_PLL_CTRL30(x).U)
#define HW_CCM_PLL_CTRL30_WR(x, v) (HW_CCM_PLL_CTRL30(x).U = (v))
#define HW_CCM_PLL_CTRL30_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL30_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL30_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL30_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL30_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL30_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL30 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL30, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL30_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL30_SETTING0. */
#define BM_CCM_PLL_CTRL30_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL30_SETTING0. */
#define BS_CCM_PLL_CTRL30_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL30_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL30_SETTING0 field. */
#define BR_CCM_PLL_CTRL30_SETTING0(x) (HW_CCM_PLL_CTRL30(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL30_SETTING0. */
#define BF_CCM_PLL_CTRL30_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL30_SETTING0) & BM_CCM_PLL_CTRL30_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL30_SETTING0(x, v) (HW_CCM_PLL_CTRL30_WR(x, (HW_CCM_PLL_CTRL30_RD(x) & ~BM_CCM_PLL_CTRL30_SETTING0) | BF_CCM_PLL_CTRL30_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL30, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL30_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL30_SETTING1. */
#define BM_CCM_PLL_CTRL30_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL30_SETTING1. */
#define BS_CCM_PLL_CTRL30_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL30_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL30_SETTING1 field. */
#define BR_CCM_PLL_CTRL30_SETTING1(x) (HW_CCM_PLL_CTRL30(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL30_SETTING1. */
#define BF_CCM_PLL_CTRL30_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL30_SETTING1) & BM_CCM_PLL_CTRL30_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL30_SETTING1(x, v) (HW_CCM_PLL_CTRL30_WR(x, (HW_CCM_PLL_CTRL30_RD(x) & ~BM_CCM_PLL_CTRL30_SETTING1) | BF_CCM_PLL_CTRL30_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL30, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL30_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL30_SETTING2. */
#define BM_CCM_PLL_CTRL30_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL30_SETTING2. */
#define BS_CCM_PLL_CTRL30_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL30_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL30_SETTING2 field. */
#define BR_CCM_PLL_CTRL30_SETTING2(x) (HW_CCM_PLL_CTRL30(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL30_SETTING2. */
#define BF_CCM_PLL_CTRL30_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL30_SETTING2) & BM_CCM_PLL_CTRL30_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL30_SETTING2(x, v) (HW_CCM_PLL_CTRL30_WR(x, (HW_CCM_PLL_CTRL30_RD(x) & ~BM_CCM_PLL_CTRL30_SETTING2) | BF_CCM_PLL_CTRL30_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL30, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL30_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL30_SETTING3. */
#define BM_CCM_PLL_CTRL30_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL30_SETTING3. */
#define BS_CCM_PLL_CTRL30_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL30_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL30_SETTING3 field. */
#define BR_CCM_PLL_CTRL30_SETTING3(x) (HW_CCM_PLL_CTRL30(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL30_SETTING3. */
#define BF_CCM_PLL_CTRL30_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL30_SETTING3) & BM_CCM_PLL_CTRL30_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL30_SETTING3(x, v) (HW_CCM_PLL_CTRL30_WR(x, (HW_CCM_PLL_CTRL30_RD(x) & ~BM_CCM_PLL_CTRL30_SETTING3) | BF_CCM_PLL_CTRL30_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL31 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL31 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl31
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl31_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl31_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL31 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL31_ADDR(x) ((uintptr_t)(x) + 0x9F0U)
#define HW_CCM_PLL_CTRL31_SET_ADDR(x) (HW_CCM_PLL_CTRL31_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL31_CLR_ADDR(x) (HW_CCM_PLL_CTRL31_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL31_TOG_ADDR(x) (HW_CCM_PLL_CTRL31_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL31(x)     (*(__IO hw_ccm_pll_ctrl31_t *) HW_CCM_PLL_CTRL31_ADDR(x))
#define HW_CCM_PLL_CTRL31_RD(x)  (HW_CCM_PLL_CTRL31(x).U)
#define HW_CCM_PLL_CTRL31_WR(x, v) (HW_CCM_PLL_CTRL31(x).U = (v))
#define HW_CCM_PLL_CTRL31_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL31_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL31_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL31_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL31_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL31_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL31 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL31, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL31_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL31_SETTING0. */
#define BM_CCM_PLL_CTRL31_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL31_SETTING0. */
#define BS_CCM_PLL_CTRL31_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL31_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL31_SETTING0 field. */
#define BR_CCM_PLL_CTRL31_SETTING0(x) (HW_CCM_PLL_CTRL31(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL31_SETTING0. */
#define BF_CCM_PLL_CTRL31_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL31_SETTING0) & BM_CCM_PLL_CTRL31_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL31_SETTING0(x, v) (HW_CCM_PLL_CTRL31_WR(x, (HW_CCM_PLL_CTRL31_RD(x) & ~BM_CCM_PLL_CTRL31_SETTING0) | BF_CCM_PLL_CTRL31_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL31, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL31_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL31_SETTING1. */
#define BM_CCM_PLL_CTRL31_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL31_SETTING1. */
#define BS_CCM_PLL_CTRL31_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL31_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL31_SETTING1 field. */
#define BR_CCM_PLL_CTRL31_SETTING1(x) (HW_CCM_PLL_CTRL31(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL31_SETTING1. */
#define BF_CCM_PLL_CTRL31_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL31_SETTING1) & BM_CCM_PLL_CTRL31_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL31_SETTING1(x, v) (HW_CCM_PLL_CTRL31_WR(x, (HW_CCM_PLL_CTRL31_RD(x) & ~BM_CCM_PLL_CTRL31_SETTING1) | BF_CCM_PLL_CTRL31_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL31, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL31_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL31_SETTING2. */
#define BM_CCM_PLL_CTRL31_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL31_SETTING2. */
#define BS_CCM_PLL_CTRL31_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL31_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL31_SETTING2 field. */
#define BR_CCM_PLL_CTRL31_SETTING2(x) (HW_CCM_PLL_CTRL31(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL31_SETTING2. */
#define BF_CCM_PLL_CTRL31_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL31_SETTING2) & BM_CCM_PLL_CTRL31_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL31_SETTING2(x, v) (HW_CCM_PLL_CTRL31_WR(x, (HW_CCM_PLL_CTRL31_RD(x) & ~BM_CCM_PLL_CTRL31_SETTING2) | BF_CCM_PLL_CTRL31_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL31, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL31_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL31_SETTING3. */
#define BM_CCM_PLL_CTRL31_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL31_SETTING3. */
#define BS_CCM_PLL_CTRL31_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL31_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL31_SETTING3 field. */
#define BR_CCM_PLL_CTRL31_SETTING3(x) (HW_CCM_PLL_CTRL31(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL31_SETTING3. */
#define BF_CCM_PLL_CTRL31_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL31_SETTING3) & BM_CCM_PLL_CTRL31_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL31_SETTING3(x, v) (HW_CCM_PLL_CTRL31_WR(x, (HW_CCM_PLL_CTRL31_RD(x) & ~BM_CCM_PLL_CTRL31_SETTING3) | BF_CCM_PLL_CTRL31_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_PLL_CTRL32 - CCM PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PLL_CTRL32 - CCM PLL Control Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See Input Clocks for PLL control mapping. For the SoC to correctly power up
 * after entering DSM, CCM_PLL_CTRLx must not be set to 0x0 or 0x3 for any domain
 * in use.
 */
typedef union _hw_ccm_pll_ctrl32
{
    uint32_t U;
    struct _hw_ccm_pll_ctrl32_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_pll_ctrl32_t;

/*!
 * @name Constants and macros for entire CCM_PLL_CTRL32 register
 */
/*@{*/
#define HW_CCM_PLL_CTRL32_ADDR(x) ((uintptr_t)(x) + 0xA00U)
#define HW_CCM_PLL_CTRL32_SET_ADDR(x) (HW_CCM_PLL_CTRL32_ADDR(x) + 0x4U)
#define HW_CCM_PLL_CTRL32_CLR_ADDR(x) (HW_CCM_PLL_CTRL32_ADDR(x) + 0x8U)
#define HW_CCM_PLL_CTRL32_TOG_ADDR(x) (HW_CCM_PLL_CTRL32_ADDR(x) + 0xCU)

#define HW_CCM_PLL_CTRL32(x)     (*(__IO hw_ccm_pll_ctrl32_t *) HW_CCM_PLL_CTRL32_ADDR(x))
#define HW_CCM_PLL_CTRL32_RD(x)  (HW_CCM_PLL_CTRL32(x).U)
#define HW_CCM_PLL_CTRL32_WR(x, v) (HW_CCM_PLL_CTRL32(x).U = (v))
#define HW_CCM_PLL_CTRL32_SET(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL32_SET_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL32_CLR(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL32_CLR_ADDR(x)) = (v))
#define HW_CCM_PLL_CTRL32_TOG(x, v) ((*(uint32_t *) HW_CCM_PLL_CTRL32_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_PLL_CTRL32 bitfields
 */

/*!
 * @name Register CCM_PLL_CTRL32, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL32_SETTING0 (0U)    /*!< Bit position for CCM_PLL_CTRL32_SETTING0. */
#define BM_CCM_PLL_CTRL32_SETTING0 (0x00000003U) /*!< Bit mask for CCM_PLL_CTRL32_SETTING0. */
#define BS_CCM_PLL_CTRL32_SETTING0 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL32_SETTING0. */

/*! @brief Read current value of the CCM_PLL_CTRL32_SETTING0 field. */
#define BR_CCM_PLL_CTRL32_SETTING0(x) (HW_CCM_PLL_CTRL32(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_PLL_CTRL32_SETTING0. */
#define BF_CCM_PLL_CTRL32_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL32_SETTING0) & BM_CCM_PLL_CTRL32_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_PLL_CTRL32_SETTING0(x, v) (HW_CCM_PLL_CTRL32_WR(x, (HW_CCM_PLL_CTRL32_RD(x) & ~BM_CCM_PLL_CTRL32_SETTING0) | BF_CCM_PLL_CTRL32_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL32, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL32_SETTING1 (4U)    /*!< Bit position for CCM_PLL_CTRL32_SETTING1. */
#define BM_CCM_PLL_CTRL32_SETTING1 (0x00000030U) /*!< Bit mask for CCM_PLL_CTRL32_SETTING1. */
#define BS_CCM_PLL_CTRL32_SETTING1 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL32_SETTING1. */

/*! @brief Read current value of the CCM_PLL_CTRL32_SETTING1 field. */
#define BR_CCM_PLL_CTRL32_SETTING1(x) (HW_CCM_PLL_CTRL32(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_PLL_CTRL32_SETTING1. */
#define BF_CCM_PLL_CTRL32_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL32_SETTING1) & BM_CCM_PLL_CTRL32_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_PLL_CTRL32_SETTING1(x, v) (HW_CCM_PLL_CTRL32_WR(x, (HW_CCM_PLL_CTRL32_RD(x) & ~BM_CCM_PLL_CTRL32_SETTING1) | BF_CCM_PLL_CTRL32_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL32, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL32_SETTING2 (8U)    /*!< Bit position for CCM_PLL_CTRL32_SETTING2. */
#define BM_CCM_PLL_CTRL32_SETTING2 (0x00000300U) /*!< Bit mask for CCM_PLL_CTRL32_SETTING2. */
#define BS_CCM_PLL_CTRL32_SETTING2 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL32_SETTING2. */

/*! @brief Read current value of the CCM_PLL_CTRL32_SETTING2 field. */
#define BR_CCM_PLL_CTRL32_SETTING2(x) (HW_CCM_PLL_CTRL32(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_PLL_CTRL32_SETTING2. */
#define BF_CCM_PLL_CTRL32_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL32_SETTING2) & BM_CCM_PLL_CTRL32_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_PLL_CTRL32_SETTING2(x, v) (HW_CCM_PLL_CTRL32_WR(x, (HW_CCM_PLL_CTRL32_RD(x) & ~BM_CCM_PLL_CTRL32_SETTING2) | BF_CCM_PLL_CTRL32_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_PLL_CTRL32, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_PLL_CTRL32_SETTING3 (12U)   /*!< Bit position for CCM_PLL_CTRL32_SETTING3. */
#define BM_CCM_PLL_CTRL32_SETTING3 (0x00003000U) /*!< Bit mask for CCM_PLL_CTRL32_SETTING3. */
#define BS_CCM_PLL_CTRL32_SETTING3 (2U)    /*!< Bit field size in bits for CCM_PLL_CTRL32_SETTING3. */

/*! @brief Read current value of the CCM_PLL_CTRL32_SETTING3 field. */
#define BR_CCM_PLL_CTRL32_SETTING3(x) (HW_CCM_PLL_CTRL32(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_PLL_CTRL32_SETTING3. */
#define BF_CCM_PLL_CTRL32_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PLL_CTRL32_SETTING3) & BM_CCM_PLL_CTRL32_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_PLL_CTRL32_SETTING3(x, v) (HW_CCM_PLL_CTRL32_WR(x, (HW_CCM_PLL_CTRL32_RD(x) & ~BM_CCM_PLL_CTRL32_SETTING3) | BF_CCM_PLL_CTRL32_SETTING3(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_CCGR0 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR0 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr0
{
    uint32_t U;
    struct _hw_ccm_ccgr0_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr0_t;

/*!
 * @name Constants and macros for entire CCM_CCGR0 register
 */
/*@{*/
#define HW_CCM_CCGR0_ADDR(x)     ((uintptr_t)(x) + 0x4000U)
#define HW_CCM_CCGR0_SET_ADDR(x) (HW_CCM_CCGR0_ADDR(x) + 0x4U)
#define HW_CCM_CCGR0_CLR_ADDR(x) (HW_CCM_CCGR0_ADDR(x) + 0x8U)
#define HW_CCM_CCGR0_TOG_ADDR(x) (HW_CCM_CCGR0_ADDR(x) + 0xCU)

#define HW_CCM_CCGR0(x)          (*(__IO hw_ccm_ccgr0_t *) HW_CCM_CCGR0_ADDR(x))
#define HW_CCM_CCGR0_RD(x)       (HW_CCM_CCGR0(x).U)
#define HW_CCM_CCGR0_WR(x, v)    (HW_CCM_CCGR0(x).U = (v))
#define HW_CCM_CCGR0_SET(x, v)   ((*(uint32_t *) HW_CCM_CCGR0_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR0_CLR(x, v)   ((*(uint32_t *) HW_CCM_CCGR0_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR0_TOG(x, v)   ((*(uint32_t *) HW_CCM_CCGR0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR0 bitfields
 */

/*!
 * @name Register CCM_CCGR0, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR0_SETTING0 (0U)         /*!< Bit position for CCM_CCGR0_SETTING0. */
#define BM_CCM_CCGR0_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR0_SETTING0. */
#define BS_CCM_CCGR0_SETTING0 (2U)         /*!< Bit field size in bits for CCM_CCGR0_SETTING0. */

/*! @brief Read current value of the CCM_CCGR0_SETTING0 field. */
#define BR_CCM_CCGR0_SETTING0(x) (HW_CCM_CCGR0(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR0_SETTING0. */
#define BF_CCM_CCGR0_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_SETTING0) & BM_CCM_CCGR0_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR0_SETTING0(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_SETTING0) | BF_CCM_CCGR0_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR0, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR0_SETTING1 (4U)         /*!< Bit position for CCM_CCGR0_SETTING1. */
#define BM_CCM_CCGR0_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR0_SETTING1. */
#define BS_CCM_CCGR0_SETTING1 (2U)         /*!< Bit field size in bits for CCM_CCGR0_SETTING1. */

/*! @brief Read current value of the CCM_CCGR0_SETTING1 field. */
#define BR_CCM_CCGR0_SETTING1(x) (HW_CCM_CCGR0(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR0_SETTING1. */
#define BF_CCM_CCGR0_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_SETTING1) & BM_CCM_CCGR0_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR0_SETTING1(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_SETTING1) | BF_CCM_CCGR0_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR0, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR0_SETTING2 (8U)         /*!< Bit position for CCM_CCGR0_SETTING2. */
#define BM_CCM_CCGR0_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR0_SETTING2. */
#define BS_CCM_CCGR0_SETTING2 (2U)         /*!< Bit field size in bits for CCM_CCGR0_SETTING2. */

/*! @brief Read current value of the CCM_CCGR0_SETTING2 field. */
#define BR_CCM_CCGR0_SETTING2(x) (HW_CCM_CCGR0(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR0_SETTING2. */
#define BF_CCM_CCGR0_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_SETTING2) & BM_CCM_CCGR0_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR0_SETTING2(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_SETTING2) | BF_CCM_CCGR0_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR0, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR0_SETTING3 (12U)        /*!< Bit position for CCM_CCGR0_SETTING3. */
#define BM_CCM_CCGR0_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR0_SETTING3. */
#define BS_CCM_CCGR0_SETTING3 (2U)         /*!< Bit field size in bits for CCM_CCGR0_SETTING3. */

/*! @brief Read current value of the CCM_CCGR0_SETTING3 field. */
#define BR_CCM_CCGR0_SETTING3(x) (HW_CCM_CCGR0(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR0_SETTING3. */
#define BF_CCM_CCGR0_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR0_SETTING3) & BM_CCM_CCGR0_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR0_SETTING3(x, v) (HW_CCM_CCGR0_WR(x, (HW_CCM_CCGR0_RD(x) & ~BM_CCM_CCGR0_SETTING3) | BF_CCM_CCGR0_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR1 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR1 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr1
{
    uint32_t U;
    struct _hw_ccm_ccgr1_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr1_t;

/*!
 * @name Constants and macros for entire CCM_CCGR1 register
 */
/*@{*/
#define HW_CCM_CCGR1_ADDR(x)     ((uintptr_t)(x) + 0x4010U)
#define HW_CCM_CCGR1_SET_ADDR(x) (HW_CCM_CCGR1_ADDR(x) + 0x4U)
#define HW_CCM_CCGR1_CLR_ADDR(x) (HW_CCM_CCGR1_ADDR(x) + 0x8U)
#define HW_CCM_CCGR1_TOG_ADDR(x) (HW_CCM_CCGR1_ADDR(x) + 0xCU)

#define HW_CCM_CCGR1(x)          (*(__IO hw_ccm_ccgr1_t *) HW_CCM_CCGR1_ADDR(x))
#define HW_CCM_CCGR1_RD(x)       (HW_CCM_CCGR1(x).U)
#define HW_CCM_CCGR1_WR(x, v)    (HW_CCM_CCGR1(x).U = (v))
#define HW_CCM_CCGR1_SET(x, v)   ((*(uint32_t *) HW_CCM_CCGR1_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR1_CLR(x, v)   ((*(uint32_t *) HW_CCM_CCGR1_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR1_TOG(x, v)   ((*(uint32_t *) HW_CCM_CCGR1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR1 bitfields
 */

/*!
 * @name Register CCM_CCGR1, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR1_SETTING0 (0U)         /*!< Bit position for CCM_CCGR1_SETTING0. */
#define BM_CCM_CCGR1_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR1_SETTING0. */
#define BS_CCM_CCGR1_SETTING0 (2U)         /*!< Bit field size in bits for CCM_CCGR1_SETTING0. */

/*! @brief Read current value of the CCM_CCGR1_SETTING0 field. */
#define BR_CCM_CCGR1_SETTING0(x) (HW_CCM_CCGR1(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR1_SETTING0. */
#define BF_CCM_CCGR1_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_SETTING0) & BM_CCM_CCGR1_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR1_SETTING0(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_SETTING0) | BF_CCM_CCGR1_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR1, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR1_SETTING1 (4U)         /*!< Bit position for CCM_CCGR1_SETTING1. */
#define BM_CCM_CCGR1_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR1_SETTING1. */
#define BS_CCM_CCGR1_SETTING1 (2U)         /*!< Bit field size in bits for CCM_CCGR1_SETTING1. */

/*! @brief Read current value of the CCM_CCGR1_SETTING1 field. */
#define BR_CCM_CCGR1_SETTING1(x) (HW_CCM_CCGR1(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR1_SETTING1. */
#define BF_CCM_CCGR1_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_SETTING1) & BM_CCM_CCGR1_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR1_SETTING1(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_SETTING1) | BF_CCM_CCGR1_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR1, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR1_SETTING2 (8U)         /*!< Bit position for CCM_CCGR1_SETTING2. */
#define BM_CCM_CCGR1_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR1_SETTING2. */
#define BS_CCM_CCGR1_SETTING2 (2U)         /*!< Bit field size in bits for CCM_CCGR1_SETTING2. */

/*! @brief Read current value of the CCM_CCGR1_SETTING2 field. */
#define BR_CCM_CCGR1_SETTING2(x) (HW_CCM_CCGR1(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR1_SETTING2. */
#define BF_CCM_CCGR1_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_SETTING2) & BM_CCM_CCGR1_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR1_SETTING2(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_SETTING2) | BF_CCM_CCGR1_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR1, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR1_SETTING3 (12U)        /*!< Bit position for CCM_CCGR1_SETTING3. */
#define BM_CCM_CCGR1_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR1_SETTING3. */
#define BS_CCM_CCGR1_SETTING3 (2U)         /*!< Bit field size in bits for CCM_CCGR1_SETTING3. */

/*! @brief Read current value of the CCM_CCGR1_SETTING3 field. */
#define BR_CCM_CCGR1_SETTING3(x) (HW_CCM_CCGR1(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR1_SETTING3. */
#define BF_CCM_CCGR1_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR1_SETTING3) & BM_CCM_CCGR1_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR1_SETTING3(x, v) (HW_CCM_CCGR1_WR(x, (HW_CCM_CCGR1_RD(x) & ~BM_CCM_CCGR1_SETTING3) | BF_CCM_CCGR1_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR2 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR2 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr2
{
    uint32_t U;
    struct _hw_ccm_ccgr2_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr2_t;

/*!
 * @name Constants and macros for entire CCM_CCGR2 register
 */
/*@{*/
#define HW_CCM_CCGR2_ADDR(x)     ((uintptr_t)(x) + 0x4020U)
#define HW_CCM_CCGR2_SET_ADDR(x) (HW_CCM_CCGR2_ADDR(x) + 0x4U)
#define HW_CCM_CCGR2_CLR_ADDR(x) (HW_CCM_CCGR2_ADDR(x) + 0x8U)
#define HW_CCM_CCGR2_TOG_ADDR(x) (HW_CCM_CCGR2_ADDR(x) + 0xCU)

#define HW_CCM_CCGR2(x)          (*(__IO hw_ccm_ccgr2_t *) HW_CCM_CCGR2_ADDR(x))
#define HW_CCM_CCGR2_RD(x)       (HW_CCM_CCGR2(x).U)
#define HW_CCM_CCGR2_WR(x, v)    (HW_CCM_CCGR2(x).U = (v))
#define HW_CCM_CCGR2_SET(x, v)   ((*(uint32_t *) HW_CCM_CCGR2_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR2_CLR(x, v)   ((*(uint32_t *) HW_CCM_CCGR2_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR2_TOG(x, v)   ((*(uint32_t *) HW_CCM_CCGR2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR2 bitfields
 */

/*!
 * @name Register CCM_CCGR2, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR2_SETTING0 (0U)         /*!< Bit position for CCM_CCGR2_SETTING0. */
#define BM_CCM_CCGR2_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR2_SETTING0. */
#define BS_CCM_CCGR2_SETTING0 (2U)         /*!< Bit field size in bits for CCM_CCGR2_SETTING0. */

/*! @brief Read current value of the CCM_CCGR2_SETTING0 field. */
#define BR_CCM_CCGR2_SETTING0(x) (HW_CCM_CCGR2(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR2_SETTING0. */
#define BF_CCM_CCGR2_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_SETTING0) & BM_CCM_CCGR2_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR2_SETTING0(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_SETTING0) | BF_CCM_CCGR2_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR2, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR2_SETTING1 (4U)         /*!< Bit position for CCM_CCGR2_SETTING1. */
#define BM_CCM_CCGR2_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR2_SETTING1. */
#define BS_CCM_CCGR2_SETTING1 (2U)         /*!< Bit field size in bits for CCM_CCGR2_SETTING1. */

/*! @brief Read current value of the CCM_CCGR2_SETTING1 field. */
#define BR_CCM_CCGR2_SETTING1(x) (HW_CCM_CCGR2(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR2_SETTING1. */
#define BF_CCM_CCGR2_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_SETTING1) & BM_CCM_CCGR2_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR2_SETTING1(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_SETTING1) | BF_CCM_CCGR2_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR2, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR2_SETTING2 (8U)         /*!< Bit position for CCM_CCGR2_SETTING2. */
#define BM_CCM_CCGR2_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR2_SETTING2. */
#define BS_CCM_CCGR2_SETTING2 (2U)         /*!< Bit field size in bits for CCM_CCGR2_SETTING2. */

/*! @brief Read current value of the CCM_CCGR2_SETTING2 field. */
#define BR_CCM_CCGR2_SETTING2(x) (HW_CCM_CCGR2(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR2_SETTING2. */
#define BF_CCM_CCGR2_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_SETTING2) & BM_CCM_CCGR2_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR2_SETTING2(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_SETTING2) | BF_CCM_CCGR2_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR2, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR2_SETTING3 (12U)        /*!< Bit position for CCM_CCGR2_SETTING3. */
#define BM_CCM_CCGR2_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR2_SETTING3. */
#define BS_CCM_CCGR2_SETTING3 (2U)         /*!< Bit field size in bits for CCM_CCGR2_SETTING3. */

/*! @brief Read current value of the CCM_CCGR2_SETTING3 field. */
#define BR_CCM_CCGR2_SETTING3(x) (HW_CCM_CCGR2(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR2_SETTING3. */
#define BF_CCM_CCGR2_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR2_SETTING3) & BM_CCM_CCGR2_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR2_SETTING3(x, v) (HW_CCM_CCGR2_WR(x, (HW_CCM_CCGR2_RD(x) & ~BM_CCM_CCGR2_SETTING3) | BF_CCM_CCGR2_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR3 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR3 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr3
{
    uint32_t U;
    struct _hw_ccm_ccgr3_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr3_t;

/*!
 * @name Constants and macros for entire CCM_CCGR3 register
 */
/*@{*/
#define HW_CCM_CCGR3_ADDR(x)     ((uintptr_t)(x) + 0x4030U)
#define HW_CCM_CCGR3_SET_ADDR(x) (HW_CCM_CCGR3_ADDR(x) + 0x4U)
#define HW_CCM_CCGR3_CLR_ADDR(x) (HW_CCM_CCGR3_ADDR(x) + 0x8U)
#define HW_CCM_CCGR3_TOG_ADDR(x) (HW_CCM_CCGR3_ADDR(x) + 0xCU)

#define HW_CCM_CCGR3(x)          (*(__IO hw_ccm_ccgr3_t *) HW_CCM_CCGR3_ADDR(x))
#define HW_CCM_CCGR3_RD(x)       (HW_CCM_CCGR3(x).U)
#define HW_CCM_CCGR3_WR(x, v)    (HW_CCM_CCGR3(x).U = (v))
#define HW_CCM_CCGR3_SET(x, v)   ((*(uint32_t *) HW_CCM_CCGR3_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR3_CLR(x, v)   ((*(uint32_t *) HW_CCM_CCGR3_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR3_TOG(x, v)   ((*(uint32_t *) HW_CCM_CCGR3_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR3 bitfields
 */

/*!
 * @name Register CCM_CCGR3, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR3_SETTING0 (0U)         /*!< Bit position for CCM_CCGR3_SETTING0. */
#define BM_CCM_CCGR3_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR3_SETTING0. */
#define BS_CCM_CCGR3_SETTING0 (2U)         /*!< Bit field size in bits for CCM_CCGR3_SETTING0. */

/*! @brief Read current value of the CCM_CCGR3_SETTING0 field. */
#define BR_CCM_CCGR3_SETTING0(x) (HW_CCM_CCGR3(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR3_SETTING0. */
#define BF_CCM_CCGR3_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_SETTING0) & BM_CCM_CCGR3_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR3_SETTING0(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_SETTING0) | BF_CCM_CCGR3_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR3, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR3_SETTING1 (4U)         /*!< Bit position for CCM_CCGR3_SETTING1. */
#define BM_CCM_CCGR3_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR3_SETTING1. */
#define BS_CCM_CCGR3_SETTING1 (2U)         /*!< Bit field size in bits for CCM_CCGR3_SETTING1. */

/*! @brief Read current value of the CCM_CCGR3_SETTING1 field. */
#define BR_CCM_CCGR3_SETTING1(x) (HW_CCM_CCGR3(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR3_SETTING1. */
#define BF_CCM_CCGR3_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_SETTING1) & BM_CCM_CCGR3_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR3_SETTING1(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_SETTING1) | BF_CCM_CCGR3_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR3, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR3_SETTING2 (8U)         /*!< Bit position for CCM_CCGR3_SETTING2. */
#define BM_CCM_CCGR3_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR3_SETTING2. */
#define BS_CCM_CCGR3_SETTING2 (2U)         /*!< Bit field size in bits for CCM_CCGR3_SETTING2. */

/*! @brief Read current value of the CCM_CCGR3_SETTING2 field. */
#define BR_CCM_CCGR3_SETTING2(x) (HW_CCM_CCGR3(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR3_SETTING2. */
#define BF_CCM_CCGR3_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_SETTING2) & BM_CCM_CCGR3_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR3_SETTING2(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_SETTING2) | BF_CCM_CCGR3_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR3, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR3_SETTING3 (12U)        /*!< Bit position for CCM_CCGR3_SETTING3. */
#define BM_CCM_CCGR3_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR3_SETTING3. */
#define BS_CCM_CCGR3_SETTING3 (2U)         /*!< Bit field size in bits for CCM_CCGR3_SETTING3. */

/*! @brief Read current value of the CCM_CCGR3_SETTING3 field. */
#define BR_CCM_CCGR3_SETTING3(x) (HW_CCM_CCGR3(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR3_SETTING3. */
#define BF_CCM_CCGR3_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR3_SETTING3) & BM_CCM_CCGR3_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR3_SETTING3(x, v) (HW_CCM_CCGR3_WR(x, (HW_CCM_CCGR3_RD(x) & ~BM_CCM_CCGR3_SETTING3) | BF_CCM_CCGR3_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR4 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR4 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr4
{
    uint32_t U;
    struct _hw_ccm_ccgr4_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr4_t;

/*!
 * @name Constants and macros for entire CCM_CCGR4 register
 */
/*@{*/
#define HW_CCM_CCGR4_ADDR(x)     ((uintptr_t)(x) + 0x4040U)
#define HW_CCM_CCGR4_SET_ADDR(x) (HW_CCM_CCGR4_ADDR(x) + 0x4U)
#define HW_CCM_CCGR4_CLR_ADDR(x) (HW_CCM_CCGR4_ADDR(x) + 0x8U)
#define HW_CCM_CCGR4_TOG_ADDR(x) (HW_CCM_CCGR4_ADDR(x) + 0xCU)

#define HW_CCM_CCGR4(x)          (*(__IO hw_ccm_ccgr4_t *) HW_CCM_CCGR4_ADDR(x))
#define HW_CCM_CCGR4_RD(x)       (HW_CCM_CCGR4(x).U)
#define HW_CCM_CCGR4_WR(x, v)    (HW_CCM_CCGR4(x).U = (v))
#define HW_CCM_CCGR4_SET(x, v)   ((*(uint32_t *) HW_CCM_CCGR4_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR4_CLR(x, v)   ((*(uint32_t *) HW_CCM_CCGR4_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR4_TOG(x, v)   ((*(uint32_t *) HW_CCM_CCGR4_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR4 bitfields
 */

/*!
 * @name Register CCM_CCGR4, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR4_SETTING0 (0U)         /*!< Bit position for CCM_CCGR4_SETTING0. */
#define BM_CCM_CCGR4_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR4_SETTING0. */
#define BS_CCM_CCGR4_SETTING0 (2U)         /*!< Bit field size in bits for CCM_CCGR4_SETTING0. */

/*! @brief Read current value of the CCM_CCGR4_SETTING0 field. */
#define BR_CCM_CCGR4_SETTING0(x) (HW_CCM_CCGR4(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR4_SETTING0. */
#define BF_CCM_CCGR4_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_SETTING0) & BM_CCM_CCGR4_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR4_SETTING0(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_SETTING0) | BF_CCM_CCGR4_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR4, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR4_SETTING1 (4U)         /*!< Bit position for CCM_CCGR4_SETTING1. */
#define BM_CCM_CCGR4_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR4_SETTING1. */
#define BS_CCM_CCGR4_SETTING1 (2U)         /*!< Bit field size in bits for CCM_CCGR4_SETTING1. */

/*! @brief Read current value of the CCM_CCGR4_SETTING1 field. */
#define BR_CCM_CCGR4_SETTING1(x) (HW_CCM_CCGR4(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR4_SETTING1. */
#define BF_CCM_CCGR4_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_SETTING1) & BM_CCM_CCGR4_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR4_SETTING1(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_SETTING1) | BF_CCM_CCGR4_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR4, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR4_SETTING2 (8U)         /*!< Bit position for CCM_CCGR4_SETTING2. */
#define BM_CCM_CCGR4_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR4_SETTING2. */
#define BS_CCM_CCGR4_SETTING2 (2U)         /*!< Bit field size in bits for CCM_CCGR4_SETTING2. */

/*! @brief Read current value of the CCM_CCGR4_SETTING2 field. */
#define BR_CCM_CCGR4_SETTING2(x) (HW_CCM_CCGR4(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR4_SETTING2. */
#define BF_CCM_CCGR4_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_SETTING2) & BM_CCM_CCGR4_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR4_SETTING2(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_SETTING2) | BF_CCM_CCGR4_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR4, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR4_SETTING3 (12U)        /*!< Bit position for CCM_CCGR4_SETTING3. */
#define BM_CCM_CCGR4_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR4_SETTING3. */
#define BS_CCM_CCGR4_SETTING3 (2U)         /*!< Bit field size in bits for CCM_CCGR4_SETTING3. */

/*! @brief Read current value of the CCM_CCGR4_SETTING3 field. */
#define BR_CCM_CCGR4_SETTING3(x) (HW_CCM_CCGR4(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR4_SETTING3. */
#define BF_CCM_CCGR4_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR4_SETTING3) & BM_CCM_CCGR4_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR4_SETTING3(x, v) (HW_CCM_CCGR4_WR(x, (HW_CCM_CCGR4_RD(x) & ~BM_CCM_CCGR4_SETTING3) | BF_CCM_CCGR4_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR5 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR5 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr5
{
    uint32_t U;
    struct _hw_ccm_ccgr5_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr5_t;

/*!
 * @name Constants and macros for entire CCM_CCGR5 register
 */
/*@{*/
#define HW_CCM_CCGR5_ADDR(x)     ((uintptr_t)(x) + 0x4050U)
#define HW_CCM_CCGR5_SET_ADDR(x) (HW_CCM_CCGR5_ADDR(x) + 0x4U)
#define HW_CCM_CCGR5_CLR_ADDR(x) (HW_CCM_CCGR5_ADDR(x) + 0x8U)
#define HW_CCM_CCGR5_TOG_ADDR(x) (HW_CCM_CCGR5_ADDR(x) + 0xCU)

#define HW_CCM_CCGR5(x)          (*(__IO hw_ccm_ccgr5_t *) HW_CCM_CCGR5_ADDR(x))
#define HW_CCM_CCGR5_RD(x)       (HW_CCM_CCGR5(x).U)
#define HW_CCM_CCGR5_WR(x, v)    (HW_CCM_CCGR5(x).U = (v))
#define HW_CCM_CCGR5_SET(x, v)   ((*(uint32_t *) HW_CCM_CCGR5_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR5_CLR(x, v)   ((*(uint32_t *) HW_CCM_CCGR5_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR5_TOG(x, v)   ((*(uint32_t *) HW_CCM_CCGR5_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR5 bitfields
 */

/*!
 * @name Register CCM_CCGR5, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR5_SETTING0 (0U)         /*!< Bit position for CCM_CCGR5_SETTING0. */
#define BM_CCM_CCGR5_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR5_SETTING0. */
#define BS_CCM_CCGR5_SETTING0 (2U)         /*!< Bit field size in bits for CCM_CCGR5_SETTING0. */

/*! @brief Read current value of the CCM_CCGR5_SETTING0 field. */
#define BR_CCM_CCGR5_SETTING0(x) (HW_CCM_CCGR5(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR5_SETTING0. */
#define BF_CCM_CCGR5_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_SETTING0) & BM_CCM_CCGR5_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR5_SETTING0(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_SETTING0) | BF_CCM_CCGR5_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR5, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR5_SETTING1 (4U)         /*!< Bit position for CCM_CCGR5_SETTING1. */
#define BM_CCM_CCGR5_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR5_SETTING1. */
#define BS_CCM_CCGR5_SETTING1 (2U)         /*!< Bit field size in bits for CCM_CCGR5_SETTING1. */

/*! @brief Read current value of the CCM_CCGR5_SETTING1 field. */
#define BR_CCM_CCGR5_SETTING1(x) (HW_CCM_CCGR5(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR5_SETTING1. */
#define BF_CCM_CCGR5_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_SETTING1) & BM_CCM_CCGR5_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR5_SETTING1(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_SETTING1) | BF_CCM_CCGR5_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR5, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR5_SETTING2 (8U)         /*!< Bit position for CCM_CCGR5_SETTING2. */
#define BM_CCM_CCGR5_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR5_SETTING2. */
#define BS_CCM_CCGR5_SETTING2 (2U)         /*!< Bit field size in bits for CCM_CCGR5_SETTING2. */

/*! @brief Read current value of the CCM_CCGR5_SETTING2 field. */
#define BR_CCM_CCGR5_SETTING2(x) (HW_CCM_CCGR5(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR5_SETTING2. */
#define BF_CCM_CCGR5_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_SETTING2) & BM_CCM_CCGR5_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR5_SETTING2(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_SETTING2) | BF_CCM_CCGR5_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR5, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR5_SETTING3 (12U)        /*!< Bit position for CCM_CCGR5_SETTING3. */
#define BM_CCM_CCGR5_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR5_SETTING3. */
#define BS_CCM_CCGR5_SETTING3 (2U)         /*!< Bit field size in bits for CCM_CCGR5_SETTING3. */

/*! @brief Read current value of the CCM_CCGR5_SETTING3 field. */
#define BR_CCM_CCGR5_SETTING3(x) (HW_CCM_CCGR5(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR5_SETTING3. */
#define BF_CCM_CCGR5_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR5_SETTING3) & BM_CCM_CCGR5_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR5_SETTING3(x, v) (HW_CCM_CCGR5_WR(x, (HW_CCM_CCGR5_RD(x) & ~BM_CCM_CCGR5_SETTING3) | BF_CCM_CCGR5_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR6 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR6 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr6
{
    uint32_t U;
    struct _hw_ccm_ccgr6_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr6_t;

/*!
 * @name Constants and macros for entire CCM_CCGR6 register
 */
/*@{*/
#define HW_CCM_CCGR6_ADDR(x)     ((uintptr_t)(x) + 0x4060U)
#define HW_CCM_CCGR6_SET_ADDR(x) (HW_CCM_CCGR6_ADDR(x) + 0x4U)
#define HW_CCM_CCGR6_CLR_ADDR(x) (HW_CCM_CCGR6_ADDR(x) + 0x8U)
#define HW_CCM_CCGR6_TOG_ADDR(x) (HW_CCM_CCGR6_ADDR(x) + 0xCU)

#define HW_CCM_CCGR6(x)          (*(__IO hw_ccm_ccgr6_t *) HW_CCM_CCGR6_ADDR(x))
#define HW_CCM_CCGR6_RD(x)       (HW_CCM_CCGR6(x).U)
#define HW_CCM_CCGR6_WR(x, v)    (HW_CCM_CCGR6(x).U = (v))
#define HW_CCM_CCGR6_SET(x, v)   ((*(uint32_t *) HW_CCM_CCGR6_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR6_CLR(x, v)   ((*(uint32_t *) HW_CCM_CCGR6_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR6_TOG(x, v)   ((*(uint32_t *) HW_CCM_CCGR6_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR6 bitfields
 */

/*!
 * @name Register CCM_CCGR6, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR6_SETTING0 (0U)         /*!< Bit position for CCM_CCGR6_SETTING0. */
#define BM_CCM_CCGR6_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR6_SETTING0. */
#define BS_CCM_CCGR6_SETTING0 (2U)         /*!< Bit field size in bits for CCM_CCGR6_SETTING0. */

/*! @brief Read current value of the CCM_CCGR6_SETTING0 field. */
#define BR_CCM_CCGR6_SETTING0(x) (HW_CCM_CCGR6(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR6_SETTING0. */
#define BF_CCM_CCGR6_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_SETTING0) & BM_CCM_CCGR6_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR6_SETTING0(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_SETTING0) | BF_CCM_CCGR6_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR6, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR6_SETTING1 (4U)         /*!< Bit position for CCM_CCGR6_SETTING1. */
#define BM_CCM_CCGR6_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR6_SETTING1. */
#define BS_CCM_CCGR6_SETTING1 (2U)         /*!< Bit field size in bits for CCM_CCGR6_SETTING1. */

/*! @brief Read current value of the CCM_CCGR6_SETTING1 field. */
#define BR_CCM_CCGR6_SETTING1(x) (HW_CCM_CCGR6(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR6_SETTING1. */
#define BF_CCM_CCGR6_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_SETTING1) & BM_CCM_CCGR6_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR6_SETTING1(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_SETTING1) | BF_CCM_CCGR6_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR6, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR6_SETTING2 (8U)         /*!< Bit position for CCM_CCGR6_SETTING2. */
#define BM_CCM_CCGR6_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR6_SETTING2. */
#define BS_CCM_CCGR6_SETTING2 (2U)         /*!< Bit field size in bits for CCM_CCGR6_SETTING2. */

/*! @brief Read current value of the CCM_CCGR6_SETTING2 field. */
#define BR_CCM_CCGR6_SETTING2(x) (HW_CCM_CCGR6(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR6_SETTING2. */
#define BF_CCM_CCGR6_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_SETTING2) & BM_CCM_CCGR6_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR6_SETTING2(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_SETTING2) | BF_CCM_CCGR6_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR6, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR6_SETTING3 (12U)        /*!< Bit position for CCM_CCGR6_SETTING3. */
#define BM_CCM_CCGR6_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR6_SETTING3. */
#define BS_CCM_CCGR6_SETTING3 (2U)         /*!< Bit field size in bits for CCM_CCGR6_SETTING3. */

/*! @brief Read current value of the CCM_CCGR6_SETTING3 field. */
#define BR_CCM_CCGR6_SETTING3(x) (HW_CCM_CCGR6(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR6_SETTING3. */
#define BF_CCM_CCGR6_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR6_SETTING3) & BM_CCM_CCGR6_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR6_SETTING3(x, v) (HW_CCM_CCGR6_WR(x, (HW_CCM_CCGR6_RD(x) & ~BM_CCM_CCGR6_SETTING3) | BF_CCM_CCGR6_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR7 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR7 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr7
{
    uint32_t U;
    struct _hw_ccm_ccgr7_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr7_t;

/*!
 * @name Constants and macros for entire CCM_CCGR7 register
 */
/*@{*/
#define HW_CCM_CCGR7_ADDR(x)     ((uintptr_t)(x) + 0x4070U)
#define HW_CCM_CCGR7_SET_ADDR(x) (HW_CCM_CCGR7_ADDR(x) + 0x4U)
#define HW_CCM_CCGR7_CLR_ADDR(x) (HW_CCM_CCGR7_ADDR(x) + 0x8U)
#define HW_CCM_CCGR7_TOG_ADDR(x) (HW_CCM_CCGR7_ADDR(x) + 0xCU)

#define HW_CCM_CCGR7(x)          (*(__IO hw_ccm_ccgr7_t *) HW_CCM_CCGR7_ADDR(x))
#define HW_CCM_CCGR7_RD(x)       (HW_CCM_CCGR7(x).U)
#define HW_CCM_CCGR7_WR(x, v)    (HW_CCM_CCGR7(x).U = (v))
#define HW_CCM_CCGR7_SET(x, v)   ((*(uint32_t *) HW_CCM_CCGR7_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR7_CLR(x, v)   ((*(uint32_t *) HW_CCM_CCGR7_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR7_TOG(x, v)   ((*(uint32_t *) HW_CCM_CCGR7_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR7 bitfields
 */

/*!
 * @name Register CCM_CCGR7, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR7_SETTING0 (0U)         /*!< Bit position for CCM_CCGR7_SETTING0. */
#define BM_CCM_CCGR7_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR7_SETTING0. */
#define BS_CCM_CCGR7_SETTING0 (2U)         /*!< Bit field size in bits for CCM_CCGR7_SETTING0. */

/*! @brief Read current value of the CCM_CCGR7_SETTING0 field. */
#define BR_CCM_CCGR7_SETTING0(x) (HW_CCM_CCGR7(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR7_SETTING0. */
#define BF_CCM_CCGR7_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR7_SETTING0) & BM_CCM_CCGR7_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR7_SETTING0(x, v) (HW_CCM_CCGR7_WR(x, (HW_CCM_CCGR7_RD(x) & ~BM_CCM_CCGR7_SETTING0) | BF_CCM_CCGR7_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR7, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR7_SETTING1 (4U)         /*!< Bit position for CCM_CCGR7_SETTING1. */
#define BM_CCM_CCGR7_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR7_SETTING1. */
#define BS_CCM_CCGR7_SETTING1 (2U)         /*!< Bit field size in bits for CCM_CCGR7_SETTING1. */

/*! @brief Read current value of the CCM_CCGR7_SETTING1 field. */
#define BR_CCM_CCGR7_SETTING1(x) (HW_CCM_CCGR7(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR7_SETTING1. */
#define BF_CCM_CCGR7_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR7_SETTING1) & BM_CCM_CCGR7_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR7_SETTING1(x, v) (HW_CCM_CCGR7_WR(x, (HW_CCM_CCGR7_RD(x) & ~BM_CCM_CCGR7_SETTING1) | BF_CCM_CCGR7_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR7, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR7_SETTING2 (8U)         /*!< Bit position for CCM_CCGR7_SETTING2. */
#define BM_CCM_CCGR7_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR7_SETTING2. */
#define BS_CCM_CCGR7_SETTING2 (2U)         /*!< Bit field size in bits for CCM_CCGR7_SETTING2. */

/*! @brief Read current value of the CCM_CCGR7_SETTING2 field. */
#define BR_CCM_CCGR7_SETTING2(x) (HW_CCM_CCGR7(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR7_SETTING2. */
#define BF_CCM_CCGR7_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR7_SETTING2) & BM_CCM_CCGR7_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR7_SETTING2(x, v) (HW_CCM_CCGR7_WR(x, (HW_CCM_CCGR7_RD(x) & ~BM_CCM_CCGR7_SETTING2) | BF_CCM_CCGR7_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR7, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR7_SETTING3 (12U)        /*!< Bit position for CCM_CCGR7_SETTING3. */
#define BM_CCM_CCGR7_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR7_SETTING3. */
#define BS_CCM_CCGR7_SETTING3 (2U)         /*!< Bit field size in bits for CCM_CCGR7_SETTING3. */

/*! @brief Read current value of the CCM_CCGR7_SETTING3 field. */
#define BR_CCM_CCGR7_SETTING3(x) (HW_CCM_CCGR7(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR7_SETTING3. */
#define BF_CCM_CCGR7_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR7_SETTING3) & BM_CCM_CCGR7_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR7_SETTING3(x, v) (HW_CCM_CCGR7_WR(x, (HW_CCM_CCGR7_RD(x) & ~BM_CCM_CCGR7_SETTING3) | BF_CCM_CCGR7_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR8 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR8 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr8
{
    uint32_t U;
    struct _hw_ccm_ccgr8_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr8_t;

/*!
 * @name Constants and macros for entire CCM_CCGR8 register
 */
/*@{*/
#define HW_CCM_CCGR8_ADDR(x)     ((uintptr_t)(x) + 0x4080U)
#define HW_CCM_CCGR8_SET_ADDR(x) (HW_CCM_CCGR8_ADDR(x) + 0x4U)
#define HW_CCM_CCGR8_CLR_ADDR(x) (HW_CCM_CCGR8_ADDR(x) + 0x8U)
#define HW_CCM_CCGR8_TOG_ADDR(x) (HW_CCM_CCGR8_ADDR(x) + 0xCU)

#define HW_CCM_CCGR8(x)          (*(__IO hw_ccm_ccgr8_t *) HW_CCM_CCGR8_ADDR(x))
#define HW_CCM_CCGR8_RD(x)       (HW_CCM_CCGR8(x).U)
#define HW_CCM_CCGR8_WR(x, v)    (HW_CCM_CCGR8(x).U = (v))
#define HW_CCM_CCGR8_SET(x, v)   ((*(uint32_t *) HW_CCM_CCGR8_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR8_CLR(x, v)   ((*(uint32_t *) HW_CCM_CCGR8_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR8_TOG(x, v)   ((*(uint32_t *) HW_CCM_CCGR8_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR8 bitfields
 */

/*!
 * @name Register CCM_CCGR8, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR8_SETTING0 (0U)         /*!< Bit position for CCM_CCGR8_SETTING0. */
#define BM_CCM_CCGR8_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR8_SETTING0. */
#define BS_CCM_CCGR8_SETTING0 (2U)         /*!< Bit field size in bits for CCM_CCGR8_SETTING0. */

/*! @brief Read current value of the CCM_CCGR8_SETTING0 field. */
#define BR_CCM_CCGR8_SETTING0(x) (HW_CCM_CCGR8(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR8_SETTING0. */
#define BF_CCM_CCGR8_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR8_SETTING0) & BM_CCM_CCGR8_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR8_SETTING0(x, v) (HW_CCM_CCGR8_WR(x, (HW_CCM_CCGR8_RD(x) & ~BM_CCM_CCGR8_SETTING0) | BF_CCM_CCGR8_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR8, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR8_SETTING1 (4U)         /*!< Bit position for CCM_CCGR8_SETTING1. */
#define BM_CCM_CCGR8_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR8_SETTING1. */
#define BS_CCM_CCGR8_SETTING1 (2U)         /*!< Bit field size in bits for CCM_CCGR8_SETTING1. */

/*! @brief Read current value of the CCM_CCGR8_SETTING1 field. */
#define BR_CCM_CCGR8_SETTING1(x) (HW_CCM_CCGR8(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR8_SETTING1. */
#define BF_CCM_CCGR8_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR8_SETTING1) & BM_CCM_CCGR8_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR8_SETTING1(x, v) (HW_CCM_CCGR8_WR(x, (HW_CCM_CCGR8_RD(x) & ~BM_CCM_CCGR8_SETTING1) | BF_CCM_CCGR8_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR8, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR8_SETTING2 (8U)         /*!< Bit position for CCM_CCGR8_SETTING2. */
#define BM_CCM_CCGR8_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR8_SETTING2. */
#define BS_CCM_CCGR8_SETTING2 (2U)         /*!< Bit field size in bits for CCM_CCGR8_SETTING2. */

/*! @brief Read current value of the CCM_CCGR8_SETTING2 field. */
#define BR_CCM_CCGR8_SETTING2(x) (HW_CCM_CCGR8(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR8_SETTING2. */
#define BF_CCM_CCGR8_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR8_SETTING2) & BM_CCM_CCGR8_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR8_SETTING2(x, v) (HW_CCM_CCGR8_WR(x, (HW_CCM_CCGR8_RD(x) & ~BM_CCM_CCGR8_SETTING2) | BF_CCM_CCGR8_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR8, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR8_SETTING3 (12U)        /*!< Bit position for CCM_CCGR8_SETTING3. */
#define BM_CCM_CCGR8_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR8_SETTING3. */
#define BS_CCM_CCGR8_SETTING3 (2U)         /*!< Bit field size in bits for CCM_CCGR8_SETTING3. */

/*! @brief Read current value of the CCM_CCGR8_SETTING3 field. */
#define BR_CCM_CCGR8_SETTING3(x) (HW_CCM_CCGR8(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR8_SETTING3. */
#define BF_CCM_CCGR8_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR8_SETTING3) & BM_CCM_CCGR8_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR8_SETTING3(x, v) (HW_CCM_CCGR8_WR(x, (HW_CCM_CCGR8_RD(x) & ~BM_CCM_CCGR8_SETTING3) | BF_CCM_CCGR8_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR9 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR9 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr9
{
    uint32_t U;
    struct _hw_ccm_ccgr9_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr9_t;

/*!
 * @name Constants and macros for entire CCM_CCGR9 register
 */
/*@{*/
#define HW_CCM_CCGR9_ADDR(x)     ((uintptr_t)(x) + 0x4090U)
#define HW_CCM_CCGR9_SET_ADDR(x) (HW_CCM_CCGR9_ADDR(x) + 0x4U)
#define HW_CCM_CCGR9_CLR_ADDR(x) (HW_CCM_CCGR9_ADDR(x) + 0x8U)
#define HW_CCM_CCGR9_TOG_ADDR(x) (HW_CCM_CCGR9_ADDR(x) + 0xCU)

#define HW_CCM_CCGR9(x)          (*(__IO hw_ccm_ccgr9_t *) HW_CCM_CCGR9_ADDR(x))
#define HW_CCM_CCGR9_RD(x)       (HW_CCM_CCGR9(x).U)
#define HW_CCM_CCGR9_WR(x, v)    (HW_CCM_CCGR9(x).U = (v))
#define HW_CCM_CCGR9_SET(x, v)   ((*(uint32_t *) HW_CCM_CCGR9_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR9_CLR(x, v)   ((*(uint32_t *) HW_CCM_CCGR9_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR9_TOG(x, v)   ((*(uint32_t *) HW_CCM_CCGR9_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR9 bitfields
 */

/*!
 * @name Register CCM_CCGR9, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR9_SETTING0 (0U)         /*!< Bit position for CCM_CCGR9_SETTING0. */
#define BM_CCM_CCGR9_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR9_SETTING0. */
#define BS_CCM_CCGR9_SETTING0 (2U)         /*!< Bit field size in bits for CCM_CCGR9_SETTING0. */

/*! @brief Read current value of the CCM_CCGR9_SETTING0 field. */
#define BR_CCM_CCGR9_SETTING0(x) (HW_CCM_CCGR9(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR9_SETTING0. */
#define BF_CCM_CCGR9_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR9_SETTING0) & BM_CCM_CCGR9_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR9_SETTING0(x, v) (HW_CCM_CCGR9_WR(x, (HW_CCM_CCGR9_RD(x) & ~BM_CCM_CCGR9_SETTING0) | BF_CCM_CCGR9_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR9, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR9_SETTING1 (4U)         /*!< Bit position for CCM_CCGR9_SETTING1. */
#define BM_CCM_CCGR9_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR9_SETTING1. */
#define BS_CCM_CCGR9_SETTING1 (2U)         /*!< Bit field size in bits for CCM_CCGR9_SETTING1. */

/*! @brief Read current value of the CCM_CCGR9_SETTING1 field. */
#define BR_CCM_CCGR9_SETTING1(x) (HW_CCM_CCGR9(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR9_SETTING1. */
#define BF_CCM_CCGR9_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR9_SETTING1) & BM_CCM_CCGR9_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR9_SETTING1(x, v) (HW_CCM_CCGR9_WR(x, (HW_CCM_CCGR9_RD(x) & ~BM_CCM_CCGR9_SETTING1) | BF_CCM_CCGR9_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR9, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR9_SETTING2 (8U)         /*!< Bit position for CCM_CCGR9_SETTING2. */
#define BM_CCM_CCGR9_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR9_SETTING2. */
#define BS_CCM_CCGR9_SETTING2 (2U)         /*!< Bit field size in bits for CCM_CCGR9_SETTING2. */

/*! @brief Read current value of the CCM_CCGR9_SETTING2 field. */
#define BR_CCM_CCGR9_SETTING2(x) (HW_CCM_CCGR9(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR9_SETTING2. */
#define BF_CCM_CCGR9_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR9_SETTING2) & BM_CCM_CCGR9_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR9_SETTING2(x, v) (HW_CCM_CCGR9_WR(x, (HW_CCM_CCGR9_RD(x) & ~BM_CCM_CCGR9_SETTING2) | BF_CCM_CCGR9_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR9, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR9_SETTING3 (12U)        /*!< Bit position for CCM_CCGR9_SETTING3. */
#define BM_CCM_CCGR9_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR9_SETTING3. */
#define BS_CCM_CCGR9_SETTING3 (2U)         /*!< Bit field size in bits for CCM_CCGR9_SETTING3. */

/*! @brief Read current value of the CCM_CCGR9_SETTING3 field. */
#define BR_CCM_CCGR9_SETTING3(x) (HW_CCM_CCGR9(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR9_SETTING3. */
#define BF_CCM_CCGR9_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR9_SETTING3) & BM_CCM_CCGR9_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR9_SETTING3(x, v) (HW_CCM_CCGR9_WR(x, (HW_CCM_CCGR9_RD(x) & ~BM_CCM_CCGR9_SETTING3) | BF_CCM_CCGR9_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR10 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR10 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr10
{
    uint32_t U;
    struct _hw_ccm_ccgr10_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr10_t;

/*!
 * @name Constants and macros for entire CCM_CCGR10 register
 */
/*@{*/
#define HW_CCM_CCGR10_ADDR(x)    ((uintptr_t)(x) + 0x40A0U)
#define HW_CCM_CCGR10_SET_ADDR(x) (HW_CCM_CCGR10_ADDR(x) + 0x4U)
#define HW_CCM_CCGR10_CLR_ADDR(x) (HW_CCM_CCGR10_ADDR(x) + 0x8U)
#define HW_CCM_CCGR10_TOG_ADDR(x) (HW_CCM_CCGR10_ADDR(x) + 0xCU)

#define HW_CCM_CCGR10(x)         (*(__IO hw_ccm_ccgr10_t *) HW_CCM_CCGR10_ADDR(x))
#define HW_CCM_CCGR10_RD(x)      (HW_CCM_CCGR10(x).U)
#define HW_CCM_CCGR10_WR(x, v)   (HW_CCM_CCGR10(x).U = (v))
#define HW_CCM_CCGR10_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR10_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR10_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR10_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR10_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR10_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR10 bitfields
 */

/*!
 * @name Register CCM_CCGR10, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR10_SETTING0 (0U)        /*!< Bit position for CCM_CCGR10_SETTING0. */
#define BM_CCM_CCGR10_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR10_SETTING0. */
#define BS_CCM_CCGR10_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR10_SETTING0. */

/*! @brief Read current value of the CCM_CCGR10_SETTING0 field. */
#define BR_CCM_CCGR10_SETTING0(x) (HW_CCM_CCGR10(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR10_SETTING0. */
#define BF_CCM_CCGR10_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR10_SETTING0) & BM_CCM_CCGR10_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR10_SETTING0(x, v) (HW_CCM_CCGR10_WR(x, (HW_CCM_CCGR10_RD(x) & ~BM_CCM_CCGR10_SETTING0) | BF_CCM_CCGR10_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR10, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR10_SETTING1 (4U)        /*!< Bit position for CCM_CCGR10_SETTING1. */
#define BM_CCM_CCGR10_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR10_SETTING1. */
#define BS_CCM_CCGR10_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR10_SETTING1. */

/*! @brief Read current value of the CCM_CCGR10_SETTING1 field. */
#define BR_CCM_CCGR10_SETTING1(x) (HW_CCM_CCGR10(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR10_SETTING1. */
#define BF_CCM_CCGR10_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR10_SETTING1) & BM_CCM_CCGR10_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR10_SETTING1(x, v) (HW_CCM_CCGR10_WR(x, (HW_CCM_CCGR10_RD(x) & ~BM_CCM_CCGR10_SETTING1) | BF_CCM_CCGR10_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR10, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR10_SETTING2 (8U)        /*!< Bit position for CCM_CCGR10_SETTING2. */
#define BM_CCM_CCGR10_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR10_SETTING2. */
#define BS_CCM_CCGR10_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR10_SETTING2. */

/*! @brief Read current value of the CCM_CCGR10_SETTING2 field. */
#define BR_CCM_CCGR10_SETTING2(x) (HW_CCM_CCGR10(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR10_SETTING2. */
#define BF_CCM_CCGR10_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR10_SETTING2) & BM_CCM_CCGR10_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR10_SETTING2(x, v) (HW_CCM_CCGR10_WR(x, (HW_CCM_CCGR10_RD(x) & ~BM_CCM_CCGR10_SETTING2) | BF_CCM_CCGR10_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR10, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR10_SETTING3 (12U)       /*!< Bit position for CCM_CCGR10_SETTING3. */
#define BM_CCM_CCGR10_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR10_SETTING3. */
#define BS_CCM_CCGR10_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR10_SETTING3. */

/*! @brief Read current value of the CCM_CCGR10_SETTING3 field. */
#define BR_CCM_CCGR10_SETTING3(x) (HW_CCM_CCGR10(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR10_SETTING3. */
#define BF_CCM_CCGR10_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR10_SETTING3) & BM_CCM_CCGR10_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR10_SETTING3(x, v) (HW_CCM_CCGR10_WR(x, (HW_CCM_CCGR10_RD(x) & ~BM_CCM_CCGR10_SETTING3) | BF_CCM_CCGR10_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR11 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR11 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr11
{
    uint32_t U;
    struct _hw_ccm_ccgr11_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr11_t;

/*!
 * @name Constants and macros for entire CCM_CCGR11 register
 */
/*@{*/
#define HW_CCM_CCGR11_ADDR(x)    ((uintptr_t)(x) + 0x40B0U)
#define HW_CCM_CCGR11_SET_ADDR(x) (HW_CCM_CCGR11_ADDR(x) + 0x4U)
#define HW_CCM_CCGR11_CLR_ADDR(x) (HW_CCM_CCGR11_ADDR(x) + 0x8U)
#define HW_CCM_CCGR11_TOG_ADDR(x) (HW_CCM_CCGR11_ADDR(x) + 0xCU)

#define HW_CCM_CCGR11(x)         (*(__IO hw_ccm_ccgr11_t *) HW_CCM_CCGR11_ADDR(x))
#define HW_CCM_CCGR11_RD(x)      (HW_CCM_CCGR11(x).U)
#define HW_CCM_CCGR11_WR(x, v)   (HW_CCM_CCGR11(x).U = (v))
#define HW_CCM_CCGR11_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR11_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR11_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR11_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR11_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR11_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR11 bitfields
 */

/*!
 * @name Register CCM_CCGR11, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR11_SETTING0 (0U)        /*!< Bit position for CCM_CCGR11_SETTING0. */
#define BM_CCM_CCGR11_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR11_SETTING0. */
#define BS_CCM_CCGR11_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR11_SETTING0. */

/*! @brief Read current value of the CCM_CCGR11_SETTING0 field. */
#define BR_CCM_CCGR11_SETTING0(x) (HW_CCM_CCGR11(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR11_SETTING0. */
#define BF_CCM_CCGR11_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR11_SETTING0) & BM_CCM_CCGR11_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR11_SETTING0(x, v) (HW_CCM_CCGR11_WR(x, (HW_CCM_CCGR11_RD(x) & ~BM_CCM_CCGR11_SETTING0) | BF_CCM_CCGR11_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR11, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR11_SETTING1 (4U)        /*!< Bit position for CCM_CCGR11_SETTING1. */
#define BM_CCM_CCGR11_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR11_SETTING1. */
#define BS_CCM_CCGR11_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR11_SETTING1. */

/*! @brief Read current value of the CCM_CCGR11_SETTING1 field. */
#define BR_CCM_CCGR11_SETTING1(x) (HW_CCM_CCGR11(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR11_SETTING1. */
#define BF_CCM_CCGR11_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR11_SETTING1) & BM_CCM_CCGR11_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR11_SETTING1(x, v) (HW_CCM_CCGR11_WR(x, (HW_CCM_CCGR11_RD(x) & ~BM_CCM_CCGR11_SETTING1) | BF_CCM_CCGR11_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR11, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR11_SETTING2 (8U)        /*!< Bit position for CCM_CCGR11_SETTING2. */
#define BM_CCM_CCGR11_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR11_SETTING2. */
#define BS_CCM_CCGR11_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR11_SETTING2. */

/*! @brief Read current value of the CCM_CCGR11_SETTING2 field. */
#define BR_CCM_CCGR11_SETTING2(x) (HW_CCM_CCGR11(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR11_SETTING2. */
#define BF_CCM_CCGR11_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR11_SETTING2) & BM_CCM_CCGR11_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR11_SETTING2(x, v) (HW_CCM_CCGR11_WR(x, (HW_CCM_CCGR11_RD(x) & ~BM_CCM_CCGR11_SETTING2) | BF_CCM_CCGR11_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR11, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR11_SETTING3 (12U)       /*!< Bit position for CCM_CCGR11_SETTING3. */
#define BM_CCM_CCGR11_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR11_SETTING3. */
#define BS_CCM_CCGR11_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR11_SETTING3. */

/*! @brief Read current value of the CCM_CCGR11_SETTING3 field. */
#define BR_CCM_CCGR11_SETTING3(x) (HW_CCM_CCGR11(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR11_SETTING3. */
#define BF_CCM_CCGR11_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR11_SETTING3) & BM_CCM_CCGR11_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR11_SETTING3(x, v) (HW_CCM_CCGR11_WR(x, (HW_CCM_CCGR11_RD(x) & ~BM_CCM_CCGR11_SETTING3) | BF_CCM_CCGR11_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR12 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR12 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr12
{
    uint32_t U;
    struct _hw_ccm_ccgr12_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr12_t;

/*!
 * @name Constants and macros for entire CCM_CCGR12 register
 */
/*@{*/
#define HW_CCM_CCGR12_ADDR(x)    ((uintptr_t)(x) + 0x40C0U)
#define HW_CCM_CCGR12_SET_ADDR(x) (HW_CCM_CCGR12_ADDR(x) + 0x4U)
#define HW_CCM_CCGR12_CLR_ADDR(x) (HW_CCM_CCGR12_ADDR(x) + 0x8U)
#define HW_CCM_CCGR12_TOG_ADDR(x) (HW_CCM_CCGR12_ADDR(x) + 0xCU)

#define HW_CCM_CCGR12(x)         (*(__IO hw_ccm_ccgr12_t *) HW_CCM_CCGR12_ADDR(x))
#define HW_CCM_CCGR12_RD(x)      (HW_CCM_CCGR12(x).U)
#define HW_CCM_CCGR12_WR(x, v)   (HW_CCM_CCGR12(x).U = (v))
#define HW_CCM_CCGR12_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR12_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR12_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR12_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR12_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR12_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR12 bitfields
 */

/*!
 * @name Register CCM_CCGR12, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR12_SETTING0 (0U)        /*!< Bit position for CCM_CCGR12_SETTING0. */
#define BM_CCM_CCGR12_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR12_SETTING0. */
#define BS_CCM_CCGR12_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR12_SETTING0. */

/*! @brief Read current value of the CCM_CCGR12_SETTING0 field. */
#define BR_CCM_CCGR12_SETTING0(x) (HW_CCM_CCGR12(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR12_SETTING0. */
#define BF_CCM_CCGR12_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR12_SETTING0) & BM_CCM_CCGR12_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR12_SETTING0(x, v) (HW_CCM_CCGR12_WR(x, (HW_CCM_CCGR12_RD(x) & ~BM_CCM_CCGR12_SETTING0) | BF_CCM_CCGR12_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR12, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR12_SETTING1 (4U)        /*!< Bit position for CCM_CCGR12_SETTING1. */
#define BM_CCM_CCGR12_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR12_SETTING1. */
#define BS_CCM_CCGR12_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR12_SETTING1. */

/*! @brief Read current value of the CCM_CCGR12_SETTING1 field. */
#define BR_CCM_CCGR12_SETTING1(x) (HW_CCM_CCGR12(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR12_SETTING1. */
#define BF_CCM_CCGR12_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR12_SETTING1) & BM_CCM_CCGR12_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR12_SETTING1(x, v) (HW_CCM_CCGR12_WR(x, (HW_CCM_CCGR12_RD(x) & ~BM_CCM_CCGR12_SETTING1) | BF_CCM_CCGR12_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR12, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR12_SETTING2 (8U)        /*!< Bit position for CCM_CCGR12_SETTING2. */
#define BM_CCM_CCGR12_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR12_SETTING2. */
#define BS_CCM_CCGR12_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR12_SETTING2. */

/*! @brief Read current value of the CCM_CCGR12_SETTING2 field. */
#define BR_CCM_CCGR12_SETTING2(x) (HW_CCM_CCGR12(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR12_SETTING2. */
#define BF_CCM_CCGR12_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR12_SETTING2) & BM_CCM_CCGR12_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR12_SETTING2(x, v) (HW_CCM_CCGR12_WR(x, (HW_CCM_CCGR12_RD(x) & ~BM_CCM_CCGR12_SETTING2) | BF_CCM_CCGR12_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR12, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR12_SETTING3 (12U)       /*!< Bit position for CCM_CCGR12_SETTING3. */
#define BM_CCM_CCGR12_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR12_SETTING3. */
#define BS_CCM_CCGR12_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR12_SETTING3. */

/*! @brief Read current value of the CCM_CCGR12_SETTING3 field. */
#define BR_CCM_CCGR12_SETTING3(x) (HW_CCM_CCGR12(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR12_SETTING3. */
#define BF_CCM_CCGR12_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR12_SETTING3) & BM_CCM_CCGR12_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR12_SETTING3(x, v) (HW_CCM_CCGR12_WR(x, (HW_CCM_CCGR12_RD(x) & ~BM_CCM_CCGR12_SETTING3) | BF_CCM_CCGR12_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR13 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR13 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr13
{
    uint32_t U;
    struct _hw_ccm_ccgr13_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr13_t;

/*!
 * @name Constants and macros for entire CCM_CCGR13 register
 */
/*@{*/
#define HW_CCM_CCGR13_ADDR(x)    ((uintptr_t)(x) + 0x40D0U)
#define HW_CCM_CCGR13_SET_ADDR(x) (HW_CCM_CCGR13_ADDR(x) + 0x4U)
#define HW_CCM_CCGR13_CLR_ADDR(x) (HW_CCM_CCGR13_ADDR(x) + 0x8U)
#define HW_CCM_CCGR13_TOG_ADDR(x) (HW_CCM_CCGR13_ADDR(x) + 0xCU)

#define HW_CCM_CCGR13(x)         (*(__IO hw_ccm_ccgr13_t *) HW_CCM_CCGR13_ADDR(x))
#define HW_CCM_CCGR13_RD(x)      (HW_CCM_CCGR13(x).U)
#define HW_CCM_CCGR13_WR(x, v)   (HW_CCM_CCGR13(x).U = (v))
#define HW_CCM_CCGR13_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR13_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR13_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR13_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR13_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR13_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR13 bitfields
 */

/*!
 * @name Register CCM_CCGR13, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR13_SETTING0 (0U)        /*!< Bit position for CCM_CCGR13_SETTING0. */
#define BM_CCM_CCGR13_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR13_SETTING0. */
#define BS_CCM_CCGR13_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR13_SETTING0. */

/*! @brief Read current value of the CCM_CCGR13_SETTING0 field. */
#define BR_CCM_CCGR13_SETTING0(x) (HW_CCM_CCGR13(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR13_SETTING0. */
#define BF_CCM_CCGR13_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR13_SETTING0) & BM_CCM_CCGR13_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR13_SETTING0(x, v) (HW_CCM_CCGR13_WR(x, (HW_CCM_CCGR13_RD(x) & ~BM_CCM_CCGR13_SETTING0) | BF_CCM_CCGR13_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR13, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR13_SETTING1 (4U)        /*!< Bit position for CCM_CCGR13_SETTING1. */
#define BM_CCM_CCGR13_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR13_SETTING1. */
#define BS_CCM_CCGR13_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR13_SETTING1. */

/*! @brief Read current value of the CCM_CCGR13_SETTING1 field. */
#define BR_CCM_CCGR13_SETTING1(x) (HW_CCM_CCGR13(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR13_SETTING1. */
#define BF_CCM_CCGR13_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR13_SETTING1) & BM_CCM_CCGR13_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR13_SETTING1(x, v) (HW_CCM_CCGR13_WR(x, (HW_CCM_CCGR13_RD(x) & ~BM_CCM_CCGR13_SETTING1) | BF_CCM_CCGR13_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR13, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR13_SETTING2 (8U)        /*!< Bit position for CCM_CCGR13_SETTING2. */
#define BM_CCM_CCGR13_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR13_SETTING2. */
#define BS_CCM_CCGR13_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR13_SETTING2. */

/*! @brief Read current value of the CCM_CCGR13_SETTING2 field. */
#define BR_CCM_CCGR13_SETTING2(x) (HW_CCM_CCGR13(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR13_SETTING2. */
#define BF_CCM_CCGR13_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR13_SETTING2) & BM_CCM_CCGR13_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR13_SETTING2(x, v) (HW_CCM_CCGR13_WR(x, (HW_CCM_CCGR13_RD(x) & ~BM_CCM_CCGR13_SETTING2) | BF_CCM_CCGR13_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR13, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR13_SETTING3 (12U)       /*!< Bit position for CCM_CCGR13_SETTING3. */
#define BM_CCM_CCGR13_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR13_SETTING3. */
#define BS_CCM_CCGR13_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR13_SETTING3. */

/*! @brief Read current value of the CCM_CCGR13_SETTING3 field. */
#define BR_CCM_CCGR13_SETTING3(x) (HW_CCM_CCGR13(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR13_SETTING3. */
#define BF_CCM_CCGR13_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR13_SETTING3) & BM_CCM_CCGR13_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR13_SETTING3(x, v) (HW_CCM_CCGR13_WR(x, (HW_CCM_CCGR13_RD(x) & ~BM_CCM_CCGR13_SETTING3) | BF_CCM_CCGR13_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR14 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR14 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr14
{
    uint32_t U;
    struct _hw_ccm_ccgr14_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr14_t;

/*!
 * @name Constants and macros for entire CCM_CCGR14 register
 */
/*@{*/
#define HW_CCM_CCGR14_ADDR(x)    ((uintptr_t)(x) + 0x40E0U)
#define HW_CCM_CCGR14_SET_ADDR(x) (HW_CCM_CCGR14_ADDR(x) + 0x4U)
#define HW_CCM_CCGR14_CLR_ADDR(x) (HW_CCM_CCGR14_ADDR(x) + 0x8U)
#define HW_CCM_CCGR14_TOG_ADDR(x) (HW_CCM_CCGR14_ADDR(x) + 0xCU)

#define HW_CCM_CCGR14(x)         (*(__IO hw_ccm_ccgr14_t *) HW_CCM_CCGR14_ADDR(x))
#define HW_CCM_CCGR14_RD(x)      (HW_CCM_CCGR14(x).U)
#define HW_CCM_CCGR14_WR(x, v)   (HW_CCM_CCGR14(x).U = (v))
#define HW_CCM_CCGR14_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR14_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR14_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR14_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR14_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR14_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR14 bitfields
 */

/*!
 * @name Register CCM_CCGR14, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR14_SETTING0 (0U)        /*!< Bit position for CCM_CCGR14_SETTING0. */
#define BM_CCM_CCGR14_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR14_SETTING0. */
#define BS_CCM_CCGR14_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR14_SETTING0. */

/*! @brief Read current value of the CCM_CCGR14_SETTING0 field. */
#define BR_CCM_CCGR14_SETTING0(x) (HW_CCM_CCGR14(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR14_SETTING0. */
#define BF_CCM_CCGR14_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR14_SETTING0) & BM_CCM_CCGR14_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR14_SETTING0(x, v) (HW_CCM_CCGR14_WR(x, (HW_CCM_CCGR14_RD(x) & ~BM_CCM_CCGR14_SETTING0) | BF_CCM_CCGR14_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR14, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR14_SETTING1 (4U)        /*!< Bit position for CCM_CCGR14_SETTING1. */
#define BM_CCM_CCGR14_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR14_SETTING1. */
#define BS_CCM_CCGR14_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR14_SETTING1. */

/*! @brief Read current value of the CCM_CCGR14_SETTING1 field. */
#define BR_CCM_CCGR14_SETTING1(x) (HW_CCM_CCGR14(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR14_SETTING1. */
#define BF_CCM_CCGR14_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR14_SETTING1) & BM_CCM_CCGR14_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR14_SETTING1(x, v) (HW_CCM_CCGR14_WR(x, (HW_CCM_CCGR14_RD(x) & ~BM_CCM_CCGR14_SETTING1) | BF_CCM_CCGR14_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR14, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR14_SETTING2 (8U)        /*!< Bit position for CCM_CCGR14_SETTING2. */
#define BM_CCM_CCGR14_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR14_SETTING2. */
#define BS_CCM_CCGR14_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR14_SETTING2. */

/*! @brief Read current value of the CCM_CCGR14_SETTING2 field. */
#define BR_CCM_CCGR14_SETTING2(x) (HW_CCM_CCGR14(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR14_SETTING2. */
#define BF_CCM_CCGR14_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR14_SETTING2) & BM_CCM_CCGR14_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR14_SETTING2(x, v) (HW_CCM_CCGR14_WR(x, (HW_CCM_CCGR14_RD(x) & ~BM_CCM_CCGR14_SETTING2) | BF_CCM_CCGR14_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR14, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR14_SETTING3 (12U)       /*!< Bit position for CCM_CCGR14_SETTING3. */
#define BM_CCM_CCGR14_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR14_SETTING3. */
#define BS_CCM_CCGR14_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR14_SETTING3. */

/*! @brief Read current value of the CCM_CCGR14_SETTING3 field. */
#define BR_CCM_CCGR14_SETTING3(x) (HW_CCM_CCGR14(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR14_SETTING3. */
#define BF_CCM_CCGR14_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR14_SETTING3) & BM_CCM_CCGR14_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR14_SETTING3(x, v) (HW_CCM_CCGR14_WR(x, (HW_CCM_CCGR14_RD(x) & ~BM_CCM_CCGR14_SETTING3) | BF_CCM_CCGR14_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR15 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR15 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr15
{
    uint32_t U;
    struct _hw_ccm_ccgr15_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr15_t;

/*!
 * @name Constants and macros for entire CCM_CCGR15 register
 */
/*@{*/
#define HW_CCM_CCGR15_ADDR(x)    ((uintptr_t)(x) + 0x40F0U)
#define HW_CCM_CCGR15_SET_ADDR(x) (HW_CCM_CCGR15_ADDR(x) + 0x4U)
#define HW_CCM_CCGR15_CLR_ADDR(x) (HW_CCM_CCGR15_ADDR(x) + 0x8U)
#define HW_CCM_CCGR15_TOG_ADDR(x) (HW_CCM_CCGR15_ADDR(x) + 0xCU)

#define HW_CCM_CCGR15(x)         (*(__IO hw_ccm_ccgr15_t *) HW_CCM_CCGR15_ADDR(x))
#define HW_CCM_CCGR15_RD(x)      (HW_CCM_CCGR15(x).U)
#define HW_CCM_CCGR15_WR(x, v)   (HW_CCM_CCGR15(x).U = (v))
#define HW_CCM_CCGR15_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR15_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR15_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR15_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR15_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR15_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR15 bitfields
 */

/*!
 * @name Register CCM_CCGR15, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR15_SETTING0 (0U)        /*!< Bit position for CCM_CCGR15_SETTING0. */
#define BM_CCM_CCGR15_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR15_SETTING0. */
#define BS_CCM_CCGR15_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR15_SETTING0. */

/*! @brief Read current value of the CCM_CCGR15_SETTING0 field. */
#define BR_CCM_CCGR15_SETTING0(x) (HW_CCM_CCGR15(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR15_SETTING0. */
#define BF_CCM_CCGR15_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR15_SETTING0) & BM_CCM_CCGR15_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR15_SETTING0(x, v) (HW_CCM_CCGR15_WR(x, (HW_CCM_CCGR15_RD(x) & ~BM_CCM_CCGR15_SETTING0) | BF_CCM_CCGR15_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR15, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR15_SETTING1 (4U)        /*!< Bit position for CCM_CCGR15_SETTING1. */
#define BM_CCM_CCGR15_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR15_SETTING1. */
#define BS_CCM_CCGR15_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR15_SETTING1. */

/*! @brief Read current value of the CCM_CCGR15_SETTING1 field. */
#define BR_CCM_CCGR15_SETTING1(x) (HW_CCM_CCGR15(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR15_SETTING1. */
#define BF_CCM_CCGR15_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR15_SETTING1) & BM_CCM_CCGR15_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR15_SETTING1(x, v) (HW_CCM_CCGR15_WR(x, (HW_CCM_CCGR15_RD(x) & ~BM_CCM_CCGR15_SETTING1) | BF_CCM_CCGR15_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR15, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR15_SETTING2 (8U)        /*!< Bit position for CCM_CCGR15_SETTING2. */
#define BM_CCM_CCGR15_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR15_SETTING2. */
#define BS_CCM_CCGR15_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR15_SETTING2. */

/*! @brief Read current value of the CCM_CCGR15_SETTING2 field. */
#define BR_CCM_CCGR15_SETTING2(x) (HW_CCM_CCGR15(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR15_SETTING2. */
#define BF_CCM_CCGR15_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR15_SETTING2) & BM_CCM_CCGR15_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR15_SETTING2(x, v) (HW_CCM_CCGR15_WR(x, (HW_CCM_CCGR15_RD(x) & ~BM_CCM_CCGR15_SETTING2) | BF_CCM_CCGR15_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR15, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR15_SETTING3 (12U)       /*!< Bit position for CCM_CCGR15_SETTING3. */
#define BM_CCM_CCGR15_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR15_SETTING3. */
#define BS_CCM_CCGR15_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR15_SETTING3. */

/*! @brief Read current value of the CCM_CCGR15_SETTING3 field. */
#define BR_CCM_CCGR15_SETTING3(x) (HW_CCM_CCGR15(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR15_SETTING3. */
#define BF_CCM_CCGR15_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR15_SETTING3) & BM_CCM_CCGR15_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR15_SETTING3(x, v) (HW_CCM_CCGR15_WR(x, (HW_CCM_CCGR15_RD(x) & ~BM_CCM_CCGR15_SETTING3) | BF_CCM_CCGR15_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR16 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR16 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr16
{
    uint32_t U;
    struct _hw_ccm_ccgr16_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr16_t;

/*!
 * @name Constants and macros for entire CCM_CCGR16 register
 */
/*@{*/
#define HW_CCM_CCGR16_ADDR(x)    ((uintptr_t)(x) + 0x4100U)
#define HW_CCM_CCGR16_SET_ADDR(x) (HW_CCM_CCGR16_ADDR(x) + 0x4U)
#define HW_CCM_CCGR16_CLR_ADDR(x) (HW_CCM_CCGR16_ADDR(x) + 0x8U)
#define HW_CCM_CCGR16_TOG_ADDR(x) (HW_CCM_CCGR16_ADDR(x) + 0xCU)

#define HW_CCM_CCGR16(x)         (*(__IO hw_ccm_ccgr16_t *) HW_CCM_CCGR16_ADDR(x))
#define HW_CCM_CCGR16_RD(x)      (HW_CCM_CCGR16(x).U)
#define HW_CCM_CCGR16_WR(x, v)   (HW_CCM_CCGR16(x).U = (v))
#define HW_CCM_CCGR16_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR16_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR16_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR16_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR16_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR16_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR16 bitfields
 */

/*!
 * @name Register CCM_CCGR16, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR16_SETTING0 (0U)        /*!< Bit position for CCM_CCGR16_SETTING0. */
#define BM_CCM_CCGR16_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR16_SETTING0. */
#define BS_CCM_CCGR16_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR16_SETTING0. */

/*! @brief Read current value of the CCM_CCGR16_SETTING0 field. */
#define BR_CCM_CCGR16_SETTING0(x) (HW_CCM_CCGR16(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR16_SETTING0. */
#define BF_CCM_CCGR16_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR16_SETTING0) & BM_CCM_CCGR16_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR16_SETTING0(x, v) (HW_CCM_CCGR16_WR(x, (HW_CCM_CCGR16_RD(x) & ~BM_CCM_CCGR16_SETTING0) | BF_CCM_CCGR16_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR16, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR16_SETTING1 (4U)        /*!< Bit position for CCM_CCGR16_SETTING1. */
#define BM_CCM_CCGR16_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR16_SETTING1. */
#define BS_CCM_CCGR16_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR16_SETTING1. */

/*! @brief Read current value of the CCM_CCGR16_SETTING1 field. */
#define BR_CCM_CCGR16_SETTING1(x) (HW_CCM_CCGR16(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR16_SETTING1. */
#define BF_CCM_CCGR16_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR16_SETTING1) & BM_CCM_CCGR16_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR16_SETTING1(x, v) (HW_CCM_CCGR16_WR(x, (HW_CCM_CCGR16_RD(x) & ~BM_CCM_CCGR16_SETTING1) | BF_CCM_CCGR16_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR16, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR16_SETTING2 (8U)        /*!< Bit position for CCM_CCGR16_SETTING2. */
#define BM_CCM_CCGR16_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR16_SETTING2. */
#define BS_CCM_CCGR16_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR16_SETTING2. */

/*! @brief Read current value of the CCM_CCGR16_SETTING2 field. */
#define BR_CCM_CCGR16_SETTING2(x) (HW_CCM_CCGR16(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR16_SETTING2. */
#define BF_CCM_CCGR16_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR16_SETTING2) & BM_CCM_CCGR16_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR16_SETTING2(x, v) (HW_CCM_CCGR16_WR(x, (HW_CCM_CCGR16_RD(x) & ~BM_CCM_CCGR16_SETTING2) | BF_CCM_CCGR16_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR16, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR16_SETTING3 (12U)       /*!< Bit position for CCM_CCGR16_SETTING3. */
#define BM_CCM_CCGR16_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR16_SETTING3. */
#define BS_CCM_CCGR16_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR16_SETTING3. */

/*! @brief Read current value of the CCM_CCGR16_SETTING3 field. */
#define BR_CCM_CCGR16_SETTING3(x) (HW_CCM_CCGR16(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR16_SETTING3. */
#define BF_CCM_CCGR16_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR16_SETTING3) & BM_CCM_CCGR16_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR16_SETTING3(x, v) (HW_CCM_CCGR16_WR(x, (HW_CCM_CCGR16_RD(x) & ~BM_CCM_CCGR16_SETTING3) | BF_CCM_CCGR16_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR17 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR17 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr17
{
    uint32_t U;
    struct _hw_ccm_ccgr17_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr17_t;

/*!
 * @name Constants and macros for entire CCM_CCGR17 register
 */
/*@{*/
#define HW_CCM_CCGR17_ADDR(x)    ((uintptr_t)(x) + 0x4110U)
#define HW_CCM_CCGR17_SET_ADDR(x) (HW_CCM_CCGR17_ADDR(x) + 0x4U)
#define HW_CCM_CCGR17_CLR_ADDR(x) (HW_CCM_CCGR17_ADDR(x) + 0x8U)
#define HW_CCM_CCGR17_TOG_ADDR(x) (HW_CCM_CCGR17_ADDR(x) + 0xCU)

#define HW_CCM_CCGR17(x)         (*(__IO hw_ccm_ccgr17_t *) HW_CCM_CCGR17_ADDR(x))
#define HW_CCM_CCGR17_RD(x)      (HW_CCM_CCGR17(x).U)
#define HW_CCM_CCGR17_WR(x, v)   (HW_CCM_CCGR17(x).U = (v))
#define HW_CCM_CCGR17_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR17_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR17_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR17_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR17_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR17_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR17 bitfields
 */

/*!
 * @name Register CCM_CCGR17, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR17_SETTING0 (0U)        /*!< Bit position for CCM_CCGR17_SETTING0. */
#define BM_CCM_CCGR17_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR17_SETTING0. */
#define BS_CCM_CCGR17_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR17_SETTING0. */

/*! @brief Read current value of the CCM_CCGR17_SETTING0 field. */
#define BR_CCM_CCGR17_SETTING0(x) (HW_CCM_CCGR17(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR17_SETTING0. */
#define BF_CCM_CCGR17_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR17_SETTING0) & BM_CCM_CCGR17_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR17_SETTING0(x, v) (HW_CCM_CCGR17_WR(x, (HW_CCM_CCGR17_RD(x) & ~BM_CCM_CCGR17_SETTING0) | BF_CCM_CCGR17_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR17, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR17_SETTING1 (4U)        /*!< Bit position for CCM_CCGR17_SETTING1. */
#define BM_CCM_CCGR17_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR17_SETTING1. */
#define BS_CCM_CCGR17_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR17_SETTING1. */

/*! @brief Read current value of the CCM_CCGR17_SETTING1 field. */
#define BR_CCM_CCGR17_SETTING1(x) (HW_CCM_CCGR17(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR17_SETTING1. */
#define BF_CCM_CCGR17_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR17_SETTING1) & BM_CCM_CCGR17_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR17_SETTING1(x, v) (HW_CCM_CCGR17_WR(x, (HW_CCM_CCGR17_RD(x) & ~BM_CCM_CCGR17_SETTING1) | BF_CCM_CCGR17_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR17, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR17_SETTING2 (8U)        /*!< Bit position for CCM_CCGR17_SETTING2. */
#define BM_CCM_CCGR17_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR17_SETTING2. */
#define BS_CCM_CCGR17_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR17_SETTING2. */

/*! @brief Read current value of the CCM_CCGR17_SETTING2 field. */
#define BR_CCM_CCGR17_SETTING2(x) (HW_CCM_CCGR17(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR17_SETTING2. */
#define BF_CCM_CCGR17_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR17_SETTING2) & BM_CCM_CCGR17_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR17_SETTING2(x, v) (HW_CCM_CCGR17_WR(x, (HW_CCM_CCGR17_RD(x) & ~BM_CCM_CCGR17_SETTING2) | BF_CCM_CCGR17_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR17, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR17_SETTING3 (12U)       /*!< Bit position for CCM_CCGR17_SETTING3. */
#define BM_CCM_CCGR17_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR17_SETTING3. */
#define BS_CCM_CCGR17_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR17_SETTING3. */

/*! @brief Read current value of the CCM_CCGR17_SETTING3 field. */
#define BR_CCM_CCGR17_SETTING3(x) (HW_CCM_CCGR17(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR17_SETTING3. */
#define BF_CCM_CCGR17_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR17_SETTING3) & BM_CCM_CCGR17_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR17_SETTING3(x, v) (HW_CCM_CCGR17_WR(x, (HW_CCM_CCGR17_RD(x) & ~BM_CCM_CCGR17_SETTING3) | BF_CCM_CCGR17_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR18 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR18 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr18
{
    uint32_t U;
    struct _hw_ccm_ccgr18_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr18_t;

/*!
 * @name Constants and macros for entire CCM_CCGR18 register
 */
/*@{*/
#define HW_CCM_CCGR18_ADDR(x)    ((uintptr_t)(x) + 0x4120U)
#define HW_CCM_CCGR18_SET_ADDR(x) (HW_CCM_CCGR18_ADDR(x) + 0x4U)
#define HW_CCM_CCGR18_CLR_ADDR(x) (HW_CCM_CCGR18_ADDR(x) + 0x8U)
#define HW_CCM_CCGR18_TOG_ADDR(x) (HW_CCM_CCGR18_ADDR(x) + 0xCU)

#define HW_CCM_CCGR18(x)         (*(__IO hw_ccm_ccgr18_t *) HW_CCM_CCGR18_ADDR(x))
#define HW_CCM_CCGR18_RD(x)      (HW_CCM_CCGR18(x).U)
#define HW_CCM_CCGR18_WR(x, v)   (HW_CCM_CCGR18(x).U = (v))
#define HW_CCM_CCGR18_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR18_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR18_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR18_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR18_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR18_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR18 bitfields
 */

/*!
 * @name Register CCM_CCGR18, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR18_SETTING0 (0U)        /*!< Bit position for CCM_CCGR18_SETTING0. */
#define BM_CCM_CCGR18_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR18_SETTING0. */
#define BS_CCM_CCGR18_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR18_SETTING0. */

/*! @brief Read current value of the CCM_CCGR18_SETTING0 field. */
#define BR_CCM_CCGR18_SETTING0(x) (HW_CCM_CCGR18(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR18_SETTING0. */
#define BF_CCM_CCGR18_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR18_SETTING0) & BM_CCM_CCGR18_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR18_SETTING0(x, v) (HW_CCM_CCGR18_WR(x, (HW_CCM_CCGR18_RD(x) & ~BM_CCM_CCGR18_SETTING0) | BF_CCM_CCGR18_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR18, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR18_SETTING1 (4U)        /*!< Bit position for CCM_CCGR18_SETTING1. */
#define BM_CCM_CCGR18_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR18_SETTING1. */
#define BS_CCM_CCGR18_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR18_SETTING1. */

/*! @brief Read current value of the CCM_CCGR18_SETTING1 field. */
#define BR_CCM_CCGR18_SETTING1(x) (HW_CCM_CCGR18(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR18_SETTING1. */
#define BF_CCM_CCGR18_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR18_SETTING1) & BM_CCM_CCGR18_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR18_SETTING1(x, v) (HW_CCM_CCGR18_WR(x, (HW_CCM_CCGR18_RD(x) & ~BM_CCM_CCGR18_SETTING1) | BF_CCM_CCGR18_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR18, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR18_SETTING2 (8U)        /*!< Bit position for CCM_CCGR18_SETTING2. */
#define BM_CCM_CCGR18_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR18_SETTING2. */
#define BS_CCM_CCGR18_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR18_SETTING2. */

/*! @brief Read current value of the CCM_CCGR18_SETTING2 field. */
#define BR_CCM_CCGR18_SETTING2(x) (HW_CCM_CCGR18(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR18_SETTING2. */
#define BF_CCM_CCGR18_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR18_SETTING2) & BM_CCM_CCGR18_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR18_SETTING2(x, v) (HW_CCM_CCGR18_WR(x, (HW_CCM_CCGR18_RD(x) & ~BM_CCM_CCGR18_SETTING2) | BF_CCM_CCGR18_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR18, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR18_SETTING3 (12U)       /*!< Bit position for CCM_CCGR18_SETTING3. */
#define BM_CCM_CCGR18_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR18_SETTING3. */
#define BS_CCM_CCGR18_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR18_SETTING3. */

/*! @brief Read current value of the CCM_CCGR18_SETTING3 field. */
#define BR_CCM_CCGR18_SETTING3(x) (HW_CCM_CCGR18(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR18_SETTING3. */
#define BF_CCM_CCGR18_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR18_SETTING3) & BM_CCM_CCGR18_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR18_SETTING3(x, v) (HW_CCM_CCGR18_WR(x, (HW_CCM_CCGR18_RD(x) & ~BM_CCM_CCGR18_SETTING3) | BF_CCM_CCGR18_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR19 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR19 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr19
{
    uint32_t U;
    struct _hw_ccm_ccgr19_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr19_t;

/*!
 * @name Constants and macros for entire CCM_CCGR19 register
 */
/*@{*/
#define HW_CCM_CCGR19_ADDR(x)    ((uintptr_t)(x) + 0x4130U)
#define HW_CCM_CCGR19_SET_ADDR(x) (HW_CCM_CCGR19_ADDR(x) + 0x4U)
#define HW_CCM_CCGR19_CLR_ADDR(x) (HW_CCM_CCGR19_ADDR(x) + 0x8U)
#define HW_CCM_CCGR19_TOG_ADDR(x) (HW_CCM_CCGR19_ADDR(x) + 0xCU)

#define HW_CCM_CCGR19(x)         (*(__IO hw_ccm_ccgr19_t *) HW_CCM_CCGR19_ADDR(x))
#define HW_CCM_CCGR19_RD(x)      (HW_CCM_CCGR19(x).U)
#define HW_CCM_CCGR19_WR(x, v)   (HW_CCM_CCGR19(x).U = (v))
#define HW_CCM_CCGR19_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR19_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR19_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR19_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR19_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR19_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR19 bitfields
 */

/*!
 * @name Register CCM_CCGR19, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR19_SETTING0 (0U)        /*!< Bit position for CCM_CCGR19_SETTING0. */
#define BM_CCM_CCGR19_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR19_SETTING0. */
#define BS_CCM_CCGR19_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR19_SETTING0. */

/*! @brief Read current value of the CCM_CCGR19_SETTING0 field. */
#define BR_CCM_CCGR19_SETTING0(x) (HW_CCM_CCGR19(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR19_SETTING0. */
#define BF_CCM_CCGR19_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR19_SETTING0) & BM_CCM_CCGR19_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR19_SETTING0(x, v) (HW_CCM_CCGR19_WR(x, (HW_CCM_CCGR19_RD(x) & ~BM_CCM_CCGR19_SETTING0) | BF_CCM_CCGR19_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR19, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR19_SETTING1 (4U)        /*!< Bit position for CCM_CCGR19_SETTING1. */
#define BM_CCM_CCGR19_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR19_SETTING1. */
#define BS_CCM_CCGR19_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR19_SETTING1. */

/*! @brief Read current value of the CCM_CCGR19_SETTING1 field. */
#define BR_CCM_CCGR19_SETTING1(x) (HW_CCM_CCGR19(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR19_SETTING1. */
#define BF_CCM_CCGR19_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR19_SETTING1) & BM_CCM_CCGR19_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR19_SETTING1(x, v) (HW_CCM_CCGR19_WR(x, (HW_CCM_CCGR19_RD(x) & ~BM_CCM_CCGR19_SETTING1) | BF_CCM_CCGR19_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR19, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR19_SETTING2 (8U)        /*!< Bit position for CCM_CCGR19_SETTING2. */
#define BM_CCM_CCGR19_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR19_SETTING2. */
#define BS_CCM_CCGR19_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR19_SETTING2. */

/*! @brief Read current value of the CCM_CCGR19_SETTING2 field. */
#define BR_CCM_CCGR19_SETTING2(x) (HW_CCM_CCGR19(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR19_SETTING2. */
#define BF_CCM_CCGR19_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR19_SETTING2) & BM_CCM_CCGR19_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR19_SETTING2(x, v) (HW_CCM_CCGR19_WR(x, (HW_CCM_CCGR19_RD(x) & ~BM_CCM_CCGR19_SETTING2) | BF_CCM_CCGR19_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR19, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR19_SETTING3 (12U)       /*!< Bit position for CCM_CCGR19_SETTING3. */
#define BM_CCM_CCGR19_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR19_SETTING3. */
#define BS_CCM_CCGR19_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR19_SETTING3. */

/*! @brief Read current value of the CCM_CCGR19_SETTING3 field. */
#define BR_CCM_CCGR19_SETTING3(x) (HW_CCM_CCGR19(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR19_SETTING3. */
#define BF_CCM_CCGR19_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR19_SETTING3) & BM_CCM_CCGR19_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR19_SETTING3(x, v) (HW_CCM_CCGR19_WR(x, (HW_CCM_CCGR19_RD(x) & ~BM_CCM_CCGR19_SETTING3) | BF_CCM_CCGR19_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR20 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR20 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr20
{
    uint32_t U;
    struct _hw_ccm_ccgr20_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr20_t;

/*!
 * @name Constants and macros for entire CCM_CCGR20 register
 */
/*@{*/
#define HW_CCM_CCGR20_ADDR(x)    ((uintptr_t)(x) + 0x4140U)
#define HW_CCM_CCGR20_SET_ADDR(x) (HW_CCM_CCGR20_ADDR(x) + 0x4U)
#define HW_CCM_CCGR20_CLR_ADDR(x) (HW_CCM_CCGR20_ADDR(x) + 0x8U)
#define HW_CCM_CCGR20_TOG_ADDR(x) (HW_CCM_CCGR20_ADDR(x) + 0xCU)

#define HW_CCM_CCGR20(x)         (*(__IO hw_ccm_ccgr20_t *) HW_CCM_CCGR20_ADDR(x))
#define HW_CCM_CCGR20_RD(x)      (HW_CCM_CCGR20(x).U)
#define HW_CCM_CCGR20_WR(x, v)   (HW_CCM_CCGR20(x).U = (v))
#define HW_CCM_CCGR20_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR20_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR20_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR20_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR20_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR20_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR20 bitfields
 */

/*!
 * @name Register CCM_CCGR20, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR20_SETTING0 (0U)        /*!< Bit position for CCM_CCGR20_SETTING0. */
#define BM_CCM_CCGR20_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR20_SETTING0. */
#define BS_CCM_CCGR20_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR20_SETTING0. */

/*! @brief Read current value of the CCM_CCGR20_SETTING0 field. */
#define BR_CCM_CCGR20_SETTING0(x) (HW_CCM_CCGR20(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR20_SETTING0. */
#define BF_CCM_CCGR20_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR20_SETTING0) & BM_CCM_CCGR20_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR20_SETTING0(x, v) (HW_CCM_CCGR20_WR(x, (HW_CCM_CCGR20_RD(x) & ~BM_CCM_CCGR20_SETTING0) | BF_CCM_CCGR20_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR20, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR20_SETTING1 (4U)        /*!< Bit position for CCM_CCGR20_SETTING1. */
#define BM_CCM_CCGR20_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR20_SETTING1. */
#define BS_CCM_CCGR20_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR20_SETTING1. */

/*! @brief Read current value of the CCM_CCGR20_SETTING1 field. */
#define BR_CCM_CCGR20_SETTING1(x) (HW_CCM_CCGR20(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR20_SETTING1. */
#define BF_CCM_CCGR20_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR20_SETTING1) & BM_CCM_CCGR20_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR20_SETTING1(x, v) (HW_CCM_CCGR20_WR(x, (HW_CCM_CCGR20_RD(x) & ~BM_CCM_CCGR20_SETTING1) | BF_CCM_CCGR20_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR20, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR20_SETTING2 (8U)        /*!< Bit position for CCM_CCGR20_SETTING2. */
#define BM_CCM_CCGR20_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR20_SETTING2. */
#define BS_CCM_CCGR20_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR20_SETTING2. */

/*! @brief Read current value of the CCM_CCGR20_SETTING2 field. */
#define BR_CCM_CCGR20_SETTING2(x) (HW_CCM_CCGR20(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR20_SETTING2. */
#define BF_CCM_CCGR20_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR20_SETTING2) & BM_CCM_CCGR20_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR20_SETTING2(x, v) (HW_CCM_CCGR20_WR(x, (HW_CCM_CCGR20_RD(x) & ~BM_CCM_CCGR20_SETTING2) | BF_CCM_CCGR20_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR20, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR20_SETTING3 (12U)       /*!< Bit position for CCM_CCGR20_SETTING3. */
#define BM_CCM_CCGR20_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR20_SETTING3. */
#define BS_CCM_CCGR20_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR20_SETTING3. */

/*! @brief Read current value of the CCM_CCGR20_SETTING3 field. */
#define BR_CCM_CCGR20_SETTING3(x) (HW_CCM_CCGR20(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR20_SETTING3. */
#define BF_CCM_CCGR20_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR20_SETTING3) & BM_CCM_CCGR20_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR20_SETTING3(x, v) (HW_CCM_CCGR20_WR(x, (HW_CCM_CCGR20_RD(x) & ~BM_CCM_CCGR20_SETTING3) | BF_CCM_CCGR20_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR21 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR21 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr21
{
    uint32_t U;
    struct _hw_ccm_ccgr21_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr21_t;

/*!
 * @name Constants and macros for entire CCM_CCGR21 register
 */
/*@{*/
#define HW_CCM_CCGR21_ADDR(x)    ((uintptr_t)(x) + 0x4150U)
#define HW_CCM_CCGR21_SET_ADDR(x) (HW_CCM_CCGR21_ADDR(x) + 0x4U)
#define HW_CCM_CCGR21_CLR_ADDR(x) (HW_CCM_CCGR21_ADDR(x) + 0x8U)
#define HW_CCM_CCGR21_TOG_ADDR(x) (HW_CCM_CCGR21_ADDR(x) + 0xCU)

#define HW_CCM_CCGR21(x)         (*(__IO hw_ccm_ccgr21_t *) HW_CCM_CCGR21_ADDR(x))
#define HW_CCM_CCGR21_RD(x)      (HW_CCM_CCGR21(x).U)
#define HW_CCM_CCGR21_WR(x, v)   (HW_CCM_CCGR21(x).U = (v))
#define HW_CCM_CCGR21_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR21_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR21_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR21_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR21_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR21_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR21 bitfields
 */

/*!
 * @name Register CCM_CCGR21, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR21_SETTING0 (0U)        /*!< Bit position for CCM_CCGR21_SETTING0. */
#define BM_CCM_CCGR21_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR21_SETTING0. */
#define BS_CCM_CCGR21_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR21_SETTING0. */

/*! @brief Read current value of the CCM_CCGR21_SETTING0 field. */
#define BR_CCM_CCGR21_SETTING0(x) (HW_CCM_CCGR21(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR21_SETTING0. */
#define BF_CCM_CCGR21_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR21_SETTING0) & BM_CCM_CCGR21_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR21_SETTING0(x, v) (HW_CCM_CCGR21_WR(x, (HW_CCM_CCGR21_RD(x) & ~BM_CCM_CCGR21_SETTING0) | BF_CCM_CCGR21_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR21, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR21_SETTING1 (4U)        /*!< Bit position for CCM_CCGR21_SETTING1. */
#define BM_CCM_CCGR21_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR21_SETTING1. */
#define BS_CCM_CCGR21_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR21_SETTING1. */

/*! @brief Read current value of the CCM_CCGR21_SETTING1 field. */
#define BR_CCM_CCGR21_SETTING1(x) (HW_CCM_CCGR21(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR21_SETTING1. */
#define BF_CCM_CCGR21_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR21_SETTING1) & BM_CCM_CCGR21_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR21_SETTING1(x, v) (HW_CCM_CCGR21_WR(x, (HW_CCM_CCGR21_RD(x) & ~BM_CCM_CCGR21_SETTING1) | BF_CCM_CCGR21_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR21, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR21_SETTING2 (8U)        /*!< Bit position for CCM_CCGR21_SETTING2. */
#define BM_CCM_CCGR21_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR21_SETTING2. */
#define BS_CCM_CCGR21_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR21_SETTING2. */

/*! @brief Read current value of the CCM_CCGR21_SETTING2 field. */
#define BR_CCM_CCGR21_SETTING2(x) (HW_CCM_CCGR21(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR21_SETTING2. */
#define BF_CCM_CCGR21_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR21_SETTING2) & BM_CCM_CCGR21_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR21_SETTING2(x, v) (HW_CCM_CCGR21_WR(x, (HW_CCM_CCGR21_RD(x) & ~BM_CCM_CCGR21_SETTING2) | BF_CCM_CCGR21_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR21, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR21_SETTING3 (12U)       /*!< Bit position for CCM_CCGR21_SETTING3. */
#define BM_CCM_CCGR21_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR21_SETTING3. */
#define BS_CCM_CCGR21_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR21_SETTING3. */

/*! @brief Read current value of the CCM_CCGR21_SETTING3 field. */
#define BR_CCM_CCGR21_SETTING3(x) (HW_CCM_CCGR21(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR21_SETTING3. */
#define BF_CCM_CCGR21_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR21_SETTING3) & BM_CCM_CCGR21_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR21_SETTING3(x, v) (HW_CCM_CCGR21_WR(x, (HW_CCM_CCGR21_RD(x) & ~BM_CCM_CCGR21_SETTING3) | BF_CCM_CCGR21_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR22 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR22 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr22
{
    uint32_t U;
    struct _hw_ccm_ccgr22_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr22_t;

/*!
 * @name Constants and macros for entire CCM_CCGR22 register
 */
/*@{*/
#define HW_CCM_CCGR22_ADDR(x)    ((uintptr_t)(x) + 0x4160U)
#define HW_CCM_CCGR22_SET_ADDR(x) (HW_CCM_CCGR22_ADDR(x) + 0x4U)
#define HW_CCM_CCGR22_CLR_ADDR(x) (HW_CCM_CCGR22_ADDR(x) + 0x8U)
#define HW_CCM_CCGR22_TOG_ADDR(x) (HW_CCM_CCGR22_ADDR(x) + 0xCU)

#define HW_CCM_CCGR22(x)         (*(__IO hw_ccm_ccgr22_t *) HW_CCM_CCGR22_ADDR(x))
#define HW_CCM_CCGR22_RD(x)      (HW_CCM_CCGR22(x).U)
#define HW_CCM_CCGR22_WR(x, v)   (HW_CCM_CCGR22(x).U = (v))
#define HW_CCM_CCGR22_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR22_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR22_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR22_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR22_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR22_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR22 bitfields
 */

/*!
 * @name Register CCM_CCGR22, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR22_SETTING0 (0U)        /*!< Bit position for CCM_CCGR22_SETTING0. */
#define BM_CCM_CCGR22_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR22_SETTING0. */
#define BS_CCM_CCGR22_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR22_SETTING0. */

/*! @brief Read current value of the CCM_CCGR22_SETTING0 field. */
#define BR_CCM_CCGR22_SETTING0(x) (HW_CCM_CCGR22(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR22_SETTING0. */
#define BF_CCM_CCGR22_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR22_SETTING0) & BM_CCM_CCGR22_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR22_SETTING0(x, v) (HW_CCM_CCGR22_WR(x, (HW_CCM_CCGR22_RD(x) & ~BM_CCM_CCGR22_SETTING0) | BF_CCM_CCGR22_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR22, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR22_SETTING1 (4U)        /*!< Bit position for CCM_CCGR22_SETTING1. */
#define BM_CCM_CCGR22_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR22_SETTING1. */
#define BS_CCM_CCGR22_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR22_SETTING1. */

/*! @brief Read current value of the CCM_CCGR22_SETTING1 field. */
#define BR_CCM_CCGR22_SETTING1(x) (HW_CCM_CCGR22(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR22_SETTING1. */
#define BF_CCM_CCGR22_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR22_SETTING1) & BM_CCM_CCGR22_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR22_SETTING1(x, v) (HW_CCM_CCGR22_WR(x, (HW_CCM_CCGR22_RD(x) & ~BM_CCM_CCGR22_SETTING1) | BF_CCM_CCGR22_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR22, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR22_SETTING2 (8U)        /*!< Bit position for CCM_CCGR22_SETTING2. */
#define BM_CCM_CCGR22_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR22_SETTING2. */
#define BS_CCM_CCGR22_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR22_SETTING2. */

/*! @brief Read current value of the CCM_CCGR22_SETTING2 field. */
#define BR_CCM_CCGR22_SETTING2(x) (HW_CCM_CCGR22(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR22_SETTING2. */
#define BF_CCM_CCGR22_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR22_SETTING2) & BM_CCM_CCGR22_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR22_SETTING2(x, v) (HW_CCM_CCGR22_WR(x, (HW_CCM_CCGR22_RD(x) & ~BM_CCM_CCGR22_SETTING2) | BF_CCM_CCGR22_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR22, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR22_SETTING3 (12U)       /*!< Bit position for CCM_CCGR22_SETTING3. */
#define BM_CCM_CCGR22_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR22_SETTING3. */
#define BS_CCM_CCGR22_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR22_SETTING3. */

/*! @brief Read current value of the CCM_CCGR22_SETTING3 field. */
#define BR_CCM_CCGR22_SETTING3(x) (HW_CCM_CCGR22(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR22_SETTING3. */
#define BF_CCM_CCGR22_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR22_SETTING3) & BM_CCM_CCGR22_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR22_SETTING3(x, v) (HW_CCM_CCGR22_WR(x, (HW_CCM_CCGR22_RD(x) & ~BM_CCM_CCGR22_SETTING3) | BF_CCM_CCGR22_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR23 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR23 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr23
{
    uint32_t U;
    struct _hw_ccm_ccgr23_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr23_t;

/*!
 * @name Constants and macros for entire CCM_CCGR23 register
 */
/*@{*/
#define HW_CCM_CCGR23_ADDR(x)    ((uintptr_t)(x) + 0x4170U)
#define HW_CCM_CCGR23_SET_ADDR(x) (HW_CCM_CCGR23_ADDR(x) + 0x4U)
#define HW_CCM_CCGR23_CLR_ADDR(x) (HW_CCM_CCGR23_ADDR(x) + 0x8U)
#define HW_CCM_CCGR23_TOG_ADDR(x) (HW_CCM_CCGR23_ADDR(x) + 0xCU)

#define HW_CCM_CCGR23(x)         (*(__IO hw_ccm_ccgr23_t *) HW_CCM_CCGR23_ADDR(x))
#define HW_CCM_CCGR23_RD(x)      (HW_CCM_CCGR23(x).U)
#define HW_CCM_CCGR23_WR(x, v)   (HW_CCM_CCGR23(x).U = (v))
#define HW_CCM_CCGR23_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR23_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR23_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR23_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR23_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR23_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR23 bitfields
 */

/*!
 * @name Register CCM_CCGR23, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR23_SETTING0 (0U)        /*!< Bit position for CCM_CCGR23_SETTING0. */
#define BM_CCM_CCGR23_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR23_SETTING0. */
#define BS_CCM_CCGR23_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR23_SETTING0. */

/*! @brief Read current value of the CCM_CCGR23_SETTING0 field. */
#define BR_CCM_CCGR23_SETTING0(x) (HW_CCM_CCGR23(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR23_SETTING0. */
#define BF_CCM_CCGR23_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR23_SETTING0) & BM_CCM_CCGR23_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR23_SETTING0(x, v) (HW_CCM_CCGR23_WR(x, (HW_CCM_CCGR23_RD(x) & ~BM_CCM_CCGR23_SETTING0) | BF_CCM_CCGR23_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR23, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR23_SETTING1 (4U)        /*!< Bit position for CCM_CCGR23_SETTING1. */
#define BM_CCM_CCGR23_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR23_SETTING1. */
#define BS_CCM_CCGR23_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR23_SETTING1. */

/*! @brief Read current value of the CCM_CCGR23_SETTING1 field. */
#define BR_CCM_CCGR23_SETTING1(x) (HW_CCM_CCGR23(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR23_SETTING1. */
#define BF_CCM_CCGR23_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR23_SETTING1) & BM_CCM_CCGR23_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR23_SETTING1(x, v) (HW_CCM_CCGR23_WR(x, (HW_CCM_CCGR23_RD(x) & ~BM_CCM_CCGR23_SETTING1) | BF_CCM_CCGR23_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR23, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR23_SETTING2 (8U)        /*!< Bit position for CCM_CCGR23_SETTING2. */
#define BM_CCM_CCGR23_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR23_SETTING2. */
#define BS_CCM_CCGR23_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR23_SETTING2. */

/*! @brief Read current value of the CCM_CCGR23_SETTING2 field. */
#define BR_CCM_CCGR23_SETTING2(x) (HW_CCM_CCGR23(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR23_SETTING2. */
#define BF_CCM_CCGR23_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR23_SETTING2) & BM_CCM_CCGR23_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR23_SETTING2(x, v) (HW_CCM_CCGR23_WR(x, (HW_CCM_CCGR23_RD(x) & ~BM_CCM_CCGR23_SETTING2) | BF_CCM_CCGR23_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR23, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR23_SETTING3 (12U)       /*!< Bit position for CCM_CCGR23_SETTING3. */
#define BM_CCM_CCGR23_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR23_SETTING3. */
#define BS_CCM_CCGR23_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR23_SETTING3. */

/*! @brief Read current value of the CCM_CCGR23_SETTING3 field. */
#define BR_CCM_CCGR23_SETTING3(x) (HW_CCM_CCGR23(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR23_SETTING3. */
#define BF_CCM_CCGR23_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR23_SETTING3) & BM_CCM_CCGR23_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR23_SETTING3(x, v) (HW_CCM_CCGR23_WR(x, (HW_CCM_CCGR23_RD(x) & ~BM_CCM_CCGR23_SETTING3) | BF_CCM_CCGR23_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR24 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR24 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr24
{
    uint32_t U;
    struct _hw_ccm_ccgr24_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr24_t;

/*!
 * @name Constants and macros for entire CCM_CCGR24 register
 */
/*@{*/
#define HW_CCM_CCGR24_ADDR(x)    ((uintptr_t)(x) + 0x4180U)
#define HW_CCM_CCGR24_SET_ADDR(x) (HW_CCM_CCGR24_ADDR(x) + 0x4U)
#define HW_CCM_CCGR24_CLR_ADDR(x) (HW_CCM_CCGR24_ADDR(x) + 0x8U)
#define HW_CCM_CCGR24_TOG_ADDR(x) (HW_CCM_CCGR24_ADDR(x) + 0xCU)

#define HW_CCM_CCGR24(x)         (*(__IO hw_ccm_ccgr24_t *) HW_CCM_CCGR24_ADDR(x))
#define HW_CCM_CCGR24_RD(x)      (HW_CCM_CCGR24(x).U)
#define HW_CCM_CCGR24_WR(x, v)   (HW_CCM_CCGR24(x).U = (v))
#define HW_CCM_CCGR24_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR24_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR24_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR24_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR24_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR24_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR24 bitfields
 */

/*!
 * @name Register CCM_CCGR24, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR24_SETTING0 (0U)        /*!< Bit position for CCM_CCGR24_SETTING0. */
#define BM_CCM_CCGR24_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR24_SETTING0. */
#define BS_CCM_CCGR24_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR24_SETTING0. */

/*! @brief Read current value of the CCM_CCGR24_SETTING0 field. */
#define BR_CCM_CCGR24_SETTING0(x) (HW_CCM_CCGR24(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR24_SETTING0. */
#define BF_CCM_CCGR24_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR24_SETTING0) & BM_CCM_CCGR24_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR24_SETTING0(x, v) (HW_CCM_CCGR24_WR(x, (HW_CCM_CCGR24_RD(x) & ~BM_CCM_CCGR24_SETTING0) | BF_CCM_CCGR24_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR24, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR24_SETTING1 (4U)        /*!< Bit position for CCM_CCGR24_SETTING1. */
#define BM_CCM_CCGR24_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR24_SETTING1. */
#define BS_CCM_CCGR24_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR24_SETTING1. */

/*! @brief Read current value of the CCM_CCGR24_SETTING1 field. */
#define BR_CCM_CCGR24_SETTING1(x) (HW_CCM_CCGR24(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR24_SETTING1. */
#define BF_CCM_CCGR24_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR24_SETTING1) & BM_CCM_CCGR24_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR24_SETTING1(x, v) (HW_CCM_CCGR24_WR(x, (HW_CCM_CCGR24_RD(x) & ~BM_CCM_CCGR24_SETTING1) | BF_CCM_CCGR24_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR24, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR24_SETTING2 (8U)        /*!< Bit position for CCM_CCGR24_SETTING2. */
#define BM_CCM_CCGR24_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR24_SETTING2. */
#define BS_CCM_CCGR24_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR24_SETTING2. */

/*! @brief Read current value of the CCM_CCGR24_SETTING2 field. */
#define BR_CCM_CCGR24_SETTING2(x) (HW_CCM_CCGR24(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR24_SETTING2. */
#define BF_CCM_CCGR24_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR24_SETTING2) & BM_CCM_CCGR24_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR24_SETTING2(x, v) (HW_CCM_CCGR24_WR(x, (HW_CCM_CCGR24_RD(x) & ~BM_CCM_CCGR24_SETTING2) | BF_CCM_CCGR24_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR24, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR24_SETTING3 (12U)       /*!< Bit position for CCM_CCGR24_SETTING3. */
#define BM_CCM_CCGR24_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR24_SETTING3. */
#define BS_CCM_CCGR24_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR24_SETTING3. */

/*! @brief Read current value of the CCM_CCGR24_SETTING3 field. */
#define BR_CCM_CCGR24_SETTING3(x) (HW_CCM_CCGR24(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR24_SETTING3. */
#define BF_CCM_CCGR24_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR24_SETTING3) & BM_CCM_CCGR24_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR24_SETTING3(x, v) (HW_CCM_CCGR24_WR(x, (HW_CCM_CCGR24_RD(x) & ~BM_CCM_CCGR24_SETTING3) | BF_CCM_CCGR24_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR25 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR25 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr25
{
    uint32_t U;
    struct _hw_ccm_ccgr25_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr25_t;

/*!
 * @name Constants and macros for entire CCM_CCGR25 register
 */
/*@{*/
#define HW_CCM_CCGR25_ADDR(x)    ((uintptr_t)(x) + 0x4190U)
#define HW_CCM_CCGR25_SET_ADDR(x) (HW_CCM_CCGR25_ADDR(x) + 0x4U)
#define HW_CCM_CCGR25_CLR_ADDR(x) (HW_CCM_CCGR25_ADDR(x) + 0x8U)
#define HW_CCM_CCGR25_TOG_ADDR(x) (HW_CCM_CCGR25_ADDR(x) + 0xCU)

#define HW_CCM_CCGR25(x)         (*(__IO hw_ccm_ccgr25_t *) HW_CCM_CCGR25_ADDR(x))
#define HW_CCM_CCGR25_RD(x)      (HW_CCM_CCGR25(x).U)
#define HW_CCM_CCGR25_WR(x, v)   (HW_CCM_CCGR25(x).U = (v))
#define HW_CCM_CCGR25_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR25_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR25_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR25_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR25_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR25_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR25 bitfields
 */

/*!
 * @name Register CCM_CCGR25, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR25_SETTING0 (0U)        /*!< Bit position for CCM_CCGR25_SETTING0. */
#define BM_CCM_CCGR25_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR25_SETTING0. */
#define BS_CCM_CCGR25_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR25_SETTING0. */

/*! @brief Read current value of the CCM_CCGR25_SETTING0 field. */
#define BR_CCM_CCGR25_SETTING0(x) (HW_CCM_CCGR25(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR25_SETTING0. */
#define BF_CCM_CCGR25_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR25_SETTING0) & BM_CCM_CCGR25_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR25_SETTING0(x, v) (HW_CCM_CCGR25_WR(x, (HW_CCM_CCGR25_RD(x) & ~BM_CCM_CCGR25_SETTING0) | BF_CCM_CCGR25_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR25, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR25_SETTING1 (4U)        /*!< Bit position for CCM_CCGR25_SETTING1. */
#define BM_CCM_CCGR25_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR25_SETTING1. */
#define BS_CCM_CCGR25_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR25_SETTING1. */

/*! @brief Read current value of the CCM_CCGR25_SETTING1 field. */
#define BR_CCM_CCGR25_SETTING1(x) (HW_CCM_CCGR25(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR25_SETTING1. */
#define BF_CCM_CCGR25_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR25_SETTING1) & BM_CCM_CCGR25_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR25_SETTING1(x, v) (HW_CCM_CCGR25_WR(x, (HW_CCM_CCGR25_RD(x) & ~BM_CCM_CCGR25_SETTING1) | BF_CCM_CCGR25_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR25, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR25_SETTING2 (8U)        /*!< Bit position for CCM_CCGR25_SETTING2. */
#define BM_CCM_CCGR25_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR25_SETTING2. */
#define BS_CCM_CCGR25_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR25_SETTING2. */

/*! @brief Read current value of the CCM_CCGR25_SETTING2 field. */
#define BR_CCM_CCGR25_SETTING2(x) (HW_CCM_CCGR25(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR25_SETTING2. */
#define BF_CCM_CCGR25_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR25_SETTING2) & BM_CCM_CCGR25_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR25_SETTING2(x, v) (HW_CCM_CCGR25_WR(x, (HW_CCM_CCGR25_RD(x) & ~BM_CCM_CCGR25_SETTING2) | BF_CCM_CCGR25_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR25, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR25_SETTING3 (12U)       /*!< Bit position for CCM_CCGR25_SETTING3. */
#define BM_CCM_CCGR25_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR25_SETTING3. */
#define BS_CCM_CCGR25_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR25_SETTING3. */

/*! @brief Read current value of the CCM_CCGR25_SETTING3 field. */
#define BR_CCM_CCGR25_SETTING3(x) (HW_CCM_CCGR25(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR25_SETTING3. */
#define BF_CCM_CCGR25_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR25_SETTING3) & BM_CCM_CCGR25_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR25_SETTING3(x, v) (HW_CCM_CCGR25_WR(x, (HW_CCM_CCGR25_RD(x) & ~BM_CCM_CCGR25_SETTING3) | BF_CCM_CCGR25_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR26 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR26 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr26
{
    uint32_t U;
    struct _hw_ccm_ccgr26_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr26_t;

/*!
 * @name Constants and macros for entire CCM_CCGR26 register
 */
/*@{*/
#define HW_CCM_CCGR26_ADDR(x)    ((uintptr_t)(x) + 0x41A0U)
#define HW_CCM_CCGR26_SET_ADDR(x) (HW_CCM_CCGR26_ADDR(x) + 0x4U)
#define HW_CCM_CCGR26_CLR_ADDR(x) (HW_CCM_CCGR26_ADDR(x) + 0x8U)
#define HW_CCM_CCGR26_TOG_ADDR(x) (HW_CCM_CCGR26_ADDR(x) + 0xCU)

#define HW_CCM_CCGR26(x)         (*(__IO hw_ccm_ccgr26_t *) HW_CCM_CCGR26_ADDR(x))
#define HW_CCM_CCGR26_RD(x)      (HW_CCM_CCGR26(x).U)
#define HW_CCM_CCGR26_WR(x, v)   (HW_CCM_CCGR26(x).U = (v))
#define HW_CCM_CCGR26_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR26_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR26_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR26_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR26_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR26_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR26 bitfields
 */

/*!
 * @name Register CCM_CCGR26, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR26_SETTING0 (0U)        /*!< Bit position for CCM_CCGR26_SETTING0. */
#define BM_CCM_CCGR26_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR26_SETTING0. */
#define BS_CCM_CCGR26_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR26_SETTING0. */

/*! @brief Read current value of the CCM_CCGR26_SETTING0 field. */
#define BR_CCM_CCGR26_SETTING0(x) (HW_CCM_CCGR26(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR26_SETTING0. */
#define BF_CCM_CCGR26_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR26_SETTING0) & BM_CCM_CCGR26_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR26_SETTING0(x, v) (HW_CCM_CCGR26_WR(x, (HW_CCM_CCGR26_RD(x) & ~BM_CCM_CCGR26_SETTING0) | BF_CCM_CCGR26_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR26, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR26_SETTING1 (4U)        /*!< Bit position for CCM_CCGR26_SETTING1. */
#define BM_CCM_CCGR26_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR26_SETTING1. */
#define BS_CCM_CCGR26_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR26_SETTING1. */

/*! @brief Read current value of the CCM_CCGR26_SETTING1 field. */
#define BR_CCM_CCGR26_SETTING1(x) (HW_CCM_CCGR26(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR26_SETTING1. */
#define BF_CCM_CCGR26_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR26_SETTING1) & BM_CCM_CCGR26_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR26_SETTING1(x, v) (HW_CCM_CCGR26_WR(x, (HW_CCM_CCGR26_RD(x) & ~BM_CCM_CCGR26_SETTING1) | BF_CCM_CCGR26_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR26, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR26_SETTING2 (8U)        /*!< Bit position for CCM_CCGR26_SETTING2. */
#define BM_CCM_CCGR26_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR26_SETTING2. */
#define BS_CCM_CCGR26_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR26_SETTING2. */

/*! @brief Read current value of the CCM_CCGR26_SETTING2 field. */
#define BR_CCM_CCGR26_SETTING2(x) (HW_CCM_CCGR26(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR26_SETTING2. */
#define BF_CCM_CCGR26_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR26_SETTING2) & BM_CCM_CCGR26_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR26_SETTING2(x, v) (HW_CCM_CCGR26_WR(x, (HW_CCM_CCGR26_RD(x) & ~BM_CCM_CCGR26_SETTING2) | BF_CCM_CCGR26_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR26, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR26_SETTING3 (12U)       /*!< Bit position for CCM_CCGR26_SETTING3. */
#define BM_CCM_CCGR26_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR26_SETTING3. */
#define BS_CCM_CCGR26_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR26_SETTING3. */

/*! @brief Read current value of the CCM_CCGR26_SETTING3 field. */
#define BR_CCM_CCGR26_SETTING3(x) (HW_CCM_CCGR26(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR26_SETTING3. */
#define BF_CCM_CCGR26_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR26_SETTING3) & BM_CCM_CCGR26_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR26_SETTING3(x, v) (HW_CCM_CCGR26_WR(x, (HW_CCM_CCGR26_RD(x) & ~BM_CCM_CCGR26_SETTING3) | BF_CCM_CCGR26_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR27 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR27 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr27
{
    uint32_t U;
    struct _hw_ccm_ccgr27_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr27_t;

/*!
 * @name Constants and macros for entire CCM_CCGR27 register
 */
/*@{*/
#define HW_CCM_CCGR27_ADDR(x)    ((uintptr_t)(x) + 0x41B0U)
#define HW_CCM_CCGR27_SET_ADDR(x) (HW_CCM_CCGR27_ADDR(x) + 0x4U)
#define HW_CCM_CCGR27_CLR_ADDR(x) (HW_CCM_CCGR27_ADDR(x) + 0x8U)
#define HW_CCM_CCGR27_TOG_ADDR(x) (HW_CCM_CCGR27_ADDR(x) + 0xCU)

#define HW_CCM_CCGR27(x)         (*(__IO hw_ccm_ccgr27_t *) HW_CCM_CCGR27_ADDR(x))
#define HW_CCM_CCGR27_RD(x)      (HW_CCM_CCGR27(x).U)
#define HW_CCM_CCGR27_WR(x, v)   (HW_CCM_CCGR27(x).U = (v))
#define HW_CCM_CCGR27_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR27_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR27_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR27_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR27_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR27_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR27 bitfields
 */

/*!
 * @name Register CCM_CCGR27, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR27_SETTING0 (0U)        /*!< Bit position for CCM_CCGR27_SETTING0. */
#define BM_CCM_CCGR27_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR27_SETTING0. */
#define BS_CCM_CCGR27_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR27_SETTING0. */

/*! @brief Read current value of the CCM_CCGR27_SETTING0 field. */
#define BR_CCM_CCGR27_SETTING0(x) (HW_CCM_CCGR27(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR27_SETTING0. */
#define BF_CCM_CCGR27_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR27_SETTING0) & BM_CCM_CCGR27_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR27_SETTING0(x, v) (HW_CCM_CCGR27_WR(x, (HW_CCM_CCGR27_RD(x) & ~BM_CCM_CCGR27_SETTING0) | BF_CCM_CCGR27_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR27, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR27_SETTING1 (4U)        /*!< Bit position for CCM_CCGR27_SETTING1. */
#define BM_CCM_CCGR27_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR27_SETTING1. */
#define BS_CCM_CCGR27_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR27_SETTING1. */

/*! @brief Read current value of the CCM_CCGR27_SETTING1 field. */
#define BR_CCM_CCGR27_SETTING1(x) (HW_CCM_CCGR27(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR27_SETTING1. */
#define BF_CCM_CCGR27_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR27_SETTING1) & BM_CCM_CCGR27_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR27_SETTING1(x, v) (HW_CCM_CCGR27_WR(x, (HW_CCM_CCGR27_RD(x) & ~BM_CCM_CCGR27_SETTING1) | BF_CCM_CCGR27_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR27, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR27_SETTING2 (8U)        /*!< Bit position for CCM_CCGR27_SETTING2. */
#define BM_CCM_CCGR27_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR27_SETTING2. */
#define BS_CCM_CCGR27_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR27_SETTING2. */

/*! @brief Read current value of the CCM_CCGR27_SETTING2 field. */
#define BR_CCM_CCGR27_SETTING2(x) (HW_CCM_CCGR27(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR27_SETTING2. */
#define BF_CCM_CCGR27_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR27_SETTING2) & BM_CCM_CCGR27_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR27_SETTING2(x, v) (HW_CCM_CCGR27_WR(x, (HW_CCM_CCGR27_RD(x) & ~BM_CCM_CCGR27_SETTING2) | BF_CCM_CCGR27_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR27, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR27_SETTING3 (12U)       /*!< Bit position for CCM_CCGR27_SETTING3. */
#define BM_CCM_CCGR27_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR27_SETTING3. */
#define BS_CCM_CCGR27_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR27_SETTING3. */

/*! @brief Read current value of the CCM_CCGR27_SETTING3 field. */
#define BR_CCM_CCGR27_SETTING3(x) (HW_CCM_CCGR27(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR27_SETTING3. */
#define BF_CCM_CCGR27_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR27_SETTING3) & BM_CCM_CCGR27_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR27_SETTING3(x, v) (HW_CCM_CCGR27_WR(x, (HW_CCM_CCGR27_RD(x) & ~BM_CCM_CCGR27_SETTING3) | BF_CCM_CCGR27_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR28 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR28 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr28
{
    uint32_t U;
    struct _hw_ccm_ccgr28_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr28_t;

/*!
 * @name Constants and macros for entire CCM_CCGR28 register
 */
/*@{*/
#define HW_CCM_CCGR28_ADDR(x)    ((uintptr_t)(x) + 0x41C0U)
#define HW_CCM_CCGR28_SET_ADDR(x) (HW_CCM_CCGR28_ADDR(x) + 0x4U)
#define HW_CCM_CCGR28_CLR_ADDR(x) (HW_CCM_CCGR28_ADDR(x) + 0x8U)
#define HW_CCM_CCGR28_TOG_ADDR(x) (HW_CCM_CCGR28_ADDR(x) + 0xCU)

#define HW_CCM_CCGR28(x)         (*(__IO hw_ccm_ccgr28_t *) HW_CCM_CCGR28_ADDR(x))
#define HW_CCM_CCGR28_RD(x)      (HW_CCM_CCGR28(x).U)
#define HW_CCM_CCGR28_WR(x, v)   (HW_CCM_CCGR28(x).U = (v))
#define HW_CCM_CCGR28_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR28_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR28_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR28_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR28_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR28_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR28 bitfields
 */

/*!
 * @name Register CCM_CCGR28, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR28_SETTING0 (0U)        /*!< Bit position for CCM_CCGR28_SETTING0. */
#define BM_CCM_CCGR28_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR28_SETTING0. */
#define BS_CCM_CCGR28_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR28_SETTING0. */

/*! @brief Read current value of the CCM_CCGR28_SETTING0 field. */
#define BR_CCM_CCGR28_SETTING0(x) (HW_CCM_CCGR28(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR28_SETTING0. */
#define BF_CCM_CCGR28_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR28_SETTING0) & BM_CCM_CCGR28_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR28_SETTING0(x, v) (HW_CCM_CCGR28_WR(x, (HW_CCM_CCGR28_RD(x) & ~BM_CCM_CCGR28_SETTING0) | BF_CCM_CCGR28_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR28, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR28_SETTING1 (4U)        /*!< Bit position for CCM_CCGR28_SETTING1. */
#define BM_CCM_CCGR28_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR28_SETTING1. */
#define BS_CCM_CCGR28_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR28_SETTING1. */

/*! @brief Read current value of the CCM_CCGR28_SETTING1 field. */
#define BR_CCM_CCGR28_SETTING1(x) (HW_CCM_CCGR28(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR28_SETTING1. */
#define BF_CCM_CCGR28_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR28_SETTING1) & BM_CCM_CCGR28_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR28_SETTING1(x, v) (HW_CCM_CCGR28_WR(x, (HW_CCM_CCGR28_RD(x) & ~BM_CCM_CCGR28_SETTING1) | BF_CCM_CCGR28_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR28, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR28_SETTING2 (8U)        /*!< Bit position for CCM_CCGR28_SETTING2. */
#define BM_CCM_CCGR28_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR28_SETTING2. */
#define BS_CCM_CCGR28_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR28_SETTING2. */

/*! @brief Read current value of the CCM_CCGR28_SETTING2 field. */
#define BR_CCM_CCGR28_SETTING2(x) (HW_CCM_CCGR28(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR28_SETTING2. */
#define BF_CCM_CCGR28_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR28_SETTING2) & BM_CCM_CCGR28_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR28_SETTING2(x, v) (HW_CCM_CCGR28_WR(x, (HW_CCM_CCGR28_RD(x) & ~BM_CCM_CCGR28_SETTING2) | BF_CCM_CCGR28_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR28, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR28_SETTING3 (12U)       /*!< Bit position for CCM_CCGR28_SETTING3. */
#define BM_CCM_CCGR28_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR28_SETTING3. */
#define BS_CCM_CCGR28_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR28_SETTING3. */

/*! @brief Read current value of the CCM_CCGR28_SETTING3 field. */
#define BR_CCM_CCGR28_SETTING3(x) (HW_CCM_CCGR28(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR28_SETTING3. */
#define BF_CCM_CCGR28_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR28_SETTING3) & BM_CCM_CCGR28_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR28_SETTING3(x, v) (HW_CCM_CCGR28_WR(x, (HW_CCM_CCGR28_RD(x) & ~BM_CCM_CCGR28_SETTING3) | BF_CCM_CCGR28_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR29 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR29 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr29
{
    uint32_t U;
    struct _hw_ccm_ccgr29_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr29_t;

/*!
 * @name Constants and macros for entire CCM_CCGR29 register
 */
/*@{*/
#define HW_CCM_CCGR29_ADDR(x)    ((uintptr_t)(x) + 0x41D0U)
#define HW_CCM_CCGR29_SET_ADDR(x) (HW_CCM_CCGR29_ADDR(x) + 0x4U)
#define HW_CCM_CCGR29_CLR_ADDR(x) (HW_CCM_CCGR29_ADDR(x) + 0x8U)
#define HW_CCM_CCGR29_TOG_ADDR(x) (HW_CCM_CCGR29_ADDR(x) + 0xCU)

#define HW_CCM_CCGR29(x)         (*(__IO hw_ccm_ccgr29_t *) HW_CCM_CCGR29_ADDR(x))
#define HW_CCM_CCGR29_RD(x)      (HW_CCM_CCGR29(x).U)
#define HW_CCM_CCGR29_WR(x, v)   (HW_CCM_CCGR29(x).U = (v))
#define HW_CCM_CCGR29_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR29_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR29_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR29_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR29_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR29_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR29 bitfields
 */

/*!
 * @name Register CCM_CCGR29, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR29_SETTING0 (0U)        /*!< Bit position for CCM_CCGR29_SETTING0. */
#define BM_CCM_CCGR29_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR29_SETTING0. */
#define BS_CCM_CCGR29_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR29_SETTING0. */

/*! @brief Read current value of the CCM_CCGR29_SETTING0 field. */
#define BR_CCM_CCGR29_SETTING0(x) (HW_CCM_CCGR29(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR29_SETTING0. */
#define BF_CCM_CCGR29_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR29_SETTING0) & BM_CCM_CCGR29_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR29_SETTING0(x, v) (HW_CCM_CCGR29_WR(x, (HW_CCM_CCGR29_RD(x) & ~BM_CCM_CCGR29_SETTING0) | BF_CCM_CCGR29_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR29, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR29_SETTING1 (4U)        /*!< Bit position for CCM_CCGR29_SETTING1. */
#define BM_CCM_CCGR29_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR29_SETTING1. */
#define BS_CCM_CCGR29_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR29_SETTING1. */

/*! @brief Read current value of the CCM_CCGR29_SETTING1 field. */
#define BR_CCM_CCGR29_SETTING1(x) (HW_CCM_CCGR29(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR29_SETTING1. */
#define BF_CCM_CCGR29_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR29_SETTING1) & BM_CCM_CCGR29_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR29_SETTING1(x, v) (HW_CCM_CCGR29_WR(x, (HW_CCM_CCGR29_RD(x) & ~BM_CCM_CCGR29_SETTING1) | BF_CCM_CCGR29_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR29, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR29_SETTING2 (8U)        /*!< Bit position for CCM_CCGR29_SETTING2. */
#define BM_CCM_CCGR29_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR29_SETTING2. */
#define BS_CCM_CCGR29_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR29_SETTING2. */

/*! @brief Read current value of the CCM_CCGR29_SETTING2 field. */
#define BR_CCM_CCGR29_SETTING2(x) (HW_CCM_CCGR29(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR29_SETTING2. */
#define BF_CCM_CCGR29_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR29_SETTING2) & BM_CCM_CCGR29_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR29_SETTING2(x, v) (HW_CCM_CCGR29_WR(x, (HW_CCM_CCGR29_RD(x) & ~BM_CCM_CCGR29_SETTING2) | BF_CCM_CCGR29_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR29, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR29_SETTING3 (12U)       /*!< Bit position for CCM_CCGR29_SETTING3. */
#define BM_CCM_CCGR29_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR29_SETTING3. */
#define BS_CCM_CCGR29_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR29_SETTING3. */

/*! @brief Read current value of the CCM_CCGR29_SETTING3 field. */
#define BR_CCM_CCGR29_SETTING3(x) (HW_CCM_CCGR29(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR29_SETTING3. */
#define BF_CCM_CCGR29_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR29_SETTING3) & BM_CCM_CCGR29_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR29_SETTING3(x, v) (HW_CCM_CCGR29_WR(x, (HW_CCM_CCGR29_RD(x) & ~BM_CCM_CCGR29_SETTING3) | BF_CCM_CCGR29_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR30 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR30 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr30
{
    uint32_t U;
    struct _hw_ccm_ccgr30_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr30_t;

/*!
 * @name Constants and macros for entire CCM_CCGR30 register
 */
/*@{*/
#define HW_CCM_CCGR30_ADDR(x)    ((uintptr_t)(x) + 0x41E0U)
#define HW_CCM_CCGR30_SET_ADDR(x) (HW_CCM_CCGR30_ADDR(x) + 0x4U)
#define HW_CCM_CCGR30_CLR_ADDR(x) (HW_CCM_CCGR30_ADDR(x) + 0x8U)
#define HW_CCM_CCGR30_TOG_ADDR(x) (HW_CCM_CCGR30_ADDR(x) + 0xCU)

#define HW_CCM_CCGR30(x)         (*(__IO hw_ccm_ccgr30_t *) HW_CCM_CCGR30_ADDR(x))
#define HW_CCM_CCGR30_RD(x)      (HW_CCM_CCGR30(x).U)
#define HW_CCM_CCGR30_WR(x, v)   (HW_CCM_CCGR30(x).U = (v))
#define HW_CCM_CCGR30_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR30_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR30_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR30_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR30_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR30_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR30 bitfields
 */

/*!
 * @name Register CCM_CCGR30, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR30_SETTING0 (0U)        /*!< Bit position for CCM_CCGR30_SETTING0. */
#define BM_CCM_CCGR30_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR30_SETTING0. */
#define BS_CCM_CCGR30_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR30_SETTING0. */

/*! @brief Read current value of the CCM_CCGR30_SETTING0 field. */
#define BR_CCM_CCGR30_SETTING0(x) (HW_CCM_CCGR30(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR30_SETTING0. */
#define BF_CCM_CCGR30_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR30_SETTING0) & BM_CCM_CCGR30_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR30_SETTING0(x, v) (HW_CCM_CCGR30_WR(x, (HW_CCM_CCGR30_RD(x) & ~BM_CCM_CCGR30_SETTING0) | BF_CCM_CCGR30_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR30, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR30_SETTING1 (4U)        /*!< Bit position for CCM_CCGR30_SETTING1. */
#define BM_CCM_CCGR30_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR30_SETTING1. */
#define BS_CCM_CCGR30_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR30_SETTING1. */

/*! @brief Read current value of the CCM_CCGR30_SETTING1 field. */
#define BR_CCM_CCGR30_SETTING1(x) (HW_CCM_CCGR30(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR30_SETTING1. */
#define BF_CCM_CCGR30_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR30_SETTING1) & BM_CCM_CCGR30_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR30_SETTING1(x, v) (HW_CCM_CCGR30_WR(x, (HW_CCM_CCGR30_RD(x) & ~BM_CCM_CCGR30_SETTING1) | BF_CCM_CCGR30_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR30, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR30_SETTING2 (8U)        /*!< Bit position for CCM_CCGR30_SETTING2. */
#define BM_CCM_CCGR30_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR30_SETTING2. */
#define BS_CCM_CCGR30_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR30_SETTING2. */

/*! @brief Read current value of the CCM_CCGR30_SETTING2 field. */
#define BR_CCM_CCGR30_SETTING2(x) (HW_CCM_CCGR30(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR30_SETTING2. */
#define BF_CCM_CCGR30_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR30_SETTING2) & BM_CCM_CCGR30_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR30_SETTING2(x, v) (HW_CCM_CCGR30_WR(x, (HW_CCM_CCGR30_RD(x) & ~BM_CCM_CCGR30_SETTING2) | BF_CCM_CCGR30_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR30, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR30_SETTING3 (12U)       /*!< Bit position for CCM_CCGR30_SETTING3. */
#define BM_CCM_CCGR30_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR30_SETTING3. */
#define BS_CCM_CCGR30_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR30_SETTING3. */

/*! @brief Read current value of the CCM_CCGR30_SETTING3 field. */
#define BR_CCM_CCGR30_SETTING3(x) (HW_CCM_CCGR30(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR30_SETTING3. */
#define BF_CCM_CCGR30_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR30_SETTING3) & BM_CCM_CCGR30_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR30_SETTING3(x, v) (HW_CCM_CCGR30_WR(x, (HW_CCM_CCGR30_RD(x) & ~BM_CCM_CCGR30_SETTING3) | BF_CCM_CCGR30_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR31 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR31 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr31
{
    uint32_t U;
    struct _hw_ccm_ccgr31_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr31_t;

/*!
 * @name Constants and macros for entire CCM_CCGR31 register
 */
/*@{*/
#define HW_CCM_CCGR31_ADDR(x)    ((uintptr_t)(x) + 0x41F0U)
#define HW_CCM_CCGR31_SET_ADDR(x) (HW_CCM_CCGR31_ADDR(x) + 0x4U)
#define HW_CCM_CCGR31_CLR_ADDR(x) (HW_CCM_CCGR31_ADDR(x) + 0x8U)
#define HW_CCM_CCGR31_TOG_ADDR(x) (HW_CCM_CCGR31_ADDR(x) + 0xCU)

#define HW_CCM_CCGR31(x)         (*(__IO hw_ccm_ccgr31_t *) HW_CCM_CCGR31_ADDR(x))
#define HW_CCM_CCGR31_RD(x)      (HW_CCM_CCGR31(x).U)
#define HW_CCM_CCGR31_WR(x, v)   (HW_CCM_CCGR31(x).U = (v))
#define HW_CCM_CCGR31_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR31_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR31_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR31_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR31_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR31_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR31 bitfields
 */

/*!
 * @name Register CCM_CCGR31, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR31_SETTING0 (0U)        /*!< Bit position for CCM_CCGR31_SETTING0. */
#define BM_CCM_CCGR31_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR31_SETTING0. */
#define BS_CCM_CCGR31_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR31_SETTING0. */

/*! @brief Read current value of the CCM_CCGR31_SETTING0 field. */
#define BR_CCM_CCGR31_SETTING0(x) (HW_CCM_CCGR31(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR31_SETTING0. */
#define BF_CCM_CCGR31_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR31_SETTING0) & BM_CCM_CCGR31_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR31_SETTING0(x, v) (HW_CCM_CCGR31_WR(x, (HW_CCM_CCGR31_RD(x) & ~BM_CCM_CCGR31_SETTING0) | BF_CCM_CCGR31_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR31, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR31_SETTING1 (4U)        /*!< Bit position for CCM_CCGR31_SETTING1. */
#define BM_CCM_CCGR31_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR31_SETTING1. */
#define BS_CCM_CCGR31_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR31_SETTING1. */

/*! @brief Read current value of the CCM_CCGR31_SETTING1 field. */
#define BR_CCM_CCGR31_SETTING1(x) (HW_CCM_CCGR31(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR31_SETTING1. */
#define BF_CCM_CCGR31_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR31_SETTING1) & BM_CCM_CCGR31_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR31_SETTING1(x, v) (HW_CCM_CCGR31_WR(x, (HW_CCM_CCGR31_RD(x) & ~BM_CCM_CCGR31_SETTING1) | BF_CCM_CCGR31_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR31, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR31_SETTING2 (8U)        /*!< Bit position for CCM_CCGR31_SETTING2. */
#define BM_CCM_CCGR31_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR31_SETTING2. */
#define BS_CCM_CCGR31_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR31_SETTING2. */

/*! @brief Read current value of the CCM_CCGR31_SETTING2 field. */
#define BR_CCM_CCGR31_SETTING2(x) (HW_CCM_CCGR31(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR31_SETTING2. */
#define BF_CCM_CCGR31_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR31_SETTING2) & BM_CCM_CCGR31_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR31_SETTING2(x, v) (HW_CCM_CCGR31_WR(x, (HW_CCM_CCGR31_RD(x) & ~BM_CCM_CCGR31_SETTING2) | BF_CCM_CCGR31_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR31, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR31_SETTING3 (12U)       /*!< Bit position for CCM_CCGR31_SETTING3. */
#define BM_CCM_CCGR31_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR31_SETTING3. */
#define BS_CCM_CCGR31_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR31_SETTING3. */

/*! @brief Read current value of the CCM_CCGR31_SETTING3 field. */
#define BR_CCM_CCGR31_SETTING3(x) (HW_CCM_CCGR31(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR31_SETTING3. */
#define BF_CCM_CCGR31_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR31_SETTING3) & BM_CCM_CCGR31_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR31_SETTING3(x, v) (HW_CCM_CCGR31_WR(x, (HW_CCM_CCGR31_RD(x) & ~BM_CCM_CCGR31_SETTING3) | BF_CCM_CCGR31_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR32 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR32 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr32
{
    uint32_t U;
    struct _hw_ccm_ccgr32_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr32_t;

/*!
 * @name Constants and macros for entire CCM_CCGR32 register
 */
/*@{*/
#define HW_CCM_CCGR32_ADDR(x)    ((uintptr_t)(x) + 0x4200U)
#define HW_CCM_CCGR32_SET_ADDR(x) (HW_CCM_CCGR32_ADDR(x) + 0x4U)
#define HW_CCM_CCGR32_CLR_ADDR(x) (HW_CCM_CCGR32_ADDR(x) + 0x8U)
#define HW_CCM_CCGR32_TOG_ADDR(x) (HW_CCM_CCGR32_ADDR(x) + 0xCU)

#define HW_CCM_CCGR32(x)         (*(__IO hw_ccm_ccgr32_t *) HW_CCM_CCGR32_ADDR(x))
#define HW_CCM_CCGR32_RD(x)      (HW_CCM_CCGR32(x).U)
#define HW_CCM_CCGR32_WR(x, v)   (HW_CCM_CCGR32(x).U = (v))
#define HW_CCM_CCGR32_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR32_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR32_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR32_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR32_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR32_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR32 bitfields
 */

/*!
 * @name Register CCM_CCGR32, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR32_SETTING0 (0U)        /*!< Bit position for CCM_CCGR32_SETTING0. */
#define BM_CCM_CCGR32_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR32_SETTING0. */
#define BS_CCM_CCGR32_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR32_SETTING0. */

/*! @brief Read current value of the CCM_CCGR32_SETTING0 field. */
#define BR_CCM_CCGR32_SETTING0(x) (HW_CCM_CCGR32(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR32_SETTING0. */
#define BF_CCM_CCGR32_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR32_SETTING0) & BM_CCM_CCGR32_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR32_SETTING0(x, v) (HW_CCM_CCGR32_WR(x, (HW_CCM_CCGR32_RD(x) & ~BM_CCM_CCGR32_SETTING0) | BF_CCM_CCGR32_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR32, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR32_SETTING1 (4U)        /*!< Bit position for CCM_CCGR32_SETTING1. */
#define BM_CCM_CCGR32_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR32_SETTING1. */
#define BS_CCM_CCGR32_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR32_SETTING1. */

/*! @brief Read current value of the CCM_CCGR32_SETTING1 field. */
#define BR_CCM_CCGR32_SETTING1(x) (HW_CCM_CCGR32(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR32_SETTING1. */
#define BF_CCM_CCGR32_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR32_SETTING1) & BM_CCM_CCGR32_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR32_SETTING1(x, v) (HW_CCM_CCGR32_WR(x, (HW_CCM_CCGR32_RD(x) & ~BM_CCM_CCGR32_SETTING1) | BF_CCM_CCGR32_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR32, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR32_SETTING2 (8U)        /*!< Bit position for CCM_CCGR32_SETTING2. */
#define BM_CCM_CCGR32_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR32_SETTING2. */
#define BS_CCM_CCGR32_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR32_SETTING2. */

/*! @brief Read current value of the CCM_CCGR32_SETTING2 field. */
#define BR_CCM_CCGR32_SETTING2(x) (HW_CCM_CCGR32(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR32_SETTING2. */
#define BF_CCM_CCGR32_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR32_SETTING2) & BM_CCM_CCGR32_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR32_SETTING2(x, v) (HW_CCM_CCGR32_WR(x, (HW_CCM_CCGR32_RD(x) & ~BM_CCM_CCGR32_SETTING2) | BF_CCM_CCGR32_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR32, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR32_SETTING3 (12U)       /*!< Bit position for CCM_CCGR32_SETTING3. */
#define BM_CCM_CCGR32_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR32_SETTING3. */
#define BS_CCM_CCGR32_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR32_SETTING3. */

/*! @brief Read current value of the CCM_CCGR32_SETTING3 field. */
#define BR_CCM_CCGR32_SETTING3(x) (HW_CCM_CCGR32(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR32_SETTING3. */
#define BF_CCM_CCGR32_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR32_SETTING3) & BM_CCM_CCGR32_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR32_SETTING3(x, v) (HW_CCM_CCGR32_WR(x, (HW_CCM_CCGR32_RD(x) & ~BM_CCM_CCGR32_SETTING3) | BF_CCM_CCGR32_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR33 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR33 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr33
{
    uint32_t U;
    struct _hw_ccm_ccgr33_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr33_t;

/*!
 * @name Constants and macros for entire CCM_CCGR33 register
 */
/*@{*/
#define HW_CCM_CCGR33_ADDR(x)    ((uintptr_t)(x) + 0x4210U)
#define HW_CCM_CCGR33_SET_ADDR(x) (HW_CCM_CCGR33_ADDR(x) + 0x4U)
#define HW_CCM_CCGR33_CLR_ADDR(x) (HW_CCM_CCGR33_ADDR(x) + 0x8U)
#define HW_CCM_CCGR33_TOG_ADDR(x) (HW_CCM_CCGR33_ADDR(x) + 0xCU)

#define HW_CCM_CCGR33(x)         (*(__IO hw_ccm_ccgr33_t *) HW_CCM_CCGR33_ADDR(x))
#define HW_CCM_CCGR33_RD(x)      (HW_CCM_CCGR33(x).U)
#define HW_CCM_CCGR33_WR(x, v)   (HW_CCM_CCGR33(x).U = (v))
#define HW_CCM_CCGR33_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR33_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR33_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR33_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR33_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR33_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR33 bitfields
 */

/*!
 * @name Register CCM_CCGR33, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR33_SETTING0 (0U)        /*!< Bit position for CCM_CCGR33_SETTING0. */
#define BM_CCM_CCGR33_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR33_SETTING0. */
#define BS_CCM_CCGR33_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR33_SETTING0. */

/*! @brief Read current value of the CCM_CCGR33_SETTING0 field. */
#define BR_CCM_CCGR33_SETTING0(x) (HW_CCM_CCGR33(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR33_SETTING0. */
#define BF_CCM_CCGR33_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR33_SETTING0) & BM_CCM_CCGR33_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR33_SETTING0(x, v) (HW_CCM_CCGR33_WR(x, (HW_CCM_CCGR33_RD(x) & ~BM_CCM_CCGR33_SETTING0) | BF_CCM_CCGR33_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR33, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR33_SETTING1 (4U)        /*!< Bit position for CCM_CCGR33_SETTING1. */
#define BM_CCM_CCGR33_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR33_SETTING1. */
#define BS_CCM_CCGR33_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR33_SETTING1. */

/*! @brief Read current value of the CCM_CCGR33_SETTING1 field. */
#define BR_CCM_CCGR33_SETTING1(x) (HW_CCM_CCGR33(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR33_SETTING1. */
#define BF_CCM_CCGR33_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR33_SETTING1) & BM_CCM_CCGR33_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR33_SETTING1(x, v) (HW_CCM_CCGR33_WR(x, (HW_CCM_CCGR33_RD(x) & ~BM_CCM_CCGR33_SETTING1) | BF_CCM_CCGR33_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR33, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR33_SETTING2 (8U)        /*!< Bit position for CCM_CCGR33_SETTING2. */
#define BM_CCM_CCGR33_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR33_SETTING2. */
#define BS_CCM_CCGR33_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR33_SETTING2. */

/*! @brief Read current value of the CCM_CCGR33_SETTING2 field. */
#define BR_CCM_CCGR33_SETTING2(x) (HW_CCM_CCGR33(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR33_SETTING2. */
#define BF_CCM_CCGR33_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR33_SETTING2) & BM_CCM_CCGR33_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR33_SETTING2(x, v) (HW_CCM_CCGR33_WR(x, (HW_CCM_CCGR33_RD(x) & ~BM_CCM_CCGR33_SETTING2) | BF_CCM_CCGR33_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR33, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR33_SETTING3 (12U)       /*!< Bit position for CCM_CCGR33_SETTING3. */
#define BM_CCM_CCGR33_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR33_SETTING3. */
#define BS_CCM_CCGR33_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR33_SETTING3. */

/*! @brief Read current value of the CCM_CCGR33_SETTING3 field. */
#define BR_CCM_CCGR33_SETTING3(x) (HW_CCM_CCGR33(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR33_SETTING3. */
#define BF_CCM_CCGR33_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR33_SETTING3) & BM_CCM_CCGR33_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR33_SETTING3(x, v) (HW_CCM_CCGR33_WR(x, (HW_CCM_CCGR33_RD(x) & ~BM_CCM_CCGR33_SETTING3) | BF_CCM_CCGR33_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR34 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR34 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr34
{
    uint32_t U;
    struct _hw_ccm_ccgr34_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr34_t;

/*!
 * @name Constants and macros for entire CCM_CCGR34 register
 */
/*@{*/
#define HW_CCM_CCGR34_ADDR(x)    ((uintptr_t)(x) + 0x4220U)
#define HW_CCM_CCGR34_SET_ADDR(x) (HW_CCM_CCGR34_ADDR(x) + 0x4U)
#define HW_CCM_CCGR34_CLR_ADDR(x) (HW_CCM_CCGR34_ADDR(x) + 0x8U)
#define HW_CCM_CCGR34_TOG_ADDR(x) (HW_CCM_CCGR34_ADDR(x) + 0xCU)

#define HW_CCM_CCGR34(x)         (*(__IO hw_ccm_ccgr34_t *) HW_CCM_CCGR34_ADDR(x))
#define HW_CCM_CCGR34_RD(x)      (HW_CCM_CCGR34(x).U)
#define HW_CCM_CCGR34_WR(x, v)   (HW_CCM_CCGR34(x).U = (v))
#define HW_CCM_CCGR34_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR34_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR34_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR34_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR34_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR34_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR34 bitfields
 */

/*!
 * @name Register CCM_CCGR34, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR34_SETTING0 (0U)        /*!< Bit position for CCM_CCGR34_SETTING0. */
#define BM_CCM_CCGR34_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR34_SETTING0. */
#define BS_CCM_CCGR34_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR34_SETTING0. */

/*! @brief Read current value of the CCM_CCGR34_SETTING0 field. */
#define BR_CCM_CCGR34_SETTING0(x) (HW_CCM_CCGR34(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR34_SETTING0. */
#define BF_CCM_CCGR34_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR34_SETTING0) & BM_CCM_CCGR34_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR34_SETTING0(x, v) (HW_CCM_CCGR34_WR(x, (HW_CCM_CCGR34_RD(x) & ~BM_CCM_CCGR34_SETTING0) | BF_CCM_CCGR34_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR34, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR34_SETTING1 (4U)        /*!< Bit position for CCM_CCGR34_SETTING1. */
#define BM_CCM_CCGR34_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR34_SETTING1. */
#define BS_CCM_CCGR34_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR34_SETTING1. */

/*! @brief Read current value of the CCM_CCGR34_SETTING1 field. */
#define BR_CCM_CCGR34_SETTING1(x) (HW_CCM_CCGR34(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR34_SETTING1. */
#define BF_CCM_CCGR34_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR34_SETTING1) & BM_CCM_CCGR34_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR34_SETTING1(x, v) (HW_CCM_CCGR34_WR(x, (HW_CCM_CCGR34_RD(x) & ~BM_CCM_CCGR34_SETTING1) | BF_CCM_CCGR34_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR34, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR34_SETTING2 (8U)        /*!< Bit position for CCM_CCGR34_SETTING2. */
#define BM_CCM_CCGR34_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR34_SETTING2. */
#define BS_CCM_CCGR34_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR34_SETTING2. */

/*! @brief Read current value of the CCM_CCGR34_SETTING2 field. */
#define BR_CCM_CCGR34_SETTING2(x) (HW_CCM_CCGR34(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR34_SETTING2. */
#define BF_CCM_CCGR34_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR34_SETTING2) & BM_CCM_CCGR34_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR34_SETTING2(x, v) (HW_CCM_CCGR34_WR(x, (HW_CCM_CCGR34_RD(x) & ~BM_CCM_CCGR34_SETTING2) | BF_CCM_CCGR34_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR34, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR34_SETTING3 (12U)       /*!< Bit position for CCM_CCGR34_SETTING3. */
#define BM_CCM_CCGR34_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR34_SETTING3. */
#define BS_CCM_CCGR34_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR34_SETTING3. */

/*! @brief Read current value of the CCM_CCGR34_SETTING3 field. */
#define BR_CCM_CCGR34_SETTING3(x) (HW_CCM_CCGR34(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR34_SETTING3. */
#define BF_CCM_CCGR34_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR34_SETTING3) & BM_CCM_CCGR34_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR34_SETTING3(x, v) (HW_CCM_CCGR34_WR(x, (HW_CCM_CCGR34_RD(x) & ~BM_CCM_CCGR34_SETTING3) | BF_CCM_CCGR34_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR35 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR35 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr35
{
    uint32_t U;
    struct _hw_ccm_ccgr35_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr35_t;

/*!
 * @name Constants and macros for entire CCM_CCGR35 register
 */
/*@{*/
#define HW_CCM_CCGR35_ADDR(x)    ((uintptr_t)(x) + 0x4230U)
#define HW_CCM_CCGR35_SET_ADDR(x) (HW_CCM_CCGR35_ADDR(x) + 0x4U)
#define HW_CCM_CCGR35_CLR_ADDR(x) (HW_CCM_CCGR35_ADDR(x) + 0x8U)
#define HW_CCM_CCGR35_TOG_ADDR(x) (HW_CCM_CCGR35_ADDR(x) + 0xCU)

#define HW_CCM_CCGR35(x)         (*(__IO hw_ccm_ccgr35_t *) HW_CCM_CCGR35_ADDR(x))
#define HW_CCM_CCGR35_RD(x)      (HW_CCM_CCGR35(x).U)
#define HW_CCM_CCGR35_WR(x, v)   (HW_CCM_CCGR35(x).U = (v))
#define HW_CCM_CCGR35_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR35_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR35_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR35_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR35_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR35_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR35 bitfields
 */

/*!
 * @name Register CCM_CCGR35, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR35_SETTING0 (0U)        /*!< Bit position for CCM_CCGR35_SETTING0. */
#define BM_CCM_CCGR35_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR35_SETTING0. */
#define BS_CCM_CCGR35_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR35_SETTING0. */

/*! @brief Read current value of the CCM_CCGR35_SETTING0 field. */
#define BR_CCM_CCGR35_SETTING0(x) (HW_CCM_CCGR35(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR35_SETTING0. */
#define BF_CCM_CCGR35_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR35_SETTING0) & BM_CCM_CCGR35_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR35_SETTING0(x, v) (HW_CCM_CCGR35_WR(x, (HW_CCM_CCGR35_RD(x) & ~BM_CCM_CCGR35_SETTING0) | BF_CCM_CCGR35_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR35, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR35_SETTING1 (4U)        /*!< Bit position for CCM_CCGR35_SETTING1. */
#define BM_CCM_CCGR35_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR35_SETTING1. */
#define BS_CCM_CCGR35_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR35_SETTING1. */

/*! @brief Read current value of the CCM_CCGR35_SETTING1 field. */
#define BR_CCM_CCGR35_SETTING1(x) (HW_CCM_CCGR35(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR35_SETTING1. */
#define BF_CCM_CCGR35_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR35_SETTING1) & BM_CCM_CCGR35_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR35_SETTING1(x, v) (HW_CCM_CCGR35_WR(x, (HW_CCM_CCGR35_RD(x) & ~BM_CCM_CCGR35_SETTING1) | BF_CCM_CCGR35_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR35, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR35_SETTING2 (8U)        /*!< Bit position for CCM_CCGR35_SETTING2. */
#define BM_CCM_CCGR35_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR35_SETTING2. */
#define BS_CCM_CCGR35_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR35_SETTING2. */

/*! @brief Read current value of the CCM_CCGR35_SETTING2 field. */
#define BR_CCM_CCGR35_SETTING2(x) (HW_CCM_CCGR35(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR35_SETTING2. */
#define BF_CCM_CCGR35_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR35_SETTING2) & BM_CCM_CCGR35_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR35_SETTING2(x, v) (HW_CCM_CCGR35_WR(x, (HW_CCM_CCGR35_RD(x) & ~BM_CCM_CCGR35_SETTING2) | BF_CCM_CCGR35_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR35, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR35_SETTING3 (12U)       /*!< Bit position for CCM_CCGR35_SETTING3. */
#define BM_CCM_CCGR35_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR35_SETTING3. */
#define BS_CCM_CCGR35_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR35_SETTING3. */

/*! @brief Read current value of the CCM_CCGR35_SETTING3 field. */
#define BR_CCM_CCGR35_SETTING3(x) (HW_CCM_CCGR35(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR35_SETTING3. */
#define BF_CCM_CCGR35_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR35_SETTING3) & BM_CCM_CCGR35_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR35_SETTING3(x, v) (HW_CCM_CCGR35_WR(x, (HW_CCM_CCGR35_RD(x) & ~BM_CCM_CCGR35_SETTING3) | BF_CCM_CCGR35_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR36 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR36 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr36
{
    uint32_t U;
    struct _hw_ccm_ccgr36_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr36_t;

/*!
 * @name Constants and macros for entire CCM_CCGR36 register
 */
/*@{*/
#define HW_CCM_CCGR36_ADDR(x)    ((uintptr_t)(x) + 0x4240U)
#define HW_CCM_CCGR36_SET_ADDR(x) (HW_CCM_CCGR36_ADDR(x) + 0x4U)
#define HW_CCM_CCGR36_CLR_ADDR(x) (HW_CCM_CCGR36_ADDR(x) + 0x8U)
#define HW_CCM_CCGR36_TOG_ADDR(x) (HW_CCM_CCGR36_ADDR(x) + 0xCU)

#define HW_CCM_CCGR36(x)         (*(__IO hw_ccm_ccgr36_t *) HW_CCM_CCGR36_ADDR(x))
#define HW_CCM_CCGR36_RD(x)      (HW_CCM_CCGR36(x).U)
#define HW_CCM_CCGR36_WR(x, v)   (HW_CCM_CCGR36(x).U = (v))
#define HW_CCM_CCGR36_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR36_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR36_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR36_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR36_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR36_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR36 bitfields
 */

/*!
 * @name Register CCM_CCGR36, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR36_SETTING0 (0U)        /*!< Bit position for CCM_CCGR36_SETTING0. */
#define BM_CCM_CCGR36_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR36_SETTING0. */
#define BS_CCM_CCGR36_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR36_SETTING0. */

/*! @brief Read current value of the CCM_CCGR36_SETTING0 field. */
#define BR_CCM_CCGR36_SETTING0(x) (HW_CCM_CCGR36(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR36_SETTING0. */
#define BF_CCM_CCGR36_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR36_SETTING0) & BM_CCM_CCGR36_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR36_SETTING0(x, v) (HW_CCM_CCGR36_WR(x, (HW_CCM_CCGR36_RD(x) & ~BM_CCM_CCGR36_SETTING0) | BF_CCM_CCGR36_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR36, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR36_SETTING1 (4U)        /*!< Bit position for CCM_CCGR36_SETTING1. */
#define BM_CCM_CCGR36_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR36_SETTING1. */
#define BS_CCM_CCGR36_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR36_SETTING1. */

/*! @brief Read current value of the CCM_CCGR36_SETTING1 field. */
#define BR_CCM_CCGR36_SETTING1(x) (HW_CCM_CCGR36(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR36_SETTING1. */
#define BF_CCM_CCGR36_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR36_SETTING1) & BM_CCM_CCGR36_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR36_SETTING1(x, v) (HW_CCM_CCGR36_WR(x, (HW_CCM_CCGR36_RD(x) & ~BM_CCM_CCGR36_SETTING1) | BF_CCM_CCGR36_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR36, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR36_SETTING2 (8U)        /*!< Bit position for CCM_CCGR36_SETTING2. */
#define BM_CCM_CCGR36_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR36_SETTING2. */
#define BS_CCM_CCGR36_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR36_SETTING2. */

/*! @brief Read current value of the CCM_CCGR36_SETTING2 field. */
#define BR_CCM_CCGR36_SETTING2(x) (HW_CCM_CCGR36(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR36_SETTING2. */
#define BF_CCM_CCGR36_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR36_SETTING2) & BM_CCM_CCGR36_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR36_SETTING2(x, v) (HW_CCM_CCGR36_WR(x, (HW_CCM_CCGR36_RD(x) & ~BM_CCM_CCGR36_SETTING2) | BF_CCM_CCGR36_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR36, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR36_SETTING3 (12U)       /*!< Bit position for CCM_CCGR36_SETTING3. */
#define BM_CCM_CCGR36_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR36_SETTING3. */
#define BS_CCM_CCGR36_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR36_SETTING3. */

/*! @brief Read current value of the CCM_CCGR36_SETTING3 field. */
#define BR_CCM_CCGR36_SETTING3(x) (HW_CCM_CCGR36(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR36_SETTING3. */
#define BF_CCM_CCGR36_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR36_SETTING3) & BM_CCM_CCGR36_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR36_SETTING3(x, v) (HW_CCM_CCGR36_WR(x, (HW_CCM_CCGR36_RD(x) & ~BM_CCM_CCGR36_SETTING3) | BF_CCM_CCGR36_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR37 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR37 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr37
{
    uint32_t U;
    struct _hw_ccm_ccgr37_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr37_t;

/*!
 * @name Constants and macros for entire CCM_CCGR37 register
 */
/*@{*/
#define HW_CCM_CCGR37_ADDR(x)    ((uintptr_t)(x) + 0x4250U)
#define HW_CCM_CCGR37_SET_ADDR(x) (HW_CCM_CCGR37_ADDR(x) + 0x4U)
#define HW_CCM_CCGR37_CLR_ADDR(x) (HW_CCM_CCGR37_ADDR(x) + 0x8U)
#define HW_CCM_CCGR37_TOG_ADDR(x) (HW_CCM_CCGR37_ADDR(x) + 0xCU)

#define HW_CCM_CCGR37(x)         (*(__IO hw_ccm_ccgr37_t *) HW_CCM_CCGR37_ADDR(x))
#define HW_CCM_CCGR37_RD(x)      (HW_CCM_CCGR37(x).U)
#define HW_CCM_CCGR37_WR(x, v)   (HW_CCM_CCGR37(x).U = (v))
#define HW_CCM_CCGR37_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR37_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR37_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR37_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR37_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR37_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR37 bitfields
 */

/*!
 * @name Register CCM_CCGR37, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR37_SETTING0 (0U)        /*!< Bit position for CCM_CCGR37_SETTING0. */
#define BM_CCM_CCGR37_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR37_SETTING0. */
#define BS_CCM_CCGR37_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR37_SETTING0. */

/*! @brief Read current value of the CCM_CCGR37_SETTING0 field. */
#define BR_CCM_CCGR37_SETTING0(x) (HW_CCM_CCGR37(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR37_SETTING0. */
#define BF_CCM_CCGR37_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR37_SETTING0) & BM_CCM_CCGR37_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR37_SETTING0(x, v) (HW_CCM_CCGR37_WR(x, (HW_CCM_CCGR37_RD(x) & ~BM_CCM_CCGR37_SETTING0) | BF_CCM_CCGR37_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR37, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR37_SETTING1 (4U)        /*!< Bit position for CCM_CCGR37_SETTING1. */
#define BM_CCM_CCGR37_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR37_SETTING1. */
#define BS_CCM_CCGR37_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR37_SETTING1. */

/*! @brief Read current value of the CCM_CCGR37_SETTING1 field. */
#define BR_CCM_CCGR37_SETTING1(x) (HW_CCM_CCGR37(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR37_SETTING1. */
#define BF_CCM_CCGR37_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR37_SETTING1) & BM_CCM_CCGR37_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR37_SETTING1(x, v) (HW_CCM_CCGR37_WR(x, (HW_CCM_CCGR37_RD(x) & ~BM_CCM_CCGR37_SETTING1) | BF_CCM_CCGR37_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR37, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR37_SETTING2 (8U)        /*!< Bit position for CCM_CCGR37_SETTING2. */
#define BM_CCM_CCGR37_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR37_SETTING2. */
#define BS_CCM_CCGR37_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR37_SETTING2. */

/*! @brief Read current value of the CCM_CCGR37_SETTING2 field. */
#define BR_CCM_CCGR37_SETTING2(x) (HW_CCM_CCGR37(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR37_SETTING2. */
#define BF_CCM_CCGR37_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR37_SETTING2) & BM_CCM_CCGR37_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR37_SETTING2(x, v) (HW_CCM_CCGR37_WR(x, (HW_CCM_CCGR37_RD(x) & ~BM_CCM_CCGR37_SETTING2) | BF_CCM_CCGR37_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR37, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR37_SETTING3 (12U)       /*!< Bit position for CCM_CCGR37_SETTING3. */
#define BM_CCM_CCGR37_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR37_SETTING3. */
#define BS_CCM_CCGR37_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR37_SETTING3. */

/*! @brief Read current value of the CCM_CCGR37_SETTING3 field. */
#define BR_CCM_CCGR37_SETTING3(x) (HW_CCM_CCGR37(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR37_SETTING3. */
#define BF_CCM_CCGR37_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR37_SETTING3) & BM_CCM_CCGR37_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR37_SETTING3(x, v) (HW_CCM_CCGR37_WR(x, (HW_CCM_CCGR37_RD(x) & ~BM_CCM_CCGR37_SETTING3) | BF_CCM_CCGR37_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR38 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR38 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr38
{
    uint32_t U;
    struct _hw_ccm_ccgr38_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr38_t;

/*!
 * @name Constants and macros for entire CCM_CCGR38 register
 */
/*@{*/
#define HW_CCM_CCGR38_ADDR(x)    ((uintptr_t)(x) + 0x4260U)
#define HW_CCM_CCGR38_SET_ADDR(x) (HW_CCM_CCGR38_ADDR(x) + 0x4U)
#define HW_CCM_CCGR38_CLR_ADDR(x) (HW_CCM_CCGR38_ADDR(x) + 0x8U)
#define HW_CCM_CCGR38_TOG_ADDR(x) (HW_CCM_CCGR38_ADDR(x) + 0xCU)

#define HW_CCM_CCGR38(x)         (*(__IO hw_ccm_ccgr38_t *) HW_CCM_CCGR38_ADDR(x))
#define HW_CCM_CCGR38_RD(x)      (HW_CCM_CCGR38(x).U)
#define HW_CCM_CCGR38_WR(x, v)   (HW_CCM_CCGR38(x).U = (v))
#define HW_CCM_CCGR38_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR38_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR38_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR38_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR38_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR38_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR38 bitfields
 */

/*!
 * @name Register CCM_CCGR38, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR38_SETTING0 (0U)        /*!< Bit position for CCM_CCGR38_SETTING0. */
#define BM_CCM_CCGR38_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR38_SETTING0. */
#define BS_CCM_CCGR38_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR38_SETTING0. */

/*! @brief Read current value of the CCM_CCGR38_SETTING0 field. */
#define BR_CCM_CCGR38_SETTING0(x) (HW_CCM_CCGR38(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR38_SETTING0. */
#define BF_CCM_CCGR38_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR38_SETTING0) & BM_CCM_CCGR38_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR38_SETTING0(x, v) (HW_CCM_CCGR38_WR(x, (HW_CCM_CCGR38_RD(x) & ~BM_CCM_CCGR38_SETTING0) | BF_CCM_CCGR38_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR38, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR38_SETTING1 (4U)        /*!< Bit position for CCM_CCGR38_SETTING1. */
#define BM_CCM_CCGR38_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR38_SETTING1. */
#define BS_CCM_CCGR38_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR38_SETTING1. */

/*! @brief Read current value of the CCM_CCGR38_SETTING1 field. */
#define BR_CCM_CCGR38_SETTING1(x) (HW_CCM_CCGR38(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR38_SETTING1. */
#define BF_CCM_CCGR38_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR38_SETTING1) & BM_CCM_CCGR38_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR38_SETTING1(x, v) (HW_CCM_CCGR38_WR(x, (HW_CCM_CCGR38_RD(x) & ~BM_CCM_CCGR38_SETTING1) | BF_CCM_CCGR38_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR38, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR38_SETTING2 (8U)        /*!< Bit position for CCM_CCGR38_SETTING2. */
#define BM_CCM_CCGR38_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR38_SETTING2. */
#define BS_CCM_CCGR38_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR38_SETTING2. */

/*! @brief Read current value of the CCM_CCGR38_SETTING2 field. */
#define BR_CCM_CCGR38_SETTING2(x) (HW_CCM_CCGR38(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR38_SETTING2. */
#define BF_CCM_CCGR38_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR38_SETTING2) & BM_CCM_CCGR38_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR38_SETTING2(x, v) (HW_CCM_CCGR38_WR(x, (HW_CCM_CCGR38_RD(x) & ~BM_CCM_CCGR38_SETTING2) | BF_CCM_CCGR38_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR38, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR38_SETTING3 (12U)       /*!< Bit position for CCM_CCGR38_SETTING3. */
#define BM_CCM_CCGR38_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR38_SETTING3. */
#define BS_CCM_CCGR38_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR38_SETTING3. */

/*! @brief Read current value of the CCM_CCGR38_SETTING3 field. */
#define BR_CCM_CCGR38_SETTING3(x) (HW_CCM_CCGR38(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR38_SETTING3. */
#define BF_CCM_CCGR38_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR38_SETTING3) & BM_CCM_CCGR38_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR38_SETTING3(x, v) (HW_CCM_CCGR38_WR(x, (HW_CCM_CCGR38_RD(x) & ~BM_CCM_CCGR38_SETTING3) | BF_CCM_CCGR38_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR39 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR39 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr39
{
    uint32_t U;
    struct _hw_ccm_ccgr39_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr39_t;

/*!
 * @name Constants and macros for entire CCM_CCGR39 register
 */
/*@{*/
#define HW_CCM_CCGR39_ADDR(x)    ((uintptr_t)(x) + 0x4270U)
#define HW_CCM_CCGR39_SET_ADDR(x) (HW_CCM_CCGR39_ADDR(x) + 0x4U)
#define HW_CCM_CCGR39_CLR_ADDR(x) (HW_CCM_CCGR39_ADDR(x) + 0x8U)
#define HW_CCM_CCGR39_TOG_ADDR(x) (HW_CCM_CCGR39_ADDR(x) + 0xCU)

#define HW_CCM_CCGR39(x)         (*(__IO hw_ccm_ccgr39_t *) HW_CCM_CCGR39_ADDR(x))
#define HW_CCM_CCGR39_RD(x)      (HW_CCM_CCGR39(x).U)
#define HW_CCM_CCGR39_WR(x, v)   (HW_CCM_CCGR39(x).U = (v))
#define HW_CCM_CCGR39_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR39_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR39_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR39_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR39_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR39_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR39 bitfields
 */

/*!
 * @name Register CCM_CCGR39, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR39_SETTING0 (0U)        /*!< Bit position for CCM_CCGR39_SETTING0. */
#define BM_CCM_CCGR39_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR39_SETTING0. */
#define BS_CCM_CCGR39_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR39_SETTING0. */

/*! @brief Read current value of the CCM_CCGR39_SETTING0 field. */
#define BR_CCM_CCGR39_SETTING0(x) (HW_CCM_CCGR39(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR39_SETTING0. */
#define BF_CCM_CCGR39_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR39_SETTING0) & BM_CCM_CCGR39_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR39_SETTING0(x, v) (HW_CCM_CCGR39_WR(x, (HW_CCM_CCGR39_RD(x) & ~BM_CCM_CCGR39_SETTING0) | BF_CCM_CCGR39_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR39, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR39_SETTING1 (4U)        /*!< Bit position for CCM_CCGR39_SETTING1. */
#define BM_CCM_CCGR39_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR39_SETTING1. */
#define BS_CCM_CCGR39_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR39_SETTING1. */

/*! @brief Read current value of the CCM_CCGR39_SETTING1 field. */
#define BR_CCM_CCGR39_SETTING1(x) (HW_CCM_CCGR39(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR39_SETTING1. */
#define BF_CCM_CCGR39_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR39_SETTING1) & BM_CCM_CCGR39_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR39_SETTING1(x, v) (HW_CCM_CCGR39_WR(x, (HW_CCM_CCGR39_RD(x) & ~BM_CCM_CCGR39_SETTING1) | BF_CCM_CCGR39_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR39, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR39_SETTING2 (8U)        /*!< Bit position for CCM_CCGR39_SETTING2. */
#define BM_CCM_CCGR39_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR39_SETTING2. */
#define BS_CCM_CCGR39_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR39_SETTING2. */

/*! @brief Read current value of the CCM_CCGR39_SETTING2 field. */
#define BR_CCM_CCGR39_SETTING2(x) (HW_CCM_CCGR39(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR39_SETTING2. */
#define BF_CCM_CCGR39_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR39_SETTING2) & BM_CCM_CCGR39_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR39_SETTING2(x, v) (HW_CCM_CCGR39_WR(x, (HW_CCM_CCGR39_RD(x) & ~BM_CCM_CCGR39_SETTING2) | BF_CCM_CCGR39_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR39, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR39_SETTING3 (12U)       /*!< Bit position for CCM_CCGR39_SETTING3. */
#define BM_CCM_CCGR39_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR39_SETTING3. */
#define BS_CCM_CCGR39_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR39_SETTING3. */

/*! @brief Read current value of the CCM_CCGR39_SETTING3 field. */
#define BR_CCM_CCGR39_SETTING3(x) (HW_CCM_CCGR39(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR39_SETTING3. */
#define BF_CCM_CCGR39_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR39_SETTING3) & BM_CCM_CCGR39_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR39_SETTING3(x, v) (HW_CCM_CCGR39_WR(x, (HW_CCM_CCGR39_RD(x) & ~BM_CCM_CCGR39_SETTING3) | BF_CCM_CCGR39_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR40 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR40 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr40
{
    uint32_t U;
    struct _hw_ccm_ccgr40_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr40_t;

/*!
 * @name Constants and macros for entire CCM_CCGR40 register
 */
/*@{*/
#define HW_CCM_CCGR40_ADDR(x)    ((uintptr_t)(x) + 0x4280U)
#define HW_CCM_CCGR40_SET_ADDR(x) (HW_CCM_CCGR40_ADDR(x) + 0x4U)
#define HW_CCM_CCGR40_CLR_ADDR(x) (HW_CCM_CCGR40_ADDR(x) + 0x8U)
#define HW_CCM_CCGR40_TOG_ADDR(x) (HW_CCM_CCGR40_ADDR(x) + 0xCU)

#define HW_CCM_CCGR40(x)         (*(__IO hw_ccm_ccgr40_t *) HW_CCM_CCGR40_ADDR(x))
#define HW_CCM_CCGR40_RD(x)      (HW_CCM_CCGR40(x).U)
#define HW_CCM_CCGR40_WR(x, v)   (HW_CCM_CCGR40(x).U = (v))
#define HW_CCM_CCGR40_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR40_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR40_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR40_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR40_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR40_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR40 bitfields
 */

/*!
 * @name Register CCM_CCGR40, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR40_SETTING0 (0U)        /*!< Bit position for CCM_CCGR40_SETTING0. */
#define BM_CCM_CCGR40_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR40_SETTING0. */
#define BS_CCM_CCGR40_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR40_SETTING0. */

/*! @brief Read current value of the CCM_CCGR40_SETTING0 field. */
#define BR_CCM_CCGR40_SETTING0(x) (HW_CCM_CCGR40(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR40_SETTING0. */
#define BF_CCM_CCGR40_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR40_SETTING0) & BM_CCM_CCGR40_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR40_SETTING0(x, v) (HW_CCM_CCGR40_WR(x, (HW_CCM_CCGR40_RD(x) & ~BM_CCM_CCGR40_SETTING0) | BF_CCM_CCGR40_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR40, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR40_SETTING1 (4U)        /*!< Bit position for CCM_CCGR40_SETTING1. */
#define BM_CCM_CCGR40_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR40_SETTING1. */
#define BS_CCM_CCGR40_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR40_SETTING1. */

/*! @brief Read current value of the CCM_CCGR40_SETTING1 field. */
#define BR_CCM_CCGR40_SETTING1(x) (HW_CCM_CCGR40(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR40_SETTING1. */
#define BF_CCM_CCGR40_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR40_SETTING1) & BM_CCM_CCGR40_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR40_SETTING1(x, v) (HW_CCM_CCGR40_WR(x, (HW_CCM_CCGR40_RD(x) & ~BM_CCM_CCGR40_SETTING1) | BF_CCM_CCGR40_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR40, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR40_SETTING2 (8U)        /*!< Bit position for CCM_CCGR40_SETTING2. */
#define BM_CCM_CCGR40_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR40_SETTING2. */
#define BS_CCM_CCGR40_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR40_SETTING2. */

/*! @brief Read current value of the CCM_CCGR40_SETTING2 field. */
#define BR_CCM_CCGR40_SETTING2(x) (HW_CCM_CCGR40(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR40_SETTING2. */
#define BF_CCM_CCGR40_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR40_SETTING2) & BM_CCM_CCGR40_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR40_SETTING2(x, v) (HW_CCM_CCGR40_WR(x, (HW_CCM_CCGR40_RD(x) & ~BM_CCM_CCGR40_SETTING2) | BF_CCM_CCGR40_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR40, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR40_SETTING3 (12U)       /*!< Bit position for CCM_CCGR40_SETTING3. */
#define BM_CCM_CCGR40_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR40_SETTING3. */
#define BS_CCM_CCGR40_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR40_SETTING3. */

/*! @brief Read current value of the CCM_CCGR40_SETTING3 field. */
#define BR_CCM_CCGR40_SETTING3(x) (HW_CCM_CCGR40(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR40_SETTING3. */
#define BF_CCM_CCGR40_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR40_SETTING3) & BM_CCM_CCGR40_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR40_SETTING3(x, v) (HW_CCM_CCGR40_WR(x, (HW_CCM_CCGR40_RD(x) & ~BM_CCM_CCGR40_SETTING3) | BF_CCM_CCGR40_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR41 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR41 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr41
{
    uint32_t U;
    struct _hw_ccm_ccgr41_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr41_t;

/*!
 * @name Constants and macros for entire CCM_CCGR41 register
 */
/*@{*/
#define HW_CCM_CCGR41_ADDR(x)    ((uintptr_t)(x) + 0x4290U)
#define HW_CCM_CCGR41_SET_ADDR(x) (HW_CCM_CCGR41_ADDR(x) + 0x4U)
#define HW_CCM_CCGR41_CLR_ADDR(x) (HW_CCM_CCGR41_ADDR(x) + 0x8U)
#define HW_CCM_CCGR41_TOG_ADDR(x) (HW_CCM_CCGR41_ADDR(x) + 0xCU)

#define HW_CCM_CCGR41(x)         (*(__IO hw_ccm_ccgr41_t *) HW_CCM_CCGR41_ADDR(x))
#define HW_CCM_CCGR41_RD(x)      (HW_CCM_CCGR41(x).U)
#define HW_CCM_CCGR41_WR(x, v)   (HW_CCM_CCGR41(x).U = (v))
#define HW_CCM_CCGR41_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR41_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR41_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR41_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR41_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR41_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR41 bitfields
 */

/*!
 * @name Register CCM_CCGR41, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR41_SETTING0 (0U)        /*!< Bit position for CCM_CCGR41_SETTING0. */
#define BM_CCM_CCGR41_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR41_SETTING0. */
#define BS_CCM_CCGR41_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR41_SETTING0. */

/*! @brief Read current value of the CCM_CCGR41_SETTING0 field. */
#define BR_CCM_CCGR41_SETTING0(x) (HW_CCM_CCGR41(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR41_SETTING0. */
#define BF_CCM_CCGR41_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR41_SETTING0) & BM_CCM_CCGR41_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR41_SETTING0(x, v) (HW_CCM_CCGR41_WR(x, (HW_CCM_CCGR41_RD(x) & ~BM_CCM_CCGR41_SETTING0) | BF_CCM_CCGR41_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR41, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR41_SETTING1 (4U)        /*!< Bit position for CCM_CCGR41_SETTING1. */
#define BM_CCM_CCGR41_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR41_SETTING1. */
#define BS_CCM_CCGR41_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR41_SETTING1. */

/*! @brief Read current value of the CCM_CCGR41_SETTING1 field. */
#define BR_CCM_CCGR41_SETTING1(x) (HW_CCM_CCGR41(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR41_SETTING1. */
#define BF_CCM_CCGR41_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR41_SETTING1) & BM_CCM_CCGR41_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR41_SETTING1(x, v) (HW_CCM_CCGR41_WR(x, (HW_CCM_CCGR41_RD(x) & ~BM_CCM_CCGR41_SETTING1) | BF_CCM_CCGR41_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR41, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR41_SETTING2 (8U)        /*!< Bit position for CCM_CCGR41_SETTING2. */
#define BM_CCM_CCGR41_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR41_SETTING2. */
#define BS_CCM_CCGR41_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR41_SETTING2. */

/*! @brief Read current value of the CCM_CCGR41_SETTING2 field. */
#define BR_CCM_CCGR41_SETTING2(x) (HW_CCM_CCGR41(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR41_SETTING2. */
#define BF_CCM_CCGR41_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR41_SETTING2) & BM_CCM_CCGR41_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR41_SETTING2(x, v) (HW_CCM_CCGR41_WR(x, (HW_CCM_CCGR41_RD(x) & ~BM_CCM_CCGR41_SETTING2) | BF_CCM_CCGR41_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR41, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR41_SETTING3 (12U)       /*!< Bit position for CCM_CCGR41_SETTING3. */
#define BM_CCM_CCGR41_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR41_SETTING3. */
#define BS_CCM_CCGR41_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR41_SETTING3. */

/*! @brief Read current value of the CCM_CCGR41_SETTING3 field. */
#define BR_CCM_CCGR41_SETTING3(x) (HW_CCM_CCGR41(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR41_SETTING3. */
#define BF_CCM_CCGR41_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR41_SETTING3) & BM_CCM_CCGR41_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR41_SETTING3(x, v) (HW_CCM_CCGR41_WR(x, (HW_CCM_CCGR41_RD(x) & ~BM_CCM_CCGR41_SETTING3) | BF_CCM_CCGR41_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR42 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR42 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr42
{
    uint32_t U;
    struct _hw_ccm_ccgr42_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr42_t;

/*!
 * @name Constants and macros for entire CCM_CCGR42 register
 */
/*@{*/
#define HW_CCM_CCGR42_ADDR(x)    ((uintptr_t)(x) + 0x42A0U)
#define HW_CCM_CCGR42_SET_ADDR(x) (HW_CCM_CCGR42_ADDR(x) + 0x4U)
#define HW_CCM_CCGR42_CLR_ADDR(x) (HW_CCM_CCGR42_ADDR(x) + 0x8U)
#define HW_CCM_CCGR42_TOG_ADDR(x) (HW_CCM_CCGR42_ADDR(x) + 0xCU)

#define HW_CCM_CCGR42(x)         (*(__IO hw_ccm_ccgr42_t *) HW_CCM_CCGR42_ADDR(x))
#define HW_CCM_CCGR42_RD(x)      (HW_CCM_CCGR42(x).U)
#define HW_CCM_CCGR42_WR(x, v)   (HW_CCM_CCGR42(x).U = (v))
#define HW_CCM_CCGR42_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR42_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR42_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR42_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR42_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR42_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR42 bitfields
 */

/*!
 * @name Register CCM_CCGR42, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR42_SETTING0 (0U)        /*!< Bit position for CCM_CCGR42_SETTING0. */
#define BM_CCM_CCGR42_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR42_SETTING0. */
#define BS_CCM_CCGR42_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR42_SETTING0. */

/*! @brief Read current value of the CCM_CCGR42_SETTING0 field. */
#define BR_CCM_CCGR42_SETTING0(x) (HW_CCM_CCGR42(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR42_SETTING0. */
#define BF_CCM_CCGR42_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR42_SETTING0) & BM_CCM_CCGR42_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR42_SETTING0(x, v) (HW_CCM_CCGR42_WR(x, (HW_CCM_CCGR42_RD(x) & ~BM_CCM_CCGR42_SETTING0) | BF_CCM_CCGR42_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR42, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR42_SETTING1 (4U)        /*!< Bit position for CCM_CCGR42_SETTING1. */
#define BM_CCM_CCGR42_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR42_SETTING1. */
#define BS_CCM_CCGR42_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR42_SETTING1. */

/*! @brief Read current value of the CCM_CCGR42_SETTING1 field. */
#define BR_CCM_CCGR42_SETTING1(x) (HW_CCM_CCGR42(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR42_SETTING1. */
#define BF_CCM_CCGR42_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR42_SETTING1) & BM_CCM_CCGR42_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR42_SETTING1(x, v) (HW_CCM_CCGR42_WR(x, (HW_CCM_CCGR42_RD(x) & ~BM_CCM_CCGR42_SETTING1) | BF_CCM_CCGR42_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR42, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR42_SETTING2 (8U)        /*!< Bit position for CCM_CCGR42_SETTING2. */
#define BM_CCM_CCGR42_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR42_SETTING2. */
#define BS_CCM_CCGR42_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR42_SETTING2. */

/*! @brief Read current value of the CCM_CCGR42_SETTING2 field. */
#define BR_CCM_CCGR42_SETTING2(x) (HW_CCM_CCGR42(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR42_SETTING2. */
#define BF_CCM_CCGR42_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR42_SETTING2) & BM_CCM_CCGR42_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR42_SETTING2(x, v) (HW_CCM_CCGR42_WR(x, (HW_CCM_CCGR42_RD(x) & ~BM_CCM_CCGR42_SETTING2) | BF_CCM_CCGR42_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR42, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR42_SETTING3 (12U)       /*!< Bit position for CCM_CCGR42_SETTING3. */
#define BM_CCM_CCGR42_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR42_SETTING3. */
#define BS_CCM_CCGR42_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR42_SETTING3. */

/*! @brief Read current value of the CCM_CCGR42_SETTING3 field. */
#define BR_CCM_CCGR42_SETTING3(x) (HW_CCM_CCGR42(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR42_SETTING3. */
#define BF_CCM_CCGR42_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR42_SETTING3) & BM_CCM_CCGR42_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR42_SETTING3(x, v) (HW_CCM_CCGR42_WR(x, (HW_CCM_CCGR42_RD(x) & ~BM_CCM_CCGR42_SETTING3) | BF_CCM_CCGR42_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR43 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR43 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr43
{
    uint32_t U;
    struct _hw_ccm_ccgr43_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr43_t;

/*!
 * @name Constants and macros for entire CCM_CCGR43 register
 */
/*@{*/
#define HW_CCM_CCGR43_ADDR(x)    ((uintptr_t)(x) + 0x42B0U)
#define HW_CCM_CCGR43_SET_ADDR(x) (HW_CCM_CCGR43_ADDR(x) + 0x4U)
#define HW_CCM_CCGR43_CLR_ADDR(x) (HW_CCM_CCGR43_ADDR(x) + 0x8U)
#define HW_CCM_CCGR43_TOG_ADDR(x) (HW_CCM_CCGR43_ADDR(x) + 0xCU)

#define HW_CCM_CCGR43(x)         (*(__IO hw_ccm_ccgr43_t *) HW_CCM_CCGR43_ADDR(x))
#define HW_CCM_CCGR43_RD(x)      (HW_CCM_CCGR43(x).U)
#define HW_CCM_CCGR43_WR(x, v)   (HW_CCM_CCGR43(x).U = (v))
#define HW_CCM_CCGR43_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR43_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR43_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR43_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR43_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR43_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR43 bitfields
 */

/*!
 * @name Register CCM_CCGR43, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR43_SETTING0 (0U)        /*!< Bit position for CCM_CCGR43_SETTING0. */
#define BM_CCM_CCGR43_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR43_SETTING0. */
#define BS_CCM_CCGR43_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR43_SETTING0. */

/*! @brief Read current value of the CCM_CCGR43_SETTING0 field. */
#define BR_CCM_CCGR43_SETTING0(x) (HW_CCM_CCGR43(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR43_SETTING0. */
#define BF_CCM_CCGR43_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR43_SETTING0) & BM_CCM_CCGR43_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR43_SETTING0(x, v) (HW_CCM_CCGR43_WR(x, (HW_CCM_CCGR43_RD(x) & ~BM_CCM_CCGR43_SETTING0) | BF_CCM_CCGR43_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR43, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR43_SETTING1 (4U)        /*!< Bit position for CCM_CCGR43_SETTING1. */
#define BM_CCM_CCGR43_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR43_SETTING1. */
#define BS_CCM_CCGR43_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR43_SETTING1. */

/*! @brief Read current value of the CCM_CCGR43_SETTING1 field. */
#define BR_CCM_CCGR43_SETTING1(x) (HW_CCM_CCGR43(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR43_SETTING1. */
#define BF_CCM_CCGR43_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR43_SETTING1) & BM_CCM_CCGR43_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR43_SETTING1(x, v) (HW_CCM_CCGR43_WR(x, (HW_CCM_CCGR43_RD(x) & ~BM_CCM_CCGR43_SETTING1) | BF_CCM_CCGR43_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR43, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR43_SETTING2 (8U)        /*!< Bit position for CCM_CCGR43_SETTING2. */
#define BM_CCM_CCGR43_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR43_SETTING2. */
#define BS_CCM_CCGR43_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR43_SETTING2. */

/*! @brief Read current value of the CCM_CCGR43_SETTING2 field. */
#define BR_CCM_CCGR43_SETTING2(x) (HW_CCM_CCGR43(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR43_SETTING2. */
#define BF_CCM_CCGR43_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR43_SETTING2) & BM_CCM_CCGR43_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR43_SETTING2(x, v) (HW_CCM_CCGR43_WR(x, (HW_CCM_CCGR43_RD(x) & ~BM_CCM_CCGR43_SETTING2) | BF_CCM_CCGR43_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR43, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR43_SETTING3 (12U)       /*!< Bit position for CCM_CCGR43_SETTING3. */
#define BM_CCM_CCGR43_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR43_SETTING3. */
#define BS_CCM_CCGR43_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR43_SETTING3. */

/*! @brief Read current value of the CCM_CCGR43_SETTING3 field. */
#define BR_CCM_CCGR43_SETTING3(x) (HW_CCM_CCGR43(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR43_SETTING3. */
#define BF_CCM_CCGR43_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR43_SETTING3) & BM_CCM_CCGR43_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR43_SETTING3(x, v) (HW_CCM_CCGR43_WR(x, (HW_CCM_CCGR43_RD(x) & ~BM_CCM_CCGR43_SETTING3) | BF_CCM_CCGR43_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR44 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR44 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr44
{
    uint32_t U;
    struct _hw_ccm_ccgr44_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr44_t;

/*!
 * @name Constants and macros for entire CCM_CCGR44 register
 */
/*@{*/
#define HW_CCM_CCGR44_ADDR(x)    ((uintptr_t)(x) + 0x42C0U)
#define HW_CCM_CCGR44_SET_ADDR(x) (HW_CCM_CCGR44_ADDR(x) + 0x4U)
#define HW_CCM_CCGR44_CLR_ADDR(x) (HW_CCM_CCGR44_ADDR(x) + 0x8U)
#define HW_CCM_CCGR44_TOG_ADDR(x) (HW_CCM_CCGR44_ADDR(x) + 0xCU)

#define HW_CCM_CCGR44(x)         (*(__IO hw_ccm_ccgr44_t *) HW_CCM_CCGR44_ADDR(x))
#define HW_CCM_CCGR44_RD(x)      (HW_CCM_CCGR44(x).U)
#define HW_CCM_CCGR44_WR(x, v)   (HW_CCM_CCGR44(x).U = (v))
#define HW_CCM_CCGR44_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR44_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR44_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR44_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR44_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR44_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR44 bitfields
 */

/*!
 * @name Register CCM_CCGR44, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR44_SETTING0 (0U)        /*!< Bit position for CCM_CCGR44_SETTING0. */
#define BM_CCM_CCGR44_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR44_SETTING0. */
#define BS_CCM_CCGR44_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR44_SETTING0. */

/*! @brief Read current value of the CCM_CCGR44_SETTING0 field. */
#define BR_CCM_CCGR44_SETTING0(x) (HW_CCM_CCGR44(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR44_SETTING0. */
#define BF_CCM_CCGR44_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR44_SETTING0) & BM_CCM_CCGR44_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR44_SETTING0(x, v) (HW_CCM_CCGR44_WR(x, (HW_CCM_CCGR44_RD(x) & ~BM_CCM_CCGR44_SETTING0) | BF_CCM_CCGR44_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR44, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR44_SETTING1 (4U)        /*!< Bit position for CCM_CCGR44_SETTING1. */
#define BM_CCM_CCGR44_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR44_SETTING1. */
#define BS_CCM_CCGR44_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR44_SETTING1. */

/*! @brief Read current value of the CCM_CCGR44_SETTING1 field. */
#define BR_CCM_CCGR44_SETTING1(x) (HW_CCM_CCGR44(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR44_SETTING1. */
#define BF_CCM_CCGR44_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR44_SETTING1) & BM_CCM_CCGR44_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR44_SETTING1(x, v) (HW_CCM_CCGR44_WR(x, (HW_CCM_CCGR44_RD(x) & ~BM_CCM_CCGR44_SETTING1) | BF_CCM_CCGR44_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR44, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR44_SETTING2 (8U)        /*!< Bit position for CCM_CCGR44_SETTING2. */
#define BM_CCM_CCGR44_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR44_SETTING2. */
#define BS_CCM_CCGR44_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR44_SETTING2. */

/*! @brief Read current value of the CCM_CCGR44_SETTING2 field. */
#define BR_CCM_CCGR44_SETTING2(x) (HW_CCM_CCGR44(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR44_SETTING2. */
#define BF_CCM_CCGR44_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR44_SETTING2) & BM_CCM_CCGR44_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR44_SETTING2(x, v) (HW_CCM_CCGR44_WR(x, (HW_CCM_CCGR44_RD(x) & ~BM_CCM_CCGR44_SETTING2) | BF_CCM_CCGR44_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR44, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR44_SETTING3 (12U)       /*!< Bit position for CCM_CCGR44_SETTING3. */
#define BM_CCM_CCGR44_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR44_SETTING3. */
#define BS_CCM_CCGR44_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR44_SETTING3. */

/*! @brief Read current value of the CCM_CCGR44_SETTING3 field. */
#define BR_CCM_CCGR44_SETTING3(x) (HW_CCM_CCGR44(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR44_SETTING3. */
#define BF_CCM_CCGR44_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR44_SETTING3) & BM_CCM_CCGR44_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR44_SETTING3(x, v) (HW_CCM_CCGR44_WR(x, (HW_CCM_CCGR44_RD(x) & ~BM_CCM_CCGR44_SETTING3) | BF_CCM_CCGR44_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR45 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR45 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr45
{
    uint32_t U;
    struct _hw_ccm_ccgr45_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr45_t;

/*!
 * @name Constants and macros for entire CCM_CCGR45 register
 */
/*@{*/
#define HW_CCM_CCGR45_ADDR(x)    ((uintptr_t)(x) + 0x42D0U)
#define HW_CCM_CCGR45_SET_ADDR(x) (HW_CCM_CCGR45_ADDR(x) + 0x4U)
#define HW_CCM_CCGR45_CLR_ADDR(x) (HW_CCM_CCGR45_ADDR(x) + 0x8U)
#define HW_CCM_CCGR45_TOG_ADDR(x) (HW_CCM_CCGR45_ADDR(x) + 0xCU)

#define HW_CCM_CCGR45(x)         (*(__IO hw_ccm_ccgr45_t *) HW_CCM_CCGR45_ADDR(x))
#define HW_CCM_CCGR45_RD(x)      (HW_CCM_CCGR45(x).U)
#define HW_CCM_CCGR45_WR(x, v)   (HW_CCM_CCGR45(x).U = (v))
#define HW_CCM_CCGR45_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR45_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR45_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR45_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR45_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR45_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR45 bitfields
 */

/*!
 * @name Register CCM_CCGR45, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR45_SETTING0 (0U)        /*!< Bit position for CCM_CCGR45_SETTING0. */
#define BM_CCM_CCGR45_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR45_SETTING0. */
#define BS_CCM_CCGR45_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR45_SETTING0. */

/*! @brief Read current value of the CCM_CCGR45_SETTING0 field. */
#define BR_CCM_CCGR45_SETTING0(x) (HW_CCM_CCGR45(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR45_SETTING0. */
#define BF_CCM_CCGR45_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR45_SETTING0) & BM_CCM_CCGR45_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR45_SETTING0(x, v) (HW_CCM_CCGR45_WR(x, (HW_CCM_CCGR45_RD(x) & ~BM_CCM_CCGR45_SETTING0) | BF_CCM_CCGR45_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR45, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR45_SETTING1 (4U)        /*!< Bit position for CCM_CCGR45_SETTING1. */
#define BM_CCM_CCGR45_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR45_SETTING1. */
#define BS_CCM_CCGR45_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR45_SETTING1. */

/*! @brief Read current value of the CCM_CCGR45_SETTING1 field. */
#define BR_CCM_CCGR45_SETTING1(x) (HW_CCM_CCGR45(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR45_SETTING1. */
#define BF_CCM_CCGR45_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR45_SETTING1) & BM_CCM_CCGR45_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR45_SETTING1(x, v) (HW_CCM_CCGR45_WR(x, (HW_CCM_CCGR45_RD(x) & ~BM_CCM_CCGR45_SETTING1) | BF_CCM_CCGR45_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR45, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR45_SETTING2 (8U)        /*!< Bit position for CCM_CCGR45_SETTING2. */
#define BM_CCM_CCGR45_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR45_SETTING2. */
#define BS_CCM_CCGR45_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR45_SETTING2. */

/*! @brief Read current value of the CCM_CCGR45_SETTING2 field. */
#define BR_CCM_CCGR45_SETTING2(x) (HW_CCM_CCGR45(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR45_SETTING2. */
#define BF_CCM_CCGR45_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR45_SETTING2) & BM_CCM_CCGR45_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR45_SETTING2(x, v) (HW_CCM_CCGR45_WR(x, (HW_CCM_CCGR45_RD(x) & ~BM_CCM_CCGR45_SETTING2) | BF_CCM_CCGR45_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR45, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR45_SETTING3 (12U)       /*!< Bit position for CCM_CCGR45_SETTING3. */
#define BM_CCM_CCGR45_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR45_SETTING3. */
#define BS_CCM_CCGR45_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR45_SETTING3. */

/*! @brief Read current value of the CCM_CCGR45_SETTING3 field. */
#define BR_CCM_CCGR45_SETTING3(x) (HW_CCM_CCGR45(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR45_SETTING3. */
#define BF_CCM_CCGR45_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR45_SETTING3) & BM_CCM_CCGR45_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR45_SETTING3(x, v) (HW_CCM_CCGR45_WR(x, (HW_CCM_CCGR45_RD(x) & ~BM_CCM_CCGR45_SETTING3) | BF_CCM_CCGR45_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR46 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR46 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr46
{
    uint32_t U;
    struct _hw_ccm_ccgr46_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr46_t;

/*!
 * @name Constants and macros for entire CCM_CCGR46 register
 */
/*@{*/
#define HW_CCM_CCGR46_ADDR(x)    ((uintptr_t)(x) + 0x42E0U)
#define HW_CCM_CCGR46_SET_ADDR(x) (HW_CCM_CCGR46_ADDR(x) + 0x4U)
#define HW_CCM_CCGR46_CLR_ADDR(x) (HW_CCM_CCGR46_ADDR(x) + 0x8U)
#define HW_CCM_CCGR46_TOG_ADDR(x) (HW_CCM_CCGR46_ADDR(x) + 0xCU)

#define HW_CCM_CCGR46(x)         (*(__IO hw_ccm_ccgr46_t *) HW_CCM_CCGR46_ADDR(x))
#define HW_CCM_CCGR46_RD(x)      (HW_CCM_CCGR46(x).U)
#define HW_CCM_CCGR46_WR(x, v)   (HW_CCM_CCGR46(x).U = (v))
#define HW_CCM_CCGR46_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR46_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR46_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR46_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR46_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR46_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR46 bitfields
 */

/*!
 * @name Register CCM_CCGR46, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR46_SETTING0 (0U)        /*!< Bit position for CCM_CCGR46_SETTING0. */
#define BM_CCM_CCGR46_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR46_SETTING0. */
#define BS_CCM_CCGR46_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR46_SETTING0. */

/*! @brief Read current value of the CCM_CCGR46_SETTING0 field. */
#define BR_CCM_CCGR46_SETTING0(x) (HW_CCM_CCGR46(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR46_SETTING0. */
#define BF_CCM_CCGR46_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR46_SETTING0) & BM_CCM_CCGR46_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR46_SETTING0(x, v) (HW_CCM_CCGR46_WR(x, (HW_CCM_CCGR46_RD(x) & ~BM_CCM_CCGR46_SETTING0) | BF_CCM_CCGR46_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR46, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR46_SETTING1 (4U)        /*!< Bit position for CCM_CCGR46_SETTING1. */
#define BM_CCM_CCGR46_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR46_SETTING1. */
#define BS_CCM_CCGR46_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR46_SETTING1. */

/*! @brief Read current value of the CCM_CCGR46_SETTING1 field. */
#define BR_CCM_CCGR46_SETTING1(x) (HW_CCM_CCGR46(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR46_SETTING1. */
#define BF_CCM_CCGR46_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR46_SETTING1) & BM_CCM_CCGR46_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR46_SETTING1(x, v) (HW_CCM_CCGR46_WR(x, (HW_CCM_CCGR46_RD(x) & ~BM_CCM_CCGR46_SETTING1) | BF_CCM_CCGR46_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR46, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR46_SETTING2 (8U)        /*!< Bit position for CCM_CCGR46_SETTING2. */
#define BM_CCM_CCGR46_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR46_SETTING2. */
#define BS_CCM_CCGR46_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR46_SETTING2. */

/*! @brief Read current value of the CCM_CCGR46_SETTING2 field. */
#define BR_CCM_CCGR46_SETTING2(x) (HW_CCM_CCGR46(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR46_SETTING2. */
#define BF_CCM_CCGR46_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR46_SETTING2) & BM_CCM_CCGR46_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR46_SETTING2(x, v) (HW_CCM_CCGR46_WR(x, (HW_CCM_CCGR46_RD(x) & ~BM_CCM_CCGR46_SETTING2) | BF_CCM_CCGR46_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR46, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR46_SETTING3 (12U)       /*!< Bit position for CCM_CCGR46_SETTING3. */
#define BM_CCM_CCGR46_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR46_SETTING3. */
#define BS_CCM_CCGR46_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR46_SETTING3. */

/*! @brief Read current value of the CCM_CCGR46_SETTING3 field. */
#define BR_CCM_CCGR46_SETTING3(x) (HW_CCM_CCGR46(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR46_SETTING3. */
#define BF_CCM_CCGR46_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR46_SETTING3) & BM_CCM_CCGR46_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR46_SETTING3(x, v) (HW_CCM_CCGR46_WR(x, (HW_CCM_CCGR46_RD(x) & ~BM_CCM_CCGR46_SETTING3) | BF_CCM_CCGR46_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR47 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR47 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr47
{
    uint32_t U;
    struct _hw_ccm_ccgr47_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr47_t;

/*!
 * @name Constants and macros for entire CCM_CCGR47 register
 */
/*@{*/
#define HW_CCM_CCGR47_ADDR(x)    ((uintptr_t)(x) + 0x42F0U)
#define HW_CCM_CCGR47_SET_ADDR(x) (HW_CCM_CCGR47_ADDR(x) + 0x4U)
#define HW_CCM_CCGR47_CLR_ADDR(x) (HW_CCM_CCGR47_ADDR(x) + 0x8U)
#define HW_CCM_CCGR47_TOG_ADDR(x) (HW_CCM_CCGR47_ADDR(x) + 0xCU)

#define HW_CCM_CCGR47(x)         (*(__IO hw_ccm_ccgr47_t *) HW_CCM_CCGR47_ADDR(x))
#define HW_CCM_CCGR47_RD(x)      (HW_CCM_CCGR47(x).U)
#define HW_CCM_CCGR47_WR(x, v)   (HW_CCM_CCGR47(x).U = (v))
#define HW_CCM_CCGR47_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR47_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR47_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR47_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR47_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR47_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR47 bitfields
 */

/*!
 * @name Register CCM_CCGR47, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR47_SETTING0 (0U)        /*!< Bit position for CCM_CCGR47_SETTING0. */
#define BM_CCM_CCGR47_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR47_SETTING0. */
#define BS_CCM_CCGR47_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR47_SETTING0. */

/*! @brief Read current value of the CCM_CCGR47_SETTING0 field. */
#define BR_CCM_CCGR47_SETTING0(x) (HW_CCM_CCGR47(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR47_SETTING0. */
#define BF_CCM_CCGR47_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR47_SETTING0) & BM_CCM_CCGR47_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR47_SETTING0(x, v) (HW_CCM_CCGR47_WR(x, (HW_CCM_CCGR47_RD(x) & ~BM_CCM_CCGR47_SETTING0) | BF_CCM_CCGR47_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR47, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR47_SETTING1 (4U)        /*!< Bit position for CCM_CCGR47_SETTING1. */
#define BM_CCM_CCGR47_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR47_SETTING1. */
#define BS_CCM_CCGR47_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR47_SETTING1. */

/*! @brief Read current value of the CCM_CCGR47_SETTING1 field. */
#define BR_CCM_CCGR47_SETTING1(x) (HW_CCM_CCGR47(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR47_SETTING1. */
#define BF_CCM_CCGR47_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR47_SETTING1) & BM_CCM_CCGR47_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR47_SETTING1(x, v) (HW_CCM_CCGR47_WR(x, (HW_CCM_CCGR47_RD(x) & ~BM_CCM_CCGR47_SETTING1) | BF_CCM_CCGR47_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR47, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR47_SETTING2 (8U)        /*!< Bit position for CCM_CCGR47_SETTING2. */
#define BM_CCM_CCGR47_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR47_SETTING2. */
#define BS_CCM_CCGR47_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR47_SETTING2. */

/*! @brief Read current value of the CCM_CCGR47_SETTING2 field. */
#define BR_CCM_CCGR47_SETTING2(x) (HW_CCM_CCGR47(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR47_SETTING2. */
#define BF_CCM_CCGR47_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR47_SETTING2) & BM_CCM_CCGR47_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR47_SETTING2(x, v) (HW_CCM_CCGR47_WR(x, (HW_CCM_CCGR47_RD(x) & ~BM_CCM_CCGR47_SETTING2) | BF_CCM_CCGR47_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR47, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR47_SETTING3 (12U)       /*!< Bit position for CCM_CCGR47_SETTING3. */
#define BM_CCM_CCGR47_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR47_SETTING3. */
#define BS_CCM_CCGR47_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR47_SETTING3. */

/*! @brief Read current value of the CCM_CCGR47_SETTING3 field. */
#define BR_CCM_CCGR47_SETTING3(x) (HW_CCM_CCGR47(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR47_SETTING3. */
#define BF_CCM_CCGR47_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR47_SETTING3) & BM_CCM_CCGR47_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR47_SETTING3(x, v) (HW_CCM_CCGR47_WR(x, (HW_CCM_CCGR47_RD(x) & ~BM_CCM_CCGR47_SETTING3) | BF_CCM_CCGR47_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR48 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR48 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr48
{
    uint32_t U;
    struct _hw_ccm_ccgr48_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr48_t;

/*!
 * @name Constants and macros for entire CCM_CCGR48 register
 */
/*@{*/
#define HW_CCM_CCGR48_ADDR(x)    ((uintptr_t)(x) + 0x4300U)
#define HW_CCM_CCGR48_SET_ADDR(x) (HW_CCM_CCGR48_ADDR(x) + 0x4U)
#define HW_CCM_CCGR48_CLR_ADDR(x) (HW_CCM_CCGR48_ADDR(x) + 0x8U)
#define HW_CCM_CCGR48_TOG_ADDR(x) (HW_CCM_CCGR48_ADDR(x) + 0xCU)

#define HW_CCM_CCGR48(x)         (*(__IO hw_ccm_ccgr48_t *) HW_CCM_CCGR48_ADDR(x))
#define HW_CCM_CCGR48_RD(x)      (HW_CCM_CCGR48(x).U)
#define HW_CCM_CCGR48_WR(x, v)   (HW_CCM_CCGR48(x).U = (v))
#define HW_CCM_CCGR48_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR48_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR48_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR48_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR48_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR48_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR48 bitfields
 */

/*!
 * @name Register CCM_CCGR48, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR48_SETTING0 (0U)        /*!< Bit position for CCM_CCGR48_SETTING0. */
#define BM_CCM_CCGR48_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR48_SETTING0. */
#define BS_CCM_CCGR48_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR48_SETTING0. */

/*! @brief Read current value of the CCM_CCGR48_SETTING0 field. */
#define BR_CCM_CCGR48_SETTING0(x) (HW_CCM_CCGR48(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR48_SETTING0. */
#define BF_CCM_CCGR48_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR48_SETTING0) & BM_CCM_CCGR48_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR48_SETTING0(x, v) (HW_CCM_CCGR48_WR(x, (HW_CCM_CCGR48_RD(x) & ~BM_CCM_CCGR48_SETTING0) | BF_CCM_CCGR48_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR48, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR48_SETTING1 (4U)        /*!< Bit position for CCM_CCGR48_SETTING1. */
#define BM_CCM_CCGR48_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR48_SETTING1. */
#define BS_CCM_CCGR48_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR48_SETTING1. */

/*! @brief Read current value of the CCM_CCGR48_SETTING1 field. */
#define BR_CCM_CCGR48_SETTING1(x) (HW_CCM_CCGR48(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR48_SETTING1. */
#define BF_CCM_CCGR48_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR48_SETTING1) & BM_CCM_CCGR48_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR48_SETTING1(x, v) (HW_CCM_CCGR48_WR(x, (HW_CCM_CCGR48_RD(x) & ~BM_CCM_CCGR48_SETTING1) | BF_CCM_CCGR48_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR48, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR48_SETTING2 (8U)        /*!< Bit position for CCM_CCGR48_SETTING2. */
#define BM_CCM_CCGR48_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR48_SETTING2. */
#define BS_CCM_CCGR48_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR48_SETTING2. */

/*! @brief Read current value of the CCM_CCGR48_SETTING2 field. */
#define BR_CCM_CCGR48_SETTING2(x) (HW_CCM_CCGR48(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR48_SETTING2. */
#define BF_CCM_CCGR48_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR48_SETTING2) & BM_CCM_CCGR48_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR48_SETTING2(x, v) (HW_CCM_CCGR48_WR(x, (HW_CCM_CCGR48_RD(x) & ~BM_CCM_CCGR48_SETTING2) | BF_CCM_CCGR48_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR48, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR48_SETTING3 (12U)       /*!< Bit position for CCM_CCGR48_SETTING3. */
#define BM_CCM_CCGR48_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR48_SETTING3. */
#define BS_CCM_CCGR48_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR48_SETTING3. */

/*! @brief Read current value of the CCM_CCGR48_SETTING3 field. */
#define BR_CCM_CCGR48_SETTING3(x) (HW_CCM_CCGR48(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR48_SETTING3. */
#define BF_CCM_CCGR48_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR48_SETTING3) & BM_CCM_CCGR48_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR48_SETTING3(x, v) (HW_CCM_CCGR48_WR(x, (HW_CCM_CCGR48_RD(x) & ~BM_CCM_CCGR48_SETTING3) | BF_CCM_CCGR48_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR49 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR49 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr49
{
    uint32_t U;
    struct _hw_ccm_ccgr49_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr49_t;

/*!
 * @name Constants and macros for entire CCM_CCGR49 register
 */
/*@{*/
#define HW_CCM_CCGR49_ADDR(x)    ((uintptr_t)(x) + 0x4310U)
#define HW_CCM_CCGR49_SET_ADDR(x) (HW_CCM_CCGR49_ADDR(x) + 0x4U)
#define HW_CCM_CCGR49_CLR_ADDR(x) (HW_CCM_CCGR49_ADDR(x) + 0x8U)
#define HW_CCM_CCGR49_TOG_ADDR(x) (HW_CCM_CCGR49_ADDR(x) + 0xCU)

#define HW_CCM_CCGR49(x)         (*(__IO hw_ccm_ccgr49_t *) HW_CCM_CCGR49_ADDR(x))
#define HW_CCM_CCGR49_RD(x)      (HW_CCM_CCGR49(x).U)
#define HW_CCM_CCGR49_WR(x, v)   (HW_CCM_CCGR49(x).U = (v))
#define HW_CCM_CCGR49_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR49_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR49_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR49_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR49_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR49_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR49 bitfields
 */

/*!
 * @name Register CCM_CCGR49, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR49_SETTING0 (0U)        /*!< Bit position for CCM_CCGR49_SETTING0. */
#define BM_CCM_CCGR49_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR49_SETTING0. */
#define BS_CCM_CCGR49_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR49_SETTING0. */

/*! @brief Read current value of the CCM_CCGR49_SETTING0 field. */
#define BR_CCM_CCGR49_SETTING0(x) (HW_CCM_CCGR49(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR49_SETTING0. */
#define BF_CCM_CCGR49_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR49_SETTING0) & BM_CCM_CCGR49_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR49_SETTING0(x, v) (HW_CCM_CCGR49_WR(x, (HW_CCM_CCGR49_RD(x) & ~BM_CCM_CCGR49_SETTING0) | BF_CCM_CCGR49_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR49, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR49_SETTING1 (4U)        /*!< Bit position for CCM_CCGR49_SETTING1. */
#define BM_CCM_CCGR49_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR49_SETTING1. */
#define BS_CCM_CCGR49_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR49_SETTING1. */

/*! @brief Read current value of the CCM_CCGR49_SETTING1 field. */
#define BR_CCM_CCGR49_SETTING1(x) (HW_CCM_CCGR49(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR49_SETTING1. */
#define BF_CCM_CCGR49_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR49_SETTING1) & BM_CCM_CCGR49_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR49_SETTING1(x, v) (HW_CCM_CCGR49_WR(x, (HW_CCM_CCGR49_RD(x) & ~BM_CCM_CCGR49_SETTING1) | BF_CCM_CCGR49_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR49, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR49_SETTING2 (8U)        /*!< Bit position for CCM_CCGR49_SETTING2. */
#define BM_CCM_CCGR49_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR49_SETTING2. */
#define BS_CCM_CCGR49_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR49_SETTING2. */

/*! @brief Read current value of the CCM_CCGR49_SETTING2 field. */
#define BR_CCM_CCGR49_SETTING2(x) (HW_CCM_CCGR49(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR49_SETTING2. */
#define BF_CCM_CCGR49_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR49_SETTING2) & BM_CCM_CCGR49_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR49_SETTING2(x, v) (HW_CCM_CCGR49_WR(x, (HW_CCM_CCGR49_RD(x) & ~BM_CCM_CCGR49_SETTING2) | BF_CCM_CCGR49_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR49, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR49_SETTING3 (12U)       /*!< Bit position for CCM_CCGR49_SETTING3. */
#define BM_CCM_CCGR49_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR49_SETTING3. */
#define BS_CCM_CCGR49_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR49_SETTING3. */

/*! @brief Read current value of the CCM_CCGR49_SETTING3 field. */
#define BR_CCM_CCGR49_SETTING3(x) (HW_CCM_CCGR49(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR49_SETTING3. */
#define BF_CCM_CCGR49_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR49_SETTING3) & BM_CCM_CCGR49_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR49_SETTING3(x, v) (HW_CCM_CCGR49_WR(x, (HW_CCM_CCGR49_RD(x) & ~BM_CCM_CCGR49_SETTING3) | BF_CCM_CCGR49_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR50 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR50 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr50
{
    uint32_t U;
    struct _hw_ccm_ccgr50_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr50_t;

/*!
 * @name Constants and macros for entire CCM_CCGR50 register
 */
/*@{*/
#define HW_CCM_CCGR50_ADDR(x)    ((uintptr_t)(x) + 0x4320U)
#define HW_CCM_CCGR50_SET_ADDR(x) (HW_CCM_CCGR50_ADDR(x) + 0x4U)
#define HW_CCM_CCGR50_CLR_ADDR(x) (HW_CCM_CCGR50_ADDR(x) + 0x8U)
#define HW_CCM_CCGR50_TOG_ADDR(x) (HW_CCM_CCGR50_ADDR(x) + 0xCU)

#define HW_CCM_CCGR50(x)         (*(__IO hw_ccm_ccgr50_t *) HW_CCM_CCGR50_ADDR(x))
#define HW_CCM_CCGR50_RD(x)      (HW_CCM_CCGR50(x).U)
#define HW_CCM_CCGR50_WR(x, v)   (HW_CCM_CCGR50(x).U = (v))
#define HW_CCM_CCGR50_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR50_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR50_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR50_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR50_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR50_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR50 bitfields
 */

/*!
 * @name Register CCM_CCGR50, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR50_SETTING0 (0U)        /*!< Bit position for CCM_CCGR50_SETTING0. */
#define BM_CCM_CCGR50_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR50_SETTING0. */
#define BS_CCM_CCGR50_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR50_SETTING0. */

/*! @brief Read current value of the CCM_CCGR50_SETTING0 field. */
#define BR_CCM_CCGR50_SETTING0(x) (HW_CCM_CCGR50(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR50_SETTING0. */
#define BF_CCM_CCGR50_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR50_SETTING0) & BM_CCM_CCGR50_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR50_SETTING0(x, v) (HW_CCM_CCGR50_WR(x, (HW_CCM_CCGR50_RD(x) & ~BM_CCM_CCGR50_SETTING0) | BF_CCM_CCGR50_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR50, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR50_SETTING1 (4U)        /*!< Bit position for CCM_CCGR50_SETTING1. */
#define BM_CCM_CCGR50_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR50_SETTING1. */
#define BS_CCM_CCGR50_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR50_SETTING1. */

/*! @brief Read current value of the CCM_CCGR50_SETTING1 field. */
#define BR_CCM_CCGR50_SETTING1(x) (HW_CCM_CCGR50(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR50_SETTING1. */
#define BF_CCM_CCGR50_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR50_SETTING1) & BM_CCM_CCGR50_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR50_SETTING1(x, v) (HW_CCM_CCGR50_WR(x, (HW_CCM_CCGR50_RD(x) & ~BM_CCM_CCGR50_SETTING1) | BF_CCM_CCGR50_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR50, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR50_SETTING2 (8U)        /*!< Bit position for CCM_CCGR50_SETTING2. */
#define BM_CCM_CCGR50_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR50_SETTING2. */
#define BS_CCM_CCGR50_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR50_SETTING2. */

/*! @brief Read current value of the CCM_CCGR50_SETTING2 field. */
#define BR_CCM_CCGR50_SETTING2(x) (HW_CCM_CCGR50(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR50_SETTING2. */
#define BF_CCM_CCGR50_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR50_SETTING2) & BM_CCM_CCGR50_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR50_SETTING2(x, v) (HW_CCM_CCGR50_WR(x, (HW_CCM_CCGR50_RD(x) & ~BM_CCM_CCGR50_SETTING2) | BF_CCM_CCGR50_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR50, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR50_SETTING3 (12U)       /*!< Bit position for CCM_CCGR50_SETTING3. */
#define BM_CCM_CCGR50_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR50_SETTING3. */
#define BS_CCM_CCGR50_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR50_SETTING3. */

/*! @brief Read current value of the CCM_CCGR50_SETTING3 field. */
#define BR_CCM_CCGR50_SETTING3(x) (HW_CCM_CCGR50(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR50_SETTING3. */
#define BF_CCM_CCGR50_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR50_SETTING3) & BM_CCM_CCGR50_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR50_SETTING3(x, v) (HW_CCM_CCGR50_WR(x, (HW_CCM_CCGR50_RD(x) & ~BM_CCM_CCGR50_SETTING3) | BF_CCM_CCGR50_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR51 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR51 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr51
{
    uint32_t U;
    struct _hw_ccm_ccgr51_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr51_t;

/*!
 * @name Constants and macros for entire CCM_CCGR51 register
 */
/*@{*/
#define HW_CCM_CCGR51_ADDR(x)    ((uintptr_t)(x) + 0x4330U)
#define HW_CCM_CCGR51_SET_ADDR(x) (HW_CCM_CCGR51_ADDR(x) + 0x4U)
#define HW_CCM_CCGR51_CLR_ADDR(x) (HW_CCM_CCGR51_ADDR(x) + 0x8U)
#define HW_CCM_CCGR51_TOG_ADDR(x) (HW_CCM_CCGR51_ADDR(x) + 0xCU)

#define HW_CCM_CCGR51(x)         (*(__IO hw_ccm_ccgr51_t *) HW_CCM_CCGR51_ADDR(x))
#define HW_CCM_CCGR51_RD(x)      (HW_CCM_CCGR51(x).U)
#define HW_CCM_CCGR51_WR(x, v)   (HW_CCM_CCGR51(x).U = (v))
#define HW_CCM_CCGR51_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR51_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR51_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR51_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR51_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR51_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR51 bitfields
 */

/*!
 * @name Register CCM_CCGR51, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR51_SETTING0 (0U)        /*!< Bit position for CCM_CCGR51_SETTING0. */
#define BM_CCM_CCGR51_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR51_SETTING0. */
#define BS_CCM_CCGR51_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR51_SETTING0. */

/*! @brief Read current value of the CCM_CCGR51_SETTING0 field. */
#define BR_CCM_CCGR51_SETTING0(x) (HW_CCM_CCGR51(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR51_SETTING0. */
#define BF_CCM_CCGR51_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR51_SETTING0) & BM_CCM_CCGR51_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR51_SETTING0(x, v) (HW_CCM_CCGR51_WR(x, (HW_CCM_CCGR51_RD(x) & ~BM_CCM_CCGR51_SETTING0) | BF_CCM_CCGR51_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR51, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR51_SETTING1 (4U)        /*!< Bit position for CCM_CCGR51_SETTING1. */
#define BM_CCM_CCGR51_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR51_SETTING1. */
#define BS_CCM_CCGR51_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR51_SETTING1. */

/*! @brief Read current value of the CCM_CCGR51_SETTING1 field. */
#define BR_CCM_CCGR51_SETTING1(x) (HW_CCM_CCGR51(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR51_SETTING1. */
#define BF_CCM_CCGR51_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR51_SETTING1) & BM_CCM_CCGR51_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR51_SETTING1(x, v) (HW_CCM_CCGR51_WR(x, (HW_CCM_CCGR51_RD(x) & ~BM_CCM_CCGR51_SETTING1) | BF_CCM_CCGR51_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR51, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR51_SETTING2 (8U)        /*!< Bit position for CCM_CCGR51_SETTING2. */
#define BM_CCM_CCGR51_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR51_SETTING2. */
#define BS_CCM_CCGR51_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR51_SETTING2. */

/*! @brief Read current value of the CCM_CCGR51_SETTING2 field. */
#define BR_CCM_CCGR51_SETTING2(x) (HW_CCM_CCGR51(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR51_SETTING2. */
#define BF_CCM_CCGR51_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR51_SETTING2) & BM_CCM_CCGR51_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR51_SETTING2(x, v) (HW_CCM_CCGR51_WR(x, (HW_CCM_CCGR51_RD(x) & ~BM_CCM_CCGR51_SETTING2) | BF_CCM_CCGR51_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR51, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR51_SETTING3 (12U)       /*!< Bit position for CCM_CCGR51_SETTING3. */
#define BM_CCM_CCGR51_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR51_SETTING3. */
#define BS_CCM_CCGR51_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR51_SETTING3. */

/*! @brief Read current value of the CCM_CCGR51_SETTING3 field. */
#define BR_CCM_CCGR51_SETTING3(x) (HW_CCM_CCGR51(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR51_SETTING3. */
#define BF_CCM_CCGR51_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR51_SETTING3) & BM_CCM_CCGR51_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR51_SETTING3(x, v) (HW_CCM_CCGR51_WR(x, (HW_CCM_CCGR51_RD(x) & ~BM_CCM_CCGR51_SETTING3) | BF_CCM_CCGR51_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR52 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR52 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr52
{
    uint32_t U;
    struct _hw_ccm_ccgr52_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr52_t;

/*!
 * @name Constants and macros for entire CCM_CCGR52 register
 */
/*@{*/
#define HW_CCM_CCGR52_ADDR(x)    ((uintptr_t)(x) + 0x4340U)
#define HW_CCM_CCGR52_SET_ADDR(x) (HW_CCM_CCGR52_ADDR(x) + 0x4U)
#define HW_CCM_CCGR52_CLR_ADDR(x) (HW_CCM_CCGR52_ADDR(x) + 0x8U)
#define HW_CCM_CCGR52_TOG_ADDR(x) (HW_CCM_CCGR52_ADDR(x) + 0xCU)

#define HW_CCM_CCGR52(x)         (*(__IO hw_ccm_ccgr52_t *) HW_CCM_CCGR52_ADDR(x))
#define HW_CCM_CCGR52_RD(x)      (HW_CCM_CCGR52(x).U)
#define HW_CCM_CCGR52_WR(x, v)   (HW_CCM_CCGR52(x).U = (v))
#define HW_CCM_CCGR52_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR52_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR52_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR52_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR52_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR52_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR52 bitfields
 */

/*!
 * @name Register CCM_CCGR52, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR52_SETTING0 (0U)        /*!< Bit position for CCM_CCGR52_SETTING0. */
#define BM_CCM_CCGR52_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR52_SETTING0. */
#define BS_CCM_CCGR52_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR52_SETTING0. */

/*! @brief Read current value of the CCM_CCGR52_SETTING0 field. */
#define BR_CCM_CCGR52_SETTING0(x) (HW_CCM_CCGR52(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR52_SETTING0. */
#define BF_CCM_CCGR52_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR52_SETTING0) & BM_CCM_CCGR52_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR52_SETTING0(x, v) (HW_CCM_CCGR52_WR(x, (HW_CCM_CCGR52_RD(x) & ~BM_CCM_CCGR52_SETTING0) | BF_CCM_CCGR52_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR52, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR52_SETTING1 (4U)        /*!< Bit position for CCM_CCGR52_SETTING1. */
#define BM_CCM_CCGR52_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR52_SETTING1. */
#define BS_CCM_CCGR52_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR52_SETTING1. */

/*! @brief Read current value of the CCM_CCGR52_SETTING1 field. */
#define BR_CCM_CCGR52_SETTING1(x) (HW_CCM_CCGR52(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR52_SETTING1. */
#define BF_CCM_CCGR52_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR52_SETTING1) & BM_CCM_CCGR52_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR52_SETTING1(x, v) (HW_CCM_CCGR52_WR(x, (HW_CCM_CCGR52_RD(x) & ~BM_CCM_CCGR52_SETTING1) | BF_CCM_CCGR52_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR52, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR52_SETTING2 (8U)        /*!< Bit position for CCM_CCGR52_SETTING2. */
#define BM_CCM_CCGR52_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR52_SETTING2. */
#define BS_CCM_CCGR52_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR52_SETTING2. */

/*! @brief Read current value of the CCM_CCGR52_SETTING2 field. */
#define BR_CCM_CCGR52_SETTING2(x) (HW_CCM_CCGR52(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR52_SETTING2. */
#define BF_CCM_CCGR52_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR52_SETTING2) & BM_CCM_CCGR52_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR52_SETTING2(x, v) (HW_CCM_CCGR52_WR(x, (HW_CCM_CCGR52_RD(x) & ~BM_CCM_CCGR52_SETTING2) | BF_CCM_CCGR52_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR52, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR52_SETTING3 (12U)       /*!< Bit position for CCM_CCGR52_SETTING3. */
#define BM_CCM_CCGR52_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR52_SETTING3. */
#define BS_CCM_CCGR52_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR52_SETTING3. */

/*! @brief Read current value of the CCM_CCGR52_SETTING3 field. */
#define BR_CCM_CCGR52_SETTING3(x) (HW_CCM_CCGR52(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR52_SETTING3. */
#define BF_CCM_CCGR52_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR52_SETTING3) & BM_CCM_CCGR52_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR52_SETTING3(x, v) (HW_CCM_CCGR52_WR(x, (HW_CCM_CCGR52_RD(x) & ~BM_CCM_CCGR52_SETTING3) | BF_CCM_CCGR52_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR53 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR53 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr53
{
    uint32_t U;
    struct _hw_ccm_ccgr53_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr53_t;

/*!
 * @name Constants and macros for entire CCM_CCGR53 register
 */
/*@{*/
#define HW_CCM_CCGR53_ADDR(x)    ((uintptr_t)(x) + 0x4350U)
#define HW_CCM_CCGR53_SET_ADDR(x) (HW_CCM_CCGR53_ADDR(x) + 0x4U)
#define HW_CCM_CCGR53_CLR_ADDR(x) (HW_CCM_CCGR53_ADDR(x) + 0x8U)
#define HW_CCM_CCGR53_TOG_ADDR(x) (HW_CCM_CCGR53_ADDR(x) + 0xCU)

#define HW_CCM_CCGR53(x)         (*(__IO hw_ccm_ccgr53_t *) HW_CCM_CCGR53_ADDR(x))
#define HW_CCM_CCGR53_RD(x)      (HW_CCM_CCGR53(x).U)
#define HW_CCM_CCGR53_WR(x, v)   (HW_CCM_CCGR53(x).U = (v))
#define HW_CCM_CCGR53_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR53_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR53_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR53_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR53_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR53_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR53 bitfields
 */

/*!
 * @name Register CCM_CCGR53, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR53_SETTING0 (0U)        /*!< Bit position for CCM_CCGR53_SETTING0. */
#define BM_CCM_CCGR53_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR53_SETTING0. */
#define BS_CCM_CCGR53_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR53_SETTING0. */

/*! @brief Read current value of the CCM_CCGR53_SETTING0 field. */
#define BR_CCM_CCGR53_SETTING0(x) (HW_CCM_CCGR53(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR53_SETTING0. */
#define BF_CCM_CCGR53_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR53_SETTING0) & BM_CCM_CCGR53_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR53_SETTING0(x, v) (HW_CCM_CCGR53_WR(x, (HW_CCM_CCGR53_RD(x) & ~BM_CCM_CCGR53_SETTING0) | BF_CCM_CCGR53_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR53, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR53_SETTING1 (4U)        /*!< Bit position for CCM_CCGR53_SETTING1. */
#define BM_CCM_CCGR53_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR53_SETTING1. */
#define BS_CCM_CCGR53_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR53_SETTING1. */

/*! @brief Read current value of the CCM_CCGR53_SETTING1 field. */
#define BR_CCM_CCGR53_SETTING1(x) (HW_CCM_CCGR53(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR53_SETTING1. */
#define BF_CCM_CCGR53_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR53_SETTING1) & BM_CCM_CCGR53_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR53_SETTING1(x, v) (HW_CCM_CCGR53_WR(x, (HW_CCM_CCGR53_RD(x) & ~BM_CCM_CCGR53_SETTING1) | BF_CCM_CCGR53_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR53, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR53_SETTING2 (8U)        /*!< Bit position for CCM_CCGR53_SETTING2. */
#define BM_CCM_CCGR53_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR53_SETTING2. */
#define BS_CCM_CCGR53_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR53_SETTING2. */

/*! @brief Read current value of the CCM_CCGR53_SETTING2 field. */
#define BR_CCM_CCGR53_SETTING2(x) (HW_CCM_CCGR53(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR53_SETTING2. */
#define BF_CCM_CCGR53_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR53_SETTING2) & BM_CCM_CCGR53_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR53_SETTING2(x, v) (HW_CCM_CCGR53_WR(x, (HW_CCM_CCGR53_RD(x) & ~BM_CCM_CCGR53_SETTING2) | BF_CCM_CCGR53_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR53, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR53_SETTING3 (12U)       /*!< Bit position for CCM_CCGR53_SETTING3. */
#define BM_CCM_CCGR53_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR53_SETTING3. */
#define BS_CCM_CCGR53_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR53_SETTING3. */

/*! @brief Read current value of the CCM_CCGR53_SETTING3 field. */
#define BR_CCM_CCGR53_SETTING3(x) (HW_CCM_CCGR53(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR53_SETTING3. */
#define BF_CCM_CCGR53_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR53_SETTING3) & BM_CCM_CCGR53_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR53_SETTING3(x, v) (HW_CCM_CCGR53_WR(x, (HW_CCM_CCGR53_RD(x) & ~BM_CCM_CCGR53_SETTING3) | BF_CCM_CCGR53_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR54 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR54 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr54
{
    uint32_t U;
    struct _hw_ccm_ccgr54_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr54_t;

/*!
 * @name Constants and macros for entire CCM_CCGR54 register
 */
/*@{*/
#define HW_CCM_CCGR54_ADDR(x)    ((uintptr_t)(x) + 0x4360U)
#define HW_CCM_CCGR54_SET_ADDR(x) (HW_CCM_CCGR54_ADDR(x) + 0x4U)
#define HW_CCM_CCGR54_CLR_ADDR(x) (HW_CCM_CCGR54_ADDR(x) + 0x8U)
#define HW_CCM_CCGR54_TOG_ADDR(x) (HW_CCM_CCGR54_ADDR(x) + 0xCU)

#define HW_CCM_CCGR54(x)         (*(__IO hw_ccm_ccgr54_t *) HW_CCM_CCGR54_ADDR(x))
#define HW_CCM_CCGR54_RD(x)      (HW_CCM_CCGR54(x).U)
#define HW_CCM_CCGR54_WR(x, v)   (HW_CCM_CCGR54(x).U = (v))
#define HW_CCM_CCGR54_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR54_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR54_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR54_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR54_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR54_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR54 bitfields
 */

/*!
 * @name Register CCM_CCGR54, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR54_SETTING0 (0U)        /*!< Bit position for CCM_CCGR54_SETTING0. */
#define BM_CCM_CCGR54_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR54_SETTING0. */
#define BS_CCM_CCGR54_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR54_SETTING0. */

/*! @brief Read current value of the CCM_CCGR54_SETTING0 field. */
#define BR_CCM_CCGR54_SETTING0(x) (HW_CCM_CCGR54(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR54_SETTING0. */
#define BF_CCM_CCGR54_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR54_SETTING0) & BM_CCM_CCGR54_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR54_SETTING0(x, v) (HW_CCM_CCGR54_WR(x, (HW_CCM_CCGR54_RD(x) & ~BM_CCM_CCGR54_SETTING0) | BF_CCM_CCGR54_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR54, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR54_SETTING1 (4U)        /*!< Bit position for CCM_CCGR54_SETTING1. */
#define BM_CCM_CCGR54_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR54_SETTING1. */
#define BS_CCM_CCGR54_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR54_SETTING1. */

/*! @brief Read current value of the CCM_CCGR54_SETTING1 field. */
#define BR_CCM_CCGR54_SETTING1(x) (HW_CCM_CCGR54(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR54_SETTING1. */
#define BF_CCM_CCGR54_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR54_SETTING1) & BM_CCM_CCGR54_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR54_SETTING1(x, v) (HW_CCM_CCGR54_WR(x, (HW_CCM_CCGR54_RD(x) & ~BM_CCM_CCGR54_SETTING1) | BF_CCM_CCGR54_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR54, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR54_SETTING2 (8U)        /*!< Bit position for CCM_CCGR54_SETTING2. */
#define BM_CCM_CCGR54_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR54_SETTING2. */
#define BS_CCM_CCGR54_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR54_SETTING2. */

/*! @brief Read current value of the CCM_CCGR54_SETTING2 field. */
#define BR_CCM_CCGR54_SETTING2(x) (HW_CCM_CCGR54(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR54_SETTING2. */
#define BF_CCM_CCGR54_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR54_SETTING2) & BM_CCM_CCGR54_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR54_SETTING2(x, v) (HW_CCM_CCGR54_WR(x, (HW_CCM_CCGR54_RD(x) & ~BM_CCM_CCGR54_SETTING2) | BF_CCM_CCGR54_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR54, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR54_SETTING3 (12U)       /*!< Bit position for CCM_CCGR54_SETTING3. */
#define BM_CCM_CCGR54_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR54_SETTING3. */
#define BS_CCM_CCGR54_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR54_SETTING3. */

/*! @brief Read current value of the CCM_CCGR54_SETTING3 field. */
#define BR_CCM_CCGR54_SETTING3(x) (HW_CCM_CCGR54(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR54_SETTING3. */
#define BF_CCM_CCGR54_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR54_SETTING3) & BM_CCM_CCGR54_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR54_SETTING3(x, v) (HW_CCM_CCGR54_WR(x, (HW_CCM_CCGR54_RD(x) & ~BM_CCM_CCGR54_SETTING3) | BF_CCM_CCGR54_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR55 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR55 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr55
{
    uint32_t U;
    struct _hw_ccm_ccgr55_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr55_t;

/*!
 * @name Constants and macros for entire CCM_CCGR55 register
 */
/*@{*/
#define HW_CCM_CCGR55_ADDR(x)    ((uintptr_t)(x) + 0x4370U)
#define HW_CCM_CCGR55_SET_ADDR(x) (HW_CCM_CCGR55_ADDR(x) + 0x4U)
#define HW_CCM_CCGR55_CLR_ADDR(x) (HW_CCM_CCGR55_ADDR(x) + 0x8U)
#define HW_CCM_CCGR55_TOG_ADDR(x) (HW_CCM_CCGR55_ADDR(x) + 0xCU)

#define HW_CCM_CCGR55(x)         (*(__IO hw_ccm_ccgr55_t *) HW_CCM_CCGR55_ADDR(x))
#define HW_CCM_CCGR55_RD(x)      (HW_CCM_CCGR55(x).U)
#define HW_CCM_CCGR55_WR(x, v)   (HW_CCM_CCGR55(x).U = (v))
#define HW_CCM_CCGR55_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR55_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR55_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR55_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR55_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR55_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR55 bitfields
 */

/*!
 * @name Register CCM_CCGR55, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR55_SETTING0 (0U)        /*!< Bit position for CCM_CCGR55_SETTING0. */
#define BM_CCM_CCGR55_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR55_SETTING0. */
#define BS_CCM_CCGR55_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR55_SETTING0. */

/*! @brief Read current value of the CCM_CCGR55_SETTING0 field. */
#define BR_CCM_CCGR55_SETTING0(x) (HW_CCM_CCGR55(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR55_SETTING0. */
#define BF_CCM_CCGR55_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR55_SETTING0) & BM_CCM_CCGR55_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR55_SETTING0(x, v) (HW_CCM_CCGR55_WR(x, (HW_CCM_CCGR55_RD(x) & ~BM_CCM_CCGR55_SETTING0) | BF_CCM_CCGR55_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR55, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR55_SETTING1 (4U)        /*!< Bit position for CCM_CCGR55_SETTING1. */
#define BM_CCM_CCGR55_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR55_SETTING1. */
#define BS_CCM_CCGR55_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR55_SETTING1. */

/*! @brief Read current value of the CCM_CCGR55_SETTING1 field. */
#define BR_CCM_CCGR55_SETTING1(x) (HW_CCM_CCGR55(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR55_SETTING1. */
#define BF_CCM_CCGR55_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR55_SETTING1) & BM_CCM_CCGR55_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR55_SETTING1(x, v) (HW_CCM_CCGR55_WR(x, (HW_CCM_CCGR55_RD(x) & ~BM_CCM_CCGR55_SETTING1) | BF_CCM_CCGR55_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR55, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR55_SETTING2 (8U)        /*!< Bit position for CCM_CCGR55_SETTING2. */
#define BM_CCM_CCGR55_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR55_SETTING2. */
#define BS_CCM_CCGR55_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR55_SETTING2. */

/*! @brief Read current value of the CCM_CCGR55_SETTING2 field. */
#define BR_CCM_CCGR55_SETTING2(x) (HW_CCM_CCGR55(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR55_SETTING2. */
#define BF_CCM_CCGR55_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR55_SETTING2) & BM_CCM_CCGR55_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR55_SETTING2(x, v) (HW_CCM_CCGR55_WR(x, (HW_CCM_CCGR55_RD(x) & ~BM_CCM_CCGR55_SETTING2) | BF_CCM_CCGR55_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR55, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR55_SETTING3 (12U)       /*!< Bit position for CCM_CCGR55_SETTING3. */
#define BM_CCM_CCGR55_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR55_SETTING3. */
#define BS_CCM_CCGR55_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR55_SETTING3. */

/*! @brief Read current value of the CCM_CCGR55_SETTING3 field. */
#define BR_CCM_CCGR55_SETTING3(x) (HW_CCM_CCGR55(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR55_SETTING3. */
#define BF_CCM_CCGR55_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR55_SETTING3) & BM_CCM_CCGR55_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR55_SETTING3(x, v) (HW_CCM_CCGR55_WR(x, (HW_CCM_CCGR55_RD(x) & ~BM_CCM_CCGR55_SETTING3) | BF_CCM_CCGR55_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR56 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR56 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr56
{
    uint32_t U;
    struct _hw_ccm_ccgr56_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr56_t;

/*!
 * @name Constants and macros for entire CCM_CCGR56 register
 */
/*@{*/
#define HW_CCM_CCGR56_ADDR(x)    ((uintptr_t)(x) + 0x4380U)
#define HW_CCM_CCGR56_SET_ADDR(x) (HW_CCM_CCGR56_ADDR(x) + 0x4U)
#define HW_CCM_CCGR56_CLR_ADDR(x) (HW_CCM_CCGR56_ADDR(x) + 0x8U)
#define HW_CCM_CCGR56_TOG_ADDR(x) (HW_CCM_CCGR56_ADDR(x) + 0xCU)

#define HW_CCM_CCGR56(x)         (*(__IO hw_ccm_ccgr56_t *) HW_CCM_CCGR56_ADDR(x))
#define HW_CCM_CCGR56_RD(x)      (HW_CCM_CCGR56(x).U)
#define HW_CCM_CCGR56_WR(x, v)   (HW_CCM_CCGR56(x).U = (v))
#define HW_CCM_CCGR56_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR56_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR56_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR56_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR56_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR56_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR56 bitfields
 */

/*!
 * @name Register CCM_CCGR56, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR56_SETTING0 (0U)        /*!< Bit position for CCM_CCGR56_SETTING0. */
#define BM_CCM_CCGR56_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR56_SETTING0. */
#define BS_CCM_CCGR56_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR56_SETTING0. */

/*! @brief Read current value of the CCM_CCGR56_SETTING0 field. */
#define BR_CCM_CCGR56_SETTING0(x) (HW_CCM_CCGR56(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR56_SETTING0. */
#define BF_CCM_CCGR56_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR56_SETTING0) & BM_CCM_CCGR56_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR56_SETTING0(x, v) (HW_CCM_CCGR56_WR(x, (HW_CCM_CCGR56_RD(x) & ~BM_CCM_CCGR56_SETTING0) | BF_CCM_CCGR56_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR56, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR56_SETTING1 (4U)        /*!< Bit position for CCM_CCGR56_SETTING1. */
#define BM_CCM_CCGR56_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR56_SETTING1. */
#define BS_CCM_CCGR56_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR56_SETTING1. */

/*! @brief Read current value of the CCM_CCGR56_SETTING1 field. */
#define BR_CCM_CCGR56_SETTING1(x) (HW_CCM_CCGR56(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR56_SETTING1. */
#define BF_CCM_CCGR56_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR56_SETTING1) & BM_CCM_CCGR56_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR56_SETTING1(x, v) (HW_CCM_CCGR56_WR(x, (HW_CCM_CCGR56_RD(x) & ~BM_CCM_CCGR56_SETTING1) | BF_CCM_CCGR56_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR56, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR56_SETTING2 (8U)        /*!< Bit position for CCM_CCGR56_SETTING2. */
#define BM_CCM_CCGR56_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR56_SETTING2. */
#define BS_CCM_CCGR56_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR56_SETTING2. */

/*! @brief Read current value of the CCM_CCGR56_SETTING2 field. */
#define BR_CCM_CCGR56_SETTING2(x) (HW_CCM_CCGR56(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR56_SETTING2. */
#define BF_CCM_CCGR56_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR56_SETTING2) & BM_CCM_CCGR56_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR56_SETTING2(x, v) (HW_CCM_CCGR56_WR(x, (HW_CCM_CCGR56_RD(x) & ~BM_CCM_CCGR56_SETTING2) | BF_CCM_CCGR56_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR56, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR56_SETTING3 (12U)       /*!< Bit position for CCM_CCGR56_SETTING3. */
#define BM_CCM_CCGR56_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR56_SETTING3. */
#define BS_CCM_CCGR56_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR56_SETTING3. */

/*! @brief Read current value of the CCM_CCGR56_SETTING3 field. */
#define BR_CCM_CCGR56_SETTING3(x) (HW_CCM_CCGR56(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR56_SETTING3. */
#define BF_CCM_CCGR56_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR56_SETTING3) & BM_CCM_CCGR56_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR56_SETTING3(x, v) (HW_CCM_CCGR56_WR(x, (HW_CCM_CCGR56_RD(x) & ~BM_CCM_CCGR56_SETTING3) | BF_CCM_CCGR56_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR57 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR57 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr57
{
    uint32_t U;
    struct _hw_ccm_ccgr57_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr57_t;

/*!
 * @name Constants and macros for entire CCM_CCGR57 register
 */
/*@{*/
#define HW_CCM_CCGR57_ADDR(x)    ((uintptr_t)(x) + 0x4390U)
#define HW_CCM_CCGR57_SET_ADDR(x) (HW_CCM_CCGR57_ADDR(x) + 0x4U)
#define HW_CCM_CCGR57_CLR_ADDR(x) (HW_CCM_CCGR57_ADDR(x) + 0x8U)
#define HW_CCM_CCGR57_TOG_ADDR(x) (HW_CCM_CCGR57_ADDR(x) + 0xCU)

#define HW_CCM_CCGR57(x)         (*(__IO hw_ccm_ccgr57_t *) HW_CCM_CCGR57_ADDR(x))
#define HW_CCM_CCGR57_RD(x)      (HW_CCM_CCGR57(x).U)
#define HW_CCM_CCGR57_WR(x, v)   (HW_CCM_CCGR57(x).U = (v))
#define HW_CCM_CCGR57_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR57_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR57_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR57_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR57_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR57_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR57 bitfields
 */

/*!
 * @name Register CCM_CCGR57, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR57_SETTING0 (0U)        /*!< Bit position for CCM_CCGR57_SETTING0. */
#define BM_CCM_CCGR57_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR57_SETTING0. */
#define BS_CCM_CCGR57_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR57_SETTING0. */

/*! @brief Read current value of the CCM_CCGR57_SETTING0 field. */
#define BR_CCM_CCGR57_SETTING0(x) (HW_CCM_CCGR57(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR57_SETTING0. */
#define BF_CCM_CCGR57_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR57_SETTING0) & BM_CCM_CCGR57_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR57_SETTING0(x, v) (HW_CCM_CCGR57_WR(x, (HW_CCM_CCGR57_RD(x) & ~BM_CCM_CCGR57_SETTING0) | BF_CCM_CCGR57_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR57, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR57_SETTING1 (4U)        /*!< Bit position for CCM_CCGR57_SETTING1. */
#define BM_CCM_CCGR57_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR57_SETTING1. */
#define BS_CCM_CCGR57_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR57_SETTING1. */

/*! @brief Read current value of the CCM_CCGR57_SETTING1 field. */
#define BR_CCM_CCGR57_SETTING1(x) (HW_CCM_CCGR57(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR57_SETTING1. */
#define BF_CCM_CCGR57_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR57_SETTING1) & BM_CCM_CCGR57_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR57_SETTING1(x, v) (HW_CCM_CCGR57_WR(x, (HW_CCM_CCGR57_RD(x) & ~BM_CCM_CCGR57_SETTING1) | BF_CCM_CCGR57_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR57, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR57_SETTING2 (8U)        /*!< Bit position for CCM_CCGR57_SETTING2. */
#define BM_CCM_CCGR57_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR57_SETTING2. */
#define BS_CCM_CCGR57_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR57_SETTING2. */

/*! @brief Read current value of the CCM_CCGR57_SETTING2 field. */
#define BR_CCM_CCGR57_SETTING2(x) (HW_CCM_CCGR57(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR57_SETTING2. */
#define BF_CCM_CCGR57_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR57_SETTING2) & BM_CCM_CCGR57_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR57_SETTING2(x, v) (HW_CCM_CCGR57_WR(x, (HW_CCM_CCGR57_RD(x) & ~BM_CCM_CCGR57_SETTING2) | BF_CCM_CCGR57_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR57, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR57_SETTING3 (12U)       /*!< Bit position for CCM_CCGR57_SETTING3. */
#define BM_CCM_CCGR57_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR57_SETTING3. */
#define BS_CCM_CCGR57_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR57_SETTING3. */

/*! @brief Read current value of the CCM_CCGR57_SETTING3 field. */
#define BR_CCM_CCGR57_SETTING3(x) (HW_CCM_CCGR57(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR57_SETTING3. */
#define BF_CCM_CCGR57_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR57_SETTING3) & BM_CCM_CCGR57_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR57_SETTING3(x, v) (HW_CCM_CCGR57_WR(x, (HW_CCM_CCGR57_RD(x) & ~BM_CCM_CCGR57_SETTING3) | BF_CCM_CCGR57_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR58 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR58 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr58
{
    uint32_t U;
    struct _hw_ccm_ccgr58_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr58_t;

/*!
 * @name Constants and macros for entire CCM_CCGR58 register
 */
/*@{*/
#define HW_CCM_CCGR58_ADDR(x)    ((uintptr_t)(x) + 0x43A0U)
#define HW_CCM_CCGR58_SET_ADDR(x) (HW_CCM_CCGR58_ADDR(x) + 0x4U)
#define HW_CCM_CCGR58_CLR_ADDR(x) (HW_CCM_CCGR58_ADDR(x) + 0x8U)
#define HW_CCM_CCGR58_TOG_ADDR(x) (HW_CCM_CCGR58_ADDR(x) + 0xCU)

#define HW_CCM_CCGR58(x)         (*(__IO hw_ccm_ccgr58_t *) HW_CCM_CCGR58_ADDR(x))
#define HW_CCM_CCGR58_RD(x)      (HW_CCM_CCGR58(x).U)
#define HW_CCM_CCGR58_WR(x, v)   (HW_CCM_CCGR58(x).U = (v))
#define HW_CCM_CCGR58_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR58_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR58_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR58_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR58_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR58_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR58 bitfields
 */

/*!
 * @name Register CCM_CCGR58, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR58_SETTING0 (0U)        /*!< Bit position for CCM_CCGR58_SETTING0. */
#define BM_CCM_CCGR58_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR58_SETTING0. */
#define BS_CCM_CCGR58_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR58_SETTING0. */

/*! @brief Read current value of the CCM_CCGR58_SETTING0 field. */
#define BR_CCM_CCGR58_SETTING0(x) (HW_CCM_CCGR58(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR58_SETTING0. */
#define BF_CCM_CCGR58_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR58_SETTING0) & BM_CCM_CCGR58_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR58_SETTING0(x, v) (HW_CCM_CCGR58_WR(x, (HW_CCM_CCGR58_RD(x) & ~BM_CCM_CCGR58_SETTING0) | BF_CCM_CCGR58_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR58, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR58_SETTING1 (4U)        /*!< Bit position for CCM_CCGR58_SETTING1. */
#define BM_CCM_CCGR58_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR58_SETTING1. */
#define BS_CCM_CCGR58_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR58_SETTING1. */

/*! @brief Read current value of the CCM_CCGR58_SETTING1 field. */
#define BR_CCM_CCGR58_SETTING1(x) (HW_CCM_CCGR58(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR58_SETTING1. */
#define BF_CCM_CCGR58_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR58_SETTING1) & BM_CCM_CCGR58_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR58_SETTING1(x, v) (HW_CCM_CCGR58_WR(x, (HW_CCM_CCGR58_RD(x) & ~BM_CCM_CCGR58_SETTING1) | BF_CCM_CCGR58_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR58, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR58_SETTING2 (8U)        /*!< Bit position for CCM_CCGR58_SETTING2. */
#define BM_CCM_CCGR58_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR58_SETTING2. */
#define BS_CCM_CCGR58_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR58_SETTING2. */

/*! @brief Read current value of the CCM_CCGR58_SETTING2 field. */
#define BR_CCM_CCGR58_SETTING2(x) (HW_CCM_CCGR58(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR58_SETTING2. */
#define BF_CCM_CCGR58_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR58_SETTING2) & BM_CCM_CCGR58_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR58_SETTING2(x, v) (HW_CCM_CCGR58_WR(x, (HW_CCM_CCGR58_RD(x) & ~BM_CCM_CCGR58_SETTING2) | BF_CCM_CCGR58_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR58, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR58_SETTING3 (12U)       /*!< Bit position for CCM_CCGR58_SETTING3. */
#define BM_CCM_CCGR58_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR58_SETTING3. */
#define BS_CCM_CCGR58_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR58_SETTING3. */

/*! @brief Read current value of the CCM_CCGR58_SETTING3 field. */
#define BR_CCM_CCGR58_SETTING3(x) (HW_CCM_CCGR58(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR58_SETTING3. */
#define BF_CCM_CCGR58_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR58_SETTING3) & BM_CCM_CCGR58_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR58_SETTING3(x, v) (HW_CCM_CCGR58_WR(x, (HW_CCM_CCGR58_RD(x) & ~BM_CCM_CCGR58_SETTING3) | BF_CCM_CCGR58_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR59 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR59 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr59
{
    uint32_t U;
    struct _hw_ccm_ccgr59_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr59_t;

/*!
 * @name Constants and macros for entire CCM_CCGR59 register
 */
/*@{*/
#define HW_CCM_CCGR59_ADDR(x)    ((uintptr_t)(x) + 0x43B0U)
#define HW_CCM_CCGR59_SET_ADDR(x) (HW_CCM_CCGR59_ADDR(x) + 0x4U)
#define HW_CCM_CCGR59_CLR_ADDR(x) (HW_CCM_CCGR59_ADDR(x) + 0x8U)
#define HW_CCM_CCGR59_TOG_ADDR(x) (HW_CCM_CCGR59_ADDR(x) + 0xCU)

#define HW_CCM_CCGR59(x)         (*(__IO hw_ccm_ccgr59_t *) HW_CCM_CCGR59_ADDR(x))
#define HW_CCM_CCGR59_RD(x)      (HW_CCM_CCGR59(x).U)
#define HW_CCM_CCGR59_WR(x, v)   (HW_CCM_CCGR59(x).U = (v))
#define HW_CCM_CCGR59_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR59_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR59_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR59_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR59_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR59_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR59 bitfields
 */

/*!
 * @name Register CCM_CCGR59, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR59_SETTING0 (0U)        /*!< Bit position for CCM_CCGR59_SETTING0. */
#define BM_CCM_CCGR59_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR59_SETTING0. */
#define BS_CCM_CCGR59_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR59_SETTING0. */

/*! @brief Read current value of the CCM_CCGR59_SETTING0 field. */
#define BR_CCM_CCGR59_SETTING0(x) (HW_CCM_CCGR59(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR59_SETTING0. */
#define BF_CCM_CCGR59_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR59_SETTING0) & BM_CCM_CCGR59_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR59_SETTING0(x, v) (HW_CCM_CCGR59_WR(x, (HW_CCM_CCGR59_RD(x) & ~BM_CCM_CCGR59_SETTING0) | BF_CCM_CCGR59_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR59, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR59_SETTING1 (4U)        /*!< Bit position for CCM_CCGR59_SETTING1. */
#define BM_CCM_CCGR59_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR59_SETTING1. */
#define BS_CCM_CCGR59_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR59_SETTING1. */

/*! @brief Read current value of the CCM_CCGR59_SETTING1 field. */
#define BR_CCM_CCGR59_SETTING1(x) (HW_CCM_CCGR59(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR59_SETTING1. */
#define BF_CCM_CCGR59_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR59_SETTING1) & BM_CCM_CCGR59_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR59_SETTING1(x, v) (HW_CCM_CCGR59_WR(x, (HW_CCM_CCGR59_RD(x) & ~BM_CCM_CCGR59_SETTING1) | BF_CCM_CCGR59_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR59, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR59_SETTING2 (8U)        /*!< Bit position for CCM_CCGR59_SETTING2. */
#define BM_CCM_CCGR59_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR59_SETTING2. */
#define BS_CCM_CCGR59_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR59_SETTING2. */

/*! @brief Read current value of the CCM_CCGR59_SETTING2 field. */
#define BR_CCM_CCGR59_SETTING2(x) (HW_CCM_CCGR59(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR59_SETTING2. */
#define BF_CCM_CCGR59_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR59_SETTING2) & BM_CCM_CCGR59_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR59_SETTING2(x, v) (HW_CCM_CCGR59_WR(x, (HW_CCM_CCGR59_RD(x) & ~BM_CCM_CCGR59_SETTING2) | BF_CCM_CCGR59_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR59, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR59_SETTING3 (12U)       /*!< Bit position for CCM_CCGR59_SETTING3. */
#define BM_CCM_CCGR59_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR59_SETTING3. */
#define BS_CCM_CCGR59_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR59_SETTING3. */

/*! @brief Read current value of the CCM_CCGR59_SETTING3 field. */
#define BR_CCM_CCGR59_SETTING3(x) (HW_CCM_CCGR59(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR59_SETTING3. */
#define BF_CCM_CCGR59_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR59_SETTING3) & BM_CCM_CCGR59_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR59_SETTING3(x, v) (HW_CCM_CCGR59_WR(x, (HW_CCM_CCGR59_RD(x) & ~BM_CCM_CCGR59_SETTING3) | BF_CCM_CCGR59_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR60 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR60 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr60
{
    uint32_t U;
    struct _hw_ccm_ccgr60_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr60_t;

/*!
 * @name Constants and macros for entire CCM_CCGR60 register
 */
/*@{*/
#define HW_CCM_CCGR60_ADDR(x)    ((uintptr_t)(x) + 0x43C0U)
#define HW_CCM_CCGR60_SET_ADDR(x) (HW_CCM_CCGR60_ADDR(x) + 0x4U)
#define HW_CCM_CCGR60_CLR_ADDR(x) (HW_CCM_CCGR60_ADDR(x) + 0x8U)
#define HW_CCM_CCGR60_TOG_ADDR(x) (HW_CCM_CCGR60_ADDR(x) + 0xCU)

#define HW_CCM_CCGR60(x)         (*(__IO hw_ccm_ccgr60_t *) HW_CCM_CCGR60_ADDR(x))
#define HW_CCM_CCGR60_RD(x)      (HW_CCM_CCGR60(x).U)
#define HW_CCM_CCGR60_WR(x, v)   (HW_CCM_CCGR60(x).U = (v))
#define HW_CCM_CCGR60_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR60_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR60_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR60_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR60_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR60_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR60 bitfields
 */

/*!
 * @name Register CCM_CCGR60, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR60_SETTING0 (0U)        /*!< Bit position for CCM_CCGR60_SETTING0. */
#define BM_CCM_CCGR60_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR60_SETTING0. */
#define BS_CCM_CCGR60_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR60_SETTING0. */

/*! @brief Read current value of the CCM_CCGR60_SETTING0 field. */
#define BR_CCM_CCGR60_SETTING0(x) (HW_CCM_CCGR60(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR60_SETTING0. */
#define BF_CCM_CCGR60_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR60_SETTING0) & BM_CCM_CCGR60_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR60_SETTING0(x, v) (HW_CCM_CCGR60_WR(x, (HW_CCM_CCGR60_RD(x) & ~BM_CCM_CCGR60_SETTING0) | BF_CCM_CCGR60_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR60, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR60_SETTING1 (4U)        /*!< Bit position for CCM_CCGR60_SETTING1. */
#define BM_CCM_CCGR60_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR60_SETTING1. */
#define BS_CCM_CCGR60_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR60_SETTING1. */

/*! @brief Read current value of the CCM_CCGR60_SETTING1 field. */
#define BR_CCM_CCGR60_SETTING1(x) (HW_CCM_CCGR60(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR60_SETTING1. */
#define BF_CCM_CCGR60_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR60_SETTING1) & BM_CCM_CCGR60_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR60_SETTING1(x, v) (HW_CCM_CCGR60_WR(x, (HW_CCM_CCGR60_RD(x) & ~BM_CCM_CCGR60_SETTING1) | BF_CCM_CCGR60_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR60, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR60_SETTING2 (8U)        /*!< Bit position for CCM_CCGR60_SETTING2. */
#define BM_CCM_CCGR60_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR60_SETTING2. */
#define BS_CCM_CCGR60_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR60_SETTING2. */

/*! @brief Read current value of the CCM_CCGR60_SETTING2 field. */
#define BR_CCM_CCGR60_SETTING2(x) (HW_CCM_CCGR60(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR60_SETTING2. */
#define BF_CCM_CCGR60_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR60_SETTING2) & BM_CCM_CCGR60_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR60_SETTING2(x, v) (HW_CCM_CCGR60_WR(x, (HW_CCM_CCGR60_RD(x) & ~BM_CCM_CCGR60_SETTING2) | BF_CCM_CCGR60_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR60, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR60_SETTING3 (12U)       /*!< Bit position for CCM_CCGR60_SETTING3. */
#define BM_CCM_CCGR60_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR60_SETTING3. */
#define BS_CCM_CCGR60_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR60_SETTING3. */

/*! @brief Read current value of the CCM_CCGR60_SETTING3 field. */
#define BR_CCM_CCGR60_SETTING3(x) (HW_CCM_CCGR60(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR60_SETTING3. */
#define BF_CCM_CCGR60_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR60_SETTING3) & BM_CCM_CCGR60_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR60_SETTING3(x, v) (HW_CCM_CCGR60_WR(x, (HW_CCM_CCGR60_RD(x) & ~BM_CCM_CCGR60_SETTING3) | BF_CCM_CCGR60_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR61 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR61 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr61
{
    uint32_t U;
    struct _hw_ccm_ccgr61_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr61_t;

/*!
 * @name Constants and macros for entire CCM_CCGR61 register
 */
/*@{*/
#define HW_CCM_CCGR61_ADDR(x)    ((uintptr_t)(x) + 0x43D0U)
#define HW_CCM_CCGR61_SET_ADDR(x) (HW_CCM_CCGR61_ADDR(x) + 0x4U)
#define HW_CCM_CCGR61_CLR_ADDR(x) (HW_CCM_CCGR61_ADDR(x) + 0x8U)
#define HW_CCM_CCGR61_TOG_ADDR(x) (HW_CCM_CCGR61_ADDR(x) + 0xCU)

#define HW_CCM_CCGR61(x)         (*(__IO hw_ccm_ccgr61_t *) HW_CCM_CCGR61_ADDR(x))
#define HW_CCM_CCGR61_RD(x)      (HW_CCM_CCGR61(x).U)
#define HW_CCM_CCGR61_WR(x, v)   (HW_CCM_CCGR61(x).U = (v))
#define HW_CCM_CCGR61_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR61_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR61_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR61_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR61_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR61_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR61 bitfields
 */

/*!
 * @name Register CCM_CCGR61, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR61_SETTING0 (0U)        /*!< Bit position for CCM_CCGR61_SETTING0. */
#define BM_CCM_CCGR61_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR61_SETTING0. */
#define BS_CCM_CCGR61_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR61_SETTING0. */

/*! @brief Read current value of the CCM_CCGR61_SETTING0 field. */
#define BR_CCM_CCGR61_SETTING0(x) (HW_CCM_CCGR61(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR61_SETTING0. */
#define BF_CCM_CCGR61_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR61_SETTING0) & BM_CCM_CCGR61_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR61_SETTING0(x, v) (HW_CCM_CCGR61_WR(x, (HW_CCM_CCGR61_RD(x) & ~BM_CCM_CCGR61_SETTING0) | BF_CCM_CCGR61_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR61, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR61_SETTING1 (4U)        /*!< Bit position for CCM_CCGR61_SETTING1. */
#define BM_CCM_CCGR61_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR61_SETTING1. */
#define BS_CCM_CCGR61_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR61_SETTING1. */

/*! @brief Read current value of the CCM_CCGR61_SETTING1 field. */
#define BR_CCM_CCGR61_SETTING1(x) (HW_CCM_CCGR61(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR61_SETTING1. */
#define BF_CCM_CCGR61_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR61_SETTING1) & BM_CCM_CCGR61_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR61_SETTING1(x, v) (HW_CCM_CCGR61_WR(x, (HW_CCM_CCGR61_RD(x) & ~BM_CCM_CCGR61_SETTING1) | BF_CCM_CCGR61_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR61, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR61_SETTING2 (8U)        /*!< Bit position for CCM_CCGR61_SETTING2. */
#define BM_CCM_CCGR61_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR61_SETTING2. */
#define BS_CCM_CCGR61_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR61_SETTING2. */

/*! @brief Read current value of the CCM_CCGR61_SETTING2 field. */
#define BR_CCM_CCGR61_SETTING2(x) (HW_CCM_CCGR61(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR61_SETTING2. */
#define BF_CCM_CCGR61_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR61_SETTING2) & BM_CCM_CCGR61_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR61_SETTING2(x, v) (HW_CCM_CCGR61_WR(x, (HW_CCM_CCGR61_RD(x) & ~BM_CCM_CCGR61_SETTING2) | BF_CCM_CCGR61_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR61, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR61_SETTING3 (12U)       /*!< Bit position for CCM_CCGR61_SETTING3. */
#define BM_CCM_CCGR61_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR61_SETTING3. */
#define BS_CCM_CCGR61_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR61_SETTING3. */

/*! @brief Read current value of the CCM_CCGR61_SETTING3 field. */
#define BR_CCM_CCGR61_SETTING3(x) (HW_CCM_CCGR61(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR61_SETTING3. */
#define BF_CCM_CCGR61_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR61_SETTING3) & BM_CCM_CCGR61_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR61_SETTING3(x, v) (HW_CCM_CCGR61_WR(x, (HW_CCM_CCGR61_RD(x) & ~BM_CCM_CCGR61_SETTING3) | BF_CCM_CCGR61_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR62 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR62 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr62
{
    uint32_t U;
    struct _hw_ccm_ccgr62_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr62_t;

/*!
 * @name Constants and macros for entire CCM_CCGR62 register
 */
/*@{*/
#define HW_CCM_CCGR62_ADDR(x)    ((uintptr_t)(x) + 0x43E0U)
#define HW_CCM_CCGR62_SET_ADDR(x) (HW_CCM_CCGR62_ADDR(x) + 0x4U)
#define HW_CCM_CCGR62_CLR_ADDR(x) (HW_CCM_CCGR62_ADDR(x) + 0x8U)
#define HW_CCM_CCGR62_TOG_ADDR(x) (HW_CCM_CCGR62_ADDR(x) + 0xCU)

#define HW_CCM_CCGR62(x)         (*(__IO hw_ccm_ccgr62_t *) HW_CCM_CCGR62_ADDR(x))
#define HW_CCM_CCGR62_RD(x)      (HW_CCM_CCGR62(x).U)
#define HW_CCM_CCGR62_WR(x, v)   (HW_CCM_CCGR62(x).U = (v))
#define HW_CCM_CCGR62_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR62_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR62_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR62_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR62_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR62_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR62 bitfields
 */

/*!
 * @name Register CCM_CCGR62, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR62_SETTING0 (0U)        /*!< Bit position for CCM_CCGR62_SETTING0. */
#define BM_CCM_CCGR62_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR62_SETTING0. */
#define BS_CCM_CCGR62_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR62_SETTING0. */

/*! @brief Read current value of the CCM_CCGR62_SETTING0 field. */
#define BR_CCM_CCGR62_SETTING0(x) (HW_CCM_CCGR62(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR62_SETTING0. */
#define BF_CCM_CCGR62_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR62_SETTING0) & BM_CCM_CCGR62_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR62_SETTING0(x, v) (HW_CCM_CCGR62_WR(x, (HW_CCM_CCGR62_RD(x) & ~BM_CCM_CCGR62_SETTING0) | BF_CCM_CCGR62_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR62, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR62_SETTING1 (4U)        /*!< Bit position for CCM_CCGR62_SETTING1. */
#define BM_CCM_CCGR62_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR62_SETTING1. */
#define BS_CCM_CCGR62_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR62_SETTING1. */

/*! @brief Read current value of the CCM_CCGR62_SETTING1 field. */
#define BR_CCM_CCGR62_SETTING1(x) (HW_CCM_CCGR62(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR62_SETTING1. */
#define BF_CCM_CCGR62_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR62_SETTING1) & BM_CCM_CCGR62_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR62_SETTING1(x, v) (HW_CCM_CCGR62_WR(x, (HW_CCM_CCGR62_RD(x) & ~BM_CCM_CCGR62_SETTING1) | BF_CCM_CCGR62_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR62, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR62_SETTING2 (8U)        /*!< Bit position for CCM_CCGR62_SETTING2. */
#define BM_CCM_CCGR62_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR62_SETTING2. */
#define BS_CCM_CCGR62_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR62_SETTING2. */

/*! @brief Read current value of the CCM_CCGR62_SETTING2 field. */
#define BR_CCM_CCGR62_SETTING2(x) (HW_CCM_CCGR62(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR62_SETTING2. */
#define BF_CCM_CCGR62_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR62_SETTING2) & BM_CCM_CCGR62_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR62_SETTING2(x, v) (HW_CCM_CCGR62_WR(x, (HW_CCM_CCGR62_RD(x) & ~BM_CCM_CCGR62_SETTING2) | BF_CCM_CCGR62_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR62, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR62_SETTING3 (12U)       /*!< Bit position for CCM_CCGR62_SETTING3. */
#define BM_CCM_CCGR62_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR62_SETTING3. */
#define BS_CCM_CCGR62_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR62_SETTING3. */

/*! @brief Read current value of the CCM_CCGR62_SETTING3 field. */
#define BR_CCM_CCGR62_SETTING3(x) (HW_CCM_CCGR62(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR62_SETTING3. */
#define BF_CCM_CCGR62_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR62_SETTING3) & BM_CCM_CCGR62_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR62_SETTING3(x, v) (HW_CCM_CCGR62_WR(x, (HW_CCM_CCGR62_RD(x) & ~BM_CCM_CCGR62_SETTING3) | BF_CCM_CCGR62_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR63 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR63 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr63
{
    uint32_t U;
    struct _hw_ccm_ccgr63_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr63_t;

/*!
 * @name Constants and macros for entire CCM_CCGR63 register
 */
/*@{*/
#define HW_CCM_CCGR63_ADDR(x)    ((uintptr_t)(x) + 0x43F0U)
#define HW_CCM_CCGR63_SET_ADDR(x) (HW_CCM_CCGR63_ADDR(x) + 0x4U)
#define HW_CCM_CCGR63_CLR_ADDR(x) (HW_CCM_CCGR63_ADDR(x) + 0x8U)
#define HW_CCM_CCGR63_TOG_ADDR(x) (HW_CCM_CCGR63_ADDR(x) + 0xCU)

#define HW_CCM_CCGR63(x)         (*(__IO hw_ccm_ccgr63_t *) HW_CCM_CCGR63_ADDR(x))
#define HW_CCM_CCGR63_RD(x)      (HW_CCM_CCGR63(x).U)
#define HW_CCM_CCGR63_WR(x, v)   (HW_CCM_CCGR63(x).U = (v))
#define HW_CCM_CCGR63_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR63_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR63_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR63_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR63_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR63_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR63 bitfields
 */

/*!
 * @name Register CCM_CCGR63, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR63_SETTING0 (0U)        /*!< Bit position for CCM_CCGR63_SETTING0. */
#define BM_CCM_CCGR63_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR63_SETTING0. */
#define BS_CCM_CCGR63_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR63_SETTING0. */

/*! @brief Read current value of the CCM_CCGR63_SETTING0 field. */
#define BR_CCM_CCGR63_SETTING0(x) (HW_CCM_CCGR63(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR63_SETTING0. */
#define BF_CCM_CCGR63_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR63_SETTING0) & BM_CCM_CCGR63_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR63_SETTING0(x, v) (HW_CCM_CCGR63_WR(x, (HW_CCM_CCGR63_RD(x) & ~BM_CCM_CCGR63_SETTING0) | BF_CCM_CCGR63_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR63, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR63_SETTING1 (4U)        /*!< Bit position for CCM_CCGR63_SETTING1. */
#define BM_CCM_CCGR63_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR63_SETTING1. */
#define BS_CCM_CCGR63_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR63_SETTING1. */

/*! @brief Read current value of the CCM_CCGR63_SETTING1 field. */
#define BR_CCM_CCGR63_SETTING1(x) (HW_CCM_CCGR63(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR63_SETTING1. */
#define BF_CCM_CCGR63_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR63_SETTING1) & BM_CCM_CCGR63_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR63_SETTING1(x, v) (HW_CCM_CCGR63_WR(x, (HW_CCM_CCGR63_RD(x) & ~BM_CCM_CCGR63_SETTING1) | BF_CCM_CCGR63_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR63, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR63_SETTING2 (8U)        /*!< Bit position for CCM_CCGR63_SETTING2. */
#define BM_CCM_CCGR63_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR63_SETTING2. */
#define BS_CCM_CCGR63_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR63_SETTING2. */

/*! @brief Read current value of the CCM_CCGR63_SETTING2 field. */
#define BR_CCM_CCGR63_SETTING2(x) (HW_CCM_CCGR63(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR63_SETTING2. */
#define BF_CCM_CCGR63_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR63_SETTING2) & BM_CCM_CCGR63_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR63_SETTING2(x, v) (HW_CCM_CCGR63_WR(x, (HW_CCM_CCGR63_RD(x) & ~BM_CCM_CCGR63_SETTING2) | BF_CCM_CCGR63_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR63, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR63_SETTING3 (12U)       /*!< Bit position for CCM_CCGR63_SETTING3. */
#define BM_CCM_CCGR63_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR63_SETTING3. */
#define BS_CCM_CCGR63_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR63_SETTING3. */

/*! @brief Read current value of the CCM_CCGR63_SETTING3 field. */
#define BR_CCM_CCGR63_SETTING3(x) (HW_CCM_CCGR63(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR63_SETTING3. */
#define BF_CCM_CCGR63_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR63_SETTING3) & BM_CCM_CCGR63_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR63_SETTING3(x, v) (HW_CCM_CCGR63_WR(x, (HW_CCM_CCGR63_RD(x) & ~BM_CCM_CCGR63_SETTING3) | BF_CCM_CCGR63_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR64 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR64 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr64
{
    uint32_t U;
    struct _hw_ccm_ccgr64_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr64_t;

/*!
 * @name Constants and macros for entire CCM_CCGR64 register
 */
/*@{*/
#define HW_CCM_CCGR64_ADDR(x)    ((uintptr_t)(x) + 0x4400U)
#define HW_CCM_CCGR64_SET_ADDR(x) (HW_CCM_CCGR64_ADDR(x) + 0x4U)
#define HW_CCM_CCGR64_CLR_ADDR(x) (HW_CCM_CCGR64_ADDR(x) + 0x8U)
#define HW_CCM_CCGR64_TOG_ADDR(x) (HW_CCM_CCGR64_ADDR(x) + 0xCU)

#define HW_CCM_CCGR64(x)         (*(__IO hw_ccm_ccgr64_t *) HW_CCM_CCGR64_ADDR(x))
#define HW_CCM_CCGR64_RD(x)      (HW_CCM_CCGR64(x).U)
#define HW_CCM_CCGR64_WR(x, v)   (HW_CCM_CCGR64(x).U = (v))
#define HW_CCM_CCGR64_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR64_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR64_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR64_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR64_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR64_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR64 bitfields
 */

/*!
 * @name Register CCM_CCGR64, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR64_SETTING0 (0U)        /*!< Bit position for CCM_CCGR64_SETTING0. */
#define BM_CCM_CCGR64_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR64_SETTING0. */
#define BS_CCM_CCGR64_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR64_SETTING0. */

/*! @brief Read current value of the CCM_CCGR64_SETTING0 field. */
#define BR_CCM_CCGR64_SETTING0(x) (HW_CCM_CCGR64(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR64_SETTING0. */
#define BF_CCM_CCGR64_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR64_SETTING0) & BM_CCM_CCGR64_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR64_SETTING0(x, v) (HW_CCM_CCGR64_WR(x, (HW_CCM_CCGR64_RD(x) & ~BM_CCM_CCGR64_SETTING0) | BF_CCM_CCGR64_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR64, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR64_SETTING1 (4U)        /*!< Bit position for CCM_CCGR64_SETTING1. */
#define BM_CCM_CCGR64_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR64_SETTING1. */
#define BS_CCM_CCGR64_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR64_SETTING1. */

/*! @brief Read current value of the CCM_CCGR64_SETTING1 field. */
#define BR_CCM_CCGR64_SETTING1(x) (HW_CCM_CCGR64(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR64_SETTING1. */
#define BF_CCM_CCGR64_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR64_SETTING1) & BM_CCM_CCGR64_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR64_SETTING1(x, v) (HW_CCM_CCGR64_WR(x, (HW_CCM_CCGR64_RD(x) & ~BM_CCM_CCGR64_SETTING1) | BF_CCM_CCGR64_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR64, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR64_SETTING2 (8U)        /*!< Bit position for CCM_CCGR64_SETTING2. */
#define BM_CCM_CCGR64_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR64_SETTING2. */
#define BS_CCM_CCGR64_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR64_SETTING2. */

/*! @brief Read current value of the CCM_CCGR64_SETTING2 field. */
#define BR_CCM_CCGR64_SETTING2(x) (HW_CCM_CCGR64(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR64_SETTING2. */
#define BF_CCM_CCGR64_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR64_SETTING2) & BM_CCM_CCGR64_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR64_SETTING2(x, v) (HW_CCM_CCGR64_WR(x, (HW_CCM_CCGR64_RD(x) & ~BM_CCM_CCGR64_SETTING2) | BF_CCM_CCGR64_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR64, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR64_SETTING3 (12U)       /*!< Bit position for CCM_CCGR64_SETTING3. */
#define BM_CCM_CCGR64_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR64_SETTING3. */
#define BS_CCM_CCGR64_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR64_SETTING3. */

/*! @brief Read current value of the CCM_CCGR64_SETTING3 field. */
#define BR_CCM_CCGR64_SETTING3(x) (HW_CCM_CCGR64(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR64_SETTING3. */
#define BF_CCM_CCGR64_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR64_SETTING3) & BM_CCM_CCGR64_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR64_SETTING3(x, v) (HW_CCM_CCGR64_WR(x, (HW_CCM_CCGR64_RD(x) & ~BM_CCM_CCGR64_SETTING3) | BF_CCM_CCGR64_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR65 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR65 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr65
{
    uint32_t U;
    struct _hw_ccm_ccgr65_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr65_t;

/*!
 * @name Constants and macros for entire CCM_CCGR65 register
 */
/*@{*/
#define HW_CCM_CCGR65_ADDR(x)    ((uintptr_t)(x) + 0x4410U)
#define HW_CCM_CCGR65_SET_ADDR(x) (HW_CCM_CCGR65_ADDR(x) + 0x4U)
#define HW_CCM_CCGR65_CLR_ADDR(x) (HW_CCM_CCGR65_ADDR(x) + 0x8U)
#define HW_CCM_CCGR65_TOG_ADDR(x) (HW_CCM_CCGR65_ADDR(x) + 0xCU)

#define HW_CCM_CCGR65(x)         (*(__IO hw_ccm_ccgr65_t *) HW_CCM_CCGR65_ADDR(x))
#define HW_CCM_CCGR65_RD(x)      (HW_CCM_CCGR65(x).U)
#define HW_CCM_CCGR65_WR(x, v)   (HW_CCM_CCGR65(x).U = (v))
#define HW_CCM_CCGR65_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR65_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR65_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR65_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR65_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR65_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR65 bitfields
 */

/*!
 * @name Register CCM_CCGR65, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR65_SETTING0 (0U)        /*!< Bit position for CCM_CCGR65_SETTING0. */
#define BM_CCM_CCGR65_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR65_SETTING0. */
#define BS_CCM_CCGR65_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR65_SETTING0. */

/*! @brief Read current value of the CCM_CCGR65_SETTING0 field. */
#define BR_CCM_CCGR65_SETTING0(x) (HW_CCM_CCGR65(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR65_SETTING0. */
#define BF_CCM_CCGR65_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR65_SETTING0) & BM_CCM_CCGR65_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR65_SETTING0(x, v) (HW_CCM_CCGR65_WR(x, (HW_CCM_CCGR65_RD(x) & ~BM_CCM_CCGR65_SETTING0) | BF_CCM_CCGR65_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR65, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR65_SETTING1 (4U)        /*!< Bit position for CCM_CCGR65_SETTING1. */
#define BM_CCM_CCGR65_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR65_SETTING1. */
#define BS_CCM_CCGR65_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR65_SETTING1. */

/*! @brief Read current value of the CCM_CCGR65_SETTING1 field. */
#define BR_CCM_CCGR65_SETTING1(x) (HW_CCM_CCGR65(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR65_SETTING1. */
#define BF_CCM_CCGR65_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR65_SETTING1) & BM_CCM_CCGR65_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR65_SETTING1(x, v) (HW_CCM_CCGR65_WR(x, (HW_CCM_CCGR65_RD(x) & ~BM_CCM_CCGR65_SETTING1) | BF_CCM_CCGR65_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR65, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR65_SETTING2 (8U)        /*!< Bit position for CCM_CCGR65_SETTING2. */
#define BM_CCM_CCGR65_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR65_SETTING2. */
#define BS_CCM_CCGR65_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR65_SETTING2. */

/*! @brief Read current value of the CCM_CCGR65_SETTING2 field. */
#define BR_CCM_CCGR65_SETTING2(x) (HW_CCM_CCGR65(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR65_SETTING2. */
#define BF_CCM_CCGR65_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR65_SETTING2) & BM_CCM_CCGR65_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR65_SETTING2(x, v) (HW_CCM_CCGR65_WR(x, (HW_CCM_CCGR65_RD(x) & ~BM_CCM_CCGR65_SETTING2) | BF_CCM_CCGR65_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR65, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR65_SETTING3 (12U)       /*!< Bit position for CCM_CCGR65_SETTING3. */
#define BM_CCM_CCGR65_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR65_SETTING3. */
#define BS_CCM_CCGR65_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR65_SETTING3. */

/*! @brief Read current value of the CCM_CCGR65_SETTING3 field. */
#define BR_CCM_CCGR65_SETTING3(x) (HW_CCM_CCGR65(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR65_SETTING3. */
#define BF_CCM_CCGR65_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR65_SETTING3) & BM_CCM_CCGR65_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR65_SETTING3(x, v) (HW_CCM_CCGR65_WR(x, (HW_CCM_CCGR65_RD(x) & ~BM_CCM_CCGR65_SETTING3) | BF_CCM_CCGR65_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR66 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR66 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr66
{
    uint32_t U;
    struct _hw_ccm_ccgr66_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr66_t;

/*!
 * @name Constants and macros for entire CCM_CCGR66 register
 */
/*@{*/
#define HW_CCM_CCGR66_ADDR(x)    ((uintptr_t)(x) + 0x4420U)
#define HW_CCM_CCGR66_SET_ADDR(x) (HW_CCM_CCGR66_ADDR(x) + 0x4U)
#define HW_CCM_CCGR66_CLR_ADDR(x) (HW_CCM_CCGR66_ADDR(x) + 0x8U)
#define HW_CCM_CCGR66_TOG_ADDR(x) (HW_CCM_CCGR66_ADDR(x) + 0xCU)

#define HW_CCM_CCGR66(x)         (*(__IO hw_ccm_ccgr66_t *) HW_CCM_CCGR66_ADDR(x))
#define HW_CCM_CCGR66_RD(x)      (HW_CCM_CCGR66(x).U)
#define HW_CCM_CCGR66_WR(x, v)   (HW_CCM_CCGR66(x).U = (v))
#define HW_CCM_CCGR66_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR66_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR66_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR66_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR66_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR66_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR66 bitfields
 */

/*!
 * @name Register CCM_CCGR66, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR66_SETTING0 (0U)        /*!< Bit position for CCM_CCGR66_SETTING0. */
#define BM_CCM_CCGR66_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR66_SETTING0. */
#define BS_CCM_CCGR66_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR66_SETTING0. */

/*! @brief Read current value of the CCM_CCGR66_SETTING0 field. */
#define BR_CCM_CCGR66_SETTING0(x) (HW_CCM_CCGR66(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR66_SETTING0. */
#define BF_CCM_CCGR66_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR66_SETTING0) & BM_CCM_CCGR66_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR66_SETTING0(x, v) (HW_CCM_CCGR66_WR(x, (HW_CCM_CCGR66_RD(x) & ~BM_CCM_CCGR66_SETTING0) | BF_CCM_CCGR66_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR66, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR66_SETTING1 (4U)        /*!< Bit position for CCM_CCGR66_SETTING1. */
#define BM_CCM_CCGR66_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR66_SETTING1. */
#define BS_CCM_CCGR66_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR66_SETTING1. */

/*! @brief Read current value of the CCM_CCGR66_SETTING1 field. */
#define BR_CCM_CCGR66_SETTING1(x) (HW_CCM_CCGR66(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR66_SETTING1. */
#define BF_CCM_CCGR66_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR66_SETTING1) & BM_CCM_CCGR66_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR66_SETTING1(x, v) (HW_CCM_CCGR66_WR(x, (HW_CCM_CCGR66_RD(x) & ~BM_CCM_CCGR66_SETTING1) | BF_CCM_CCGR66_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR66, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR66_SETTING2 (8U)        /*!< Bit position for CCM_CCGR66_SETTING2. */
#define BM_CCM_CCGR66_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR66_SETTING2. */
#define BS_CCM_CCGR66_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR66_SETTING2. */

/*! @brief Read current value of the CCM_CCGR66_SETTING2 field. */
#define BR_CCM_CCGR66_SETTING2(x) (HW_CCM_CCGR66(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR66_SETTING2. */
#define BF_CCM_CCGR66_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR66_SETTING2) & BM_CCM_CCGR66_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR66_SETTING2(x, v) (HW_CCM_CCGR66_WR(x, (HW_CCM_CCGR66_RD(x) & ~BM_CCM_CCGR66_SETTING2) | BF_CCM_CCGR66_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR66, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR66_SETTING3 (12U)       /*!< Bit position for CCM_CCGR66_SETTING3. */
#define BM_CCM_CCGR66_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR66_SETTING3. */
#define BS_CCM_CCGR66_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR66_SETTING3. */

/*! @brief Read current value of the CCM_CCGR66_SETTING3 field. */
#define BR_CCM_CCGR66_SETTING3(x) (HW_CCM_CCGR66(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR66_SETTING3. */
#define BF_CCM_CCGR66_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR66_SETTING3) & BM_CCM_CCGR66_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR66_SETTING3(x, v) (HW_CCM_CCGR66_WR(x, (HW_CCM_CCGR66_RD(x) & ~BM_CCM_CCGR66_SETTING3) | BF_CCM_CCGR66_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR67 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR67 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr67
{
    uint32_t U;
    struct _hw_ccm_ccgr67_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr67_t;

/*!
 * @name Constants and macros for entire CCM_CCGR67 register
 */
/*@{*/
#define HW_CCM_CCGR67_ADDR(x)    ((uintptr_t)(x) + 0x4430U)
#define HW_CCM_CCGR67_SET_ADDR(x) (HW_CCM_CCGR67_ADDR(x) + 0x4U)
#define HW_CCM_CCGR67_CLR_ADDR(x) (HW_CCM_CCGR67_ADDR(x) + 0x8U)
#define HW_CCM_CCGR67_TOG_ADDR(x) (HW_CCM_CCGR67_ADDR(x) + 0xCU)

#define HW_CCM_CCGR67(x)         (*(__IO hw_ccm_ccgr67_t *) HW_CCM_CCGR67_ADDR(x))
#define HW_CCM_CCGR67_RD(x)      (HW_CCM_CCGR67(x).U)
#define HW_CCM_CCGR67_WR(x, v)   (HW_CCM_CCGR67(x).U = (v))
#define HW_CCM_CCGR67_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR67_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR67_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR67_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR67_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR67_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR67 bitfields
 */

/*!
 * @name Register CCM_CCGR67, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR67_SETTING0 (0U)        /*!< Bit position for CCM_CCGR67_SETTING0. */
#define BM_CCM_CCGR67_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR67_SETTING0. */
#define BS_CCM_CCGR67_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR67_SETTING0. */

/*! @brief Read current value of the CCM_CCGR67_SETTING0 field. */
#define BR_CCM_CCGR67_SETTING0(x) (HW_CCM_CCGR67(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR67_SETTING0. */
#define BF_CCM_CCGR67_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR67_SETTING0) & BM_CCM_CCGR67_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR67_SETTING0(x, v) (HW_CCM_CCGR67_WR(x, (HW_CCM_CCGR67_RD(x) & ~BM_CCM_CCGR67_SETTING0) | BF_CCM_CCGR67_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR67, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR67_SETTING1 (4U)        /*!< Bit position for CCM_CCGR67_SETTING1. */
#define BM_CCM_CCGR67_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR67_SETTING1. */
#define BS_CCM_CCGR67_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR67_SETTING1. */

/*! @brief Read current value of the CCM_CCGR67_SETTING1 field. */
#define BR_CCM_CCGR67_SETTING1(x) (HW_CCM_CCGR67(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR67_SETTING1. */
#define BF_CCM_CCGR67_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR67_SETTING1) & BM_CCM_CCGR67_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR67_SETTING1(x, v) (HW_CCM_CCGR67_WR(x, (HW_CCM_CCGR67_RD(x) & ~BM_CCM_CCGR67_SETTING1) | BF_CCM_CCGR67_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR67, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR67_SETTING2 (8U)        /*!< Bit position for CCM_CCGR67_SETTING2. */
#define BM_CCM_CCGR67_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR67_SETTING2. */
#define BS_CCM_CCGR67_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR67_SETTING2. */

/*! @brief Read current value of the CCM_CCGR67_SETTING2 field. */
#define BR_CCM_CCGR67_SETTING2(x) (HW_CCM_CCGR67(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR67_SETTING2. */
#define BF_CCM_CCGR67_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR67_SETTING2) & BM_CCM_CCGR67_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR67_SETTING2(x, v) (HW_CCM_CCGR67_WR(x, (HW_CCM_CCGR67_RD(x) & ~BM_CCM_CCGR67_SETTING2) | BF_CCM_CCGR67_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR67, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR67_SETTING3 (12U)       /*!< Bit position for CCM_CCGR67_SETTING3. */
#define BM_CCM_CCGR67_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR67_SETTING3. */
#define BS_CCM_CCGR67_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR67_SETTING3. */

/*! @brief Read current value of the CCM_CCGR67_SETTING3 field. */
#define BR_CCM_CCGR67_SETTING3(x) (HW_CCM_CCGR67(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR67_SETTING3. */
#define BF_CCM_CCGR67_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR67_SETTING3) & BM_CCM_CCGR67_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR67_SETTING3(x, v) (HW_CCM_CCGR67_WR(x, (HW_CCM_CCGR67_RD(x) & ~BM_CCM_CCGR67_SETTING3) | BF_CCM_CCGR67_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR68 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR68 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr68
{
    uint32_t U;
    struct _hw_ccm_ccgr68_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr68_t;

/*!
 * @name Constants and macros for entire CCM_CCGR68 register
 */
/*@{*/
#define HW_CCM_CCGR68_ADDR(x)    ((uintptr_t)(x) + 0x4440U)
#define HW_CCM_CCGR68_SET_ADDR(x) (HW_CCM_CCGR68_ADDR(x) + 0x4U)
#define HW_CCM_CCGR68_CLR_ADDR(x) (HW_CCM_CCGR68_ADDR(x) + 0x8U)
#define HW_CCM_CCGR68_TOG_ADDR(x) (HW_CCM_CCGR68_ADDR(x) + 0xCU)

#define HW_CCM_CCGR68(x)         (*(__IO hw_ccm_ccgr68_t *) HW_CCM_CCGR68_ADDR(x))
#define HW_CCM_CCGR68_RD(x)      (HW_CCM_CCGR68(x).U)
#define HW_CCM_CCGR68_WR(x, v)   (HW_CCM_CCGR68(x).U = (v))
#define HW_CCM_CCGR68_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR68_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR68_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR68_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR68_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR68_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR68 bitfields
 */

/*!
 * @name Register CCM_CCGR68, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR68_SETTING0 (0U)        /*!< Bit position for CCM_CCGR68_SETTING0. */
#define BM_CCM_CCGR68_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR68_SETTING0. */
#define BS_CCM_CCGR68_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR68_SETTING0. */

/*! @brief Read current value of the CCM_CCGR68_SETTING0 field. */
#define BR_CCM_CCGR68_SETTING0(x) (HW_CCM_CCGR68(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR68_SETTING0. */
#define BF_CCM_CCGR68_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR68_SETTING0) & BM_CCM_CCGR68_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR68_SETTING0(x, v) (HW_CCM_CCGR68_WR(x, (HW_CCM_CCGR68_RD(x) & ~BM_CCM_CCGR68_SETTING0) | BF_CCM_CCGR68_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR68, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR68_SETTING1 (4U)        /*!< Bit position for CCM_CCGR68_SETTING1. */
#define BM_CCM_CCGR68_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR68_SETTING1. */
#define BS_CCM_CCGR68_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR68_SETTING1. */

/*! @brief Read current value of the CCM_CCGR68_SETTING1 field. */
#define BR_CCM_CCGR68_SETTING1(x) (HW_CCM_CCGR68(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR68_SETTING1. */
#define BF_CCM_CCGR68_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR68_SETTING1) & BM_CCM_CCGR68_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR68_SETTING1(x, v) (HW_CCM_CCGR68_WR(x, (HW_CCM_CCGR68_RD(x) & ~BM_CCM_CCGR68_SETTING1) | BF_CCM_CCGR68_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR68, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR68_SETTING2 (8U)        /*!< Bit position for CCM_CCGR68_SETTING2. */
#define BM_CCM_CCGR68_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR68_SETTING2. */
#define BS_CCM_CCGR68_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR68_SETTING2. */

/*! @brief Read current value of the CCM_CCGR68_SETTING2 field. */
#define BR_CCM_CCGR68_SETTING2(x) (HW_CCM_CCGR68(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR68_SETTING2. */
#define BF_CCM_CCGR68_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR68_SETTING2) & BM_CCM_CCGR68_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR68_SETTING2(x, v) (HW_CCM_CCGR68_WR(x, (HW_CCM_CCGR68_RD(x) & ~BM_CCM_CCGR68_SETTING2) | BF_CCM_CCGR68_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR68, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR68_SETTING3 (12U)       /*!< Bit position for CCM_CCGR68_SETTING3. */
#define BM_CCM_CCGR68_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR68_SETTING3. */
#define BS_CCM_CCGR68_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR68_SETTING3. */

/*! @brief Read current value of the CCM_CCGR68_SETTING3 field. */
#define BR_CCM_CCGR68_SETTING3(x) (HW_CCM_CCGR68(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR68_SETTING3. */
#define BF_CCM_CCGR68_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR68_SETTING3) & BM_CCM_CCGR68_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR68_SETTING3(x, v) (HW_CCM_CCGR68_WR(x, (HW_CCM_CCGR68_RD(x) & ~BM_CCM_CCGR68_SETTING3) | BF_CCM_CCGR68_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR69 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR69 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr69
{
    uint32_t U;
    struct _hw_ccm_ccgr69_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr69_t;

/*!
 * @name Constants and macros for entire CCM_CCGR69 register
 */
/*@{*/
#define HW_CCM_CCGR69_ADDR(x)    ((uintptr_t)(x) + 0x4450U)
#define HW_CCM_CCGR69_SET_ADDR(x) (HW_CCM_CCGR69_ADDR(x) + 0x4U)
#define HW_CCM_CCGR69_CLR_ADDR(x) (HW_CCM_CCGR69_ADDR(x) + 0x8U)
#define HW_CCM_CCGR69_TOG_ADDR(x) (HW_CCM_CCGR69_ADDR(x) + 0xCU)

#define HW_CCM_CCGR69(x)         (*(__IO hw_ccm_ccgr69_t *) HW_CCM_CCGR69_ADDR(x))
#define HW_CCM_CCGR69_RD(x)      (HW_CCM_CCGR69(x).U)
#define HW_CCM_CCGR69_WR(x, v)   (HW_CCM_CCGR69(x).U = (v))
#define HW_CCM_CCGR69_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR69_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR69_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR69_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR69_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR69_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR69 bitfields
 */

/*!
 * @name Register CCM_CCGR69, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR69_SETTING0 (0U)        /*!< Bit position for CCM_CCGR69_SETTING0. */
#define BM_CCM_CCGR69_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR69_SETTING0. */
#define BS_CCM_CCGR69_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR69_SETTING0. */

/*! @brief Read current value of the CCM_CCGR69_SETTING0 field. */
#define BR_CCM_CCGR69_SETTING0(x) (HW_CCM_CCGR69(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR69_SETTING0. */
#define BF_CCM_CCGR69_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR69_SETTING0) & BM_CCM_CCGR69_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR69_SETTING0(x, v) (HW_CCM_CCGR69_WR(x, (HW_CCM_CCGR69_RD(x) & ~BM_CCM_CCGR69_SETTING0) | BF_CCM_CCGR69_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR69, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR69_SETTING1 (4U)        /*!< Bit position for CCM_CCGR69_SETTING1. */
#define BM_CCM_CCGR69_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR69_SETTING1. */
#define BS_CCM_CCGR69_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR69_SETTING1. */

/*! @brief Read current value of the CCM_CCGR69_SETTING1 field. */
#define BR_CCM_CCGR69_SETTING1(x) (HW_CCM_CCGR69(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR69_SETTING1. */
#define BF_CCM_CCGR69_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR69_SETTING1) & BM_CCM_CCGR69_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR69_SETTING1(x, v) (HW_CCM_CCGR69_WR(x, (HW_CCM_CCGR69_RD(x) & ~BM_CCM_CCGR69_SETTING1) | BF_CCM_CCGR69_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR69, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR69_SETTING2 (8U)        /*!< Bit position for CCM_CCGR69_SETTING2. */
#define BM_CCM_CCGR69_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR69_SETTING2. */
#define BS_CCM_CCGR69_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR69_SETTING2. */

/*! @brief Read current value of the CCM_CCGR69_SETTING2 field. */
#define BR_CCM_CCGR69_SETTING2(x) (HW_CCM_CCGR69(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR69_SETTING2. */
#define BF_CCM_CCGR69_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR69_SETTING2) & BM_CCM_CCGR69_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR69_SETTING2(x, v) (HW_CCM_CCGR69_WR(x, (HW_CCM_CCGR69_RD(x) & ~BM_CCM_CCGR69_SETTING2) | BF_CCM_CCGR69_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR69, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR69_SETTING3 (12U)       /*!< Bit position for CCM_CCGR69_SETTING3. */
#define BM_CCM_CCGR69_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR69_SETTING3. */
#define BS_CCM_CCGR69_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR69_SETTING3. */

/*! @brief Read current value of the CCM_CCGR69_SETTING3 field. */
#define BR_CCM_CCGR69_SETTING3(x) (HW_CCM_CCGR69(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR69_SETTING3. */
#define BF_CCM_CCGR69_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR69_SETTING3) & BM_CCM_CCGR69_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR69_SETTING3(x, v) (HW_CCM_CCGR69_WR(x, (HW_CCM_CCGR69_RD(x) & ~BM_CCM_CCGR69_SETTING3) | BF_CCM_CCGR69_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR70 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR70 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr70
{
    uint32_t U;
    struct _hw_ccm_ccgr70_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr70_t;

/*!
 * @name Constants and macros for entire CCM_CCGR70 register
 */
/*@{*/
#define HW_CCM_CCGR70_ADDR(x)    ((uintptr_t)(x) + 0x4460U)
#define HW_CCM_CCGR70_SET_ADDR(x) (HW_CCM_CCGR70_ADDR(x) + 0x4U)
#define HW_CCM_CCGR70_CLR_ADDR(x) (HW_CCM_CCGR70_ADDR(x) + 0x8U)
#define HW_CCM_CCGR70_TOG_ADDR(x) (HW_CCM_CCGR70_ADDR(x) + 0xCU)

#define HW_CCM_CCGR70(x)         (*(__IO hw_ccm_ccgr70_t *) HW_CCM_CCGR70_ADDR(x))
#define HW_CCM_CCGR70_RD(x)      (HW_CCM_CCGR70(x).U)
#define HW_CCM_CCGR70_WR(x, v)   (HW_CCM_CCGR70(x).U = (v))
#define HW_CCM_CCGR70_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR70_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR70_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR70_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR70_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR70_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR70 bitfields
 */

/*!
 * @name Register CCM_CCGR70, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR70_SETTING0 (0U)        /*!< Bit position for CCM_CCGR70_SETTING0. */
#define BM_CCM_CCGR70_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR70_SETTING0. */
#define BS_CCM_CCGR70_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR70_SETTING0. */

/*! @brief Read current value of the CCM_CCGR70_SETTING0 field. */
#define BR_CCM_CCGR70_SETTING0(x) (HW_CCM_CCGR70(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR70_SETTING0. */
#define BF_CCM_CCGR70_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR70_SETTING0) & BM_CCM_CCGR70_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR70_SETTING0(x, v) (HW_CCM_CCGR70_WR(x, (HW_CCM_CCGR70_RD(x) & ~BM_CCM_CCGR70_SETTING0) | BF_CCM_CCGR70_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR70, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR70_SETTING1 (4U)        /*!< Bit position for CCM_CCGR70_SETTING1. */
#define BM_CCM_CCGR70_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR70_SETTING1. */
#define BS_CCM_CCGR70_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR70_SETTING1. */

/*! @brief Read current value of the CCM_CCGR70_SETTING1 field. */
#define BR_CCM_CCGR70_SETTING1(x) (HW_CCM_CCGR70(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR70_SETTING1. */
#define BF_CCM_CCGR70_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR70_SETTING1) & BM_CCM_CCGR70_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR70_SETTING1(x, v) (HW_CCM_CCGR70_WR(x, (HW_CCM_CCGR70_RD(x) & ~BM_CCM_CCGR70_SETTING1) | BF_CCM_CCGR70_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR70, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR70_SETTING2 (8U)        /*!< Bit position for CCM_CCGR70_SETTING2. */
#define BM_CCM_CCGR70_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR70_SETTING2. */
#define BS_CCM_CCGR70_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR70_SETTING2. */

/*! @brief Read current value of the CCM_CCGR70_SETTING2 field. */
#define BR_CCM_CCGR70_SETTING2(x) (HW_CCM_CCGR70(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR70_SETTING2. */
#define BF_CCM_CCGR70_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR70_SETTING2) & BM_CCM_CCGR70_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR70_SETTING2(x, v) (HW_CCM_CCGR70_WR(x, (HW_CCM_CCGR70_RD(x) & ~BM_CCM_CCGR70_SETTING2) | BF_CCM_CCGR70_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR70, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR70_SETTING3 (12U)       /*!< Bit position for CCM_CCGR70_SETTING3. */
#define BM_CCM_CCGR70_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR70_SETTING3. */
#define BS_CCM_CCGR70_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR70_SETTING3. */

/*! @brief Read current value of the CCM_CCGR70_SETTING3 field. */
#define BR_CCM_CCGR70_SETTING3(x) (HW_CCM_CCGR70(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR70_SETTING3. */
#define BF_CCM_CCGR70_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR70_SETTING3) & BM_CCM_CCGR70_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR70_SETTING3(x, v) (HW_CCM_CCGR70_WR(x, (HW_CCM_CCGR70_RD(x) & ~BM_CCM_CCGR70_SETTING3) | BF_CCM_CCGR70_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR71 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR71 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr71
{
    uint32_t U;
    struct _hw_ccm_ccgr71_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr71_t;

/*!
 * @name Constants and macros for entire CCM_CCGR71 register
 */
/*@{*/
#define HW_CCM_CCGR71_ADDR(x)    ((uintptr_t)(x) + 0x4470U)
#define HW_CCM_CCGR71_SET_ADDR(x) (HW_CCM_CCGR71_ADDR(x) + 0x4U)
#define HW_CCM_CCGR71_CLR_ADDR(x) (HW_CCM_CCGR71_ADDR(x) + 0x8U)
#define HW_CCM_CCGR71_TOG_ADDR(x) (HW_CCM_CCGR71_ADDR(x) + 0xCU)

#define HW_CCM_CCGR71(x)         (*(__IO hw_ccm_ccgr71_t *) HW_CCM_CCGR71_ADDR(x))
#define HW_CCM_CCGR71_RD(x)      (HW_CCM_CCGR71(x).U)
#define HW_CCM_CCGR71_WR(x, v)   (HW_CCM_CCGR71(x).U = (v))
#define HW_CCM_CCGR71_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR71_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR71_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR71_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR71_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR71_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR71 bitfields
 */

/*!
 * @name Register CCM_CCGR71, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR71_SETTING0 (0U)        /*!< Bit position for CCM_CCGR71_SETTING0. */
#define BM_CCM_CCGR71_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR71_SETTING0. */
#define BS_CCM_CCGR71_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR71_SETTING0. */

/*! @brief Read current value of the CCM_CCGR71_SETTING0 field. */
#define BR_CCM_CCGR71_SETTING0(x) (HW_CCM_CCGR71(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR71_SETTING0. */
#define BF_CCM_CCGR71_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR71_SETTING0) & BM_CCM_CCGR71_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR71_SETTING0(x, v) (HW_CCM_CCGR71_WR(x, (HW_CCM_CCGR71_RD(x) & ~BM_CCM_CCGR71_SETTING0) | BF_CCM_CCGR71_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR71, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR71_SETTING1 (4U)        /*!< Bit position for CCM_CCGR71_SETTING1. */
#define BM_CCM_CCGR71_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR71_SETTING1. */
#define BS_CCM_CCGR71_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR71_SETTING1. */

/*! @brief Read current value of the CCM_CCGR71_SETTING1 field. */
#define BR_CCM_CCGR71_SETTING1(x) (HW_CCM_CCGR71(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR71_SETTING1. */
#define BF_CCM_CCGR71_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR71_SETTING1) & BM_CCM_CCGR71_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR71_SETTING1(x, v) (HW_CCM_CCGR71_WR(x, (HW_CCM_CCGR71_RD(x) & ~BM_CCM_CCGR71_SETTING1) | BF_CCM_CCGR71_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR71, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR71_SETTING2 (8U)        /*!< Bit position for CCM_CCGR71_SETTING2. */
#define BM_CCM_CCGR71_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR71_SETTING2. */
#define BS_CCM_CCGR71_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR71_SETTING2. */

/*! @brief Read current value of the CCM_CCGR71_SETTING2 field. */
#define BR_CCM_CCGR71_SETTING2(x) (HW_CCM_CCGR71(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR71_SETTING2. */
#define BF_CCM_CCGR71_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR71_SETTING2) & BM_CCM_CCGR71_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR71_SETTING2(x, v) (HW_CCM_CCGR71_WR(x, (HW_CCM_CCGR71_RD(x) & ~BM_CCM_CCGR71_SETTING2) | BF_CCM_CCGR71_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR71, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR71_SETTING3 (12U)       /*!< Bit position for CCM_CCGR71_SETTING3. */
#define BM_CCM_CCGR71_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR71_SETTING3. */
#define BS_CCM_CCGR71_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR71_SETTING3. */

/*! @brief Read current value of the CCM_CCGR71_SETTING3 field. */
#define BR_CCM_CCGR71_SETTING3(x) (HW_CCM_CCGR71(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR71_SETTING3. */
#define BF_CCM_CCGR71_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR71_SETTING3) & BM_CCM_CCGR71_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR71_SETTING3(x, v) (HW_CCM_CCGR71_WR(x, (HW_CCM_CCGR71_RD(x) & ~BM_CCM_CCGR71_SETTING3) | BF_CCM_CCGR71_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR72 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR72 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr72
{
    uint32_t U;
    struct _hw_ccm_ccgr72_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr72_t;

/*!
 * @name Constants and macros for entire CCM_CCGR72 register
 */
/*@{*/
#define HW_CCM_CCGR72_ADDR(x)    ((uintptr_t)(x) + 0x4480U)
#define HW_CCM_CCGR72_SET_ADDR(x) (HW_CCM_CCGR72_ADDR(x) + 0x4U)
#define HW_CCM_CCGR72_CLR_ADDR(x) (HW_CCM_CCGR72_ADDR(x) + 0x8U)
#define HW_CCM_CCGR72_TOG_ADDR(x) (HW_CCM_CCGR72_ADDR(x) + 0xCU)

#define HW_CCM_CCGR72(x)         (*(__IO hw_ccm_ccgr72_t *) HW_CCM_CCGR72_ADDR(x))
#define HW_CCM_CCGR72_RD(x)      (HW_CCM_CCGR72(x).U)
#define HW_CCM_CCGR72_WR(x, v)   (HW_CCM_CCGR72(x).U = (v))
#define HW_CCM_CCGR72_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR72_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR72_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR72_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR72_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR72_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR72 bitfields
 */

/*!
 * @name Register CCM_CCGR72, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR72_SETTING0 (0U)        /*!< Bit position for CCM_CCGR72_SETTING0. */
#define BM_CCM_CCGR72_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR72_SETTING0. */
#define BS_CCM_CCGR72_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR72_SETTING0. */

/*! @brief Read current value of the CCM_CCGR72_SETTING0 field. */
#define BR_CCM_CCGR72_SETTING0(x) (HW_CCM_CCGR72(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR72_SETTING0. */
#define BF_CCM_CCGR72_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR72_SETTING0) & BM_CCM_CCGR72_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR72_SETTING0(x, v) (HW_CCM_CCGR72_WR(x, (HW_CCM_CCGR72_RD(x) & ~BM_CCM_CCGR72_SETTING0) | BF_CCM_CCGR72_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR72, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR72_SETTING1 (4U)        /*!< Bit position for CCM_CCGR72_SETTING1. */
#define BM_CCM_CCGR72_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR72_SETTING1. */
#define BS_CCM_CCGR72_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR72_SETTING1. */

/*! @brief Read current value of the CCM_CCGR72_SETTING1 field. */
#define BR_CCM_CCGR72_SETTING1(x) (HW_CCM_CCGR72(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR72_SETTING1. */
#define BF_CCM_CCGR72_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR72_SETTING1) & BM_CCM_CCGR72_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR72_SETTING1(x, v) (HW_CCM_CCGR72_WR(x, (HW_CCM_CCGR72_RD(x) & ~BM_CCM_CCGR72_SETTING1) | BF_CCM_CCGR72_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR72, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR72_SETTING2 (8U)        /*!< Bit position for CCM_CCGR72_SETTING2. */
#define BM_CCM_CCGR72_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR72_SETTING2. */
#define BS_CCM_CCGR72_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR72_SETTING2. */

/*! @brief Read current value of the CCM_CCGR72_SETTING2 field. */
#define BR_CCM_CCGR72_SETTING2(x) (HW_CCM_CCGR72(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR72_SETTING2. */
#define BF_CCM_CCGR72_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR72_SETTING2) & BM_CCM_CCGR72_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR72_SETTING2(x, v) (HW_CCM_CCGR72_WR(x, (HW_CCM_CCGR72_RD(x) & ~BM_CCM_CCGR72_SETTING2) | BF_CCM_CCGR72_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR72, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR72_SETTING3 (12U)       /*!< Bit position for CCM_CCGR72_SETTING3. */
#define BM_CCM_CCGR72_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR72_SETTING3. */
#define BS_CCM_CCGR72_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR72_SETTING3. */

/*! @brief Read current value of the CCM_CCGR72_SETTING3 field. */
#define BR_CCM_CCGR72_SETTING3(x) (HW_CCM_CCGR72(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR72_SETTING3. */
#define BF_CCM_CCGR72_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR72_SETTING3) & BM_CCM_CCGR72_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR72_SETTING3(x, v) (HW_CCM_CCGR72_WR(x, (HW_CCM_CCGR72_RD(x) & ~BM_CCM_CCGR72_SETTING3) | BF_CCM_CCGR72_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR73 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR73 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr73
{
    uint32_t U;
    struct _hw_ccm_ccgr73_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr73_t;

/*!
 * @name Constants and macros for entire CCM_CCGR73 register
 */
/*@{*/
#define HW_CCM_CCGR73_ADDR(x)    ((uintptr_t)(x) + 0x4490U)
#define HW_CCM_CCGR73_SET_ADDR(x) (HW_CCM_CCGR73_ADDR(x) + 0x4U)
#define HW_CCM_CCGR73_CLR_ADDR(x) (HW_CCM_CCGR73_ADDR(x) + 0x8U)
#define HW_CCM_CCGR73_TOG_ADDR(x) (HW_CCM_CCGR73_ADDR(x) + 0xCU)

#define HW_CCM_CCGR73(x)         (*(__IO hw_ccm_ccgr73_t *) HW_CCM_CCGR73_ADDR(x))
#define HW_CCM_CCGR73_RD(x)      (HW_CCM_CCGR73(x).U)
#define HW_CCM_CCGR73_WR(x, v)   (HW_CCM_CCGR73(x).U = (v))
#define HW_CCM_CCGR73_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR73_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR73_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR73_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR73_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR73_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR73 bitfields
 */

/*!
 * @name Register CCM_CCGR73, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR73_SETTING0 (0U)        /*!< Bit position for CCM_CCGR73_SETTING0. */
#define BM_CCM_CCGR73_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR73_SETTING0. */
#define BS_CCM_CCGR73_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR73_SETTING0. */

/*! @brief Read current value of the CCM_CCGR73_SETTING0 field. */
#define BR_CCM_CCGR73_SETTING0(x) (HW_CCM_CCGR73(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR73_SETTING0. */
#define BF_CCM_CCGR73_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR73_SETTING0) & BM_CCM_CCGR73_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR73_SETTING0(x, v) (HW_CCM_CCGR73_WR(x, (HW_CCM_CCGR73_RD(x) & ~BM_CCM_CCGR73_SETTING0) | BF_CCM_CCGR73_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR73, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR73_SETTING1 (4U)        /*!< Bit position for CCM_CCGR73_SETTING1. */
#define BM_CCM_CCGR73_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR73_SETTING1. */
#define BS_CCM_CCGR73_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR73_SETTING1. */

/*! @brief Read current value of the CCM_CCGR73_SETTING1 field. */
#define BR_CCM_CCGR73_SETTING1(x) (HW_CCM_CCGR73(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR73_SETTING1. */
#define BF_CCM_CCGR73_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR73_SETTING1) & BM_CCM_CCGR73_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR73_SETTING1(x, v) (HW_CCM_CCGR73_WR(x, (HW_CCM_CCGR73_RD(x) & ~BM_CCM_CCGR73_SETTING1) | BF_CCM_CCGR73_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR73, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR73_SETTING2 (8U)        /*!< Bit position for CCM_CCGR73_SETTING2. */
#define BM_CCM_CCGR73_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR73_SETTING2. */
#define BS_CCM_CCGR73_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR73_SETTING2. */

/*! @brief Read current value of the CCM_CCGR73_SETTING2 field. */
#define BR_CCM_CCGR73_SETTING2(x) (HW_CCM_CCGR73(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR73_SETTING2. */
#define BF_CCM_CCGR73_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR73_SETTING2) & BM_CCM_CCGR73_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR73_SETTING2(x, v) (HW_CCM_CCGR73_WR(x, (HW_CCM_CCGR73_RD(x) & ~BM_CCM_CCGR73_SETTING2) | BF_CCM_CCGR73_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR73, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR73_SETTING3 (12U)       /*!< Bit position for CCM_CCGR73_SETTING3. */
#define BM_CCM_CCGR73_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR73_SETTING3. */
#define BS_CCM_CCGR73_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR73_SETTING3. */

/*! @brief Read current value of the CCM_CCGR73_SETTING3 field. */
#define BR_CCM_CCGR73_SETTING3(x) (HW_CCM_CCGR73(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR73_SETTING3. */
#define BF_CCM_CCGR73_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR73_SETTING3) & BM_CCM_CCGR73_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR73_SETTING3(x, v) (HW_CCM_CCGR73_WR(x, (HW_CCM_CCGR73_RD(x) & ~BM_CCM_CCGR73_SETTING3) | BF_CCM_CCGR73_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR74 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR74 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr74
{
    uint32_t U;
    struct _hw_ccm_ccgr74_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr74_t;

/*!
 * @name Constants and macros for entire CCM_CCGR74 register
 */
/*@{*/
#define HW_CCM_CCGR74_ADDR(x)    ((uintptr_t)(x) + 0x44A0U)
#define HW_CCM_CCGR74_SET_ADDR(x) (HW_CCM_CCGR74_ADDR(x) + 0x4U)
#define HW_CCM_CCGR74_CLR_ADDR(x) (HW_CCM_CCGR74_ADDR(x) + 0x8U)
#define HW_CCM_CCGR74_TOG_ADDR(x) (HW_CCM_CCGR74_ADDR(x) + 0xCU)

#define HW_CCM_CCGR74(x)         (*(__IO hw_ccm_ccgr74_t *) HW_CCM_CCGR74_ADDR(x))
#define HW_CCM_CCGR74_RD(x)      (HW_CCM_CCGR74(x).U)
#define HW_CCM_CCGR74_WR(x, v)   (HW_CCM_CCGR74(x).U = (v))
#define HW_CCM_CCGR74_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR74_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR74_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR74_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR74_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR74_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR74 bitfields
 */

/*!
 * @name Register CCM_CCGR74, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR74_SETTING0 (0U)        /*!< Bit position for CCM_CCGR74_SETTING0. */
#define BM_CCM_CCGR74_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR74_SETTING0. */
#define BS_CCM_CCGR74_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR74_SETTING0. */

/*! @brief Read current value of the CCM_CCGR74_SETTING0 field. */
#define BR_CCM_CCGR74_SETTING0(x) (HW_CCM_CCGR74(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR74_SETTING0. */
#define BF_CCM_CCGR74_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR74_SETTING0) & BM_CCM_CCGR74_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR74_SETTING0(x, v) (HW_CCM_CCGR74_WR(x, (HW_CCM_CCGR74_RD(x) & ~BM_CCM_CCGR74_SETTING0) | BF_CCM_CCGR74_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR74, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR74_SETTING1 (4U)        /*!< Bit position for CCM_CCGR74_SETTING1. */
#define BM_CCM_CCGR74_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR74_SETTING1. */
#define BS_CCM_CCGR74_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR74_SETTING1. */

/*! @brief Read current value of the CCM_CCGR74_SETTING1 field. */
#define BR_CCM_CCGR74_SETTING1(x) (HW_CCM_CCGR74(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR74_SETTING1. */
#define BF_CCM_CCGR74_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR74_SETTING1) & BM_CCM_CCGR74_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR74_SETTING1(x, v) (HW_CCM_CCGR74_WR(x, (HW_CCM_CCGR74_RD(x) & ~BM_CCM_CCGR74_SETTING1) | BF_CCM_CCGR74_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR74, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR74_SETTING2 (8U)        /*!< Bit position for CCM_CCGR74_SETTING2. */
#define BM_CCM_CCGR74_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR74_SETTING2. */
#define BS_CCM_CCGR74_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR74_SETTING2. */

/*! @brief Read current value of the CCM_CCGR74_SETTING2 field. */
#define BR_CCM_CCGR74_SETTING2(x) (HW_CCM_CCGR74(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR74_SETTING2. */
#define BF_CCM_CCGR74_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR74_SETTING2) & BM_CCM_CCGR74_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR74_SETTING2(x, v) (HW_CCM_CCGR74_WR(x, (HW_CCM_CCGR74_RD(x) & ~BM_CCM_CCGR74_SETTING2) | BF_CCM_CCGR74_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR74, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR74_SETTING3 (12U)       /*!< Bit position for CCM_CCGR74_SETTING3. */
#define BM_CCM_CCGR74_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR74_SETTING3. */
#define BS_CCM_CCGR74_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR74_SETTING3. */

/*! @brief Read current value of the CCM_CCGR74_SETTING3 field. */
#define BR_CCM_CCGR74_SETTING3(x) (HW_CCM_CCGR74(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR74_SETTING3. */
#define BF_CCM_CCGR74_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR74_SETTING3) & BM_CCM_CCGR74_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR74_SETTING3(x, v) (HW_CCM_CCGR74_WR(x, (HW_CCM_CCGR74_RD(x) & ~BM_CCM_CCGR74_SETTING3) | BF_CCM_CCGR74_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR75 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR75 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr75
{
    uint32_t U;
    struct _hw_ccm_ccgr75_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr75_t;

/*!
 * @name Constants and macros for entire CCM_CCGR75 register
 */
/*@{*/
#define HW_CCM_CCGR75_ADDR(x)    ((uintptr_t)(x) + 0x44B0U)
#define HW_CCM_CCGR75_SET_ADDR(x) (HW_CCM_CCGR75_ADDR(x) + 0x4U)
#define HW_CCM_CCGR75_CLR_ADDR(x) (HW_CCM_CCGR75_ADDR(x) + 0x8U)
#define HW_CCM_CCGR75_TOG_ADDR(x) (HW_CCM_CCGR75_ADDR(x) + 0xCU)

#define HW_CCM_CCGR75(x)         (*(__IO hw_ccm_ccgr75_t *) HW_CCM_CCGR75_ADDR(x))
#define HW_CCM_CCGR75_RD(x)      (HW_CCM_CCGR75(x).U)
#define HW_CCM_CCGR75_WR(x, v)   (HW_CCM_CCGR75(x).U = (v))
#define HW_CCM_CCGR75_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR75_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR75_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR75_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR75_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR75_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR75 bitfields
 */

/*!
 * @name Register CCM_CCGR75, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR75_SETTING0 (0U)        /*!< Bit position for CCM_CCGR75_SETTING0. */
#define BM_CCM_CCGR75_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR75_SETTING0. */
#define BS_CCM_CCGR75_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR75_SETTING0. */

/*! @brief Read current value of the CCM_CCGR75_SETTING0 field. */
#define BR_CCM_CCGR75_SETTING0(x) (HW_CCM_CCGR75(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR75_SETTING0. */
#define BF_CCM_CCGR75_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR75_SETTING0) & BM_CCM_CCGR75_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR75_SETTING0(x, v) (HW_CCM_CCGR75_WR(x, (HW_CCM_CCGR75_RD(x) & ~BM_CCM_CCGR75_SETTING0) | BF_CCM_CCGR75_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR75, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR75_SETTING1 (4U)        /*!< Bit position for CCM_CCGR75_SETTING1. */
#define BM_CCM_CCGR75_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR75_SETTING1. */
#define BS_CCM_CCGR75_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR75_SETTING1. */

/*! @brief Read current value of the CCM_CCGR75_SETTING1 field. */
#define BR_CCM_CCGR75_SETTING1(x) (HW_CCM_CCGR75(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR75_SETTING1. */
#define BF_CCM_CCGR75_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR75_SETTING1) & BM_CCM_CCGR75_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR75_SETTING1(x, v) (HW_CCM_CCGR75_WR(x, (HW_CCM_CCGR75_RD(x) & ~BM_CCM_CCGR75_SETTING1) | BF_CCM_CCGR75_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR75, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR75_SETTING2 (8U)        /*!< Bit position for CCM_CCGR75_SETTING2. */
#define BM_CCM_CCGR75_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR75_SETTING2. */
#define BS_CCM_CCGR75_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR75_SETTING2. */

/*! @brief Read current value of the CCM_CCGR75_SETTING2 field. */
#define BR_CCM_CCGR75_SETTING2(x) (HW_CCM_CCGR75(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR75_SETTING2. */
#define BF_CCM_CCGR75_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR75_SETTING2) & BM_CCM_CCGR75_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR75_SETTING2(x, v) (HW_CCM_CCGR75_WR(x, (HW_CCM_CCGR75_RD(x) & ~BM_CCM_CCGR75_SETTING2) | BF_CCM_CCGR75_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR75, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR75_SETTING3 (12U)       /*!< Bit position for CCM_CCGR75_SETTING3. */
#define BM_CCM_CCGR75_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR75_SETTING3. */
#define BS_CCM_CCGR75_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR75_SETTING3. */

/*! @brief Read current value of the CCM_CCGR75_SETTING3 field. */
#define BR_CCM_CCGR75_SETTING3(x) (HW_CCM_CCGR75(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR75_SETTING3. */
#define BF_CCM_CCGR75_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR75_SETTING3) & BM_CCM_CCGR75_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR75_SETTING3(x, v) (HW_CCM_CCGR75_WR(x, (HW_CCM_CCGR75_RD(x) & ~BM_CCM_CCGR75_SETTING3) | BF_CCM_CCGR75_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR76 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR76 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr76
{
    uint32_t U;
    struct _hw_ccm_ccgr76_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr76_t;

/*!
 * @name Constants and macros for entire CCM_CCGR76 register
 */
/*@{*/
#define HW_CCM_CCGR76_ADDR(x)    ((uintptr_t)(x) + 0x44C0U)
#define HW_CCM_CCGR76_SET_ADDR(x) (HW_CCM_CCGR76_ADDR(x) + 0x4U)
#define HW_CCM_CCGR76_CLR_ADDR(x) (HW_CCM_CCGR76_ADDR(x) + 0x8U)
#define HW_CCM_CCGR76_TOG_ADDR(x) (HW_CCM_CCGR76_ADDR(x) + 0xCU)

#define HW_CCM_CCGR76(x)         (*(__IO hw_ccm_ccgr76_t *) HW_CCM_CCGR76_ADDR(x))
#define HW_CCM_CCGR76_RD(x)      (HW_CCM_CCGR76(x).U)
#define HW_CCM_CCGR76_WR(x, v)   (HW_CCM_CCGR76(x).U = (v))
#define HW_CCM_CCGR76_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR76_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR76_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR76_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR76_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR76_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR76 bitfields
 */

/*!
 * @name Register CCM_CCGR76, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR76_SETTING0 (0U)        /*!< Bit position for CCM_CCGR76_SETTING0. */
#define BM_CCM_CCGR76_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR76_SETTING0. */
#define BS_CCM_CCGR76_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR76_SETTING0. */

/*! @brief Read current value of the CCM_CCGR76_SETTING0 field. */
#define BR_CCM_CCGR76_SETTING0(x) (HW_CCM_CCGR76(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR76_SETTING0. */
#define BF_CCM_CCGR76_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR76_SETTING0) & BM_CCM_CCGR76_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR76_SETTING0(x, v) (HW_CCM_CCGR76_WR(x, (HW_CCM_CCGR76_RD(x) & ~BM_CCM_CCGR76_SETTING0) | BF_CCM_CCGR76_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR76, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR76_SETTING1 (4U)        /*!< Bit position for CCM_CCGR76_SETTING1. */
#define BM_CCM_CCGR76_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR76_SETTING1. */
#define BS_CCM_CCGR76_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR76_SETTING1. */

/*! @brief Read current value of the CCM_CCGR76_SETTING1 field. */
#define BR_CCM_CCGR76_SETTING1(x) (HW_CCM_CCGR76(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR76_SETTING1. */
#define BF_CCM_CCGR76_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR76_SETTING1) & BM_CCM_CCGR76_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR76_SETTING1(x, v) (HW_CCM_CCGR76_WR(x, (HW_CCM_CCGR76_RD(x) & ~BM_CCM_CCGR76_SETTING1) | BF_CCM_CCGR76_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR76, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR76_SETTING2 (8U)        /*!< Bit position for CCM_CCGR76_SETTING2. */
#define BM_CCM_CCGR76_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR76_SETTING2. */
#define BS_CCM_CCGR76_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR76_SETTING2. */

/*! @brief Read current value of the CCM_CCGR76_SETTING2 field. */
#define BR_CCM_CCGR76_SETTING2(x) (HW_CCM_CCGR76(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR76_SETTING2. */
#define BF_CCM_CCGR76_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR76_SETTING2) & BM_CCM_CCGR76_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR76_SETTING2(x, v) (HW_CCM_CCGR76_WR(x, (HW_CCM_CCGR76_RD(x) & ~BM_CCM_CCGR76_SETTING2) | BF_CCM_CCGR76_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR76, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR76_SETTING3 (12U)       /*!< Bit position for CCM_CCGR76_SETTING3. */
#define BM_CCM_CCGR76_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR76_SETTING3. */
#define BS_CCM_CCGR76_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR76_SETTING3. */

/*! @brief Read current value of the CCM_CCGR76_SETTING3 field. */
#define BR_CCM_CCGR76_SETTING3(x) (HW_CCM_CCGR76(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR76_SETTING3. */
#define BF_CCM_CCGR76_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR76_SETTING3) & BM_CCM_CCGR76_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR76_SETTING3(x, v) (HW_CCM_CCGR76_WR(x, (HW_CCM_CCGR76_RD(x) & ~BM_CCM_CCGR76_SETTING3) | BF_CCM_CCGR76_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR77 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR77 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr77
{
    uint32_t U;
    struct _hw_ccm_ccgr77_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr77_t;

/*!
 * @name Constants and macros for entire CCM_CCGR77 register
 */
/*@{*/
#define HW_CCM_CCGR77_ADDR(x)    ((uintptr_t)(x) + 0x44D0U)
#define HW_CCM_CCGR77_SET_ADDR(x) (HW_CCM_CCGR77_ADDR(x) + 0x4U)
#define HW_CCM_CCGR77_CLR_ADDR(x) (HW_CCM_CCGR77_ADDR(x) + 0x8U)
#define HW_CCM_CCGR77_TOG_ADDR(x) (HW_CCM_CCGR77_ADDR(x) + 0xCU)

#define HW_CCM_CCGR77(x)         (*(__IO hw_ccm_ccgr77_t *) HW_CCM_CCGR77_ADDR(x))
#define HW_CCM_CCGR77_RD(x)      (HW_CCM_CCGR77(x).U)
#define HW_CCM_CCGR77_WR(x, v)   (HW_CCM_CCGR77(x).U = (v))
#define HW_CCM_CCGR77_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR77_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR77_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR77_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR77_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR77_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR77 bitfields
 */

/*!
 * @name Register CCM_CCGR77, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR77_SETTING0 (0U)        /*!< Bit position for CCM_CCGR77_SETTING0. */
#define BM_CCM_CCGR77_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR77_SETTING0. */
#define BS_CCM_CCGR77_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR77_SETTING0. */

/*! @brief Read current value of the CCM_CCGR77_SETTING0 field. */
#define BR_CCM_CCGR77_SETTING0(x) (HW_CCM_CCGR77(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR77_SETTING0. */
#define BF_CCM_CCGR77_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR77_SETTING0) & BM_CCM_CCGR77_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR77_SETTING0(x, v) (HW_CCM_CCGR77_WR(x, (HW_CCM_CCGR77_RD(x) & ~BM_CCM_CCGR77_SETTING0) | BF_CCM_CCGR77_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR77, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR77_SETTING1 (4U)        /*!< Bit position for CCM_CCGR77_SETTING1. */
#define BM_CCM_CCGR77_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR77_SETTING1. */
#define BS_CCM_CCGR77_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR77_SETTING1. */

/*! @brief Read current value of the CCM_CCGR77_SETTING1 field. */
#define BR_CCM_CCGR77_SETTING1(x) (HW_CCM_CCGR77(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR77_SETTING1. */
#define BF_CCM_CCGR77_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR77_SETTING1) & BM_CCM_CCGR77_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR77_SETTING1(x, v) (HW_CCM_CCGR77_WR(x, (HW_CCM_CCGR77_RD(x) & ~BM_CCM_CCGR77_SETTING1) | BF_CCM_CCGR77_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR77, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR77_SETTING2 (8U)        /*!< Bit position for CCM_CCGR77_SETTING2. */
#define BM_CCM_CCGR77_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR77_SETTING2. */
#define BS_CCM_CCGR77_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR77_SETTING2. */

/*! @brief Read current value of the CCM_CCGR77_SETTING2 field. */
#define BR_CCM_CCGR77_SETTING2(x) (HW_CCM_CCGR77(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR77_SETTING2. */
#define BF_CCM_CCGR77_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR77_SETTING2) & BM_CCM_CCGR77_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR77_SETTING2(x, v) (HW_CCM_CCGR77_WR(x, (HW_CCM_CCGR77_RD(x) & ~BM_CCM_CCGR77_SETTING2) | BF_CCM_CCGR77_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR77, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR77_SETTING3 (12U)       /*!< Bit position for CCM_CCGR77_SETTING3. */
#define BM_CCM_CCGR77_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR77_SETTING3. */
#define BS_CCM_CCGR77_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR77_SETTING3. */

/*! @brief Read current value of the CCM_CCGR77_SETTING3 field. */
#define BR_CCM_CCGR77_SETTING3(x) (HW_CCM_CCGR77(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR77_SETTING3. */
#define BF_CCM_CCGR77_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR77_SETTING3) & BM_CCM_CCGR77_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR77_SETTING3(x, v) (HW_CCM_CCGR77_WR(x, (HW_CCM_CCGR77_RD(x) & ~BM_CCM_CCGR77_SETTING3) | BF_CCM_CCGR77_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR78 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR78 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr78
{
    uint32_t U;
    struct _hw_ccm_ccgr78_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr78_t;

/*!
 * @name Constants and macros for entire CCM_CCGR78 register
 */
/*@{*/
#define HW_CCM_CCGR78_ADDR(x)    ((uintptr_t)(x) + 0x44E0U)
#define HW_CCM_CCGR78_SET_ADDR(x) (HW_CCM_CCGR78_ADDR(x) + 0x4U)
#define HW_CCM_CCGR78_CLR_ADDR(x) (HW_CCM_CCGR78_ADDR(x) + 0x8U)
#define HW_CCM_CCGR78_TOG_ADDR(x) (HW_CCM_CCGR78_ADDR(x) + 0xCU)

#define HW_CCM_CCGR78(x)         (*(__IO hw_ccm_ccgr78_t *) HW_CCM_CCGR78_ADDR(x))
#define HW_CCM_CCGR78_RD(x)      (HW_CCM_CCGR78(x).U)
#define HW_CCM_CCGR78_WR(x, v)   (HW_CCM_CCGR78(x).U = (v))
#define HW_CCM_CCGR78_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR78_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR78_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR78_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR78_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR78_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR78 bitfields
 */

/*!
 * @name Register CCM_CCGR78, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR78_SETTING0 (0U)        /*!< Bit position for CCM_CCGR78_SETTING0. */
#define BM_CCM_CCGR78_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR78_SETTING0. */
#define BS_CCM_CCGR78_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR78_SETTING0. */

/*! @brief Read current value of the CCM_CCGR78_SETTING0 field. */
#define BR_CCM_CCGR78_SETTING0(x) (HW_CCM_CCGR78(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR78_SETTING0. */
#define BF_CCM_CCGR78_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR78_SETTING0) & BM_CCM_CCGR78_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR78_SETTING0(x, v) (HW_CCM_CCGR78_WR(x, (HW_CCM_CCGR78_RD(x) & ~BM_CCM_CCGR78_SETTING0) | BF_CCM_CCGR78_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR78, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR78_SETTING1 (4U)        /*!< Bit position for CCM_CCGR78_SETTING1. */
#define BM_CCM_CCGR78_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR78_SETTING1. */
#define BS_CCM_CCGR78_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR78_SETTING1. */

/*! @brief Read current value of the CCM_CCGR78_SETTING1 field. */
#define BR_CCM_CCGR78_SETTING1(x) (HW_CCM_CCGR78(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR78_SETTING1. */
#define BF_CCM_CCGR78_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR78_SETTING1) & BM_CCM_CCGR78_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR78_SETTING1(x, v) (HW_CCM_CCGR78_WR(x, (HW_CCM_CCGR78_RD(x) & ~BM_CCM_CCGR78_SETTING1) | BF_CCM_CCGR78_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR78, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR78_SETTING2 (8U)        /*!< Bit position for CCM_CCGR78_SETTING2. */
#define BM_CCM_CCGR78_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR78_SETTING2. */
#define BS_CCM_CCGR78_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR78_SETTING2. */

/*! @brief Read current value of the CCM_CCGR78_SETTING2 field. */
#define BR_CCM_CCGR78_SETTING2(x) (HW_CCM_CCGR78(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR78_SETTING2. */
#define BF_CCM_CCGR78_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR78_SETTING2) & BM_CCM_CCGR78_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR78_SETTING2(x, v) (HW_CCM_CCGR78_WR(x, (HW_CCM_CCGR78_RD(x) & ~BM_CCM_CCGR78_SETTING2) | BF_CCM_CCGR78_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR78, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR78_SETTING3 (12U)       /*!< Bit position for CCM_CCGR78_SETTING3. */
#define BM_CCM_CCGR78_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR78_SETTING3. */
#define BS_CCM_CCGR78_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR78_SETTING3. */

/*! @brief Read current value of the CCM_CCGR78_SETTING3 field. */
#define BR_CCM_CCGR78_SETTING3(x) (HW_CCM_CCGR78(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR78_SETTING3. */
#define BF_CCM_CCGR78_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR78_SETTING3) & BM_CCM_CCGR78_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR78_SETTING3(x, v) (HW_CCM_CCGR78_WR(x, (HW_CCM_CCGR78_RD(x) & ~BM_CCM_CCGR78_SETTING3) | BF_CCM_CCGR78_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR79 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR79 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr79
{
    uint32_t U;
    struct _hw_ccm_ccgr79_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr79_t;

/*!
 * @name Constants and macros for entire CCM_CCGR79 register
 */
/*@{*/
#define HW_CCM_CCGR79_ADDR(x)    ((uintptr_t)(x) + 0x44F0U)
#define HW_CCM_CCGR79_SET_ADDR(x) (HW_CCM_CCGR79_ADDR(x) + 0x4U)
#define HW_CCM_CCGR79_CLR_ADDR(x) (HW_CCM_CCGR79_ADDR(x) + 0x8U)
#define HW_CCM_CCGR79_TOG_ADDR(x) (HW_CCM_CCGR79_ADDR(x) + 0xCU)

#define HW_CCM_CCGR79(x)         (*(__IO hw_ccm_ccgr79_t *) HW_CCM_CCGR79_ADDR(x))
#define HW_CCM_CCGR79_RD(x)      (HW_CCM_CCGR79(x).U)
#define HW_CCM_CCGR79_WR(x, v)   (HW_CCM_CCGR79(x).U = (v))
#define HW_CCM_CCGR79_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR79_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR79_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR79_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR79_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR79_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR79 bitfields
 */

/*!
 * @name Register CCM_CCGR79, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR79_SETTING0 (0U)        /*!< Bit position for CCM_CCGR79_SETTING0. */
#define BM_CCM_CCGR79_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR79_SETTING0. */
#define BS_CCM_CCGR79_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR79_SETTING0. */

/*! @brief Read current value of the CCM_CCGR79_SETTING0 field. */
#define BR_CCM_CCGR79_SETTING0(x) (HW_CCM_CCGR79(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR79_SETTING0. */
#define BF_CCM_CCGR79_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR79_SETTING0) & BM_CCM_CCGR79_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR79_SETTING0(x, v) (HW_CCM_CCGR79_WR(x, (HW_CCM_CCGR79_RD(x) & ~BM_CCM_CCGR79_SETTING0) | BF_CCM_CCGR79_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR79, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR79_SETTING1 (4U)        /*!< Bit position for CCM_CCGR79_SETTING1. */
#define BM_CCM_CCGR79_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR79_SETTING1. */
#define BS_CCM_CCGR79_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR79_SETTING1. */

/*! @brief Read current value of the CCM_CCGR79_SETTING1 field. */
#define BR_CCM_CCGR79_SETTING1(x) (HW_CCM_CCGR79(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR79_SETTING1. */
#define BF_CCM_CCGR79_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR79_SETTING1) & BM_CCM_CCGR79_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR79_SETTING1(x, v) (HW_CCM_CCGR79_WR(x, (HW_CCM_CCGR79_RD(x) & ~BM_CCM_CCGR79_SETTING1) | BF_CCM_CCGR79_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR79, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR79_SETTING2 (8U)        /*!< Bit position for CCM_CCGR79_SETTING2. */
#define BM_CCM_CCGR79_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR79_SETTING2. */
#define BS_CCM_CCGR79_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR79_SETTING2. */

/*! @brief Read current value of the CCM_CCGR79_SETTING2 field. */
#define BR_CCM_CCGR79_SETTING2(x) (HW_CCM_CCGR79(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR79_SETTING2. */
#define BF_CCM_CCGR79_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR79_SETTING2) & BM_CCM_CCGR79_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR79_SETTING2(x, v) (HW_CCM_CCGR79_WR(x, (HW_CCM_CCGR79_RD(x) & ~BM_CCM_CCGR79_SETTING2) | BF_CCM_CCGR79_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR79, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR79_SETTING3 (12U)       /*!< Bit position for CCM_CCGR79_SETTING3. */
#define BM_CCM_CCGR79_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR79_SETTING3. */
#define BS_CCM_CCGR79_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR79_SETTING3. */

/*! @brief Read current value of the CCM_CCGR79_SETTING3 field. */
#define BR_CCM_CCGR79_SETTING3(x) (HW_CCM_CCGR79(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR79_SETTING3. */
#define BF_CCM_CCGR79_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR79_SETTING3) & BM_CCM_CCGR79_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR79_SETTING3(x, v) (HW_CCM_CCGR79_WR(x, (HW_CCM_CCGR79_RD(x) & ~BM_CCM_CCGR79_SETTING3) | BF_CCM_CCGR79_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR80 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR80 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr80
{
    uint32_t U;
    struct _hw_ccm_ccgr80_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr80_t;

/*!
 * @name Constants and macros for entire CCM_CCGR80 register
 */
/*@{*/
#define HW_CCM_CCGR80_ADDR(x)    ((uintptr_t)(x) + 0x4500U)
#define HW_CCM_CCGR80_SET_ADDR(x) (HW_CCM_CCGR80_ADDR(x) + 0x4U)
#define HW_CCM_CCGR80_CLR_ADDR(x) (HW_CCM_CCGR80_ADDR(x) + 0x8U)
#define HW_CCM_CCGR80_TOG_ADDR(x) (HW_CCM_CCGR80_ADDR(x) + 0xCU)

#define HW_CCM_CCGR80(x)         (*(__IO hw_ccm_ccgr80_t *) HW_CCM_CCGR80_ADDR(x))
#define HW_CCM_CCGR80_RD(x)      (HW_CCM_CCGR80(x).U)
#define HW_CCM_CCGR80_WR(x, v)   (HW_CCM_CCGR80(x).U = (v))
#define HW_CCM_CCGR80_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR80_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR80_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR80_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR80_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR80_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR80 bitfields
 */

/*!
 * @name Register CCM_CCGR80, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR80_SETTING0 (0U)        /*!< Bit position for CCM_CCGR80_SETTING0. */
#define BM_CCM_CCGR80_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR80_SETTING0. */
#define BS_CCM_CCGR80_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR80_SETTING0. */

/*! @brief Read current value of the CCM_CCGR80_SETTING0 field. */
#define BR_CCM_CCGR80_SETTING0(x) (HW_CCM_CCGR80(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR80_SETTING0. */
#define BF_CCM_CCGR80_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR80_SETTING0) & BM_CCM_CCGR80_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR80_SETTING0(x, v) (HW_CCM_CCGR80_WR(x, (HW_CCM_CCGR80_RD(x) & ~BM_CCM_CCGR80_SETTING0) | BF_CCM_CCGR80_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR80, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR80_SETTING1 (4U)        /*!< Bit position for CCM_CCGR80_SETTING1. */
#define BM_CCM_CCGR80_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR80_SETTING1. */
#define BS_CCM_CCGR80_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR80_SETTING1. */

/*! @brief Read current value of the CCM_CCGR80_SETTING1 field. */
#define BR_CCM_CCGR80_SETTING1(x) (HW_CCM_CCGR80(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR80_SETTING1. */
#define BF_CCM_CCGR80_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR80_SETTING1) & BM_CCM_CCGR80_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR80_SETTING1(x, v) (HW_CCM_CCGR80_WR(x, (HW_CCM_CCGR80_RD(x) & ~BM_CCM_CCGR80_SETTING1) | BF_CCM_CCGR80_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR80, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR80_SETTING2 (8U)        /*!< Bit position for CCM_CCGR80_SETTING2. */
#define BM_CCM_CCGR80_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR80_SETTING2. */
#define BS_CCM_CCGR80_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR80_SETTING2. */

/*! @brief Read current value of the CCM_CCGR80_SETTING2 field. */
#define BR_CCM_CCGR80_SETTING2(x) (HW_CCM_CCGR80(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR80_SETTING2. */
#define BF_CCM_CCGR80_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR80_SETTING2) & BM_CCM_CCGR80_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR80_SETTING2(x, v) (HW_CCM_CCGR80_WR(x, (HW_CCM_CCGR80_RD(x) & ~BM_CCM_CCGR80_SETTING2) | BF_CCM_CCGR80_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR80, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR80_SETTING3 (12U)       /*!< Bit position for CCM_CCGR80_SETTING3. */
#define BM_CCM_CCGR80_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR80_SETTING3. */
#define BS_CCM_CCGR80_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR80_SETTING3. */

/*! @brief Read current value of the CCM_CCGR80_SETTING3 field. */
#define BR_CCM_CCGR80_SETTING3(x) (HW_CCM_CCGR80(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR80_SETTING3. */
#define BF_CCM_CCGR80_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR80_SETTING3) & BM_CCM_CCGR80_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR80_SETTING3(x, v) (HW_CCM_CCGR80_WR(x, (HW_CCM_CCGR80_RD(x) & ~BM_CCM_CCGR80_SETTING3) | BF_CCM_CCGR80_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR81 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR81 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr81
{
    uint32_t U;
    struct _hw_ccm_ccgr81_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr81_t;

/*!
 * @name Constants and macros for entire CCM_CCGR81 register
 */
/*@{*/
#define HW_CCM_CCGR81_ADDR(x)    ((uintptr_t)(x) + 0x4510U)
#define HW_CCM_CCGR81_SET_ADDR(x) (HW_CCM_CCGR81_ADDR(x) + 0x4U)
#define HW_CCM_CCGR81_CLR_ADDR(x) (HW_CCM_CCGR81_ADDR(x) + 0x8U)
#define HW_CCM_CCGR81_TOG_ADDR(x) (HW_CCM_CCGR81_ADDR(x) + 0xCU)

#define HW_CCM_CCGR81(x)         (*(__IO hw_ccm_ccgr81_t *) HW_CCM_CCGR81_ADDR(x))
#define HW_CCM_CCGR81_RD(x)      (HW_CCM_CCGR81(x).U)
#define HW_CCM_CCGR81_WR(x, v)   (HW_CCM_CCGR81(x).U = (v))
#define HW_CCM_CCGR81_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR81_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR81_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR81_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR81_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR81_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR81 bitfields
 */

/*!
 * @name Register CCM_CCGR81, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR81_SETTING0 (0U)        /*!< Bit position for CCM_CCGR81_SETTING0. */
#define BM_CCM_CCGR81_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR81_SETTING0. */
#define BS_CCM_CCGR81_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR81_SETTING0. */

/*! @brief Read current value of the CCM_CCGR81_SETTING0 field. */
#define BR_CCM_CCGR81_SETTING0(x) (HW_CCM_CCGR81(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR81_SETTING0. */
#define BF_CCM_CCGR81_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR81_SETTING0) & BM_CCM_CCGR81_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR81_SETTING0(x, v) (HW_CCM_CCGR81_WR(x, (HW_CCM_CCGR81_RD(x) & ~BM_CCM_CCGR81_SETTING0) | BF_CCM_CCGR81_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR81, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR81_SETTING1 (4U)        /*!< Bit position for CCM_CCGR81_SETTING1. */
#define BM_CCM_CCGR81_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR81_SETTING1. */
#define BS_CCM_CCGR81_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR81_SETTING1. */

/*! @brief Read current value of the CCM_CCGR81_SETTING1 field. */
#define BR_CCM_CCGR81_SETTING1(x) (HW_CCM_CCGR81(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR81_SETTING1. */
#define BF_CCM_CCGR81_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR81_SETTING1) & BM_CCM_CCGR81_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR81_SETTING1(x, v) (HW_CCM_CCGR81_WR(x, (HW_CCM_CCGR81_RD(x) & ~BM_CCM_CCGR81_SETTING1) | BF_CCM_CCGR81_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR81, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR81_SETTING2 (8U)        /*!< Bit position for CCM_CCGR81_SETTING2. */
#define BM_CCM_CCGR81_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR81_SETTING2. */
#define BS_CCM_CCGR81_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR81_SETTING2. */

/*! @brief Read current value of the CCM_CCGR81_SETTING2 field. */
#define BR_CCM_CCGR81_SETTING2(x) (HW_CCM_CCGR81(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR81_SETTING2. */
#define BF_CCM_CCGR81_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR81_SETTING2) & BM_CCM_CCGR81_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR81_SETTING2(x, v) (HW_CCM_CCGR81_WR(x, (HW_CCM_CCGR81_RD(x) & ~BM_CCM_CCGR81_SETTING2) | BF_CCM_CCGR81_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR81, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR81_SETTING3 (12U)       /*!< Bit position for CCM_CCGR81_SETTING3. */
#define BM_CCM_CCGR81_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR81_SETTING3. */
#define BS_CCM_CCGR81_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR81_SETTING3. */

/*! @brief Read current value of the CCM_CCGR81_SETTING3 field. */
#define BR_CCM_CCGR81_SETTING3(x) (HW_CCM_CCGR81(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR81_SETTING3. */
#define BF_CCM_CCGR81_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR81_SETTING3) & BM_CCM_CCGR81_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR81_SETTING3(x, v) (HW_CCM_CCGR81_WR(x, (HW_CCM_CCGR81_RD(x) & ~BM_CCM_CCGR81_SETTING3) | BF_CCM_CCGR81_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR82 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR82 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr82
{
    uint32_t U;
    struct _hw_ccm_ccgr82_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr82_t;

/*!
 * @name Constants and macros for entire CCM_CCGR82 register
 */
/*@{*/
#define HW_CCM_CCGR82_ADDR(x)    ((uintptr_t)(x) + 0x4520U)
#define HW_CCM_CCGR82_SET_ADDR(x) (HW_CCM_CCGR82_ADDR(x) + 0x4U)
#define HW_CCM_CCGR82_CLR_ADDR(x) (HW_CCM_CCGR82_ADDR(x) + 0x8U)
#define HW_CCM_CCGR82_TOG_ADDR(x) (HW_CCM_CCGR82_ADDR(x) + 0xCU)

#define HW_CCM_CCGR82(x)         (*(__IO hw_ccm_ccgr82_t *) HW_CCM_CCGR82_ADDR(x))
#define HW_CCM_CCGR82_RD(x)      (HW_CCM_CCGR82(x).U)
#define HW_CCM_CCGR82_WR(x, v)   (HW_CCM_CCGR82(x).U = (v))
#define HW_CCM_CCGR82_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR82_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR82_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR82_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR82_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR82_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR82 bitfields
 */

/*!
 * @name Register CCM_CCGR82, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR82_SETTING0 (0U)        /*!< Bit position for CCM_CCGR82_SETTING0. */
#define BM_CCM_CCGR82_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR82_SETTING0. */
#define BS_CCM_CCGR82_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR82_SETTING0. */

/*! @brief Read current value of the CCM_CCGR82_SETTING0 field. */
#define BR_CCM_CCGR82_SETTING0(x) (HW_CCM_CCGR82(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR82_SETTING0. */
#define BF_CCM_CCGR82_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR82_SETTING0) & BM_CCM_CCGR82_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR82_SETTING0(x, v) (HW_CCM_CCGR82_WR(x, (HW_CCM_CCGR82_RD(x) & ~BM_CCM_CCGR82_SETTING0) | BF_CCM_CCGR82_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR82, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR82_SETTING1 (4U)        /*!< Bit position for CCM_CCGR82_SETTING1. */
#define BM_CCM_CCGR82_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR82_SETTING1. */
#define BS_CCM_CCGR82_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR82_SETTING1. */

/*! @brief Read current value of the CCM_CCGR82_SETTING1 field. */
#define BR_CCM_CCGR82_SETTING1(x) (HW_CCM_CCGR82(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR82_SETTING1. */
#define BF_CCM_CCGR82_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR82_SETTING1) & BM_CCM_CCGR82_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR82_SETTING1(x, v) (HW_CCM_CCGR82_WR(x, (HW_CCM_CCGR82_RD(x) & ~BM_CCM_CCGR82_SETTING1) | BF_CCM_CCGR82_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR82, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR82_SETTING2 (8U)        /*!< Bit position for CCM_CCGR82_SETTING2. */
#define BM_CCM_CCGR82_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR82_SETTING2. */
#define BS_CCM_CCGR82_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR82_SETTING2. */

/*! @brief Read current value of the CCM_CCGR82_SETTING2 field. */
#define BR_CCM_CCGR82_SETTING2(x) (HW_CCM_CCGR82(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR82_SETTING2. */
#define BF_CCM_CCGR82_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR82_SETTING2) & BM_CCM_CCGR82_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR82_SETTING2(x, v) (HW_CCM_CCGR82_WR(x, (HW_CCM_CCGR82_RD(x) & ~BM_CCM_CCGR82_SETTING2) | BF_CCM_CCGR82_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR82, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR82_SETTING3 (12U)       /*!< Bit position for CCM_CCGR82_SETTING3. */
#define BM_CCM_CCGR82_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR82_SETTING3. */
#define BS_CCM_CCGR82_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR82_SETTING3. */

/*! @brief Read current value of the CCM_CCGR82_SETTING3 field. */
#define BR_CCM_CCGR82_SETTING3(x) (HW_CCM_CCGR82(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR82_SETTING3. */
#define BF_CCM_CCGR82_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR82_SETTING3) & BM_CCM_CCGR82_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR82_SETTING3(x, v) (HW_CCM_CCGR82_WR(x, (HW_CCM_CCGR82_RD(x) & ~BM_CCM_CCGR82_SETTING3) | BF_CCM_CCGR82_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR83 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR83 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr83
{
    uint32_t U;
    struct _hw_ccm_ccgr83_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr83_t;

/*!
 * @name Constants and macros for entire CCM_CCGR83 register
 */
/*@{*/
#define HW_CCM_CCGR83_ADDR(x)    ((uintptr_t)(x) + 0x4530U)
#define HW_CCM_CCGR83_SET_ADDR(x) (HW_CCM_CCGR83_ADDR(x) + 0x4U)
#define HW_CCM_CCGR83_CLR_ADDR(x) (HW_CCM_CCGR83_ADDR(x) + 0x8U)
#define HW_CCM_CCGR83_TOG_ADDR(x) (HW_CCM_CCGR83_ADDR(x) + 0xCU)

#define HW_CCM_CCGR83(x)         (*(__IO hw_ccm_ccgr83_t *) HW_CCM_CCGR83_ADDR(x))
#define HW_CCM_CCGR83_RD(x)      (HW_CCM_CCGR83(x).U)
#define HW_CCM_CCGR83_WR(x, v)   (HW_CCM_CCGR83(x).U = (v))
#define HW_CCM_CCGR83_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR83_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR83_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR83_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR83_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR83_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR83 bitfields
 */

/*!
 * @name Register CCM_CCGR83, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR83_SETTING0 (0U)        /*!< Bit position for CCM_CCGR83_SETTING0. */
#define BM_CCM_CCGR83_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR83_SETTING0. */
#define BS_CCM_CCGR83_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR83_SETTING0. */

/*! @brief Read current value of the CCM_CCGR83_SETTING0 field. */
#define BR_CCM_CCGR83_SETTING0(x) (HW_CCM_CCGR83(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR83_SETTING0. */
#define BF_CCM_CCGR83_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR83_SETTING0) & BM_CCM_CCGR83_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR83_SETTING0(x, v) (HW_CCM_CCGR83_WR(x, (HW_CCM_CCGR83_RD(x) & ~BM_CCM_CCGR83_SETTING0) | BF_CCM_CCGR83_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR83, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR83_SETTING1 (4U)        /*!< Bit position for CCM_CCGR83_SETTING1. */
#define BM_CCM_CCGR83_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR83_SETTING1. */
#define BS_CCM_CCGR83_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR83_SETTING1. */

/*! @brief Read current value of the CCM_CCGR83_SETTING1 field. */
#define BR_CCM_CCGR83_SETTING1(x) (HW_CCM_CCGR83(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR83_SETTING1. */
#define BF_CCM_CCGR83_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR83_SETTING1) & BM_CCM_CCGR83_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR83_SETTING1(x, v) (HW_CCM_CCGR83_WR(x, (HW_CCM_CCGR83_RD(x) & ~BM_CCM_CCGR83_SETTING1) | BF_CCM_CCGR83_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR83, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR83_SETTING2 (8U)        /*!< Bit position for CCM_CCGR83_SETTING2. */
#define BM_CCM_CCGR83_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR83_SETTING2. */
#define BS_CCM_CCGR83_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR83_SETTING2. */

/*! @brief Read current value of the CCM_CCGR83_SETTING2 field. */
#define BR_CCM_CCGR83_SETTING2(x) (HW_CCM_CCGR83(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR83_SETTING2. */
#define BF_CCM_CCGR83_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR83_SETTING2) & BM_CCM_CCGR83_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR83_SETTING2(x, v) (HW_CCM_CCGR83_WR(x, (HW_CCM_CCGR83_RD(x) & ~BM_CCM_CCGR83_SETTING2) | BF_CCM_CCGR83_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR83, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR83_SETTING3 (12U)       /*!< Bit position for CCM_CCGR83_SETTING3. */
#define BM_CCM_CCGR83_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR83_SETTING3. */
#define BS_CCM_CCGR83_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR83_SETTING3. */

/*! @brief Read current value of the CCM_CCGR83_SETTING3 field. */
#define BR_CCM_CCGR83_SETTING3(x) (HW_CCM_CCGR83(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR83_SETTING3. */
#define BF_CCM_CCGR83_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR83_SETTING3) & BM_CCM_CCGR83_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR83_SETTING3(x, v) (HW_CCM_CCGR83_WR(x, (HW_CCM_CCGR83_RD(x) & ~BM_CCM_CCGR83_SETTING3) | BF_CCM_CCGR83_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR84 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR84 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr84
{
    uint32_t U;
    struct _hw_ccm_ccgr84_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr84_t;

/*!
 * @name Constants and macros for entire CCM_CCGR84 register
 */
/*@{*/
#define HW_CCM_CCGR84_ADDR(x)    ((uintptr_t)(x) + 0x4540U)
#define HW_CCM_CCGR84_SET_ADDR(x) (HW_CCM_CCGR84_ADDR(x) + 0x4U)
#define HW_CCM_CCGR84_CLR_ADDR(x) (HW_CCM_CCGR84_ADDR(x) + 0x8U)
#define HW_CCM_CCGR84_TOG_ADDR(x) (HW_CCM_CCGR84_ADDR(x) + 0xCU)

#define HW_CCM_CCGR84(x)         (*(__IO hw_ccm_ccgr84_t *) HW_CCM_CCGR84_ADDR(x))
#define HW_CCM_CCGR84_RD(x)      (HW_CCM_CCGR84(x).U)
#define HW_CCM_CCGR84_WR(x, v)   (HW_CCM_CCGR84(x).U = (v))
#define HW_CCM_CCGR84_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR84_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR84_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR84_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR84_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR84_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR84 bitfields
 */

/*!
 * @name Register CCM_CCGR84, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR84_SETTING0 (0U)        /*!< Bit position for CCM_CCGR84_SETTING0. */
#define BM_CCM_CCGR84_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR84_SETTING0. */
#define BS_CCM_CCGR84_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR84_SETTING0. */

/*! @brief Read current value of the CCM_CCGR84_SETTING0 field. */
#define BR_CCM_CCGR84_SETTING0(x) (HW_CCM_CCGR84(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR84_SETTING0. */
#define BF_CCM_CCGR84_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR84_SETTING0) & BM_CCM_CCGR84_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR84_SETTING0(x, v) (HW_CCM_CCGR84_WR(x, (HW_CCM_CCGR84_RD(x) & ~BM_CCM_CCGR84_SETTING0) | BF_CCM_CCGR84_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR84, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR84_SETTING1 (4U)        /*!< Bit position for CCM_CCGR84_SETTING1. */
#define BM_CCM_CCGR84_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR84_SETTING1. */
#define BS_CCM_CCGR84_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR84_SETTING1. */

/*! @brief Read current value of the CCM_CCGR84_SETTING1 field. */
#define BR_CCM_CCGR84_SETTING1(x) (HW_CCM_CCGR84(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR84_SETTING1. */
#define BF_CCM_CCGR84_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR84_SETTING1) & BM_CCM_CCGR84_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR84_SETTING1(x, v) (HW_CCM_CCGR84_WR(x, (HW_CCM_CCGR84_RD(x) & ~BM_CCM_CCGR84_SETTING1) | BF_CCM_CCGR84_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR84, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR84_SETTING2 (8U)        /*!< Bit position for CCM_CCGR84_SETTING2. */
#define BM_CCM_CCGR84_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR84_SETTING2. */
#define BS_CCM_CCGR84_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR84_SETTING2. */

/*! @brief Read current value of the CCM_CCGR84_SETTING2 field. */
#define BR_CCM_CCGR84_SETTING2(x) (HW_CCM_CCGR84(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR84_SETTING2. */
#define BF_CCM_CCGR84_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR84_SETTING2) & BM_CCM_CCGR84_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR84_SETTING2(x, v) (HW_CCM_CCGR84_WR(x, (HW_CCM_CCGR84_RD(x) & ~BM_CCM_CCGR84_SETTING2) | BF_CCM_CCGR84_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR84, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR84_SETTING3 (12U)       /*!< Bit position for CCM_CCGR84_SETTING3. */
#define BM_CCM_CCGR84_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR84_SETTING3. */
#define BS_CCM_CCGR84_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR84_SETTING3. */

/*! @brief Read current value of the CCM_CCGR84_SETTING3 field. */
#define BR_CCM_CCGR84_SETTING3(x) (HW_CCM_CCGR84(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR84_SETTING3. */
#define BF_CCM_CCGR84_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR84_SETTING3) & BM_CCM_CCGR84_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR84_SETTING3(x, v) (HW_CCM_CCGR84_WR(x, (HW_CCM_CCGR84_RD(x) & ~BM_CCM_CCGR84_SETTING3) | BF_CCM_CCGR84_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR85 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR85 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr85
{
    uint32_t U;
    struct _hw_ccm_ccgr85_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr85_t;

/*!
 * @name Constants and macros for entire CCM_CCGR85 register
 */
/*@{*/
#define HW_CCM_CCGR85_ADDR(x)    ((uintptr_t)(x) + 0x4550U)
#define HW_CCM_CCGR85_SET_ADDR(x) (HW_CCM_CCGR85_ADDR(x) + 0x4U)
#define HW_CCM_CCGR85_CLR_ADDR(x) (HW_CCM_CCGR85_ADDR(x) + 0x8U)
#define HW_CCM_CCGR85_TOG_ADDR(x) (HW_CCM_CCGR85_ADDR(x) + 0xCU)

#define HW_CCM_CCGR85(x)         (*(__IO hw_ccm_ccgr85_t *) HW_CCM_CCGR85_ADDR(x))
#define HW_CCM_CCGR85_RD(x)      (HW_CCM_CCGR85(x).U)
#define HW_CCM_CCGR85_WR(x, v)   (HW_CCM_CCGR85(x).U = (v))
#define HW_CCM_CCGR85_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR85_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR85_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR85_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR85_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR85_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR85 bitfields
 */

/*!
 * @name Register CCM_CCGR85, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR85_SETTING0 (0U)        /*!< Bit position for CCM_CCGR85_SETTING0. */
#define BM_CCM_CCGR85_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR85_SETTING0. */
#define BS_CCM_CCGR85_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR85_SETTING0. */

/*! @brief Read current value of the CCM_CCGR85_SETTING0 field. */
#define BR_CCM_CCGR85_SETTING0(x) (HW_CCM_CCGR85(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR85_SETTING0. */
#define BF_CCM_CCGR85_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR85_SETTING0) & BM_CCM_CCGR85_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR85_SETTING0(x, v) (HW_CCM_CCGR85_WR(x, (HW_CCM_CCGR85_RD(x) & ~BM_CCM_CCGR85_SETTING0) | BF_CCM_CCGR85_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR85, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR85_SETTING1 (4U)        /*!< Bit position for CCM_CCGR85_SETTING1. */
#define BM_CCM_CCGR85_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR85_SETTING1. */
#define BS_CCM_CCGR85_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR85_SETTING1. */

/*! @brief Read current value of the CCM_CCGR85_SETTING1 field. */
#define BR_CCM_CCGR85_SETTING1(x) (HW_CCM_CCGR85(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR85_SETTING1. */
#define BF_CCM_CCGR85_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR85_SETTING1) & BM_CCM_CCGR85_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR85_SETTING1(x, v) (HW_CCM_CCGR85_WR(x, (HW_CCM_CCGR85_RD(x) & ~BM_CCM_CCGR85_SETTING1) | BF_CCM_CCGR85_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR85, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR85_SETTING2 (8U)        /*!< Bit position for CCM_CCGR85_SETTING2. */
#define BM_CCM_CCGR85_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR85_SETTING2. */
#define BS_CCM_CCGR85_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR85_SETTING2. */

/*! @brief Read current value of the CCM_CCGR85_SETTING2 field. */
#define BR_CCM_CCGR85_SETTING2(x) (HW_CCM_CCGR85(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR85_SETTING2. */
#define BF_CCM_CCGR85_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR85_SETTING2) & BM_CCM_CCGR85_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR85_SETTING2(x, v) (HW_CCM_CCGR85_WR(x, (HW_CCM_CCGR85_RD(x) & ~BM_CCM_CCGR85_SETTING2) | BF_CCM_CCGR85_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR85, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR85_SETTING3 (12U)       /*!< Bit position for CCM_CCGR85_SETTING3. */
#define BM_CCM_CCGR85_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR85_SETTING3. */
#define BS_CCM_CCGR85_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR85_SETTING3. */

/*! @brief Read current value of the CCM_CCGR85_SETTING3 field. */
#define BR_CCM_CCGR85_SETTING3(x) (HW_CCM_CCGR85(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR85_SETTING3. */
#define BF_CCM_CCGR85_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR85_SETTING3) & BM_CCM_CCGR85_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR85_SETTING3(x, v) (HW_CCM_CCGR85_WR(x, (HW_CCM_CCGR85_RD(x) & ~BM_CCM_CCGR85_SETTING3) | BF_CCM_CCGR85_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR86 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR86 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr86
{
    uint32_t U;
    struct _hw_ccm_ccgr86_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr86_t;

/*!
 * @name Constants and macros for entire CCM_CCGR86 register
 */
/*@{*/
#define HW_CCM_CCGR86_ADDR(x)    ((uintptr_t)(x) + 0x4560U)
#define HW_CCM_CCGR86_SET_ADDR(x) (HW_CCM_CCGR86_ADDR(x) + 0x4U)
#define HW_CCM_CCGR86_CLR_ADDR(x) (HW_CCM_CCGR86_ADDR(x) + 0x8U)
#define HW_CCM_CCGR86_TOG_ADDR(x) (HW_CCM_CCGR86_ADDR(x) + 0xCU)

#define HW_CCM_CCGR86(x)         (*(__IO hw_ccm_ccgr86_t *) HW_CCM_CCGR86_ADDR(x))
#define HW_CCM_CCGR86_RD(x)      (HW_CCM_CCGR86(x).U)
#define HW_CCM_CCGR86_WR(x, v)   (HW_CCM_CCGR86(x).U = (v))
#define HW_CCM_CCGR86_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR86_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR86_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR86_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR86_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR86_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR86 bitfields
 */

/*!
 * @name Register CCM_CCGR86, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR86_SETTING0 (0U)        /*!< Bit position for CCM_CCGR86_SETTING0. */
#define BM_CCM_CCGR86_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR86_SETTING0. */
#define BS_CCM_CCGR86_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR86_SETTING0. */

/*! @brief Read current value of the CCM_CCGR86_SETTING0 field. */
#define BR_CCM_CCGR86_SETTING0(x) (HW_CCM_CCGR86(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR86_SETTING0. */
#define BF_CCM_CCGR86_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR86_SETTING0) & BM_CCM_CCGR86_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR86_SETTING0(x, v) (HW_CCM_CCGR86_WR(x, (HW_CCM_CCGR86_RD(x) & ~BM_CCM_CCGR86_SETTING0) | BF_CCM_CCGR86_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR86, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR86_SETTING1 (4U)        /*!< Bit position for CCM_CCGR86_SETTING1. */
#define BM_CCM_CCGR86_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR86_SETTING1. */
#define BS_CCM_CCGR86_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR86_SETTING1. */

/*! @brief Read current value of the CCM_CCGR86_SETTING1 field. */
#define BR_CCM_CCGR86_SETTING1(x) (HW_CCM_CCGR86(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR86_SETTING1. */
#define BF_CCM_CCGR86_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR86_SETTING1) & BM_CCM_CCGR86_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR86_SETTING1(x, v) (HW_CCM_CCGR86_WR(x, (HW_CCM_CCGR86_RD(x) & ~BM_CCM_CCGR86_SETTING1) | BF_CCM_CCGR86_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR86, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR86_SETTING2 (8U)        /*!< Bit position for CCM_CCGR86_SETTING2. */
#define BM_CCM_CCGR86_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR86_SETTING2. */
#define BS_CCM_CCGR86_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR86_SETTING2. */

/*! @brief Read current value of the CCM_CCGR86_SETTING2 field. */
#define BR_CCM_CCGR86_SETTING2(x) (HW_CCM_CCGR86(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR86_SETTING2. */
#define BF_CCM_CCGR86_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR86_SETTING2) & BM_CCM_CCGR86_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR86_SETTING2(x, v) (HW_CCM_CCGR86_WR(x, (HW_CCM_CCGR86_RD(x) & ~BM_CCM_CCGR86_SETTING2) | BF_CCM_CCGR86_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR86, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR86_SETTING3 (12U)       /*!< Bit position for CCM_CCGR86_SETTING3. */
#define BM_CCM_CCGR86_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR86_SETTING3. */
#define BS_CCM_CCGR86_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR86_SETTING3. */

/*! @brief Read current value of the CCM_CCGR86_SETTING3 field. */
#define BR_CCM_CCGR86_SETTING3(x) (HW_CCM_CCGR86(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR86_SETTING3. */
#define BF_CCM_CCGR86_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR86_SETTING3) & BM_CCM_CCGR86_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR86_SETTING3(x, v) (HW_CCM_CCGR86_WR(x, (HW_CCM_CCGR86_RD(x) & ~BM_CCM_CCGR86_SETTING3) | BF_CCM_CCGR86_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR87 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR87 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr87
{
    uint32_t U;
    struct _hw_ccm_ccgr87_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr87_t;

/*!
 * @name Constants and macros for entire CCM_CCGR87 register
 */
/*@{*/
#define HW_CCM_CCGR87_ADDR(x)    ((uintptr_t)(x) + 0x4570U)
#define HW_CCM_CCGR87_SET_ADDR(x) (HW_CCM_CCGR87_ADDR(x) + 0x4U)
#define HW_CCM_CCGR87_CLR_ADDR(x) (HW_CCM_CCGR87_ADDR(x) + 0x8U)
#define HW_CCM_CCGR87_TOG_ADDR(x) (HW_CCM_CCGR87_ADDR(x) + 0xCU)

#define HW_CCM_CCGR87(x)         (*(__IO hw_ccm_ccgr87_t *) HW_CCM_CCGR87_ADDR(x))
#define HW_CCM_CCGR87_RD(x)      (HW_CCM_CCGR87(x).U)
#define HW_CCM_CCGR87_WR(x, v)   (HW_CCM_CCGR87(x).U = (v))
#define HW_CCM_CCGR87_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR87_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR87_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR87_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR87_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR87_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR87 bitfields
 */

/*!
 * @name Register CCM_CCGR87, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR87_SETTING0 (0U)        /*!< Bit position for CCM_CCGR87_SETTING0. */
#define BM_CCM_CCGR87_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR87_SETTING0. */
#define BS_CCM_CCGR87_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR87_SETTING0. */

/*! @brief Read current value of the CCM_CCGR87_SETTING0 field. */
#define BR_CCM_CCGR87_SETTING0(x) (HW_CCM_CCGR87(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR87_SETTING0. */
#define BF_CCM_CCGR87_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR87_SETTING0) & BM_CCM_CCGR87_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR87_SETTING0(x, v) (HW_CCM_CCGR87_WR(x, (HW_CCM_CCGR87_RD(x) & ~BM_CCM_CCGR87_SETTING0) | BF_CCM_CCGR87_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR87, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR87_SETTING1 (4U)        /*!< Bit position for CCM_CCGR87_SETTING1. */
#define BM_CCM_CCGR87_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR87_SETTING1. */
#define BS_CCM_CCGR87_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR87_SETTING1. */

/*! @brief Read current value of the CCM_CCGR87_SETTING1 field. */
#define BR_CCM_CCGR87_SETTING1(x) (HW_CCM_CCGR87(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR87_SETTING1. */
#define BF_CCM_CCGR87_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR87_SETTING1) & BM_CCM_CCGR87_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR87_SETTING1(x, v) (HW_CCM_CCGR87_WR(x, (HW_CCM_CCGR87_RD(x) & ~BM_CCM_CCGR87_SETTING1) | BF_CCM_CCGR87_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR87, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR87_SETTING2 (8U)        /*!< Bit position for CCM_CCGR87_SETTING2. */
#define BM_CCM_CCGR87_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR87_SETTING2. */
#define BS_CCM_CCGR87_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR87_SETTING2. */

/*! @brief Read current value of the CCM_CCGR87_SETTING2 field. */
#define BR_CCM_CCGR87_SETTING2(x) (HW_CCM_CCGR87(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR87_SETTING2. */
#define BF_CCM_CCGR87_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR87_SETTING2) & BM_CCM_CCGR87_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR87_SETTING2(x, v) (HW_CCM_CCGR87_WR(x, (HW_CCM_CCGR87_RD(x) & ~BM_CCM_CCGR87_SETTING2) | BF_CCM_CCGR87_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR87, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR87_SETTING3 (12U)       /*!< Bit position for CCM_CCGR87_SETTING3. */
#define BM_CCM_CCGR87_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR87_SETTING3. */
#define BS_CCM_CCGR87_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR87_SETTING3. */

/*! @brief Read current value of the CCM_CCGR87_SETTING3 field. */
#define BR_CCM_CCGR87_SETTING3(x) (HW_CCM_CCGR87(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR87_SETTING3. */
#define BF_CCM_CCGR87_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR87_SETTING3) & BM_CCM_CCGR87_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR87_SETTING3(x, v) (HW_CCM_CCGR87_WR(x, (HW_CCM_CCGR87_RD(x) & ~BM_CCM_CCGR87_SETTING3) | BF_CCM_CCGR87_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR88 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR88 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr88
{
    uint32_t U;
    struct _hw_ccm_ccgr88_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr88_t;

/*!
 * @name Constants and macros for entire CCM_CCGR88 register
 */
/*@{*/
#define HW_CCM_CCGR88_ADDR(x)    ((uintptr_t)(x) + 0x4580U)
#define HW_CCM_CCGR88_SET_ADDR(x) (HW_CCM_CCGR88_ADDR(x) + 0x4U)
#define HW_CCM_CCGR88_CLR_ADDR(x) (HW_CCM_CCGR88_ADDR(x) + 0x8U)
#define HW_CCM_CCGR88_TOG_ADDR(x) (HW_CCM_CCGR88_ADDR(x) + 0xCU)

#define HW_CCM_CCGR88(x)         (*(__IO hw_ccm_ccgr88_t *) HW_CCM_CCGR88_ADDR(x))
#define HW_CCM_CCGR88_RD(x)      (HW_CCM_CCGR88(x).U)
#define HW_CCM_CCGR88_WR(x, v)   (HW_CCM_CCGR88(x).U = (v))
#define HW_CCM_CCGR88_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR88_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR88_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR88_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR88_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR88_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR88 bitfields
 */

/*!
 * @name Register CCM_CCGR88, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR88_SETTING0 (0U)        /*!< Bit position for CCM_CCGR88_SETTING0. */
#define BM_CCM_CCGR88_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR88_SETTING0. */
#define BS_CCM_CCGR88_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR88_SETTING0. */

/*! @brief Read current value of the CCM_CCGR88_SETTING0 field. */
#define BR_CCM_CCGR88_SETTING0(x) (HW_CCM_CCGR88(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR88_SETTING0. */
#define BF_CCM_CCGR88_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR88_SETTING0) & BM_CCM_CCGR88_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR88_SETTING0(x, v) (HW_CCM_CCGR88_WR(x, (HW_CCM_CCGR88_RD(x) & ~BM_CCM_CCGR88_SETTING0) | BF_CCM_CCGR88_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR88, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR88_SETTING1 (4U)        /*!< Bit position for CCM_CCGR88_SETTING1. */
#define BM_CCM_CCGR88_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR88_SETTING1. */
#define BS_CCM_CCGR88_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR88_SETTING1. */

/*! @brief Read current value of the CCM_CCGR88_SETTING1 field. */
#define BR_CCM_CCGR88_SETTING1(x) (HW_CCM_CCGR88(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR88_SETTING1. */
#define BF_CCM_CCGR88_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR88_SETTING1) & BM_CCM_CCGR88_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR88_SETTING1(x, v) (HW_CCM_CCGR88_WR(x, (HW_CCM_CCGR88_RD(x) & ~BM_CCM_CCGR88_SETTING1) | BF_CCM_CCGR88_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR88, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR88_SETTING2 (8U)        /*!< Bit position for CCM_CCGR88_SETTING2. */
#define BM_CCM_CCGR88_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR88_SETTING2. */
#define BS_CCM_CCGR88_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR88_SETTING2. */

/*! @brief Read current value of the CCM_CCGR88_SETTING2 field. */
#define BR_CCM_CCGR88_SETTING2(x) (HW_CCM_CCGR88(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR88_SETTING2. */
#define BF_CCM_CCGR88_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR88_SETTING2) & BM_CCM_CCGR88_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR88_SETTING2(x, v) (HW_CCM_CCGR88_WR(x, (HW_CCM_CCGR88_RD(x) & ~BM_CCM_CCGR88_SETTING2) | BF_CCM_CCGR88_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR88, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR88_SETTING3 (12U)       /*!< Bit position for CCM_CCGR88_SETTING3. */
#define BM_CCM_CCGR88_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR88_SETTING3. */
#define BS_CCM_CCGR88_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR88_SETTING3. */

/*! @brief Read current value of the CCM_CCGR88_SETTING3 field. */
#define BR_CCM_CCGR88_SETTING3(x) (HW_CCM_CCGR88(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR88_SETTING3. */
#define BF_CCM_CCGR88_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR88_SETTING3) & BM_CCM_CCGR88_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR88_SETTING3(x, v) (HW_CCM_CCGR88_WR(x, (HW_CCM_CCGR88_RD(x) & ~BM_CCM_CCGR88_SETTING3) | BF_CCM_CCGR88_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR89 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR89 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr89
{
    uint32_t U;
    struct _hw_ccm_ccgr89_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr89_t;

/*!
 * @name Constants and macros for entire CCM_CCGR89 register
 */
/*@{*/
#define HW_CCM_CCGR89_ADDR(x)    ((uintptr_t)(x) + 0x4590U)
#define HW_CCM_CCGR89_SET_ADDR(x) (HW_CCM_CCGR89_ADDR(x) + 0x4U)
#define HW_CCM_CCGR89_CLR_ADDR(x) (HW_CCM_CCGR89_ADDR(x) + 0x8U)
#define HW_CCM_CCGR89_TOG_ADDR(x) (HW_CCM_CCGR89_ADDR(x) + 0xCU)

#define HW_CCM_CCGR89(x)         (*(__IO hw_ccm_ccgr89_t *) HW_CCM_CCGR89_ADDR(x))
#define HW_CCM_CCGR89_RD(x)      (HW_CCM_CCGR89(x).U)
#define HW_CCM_CCGR89_WR(x, v)   (HW_CCM_CCGR89(x).U = (v))
#define HW_CCM_CCGR89_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR89_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR89_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR89_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR89_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR89_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR89 bitfields
 */

/*!
 * @name Register CCM_CCGR89, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR89_SETTING0 (0U)        /*!< Bit position for CCM_CCGR89_SETTING0. */
#define BM_CCM_CCGR89_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR89_SETTING0. */
#define BS_CCM_CCGR89_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR89_SETTING0. */

/*! @brief Read current value of the CCM_CCGR89_SETTING0 field. */
#define BR_CCM_CCGR89_SETTING0(x) (HW_CCM_CCGR89(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR89_SETTING0. */
#define BF_CCM_CCGR89_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR89_SETTING0) & BM_CCM_CCGR89_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR89_SETTING0(x, v) (HW_CCM_CCGR89_WR(x, (HW_CCM_CCGR89_RD(x) & ~BM_CCM_CCGR89_SETTING0) | BF_CCM_CCGR89_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR89, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR89_SETTING1 (4U)        /*!< Bit position for CCM_CCGR89_SETTING1. */
#define BM_CCM_CCGR89_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR89_SETTING1. */
#define BS_CCM_CCGR89_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR89_SETTING1. */

/*! @brief Read current value of the CCM_CCGR89_SETTING1 field. */
#define BR_CCM_CCGR89_SETTING1(x) (HW_CCM_CCGR89(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR89_SETTING1. */
#define BF_CCM_CCGR89_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR89_SETTING1) & BM_CCM_CCGR89_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR89_SETTING1(x, v) (HW_CCM_CCGR89_WR(x, (HW_CCM_CCGR89_RD(x) & ~BM_CCM_CCGR89_SETTING1) | BF_CCM_CCGR89_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR89, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR89_SETTING2 (8U)        /*!< Bit position for CCM_CCGR89_SETTING2. */
#define BM_CCM_CCGR89_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR89_SETTING2. */
#define BS_CCM_CCGR89_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR89_SETTING2. */

/*! @brief Read current value of the CCM_CCGR89_SETTING2 field. */
#define BR_CCM_CCGR89_SETTING2(x) (HW_CCM_CCGR89(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR89_SETTING2. */
#define BF_CCM_CCGR89_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR89_SETTING2) & BM_CCM_CCGR89_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR89_SETTING2(x, v) (HW_CCM_CCGR89_WR(x, (HW_CCM_CCGR89_RD(x) & ~BM_CCM_CCGR89_SETTING2) | BF_CCM_CCGR89_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR89, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR89_SETTING3 (12U)       /*!< Bit position for CCM_CCGR89_SETTING3. */
#define BM_CCM_CCGR89_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR89_SETTING3. */
#define BS_CCM_CCGR89_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR89_SETTING3. */

/*! @brief Read current value of the CCM_CCGR89_SETTING3 field. */
#define BR_CCM_CCGR89_SETTING3(x) (HW_CCM_CCGR89(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR89_SETTING3. */
#define BF_CCM_CCGR89_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR89_SETTING3) & BM_CCM_CCGR89_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR89_SETTING3(x, v) (HW_CCM_CCGR89_WR(x, (HW_CCM_CCGR89_RD(x) & ~BM_CCM_CCGR89_SETTING3) | BF_CCM_CCGR89_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR90 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR90 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr90
{
    uint32_t U;
    struct _hw_ccm_ccgr90_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr90_t;

/*!
 * @name Constants and macros for entire CCM_CCGR90 register
 */
/*@{*/
#define HW_CCM_CCGR90_ADDR(x)    ((uintptr_t)(x) + 0x45A0U)
#define HW_CCM_CCGR90_SET_ADDR(x) (HW_CCM_CCGR90_ADDR(x) + 0x4U)
#define HW_CCM_CCGR90_CLR_ADDR(x) (HW_CCM_CCGR90_ADDR(x) + 0x8U)
#define HW_CCM_CCGR90_TOG_ADDR(x) (HW_CCM_CCGR90_ADDR(x) + 0xCU)

#define HW_CCM_CCGR90(x)         (*(__IO hw_ccm_ccgr90_t *) HW_CCM_CCGR90_ADDR(x))
#define HW_CCM_CCGR90_RD(x)      (HW_CCM_CCGR90(x).U)
#define HW_CCM_CCGR90_WR(x, v)   (HW_CCM_CCGR90(x).U = (v))
#define HW_CCM_CCGR90_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR90_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR90_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR90_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR90_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR90_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR90 bitfields
 */

/*!
 * @name Register CCM_CCGR90, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR90_SETTING0 (0U)        /*!< Bit position for CCM_CCGR90_SETTING0. */
#define BM_CCM_CCGR90_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR90_SETTING0. */
#define BS_CCM_CCGR90_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR90_SETTING0. */

/*! @brief Read current value of the CCM_CCGR90_SETTING0 field. */
#define BR_CCM_CCGR90_SETTING0(x) (HW_CCM_CCGR90(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR90_SETTING0. */
#define BF_CCM_CCGR90_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR90_SETTING0) & BM_CCM_CCGR90_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR90_SETTING0(x, v) (HW_CCM_CCGR90_WR(x, (HW_CCM_CCGR90_RD(x) & ~BM_CCM_CCGR90_SETTING0) | BF_CCM_CCGR90_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR90, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR90_SETTING1 (4U)        /*!< Bit position for CCM_CCGR90_SETTING1. */
#define BM_CCM_CCGR90_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR90_SETTING1. */
#define BS_CCM_CCGR90_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR90_SETTING1. */

/*! @brief Read current value of the CCM_CCGR90_SETTING1 field. */
#define BR_CCM_CCGR90_SETTING1(x) (HW_CCM_CCGR90(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR90_SETTING1. */
#define BF_CCM_CCGR90_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR90_SETTING1) & BM_CCM_CCGR90_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR90_SETTING1(x, v) (HW_CCM_CCGR90_WR(x, (HW_CCM_CCGR90_RD(x) & ~BM_CCM_CCGR90_SETTING1) | BF_CCM_CCGR90_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR90, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR90_SETTING2 (8U)        /*!< Bit position for CCM_CCGR90_SETTING2. */
#define BM_CCM_CCGR90_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR90_SETTING2. */
#define BS_CCM_CCGR90_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR90_SETTING2. */

/*! @brief Read current value of the CCM_CCGR90_SETTING2 field. */
#define BR_CCM_CCGR90_SETTING2(x) (HW_CCM_CCGR90(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR90_SETTING2. */
#define BF_CCM_CCGR90_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR90_SETTING2) & BM_CCM_CCGR90_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR90_SETTING2(x, v) (HW_CCM_CCGR90_WR(x, (HW_CCM_CCGR90_RD(x) & ~BM_CCM_CCGR90_SETTING2) | BF_CCM_CCGR90_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR90, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR90_SETTING3 (12U)       /*!< Bit position for CCM_CCGR90_SETTING3. */
#define BM_CCM_CCGR90_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR90_SETTING3. */
#define BS_CCM_CCGR90_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR90_SETTING3. */

/*! @brief Read current value of the CCM_CCGR90_SETTING3 field. */
#define BR_CCM_CCGR90_SETTING3(x) (HW_CCM_CCGR90(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR90_SETTING3. */
#define BF_CCM_CCGR90_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR90_SETTING3) & BM_CCM_CCGR90_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR90_SETTING3(x, v) (HW_CCM_CCGR90_WR(x, (HW_CCM_CCGR90_RD(x) & ~BM_CCM_CCGR90_SETTING3) | BF_CCM_CCGR90_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR91 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR91 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr91
{
    uint32_t U;
    struct _hw_ccm_ccgr91_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr91_t;

/*!
 * @name Constants and macros for entire CCM_CCGR91 register
 */
/*@{*/
#define HW_CCM_CCGR91_ADDR(x)    ((uintptr_t)(x) + 0x45B0U)
#define HW_CCM_CCGR91_SET_ADDR(x) (HW_CCM_CCGR91_ADDR(x) + 0x4U)
#define HW_CCM_CCGR91_CLR_ADDR(x) (HW_CCM_CCGR91_ADDR(x) + 0x8U)
#define HW_CCM_CCGR91_TOG_ADDR(x) (HW_CCM_CCGR91_ADDR(x) + 0xCU)

#define HW_CCM_CCGR91(x)         (*(__IO hw_ccm_ccgr91_t *) HW_CCM_CCGR91_ADDR(x))
#define HW_CCM_CCGR91_RD(x)      (HW_CCM_CCGR91(x).U)
#define HW_CCM_CCGR91_WR(x, v)   (HW_CCM_CCGR91(x).U = (v))
#define HW_CCM_CCGR91_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR91_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR91_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR91_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR91_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR91_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR91 bitfields
 */

/*!
 * @name Register CCM_CCGR91, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR91_SETTING0 (0U)        /*!< Bit position for CCM_CCGR91_SETTING0. */
#define BM_CCM_CCGR91_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR91_SETTING0. */
#define BS_CCM_CCGR91_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR91_SETTING0. */

/*! @brief Read current value of the CCM_CCGR91_SETTING0 field. */
#define BR_CCM_CCGR91_SETTING0(x) (HW_CCM_CCGR91(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR91_SETTING0. */
#define BF_CCM_CCGR91_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR91_SETTING0) & BM_CCM_CCGR91_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR91_SETTING0(x, v) (HW_CCM_CCGR91_WR(x, (HW_CCM_CCGR91_RD(x) & ~BM_CCM_CCGR91_SETTING0) | BF_CCM_CCGR91_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR91, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR91_SETTING1 (4U)        /*!< Bit position for CCM_CCGR91_SETTING1. */
#define BM_CCM_CCGR91_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR91_SETTING1. */
#define BS_CCM_CCGR91_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR91_SETTING1. */

/*! @brief Read current value of the CCM_CCGR91_SETTING1 field. */
#define BR_CCM_CCGR91_SETTING1(x) (HW_CCM_CCGR91(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR91_SETTING1. */
#define BF_CCM_CCGR91_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR91_SETTING1) & BM_CCM_CCGR91_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR91_SETTING1(x, v) (HW_CCM_CCGR91_WR(x, (HW_CCM_CCGR91_RD(x) & ~BM_CCM_CCGR91_SETTING1) | BF_CCM_CCGR91_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR91, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR91_SETTING2 (8U)        /*!< Bit position for CCM_CCGR91_SETTING2. */
#define BM_CCM_CCGR91_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR91_SETTING2. */
#define BS_CCM_CCGR91_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR91_SETTING2. */

/*! @brief Read current value of the CCM_CCGR91_SETTING2 field. */
#define BR_CCM_CCGR91_SETTING2(x) (HW_CCM_CCGR91(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR91_SETTING2. */
#define BF_CCM_CCGR91_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR91_SETTING2) & BM_CCM_CCGR91_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR91_SETTING2(x, v) (HW_CCM_CCGR91_WR(x, (HW_CCM_CCGR91_RD(x) & ~BM_CCM_CCGR91_SETTING2) | BF_CCM_CCGR91_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR91, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR91_SETTING3 (12U)       /*!< Bit position for CCM_CCGR91_SETTING3. */
#define BM_CCM_CCGR91_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR91_SETTING3. */
#define BS_CCM_CCGR91_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR91_SETTING3. */

/*! @brief Read current value of the CCM_CCGR91_SETTING3 field. */
#define BR_CCM_CCGR91_SETTING3(x) (HW_CCM_CCGR91(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR91_SETTING3. */
#define BF_CCM_CCGR91_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR91_SETTING3) & BM_CCM_CCGR91_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR91_SETTING3(x, v) (HW_CCM_CCGR91_WR(x, (HW_CCM_CCGR91_RD(x) & ~BM_CCM_CCGR91_SETTING3) | BF_CCM_CCGR91_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR92 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR92 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr92
{
    uint32_t U;
    struct _hw_ccm_ccgr92_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr92_t;

/*!
 * @name Constants and macros for entire CCM_CCGR92 register
 */
/*@{*/
#define HW_CCM_CCGR92_ADDR(x)    ((uintptr_t)(x) + 0x45C0U)
#define HW_CCM_CCGR92_SET_ADDR(x) (HW_CCM_CCGR92_ADDR(x) + 0x4U)
#define HW_CCM_CCGR92_CLR_ADDR(x) (HW_CCM_CCGR92_ADDR(x) + 0x8U)
#define HW_CCM_CCGR92_TOG_ADDR(x) (HW_CCM_CCGR92_ADDR(x) + 0xCU)

#define HW_CCM_CCGR92(x)         (*(__IO hw_ccm_ccgr92_t *) HW_CCM_CCGR92_ADDR(x))
#define HW_CCM_CCGR92_RD(x)      (HW_CCM_CCGR92(x).U)
#define HW_CCM_CCGR92_WR(x, v)   (HW_CCM_CCGR92(x).U = (v))
#define HW_CCM_CCGR92_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR92_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR92_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR92_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR92_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR92_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR92 bitfields
 */

/*!
 * @name Register CCM_CCGR92, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR92_SETTING0 (0U)        /*!< Bit position for CCM_CCGR92_SETTING0. */
#define BM_CCM_CCGR92_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR92_SETTING0. */
#define BS_CCM_CCGR92_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR92_SETTING0. */

/*! @brief Read current value of the CCM_CCGR92_SETTING0 field. */
#define BR_CCM_CCGR92_SETTING0(x) (HW_CCM_CCGR92(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR92_SETTING0. */
#define BF_CCM_CCGR92_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR92_SETTING0) & BM_CCM_CCGR92_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR92_SETTING0(x, v) (HW_CCM_CCGR92_WR(x, (HW_CCM_CCGR92_RD(x) & ~BM_CCM_CCGR92_SETTING0) | BF_CCM_CCGR92_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR92, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR92_SETTING1 (4U)        /*!< Bit position for CCM_CCGR92_SETTING1. */
#define BM_CCM_CCGR92_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR92_SETTING1. */
#define BS_CCM_CCGR92_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR92_SETTING1. */

/*! @brief Read current value of the CCM_CCGR92_SETTING1 field. */
#define BR_CCM_CCGR92_SETTING1(x) (HW_CCM_CCGR92(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR92_SETTING1. */
#define BF_CCM_CCGR92_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR92_SETTING1) & BM_CCM_CCGR92_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR92_SETTING1(x, v) (HW_CCM_CCGR92_WR(x, (HW_CCM_CCGR92_RD(x) & ~BM_CCM_CCGR92_SETTING1) | BF_CCM_CCGR92_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR92, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR92_SETTING2 (8U)        /*!< Bit position for CCM_CCGR92_SETTING2. */
#define BM_CCM_CCGR92_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR92_SETTING2. */
#define BS_CCM_CCGR92_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR92_SETTING2. */

/*! @brief Read current value of the CCM_CCGR92_SETTING2 field. */
#define BR_CCM_CCGR92_SETTING2(x) (HW_CCM_CCGR92(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR92_SETTING2. */
#define BF_CCM_CCGR92_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR92_SETTING2) & BM_CCM_CCGR92_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR92_SETTING2(x, v) (HW_CCM_CCGR92_WR(x, (HW_CCM_CCGR92_RD(x) & ~BM_CCM_CCGR92_SETTING2) | BF_CCM_CCGR92_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR92, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR92_SETTING3 (12U)       /*!< Bit position for CCM_CCGR92_SETTING3. */
#define BM_CCM_CCGR92_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR92_SETTING3. */
#define BS_CCM_CCGR92_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR92_SETTING3. */

/*! @brief Read current value of the CCM_CCGR92_SETTING3 field. */
#define BR_CCM_CCGR92_SETTING3(x) (HW_CCM_CCGR92(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR92_SETTING3. */
#define BF_CCM_CCGR92_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR92_SETTING3) & BM_CCM_CCGR92_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR92_SETTING3(x, v) (HW_CCM_CCGR92_WR(x, (HW_CCM_CCGR92_RD(x) & ~BM_CCM_CCGR92_SETTING3) | BF_CCM_CCGR92_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR93 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR93 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr93
{
    uint32_t U;
    struct _hw_ccm_ccgr93_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr93_t;

/*!
 * @name Constants and macros for entire CCM_CCGR93 register
 */
/*@{*/
#define HW_CCM_CCGR93_ADDR(x)    ((uintptr_t)(x) + 0x45D0U)
#define HW_CCM_CCGR93_SET_ADDR(x) (HW_CCM_CCGR93_ADDR(x) + 0x4U)
#define HW_CCM_CCGR93_CLR_ADDR(x) (HW_CCM_CCGR93_ADDR(x) + 0x8U)
#define HW_CCM_CCGR93_TOG_ADDR(x) (HW_CCM_CCGR93_ADDR(x) + 0xCU)

#define HW_CCM_CCGR93(x)         (*(__IO hw_ccm_ccgr93_t *) HW_CCM_CCGR93_ADDR(x))
#define HW_CCM_CCGR93_RD(x)      (HW_CCM_CCGR93(x).U)
#define HW_CCM_CCGR93_WR(x, v)   (HW_CCM_CCGR93(x).U = (v))
#define HW_CCM_CCGR93_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR93_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR93_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR93_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR93_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR93_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR93 bitfields
 */

/*!
 * @name Register CCM_CCGR93, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR93_SETTING0 (0U)        /*!< Bit position for CCM_CCGR93_SETTING0. */
#define BM_CCM_CCGR93_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR93_SETTING0. */
#define BS_CCM_CCGR93_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR93_SETTING0. */

/*! @brief Read current value of the CCM_CCGR93_SETTING0 field. */
#define BR_CCM_CCGR93_SETTING0(x) (HW_CCM_CCGR93(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR93_SETTING0. */
#define BF_CCM_CCGR93_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR93_SETTING0) & BM_CCM_CCGR93_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR93_SETTING0(x, v) (HW_CCM_CCGR93_WR(x, (HW_CCM_CCGR93_RD(x) & ~BM_CCM_CCGR93_SETTING0) | BF_CCM_CCGR93_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR93, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR93_SETTING1 (4U)        /*!< Bit position for CCM_CCGR93_SETTING1. */
#define BM_CCM_CCGR93_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR93_SETTING1. */
#define BS_CCM_CCGR93_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR93_SETTING1. */

/*! @brief Read current value of the CCM_CCGR93_SETTING1 field. */
#define BR_CCM_CCGR93_SETTING1(x) (HW_CCM_CCGR93(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR93_SETTING1. */
#define BF_CCM_CCGR93_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR93_SETTING1) & BM_CCM_CCGR93_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR93_SETTING1(x, v) (HW_CCM_CCGR93_WR(x, (HW_CCM_CCGR93_RD(x) & ~BM_CCM_CCGR93_SETTING1) | BF_CCM_CCGR93_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR93, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR93_SETTING2 (8U)        /*!< Bit position for CCM_CCGR93_SETTING2. */
#define BM_CCM_CCGR93_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR93_SETTING2. */
#define BS_CCM_CCGR93_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR93_SETTING2. */

/*! @brief Read current value of the CCM_CCGR93_SETTING2 field. */
#define BR_CCM_CCGR93_SETTING2(x) (HW_CCM_CCGR93(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR93_SETTING2. */
#define BF_CCM_CCGR93_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR93_SETTING2) & BM_CCM_CCGR93_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR93_SETTING2(x, v) (HW_CCM_CCGR93_WR(x, (HW_CCM_CCGR93_RD(x) & ~BM_CCM_CCGR93_SETTING2) | BF_CCM_CCGR93_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR93, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR93_SETTING3 (12U)       /*!< Bit position for CCM_CCGR93_SETTING3. */
#define BM_CCM_CCGR93_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR93_SETTING3. */
#define BS_CCM_CCGR93_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR93_SETTING3. */

/*! @brief Read current value of the CCM_CCGR93_SETTING3 field. */
#define BR_CCM_CCGR93_SETTING3(x) (HW_CCM_CCGR93(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR93_SETTING3. */
#define BF_CCM_CCGR93_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR93_SETTING3) & BM_CCM_CCGR93_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR93_SETTING3(x, v) (HW_CCM_CCGR93_WR(x, (HW_CCM_CCGR93_RD(x) & ~BM_CCM_CCGR93_SETTING3) | BF_CCM_CCGR93_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR94 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR94 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr94
{
    uint32_t U;
    struct _hw_ccm_ccgr94_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr94_t;

/*!
 * @name Constants and macros for entire CCM_CCGR94 register
 */
/*@{*/
#define HW_CCM_CCGR94_ADDR(x)    ((uintptr_t)(x) + 0x45E0U)
#define HW_CCM_CCGR94_SET_ADDR(x) (HW_CCM_CCGR94_ADDR(x) + 0x4U)
#define HW_CCM_CCGR94_CLR_ADDR(x) (HW_CCM_CCGR94_ADDR(x) + 0x8U)
#define HW_CCM_CCGR94_TOG_ADDR(x) (HW_CCM_CCGR94_ADDR(x) + 0xCU)

#define HW_CCM_CCGR94(x)         (*(__IO hw_ccm_ccgr94_t *) HW_CCM_CCGR94_ADDR(x))
#define HW_CCM_CCGR94_RD(x)      (HW_CCM_CCGR94(x).U)
#define HW_CCM_CCGR94_WR(x, v)   (HW_CCM_CCGR94(x).U = (v))
#define HW_CCM_CCGR94_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR94_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR94_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR94_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR94_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR94_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR94 bitfields
 */

/*!
 * @name Register CCM_CCGR94, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR94_SETTING0 (0U)        /*!< Bit position for CCM_CCGR94_SETTING0. */
#define BM_CCM_CCGR94_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR94_SETTING0. */
#define BS_CCM_CCGR94_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR94_SETTING0. */

/*! @brief Read current value of the CCM_CCGR94_SETTING0 field. */
#define BR_CCM_CCGR94_SETTING0(x) (HW_CCM_CCGR94(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR94_SETTING0. */
#define BF_CCM_CCGR94_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR94_SETTING0) & BM_CCM_CCGR94_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR94_SETTING0(x, v) (HW_CCM_CCGR94_WR(x, (HW_CCM_CCGR94_RD(x) & ~BM_CCM_CCGR94_SETTING0) | BF_CCM_CCGR94_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR94, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR94_SETTING1 (4U)        /*!< Bit position for CCM_CCGR94_SETTING1. */
#define BM_CCM_CCGR94_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR94_SETTING1. */
#define BS_CCM_CCGR94_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR94_SETTING1. */

/*! @brief Read current value of the CCM_CCGR94_SETTING1 field. */
#define BR_CCM_CCGR94_SETTING1(x) (HW_CCM_CCGR94(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR94_SETTING1. */
#define BF_CCM_CCGR94_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR94_SETTING1) & BM_CCM_CCGR94_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR94_SETTING1(x, v) (HW_CCM_CCGR94_WR(x, (HW_CCM_CCGR94_RD(x) & ~BM_CCM_CCGR94_SETTING1) | BF_CCM_CCGR94_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR94, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR94_SETTING2 (8U)        /*!< Bit position for CCM_CCGR94_SETTING2. */
#define BM_CCM_CCGR94_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR94_SETTING2. */
#define BS_CCM_CCGR94_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR94_SETTING2. */

/*! @brief Read current value of the CCM_CCGR94_SETTING2 field. */
#define BR_CCM_CCGR94_SETTING2(x) (HW_CCM_CCGR94(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR94_SETTING2. */
#define BF_CCM_CCGR94_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR94_SETTING2) & BM_CCM_CCGR94_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR94_SETTING2(x, v) (HW_CCM_CCGR94_WR(x, (HW_CCM_CCGR94_RD(x) & ~BM_CCM_CCGR94_SETTING2) | BF_CCM_CCGR94_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR94, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR94_SETTING3 (12U)       /*!< Bit position for CCM_CCGR94_SETTING3. */
#define BM_CCM_CCGR94_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR94_SETTING3. */
#define BS_CCM_CCGR94_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR94_SETTING3. */

/*! @brief Read current value of the CCM_CCGR94_SETTING3 field. */
#define BR_CCM_CCGR94_SETTING3(x) (HW_CCM_CCGR94(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR94_SETTING3. */
#define BF_CCM_CCGR94_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR94_SETTING3) & BM_CCM_CCGR94_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR94_SETTING3(x, v) (HW_CCM_CCGR94_WR(x, (HW_CCM_CCGR94_RD(x) & ~BM_CCM_CCGR94_SETTING3) | BF_CCM_CCGR94_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR95 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR95 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr95
{
    uint32_t U;
    struct _hw_ccm_ccgr95_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr95_t;

/*!
 * @name Constants and macros for entire CCM_CCGR95 register
 */
/*@{*/
#define HW_CCM_CCGR95_ADDR(x)    ((uintptr_t)(x) + 0x45F0U)
#define HW_CCM_CCGR95_SET_ADDR(x) (HW_CCM_CCGR95_ADDR(x) + 0x4U)
#define HW_CCM_CCGR95_CLR_ADDR(x) (HW_CCM_CCGR95_ADDR(x) + 0x8U)
#define HW_CCM_CCGR95_TOG_ADDR(x) (HW_CCM_CCGR95_ADDR(x) + 0xCU)

#define HW_CCM_CCGR95(x)         (*(__IO hw_ccm_ccgr95_t *) HW_CCM_CCGR95_ADDR(x))
#define HW_CCM_CCGR95_RD(x)      (HW_CCM_CCGR95(x).U)
#define HW_CCM_CCGR95_WR(x, v)   (HW_CCM_CCGR95(x).U = (v))
#define HW_CCM_CCGR95_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR95_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR95_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR95_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR95_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR95_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR95 bitfields
 */

/*!
 * @name Register CCM_CCGR95, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR95_SETTING0 (0U)        /*!< Bit position for CCM_CCGR95_SETTING0. */
#define BM_CCM_CCGR95_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR95_SETTING0. */
#define BS_CCM_CCGR95_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR95_SETTING0. */

/*! @brief Read current value of the CCM_CCGR95_SETTING0 field. */
#define BR_CCM_CCGR95_SETTING0(x) (HW_CCM_CCGR95(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR95_SETTING0. */
#define BF_CCM_CCGR95_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR95_SETTING0) & BM_CCM_CCGR95_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR95_SETTING0(x, v) (HW_CCM_CCGR95_WR(x, (HW_CCM_CCGR95_RD(x) & ~BM_CCM_CCGR95_SETTING0) | BF_CCM_CCGR95_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR95, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR95_SETTING1 (4U)        /*!< Bit position for CCM_CCGR95_SETTING1. */
#define BM_CCM_CCGR95_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR95_SETTING1. */
#define BS_CCM_CCGR95_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR95_SETTING1. */

/*! @brief Read current value of the CCM_CCGR95_SETTING1 field. */
#define BR_CCM_CCGR95_SETTING1(x) (HW_CCM_CCGR95(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR95_SETTING1. */
#define BF_CCM_CCGR95_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR95_SETTING1) & BM_CCM_CCGR95_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR95_SETTING1(x, v) (HW_CCM_CCGR95_WR(x, (HW_CCM_CCGR95_RD(x) & ~BM_CCM_CCGR95_SETTING1) | BF_CCM_CCGR95_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR95, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR95_SETTING2 (8U)        /*!< Bit position for CCM_CCGR95_SETTING2. */
#define BM_CCM_CCGR95_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR95_SETTING2. */
#define BS_CCM_CCGR95_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR95_SETTING2. */

/*! @brief Read current value of the CCM_CCGR95_SETTING2 field. */
#define BR_CCM_CCGR95_SETTING2(x) (HW_CCM_CCGR95(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR95_SETTING2. */
#define BF_CCM_CCGR95_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR95_SETTING2) & BM_CCM_CCGR95_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR95_SETTING2(x, v) (HW_CCM_CCGR95_WR(x, (HW_CCM_CCGR95_RD(x) & ~BM_CCM_CCGR95_SETTING2) | BF_CCM_CCGR95_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR95, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR95_SETTING3 (12U)       /*!< Bit position for CCM_CCGR95_SETTING3. */
#define BM_CCM_CCGR95_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR95_SETTING3. */
#define BS_CCM_CCGR95_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR95_SETTING3. */

/*! @brief Read current value of the CCM_CCGR95_SETTING3 field. */
#define BR_CCM_CCGR95_SETTING3(x) (HW_CCM_CCGR95(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR95_SETTING3. */
#define BF_CCM_CCGR95_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR95_SETTING3) & BM_CCM_CCGR95_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR95_SETTING3(x, v) (HW_CCM_CCGR95_WR(x, (HW_CCM_CCGR95_RD(x) & ~BM_CCM_CCGR95_SETTING3) | BF_CCM_CCGR95_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR96 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR96 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr96
{
    uint32_t U;
    struct _hw_ccm_ccgr96_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr96_t;

/*!
 * @name Constants and macros for entire CCM_CCGR96 register
 */
/*@{*/
#define HW_CCM_CCGR96_ADDR(x)    ((uintptr_t)(x) + 0x4600U)
#define HW_CCM_CCGR96_SET_ADDR(x) (HW_CCM_CCGR96_ADDR(x) + 0x4U)
#define HW_CCM_CCGR96_CLR_ADDR(x) (HW_CCM_CCGR96_ADDR(x) + 0x8U)
#define HW_CCM_CCGR96_TOG_ADDR(x) (HW_CCM_CCGR96_ADDR(x) + 0xCU)

#define HW_CCM_CCGR96(x)         (*(__IO hw_ccm_ccgr96_t *) HW_CCM_CCGR96_ADDR(x))
#define HW_CCM_CCGR96_RD(x)      (HW_CCM_CCGR96(x).U)
#define HW_CCM_CCGR96_WR(x, v)   (HW_CCM_CCGR96(x).U = (v))
#define HW_CCM_CCGR96_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR96_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR96_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR96_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR96_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR96_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR96 bitfields
 */

/*!
 * @name Register CCM_CCGR96, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR96_SETTING0 (0U)        /*!< Bit position for CCM_CCGR96_SETTING0. */
#define BM_CCM_CCGR96_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR96_SETTING0. */
#define BS_CCM_CCGR96_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR96_SETTING0. */

/*! @brief Read current value of the CCM_CCGR96_SETTING0 field. */
#define BR_CCM_CCGR96_SETTING0(x) (HW_CCM_CCGR96(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR96_SETTING0. */
#define BF_CCM_CCGR96_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR96_SETTING0) & BM_CCM_CCGR96_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR96_SETTING0(x, v) (HW_CCM_CCGR96_WR(x, (HW_CCM_CCGR96_RD(x) & ~BM_CCM_CCGR96_SETTING0) | BF_CCM_CCGR96_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR96, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR96_SETTING1 (4U)        /*!< Bit position for CCM_CCGR96_SETTING1. */
#define BM_CCM_CCGR96_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR96_SETTING1. */
#define BS_CCM_CCGR96_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR96_SETTING1. */

/*! @brief Read current value of the CCM_CCGR96_SETTING1 field. */
#define BR_CCM_CCGR96_SETTING1(x) (HW_CCM_CCGR96(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR96_SETTING1. */
#define BF_CCM_CCGR96_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR96_SETTING1) & BM_CCM_CCGR96_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR96_SETTING1(x, v) (HW_CCM_CCGR96_WR(x, (HW_CCM_CCGR96_RD(x) & ~BM_CCM_CCGR96_SETTING1) | BF_CCM_CCGR96_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR96, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR96_SETTING2 (8U)        /*!< Bit position for CCM_CCGR96_SETTING2. */
#define BM_CCM_CCGR96_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR96_SETTING2. */
#define BS_CCM_CCGR96_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR96_SETTING2. */

/*! @brief Read current value of the CCM_CCGR96_SETTING2 field. */
#define BR_CCM_CCGR96_SETTING2(x) (HW_CCM_CCGR96(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR96_SETTING2. */
#define BF_CCM_CCGR96_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR96_SETTING2) & BM_CCM_CCGR96_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR96_SETTING2(x, v) (HW_CCM_CCGR96_WR(x, (HW_CCM_CCGR96_RD(x) & ~BM_CCM_CCGR96_SETTING2) | BF_CCM_CCGR96_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR96, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR96_SETTING3 (12U)       /*!< Bit position for CCM_CCGR96_SETTING3. */
#define BM_CCM_CCGR96_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR96_SETTING3. */
#define BS_CCM_CCGR96_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR96_SETTING3. */

/*! @brief Read current value of the CCM_CCGR96_SETTING3 field. */
#define BR_CCM_CCGR96_SETTING3(x) (HW_CCM_CCGR96(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR96_SETTING3. */
#define BF_CCM_CCGR96_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR96_SETTING3) & BM_CCM_CCGR96_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR96_SETTING3(x, v) (HW_CCM_CCGR96_WR(x, (HW_CCM_CCGR96_RD(x) & ~BM_CCM_CCGR96_SETTING3) | BF_CCM_CCGR96_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR97 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR97 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr97
{
    uint32_t U;
    struct _hw_ccm_ccgr97_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr97_t;

/*!
 * @name Constants and macros for entire CCM_CCGR97 register
 */
/*@{*/
#define HW_CCM_CCGR97_ADDR(x)    ((uintptr_t)(x) + 0x4610U)
#define HW_CCM_CCGR97_SET_ADDR(x) (HW_CCM_CCGR97_ADDR(x) + 0x4U)
#define HW_CCM_CCGR97_CLR_ADDR(x) (HW_CCM_CCGR97_ADDR(x) + 0x8U)
#define HW_CCM_CCGR97_TOG_ADDR(x) (HW_CCM_CCGR97_ADDR(x) + 0xCU)

#define HW_CCM_CCGR97(x)         (*(__IO hw_ccm_ccgr97_t *) HW_CCM_CCGR97_ADDR(x))
#define HW_CCM_CCGR97_RD(x)      (HW_CCM_CCGR97(x).U)
#define HW_CCM_CCGR97_WR(x, v)   (HW_CCM_CCGR97(x).U = (v))
#define HW_CCM_CCGR97_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR97_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR97_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR97_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR97_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR97_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR97 bitfields
 */

/*!
 * @name Register CCM_CCGR97, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR97_SETTING0 (0U)        /*!< Bit position for CCM_CCGR97_SETTING0. */
#define BM_CCM_CCGR97_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR97_SETTING0. */
#define BS_CCM_CCGR97_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR97_SETTING0. */

/*! @brief Read current value of the CCM_CCGR97_SETTING0 field. */
#define BR_CCM_CCGR97_SETTING0(x) (HW_CCM_CCGR97(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR97_SETTING0. */
#define BF_CCM_CCGR97_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR97_SETTING0) & BM_CCM_CCGR97_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR97_SETTING0(x, v) (HW_CCM_CCGR97_WR(x, (HW_CCM_CCGR97_RD(x) & ~BM_CCM_CCGR97_SETTING0) | BF_CCM_CCGR97_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR97, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR97_SETTING1 (4U)        /*!< Bit position for CCM_CCGR97_SETTING1. */
#define BM_CCM_CCGR97_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR97_SETTING1. */
#define BS_CCM_CCGR97_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR97_SETTING1. */

/*! @brief Read current value of the CCM_CCGR97_SETTING1 field. */
#define BR_CCM_CCGR97_SETTING1(x) (HW_CCM_CCGR97(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR97_SETTING1. */
#define BF_CCM_CCGR97_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR97_SETTING1) & BM_CCM_CCGR97_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR97_SETTING1(x, v) (HW_CCM_CCGR97_WR(x, (HW_CCM_CCGR97_RD(x) & ~BM_CCM_CCGR97_SETTING1) | BF_CCM_CCGR97_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR97, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR97_SETTING2 (8U)        /*!< Bit position for CCM_CCGR97_SETTING2. */
#define BM_CCM_CCGR97_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR97_SETTING2. */
#define BS_CCM_CCGR97_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR97_SETTING2. */

/*! @brief Read current value of the CCM_CCGR97_SETTING2 field. */
#define BR_CCM_CCGR97_SETTING2(x) (HW_CCM_CCGR97(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR97_SETTING2. */
#define BF_CCM_CCGR97_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR97_SETTING2) & BM_CCM_CCGR97_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR97_SETTING2(x, v) (HW_CCM_CCGR97_WR(x, (HW_CCM_CCGR97_RD(x) & ~BM_CCM_CCGR97_SETTING2) | BF_CCM_CCGR97_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR97, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR97_SETTING3 (12U)       /*!< Bit position for CCM_CCGR97_SETTING3. */
#define BM_CCM_CCGR97_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR97_SETTING3. */
#define BS_CCM_CCGR97_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR97_SETTING3. */

/*! @brief Read current value of the CCM_CCGR97_SETTING3 field. */
#define BR_CCM_CCGR97_SETTING3(x) (HW_CCM_CCGR97(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR97_SETTING3. */
#define BF_CCM_CCGR97_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR97_SETTING3) & BM_CCM_CCGR97_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR97_SETTING3(x, v) (HW_CCM_CCGR97_WR(x, (HW_CCM_CCGR97_RD(x) & ~BM_CCM_CCGR97_SETTING3) | BF_CCM_CCGR97_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR98 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR98 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr98
{
    uint32_t U;
    struct _hw_ccm_ccgr98_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr98_t;

/*!
 * @name Constants and macros for entire CCM_CCGR98 register
 */
/*@{*/
#define HW_CCM_CCGR98_ADDR(x)    ((uintptr_t)(x) + 0x4620U)
#define HW_CCM_CCGR98_SET_ADDR(x) (HW_CCM_CCGR98_ADDR(x) + 0x4U)
#define HW_CCM_CCGR98_CLR_ADDR(x) (HW_CCM_CCGR98_ADDR(x) + 0x8U)
#define HW_CCM_CCGR98_TOG_ADDR(x) (HW_CCM_CCGR98_ADDR(x) + 0xCU)

#define HW_CCM_CCGR98(x)         (*(__IO hw_ccm_ccgr98_t *) HW_CCM_CCGR98_ADDR(x))
#define HW_CCM_CCGR98_RD(x)      (HW_CCM_CCGR98(x).U)
#define HW_CCM_CCGR98_WR(x, v)   (HW_CCM_CCGR98(x).U = (v))
#define HW_CCM_CCGR98_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR98_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR98_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR98_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR98_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR98_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR98 bitfields
 */

/*!
 * @name Register CCM_CCGR98, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR98_SETTING0 (0U)        /*!< Bit position for CCM_CCGR98_SETTING0. */
#define BM_CCM_CCGR98_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR98_SETTING0. */
#define BS_CCM_CCGR98_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR98_SETTING0. */

/*! @brief Read current value of the CCM_CCGR98_SETTING0 field. */
#define BR_CCM_CCGR98_SETTING0(x) (HW_CCM_CCGR98(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR98_SETTING0. */
#define BF_CCM_CCGR98_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR98_SETTING0) & BM_CCM_CCGR98_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR98_SETTING0(x, v) (HW_CCM_CCGR98_WR(x, (HW_CCM_CCGR98_RD(x) & ~BM_CCM_CCGR98_SETTING0) | BF_CCM_CCGR98_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR98, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR98_SETTING1 (4U)        /*!< Bit position for CCM_CCGR98_SETTING1. */
#define BM_CCM_CCGR98_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR98_SETTING1. */
#define BS_CCM_CCGR98_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR98_SETTING1. */

/*! @brief Read current value of the CCM_CCGR98_SETTING1 field. */
#define BR_CCM_CCGR98_SETTING1(x) (HW_CCM_CCGR98(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR98_SETTING1. */
#define BF_CCM_CCGR98_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR98_SETTING1) & BM_CCM_CCGR98_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR98_SETTING1(x, v) (HW_CCM_CCGR98_WR(x, (HW_CCM_CCGR98_RD(x) & ~BM_CCM_CCGR98_SETTING1) | BF_CCM_CCGR98_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR98, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR98_SETTING2 (8U)        /*!< Bit position for CCM_CCGR98_SETTING2. */
#define BM_CCM_CCGR98_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR98_SETTING2. */
#define BS_CCM_CCGR98_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR98_SETTING2. */

/*! @brief Read current value of the CCM_CCGR98_SETTING2 field. */
#define BR_CCM_CCGR98_SETTING2(x) (HW_CCM_CCGR98(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR98_SETTING2. */
#define BF_CCM_CCGR98_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR98_SETTING2) & BM_CCM_CCGR98_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR98_SETTING2(x, v) (HW_CCM_CCGR98_WR(x, (HW_CCM_CCGR98_RD(x) & ~BM_CCM_CCGR98_SETTING2) | BF_CCM_CCGR98_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR98, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR98_SETTING3 (12U)       /*!< Bit position for CCM_CCGR98_SETTING3. */
#define BM_CCM_CCGR98_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR98_SETTING3. */
#define BS_CCM_CCGR98_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR98_SETTING3. */

/*! @brief Read current value of the CCM_CCGR98_SETTING3 field. */
#define BR_CCM_CCGR98_SETTING3(x) (HW_CCM_CCGR98(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR98_SETTING3. */
#define BF_CCM_CCGR98_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR98_SETTING3) & BM_CCM_CCGR98_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR98_SETTING3(x, v) (HW_CCM_CCGR98_WR(x, (HW_CCM_CCGR98_RD(x) & ~BM_CCM_CCGR98_SETTING3) | BF_CCM_CCGR98_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR99 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR99 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr99
{
    uint32_t U;
    struct _hw_ccm_ccgr99_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr99_t;

/*!
 * @name Constants and macros for entire CCM_CCGR99 register
 */
/*@{*/
#define HW_CCM_CCGR99_ADDR(x)    ((uintptr_t)(x) + 0x4630U)
#define HW_CCM_CCGR99_SET_ADDR(x) (HW_CCM_CCGR99_ADDR(x) + 0x4U)
#define HW_CCM_CCGR99_CLR_ADDR(x) (HW_CCM_CCGR99_ADDR(x) + 0x8U)
#define HW_CCM_CCGR99_TOG_ADDR(x) (HW_CCM_CCGR99_ADDR(x) + 0xCU)

#define HW_CCM_CCGR99(x)         (*(__IO hw_ccm_ccgr99_t *) HW_CCM_CCGR99_ADDR(x))
#define HW_CCM_CCGR99_RD(x)      (HW_CCM_CCGR99(x).U)
#define HW_CCM_CCGR99_WR(x, v)   (HW_CCM_CCGR99(x).U = (v))
#define HW_CCM_CCGR99_SET(x, v)  ((*(uint32_t *) HW_CCM_CCGR99_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR99_CLR(x, v)  ((*(uint32_t *) HW_CCM_CCGR99_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR99_TOG(x, v)  ((*(uint32_t *) HW_CCM_CCGR99_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR99 bitfields
 */

/*!
 * @name Register CCM_CCGR99, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR99_SETTING0 (0U)        /*!< Bit position for CCM_CCGR99_SETTING0. */
#define BM_CCM_CCGR99_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR99_SETTING0. */
#define BS_CCM_CCGR99_SETTING0 (2U)        /*!< Bit field size in bits for CCM_CCGR99_SETTING0. */

/*! @brief Read current value of the CCM_CCGR99_SETTING0 field. */
#define BR_CCM_CCGR99_SETTING0(x) (HW_CCM_CCGR99(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR99_SETTING0. */
#define BF_CCM_CCGR99_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR99_SETTING0) & BM_CCM_CCGR99_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR99_SETTING0(x, v) (HW_CCM_CCGR99_WR(x, (HW_CCM_CCGR99_RD(x) & ~BM_CCM_CCGR99_SETTING0) | BF_CCM_CCGR99_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR99, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR99_SETTING1 (4U)        /*!< Bit position for CCM_CCGR99_SETTING1. */
#define BM_CCM_CCGR99_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR99_SETTING1. */
#define BS_CCM_CCGR99_SETTING1 (2U)        /*!< Bit field size in bits for CCM_CCGR99_SETTING1. */

/*! @brief Read current value of the CCM_CCGR99_SETTING1 field. */
#define BR_CCM_CCGR99_SETTING1(x) (HW_CCM_CCGR99(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR99_SETTING1. */
#define BF_CCM_CCGR99_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR99_SETTING1) & BM_CCM_CCGR99_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR99_SETTING1(x, v) (HW_CCM_CCGR99_WR(x, (HW_CCM_CCGR99_RD(x) & ~BM_CCM_CCGR99_SETTING1) | BF_CCM_CCGR99_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR99, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR99_SETTING2 (8U)        /*!< Bit position for CCM_CCGR99_SETTING2. */
#define BM_CCM_CCGR99_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR99_SETTING2. */
#define BS_CCM_CCGR99_SETTING2 (2U)        /*!< Bit field size in bits for CCM_CCGR99_SETTING2. */

/*! @brief Read current value of the CCM_CCGR99_SETTING2 field. */
#define BR_CCM_CCGR99_SETTING2(x) (HW_CCM_CCGR99(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR99_SETTING2. */
#define BF_CCM_CCGR99_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR99_SETTING2) & BM_CCM_CCGR99_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR99_SETTING2(x, v) (HW_CCM_CCGR99_WR(x, (HW_CCM_CCGR99_RD(x) & ~BM_CCM_CCGR99_SETTING2) | BF_CCM_CCGR99_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR99, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR99_SETTING3 (12U)       /*!< Bit position for CCM_CCGR99_SETTING3. */
#define BM_CCM_CCGR99_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR99_SETTING3. */
#define BS_CCM_CCGR99_SETTING3 (2U)        /*!< Bit field size in bits for CCM_CCGR99_SETTING3. */

/*! @brief Read current value of the CCM_CCGR99_SETTING3 field. */
#define BR_CCM_CCGR99_SETTING3(x) (HW_CCM_CCGR99(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR99_SETTING3. */
#define BF_CCM_CCGR99_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR99_SETTING3) & BM_CCM_CCGR99_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR99_SETTING3(x, v) (HW_CCM_CCGR99_WR(x, (HW_CCM_CCGR99_RD(x) & ~BM_CCM_CCGR99_SETTING3) | BF_CCM_CCGR99_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR100 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR100 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr100
{
    uint32_t U;
    struct _hw_ccm_ccgr100_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr100_t;

/*!
 * @name Constants and macros for entire CCM_CCGR100 register
 */
/*@{*/
#define HW_CCM_CCGR100_ADDR(x)   ((uintptr_t)(x) + 0x4640U)
#define HW_CCM_CCGR100_SET_ADDR(x) (HW_CCM_CCGR100_ADDR(x) + 0x4U)
#define HW_CCM_CCGR100_CLR_ADDR(x) (HW_CCM_CCGR100_ADDR(x) + 0x8U)
#define HW_CCM_CCGR100_TOG_ADDR(x) (HW_CCM_CCGR100_ADDR(x) + 0xCU)

#define HW_CCM_CCGR100(x)        (*(__IO hw_ccm_ccgr100_t *) HW_CCM_CCGR100_ADDR(x))
#define HW_CCM_CCGR100_RD(x)     (HW_CCM_CCGR100(x).U)
#define HW_CCM_CCGR100_WR(x, v)  (HW_CCM_CCGR100(x).U = (v))
#define HW_CCM_CCGR100_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR100_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR100_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR100_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR100_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR100_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR100 bitfields
 */

/*!
 * @name Register CCM_CCGR100, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR100_SETTING0 (0U)       /*!< Bit position for CCM_CCGR100_SETTING0. */
#define BM_CCM_CCGR100_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR100_SETTING0. */
#define BS_CCM_CCGR100_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR100_SETTING0. */

/*! @brief Read current value of the CCM_CCGR100_SETTING0 field. */
#define BR_CCM_CCGR100_SETTING0(x) (HW_CCM_CCGR100(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR100_SETTING0. */
#define BF_CCM_CCGR100_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR100_SETTING0) & BM_CCM_CCGR100_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR100_SETTING0(x, v) (HW_CCM_CCGR100_WR(x, (HW_CCM_CCGR100_RD(x) & ~BM_CCM_CCGR100_SETTING0) | BF_CCM_CCGR100_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR100, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR100_SETTING1 (4U)       /*!< Bit position for CCM_CCGR100_SETTING1. */
#define BM_CCM_CCGR100_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR100_SETTING1. */
#define BS_CCM_CCGR100_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR100_SETTING1. */

/*! @brief Read current value of the CCM_CCGR100_SETTING1 field. */
#define BR_CCM_CCGR100_SETTING1(x) (HW_CCM_CCGR100(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR100_SETTING1. */
#define BF_CCM_CCGR100_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR100_SETTING1) & BM_CCM_CCGR100_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR100_SETTING1(x, v) (HW_CCM_CCGR100_WR(x, (HW_CCM_CCGR100_RD(x) & ~BM_CCM_CCGR100_SETTING1) | BF_CCM_CCGR100_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR100, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR100_SETTING2 (8U)       /*!< Bit position for CCM_CCGR100_SETTING2. */
#define BM_CCM_CCGR100_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR100_SETTING2. */
#define BS_CCM_CCGR100_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR100_SETTING2. */

/*! @brief Read current value of the CCM_CCGR100_SETTING2 field. */
#define BR_CCM_CCGR100_SETTING2(x) (HW_CCM_CCGR100(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR100_SETTING2. */
#define BF_CCM_CCGR100_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR100_SETTING2) & BM_CCM_CCGR100_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR100_SETTING2(x, v) (HW_CCM_CCGR100_WR(x, (HW_CCM_CCGR100_RD(x) & ~BM_CCM_CCGR100_SETTING2) | BF_CCM_CCGR100_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR100, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR100_SETTING3 (12U)      /*!< Bit position for CCM_CCGR100_SETTING3. */
#define BM_CCM_CCGR100_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR100_SETTING3. */
#define BS_CCM_CCGR100_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR100_SETTING3. */

/*! @brief Read current value of the CCM_CCGR100_SETTING3 field. */
#define BR_CCM_CCGR100_SETTING3(x) (HW_CCM_CCGR100(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR100_SETTING3. */
#define BF_CCM_CCGR100_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR100_SETTING3) & BM_CCM_CCGR100_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR100_SETTING3(x, v) (HW_CCM_CCGR100_WR(x, (HW_CCM_CCGR100_RD(x) & ~BM_CCM_CCGR100_SETTING3) | BF_CCM_CCGR100_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR101 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR101 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr101
{
    uint32_t U;
    struct _hw_ccm_ccgr101_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr101_t;

/*!
 * @name Constants and macros for entire CCM_CCGR101 register
 */
/*@{*/
#define HW_CCM_CCGR101_ADDR(x)   ((uintptr_t)(x) + 0x4650U)
#define HW_CCM_CCGR101_SET_ADDR(x) (HW_CCM_CCGR101_ADDR(x) + 0x4U)
#define HW_CCM_CCGR101_CLR_ADDR(x) (HW_CCM_CCGR101_ADDR(x) + 0x8U)
#define HW_CCM_CCGR101_TOG_ADDR(x) (HW_CCM_CCGR101_ADDR(x) + 0xCU)

#define HW_CCM_CCGR101(x)        (*(__IO hw_ccm_ccgr101_t *) HW_CCM_CCGR101_ADDR(x))
#define HW_CCM_CCGR101_RD(x)     (HW_CCM_CCGR101(x).U)
#define HW_CCM_CCGR101_WR(x, v)  (HW_CCM_CCGR101(x).U = (v))
#define HW_CCM_CCGR101_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR101_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR101_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR101_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR101_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR101_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR101 bitfields
 */

/*!
 * @name Register CCM_CCGR101, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR101_SETTING0 (0U)       /*!< Bit position for CCM_CCGR101_SETTING0. */
#define BM_CCM_CCGR101_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR101_SETTING0. */
#define BS_CCM_CCGR101_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR101_SETTING0. */

/*! @brief Read current value of the CCM_CCGR101_SETTING0 field. */
#define BR_CCM_CCGR101_SETTING0(x) (HW_CCM_CCGR101(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR101_SETTING0. */
#define BF_CCM_CCGR101_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR101_SETTING0) & BM_CCM_CCGR101_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR101_SETTING0(x, v) (HW_CCM_CCGR101_WR(x, (HW_CCM_CCGR101_RD(x) & ~BM_CCM_CCGR101_SETTING0) | BF_CCM_CCGR101_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR101, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR101_SETTING1 (4U)       /*!< Bit position for CCM_CCGR101_SETTING1. */
#define BM_CCM_CCGR101_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR101_SETTING1. */
#define BS_CCM_CCGR101_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR101_SETTING1. */

/*! @brief Read current value of the CCM_CCGR101_SETTING1 field. */
#define BR_CCM_CCGR101_SETTING1(x) (HW_CCM_CCGR101(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR101_SETTING1. */
#define BF_CCM_CCGR101_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR101_SETTING1) & BM_CCM_CCGR101_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR101_SETTING1(x, v) (HW_CCM_CCGR101_WR(x, (HW_CCM_CCGR101_RD(x) & ~BM_CCM_CCGR101_SETTING1) | BF_CCM_CCGR101_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR101, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR101_SETTING2 (8U)       /*!< Bit position for CCM_CCGR101_SETTING2. */
#define BM_CCM_CCGR101_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR101_SETTING2. */
#define BS_CCM_CCGR101_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR101_SETTING2. */

/*! @brief Read current value of the CCM_CCGR101_SETTING2 field. */
#define BR_CCM_CCGR101_SETTING2(x) (HW_CCM_CCGR101(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR101_SETTING2. */
#define BF_CCM_CCGR101_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR101_SETTING2) & BM_CCM_CCGR101_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR101_SETTING2(x, v) (HW_CCM_CCGR101_WR(x, (HW_CCM_CCGR101_RD(x) & ~BM_CCM_CCGR101_SETTING2) | BF_CCM_CCGR101_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR101, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR101_SETTING3 (12U)      /*!< Bit position for CCM_CCGR101_SETTING3. */
#define BM_CCM_CCGR101_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR101_SETTING3. */
#define BS_CCM_CCGR101_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR101_SETTING3. */

/*! @brief Read current value of the CCM_CCGR101_SETTING3 field. */
#define BR_CCM_CCGR101_SETTING3(x) (HW_CCM_CCGR101(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR101_SETTING3. */
#define BF_CCM_CCGR101_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR101_SETTING3) & BM_CCM_CCGR101_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR101_SETTING3(x, v) (HW_CCM_CCGR101_WR(x, (HW_CCM_CCGR101_RD(x) & ~BM_CCM_CCGR101_SETTING3) | BF_CCM_CCGR101_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR102 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR102 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr102
{
    uint32_t U;
    struct _hw_ccm_ccgr102_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr102_t;

/*!
 * @name Constants and macros for entire CCM_CCGR102 register
 */
/*@{*/
#define HW_CCM_CCGR102_ADDR(x)   ((uintptr_t)(x) + 0x4660U)
#define HW_CCM_CCGR102_SET_ADDR(x) (HW_CCM_CCGR102_ADDR(x) + 0x4U)
#define HW_CCM_CCGR102_CLR_ADDR(x) (HW_CCM_CCGR102_ADDR(x) + 0x8U)
#define HW_CCM_CCGR102_TOG_ADDR(x) (HW_CCM_CCGR102_ADDR(x) + 0xCU)

#define HW_CCM_CCGR102(x)        (*(__IO hw_ccm_ccgr102_t *) HW_CCM_CCGR102_ADDR(x))
#define HW_CCM_CCGR102_RD(x)     (HW_CCM_CCGR102(x).U)
#define HW_CCM_CCGR102_WR(x, v)  (HW_CCM_CCGR102(x).U = (v))
#define HW_CCM_CCGR102_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR102_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR102_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR102_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR102_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR102_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR102 bitfields
 */

/*!
 * @name Register CCM_CCGR102, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR102_SETTING0 (0U)       /*!< Bit position for CCM_CCGR102_SETTING0. */
#define BM_CCM_CCGR102_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR102_SETTING0. */
#define BS_CCM_CCGR102_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR102_SETTING0. */

/*! @brief Read current value of the CCM_CCGR102_SETTING0 field. */
#define BR_CCM_CCGR102_SETTING0(x) (HW_CCM_CCGR102(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR102_SETTING0. */
#define BF_CCM_CCGR102_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR102_SETTING0) & BM_CCM_CCGR102_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR102_SETTING0(x, v) (HW_CCM_CCGR102_WR(x, (HW_CCM_CCGR102_RD(x) & ~BM_CCM_CCGR102_SETTING0) | BF_CCM_CCGR102_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR102, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR102_SETTING1 (4U)       /*!< Bit position for CCM_CCGR102_SETTING1. */
#define BM_CCM_CCGR102_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR102_SETTING1. */
#define BS_CCM_CCGR102_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR102_SETTING1. */

/*! @brief Read current value of the CCM_CCGR102_SETTING1 field. */
#define BR_CCM_CCGR102_SETTING1(x) (HW_CCM_CCGR102(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR102_SETTING1. */
#define BF_CCM_CCGR102_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR102_SETTING1) & BM_CCM_CCGR102_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR102_SETTING1(x, v) (HW_CCM_CCGR102_WR(x, (HW_CCM_CCGR102_RD(x) & ~BM_CCM_CCGR102_SETTING1) | BF_CCM_CCGR102_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR102, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR102_SETTING2 (8U)       /*!< Bit position for CCM_CCGR102_SETTING2. */
#define BM_CCM_CCGR102_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR102_SETTING2. */
#define BS_CCM_CCGR102_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR102_SETTING2. */

/*! @brief Read current value of the CCM_CCGR102_SETTING2 field. */
#define BR_CCM_CCGR102_SETTING2(x) (HW_CCM_CCGR102(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR102_SETTING2. */
#define BF_CCM_CCGR102_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR102_SETTING2) & BM_CCM_CCGR102_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR102_SETTING2(x, v) (HW_CCM_CCGR102_WR(x, (HW_CCM_CCGR102_RD(x) & ~BM_CCM_CCGR102_SETTING2) | BF_CCM_CCGR102_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR102, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR102_SETTING3 (12U)      /*!< Bit position for CCM_CCGR102_SETTING3. */
#define BM_CCM_CCGR102_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR102_SETTING3. */
#define BS_CCM_CCGR102_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR102_SETTING3. */

/*! @brief Read current value of the CCM_CCGR102_SETTING3 field. */
#define BR_CCM_CCGR102_SETTING3(x) (HW_CCM_CCGR102(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR102_SETTING3. */
#define BF_CCM_CCGR102_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR102_SETTING3) & BM_CCM_CCGR102_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR102_SETTING3(x, v) (HW_CCM_CCGR102_WR(x, (HW_CCM_CCGR102_RD(x) & ~BM_CCM_CCGR102_SETTING3) | BF_CCM_CCGR102_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR103 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR103 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr103
{
    uint32_t U;
    struct _hw_ccm_ccgr103_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr103_t;

/*!
 * @name Constants and macros for entire CCM_CCGR103 register
 */
/*@{*/
#define HW_CCM_CCGR103_ADDR(x)   ((uintptr_t)(x) + 0x4670U)
#define HW_CCM_CCGR103_SET_ADDR(x) (HW_CCM_CCGR103_ADDR(x) + 0x4U)
#define HW_CCM_CCGR103_CLR_ADDR(x) (HW_CCM_CCGR103_ADDR(x) + 0x8U)
#define HW_CCM_CCGR103_TOG_ADDR(x) (HW_CCM_CCGR103_ADDR(x) + 0xCU)

#define HW_CCM_CCGR103(x)        (*(__IO hw_ccm_ccgr103_t *) HW_CCM_CCGR103_ADDR(x))
#define HW_CCM_CCGR103_RD(x)     (HW_CCM_CCGR103(x).U)
#define HW_CCM_CCGR103_WR(x, v)  (HW_CCM_CCGR103(x).U = (v))
#define HW_CCM_CCGR103_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR103_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR103_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR103_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR103_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR103_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR103 bitfields
 */

/*!
 * @name Register CCM_CCGR103, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR103_SETTING0 (0U)       /*!< Bit position for CCM_CCGR103_SETTING0. */
#define BM_CCM_CCGR103_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR103_SETTING0. */
#define BS_CCM_CCGR103_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR103_SETTING0. */

/*! @brief Read current value of the CCM_CCGR103_SETTING0 field. */
#define BR_CCM_CCGR103_SETTING0(x) (HW_CCM_CCGR103(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR103_SETTING0. */
#define BF_CCM_CCGR103_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR103_SETTING0) & BM_CCM_CCGR103_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR103_SETTING0(x, v) (HW_CCM_CCGR103_WR(x, (HW_CCM_CCGR103_RD(x) & ~BM_CCM_CCGR103_SETTING0) | BF_CCM_CCGR103_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR103, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR103_SETTING1 (4U)       /*!< Bit position for CCM_CCGR103_SETTING1. */
#define BM_CCM_CCGR103_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR103_SETTING1. */
#define BS_CCM_CCGR103_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR103_SETTING1. */

/*! @brief Read current value of the CCM_CCGR103_SETTING1 field. */
#define BR_CCM_CCGR103_SETTING1(x) (HW_CCM_CCGR103(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR103_SETTING1. */
#define BF_CCM_CCGR103_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR103_SETTING1) & BM_CCM_CCGR103_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR103_SETTING1(x, v) (HW_CCM_CCGR103_WR(x, (HW_CCM_CCGR103_RD(x) & ~BM_CCM_CCGR103_SETTING1) | BF_CCM_CCGR103_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR103, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR103_SETTING2 (8U)       /*!< Bit position for CCM_CCGR103_SETTING2. */
#define BM_CCM_CCGR103_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR103_SETTING2. */
#define BS_CCM_CCGR103_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR103_SETTING2. */

/*! @brief Read current value of the CCM_CCGR103_SETTING2 field. */
#define BR_CCM_CCGR103_SETTING2(x) (HW_CCM_CCGR103(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR103_SETTING2. */
#define BF_CCM_CCGR103_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR103_SETTING2) & BM_CCM_CCGR103_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR103_SETTING2(x, v) (HW_CCM_CCGR103_WR(x, (HW_CCM_CCGR103_RD(x) & ~BM_CCM_CCGR103_SETTING2) | BF_CCM_CCGR103_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR103, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR103_SETTING3 (12U)      /*!< Bit position for CCM_CCGR103_SETTING3. */
#define BM_CCM_CCGR103_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR103_SETTING3. */
#define BS_CCM_CCGR103_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR103_SETTING3. */

/*! @brief Read current value of the CCM_CCGR103_SETTING3 field. */
#define BR_CCM_CCGR103_SETTING3(x) (HW_CCM_CCGR103(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR103_SETTING3. */
#define BF_CCM_CCGR103_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR103_SETTING3) & BM_CCM_CCGR103_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR103_SETTING3(x, v) (HW_CCM_CCGR103_WR(x, (HW_CCM_CCGR103_RD(x) & ~BM_CCM_CCGR103_SETTING3) | BF_CCM_CCGR103_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR104 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR104 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr104
{
    uint32_t U;
    struct _hw_ccm_ccgr104_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr104_t;

/*!
 * @name Constants and macros for entire CCM_CCGR104 register
 */
/*@{*/
#define HW_CCM_CCGR104_ADDR(x)   ((uintptr_t)(x) + 0x4680U)
#define HW_CCM_CCGR104_SET_ADDR(x) (HW_CCM_CCGR104_ADDR(x) + 0x4U)
#define HW_CCM_CCGR104_CLR_ADDR(x) (HW_CCM_CCGR104_ADDR(x) + 0x8U)
#define HW_CCM_CCGR104_TOG_ADDR(x) (HW_CCM_CCGR104_ADDR(x) + 0xCU)

#define HW_CCM_CCGR104(x)        (*(__IO hw_ccm_ccgr104_t *) HW_CCM_CCGR104_ADDR(x))
#define HW_CCM_CCGR104_RD(x)     (HW_CCM_CCGR104(x).U)
#define HW_CCM_CCGR104_WR(x, v)  (HW_CCM_CCGR104(x).U = (v))
#define HW_CCM_CCGR104_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR104_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR104_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR104_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR104_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR104_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR104 bitfields
 */

/*!
 * @name Register CCM_CCGR104, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR104_SETTING0 (0U)       /*!< Bit position for CCM_CCGR104_SETTING0. */
#define BM_CCM_CCGR104_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR104_SETTING0. */
#define BS_CCM_CCGR104_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR104_SETTING0. */

/*! @brief Read current value of the CCM_CCGR104_SETTING0 field. */
#define BR_CCM_CCGR104_SETTING0(x) (HW_CCM_CCGR104(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR104_SETTING0. */
#define BF_CCM_CCGR104_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR104_SETTING0) & BM_CCM_CCGR104_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR104_SETTING0(x, v) (HW_CCM_CCGR104_WR(x, (HW_CCM_CCGR104_RD(x) & ~BM_CCM_CCGR104_SETTING0) | BF_CCM_CCGR104_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR104, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR104_SETTING1 (4U)       /*!< Bit position for CCM_CCGR104_SETTING1. */
#define BM_CCM_CCGR104_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR104_SETTING1. */
#define BS_CCM_CCGR104_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR104_SETTING1. */

/*! @brief Read current value of the CCM_CCGR104_SETTING1 field. */
#define BR_CCM_CCGR104_SETTING1(x) (HW_CCM_CCGR104(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR104_SETTING1. */
#define BF_CCM_CCGR104_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR104_SETTING1) & BM_CCM_CCGR104_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR104_SETTING1(x, v) (HW_CCM_CCGR104_WR(x, (HW_CCM_CCGR104_RD(x) & ~BM_CCM_CCGR104_SETTING1) | BF_CCM_CCGR104_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR104, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR104_SETTING2 (8U)       /*!< Bit position for CCM_CCGR104_SETTING2. */
#define BM_CCM_CCGR104_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR104_SETTING2. */
#define BS_CCM_CCGR104_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR104_SETTING2. */

/*! @brief Read current value of the CCM_CCGR104_SETTING2 field. */
#define BR_CCM_CCGR104_SETTING2(x) (HW_CCM_CCGR104(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR104_SETTING2. */
#define BF_CCM_CCGR104_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR104_SETTING2) & BM_CCM_CCGR104_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR104_SETTING2(x, v) (HW_CCM_CCGR104_WR(x, (HW_CCM_CCGR104_RD(x) & ~BM_CCM_CCGR104_SETTING2) | BF_CCM_CCGR104_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR104, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR104_SETTING3 (12U)      /*!< Bit position for CCM_CCGR104_SETTING3. */
#define BM_CCM_CCGR104_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR104_SETTING3. */
#define BS_CCM_CCGR104_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR104_SETTING3. */

/*! @brief Read current value of the CCM_CCGR104_SETTING3 field. */
#define BR_CCM_CCGR104_SETTING3(x) (HW_CCM_CCGR104(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR104_SETTING3. */
#define BF_CCM_CCGR104_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR104_SETTING3) & BM_CCM_CCGR104_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR104_SETTING3(x, v) (HW_CCM_CCGR104_WR(x, (HW_CCM_CCGR104_RD(x) & ~BM_CCM_CCGR104_SETTING3) | BF_CCM_CCGR104_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR105 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR105 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr105
{
    uint32_t U;
    struct _hw_ccm_ccgr105_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr105_t;

/*!
 * @name Constants and macros for entire CCM_CCGR105 register
 */
/*@{*/
#define HW_CCM_CCGR105_ADDR(x)   ((uintptr_t)(x) + 0x4690U)
#define HW_CCM_CCGR105_SET_ADDR(x) (HW_CCM_CCGR105_ADDR(x) + 0x4U)
#define HW_CCM_CCGR105_CLR_ADDR(x) (HW_CCM_CCGR105_ADDR(x) + 0x8U)
#define HW_CCM_CCGR105_TOG_ADDR(x) (HW_CCM_CCGR105_ADDR(x) + 0xCU)

#define HW_CCM_CCGR105(x)        (*(__IO hw_ccm_ccgr105_t *) HW_CCM_CCGR105_ADDR(x))
#define HW_CCM_CCGR105_RD(x)     (HW_CCM_CCGR105(x).U)
#define HW_CCM_CCGR105_WR(x, v)  (HW_CCM_CCGR105(x).U = (v))
#define HW_CCM_CCGR105_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR105_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR105_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR105_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR105_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR105_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR105 bitfields
 */

/*!
 * @name Register CCM_CCGR105, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR105_SETTING0 (0U)       /*!< Bit position for CCM_CCGR105_SETTING0. */
#define BM_CCM_CCGR105_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR105_SETTING0. */
#define BS_CCM_CCGR105_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR105_SETTING0. */

/*! @brief Read current value of the CCM_CCGR105_SETTING0 field. */
#define BR_CCM_CCGR105_SETTING0(x) (HW_CCM_CCGR105(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR105_SETTING0. */
#define BF_CCM_CCGR105_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR105_SETTING0) & BM_CCM_CCGR105_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR105_SETTING0(x, v) (HW_CCM_CCGR105_WR(x, (HW_CCM_CCGR105_RD(x) & ~BM_CCM_CCGR105_SETTING0) | BF_CCM_CCGR105_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR105, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR105_SETTING1 (4U)       /*!< Bit position for CCM_CCGR105_SETTING1. */
#define BM_CCM_CCGR105_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR105_SETTING1. */
#define BS_CCM_CCGR105_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR105_SETTING1. */

/*! @brief Read current value of the CCM_CCGR105_SETTING1 field. */
#define BR_CCM_CCGR105_SETTING1(x) (HW_CCM_CCGR105(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR105_SETTING1. */
#define BF_CCM_CCGR105_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR105_SETTING1) & BM_CCM_CCGR105_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR105_SETTING1(x, v) (HW_CCM_CCGR105_WR(x, (HW_CCM_CCGR105_RD(x) & ~BM_CCM_CCGR105_SETTING1) | BF_CCM_CCGR105_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR105, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR105_SETTING2 (8U)       /*!< Bit position for CCM_CCGR105_SETTING2. */
#define BM_CCM_CCGR105_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR105_SETTING2. */
#define BS_CCM_CCGR105_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR105_SETTING2. */

/*! @brief Read current value of the CCM_CCGR105_SETTING2 field. */
#define BR_CCM_CCGR105_SETTING2(x) (HW_CCM_CCGR105(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR105_SETTING2. */
#define BF_CCM_CCGR105_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR105_SETTING2) & BM_CCM_CCGR105_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR105_SETTING2(x, v) (HW_CCM_CCGR105_WR(x, (HW_CCM_CCGR105_RD(x) & ~BM_CCM_CCGR105_SETTING2) | BF_CCM_CCGR105_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR105, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR105_SETTING3 (12U)      /*!< Bit position for CCM_CCGR105_SETTING3. */
#define BM_CCM_CCGR105_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR105_SETTING3. */
#define BS_CCM_CCGR105_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR105_SETTING3. */

/*! @brief Read current value of the CCM_CCGR105_SETTING3 field. */
#define BR_CCM_CCGR105_SETTING3(x) (HW_CCM_CCGR105(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR105_SETTING3. */
#define BF_CCM_CCGR105_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR105_SETTING3) & BM_CCM_CCGR105_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR105_SETTING3(x, v) (HW_CCM_CCGR105_WR(x, (HW_CCM_CCGR105_RD(x) & ~BM_CCM_CCGR105_SETTING3) | BF_CCM_CCGR105_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR106 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR106 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr106
{
    uint32_t U;
    struct _hw_ccm_ccgr106_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr106_t;

/*!
 * @name Constants and macros for entire CCM_CCGR106 register
 */
/*@{*/
#define HW_CCM_CCGR106_ADDR(x)   ((uintptr_t)(x) + 0x46A0U)
#define HW_CCM_CCGR106_SET_ADDR(x) (HW_CCM_CCGR106_ADDR(x) + 0x4U)
#define HW_CCM_CCGR106_CLR_ADDR(x) (HW_CCM_CCGR106_ADDR(x) + 0x8U)
#define HW_CCM_CCGR106_TOG_ADDR(x) (HW_CCM_CCGR106_ADDR(x) + 0xCU)

#define HW_CCM_CCGR106(x)        (*(__IO hw_ccm_ccgr106_t *) HW_CCM_CCGR106_ADDR(x))
#define HW_CCM_CCGR106_RD(x)     (HW_CCM_CCGR106(x).U)
#define HW_CCM_CCGR106_WR(x, v)  (HW_CCM_CCGR106(x).U = (v))
#define HW_CCM_CCGR106_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR106_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR106_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR106_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR106_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR106_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR106 bitfields
 */

/*!
 * @name Register CCM_CCGR106, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR106_SETTING0 (0U)       /*!< Bit position for CCM_CCGR106_SETTING0. */
#define BM_CCM_CCGR106_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR106_SETTING0. */
#define BS_CCM_CCGR106_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR106_SETTING0. */

/*! @brief Read current value of the CCM_CCGR106_SETTING0 field. */
#define BR_CCM_CCGR106_SETTING0(x) (HW_CCM_CCGR106(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR106_SETTING0. */
#define BF_CCM_CCGR106_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR106_SETTING0) & BM_CCM_CCGR106_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR106_SETTING0(x, v) (HW_CCM_CCGR106_WR(x, (HW_CCM_CCGR106_RD(x) & ~BM_CCM_CCGR106_SETTING0) | BF_CCM_CCGR106_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR106, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR106_SETTING1 (4U)       /*!< Bit position for CCM_CCGR106_SETTING1. */
#define BM_CCM_CCGR106_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR106_SETTING1. */
#define BS_CCM_CCGR106_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR106_SETTING1. */

/*! @brief Read current value of the CCM_CCGR106_SETTING1 field. */
#define BR_CCM_CCGR106_SETTING1(x) (HW_CCM_CCGR106(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR106_SETTING1. */
#define BF_CCM_CCGR106_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR106_SETTING1) & BM_CCM_CCGR106_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR106_SETTING1(x, v) (HW_CCM_CCGR106_WR(x, (HW_CCM_CCGR106_RD(x) & ~BM_CCM_CCGR106_SETTING1) | BF_CCM_CCGR106_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR106, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR106_SETTING2 (8U)       /*!< Bit position for CCM_CCGR106_SETTING2. */
#define BM_CCM_CCGR106_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR106_SETTING2. */
#define BS_CCM_CCGR106_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR106_SETTING2. */

/*! @brief Read current value of the CCM_CCGR106_SETTING2 field. */
#define BR_CCM_CCGR106_SETTING2(x) (HW_CCM_CCGR106(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR106_SETTING2. */
#define BF_CCM_CCGR106_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR106_SETTING2) & BM_CCM_CCGR106_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR106_SETTING2(x, v) (HW_CCM_CCGR106_WR(x, (HW_CCM_CCGR106_RD(x) & ~BM_CCM_CCGR106_SETTING2) | BF_CCM_CCGR106_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR106, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR106_SETTING3 (12U)      /*!< Bit position for CCM_CCGR106_SETTING3. */
#define BM_CCM_CCGR106_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR106_SETTING3. */
#define BS_CCM_CCGR106_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR106_SETTING3. */

/*! @brief Read current value of the CCM_CCGR106_SETTING3 field. */
#define BR_CCM_CCGR106_SETTING3(x) (HW_CCM_CCGR106(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR106_SETTING3. */
#define BF_CCM_CCGR106_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR106_SETTING3) & BM_CCM_CCGR106_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR106_SETTING3(x, v) (HW_CCM_CCGR106_WR(x, (HW_CCM_CCGR106_RD(x) & ~BM_CCM_CCGR106_SETTING3) | BF_CCM_CCGR106_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR107 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR107 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr107
{
    uint32_t U;
    struct _hw_ccm_ccgr107_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr107_t;

/*!
 * @name Constants and macros for entire CCM_CCGR107 register
 */
/*@{*/
#define HW_CCM_CCGR107_ADDR(x)   ((uintptr_t)(x) + 0x46B0U)
#define HW_CCM_CCGR107_SET_ADDR(x) (HW_CCM_CCGR107_ADDR(x) + 0x4U)
#define HW_CCM_CCGR107_CLR_ADDR(x) (HW_CCM_CCGR107_ADDR(x) + 0x8U)
#define HW_CCM_CCGR107_TOG_ADDR(x) (HW_CCM_CCGR107_ADDR(x) + 0xCU)

#define HW_CCM_CCGR107(x)        (*(__IO hw_ccm_ccgr107_t *) HW_CCM_CCGR107_ADDR(x))
#define HW_CCM_CCGR107_RD(x)     (HW_CCM_CCGR107(x).U)
#define HW_CCM_CCGR107_WR(x, v)  (HW_CCM_CCGR107(x).U = (v))
#define HW_CCM_CCGR107_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR107_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR107_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR107_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR107_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR107_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR107 bitfields
 */

/*!
 * @name Register CCM_CCGR107, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR107_SETTING0 (0U)       /*!< Bit position for CCM_CCGR107_SETTING0. */
#define BM_CCM_CCGR107_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR107_SETTING0. */
#define BS_CCM_CCGR107_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR107_SETTING0. */

/*! @brief Read current value of the CCM_CCGR107_SETTING0 field. */
#define BR_CCM_CCGR107_SETTING0(x) (HW_CCM_CCGR107(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR107_SETTING0. */
#define BF_CCM_CCGR107_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR107_SETTING0) & BM_CCM_CCGR107_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR107_SETTING0(x, v) (HW_CCM_CCGR107_WR(x, (HW_CCM_CCGR107_RD(x) & ~BM_CCM_CCGR107_SETTING0) | BF_CCM_CCGR107_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR107, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR107_SETTING1 (4U)       /*!< Bit position for CCM_CCGR107_SETTING1. */
#define BM_CCM_CCGR107_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR107_SETTING1. */
#define BS_CCM_CCGR107_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR107_SETTING1. */

/*! @brief Read current value of the CCM_CCGR107_SETTING1 field. */
#define BR_CCM_CCGR107_SETTING1(x) (HW_CCM_CCGR107(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR107_SETTING1. */
#define BF_CCM_CCGR107_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR107_SETTING1) & BM_CCM_CCGR107_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR107_SETTING1(x, v) (HW_CCM_CCGR107_WR(x, (HW_CCM_CCGR107_RD(x) & ~BM_CCM_CCGR107_SETTING1) | BF_CCM_CCGR107_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR107, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR107_SETTING2 (8U)       /*!< Bit position for CCM_CCGR107_SETTING2. */
#define BM_CCM_CCGR107_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR107_SETTING2. */
#define BS_CCM_CCGR107_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR107_SETTING2. */

/*! @brief Read current value of the CCM_CCGR107_SETTING2 field. */
#define BR_CCM_CCGR107_SETTING2(x) (HW_CCM_CCGR107(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR107_SETTING2. */
#define BF_CCM_CCGR107_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR107_SETTING2) & BM_CCM_CCGR107_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR107_SETTING2(x, v) (HW_CCM_CCGR107_WR(x, (HW_CCM_CCGR107_RD(x) & ~BM_CCM_CCGR107_SETTING2) | BF_CCM_CCGR107_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR107, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR107_SETTING3 (12U)      /*!< Bit position for CCM_CCGR107_SETTING3. */
#define BM_CCM_CCGR107_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR107_SETTING3. */
#define BS_CCM_CCGR107_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR107_SETTING3. */

/*! @brief Read current value of the CCM_CCGR107_SETTING3 field. */
#define BR_CCM_CCGR107_SETTING3(x) (HW_CCM_CCGR107(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR107_SETTING3. */
#define BF_CCM_CCGR107_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR107_SETTING3) & BM_CCM_CCGR107_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR107_SETTING3(x, v) (HW_CCM_CCGR107_WR(x, (HW_CCM_CCGR107_RD(x) & ~BM_CCM_CCGR107_SETTING3) | BF_CCM_CCGR107_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR108 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR108 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr108
{
    uint32_t U;
    struct _hw_ccm_ccgr108_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr108_t;

/*!
 * @name Constants and macros for entire CCM_CCGR108 register
 */
/*@{*/
#define HW_CCM_CCGR108_ADDR(x)   ((uintptr_t)(x) + 0x46C0U)
#define HW_CCM_CCGR108_SET_ADDR(x) (HW_CCM_CCGR108_ADDR(x) + 0x4U)
#define HW_CCM_CCGR108_CLR_ADDR(x) (HW_CCM_CCGR108_ADDR(x) + 0x8U)
#define HW_CCM_CCGR108_TOG_ADDR(x) (HW_CCM_CCGR108_ADDR(x) + 0xCU)

#define HW_CCM_CCGR108(x)        (*(__IO hw_ccm_ccgr108_t *) HW_CCM_CCGR108_ADDR(x))
#define HW_CCM_CCGR108_RD(x)     (HW_CCM_CCGR108(x).U)
#define HW_CCM_CCGR108_WR(x, v)  (HW_CCM_CCGR108(x).U = (v))
#define HW_CCM_CCGR108_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR108_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR108_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR108_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR108_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR108_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR108 bitfields
 */

/*!
 * @name Register CCM_CCGR108, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR108_SETTING0 (0U)       /*!< Bit position for CCM_CCGR108_SETTING0. */
#define BM_CCM_CCGR108_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR108_SETTING0. */
#define BS_CCM_CCGR108_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR108_SETTING0. */

/*! @brief Read current value of the CCM_CCGR108_SETTING0 field. */
#define BR_CCM_CCGR108_SETTING0(x) (HW_CCM_CCGR108(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR108_SETTING0. */
#define BF_CCM_CCGR108_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR108_SETTING0) & BM_CCM_CCGR108_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR108_SETTING0(x, v) (HW_CCM_CCGR108_WR(x, (HW_CCM_CCGR108_RD(x) & ~BM_CCM_CCGR108_SETTING0) | BF_CCM_CCGR108_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR108, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR108_SETTING1 (4U)       /*!< Bit position for CCM_CCGR108_SETTING1. */
#define BM_CCM_CCGR108_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR108_SETTING1. */
#define BS_CCM_CCGR108_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR108_SETTING1. */

/*! @brief Read current value of the CCM_CCGR108_SETTING1 field. */
#define BR_CCM_CCGR108_SETTING1(x) (HW_CCM_CCGR108(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR108_SETTING1. */
#define BF_CCM_CCGR108_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR108_SETTING1) & BM_CCM_CCGR108_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR108_SETTING1(x, v) (HW_CCM_CCGR108_WR(x, (HW_CCM_CCGR108_RD(x) & ~BM_CCM_CCGR108_SETTING1) | BF_CCM_CCGR108_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR108, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR108_SETTING2 (8U)       /*!< Bit position for CCM_CCGR108_SETTING2. */
#define BM_CCM_CCGR108_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR108_SETTING2. */
#define BS_CCM_CCGR108_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR108_SETTING2. */

/*! @brief Read current value of the CCM_CCGR108_SETTING2 field. */
#define BR_CCM_CCGR108_SETTING2(x) (HW_CCM_CCGR108(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR108_SETTING2. */
#define BF_CCM_CCGR108_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR108_SETTING2) & BM_CCM_CCGR108_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR108_SETTING2(x, v) (HW_CCM_CCGR108_WR(x, (HW_CCM_CCGR108_RD(x) & ~BM_CCM_CCGR108_SETTING2) | BF_CCM_CCGR108_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR108, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR108_SETTING3 (12U)      /*!< Bit position for CCM_CCGR108_SETTING3. */
#define BM_CCM_CCGR108_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR108_SETTING3. */
#define BS_CCM_CCGR108_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR108_SETTING3. */

/*! @brief Read current value of the CCM_CCGR108_SETTING3 field. */
#define BR_CCM_CCGR108_SETTING3(x) (HW_CCM_CCGR108(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR108_SETTING3. */
#define BF_CCM_CCGR108_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR108_SETTING3) & BM_CCM_CCGR108_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR108_SETTING3(x, v) (HW_CCM_CCGR108_WR(x, (HW_CCM_CCGR108_RD(x) & ~BM_CCM_CCGR108_SETTING3) | BF_CCM_CCGR108_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR109 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR109 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr109
{
    uint32_t U;
    struct _hw_ccm_ccgr109_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr109_t;

/*!
 * @name Constants and macros for entire CCM_CCGR109 register
 */
/*@{*/
#define HW_CCM_CCGR109_ADDR(x)   ((uintptr_t)(x) + 0x46D0U)
#define HW_CCM_CCGR109_SET_ADDR(x) (HW_CCM_CCGR109_ADDR(x) + 0x4U)
#define HW_CCM_CCGR109_CLR_ADDR(x) (HW_CCM_CCGR109_ADDR(x) + 0x8U)
#define HW_CCM_CCGR109_TOG_ADDR(x) (HW_CCM_CCGR109_ADDR(x) + 0xCU)

#define HW_CCM_CCGR109(x)        (*(__IO hw_ccm_ccgr109_t *) HW_CCM_CCGR109_ADDR(x))
#define HW_CCM_CCGR109_RD(x)     (HW_CCM_CCGR109(x).U)
#define HW_CCM_CCGR109_WR(x, v)  (HW_CCM_CCGR109(x).U = (v))
#define HW_CCM_CCGR109_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR109_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR109_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR109_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR109_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR109_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR109 bitfields
 */

/*!
 * @name Register CCM_CCGR109, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR109_SETTING0 (0U)       /*!< Bit position for CCM_CCGR109_SETTING0. */
#define BM_CCM_CCGR109_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR109_SETTING0. */
#define BS_CCM_CCGR109_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR109_SETTING0. */

/*! @brief Read current value of the CCM_CCGR109_SETTING0 field. */
#define BR_CCM_CCGR109_SETTING0(x) (HW_CCM_CCGR109(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR109_SETTING0. */
#define BF_CCM_CCGR109_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR109_SETTING0) & BM_CCM_CCGR109_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR109_SETTING0(x, v) (HW_CCM_CCGR109_WR(x, (HW_CCM_CCGR109_RD(x) & ~BM_CCM_CCGR109_SETTING0) | BF_CCM_CCGR109_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR109, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR109_SETTING1 (4U)       /*!< Bit position for CCM_CCGR109_SETTING1. */
#define BM_CCM_CCGR109_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR109_SETTING1. */
#define BS_CCM_CCGR109_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR109_SETTING1. */

/*! @brief Read current value of the CCM_CCGR109_SETTING1 field. */
#define BR_CCM_CCGR109_SETTING1(x) (HW_CCM_CCGR109(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR109_SETTING1. */
#define BF_CCM_CCGR109_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR109_SETTING1) & BM_CCM_CCGR109_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR109_SETTING1(x, v) (HW_CCM_CCGR109_WR(x, (HW_CCM_CCGR109_RD(x) & ~BM_CCM_CCGR109_SETTING1) | BF_CCM_CCGR109_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR109, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR109_SETTING2 (8U)       /*!< Bit position for CCM_CCGR109_SETTING2. */
#define BM_CCM_CCGR109_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR109_SETTING2. */
#define BS_CCM_CCGR109_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR109_SETTING2. */

/*! @brief Read current value of the CCM_CCGR109_SETTING2 field. */
#define BR_CCM_CCGR109_SETTING2(x) (HW_CCM_CCGR109(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR109_SETTING2. */
#define BF_CCM_CCGR109_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR109_SETTING2) & BM_CCM_CCGR109_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR109_SETTING2(x, v) (HW_CCM_CCGR109_WR(x, (HW_CCM_CCGR109_RD(x) & ~BM_CCM_CCGR109_SETTING2) | BF_CCM_CCGR109_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR109, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR109_SETTING3 (12U)      /*!< Bit position for CCM_CCGR109_SETTING3. */
#define BM_CCM_CCGR109_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR109_SETTING3. */
#define BS_CCM_CCGR109_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR109_SETTING3. */

/*! @brief Read current value of the CCM_CCGR109_SETTING3 field. */
#define BR_CCM_CCGR109_SETTING3(x) (HW_CCM_CCGR109(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR109_SETTING3. */
#define BF_CCM_CCGR109_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR109_SETTING3) & BM_CCM_CCGR109_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR109_SETTING3(x, v) (HW_CCM_CCGR109_WR(x, (HW_CCM_CCGR109_RD(x) & ~BM_CCM_CCGR109_SETTING3) | BF_CCM_CCGR109_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR110 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR110 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr110
{
    uint32_t U;
    struct _hw_ccm_ccgr110_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr110_t;

/*!
 * @name Constants and macros for entire CCM_CCGR110 register
 */
/*@{*/
#define HW_CCM_CCGR110_ADDR(x)   ((uintptr_t)(x) + 0x46E0U)
#define HW_CCM_CCGR110_SET_ADDR(x) (HW_CCM_CCGR110_ADDR(x) + 0x4U)
#define HW_CCM_CCGR110_CLR_ADDR(x) (HW_CCM_CCGR110_ADDR(x) + 0x8U)
#define HW_CCM_CCGR110_TOG_ADDR(x) (HW_CCM_CCGR110_ADDR(x) + 0xCU)

#define HW_CCM_CCGR110(x)        (*(__IO hw_ccm_ccgr110_t *) HW_CCM_CCGR110_ADDR(x))
#define HW_CCM_CCGR110_RD(x)     (HW_CCM_CCGR110(x).U)
#define HW_CCM_CCGR110_WR(x, v)  (HW_CCM_CCGR110(x).U = (v))
#define HW_CCM_CCGR110_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR110_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR110_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR110_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR110_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR110_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR110 bitfields
 */

/*!
 * @name Register CCM_CCGR110, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR110_SETTING0 (0U)       /*!< Bit position for CCM_CCGR110_SETTING0. */
#define BM_CCM_CCGR110_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR110_SETTING0. */
#define BS_CCM_CCGR110_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR110_SETTING0. */

/*! @brief Read current value of the CCM_CCGR110_SETTING0 field. */
#define BR_CCM_CCGR110_SETTING0(x) (HW_CCM_CCGR110(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR110_SETTING0. */
#define BF_CCM_CCGR110_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR110_SETTING0) & BM_CCM_CCGR110_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR110_SETTING0(x, v) (HW_CCM_CCGR110_WR(x, (HW_CCM_CCGR110_RD(x) & ~BM_CCM_CCGR110_SETTING0) | BF_CCM_CCGR110_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR110, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR110_SETTING1 (4U)       /*!< Bit position for CCM_CCGR110_SETTING1. */
#define BM_CCM_CCGR110_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR110_SETTING1. */
#define BS_CCM_CCGR110_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR110_SETTING1. */

/*! @brief Read current value of the CCM_CCGR110_SETTING1 field. */
#define BR_CCM_CCGR110_SETTING1(x) (HW_CCM_CCGR110(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR110_SETTING1. */
#define BF_CCM_CCGR110_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR110_SETTING1) & BM_CCM_CCGR110_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR110_SETTING1(x, v) (HW_CCM_CCGR110_WR(x, (HW_CCM_CCGR110_RD(x) & ~BM_CCM_CCGR110_SETTING1) | BF_CCM_CCGR110_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR110, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR110_SETTING2 (8U)       /*!< Bit position for CCM_CCGR110_SETTING2. */
#define BM_CCM_CCGR110_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR110_SETTING2. */
#define BS_CCM_CCGR110_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR110_SETTING2. */

/*! @brief Read current value of the CCM_CCGR110_SETTING2 field. */
#define BR_CCM_CCGR110_SETTING2(x) (HW_CCM_CCGR110(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR110_SETTING2. */
#define BF_CCM_CCGR110_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR110_SETTING2) & BM_CCM_CCGR110_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR110_SETTING2(x, v) (HW_CCM_CCGR110_WR(x, (HW_CCM_CCGR110_RD(x) & ~BM_CCM_CCGR110_SETTING2) | BF_CCM_CCGR110_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR110, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR110_SETTING3 (12U)      /*!< Bit position for CCM_CCGR110_SETTING3. */
#define BM_CCM_CCGR110_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR110_SETTING3. */
#define BS_CCM_CCGR110_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR110_SETTING3. */

/*! @brief Read current value of the CCM_CCGR110_SETTING3 field. */
#define BR_CCM_CCGR110_SETTING3(x) (HW_CCM_CCGR110(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR110_SETTING3. */
#define BF_CCM_CCGR110_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR110_SETTING3) & BM_CCM_CCGR110_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR110_SETTING3(x, v) (HW_CCM_CCGR110_WR(x, (HW_CCM_CCGR110_RD(x) & ~BM_CCM_CCGR110_SETTING3) | BF_CCM_CCGR110_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR111 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR111 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr111
{
    uint32_t U;
    struct _hw_ccm_ccgr111_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr111_t;

/*!
 * @name Constants and macros for entire CCM_CCGR111 register
 */
/*@{*/
#define HW_CCM_CCGR111_ADDR(x)   ((uintptr_t)(x) + 0x46F0U)
#define HW_CCM_CCGR111_SET_ADDR(x) (HW_CCM_CCGR111_ADDR(x) + 0x4U)
#define HW_CCM_CCGR111_CLR_ADDR(x) (HW_CCM_CCGR111_ADDR(x) + 0x8U)
#define HW_CCM_CCGR111_TOG_ADDR(x) (HW_CCM_CCGR111_ADDR(x) + 0xCU)

#define HW_CCM_CCGR111(x)        (*(__IO hw_ccm_ccgr111_t *) HW_CCM_CCGR111_ADDR(x))
#define HW_CCM_CCGR111_RD(x)     (HW_CCM_CCGR111(x).U)
#define HW_CCM_CCGR111_WR(x, v)  (HW_CCM_CCGR111(x).U = (v))
#define HW_CCM_CCGR111_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR111_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR111_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR111_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR111_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR111_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR111 bitfields
 */

/*!
 * @name Register CCM_CCGR111, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR111_SETTING0 (0U)       /*!< Bit position for CCM_CCGR111_SETTING0. */
#define BM_CCM_CCGR111_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR111_SETTING0. */
#define BS_CCM_CCGR111_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR111_SETTING0. */

/*! @brief Read current value of the CCM_CCGR111_SETTING0 field. */
#define BR_CCM_CCGR111_SETTING0(x) (HW_CCM_CCGR111(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR111_SETTING0. */
#define BF_CCM_CCGR111_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR111_SETTING0) & BM_CCM_CCGR111_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR111_SETTING0(x, v) (HW_CCM_CCGR111_WR(x, (HW_CCM_CCGR111_RD(x) & ~BM_CCM_CCGR111_SETTING0) | BF_CCM_CCGR111_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR111, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR111_SETTING1 (4U)       /*!< Bit position for CCM_CCGR111_SETTING1. */
#define BM_CCM_CCGR111_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR111_SETTING1. */
#define BS_CCM_CCGR111_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR111_SETTING1. */

/*! @brief Read current value of the CCM_CCGR111_SETTING1 field. */
#define BR_CCM_CCGR111_SETTING1(x) (HW_CCM_CCGR111(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR111_SETTING1. */
#define BF_CCM_CCGR111_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR111_SETTING1) & BM_CCM_CCGR111_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR111_SETTING1(x, v) (HW_CCM_CCGR111_WR(x, (HW_CCM_CCGR111_RD(x) & ~BM_CCM_CCGR111_SETTING1) | BF_CCM_CCGR111_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR111, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR111_SETTING2 (8U)       /*!< Bit position for CCM_CCGR111_SETTING2. */
#define BM_CCM_CCGR111_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR111_SETTING2. */
#define BS_CCM_CCGR111_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR111_SETTING2. */

/*! @brief Read current value of the CCM_CCGR111_SETTING2 field. */
#define BR_CCM_CCGR111_SETTING2(x) (HW_CCM_CCGR111(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR111_SETTING2. */
#define BF_CCM_CCGR111_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR111_SETTING2) & BM_CCM_CCGR111_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR111_SETTING2(x, v) (HW_CCM_CCGR111_WR(x, (HW_CCM_CCGR111_RD(x) & ~BM_CCM_CCGR111_SETTING2) | BF_CCM_CCGR111_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR111, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR111_SETTING3 (12U)      /*!< Bit position for CCM_CCGR111_SETTING3. */
#define BM_CCM_CCGR111_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR111_SETTING3. */
#define BS_CCM_CCGR111_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR111_SETTING3. */

/*! @brief Read current value of the CCM_CCGR111_SETTING3 field. */
#define BR_CCM_CCGR111_SETTING3(x) (HW_CCM_CCGR111(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR111_SETTING3. */
#define BF_CCM_CCGR111_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR111_SETTING3) & BM_CCM_CCGR111_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR111_SETTING3(x, v) (HW_CCM_CCGR111_WR(x, (HW_CCM_CCGR111_RD(x) & ~BM_CCM_CCGR111_SETTING3) | BF_CCM_CCGR111_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR112 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR112 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr112
{
    uint32_t U;
    struct _hw_ccm_ccgr112_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr112_t;

/*!
 * @name Constants and macros for entire CCM_CCGR112 register
 */
/*@{*/
#define HW_CCM_CCGR112_ADDR(x)   ((uintptr_t)(x) + 0x4700U)
#define HW_CCM_CCGR112_SET_ADDR(x) (HW_CCM_CCGR112_ADDR(x) + 0x4U)
#define HW_CCM_CCGR112_CLR_ADDR(x) (HW_CCM_CCGR112_ADDR(x) + 0x8U)
#define HW_CCM_CCGR112_TOG_ADDR(x) (HW_CCM_CCGR112_ADDR(x) + 0xCU)

#define HW_CCM_CCGR112(x)        (*(__IO hw_ccm_ccgr112_t *) HW_CCM_CCGR112_ADDR(x))
#define HW_CCM_CCGR112_RD(x)     (HW_CCM_CCGR112(x).U)
#define HW_CCM_CCGR112_WR(x, v)  (HW_CCM_CCGR112(x).U = (v))
#define HW_CCM_CCGR112_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR112_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR112_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR112_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR112_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR112_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR112 bitfields
 */

/*!
 * @name Register CCM_CCGR112, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR112_SETTING0 (0U)       /*!< Bit position for CCM_CCGR112_SETTING0. */
#define BM_CCM_CCGR112_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR112_SETTING0. */
#define BS_CCM_CCGR112_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR112_SETTING0. */

/*! @brief Read current value of the CCM_CCGR112_SETTING0 field. */
#define BR_CCM_CCGR112_SETTING0(x) (HW_CCM_CCGR112(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR112_SETTING0. */
#define BF_CCM_CCGR112_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR112_SETTING0) & BM_CCM_CCGR112_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR112_SETTING0(x, v) (HW_CCM_CCGR112_WR(x, (HW_CCM_CCGR112_RD(x) & ~BM_CCM_CCGR112_SETTING0) | BF_CCM_CCGR112_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR112, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR112_SETTING1 (4U)       /*!< Bit position for CCM_CCGR112_SETTING1. */
#define BM_CCM_CCGR112_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR112_SETTING1. */
#define BS_CCM_CCGR112_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR112_SETTING1. */

/*! @brief Read current value of the CCM_CCGR112_SETTING1 field. */
#define BR_CCM_CCGR112_SETTING1(x) (HW_CCM_CCGR112(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR112_SETTING1. */
#define BF_CCM_CCGR112_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR112_SETTING1) & BM_CCM_CCGR112_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR112_SETTING1(x, v) (HW_CCM_CCGR112_WR(x, (HW_CCM_CCGR112_RD(x) & ~BM_CCM_CCGR112_SETTING1) | BF_CCM_CCGR112_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR112, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR112_SETTING2 (8U)       /*!< Bit position for CCM_CCGR112_SETTING2. */
#define BM_CCM_CCGR112_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR112_SETTING2. */
#define BS_CCM_CCGR112_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR112_SETTING2. */

/*! @brief Read current value of the CCM_CCGR112_SETTING2 field. */
#define BR_CCM_CCGR112_SETTING2(x) (HW_CCM_CCGR112(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR112_SETTING2. */
#define BF_CCM_CCGR112_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR112_SETTING2) & BM_CCM_CCGR112_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR112_SETTING2(x, v) (HW_CCM_CCGR112_WR(x, (HW_CCM_CCGR112_RD(x) & ~BM_CCM_CCGR112_SETTING2) | BF_CCM_CCGR112_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR112, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR112_SETTING3 (12U)      /*!< Bit position for CCM_CCGR112_SETTING3. */
#define BM_CCM_CCGR112_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR112_SETTING3. */
#define BS_CCM_CCGR112_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR112_SETTING3. */

/*! @brief Read current value of the CCM_CCGR112_SETTING3 field. */
#define BR_CCM_CCGR112_SETTING3(x) (HW_CCM_CCGR112(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR112_SETTING3. */
#define BF_CCM_CCGR112_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR112_SETTING3) & BM_CCM_CCGR112_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR112_SETTING3(x, v) (HW_CCM_CCGR112_WR(x, (HW_CCM_CCGR112_RD(x) & ~BM_CCM_CCGR112_SETTING3) | BF_CCM_CCGR112_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR113 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR113 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr113
{
    uint32_t U;
    struct _hw_ccm_ccgr113_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr113_t;

/*!
 * @name Constants and macros for entire CCM_CCGR113 register
 */
/*@{*/
#define HW_CCM_CCGR113_ADDR(x)   ((uintptr_t)(x) + 0x4710U)
#define HW_CCM_CCGR113_SET_ADDR(x) (HW_CCM_CCGR113_ADDR(x) + 0x4U)
#define HW_CCM_CCGR113_CLR_ADDR(x) (HW_CCM_CCGR113_ADDR(x) + 0x8U)
#define HW_CCM_CCGR113_TOG_ADDR(x) (HW_CCM_CCGR113_ADDR(x) + 0xCU)

#define HW_CCM_CCGR113(x)        (*(__IO hw_ccm_ccgr113_t *) HW_CCM_CCGR113_ADDR(x))
#define HW_CCM_CCGR113_RD(x)     (HW_CCM_CCGR113(x).U)
#define HW_CCM_CCGR113_WR(x, v)  (HW_CCM_CCGR113(x).U = (v))
#define HW_CCM_CCGR113_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR113_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR113_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR113_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR113_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR113_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR113 bitfields
 */

/*!
 * @name Register CCM_CCGR113, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR113_SETTING0 (0U)       /*!< Bit position for CCM_CCGR113_SETTING0. */
#define BM_CCM_CCGR113_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR113_SETTING0. */
#define BS_CCM_CCGR113_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR113_SETTING0. */

/*! @brief Read current value of the CCM_CCGR113_SETTING0 field. */
#define BR_CCM_CCGR113_SETTING0(x) (HW_CCM_CCGR113(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR113_SETTING0. */
#define BF_CCM_CCGR113_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR113_SETTING0) & BM_CCM_CCGR113_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR113_SETTING0(x, v) (HW_CCM_CCGR113_WR(x, (HW_CCM_CCGR113_RD(x) & ~BM_CCM_CCGR113_SETTING0) | BF_CCM_CCGR113_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR113, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR113_SETTING1 (4U)       /*!< Bit position for CCM_CCGR113_SETTING1. */
#define BM_CCM_CCGR113_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR113_SETTING1. */
#define BS_CCM_CCGR113_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR113_SETTING1. */

/*! @brief Read current value of the CCM_CCGR113_SETTING1 field. */
#define BR_CCM_CCGR113_SETTING1(x) (HW_CCM_CCGR113(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR113_SETTING1. */
#define BF_CCM_CCGR113_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR113_SETTING1) & BM_CCM_CCGR113_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR113_SETTING1(x, v) (HW_CCM_CCGR113_WR(x, (HW_CCM_CCGR113_RD(x) & ~BM_CCM_CCGR113_SETTING1) | BF_CCM_CCGR113_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR113, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR113_SETTING2 (8U)       /*!< Bit position for CCM_CCGR113_SETTING2. */
#define BM_CCM_CCGR113_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR113_SETTING2. */
#define BS_CCM_CCGR113_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR113_SETTING2. */

/*! @brief Read current value of the CCM_CCGR113_SETTING2 field. */
#define BR_CCM_CCGR113_SETTING2(x) (HW_CCM_CCGR113(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR113_SETTING2. */
#define BF_CCM_CCGR113_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR113_SETTING2) & BM_CCM_CCGR113_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR113_SETTING2(x, v) (HW_CCM_CCGR113_WR(x, (HW_CCM_CCGR113_RD(x) & ~BM_CCM_CCGR113_SETTING2) | BF_CCM_CCGR113_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR113, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR113_SETTING3 (12U)      /*!< Bit position for CCM_CCGR113_SETTING3. */
#define BM_CCM_CCGR113_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR113_SETTING3. */
#define BS_CCM_CCGR113_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR113_SETTING3. */

/*! @brief Read current value of the CCM_CCGR113_SETTING3 field. */
#define BR_CCM_CCGR113_SETTING3(x) (HW_CCM_CCGR113(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR113_SETTING3. */
#define BF_CCM_CCGR113_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR113_SETTING3) & BM_CCM_CCGR113_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR113_SETTING3(x, v) (HW_CCM_CCGR113_WR(x, (HW_CCM_CCGR113_RD(x) & ~BM_CCM_CCGR113_SETTING3) | BF_CCM_CCGR113_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR114 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR114 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr114
{
    uint32_t U;
    struct _hw_ccm_ccgr114_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr114_t;

/*!
 * @name Constants and macros for entire CCM_CCGR114 register
 */
/*@{*/
#define HW_CCM_CCGR114_ADDR(x)   ((uintptr_t)(x) + 0x4720U)
#define HW_CCM_CCGR114_SET_ADDR(x) (HW_CCM_CCGR114_ADDR(x) + 0x4U)
#define HW_CCM_CCGR114_CLR_ADDR(x) (HW_CCM_CCGR114_ADDR(x) + 0x8U)
#define HW_CCM_CCGR114_TOG_ADDR(x) (HW_CCM_CCGR114_ADDR(x) + 0xCU)

#define HW_CCM_CCGR114(x)        (*(__IO hw_ccm_ccgr114_t *) HW_CCM_CCGR114_ADDR(x))
#define HW_CCM_CCGR114_RD(x)     (HW_CCM_CCGR114(x).U)
#define HW_CCM_CCGR114_WR(x, v)  (HW_CCM_CCGR114(x).U = (v))
#define HW_CCM_CCGR114_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR114_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR114_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR114_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR114_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR114_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR114 bitfields
 */

/*!
 * @name Register CCM_CCGR114, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR114_SETTING0 (0U)       /*!< Bit position for CCM_CCGR114_SETTING0. */
#define BM_CCM_CCGR114_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR114_SETTING0. */
#define BS_CCM_CCGR114_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR114_SETTING0. */

/*! @brief Read current value of the CCM_CCGR114_SETTING0 field. */
#define BR_CCM_CCGR114_SETTING0(x) (HW_CCM_CCGR114(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR114_SETTING0. */
#define BF_CCM_CCGR114_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR114_SETTING0) & BM_CCM_CCGR114_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR114_SETTING0(x, v) (HW_CCM_CCGR114_WR(x, (HW_CCM_CCGR114_RD(x) & ~BM_CCM_CCGR114_SETTING0) | BF_CCM_CCGR114_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR114, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR114_SETTING1 (4U)       /*!< Bit position for CCM_CCGR114_SETTING1. */
#define BM_CCM_CCGR114_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR114_SETTING1. */
#define BS_CCM_CCGR114_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR114_SETTING1. */

/*! @brief Read current value of the CCM_CCGR114_SETTING1 field. */
#define BR_CCM_CCGR114_SETTING1(x) (HW_CCM_CCGR114(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR114_SETTING1. */
#define BF_CCM_CCGR114_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR114_SETTING1) & BM_CCM_CCGR114_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR114_SETTING1(x, v) (HW_CCM_CCGR114_WR(x, (HW_CCM_CCGR114_RD(x) & ~BM_CCM_CCGR114_SETTING1) | BF_CCM_CCGR114_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR114, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR114_SETTING2 (8U)       /*!< Bit position for CCM_CCGR114_SETTING2. */
#define BM_CCM_CCGR114_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR114_SETTING2. */
#define BS_CCM_CCGR114_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR114_SETTING2. */

/*! @brief Read current value of the CCM_CCGR114_SETTING2 field. */
#define BR_CCM_CCGR114_SETTING2(x) (HW_CCM_CCGR114(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR114_SETTING2. */
#define BF_CCM_CCGR114_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR114_SETTING2) & BM_CCM_CCGR114_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR114_SETTING2(x, v) (HW_CCM_CCGR114_WR(x, (HW_CCM_CCGR114_RD(x) & ~BM_CCM_CCGR114_SETTING2) | BF_CCM_CCGR114_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR114, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR114_SETTING3 (12U)      /*!< Bit position for CCM_CCGR114_SETTING3. */
#define BM_CCM_CCGR114_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR114_SETTING3. */
#define BS_CCM_CCGR114_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR114_SETTING3. */

/*! @brief Read current value of the CCM_CCGR114_SETTING3 field. */
#define BR_CCM_CCGR114_SETTING3(x) (HW_CCM_CCGR114(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR114_SETTING3. */
#define BF_CCM_CCGR114_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR114_SETTING3) & BM_CCM_CCGR114_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR114_SETTING3(x, v) (HW_CCM_CCGR114_WR(x, (HW_CCM_CCGR114_RD(x) & ~BM_CCM_CCGR114_SETTING3) | BF_CCM_CCGR114_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR115 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR115 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr115
{
    uint32_t U;
    struct _hw_ccm_ccgr115_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr115_t;

/*!
 * @name Constants and macros for entire CCM_CCGR115 register
 */
/*@{*/
#define HW_CCM_CCGR115_ADDR(x)   ((uintptr_t)(x) + 0x4730U)
#define HW_CCM_CCGR115_SET_ADDR(x) (HW_CCM_CCGR115_ADDR(x) + 0x4U)
#define HW_CCM_CCGR115_CLR_ADDR(x) (HW_CCM_CCGR115_ADDR(x) + 0x8U)
#define HW_CCM_CCGR115_TOG_ADDR(x) (HW_CCM_CCGR115_ADDR(x) + 0xCU)

#define HW_CCM_CCGR115(x)        (*(__IO hw_ccm_ccgr115_t *) HW_CCM_CCGR115_ADDR(x))
#define HW_CCM_CCGR115_RD(x)     (HW_CCM_CCGR115(x).U)
#define HW_CCM_CCGR115_WR(x, v)  (HW_CCM_CCGR115(x).U = (v))
#define HW_CCM_CCGR115_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR115_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR115_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR115_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR115_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR115_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR115 bitfields
 */

/*!
 * @name Register CCM_CCGR115, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR115_SETTING0 (0U)       /*!< Bit position for CCM_CCGR115_SETTING0. */
#define BM_CCM_CCGR115_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR115_SETTING0. */
#define BS_CCM_CCGR115_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR115_SETTING0. */

/*! @brief Read current value of the CCM_CCGR115_SETTING0 field. */
#define BR_CCM_CCGR115_SETTING0(x) (HW_CCM_CCGR115(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR115_SETTING0. */
#define BF_CCM_CCGR115_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR115_SETTING0) & BM_CCM_CCGR115_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR115_SETTING0(x, v) (HW_CCM_CCGR115_WR(x, (HW_CCM_CCGR115_RD(x) & ~BM_CCM_CCGR115_SETTING0) | BF_CCM_CCGR115_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR115, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR115_SETTING1 (4U)       /*!< Bit position for CCM_CCGR115_SETTING1. */
#define BM_CCM_CCGR115_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR115_SETTING1. */
#define BS_CCM_CCGR115_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR115_SETTING1. */

/*! @brief Read current value of the CCM_CCGR115_SETTING1 field. */
#define BR_CCM_CCGR115_SETTING1(x) (HW_CCM_CCGR115(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR115_SETTING1. */
#define BF_CCM_CCGR115_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR115_SETTING1) & BM_CCM_CCGR115_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR115_SETTING1(x, v) (HW_CCM_CCGR115_WR(x, (HW_CCM_CCGR115_RD(x) & ~BM_CCM_CCGR115_SETTING1) | BF_CCM_CCGR115_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR115, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR115_SETTING2 (8U)       /*!< Bit position for CCM_CCGR115_SETTING2. */
#define BM_CCM_CCGR115_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR115_SETTING2. */
#define BS_CCM_CCGR115_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR115_SETTING2. */

/*! @brief Read current value of the CCM_CCGR115_SETTING2 field. */
#define BR_CCM_CCGR115_SETTING2(x) (HW_CCM_CCGR115(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR115_SETTING2. */
#define BF_CCM_CCGR115_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR115_SETTING2) & BM_CCM_CCGR115_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR115_SETTING2(x, v) (HW_CCM_CCGR115_WR(x, (HW_CCM_CCGR115_RD(x) & ~BM_CCM_CCGR115_SETTING2) | BF_CCM_CCGR115_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR115, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR115_SETTING3 (12U)      /*!< Bit position for CCM_CCGR115_SETTING3. */
#define BM_CCM_CCGR115_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR115_SETTING3. */
#define BS_CCM_CCGR115_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR115_SETTING3. */

/*! @brief Read current value of the CCM_CCGR115_SETTING3 field. */
#define BR_CCM_CCGR115_SETTING3(x) (HW_CCM_CCGR115(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR115_SETTING3. */
#define BF_CCM_CCGR115_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR115_SETTING3) & BM_CCM_CCGR115_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR115_SETTING3(x, v) (HW_CCM_CCGR115_WR(x, (HW_CCM_CCGR115_RD(x) & ~BM_CCM_CCGR115_SETTING3) | BF_CCM_CCGR115_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR116 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR116 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr116
{
    uint32_t U;
    struct _hw_ccm_ccgr116_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr116_t;

/*!
 * @name Constants and macros for entire CCM_CCGR116 register
 */
/*@{*/
#define HW_CCM_CCGR116_ADDR(x)   ((uintptr_t)(x) + 0x4740U)
#define HW_CCM_CCGR116_SET_ADDR(x) (HW_CCM_CCGR116_ADDR(x) + 0x4U)
#define HW_CCM_CCGR116_CLR_ADDR(x) (HW_CCM_CCGR116_ADDR(x) + 0x8U)
#define HW_CCM_CCGR116_TOG_ADDR(x) (HW_CCM_CCGR116_ADDR(x) + 0xCU)

#define HW_CCM_CCGR116(x)        (*(__IO hw_ccm_ccgr116_t *) HW_CCM_CCGR116_ADDR(x))
#define HW_CCM_CCGR116_RD(x)     (HW_CCM_CCGR116(x).U)
#define HW_CCM_CCGR116_WR(x, v)  (HW_CCM_CCGR116(x).U = (v))
#define HW_CCM_CCGR116_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR116_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR116_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR116_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR116_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR116_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR116 bitfields
 */

/*!
 * @name Register CCM_CCGR116, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR116_SETTING0 (0U)       /*!< Bit position for CCM_CCGR116_SETTING0. */
#define BM_CCM_CCGR116_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR116_SETTING0. */
#define BS_CCM_CCGR116_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR116_SETTING0. */

/*! @brief Read current value of the CCM_CCGR116_SETTING0 field. */
#define BR_CCM_CCGR116_SETTING0(x) (HW_CCM_CCGR116(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR116_SETTING0. */
#define BF_CCM_CCGR116_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR116_SETTING0) & BM_CCM_CCGR116_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR116_SETTING0(x, v) (HW_CCM_CCGR116_WR(x, (HW_CCM_CCGR116_RD(x) & ~BM_CCM_CCGR116_SETTING0) | BF_CCM_CCGR116_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR116, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR116_SETTING1 (4U)       /*!< Bit position for CCM_CCGR116_SETTING1. */
#define BM_CCM_CCGR116_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR116_SETTING1. */
#define BS_CCM_CCGR116_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR116_SETTING1. */

/*! @brief Read current value of the CCM_CCGR116_SETTING1 field. */
#define BR_CCM_CCGR116_SETTING1(x) (HW_CCM_CCGR116(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR116_SETTING1. */
#define BF_CCM_CCGR116_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR116_SETTING1) & BM_CCM_CCGR116_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR116_SETTING1(x, v) (HW_CCM_CCGR116_WR(x, (HW_CCM_CCGR116_RD(x) & ~BM_CCM_CCGR116_SETTING1) | BF_CCM_CCGR116_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR116, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR116_SETTING2 (8U)       /*!< Bit position for CCM_CCGR116_SETTING2. */
#define BM_CCM_CCGR116_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR116_SETTING2. */
#define BS_CCM_CCGR116_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR116_SETTING2. */

/*! @brief Read current value of the CCM_CCGR116_SETTING2 field. */
#define BR_CCM_CCGR116_SETTING2(x) (HW_CCM_CCGR116(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR116_SETTING2. */
#define BF_CCM_CCGR116_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR116_SETTING2) & BM_CCM_CCGR116_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR116_SETTING2(x, v) (HW_CCM_CCGR116_WR(x, (HW_CCM_CCGR116_RD(x) & ~BM_CCM_CCGR116_SETTING2) | BF_CCM_CCGR116_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR116, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR116_SETTING3 (12U)      /*!< Bit position for CCM_CCGR116_SETTING3. */
#define BM_CCM_CCGR116_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR116_SETTING3. */
#define BS_CCM_CCGR116_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR116_SETTING3. */

/*! @brief Read current value of the CCM_CCGR116_SETTING3 field. */
#define BR_CCM_CCGR116_SETTING3(x) (HW_CCM_CCGR116(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR116_SETTING3. */
#define BF_CCM_CCGR116_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR116_SETTING3) & BM_CCM_CCGR116_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR116_SETTING3(x, v) (HW_CCM_CCGR116_WR(x, (HW_CCM_CCGR116_RD(x) & ~BM_CCM_CCGR116_SETTING3) | BF_CCM_CCGR116_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR117 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR117 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr117
{
    uint32_t U;
    struct _hw_ccm_ccgr117_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr117_t;

/*!
 * @name Constants and macros for entire CCM_CCGR117 register
 */
/*@{*/
#define HW_CCM_CCGR117_ADDR(x)   ((uintptr_t)(x) + 0x4750U)
#define HW_CCM_CCGR117_SET_ADDR(x) (HW_CCM_CCGR117_ADDR(x) + 0x4U)
#define HW_CCM_CCGR117_CLR_ADDR(x) (HW_CCM_CCGR117_ADDR(x) + 0x8U)
#define HW_CCM_CCGR117_TOG_ADDR(x) (HW_CCM_CCGR117_ADDR(x) + 0xCU)

#define HW_CCM_CCGR117(x)        (*(__IO hw_ccm_ccgr117_t *) HW_CCM_CCGR117_ADDR(x))
#define HW_CCM_CCGR117_RD(x)     (HW_CCM_CCGR117(x).U)
#define HW_CCM_CCGR117_WR(x, v)  (HW_CCM_CCGR117(x).U = (v))
#define HW_CCM_CCGR117_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR117_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR117_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR117_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR117_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR117_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR117 bitfields
 */

/*!
 * @name Register CCM_CCGR117, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR117_SETTING0 (0U)       /*!< Bit position for CCM_CCGR117_SETTING0. */
#define BM_CCM_CCGR117_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR117_SETTING0. */
#define BS_CCM_CCGR117_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR117_SETTING0. */

/*! @brief Read current value of the CCM_CCGR117_SETTING0 field. */
#define BR_CCM_CCGR117_SETTING0(x) (HW_CCM_CCGR117(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR117_SETTING0. */
#define BF_CCM_CCGR117_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR117_SETTING0) & BM_CCM_CCGR117_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR117_SETTING0(x, v) (HW_CCM_CCGR117_WR(x, (HW_CCM_CCGR117_RD(x) & ~BM_CCM_CCGR117_SETTING0) | BF_CCM_CCGR117_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR117, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR117_SETTING1 (4U)       /*!< Bit position for CCM_CCGR117_SETTING1. */
#define BM_CCM_CCGR117_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR117_SETTING1. */
#define BS_CCM_CCGR117_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR117_SETTING1. */

/*! @brief Read current value of the CCM_CCGR117_SETTING1 field. */
#define BR_CCM_CCGR117_SETTING1(x) (HW_CCM_CCGR117(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR117_SETTING1. */
#define BF_CCM_CCGR117_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR117_SETTING1) & BM_CCM_CCGR117_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR117_SETTING1(x, v) (HW_CCM_CCGR117_WR(x, (HW_CCM_CCGR117_RD(x) & ~BM_CCM_CCGR117_SETTING1) | BF_CCM_CCGR117_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR117, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR117_SETTING2 (8U)       /*!< Bit position for CCM_CCGR117_SETTING2. */
#define BM_CCM_CCGR117_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR117_SETTING2. */
#define BS_CCM_CCGR117_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR117_SETTING2. */

/*! @brief Read current value of the CCM_CCGR117_SETTING2 field. */
#define BR_CCM_CCGR117_SETTING2(x) (HW_CCM_CCGR117(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR117_SETTING2. */
#define BF_CCM_CCGR117_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR117_SETTING2) & BM_CCM_CCGR117_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR117_SETTING2(x, v) (HW_CCM_CCGR117_WR(x, (HW_CCM_CCGR117_RD(x) & ~BM_CCM_CCGR117_SETTING2) | BF_CCM_CCGR117_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR117, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR117_SETTING3 (12U)      /*!< Bit position for CCM_CCGR117_SETTING3. */
#define BM_CCM_CCGR117_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR117_SETTING3. */
#define BS_CCM_CCGR117_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR117_SETTING3. */

/*! @brief Read current value of the CCM_CCGR117_SETTING3 field. */
#define BR_CCM_CCGR117_SETTING3(x) (HW_CCM_CCGR117(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR117_SETTING3. */
#define BF_CCM_CCGR117_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR117_SETTING3) & BM_CCM_CCGR117_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR117_SETTING3(x, v) (HW_CCM_CCGR117_WR(x, (HW_CCM_CCGR117_RD(x) & ~BM_CCM_CCGR117_SETTING3) | BF_CCM_CCGR117_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR118 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR118 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr118
{
    uint32_t U;
    struct _hw_ccm_ccgr118_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr118_t;

/*!
 * @name Constants and macros for entire CCM_CCGR118 register
 */
/*@{*/
#define HW_CCM_CCGR118_ADDR(x)   ((uintptr_t)(x) + 0x4760U)
#define HW_CCM_CCGR118_SET_ADDR(x) (HW_CCM_CCGR118_ADDR(x) + 0x4U)
#define HW_CCM_CCGR118_CLR_ADDR(x) (HW_CCM_CCGR118_ADDR(x) + 0x8U)
#define HW_CCM_CCGR118_TOG_ADDR(x) (HW_CCM_CCGR118_ADDR(x) + 0xCU)

#define HW_CCM_CCGR118(x)        (*(__IO hw_ccm_ccgr118_t *) HW_CCM_CCGR118_ADDR(x))
#define HW_CCM_CCGR118_RD(x)     (HW_CCM_CCGR118(x).U)
#define HW_CCM_CCGR118_WR(x, v)  (HW_CCM_CCGR118(x).U = (v))
#define HW_CCM_CCGR118_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR118_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR118_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR118_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR118_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR118_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR118 bitfields
 */

/*!
 * @name Register CCM_CCGR118, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR118_SETTING0 (0U)       /*!< Bit position for CCM_CCGR118_SETTING0. */
#define BM_CCM_CCGR118_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR118_SETTING0. */
#define BS_CCM_CCGR118_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR118_SETTING0. */

/*! @brief Read current value of the CCM_CCGR118_SETTING0 field. */
#define BR_CCM_CCGR118_SETTING0(x) (HW_CCM_CCGR118(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR118_SETTING0. */
#define BF_CCM_CCGR118_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR118_SETTING0) & BM_CCM_CCGR118_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR118_SETTING0(x, v) (HW_CCM_CCGR118_WR(x, (HW_CCM_CCGR118_RD(x) & ~BM_CCM_CCGR118_SETTING0) | BF_CCM_CCGR118_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR118, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR118_SETTING1 (4U)       /*!< Bit position for CCM_CCGR118_SETTING1. */
#define BM_CCM_CCGR118_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR118_SETTING1. */
#define BS_CCM_CCGR118_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR118_SETTING1. */

/*! @brief Read current value of the CCM_CCGR118_SETTING1 field. */
#define BR_CCM_CCGR118_SETTING1(x) (HW_CCM_CCGR118(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR118_SETTING1. */
#define BF_CCM_CCGR118_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR118_SETTING1) & BM_CCM_CCGR118_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR118_SETTING1(x, v) (HW_CCM_CCGR118_WR(x, (HW_CCM_CCGR118_RD(x) & ~BM_CCM_CCGR118_SETTING1) | BF_CCM_CCGR118_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR118, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR118_SETTING2 (8U)       /*!< Bit position for CCM_CCGR118_SETTING2. */
#define BM_CCM_CCGR118_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR118_SETTING2. */
#define BS_CCM_CCGR118_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR118_SETTING2. */

/*! @brief Read current value of the CCM_CCGR118_SETTING2 field. */
#define BR_CCM_CCGR118_SETTING2(x) (HW_CCM_CCGR118(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR118_SETTING2. */
#define BF_CCM_CCGR118_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR118_SETTING2) & BM_CCM_CCGR118_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR118_SETTING2(x, v) (HW_CCM_CCGR118_WR(x, (HW_CCM_CCGR118_RD(x) & ~BM_CCM_CCGR118_SETTING2) | BF_CCM_CCGR118_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR118, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR118_SETTING3 (12U)      /*!< Bit position for CCM_CCGR118_SETTING3. */
#define BM_CCM_CCGR118_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR118_SETTING3. */
#define BS_CCM_CCGR118_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR118_SETTING3. */

/*! @brief Read current value of the CCM_CCGR118_SETTING3 field. */
#define BR_CCM_CCGR118_SETTING3(x) (HW_CCM_CCGR118(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR118_SETTING3. */
#define BF_CCM_CCGR118_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR118_SETTING3) & BM_CCM_CCGR118_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR118_SETTING3(x, v) (HW_CCM_CCGR118_WR(x, (HW_CCM_CCGR118_RD(x) & ~BM_CCM_CCGR118_SETTING3) | BF_CCM_CCGR118_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR119 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR119 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr119
{
    uint32_t U;
    struct _hw_ccm_ccgr119_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr119_t;

/*!
 * @name Constants and macros for entire CCM_CCGR119 register
 */
/*@{*/
#define HW_CCM_CCGR119_ADDR(x)   ((uintptr_t)(x) + 0x4770U)
#define HW_CCM_CCGR119_SET_ADDR(x) (HW_CCM_CCGR119_ADDR(x) + 0x4U)
#define HW_CCM_CCGR119_CLR_ADDR(x) (HW_CCM_CCGR119_ADDR(x) + 0x8U)
#define HW_CCM_CCGR119_TOG_ADDR(x) (HW_CCM_CCGR119_ADDR(x) + 0xCU)

#define HW_CCM_CCGR119(x)        (*(__IO hw_ccm_ccgr119_t *) HW_CCM_CCGR119_ADDR(x))
#define HW_CCM_CCGR119_RD(x)     (HW_CCM_CCGR119(x).U)
#define HW_CCM_CCGR119_WR(x, v)  (HW_CCM_CCGR119(x).U = (v))
#define HW_CCM_CCGR119_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR119_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR119_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR119_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR119_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR119_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR119 bitfields
 */

/*!
 * @name Register CCM_CCGR119, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR119_SETTING0 (0U)       /*!< Bit position for CCM_CCGR119_SETTING0. */
#define BM_CCM_CCGR119_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR119_SETTING0. */
#define BS_CCM_CCGR119_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR119_SETTING0. */

/*! @brief Read current value of the CCM_CCGR119_SETTING0 field. */
#define BR_CCM_CCGR119_SETTING0(x) (HW_CCM_CCGR119(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR119_SETTING0. */
#define BF_CCM_CCGR119_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR119_SETTING0) & BM_CCM_CCGR119_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR119_SETTING0(x, v) (HW_CCM_CCGR119_WR(x, (HW_CCM_CCGR119_RD(x) & ~BM_CCM_CCGR119_SETTING0) | BF_CCM_CCGR119_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR119, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR119_SETTING1 (4U)       /*!< Bit position for CCM_CCGR119_SETTING1. */
#define BM_CCM_CCGR119_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR119_SETTING1. */
#define BS_CCM_CCGR119_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR119_SETTING1. */

/*! @brief Read current value of the CCM_CCGR119_SETTING1 field. */
#define BR_CCM_CCGR119_SETTING1(x) (HW_CCM_CCGR119(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR119_SETTING1. */
#define BF_CCM_CCGR119_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR119_SETTING1) & BM_CCM_CCGR119_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR119_SETTING1(x, v) (HW_CCM_CCGR119_WR(x, (HW_CCM_CCGR119_RD(x) & ~BM_CCM_CCGR119_SETTING1) | BF_CCM_CCGR119_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR119, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR119_SETTING2 (8U)       /*!< Bit position for CCM_CCGR119_SETTING2. */
#define BM_CCM_CCGR119_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR119_SETTING2. */
#define BS_CCM_CCGR119_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR119_SETTING2. */

/*! @brief Read current value of the CCM_CCGR119_SETTING2 field. */
#define BR_CCM_CCGR119_SETTING2(x) (HW_CCM_CCGR119(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR119_SETTING2. */
#define BF_CCM_CCGR119_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR119_SETTING2) & BM_CCM_CCGR119_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR119_SETTING2(x, v) (HW_CCM_CCGR119_WR(x, (HW_CCM_CCGR119_RD(x) & ~BM_CCM_CCGR119_SETTING2) | BF_CCM_CCGR119_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR119, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR119_SETTING3 (12U)      /*!< Bit position for CCM_CCGR119_SETTING3. */
#define BM_CCM_CCGR119_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR119_SETTING3. */
#define BS_CCM_CCGR119_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR119_SETTING3. */

/*! @brief Read current value of the CCM_CCGR119_SETTING3 field. */
#define BR_CCM_CCGR119_SETTING3(x) (HW_CCM_CCGR119(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR119_SETTING3. */
#define BF_CCM_CCGR119_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR119_SETTING3) & BM_CCM_CCGR119_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR119_SETTING3(x, v) (HW_CCM_CCGR119_WR(x, (HW_CCM_CCGR119_RD(x) & ~BM_CCM_CCGR119_SETTING3) | BF_CCM_CCGR119_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR120 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR120 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr120
{
    uint32_t U;
    struct _hw_ccm_ccgr120_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr120_t;

/*!
 * @name Constants and macros for entire CCM_CCGR120 register
 */
/*@{*/
#define HW_CCM_CCGR120_ADDR(x)   ((uintptr_t)(x) + 0x4780U)
#define HW_CCM_CCGR120_SET_ADDR(x) (HW_CCM_CCGR120_ADDR(x) + 0x4U)
#define HW_CCM_CCGR120_CLR_ADDR(x) (HW_CCM_CCGR120_ADDR(x) + 0x8U)
#define HW_CCM_CCGR120_TOG_ADDR(x) (HW_CCM_CCGR120_ADDR(x) + 0xCU)

#define HW_CCM_CCGR120(x)        (*(__IO hw_ccm_ccgr120_t *) HW_CCM_CCGR120_ADDR(x))
#define HW_CCM_CCGR120_RD(x)     (HW_CCM_CCGR120(x).U)
#define HW_CCM_CCGR120_WR(x, v)  (HW_CCM_CCGR120(x).U = (v))
#define HW_CCM_CCGR120_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR120_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR120_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR120_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR120_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR120_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR120 bitfields
 */

/*!
 * @name Register CCM_CCGR120, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR120_SETTING0 (0U)       /*!< Bit position for CCM_CCGR120_SETTING0. */
#define BM_CCM_CCGR120_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR120_SETTING0. */
#define BS_CCM_CCGR120_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR120_SETTING0. */

/*! @brief Read current value of the CCM_CCGR120_SETTING0 field. */
#define BR_CCM_CCGR120_SETTING0(x) (HW_CCM_CCGR120(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR120_SETTING0. */
#define BF_CCM_CCGR120_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR120_SETTING0) & BM_CCM_CCGR120_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR120_SETTING0(x, v) (HW_CCM_CCGR120_WR(x, (HW_CCM_CCGR120_RD(x) & ~BM_CCM_CCGR120_SETTING0) | BF_CCM_CCGR120_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR120, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR120_SETTING1 (4U)       /*!< Bit position for CCM_CCGR120_SETTING1. */
#define BM_CCM_CCGR120_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR120_SETTING1. */
#define BS_CCM_CCGR120_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR120_SETTING1. */

/*! @brief Read current value of the CCM_CCGR120_SETTING1 field. */
#define BR_CCM_CCGR120_SETTING1(x) (HW_CCM_CCGR120(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR120_SETTING1. */
#define BF_CCM_CCGR120_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR120_SETTING1) & BM_CCM_CCGR120_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR120_SETTING1(x, v) (HW_CCM_CCGR120_WR(x, (HW_CCM_CCGR120_RD(x) & ~BM_CCM_CCGR120_SETTING1) | BF_CCM_CCGR120_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR120, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR120_SETTING2 (8U)       /*!< Bit position for CCM_CCGR120_SETTING2. */
#define BM_CCM_CCGR120_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR120_SETTING2. */
#define BS_CCM_CCGR120_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR120_SETTING2. */

/*! @brief Read current value of the CCM_CCGR120_SETTING2 field. */
#define BR_CCM_CCGR120_SETTING2(x) (HW_CCM_CCGR120(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR120_SETTING2. */
#define BF_CCM_CCGR120_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR120_SETTING2) & BM_CCM_CCGR120_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR120_SETTING2(x, v) (HW_CCM_CCGR120_WR(x, (HW_CCM_CCGR120_RD(x) & ~BM_CCM_CCGR120_SETTING2) | BF_CCM_CCGR120_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR120, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR120_SETTING3 (12U)      /*!< Bit position for CCM_CCGR120_SETTING3. */
#define BM_CCM_CCGR120_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR120_SETTING3. */
#define BS_CCM_CCGR120_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR120_SETTING3. */

/*! @brief Read current value of the CCM_CCGR120_SETTING3 field. */
#define BR_CCM_CCGR120_SETTING3(x) (HW_CCM_CCGR120(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR120_SETTING3. */
#define BF_CCM_CCGR120_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR120_SETTING3) & BM_CCM_CCGR120_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR120_SETTING3(x, v) (HW_CCM_CCGR120_WR(x, (HW_CCM_CCGR120_RD(x) & ~BM_CCM_CCGR120_SETTING3) | BF_CCM_CCGR120_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR121 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR121 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr121
{
    uint32_t U;
    struct _hw_ccm_ccgr121_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr121_t;

/*!
 * @name Constants and macros for entire CCM_CCGR121 register
 */
/*@{*/
#define HW_CCM_CCGR121_ADDR(x)   ((uintptr_t)(x) + 0x4790U)
#define HW_CCM_CCGR121_SET_ADDR(x) (HW_CCM_CCGR121_ADDR(x) + 0x4U)
#define HW_CCM_CCGR121_CLR_ADDR(x) (HW_CCM_CCGR121_ADDR(x) + 0x8U)
#define HW_CCM_CCGR121_TOG_ADDR(x) (HW_CCM_CCGR121_ADDR(x) + 0xCU)

#define HW_CCM_CCGR121(x)        (*(__IO hw_ccm_ccgr121_t *) HW_CCM_CCGR121_ADDR(x))
#define HW_CCM_CCGR121_RD(x)     (HW_CCM_CCGR121(x).U)
#define HW_CCM_CCGR121_WR(x, v)  (HW_CCM_CCGR121(x).U = (v))
#define HW_CCM_CCGR121_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR121_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR121_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR121_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR121_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR121_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR121 bitfields
 */

/*!
 * @name Register CCM_CCGR121, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR121_SETTING0 (0U)       /*!< Bit position for CCM_CCGR121_SETTING0. */
#define BM_CCM_CCGR121_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR121_SETTING0. */
#define BS_CCM_CCGR121_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR121_SETTING0. */

/*! @brief Read current value of the CCM_CCGR121_SETTING0 field. */
#define BR_CCM_CCGR121_SETTING0(x) (HW_CCM_CCGR121(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR121_SETTING0. */
#define BF_CCM_CCGR121_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR121_SETTING0) & BM_CCM_CCGR121_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR121_SETTING0(x, v) (HW_CCM_CCGR121_WR(x, (HW_CCM_CCGR121_RD(x) & ~BM_CCM_CCGR121_SETTING0) | BF_CCM_CCGR121_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR121, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR121_SETTING1 (4U)       /*!< Bit position for CCM_CCGR121_SETTING1. */
#define BM_CCM_CCGR121_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR121_SETTING1. */
#define BS_CCM_CCGR121_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR121_SETTING1. */

/*! @brief Read current value of the CCM_CCGR121_SETTING1 field. */
#define BR_CCM_CCGR121_SETTING1(x) (HW_CCM_CCGR121(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR121_SETTING1. */
#define BF_CCM_CCGR121_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR121_SETTING1) & BM_CCM_CCGR121_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR121_SETTING1(x, v) (HW_CCM_CCGR121_WR(x, (HW_CCM_CCGR121_RD(x) & ~BM_CCM_CCGR121_SETTING1) | BF_CCM_CCGR121_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR121, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR121_SETTING2 (8U)       /*!< Bit position for CCM_CCGR121_SETTING2. */
#define BM_CCM_CCGR121_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR121_SETTING2. */
#define BS_CCM_CCGR121_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR121_SETTING2. */

/*! @brief Read current value of the CCM_CCGR121_SETTING2 field. */
#define BR_CCM_CCGR121_SETTING2(x) (HW_CCM_CCGR121(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR121_SETTING2. */
#define BF_CCM_CCGR121_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR121_SETTING2) & BM_CCM_CCGR121_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR121_SETTING2(x, v) (HW_CCM_CCGR121_WR(x, (HW_CCM_CCGR121_RD(x) & ~BM_CCM_CCGR121_SETTING2) | BF_CCM_CCGR121_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR121, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR121_SETTING3 (12U)      /*!< Bit position for CCM_CCGR121_SETTING3. */
#define BM_CCM_CCGR121_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR121_SETTING3. */
#define BS_CCM_CCGR121_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR121_SETTING3. */

/*! @brief Read current value of the CCM_CCGR121_SETTING3 field. */
#define BR_CCM_CCGR121_SETTING3(x) (HW_CCM_CCGR121(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR121_SETTING3. */
#define BF_CCM_CCGR121_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR121_SETTING3) & BM_CCM_CCGR121_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR121_SETTING3(x, v) (HW_CCM_CCGR121_WR(x, (HW_CCM_CCGR121_RD(x) & ~BM_CCM_CCGR121_SETTING3) | BF_CCM_CCGR121_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR122 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR122 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr122
{
    uint32_t U;
    struct _hw_ccm_ccgr122_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr122_t;

/*!
 * @name Constants and macros for entire CCM_CCGR122 register
 */
/*@{*/
#define HW_CCM_CCGR122_ADDR(x)   ((uintptr_t)(x) + 0x47A0U)
#define HW_CCM_CCGR122_SET_ADDR(x) (HW_CCM_CCGR122_ADDR(x) + 0x4U)
#define HW_CCM_CCGR122_CLR_ADDR(x) (HW_CCM_CCGR122_ADDR(x) + 0x8U)
#define HW_CCM_CCGR122_TOG_ADDR(x) (HW_CCM_CCGR122_ADDR(x) + 0xCU)

#define HW_CCM_CCGR122(x)        (*(__IO hw_ccm_ccgr122_t *) HW_CCM_CCGR122_ADDR(x))
#define HW_CCM_CCGR122_RD(x)     (HW_CCM_CCGR122(x).U)
#define HW_CCM_CCGR122_WR(x, v)  (HW_CCM_CCGR122(x).U = (v))
#define HW_CCM_CCGR122_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR122_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR122_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR122_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR122_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR122_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR122 bitfields
 */

/*!
 * @name Register CCM_CCGR122, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR122_SETTING0 (0U)       /*!< Bit position for CCM_CCGR122_SETTING0. */
#define BM_CCM_CCGR122_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR122_SETTING0. */
#define BS_CCM_CCGR122_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR122_SETTING0. */

/*! @brief Read current value of the CCM_CCGR122_SETTING0 field. */
#define BR_CCM_CCGR122_SETTING0(x) (HW_CCM_CCGR122(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR122_SETTING0. */
#define BF_CCM_CCGR122_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR122_SETTING0) & BM_CCM_CCGR122_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR122_SETTING0(x, v) (HW_CCM_CCGR122_WR(x, (HW_CCM_CCGR122_RD(x) & ~BM_CCM_CCGR122_SETTING0) | BF_CCM_CCGR122_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR122, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR122_SETTING1 (4U)       /*!< Bit position for CCM_CCGR122_SETTING1. */
#define BM_CCM_CCGR122_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR122_SETTING1. */
#define BS_CCM_CCGR122_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR122_SETTING1. */

/*! @brief Read current value of the CCM_CCGR122_SETTING1 field. */
#define BR_CCM_CCGR122_SETTING1(x) (HW_CCM_CCGR122(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR122_SETTING1. */
#define BF_CCM_CCGR122_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR122_SETTING1) & BM_CCM_CCGR122_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR122_SETTING1(x, v) (HW_CCM_CCGR122_WR(x, (HW_CCM_CCGR122_RD(x) & ~BM_CCM_CCGR122_SETTING1) | BF_CCM_CCGR122_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR122, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR122_SETTING2 (8U)       /*!< Bit position for CCM_CCGR122_SETTING2. */
#define BM_CCM_CCGR122_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR122_SETTING2. */
#define BS_CCM_CCGR122_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR122_SETTING2. */

/*! @brief Read current value of the CCM_CCGR122_SETTING2 field. */
#define BR_CCM_CCGR122_SETTING2(x) (HW_CCM_CCGR122(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR122_SETTING2. */
#define BF_CCM_CCGR122_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR122_SETTING2) & BM_CCM_CCGR122_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR122_SETTING2(x, v) (HW_CCM_CCGR122_WR(x, (HW_CCM_CCGR122_RD(x) & ~BM_CCM_CCGR122_SETTING2) | BF_CCM_CCGR122_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR122, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR122_SETTING3 (12U)      /*!< Bit position for CCM_CCGR122_SETTING3. */
#define BM_CCM_CCGR122_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR122_SETTING3. */
#define BS_CCM_CCGR122_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR122_SETTING3. */

/*! @brief Read current value of the CCM_CCGR122_SETTING3 field. */
#define BR_CCM_CCGR122_SETTING3(x) (HW_CCM_CCGR122(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR122_SETTING3. */
#define BF_CCM_CCGR122_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR122_SETTING3) & BM_CCM_CCGR122_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR122_SETTING3(x, v) (HW_CCM_CCGR122_WR(x, (HW_CCM_CCGR122_RD(x) & ~BM_CCM_CCGR122_SETTING3) | BF_CCM_CCGR122_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR123 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR123 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr123
{
    uint32_t U;
    struct _hw_ccm_ccgr123_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr123_t;

/*!
 * @name Constants and macros for entire CCM_CCGR123 register
 */
/*@{*/
#define HW_CCM_CCGR123_ADDR(x)   ((uintptr_t)(x) + 0x47B0U)
#define HW_CCM_CCGR123_SET_ADDR(x) (HW_CCM_CCGR123_ADDR(x) + 0x4U)
#define HW_CCM_CCGR123_CLR_ADDR(x) (HW_CCM_CCGR123_ADDR(x) + 0x8U)
#define HW_CCM_CCGR123_TOG_ADDR(x) (HW_CCM_CCGR123_ADDR(x) + 0xCU)

#define HW_CCM_CCGR123(x)        (*(__IO hw_ccm_ccgr123_t *) HW_CCM_CCGR123_ADDR(x))
#define HW_CCM_CCGR123_RD(x)     (HW_CCM_CCGR123(x).U)
#define HW_CCM_CCGR123_WR(x, v)  (HW_CCM_CCGR123(x).U = (v))
#define HW_CCM_CCGR123_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR123_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR123_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR123_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR123_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR123_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR123 bitfields
 */

/*!
 * @name Register CCM_CCGR123, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR123_SETTING0 (0U)       /*!< Bit position for CCM_CCGR123_SETTING0. */
#define BM_CCM_CCGR123_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR123_SETTING0. */
#define BS_CCM_CCGR123_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR123_SETTING0. */

/*! @brief Read current value of the CCM_CCGR123_SETTING0 field. */
#define BR_CCM_CCGR123_SETTING0(x) (HW_CCM_CCGR123(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR123_SETTING0. */
#define BF_CCM_CCGR123_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR123_SETTING0) & BM_CCM_CCGR123_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR123_SETTING0(x, v) (HW_CCM_CCGR123_WR(x, (HW_CCM_CCGR123_RD(x) & ~BM_CCM_CCGR123_SETTING0) | BF_CCM_CCGR123_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR123, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR123_SETTING1 (4U)       /*!< Bit position for CCM_CCGR123_SETTING1. */
#define BM_CCM_CCGR123_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR123_SETTING1. */
#define BS_CCM_CCGR123_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR123_SETTING1. */

/*! @brief Read current value of the CCM_CCGR123_SETTING1 field. */
#define BR_CCM_CCGR123_SETTING1(x) (HW_CCM_CCGR123(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR123_SETTING1. */
#define BF_CCM_CCGR123_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR123_SETTING1) & BM_CCM_CCGR123_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR123_SETTING1(x, v) (HW_CCM_CCGR123_WR(x, (HW_CCM_CCGR123_RD(x) & ~BM_CCM_CCGR123_SETTING1) | BF_CCM_CCGR123_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR123, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR123_SETTING2 (8U)       /*!< Bit position for CCM_CCGR123_SETTING2. */
#define BM_CCM_CCGR123_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR123_SETTING2. */
#define BS_CCM_CCGR123_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR123_SETTING2. */

/*! @brief Read current value of the CCM_CCGR123_SETTING2 field. */
#define BR_CCM_CCGR123_SETTING2(x) (HW_CCM_CCGR123(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR123_SETTING2. */
#define BF_CCM_CCGR123_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR123_SETTING2) & BM_CCM_CCGR123_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR123_SETTING2(x, v) (HW_CCM_CCGR123_WR(x, (HW_CCM_CCGR123_RD(x) & ~BM_CCM_CCGR123_SETTING2) | BF_CCM_CCGR123_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR123, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR123_SETTING3 (12U)      /*!< Bit position for CCM_CCGR123_SETTING3. */
#define BM_CCM_CCGR123_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR123_SETTING3. */
#define BS_CCM_CCGR123_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR123_SETTING3. */

/*! @brief Read current value of the CCM_CCGR123_SETTING3 field. */
#define BR_CCM_CCGR123_SETTING3(x) (HW_CCM_CCGR123(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR123_SETTING3. */
#define BF_CCM_CCGR123_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR123_SETTING3) & BM_CCM_CCGR123_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR123_SETTING3(x, v) (HW_CCM_CCGR123_WR(x, (HW_CCM_CCGR123_RD(x) & ~BM_CCM_CCGR123_SETTING3) | BF_CCM_CCGR123_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR124 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR124 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr124
{
    uint32_t U;
    struct _hw_ccm_ccgr124_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr124_t;

/*!
 * @name Constants and macros for entire CCM_CCGR124 register
 */
/*@{*/
#define HW_CCM_CCGR124_ADDR(x)   ((uintptr_t)(x) + 0x47C0U)
#define HW_CCM_CCGR124_SET_ADDR(x) (HW_CCM_CCGR124_ADDR(x) + 0x4U)
#define HW_CCM_CCGR124_CLR_ADDR(x) (HW_CCM_CCGR124_ADDR(x) + 0x8U)
#define HW_CCM_CCGR124_TOG_ADDR(x) (HW_CCM_CCGR124_ADDR(x) + 0xCU)

#define HW_CCM_CCGR124(x)        (*(__IO hw_ccm_ccgr124_t *) HW_CCM_CCGR124_ADDR(x))
#define HW_CCM_CCGR124_RD(x)     (HW_CCM_CCGR124(x).U)
#define HW_CCM_CCGR124_WR(x, v)  (HW_CCM_CCGR124(x).U = (v))
#define HW_CCM_CCGR124_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR124_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR124_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR124_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR124_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR124_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR124 bitfields
 */

/*!
 * @name Register CCM_CCGR124, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR124_SETTING0 (0U)       /*!< Bit position for CCM_CCGR124_SETTING0. */
#define BM_CCM_CCGR124_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR124_SETTING0. */
#define BS_CCM_CCGR124_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR124_SETTING0. */

/*! @brief Read current value of the CCM_CCGR124_SETTING0 field. */
#define BR_CCM_CCGR124_SETTING0(x) (HW_CCM_CCGR124(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR124_SETTING0. */
#define BF_CCM_CCGR124_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR124_SETTING0) & BM_CCM_CCGR124_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR124_SETTING0(x, v) (HW_CCM_CCGR124_WR(x, (HW_CCM_CCGR124_RD(x) & ~BM_CCM_CCGR124_SETTING0) | BF_CCM_CCGR124_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR124, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR124_SETTING1 (4U)       /*!< Bit position for CCM_CCGR124_SETTING1. */
#define BM_CCM_CCGR124_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR124_SETTING1. */
#define BS_CCM_CCGR124_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR124_SETTING1. */

/*! @brief Read current value of the CCM_CCGR124_SETTING1 field. */
#define BR_CCM_CCGR124_SETTING1(x) (HW_CCM_CCGR124(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR124_SETTING1. */
#define BF_CCM_CCGR124_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR124_SETTING1) & BM_CCM_CCGR124_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR124_SETTING1(x, v) (HW_CCM_CCGR124_WR(x, (HW_CCM_CCGR124_RD(x) & ~BM_CCM_CCGR124_SETTING1) | BF_CCM_CCGR124_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR124, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR124_SETTING2 (8U)       /*!< Bit position for CCM_CCGR124_SETTING2. */
#define BM_CCM_CCGR124_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR124_SETTING2. */
#define BS_CCM_CCGR124_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR124_SETTING2. */

/*! @brief Read current value of the CCM_CCGR124_SETTING2 field. */
#define BR_CCM_CCGR124_SETTING2(x) (HW_CCM_CCGR124(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR124_SETTING2. */
#define BF_CCM_CCGR124_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR124_SETTING2) & BM_CCM_CCGR124_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR124_SETTING2(x, v) (HW_CCM_CCGR124_WR(x, (HW_CCM_CCGR124_RD(x) & ~BM_CCM_CCGR124_SETTING2) | BF_CCM_CCGR124_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR124, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR124_SETTING3 (12U)      /*!< Bit position for CCM_CCGR124_SETTING3. */
#define BM_CCM_CCGR124_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR124_SETTING3. */
#define BS_CCM_CCGR124_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR124_SETTING3. */

/*! @brief Read current value of the CCM_CCGR124_SETTING3 field. */
#define BR_CCM_CCGR124_SETTING3(x) (HW_CCM_CCGR124(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR124_SETTING3. */
#define BF_CCM_CCGR124_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR124_SETTING3) & BM_CCM_CCGR124_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR124_SETTING3(x, v) (HW_CCM_CCGR124_WR(x, (HW_CCM_CCGR124_RD(x) & ~BM_CCM_CCGR124_SETTING3) | BF_CCM_CCGR124_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR125 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR125 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr125
{
    uint32_t U;
    struct _hw_ccm_ccgr125_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr125_t;

/*!
 * @name Constants and macros for entire CCM_CCGR125 register
 */
/*@{*/
#define HW_CCM_CCGR125_ADDR(x)   ((uintptr_t)(x) + 0x47D0U)
#define HW_CCM_CCGR125_SET_ADDR(x) (HW_CCM_CCGR125_ADDR(x) + 0x4U)
#define HW_CCM_CCGR125_CLR_ADDR(x) (HW_CCM_CCGR125_ADDR(x) + 0x8U)
#define HW_CCM_CCGR125_TOG_ADDR(x) (HW_CCM_CCGR125_ADDR(x) + 0xCU)

#define HW_CCM_CCGR125(x)        (*(__IO hw_ccm_ccgr125_t *) HW_CCM_CCGR125_ADDR(x))
#define HW_CCM_CCGR125_RD(x)     (HW_CCM_CCGR125(x).U)
#define HW_CCM_CCGR125_WR(x, v)  (HW_CCM_CCGR125(x).U = (v))
#define HW_CCM_CCGR125_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR125_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR125_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR125_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR125_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR125_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR125 bitfields
 */

/*!
 * @name Register CCM_CCGR125, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR125_SETTING0 (0U)       /*!< Bit position for CCM_CCGR125_SETTING0. */
#define BM_CCM_CCGR125_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR125_SETTING0. */
#define BS_CCM_CCGR125_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR125_SETTING0. */

/*! @brief Read current value of the CCM_CCGR125_SETTING0 field. */
#define BR_CCM_CCGR125_SETTING0(x) (HW_CCM_CCGR125(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR125_SETTING0. */
#define BF_CCM_CCGR125_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR125_SETTING0) & BM_CCM_CCGR125_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR125_SETTING0(x, v) (HW_CCM_CCGR125_WR(x, (HW_CCM_CCGR125_RD(x) & ~BM_CCM_CCGR125_SETTING0) | BF_CCM_CCGR125_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR125, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR125_SETTING1 (4U)       /*!< Bit position for CCM_CCGR125_SETTING1. */
#define BM_CCM_CCGR125_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR125_SETTING1. */
#define BS_CCM_CCGR125_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR125_SETTING1. */

/*! @brief Read current value of the CCM_CCGR125_SETTING1 field. */
#define BR_CCM_CCGR125_SETTING1(x) (HW_CCM_CCGR125(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR125_SETTING1. */
#define BF_CCM_CCGR125_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR125_SETTING1) & BM_CCM_CCGR125_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR125_SETTING1(x, v) (HW_CCM_CCGR125_WR(x, (HW_CCM_CCGR125_RD(x) & ~BM_CCM_CCGR125_SETTING1) | BF_CCM_CCGR125_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR125, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR125_SETTING2 (8U)       /*!< Bit position for CCM_CCGR125_SETTING2. */
#define BM_CCM_CCGR125_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR125_SETTING2. */
#define BS_CCM_CCGR125_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR125_SETTING2. */

/*! @brief Read current value of the CCM_CCGR125_SETTING2 field. */
#define BR_CCM_CCGR125_SETTING2(x) (HW_CCM_CCGR125(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR125_SETTING2. */
#define BF_CCM_CCGR125_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR125_SETTING2) & BM_CCM_CCGR125_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR125_SETTING2(x, v) (HW_CCM_CCGR125_WR(x, (HW_CCM_CCGR125_RD(x) & ~BM_CCM_CCGR125_SETTING2) | BF_CCM_CCGR125_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR125, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR125_SETTING3 (12U)      /*!< Bit position for CCM_CCGR125_SETTING3. */
#define BM_CCM_CCGR125_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR125_SETTING3. */
#define BS_CCM_CCGR125_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR125_SETTING3. */

/*! @brief Read current value of the CCM_CCGR125_SETTING3 field. */
#define BR_CCM_CCGR125_SETTING3(x) (HW_CCM_CCGR125(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR125_SETTING3. */
#define BF_CCM_CCGR125_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR125_SETTING3) & BM_CCM_CCGR125_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR125_SETTING3(x, v) (HW_CCM_CCGR125_WR(x, (HW_CCM_CCGR125_RD(x) & ~BM_CCM_CCGR125_SETTING3) | BF_CCM_CCGR125_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR126 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR126 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr126
{
    uint32_t U;
    struct _hw_ccm_ccgr126_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr126_t;

/*!
 * @name Constants and macros for entire CCM_CCGR126 register
 */
/*@{*/
#define HW_CCM_CCGR126_ADDR(x)   ((uintptr_t)(x) + 0x47E0U)
#define HW_CCM_CCGR126_SET_ADDR(x) (HW_CCM_CCGR126_ADDR(x) + 0x4U)
#define HW_CCM_CCGR126_CLR_ADDR(x) (HW_CCM_CCGR126_ADDR(x) + 0x8U)
#define HW_CCM_CCGR126_TOG_ADDR(x) (HW_CCM_CCGR126_ADDR(x) + 0xCU)

#define HW_CCM_CCGR126(x)        (*(__IO hw_ccm_ccgr126_t *) HW_CCM_CCGR126_ADDR(x))
#define HW_CCM_CCGR126_RD(x)     (HW_CCM_CCGR126(x).U)
#define HW_CCM_CCGR126_WR(x, v)  (HW_CCM_CCGR126(x).U = (v))
#define HW_CCM_CCGR126_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR126_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR126_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR126_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR126_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR126_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR126 bitfields
 */

/*!
 * @name Register CCM_CCGR126, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR126_SETTING0 (0U)       /*!< Bit position for CCM_CCGR126_SETTING0. */
#define BM_CCM_CCGR126_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR126_SETTING0. */
#define BS_CCM_CCGR126_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR126_SETTING0. */

/*! @brief Read current value of the CCM_CCGR126_SETTING0 field. */
#define BR_CCM_CCGR126_SETTING0(x) (HW_CCM_CCGR126(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR126_SETTING0. */
#define BF_CCM_CCGR126_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR126_SETTING0) & BM_CCM_CCGR126_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR126_SETTING0(x, v) (HW_CCM_CCGR126_WR(x, (HW_CCM_CCGR126_RD(x) & ~BM_CCM_CCGR126_SETTING0) | BF_CCM_CCGR126_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR126, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR126_SETTING1 (4U)       /*!< Bit position for CCM_CCGR126_SETTING1. */
#define BM_CCM_CCGR126_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR126_SETTING1. */
#define BS_CCM_CCGR126_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR126_SETTING1. */

/*! @brief Read current value of the CCM_CCGR126_SETTING1 field. */
#define BR_CCM_CCGR126_SETTING1(x) (HW_CCM_CCGR126(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR126_SETTING1. */
#define BF_CCM_CCGR126_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR126_SETTING1) & BM_CCM_CCGR126_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR126_SETTING1(x, v) (HW_CCM_CCGR126_WR(x, (HW_CCM_CCGR126_RD(x) & ~BM_CCM_CCGR126_SETTING1) | BF_CCM_CCGR126_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR126, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR126_SETTING2 (8U)       /*!< Bit position for CCM_CCGR126_SETTING2. */
#define BM_CCM_CCGR126_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR126_SETTING2. */
#define BS_CCM_CCGR126_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR126_SETTING2. */

/*! @brief Read current value of the CCM_CCGR126_SETTING2 field. */
#define BR_CCM_CCGR126_SETTING2(x) (HW_CCM_CCGR126(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR126_SETTING2. */
#define BF_CCM_CCGR126_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR126_SETTING2) & BM_CCM_CCGR126_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR126_SETTING2(x, v) (HW_CCM_CCGR126_WR(x, (HW_CCM_CCGR126_RD(x) & ~BM_CCM_CCGR126_SETTING2) | BF_CCM_CCGR126_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR126, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR126_SETTING3 (12U)      /*!< Bit position for CCM_CCGR126_SETTING3. */
#define BM_CCM_CCGR126_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR126_SETTING3. */
#define BS_CCM_CCGR126_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR126_SETTING3. */

/*! @brief Read current value of the CCM_CCGR126_SETTING3 field. */
#define BR_CCM_CCGR126_SETTING3(x) (HW_CCM_CCGR126(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR126_SETTING3. */
#define BF_CCM_CCGR126_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR126_SETTING3) & BM_CCM_CCGR126_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR126_SETTING3(x, v) (HW_CCM_CCGR126_WR(x, (HW_CCM_CCGR126_RD(x) & ~BM_CCM_CCGR126_SETTING3) | BF_CCM_CCGR126_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR127 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR127 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr127
{
    uint32_t U;
    struct _hw_ccm_ccgr127_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr127_t;

/*!
 * @name Constants and macros for entire CCM_CCGR127 register
 */
/*@{*/
#define HW_CCM_CCGR127_ADDR(x)   ((uintptr_t)(x) + 0x47F0U)
#define HW_CCM_CCGR127_SET_ADDR(x) (HW_CCM_CCGR127_ADDR(x) + 0x4U)
#define HW_CCM_CCGR127_CLR_ADDR(x) (HW_CCM_CCGR127_ADDR(x) + 0x8U)
#define HW_CCM_CCGR127_TOG_ADDR(x) (HW_CCM_CCGR127_ADDR(x) + 0xCU)

#define HW_CCM_CCGR127(x)        (*(__IO hw_ccm_ccgr127_t *) HW_CCM_CCGR127_ADDR(x))
#define HW_CCM_CCGR127_RD(x)     (HW_CCM_CCGR127(x).U)
#define HW_CCM_CCGR127_WR(x, v)  (HW_CCM_CCGR127(x).U = (v))
#define HW_CCM_CCGR127_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR127_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR127_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR127_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR127_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR127_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR127 bitfields
 */

/*!
 * @name Register CCM_CCGR127, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR127_SETTING0 (0U)       /*!< Bit position for CCM_CCGR127_SETTING0. */
#define BM_CCM_CCGR127_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR127_SETTING0. */
#define BS_CCM_CCGR127_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR127_SETTING0. */

/*! @brief Read current value of the CCM_CCGR127_SETTING0 field. */
#define BR_CCM_CCGR127_SETTING0(x) (HW_CCM_CCGR127(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR127_SETTING0. */
#define BF_CCM_CCGR127_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR127_SETTING0) & BM_CCM_CCGR127_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR127_SETTING0(x, v) (HW_CCM_CCGR127_WR(x, (HW_CCM_CCGR127_RD(x) & ~BM_CCM_CCGR127_SETTING0) | BF_CCM_CCGR127_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR127, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR127_SETTING1 (4U)       /*!< Bit position for CCM_CCGR127_SETTING1. */
#define BM_CCM_CCGR127_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR127_SETTING1. */
#define BS_CCM_CCGR127_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR127_SETTING1. */

/*! @brief Read current value of the CCM_CCGR127_SETTING1 field. */
#define BR_CCM_CCGR127_SETTING1(x) (HW_CCM_CCGR127(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR127_SETTING1. */
#define BF_CCM_CCGR127_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR127_SETTING1) & BM_CCM_CCGR127_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR127_SETTING1(x, v) (HW_CCM_CCGR127_WR(x, (HW_CCM_CCGR127_RD(x) & ~BM_CCM_CCGR127_SETTING1) | BF_CCM_CCGR127_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR127, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR127_SETTING2 (8U)       /*!< Bit position for CCM_CCGR127_SETTING2. */
#define BM_CCM_CCGR127_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR127_SETTING2. */
#define BS_CCM_CCGR127_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR127_SETTING2. */

/*! @brief Read current value of the CCM_CCGR127_SETTING2 field. */
#define BR_CCM_CCGR127_SETTING2(x) (HW_CCM_CCGR127(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR127_SETTING2. */
#define BF_CCM_CCGR127_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR127_SETTING2) & BM_CCM_CCGR127_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR127_SETTING2(x, v) (HW_CCM_CCGR127_WR(x, (HW_CCM_CCGR127_RD(x) & ~BM_CCM_CCGR127_SETTING2) | BF_CCM_CCGR127_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR127, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR127_SETTING3 (12U)      /*!< Bit position for CCM_CCGR127_SETTING3. */
#define BM_CCM_CCGR127_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR127_SETTING3. */
#define BS_CCM_CCGR127_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR127_SETTING3. */

/*! @brief Read current value of the CCM_CCGR127_SETTING3 field. */
#define BR_CCM_CCGR127_SETTING3(x) (HW_CCM_CCGR127(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR127_SETTING3. */
#define BF_CCM_CCGR127_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR127_SETTING3) & BM_CCM_CCGR127_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR127_SETTING3(x, v) (HW_CCM_CCGR127_WR(x, (HW_CCM_CCGR127_RD(x) & ~BM_CCM_CCGR127_SETTING3) | BF_CCM_CCGR127_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR128 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR128 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr128
{
    uint32_t U;
    struct _hw_ccm_ccgr128_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr128_t;

/*!
 * @name Constants and macros for entire CCM_CCGR128 register
 */
/*@{*/
#define HW_CCM_CCGR128_ADDR(x)   ((uintptr_t)(x) + 0x4800U)
#define HW_CCM_CCGR128_SET_ADDR(x) (HW_CCM_CCGR128_ADDR(x) + 0x4U)
#define HW_CCM_CCGR128_CLR_ADDR(x) (HW_CCM_CCGR128_ADDR(x) + 0x8U)
#define HW_CCM_CCGR128_TOG_ADDR(x) (HW_CCM_CCGR128_ADDR(x) + 0xCU)

#define HW_CCM_CCGR128(x)        (*(__IO hw_ccm_ccgr128_t *) HW_CCM_CCGR128_ADDR(x))
#define HW_CCM_CCGR128_RD(x)     (HW_CCM_CCGR128(x).U)
#define HW_CCM_CCGR128_WR(x, v)  (HW_CCM_CCGR128(x).U = (v))
#define HW_CCM_CCGR128_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR128_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR128_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR128_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR128_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR128_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR128 bitfields
 */

/*!
 * @name Register CCM_CCGR128, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR128_SETTING0 (0U)       /*!< Bit position for CCM_CCGR128_SETTING0. */
#define BM_CCM_CCGR128_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR128_SETTING0. */
#define BS_CCM_CCGR128_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR128_SETTING0. */

/*! @brief Read current value of the CCM_CCGR128_SETTING0 field. */
#define BR_CCM_CCGR128_SETTING0(x) (HW_CCM_CCGR128(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR128_SETTING0. */
#define BF_CCM_CCGR128_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR128_SETTING0) & BM_CCM_CCGR128_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR128_SETTING0(x, v) (HW_CCM_CCGR128_WR(x, (HW_CCM_CCGR128_RD(x) & ~BM_CCM_CCGR128_SETTING0) | BF_CCM_CCGR128_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR128, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR128_SETTING1 (4U)       /*!< Bit position for CCM_CCGR128_SETTING1. */
#define BM_CCM_CCGR128_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR128_SETTING1. */
#define BS_CCM_CCGR128_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR128_SETTING1. */

/*! @brief Read current value of the CCM_CCGR128_SETTING1 field. */
#define BR_CCM_CCGR128_SETTING1(x) (HW_CCM_CCGR128(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR128_SETTING1. */
#define BF_CCM_CCGR128_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR128_SETTING1) & BM_CCM_CCGR128_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR128_SETTING1(x, v) (HW_CCM_CCGR128_WR(x, (HW_CCM_CCGR128_RD(x) & ~BM_CCM_CCGR128_SETTING1) | BF_CCM_CCGR128_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR128, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR128_SETTING2 (8U)       /*!< Bit position for CCM_CCGR128_SETTING2. */
#define BM_CCM_CCGR128_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR128_SETTING2. */
#define BS_CCM_CCGR128_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR128_SETTING2. */

/*! @brief Read current value of the CCM_CCGR128_SETTING2 field. */
#define BR_CCM_CCGR128_SETTING2(x) (HW_CCM_CCGR128(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR128_SETTING2. */
#define BF_CCM_CCGR128_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR128_SETTING2) & BM_CCM_CCGR128_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR128_SETTING2(x, v) (HW_CCM_CCGR128_WR(x, (HW_CCM_CCGR128_RD(x) & ~BM_CCM_CCGR128_SETTING2) | BF_CCM_CCGR128_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR128, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR128_SETTING3 (12U)      /*!< Bit position for CCM_CCGR128_SETTING3. */
#define BM_CCM_CCGR128_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR128_SETTING3. */
#define BS_CCM_CCGR128_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR128_SETTING3. */

/*! @brief Read current value of the CCM_CCGR128_SETTING3 field. */
#define BR_CCM_CCGR128_SETTING3(x) (HW_CCM_CCGR128(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR128_SETTING3. */
#define BF_CCM_CCGR128_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR128_SETTING3) & BM_CCM_CCGR128_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR128_SETTING3(x, v) (HW_CCM_CCGR128_WR(x, (HW_CCM_CCGR128_RD(x) & ~BM_CCM_CCGR128_SETTING3) | BF_CCM_CCGR128_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR129 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR129 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr129
{
    uint32_t U;
    struct _hw_ccm_ccgr129_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr129_t;

/*!
 * @name Constants and macros for entire CCM_CCGR129 register
 */
/*@{*/
#define HW_CCM_CCGR129_ADDR(x)   ((uintptr_t)(x) + 0x4810U)
#define HW_CCM_CCGR129_SET_ADDR(x) (HW_CCM_CCGR129_ADDR(x) + 0x4U)
#define HW_CCM_CCGR129_CLR_ADDR(x) (HW_CCM_CCGR129_ADDR(x) + 0x8U)
#define HW_CCM_CCGR129_TOG_ADDR(x) (HW_CCM_CCGR129_ADDR(x) + 0xCU)

#define HW_CCM_CCGR129(x)        (*(__IO hw_ccm_ccgr129_t *) HW_CCM_CCGR129_ADDR(x))
#define HW_CCM_CCGR129_RD(x)     (HW_CCM_CCGR129(x).U)
#define HW_CCM_CCGR129_WR(x, v)  (HW_CCM_CCGR129(x).U = (v))
#define HW_CCM_CCGR129_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR129_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR129_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR129_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR129_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR129_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR129 bitfields
 */

/*!
 * @name Register CCM_CCGR129, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR129_SETTING0 (0U)       /*!< Bit position for CCM_CCGR129_SETTING0. */
#define BM_CCM_CCGR129_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR129_SETTING0. */
#define BS_CCM_CCGR129_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR129_SETTING0. */

/*! @brief Read current value of the CCM_CCGR129_SETTING0 field. */
#define BR_CCM_CCGR129_SETTING0(x) (HW_CCM_CCGR129(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR129_SETTING0. */
#define BF_CCM_CCGR129_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR129_SETTING0) & BM_CCM_CCGR129_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR129_SETTING0(x, v) (HW_CCM_CCGR129_WR(x, (HW_CCM_CCGR129_RD(x) & ~BM_CCM_CCGR129_SETTING0) | BF_CCM_CCGR129_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR129, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR129_SETTING1 (4U)       /*!< Bit position for CCM_CCGR129_SETTING1. */
#define BM_CCM_CCGR129_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR129_SETTING1. */
#define BS_CCM_CCGR129_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR129_SETTING1. */

/*! @brief Read current value of the CCM_CCGR129_SETTING1 field. */
#define BR_CCM_CCGR129_SETTING1(x) (HW_CCM_CCGR129(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR129_SETTING1. */
#define BF_CCM_CCGR129_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR129_SETTING1) & BM_CCM_CCGR129_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR129_SETTING1(x, v) (HW_CCM_CCGR129_WR(x, (HW_CCM_CCGR129_RD(x) & ~BM_CCM_CCGR129_SETTING1) | BF_CCM_CCGR129_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR129, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR129_SETTING2 (8U)       /*!< Bit position for CCM_CCGR129_SETTING2. */
#define BM_CCM_CCGR129_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR129_SETTING2. */
#define BS_CCM_CCGR129_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR129_SETTING2. */

/*! @brief Read current value of the CCM_CCGR129_SETTING2 field. */
#define BR_CCM_CCGR129_SETTING2(x) (HW_CCM_CCGR129(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR129_SETTING2. */
#define BF_CCM_CCGR129_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR129_SETTING2) & BM_CCM_CCGR129_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR129_SETTING2(x, v) (HW_CCM_CCGR129_WR(x, (HW_CCM_CCGR129_RD(x) & ~BM_CCM_CCGR129_SETTING2) | BF_CCM_CCGR129_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR129, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR129_SETTING3 (12U)      /*!< Bit position for CCM_CCGR129_SETTING3. */
#define BM_CCM_CCGR129_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR129_SETTING3. */
#define BS_CCM_CCGR129_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR129_SETTING3. */

/*! @brief Read current value of the CCM_CCGR129_SETTING3 field. */
#define BR_CCM_CCGR129_SETTING3(x) (HW_CCM_CCGR129(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR129_SETTING3. */
#define BF_CCM_CCGR129_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR129_SETTING3) & BM_CCM_CCGR129_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR129_SETTING3(x, v) (HW_CCM_CCGR129_WR(x, (HW_CCM_CCGR129_RD(x) & ~BM_CCM_CCGR129_SETTING3) | BF_CCM_CCGR129_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR130 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR130 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr130
{
    uint32_t U;
    struct _hw_ccm_ccgr130_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr130_t;

/*!
 * @name Constants and macros for entire CCM_CCGR130 register
 */
/*@{*/
#define HW_CCM_CCGR130_ADDR(x)   ((uintptr_t)(x) + 0x4820U)
#define HW_CCM_CCGR130_SET_ADDR(x) (HW_CCM_CCGR130_ADDR(x) + 0x4U)
#define HW_CCM_CCGR130_CLR_ADDR(x) (HW_CCM_CCGR130_ADDR(x) + 0x8U)
#define HW_CCM_CCGR130_TOG_ADDR(x) (HW_CCM_CCGR130_ADDR(x) + 0xCU)

#define HW_CCM_CCGR130(x)        (*(__IO hw_ccm_ccgr130_t *) HW_CCM_CCGR130_ADDR(x))
#define HW_CCM_CCGR130_RD(x)     (HW_CCM_CCGR130(x).U)
#define HW_CCM_CCGR130_WR(x, v)  (HW_CCM_CCGR130(x).U = (v))
#define HW_CCM_CCGR130_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR130_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR130_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR130_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR130_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR130_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR130 bitfields
 */

/*!
 * @name Register CCM_CCGR130, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR130_SETTING0 (0U)       /*!< Bit position for CCM_CCGR130_SETTING0. */
#define BM_CCM_CCGR130_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR130_SETTING0. */
#define BS_CCM_CCGR130_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR130_SETTING0. */

/*! @brief Read current value of the CCM_CCGR130_SETTING0 field. */
#define BR_CCM_CCGR130_SETTING0(x) (HW_CCM_CCGR130(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR130_SETTING0. */
#define BF_CCM_CCGR130_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR130_SETTING0) & BM_CCM_CCGR130_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR130_SETTING0(x, v) (HW_CCM_CCGR130_WR(x, (HW_CCM_CCGR130_RD(x) & ~BM_CCM_CCGR130_SETTING0) | BF_CCM_CCGR130_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR130, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR130_SETTING1 (4U)       /*!< Bit position for CCM_CCGR130_SETTING1. */
#define BM_CCM_CCGR130_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR130_SETTING1. */
#define BS_CCM_CCGR130_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR130_SETTING1. */

/*! @brief Read current value of the CCM_CCGR130_SETTING1 field. */
#define BR_CCM_CCGR130_SETTING1(x) (HW_CCM_CCGR130(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR130_SETTING1. */
#define BF_CCM_CCGR130_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR130_SETTING1) & BM_CCM_CCGR130_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR130_SETTING1(x, v) (HW_CCM_CCGR130_WR(x, (HW_CCM_CCGR130_RD(x) & ~BM_CCM_CCGR130_SETTING1) | BF_CCM_CCGR130_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR130, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR130_SETTING2 (8U)       /*!< Bit position for CCM_CCGR130_SETTING2. */
#define BM_CCM_CCGR130_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR130_SETTING2. */
#define BS_CCM_CCGR130_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR130_SETTING2. */

/*! @brief Read current value of the CCM_CCGR130_SETTING2 field. */
#define BR_CCM_CCGR130_SETTING2(x) (HW_CCM_CCGR130(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR130_SETTING2. */
#define BF_CCM_CCGR130_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR130_SETTING2) & BM_CCM_CCGR130_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR130_SETTING2(x, v) (HW_CCM_CCGR130_WR(x, (HW_CCM_CCGR130_RD(x) & ~BM_CCM_CCGR130_SETTING2) | BF_CCM_CCGR130_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR130, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR130_SETTING3 (12U)      /*!< Bit position for CCM_CCGR130_SETTING3. */
#define BM_CCM_CCGR130_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR130_SETTING3. */
#define BS_CCM_CCGR130_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR130_SETTING3. */

/*! @brief Read current value of the CCM_CCGR130_SETTING3 field. */
#define BR_CCM_CCGR130_SETTING3(x) (HW_CCM_CCGR130(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR130_SETTING3. */
#define BF_CCM_CCGR130_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR130_SETTING3) & BM_CCM_CCGR130_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR130_SETTING3(x, v) (HW_CCM_CCGR130_WR(x, (HW_CCM_CCGR130_RD(x) & ~BM_CCM_CCGR130_SETTING3) | BF_CCM_CCGR130_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR131 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR131 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr131
{
    uint32_t U;
    struct _hw_ccm_ccgr131_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr131_t;

/*!
 * @name Constants and macros for entire CCM_CCGR131 register
 */
/*@{*/
#define HW_CCM_CCGR131_ADDR(x)   ((uintptr_t)(x) + 0x4830U)
#define HW_CCM_CCGR131_SET_ADDR(x) (HW_CCM_CCGR131_ADDR(x) + 0x4U)
#define HW_CCM_CCGR131_CLR_ADDR(x) (HW_CCM_CCGR131_ADDR(x) + 0x8U)
#define HW_CCM_CCGR131_TOG_ADDR(x) (HW_CCM_CCGR131_ADDR(x) + 0xCU)

#define HW_CCM_CCGR131(x)        (*(__IO hw_ccm_ccgr131_t *) HW_CCM_CCGR131_ADDR(x))
#define HW_CCM_CCGR131_RD(x)     (HW_CCM_CCGR131(x).U)
#define HW_CCM_CCGR131_WR(x, v)  (HW_CCM_CCGR131(x).U = (v))
#define HW_CCM_CCGR131_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR131_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR131_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR131_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR131_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR131_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR131 bitfields
 */

/*!
 * @name Register CCM_CCGR131, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR131_SETTING0 (0U)       /*!< Bit position for CCM_CCGR131_SETTING0. */
#define BM_CCM_CCGR131_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR131_SETTING0. */
#define BS_CCM_CCGR131_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR131_SETTING0. */

/*! @brief Read current value of the CCM_CCGR131_SETTING0 field. */
#define BR_CCM_CCGR131_SETTING0(x) (HW_CCM_CCGR131(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR131_SETTING0. */
#define BF_CCM_CCGR131_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR131_SETTING0) & BM_CCM_CCGR131_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR131_SETTING0(x, v) (HW_CCM_CCGR131_WR(x, (HW_CCM_CCGR131_RD(x) & ~BM_CCM_CCGR131_SETTING0) | BF_CCM_CCGR131_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR131, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR131_SETTING1 (4U)       /*!< Bit position for CCM_CCGR131_SETTING1. */
#define BM_CCM_CCGR131_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR131_SETTING1. */
#define BS_CCM_CCGR131_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR131_SETTING1. */

/*! @brief Read current value of the CCM_CCGR131_SETTING1 field. */
#define BR_CCM_CCGR131_SETTING1(x) (HW_CCM_CCGR131(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR131_SETTING1. */
#define BF_CCM_CCGR131_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR131_SETTING1) & BM_CCM_CCGR131_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR131_SETTING1(x, v) (HW_CCM_CCGR131_WR(x, (HW_CCM_CCGR131_RD(x) & ~BM_CCM_CCGR131_SETTING1) | BF_CCM_CCGR131_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR131, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR131_SETTING2 (8U)       /*!< Bit position for CCM_CCGR131_SETTING2. */
#define BM_CCM_CCGR131_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR131_SETTING2. */
#define BS_CCM_CCGR131_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR131_SETTING2. */

/*! @brief Read current value of the CCM_CCGR131_SETTING2 field. */
#define BR_CCM_CCGR131_SETTING2(x) (HW_CCM_CCGR131(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR131_SETTING2. */
#define BF_CCM_CCGR131_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR131_SETTING2) & BM_CCM_CCGR131_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR131_SETTING2(x, v) (HW_CCM_CCGR131_WR(x, (HW_CCM_CCGR131_RD(x) & ~BM_CCM_CCGR131_SETTING2) | BF_CCM_CCGR131_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR131, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR131_SETTING3 (12U)      /*!< Bit position for CCM_CCGR131_SETTING3. */
#define BM_CCM_CCGR131_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR131_SETTING3. */
#define BS_CCM_CCGR131_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR131_SETTING3. */

/*! @brief Read current value of the CCM_CCGR131_SETTING3 field. */
#define BR_CCM_CCGR131_SETTING3(x) (HW_CCM_CCGR131(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR131_SETTING3. */
#define BF_CCM_CCGR131_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR131_SETTING3) & BM_CCM_CCGR131_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR131_SETTING3(x, v) (HW_CCM_CCGR131_WR(x, (HW_CCM_CCGR131_RD(x) & ~BM_CCM_CCGR131_SETTING3) | BF_CCM_CCGR131_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR132 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR132 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr132
{
    uint32_t U;
    struct _hw_ccm_ccgr132_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr132_t;

/*!
 * @name Constants and macros for entire CCM_CCGR132 register
 */
/*@{*/
#define HW_CCM_CCGR132_ADDR(x)   ((uintptr_t)(x) + 0x4840U)
#define HW_CCM_CCGR132_SET_ADDR(x) (HW_CCM_CCGR132_ADDR(x) + 0x4U)
#define HW_CCM_CCGR132_CLR_ADDR(x) (HW_CCM_CCGR132_ADDR(x) + 0x8U)
#define HW_CCM_CCGR132_TOG_ADDR(x) (HW_CCM_CCGR132_ADDR(x) + 0xCU)

#define HW_CCM_CCGR132(x)        (*(__IO hw_ccm_ccgr132_t *) HW_CCM_CCGR132_ADDR(x))
#define HW_CCM_CCGR132_RD(x)     (HW_CCM_CCGR132(x).U)
#define HW_CCM_CCGR132_WR(x, v)  (HW_CCM_CCGR132(x).U = (v))
#define HW_CCM_CCGR132_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR132_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR132_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR132_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR132_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR132_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR132 bitfields
 */

/*!
 * @name Register CCM_CCGR132, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR132_SETTING0 (0U)       /*!< Bit position for CCM_CCGR132_SETTING0. */
#define BM_CCM_CCGR132_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR132_SETTING0. */
#define BS_CCM_CCGR132_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR132_SETTING0. */

/*! @brief Read current value of the CCM_CCGR132_SETTING0 field. */
#define BR_CCM_CCGR132_SETTING0(x) (HW_CCM_CCGR132(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR132_SETTING0. */
#define BF_CCM_CCGR132_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR132_SETTING0) & BM_CCM_CCGR132_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR132_SETTING0(x, v) (HW_CCM_CCGR132_WR(x, (HW_CCM_CCGR132_RD(x) & ~BM_CCM_CCGR132_SETTING0) | BF_CCM_CCGR132_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR132, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR132_SETTING1 (4U)       /*!< Bit position for CCM_CCGR132_SETTING1. */
#define BM_CCM_CCGR132_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR132_SETTING1. */
#define BS_CCM_CCGR132_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR132_SETTING1. */

/*! @brief Read current value of the CCM_CCGR132_SETTING1 field. */
#define BR_CCM_CCGR132_SETTING1(x) (HW_CCM_CCGR132(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR132_SETTING1. */
#define BF_CCM_CCGR132_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR132_SETTING1) & BM_CCM_CCGR132_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR132_SETTING1(x, v) (HW_CCM_CCGR132_WR(x, (HW_CCM_CCGR132_RD(x) & ~BM_CCM_CCGR132_SETTING1) | BF_CCM_CCGR132_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR132, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR132_SETTING2 (8U)       /*!< Bit position for CCM_CCGR132_SETTING2. */
#define BM_CCM_CCGR132_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR132_SETTING2. */
#define BS_CCM_CCGR132_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR132_SETTING2. */

/*! @brief Read current value of the CCM_CCGR132_SETTING2 field. */
#define BR_CCM_CCGR132_SETTING2(x) (HW_CCM_CCGR132(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR132_SETTING2. */
#define BF_CCM_CCGR132_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR132_SETTING2) & BM_CCM_CCGR132_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR132_SETTING2(x, v) (HW_CCM_CCGR132_WR(x, (HW_CCM_CCGR132_RD(x) & ~BM_CCM_CCGR132_SETTING2) | BF_CCM_CCGR132_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR132, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR132_SETTING3 (12U)      /*!< Bit position for CCM_CCGR132_SETTING3. */
#define BM_CCM_CCGR132_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR132_SETTING3. */
#define BS_CCM_CCGR132_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR132_SETTING3. */

/*! @brief Read current value of the CCM_CCGR132_SETTING3 field. */
#define BR_CCM_CCGR132_SETTING3(x) (HW_CCM_CCGR132(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR132_SETTING3. */
#define BF_CCM_CCGR132_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR132_SETTING3) & BM_CCM_CCGR132_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR132_SETTING3(x, v) (HW_CCM_CCGR132_WR(x, (HW_CCM_CCGR132_RD(x) & ~BM_CCM_CCGR132_SETTING3) | BF_CCM_CCGR132_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR133 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR133 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr133
{
    uint32_t U;
    struct _hw_ccm_ccgr133_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr133_t;

/*!
 * @name Constants and macros for entire CCM_CCGR133 register
 */
/*@{*/
#define HW_CCM_CCGR133_ADDR(x)   ((uintptr_t)(x) + 0x4850U)
#define HW_CCM_CCGR133_SET_ADDR(x) (HW_CCM_CCGR133_ADDR(x) + 0x4U)
#define HW_CCM_CCGR133_CLR_ADDR(x) (HW_CCM_CCGR133_ADDR(x) + 0x8U)
#define HW_CCM_CCGR133_TOG_ADDR(x) (HW_CCM_CCGR133_ADDR(x) + 0xCU)

#define HW_CCM_CCGR133(x)        (*(__IO hw_ccm_ccgr133_t *) HW_CCM_CCGR133_ADDR(x))
#define HW_CCM_CCGR133_RD(x)     (HW_CCM_CCGR133(x).U)
#define HW_CCM_CCGR133_WR(x, v)  (HW_CCM_CCGR133(x).U = (v))
#define HW_CCM_CCGR133_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR133_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR133_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR133_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR133_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR133_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR133 bitfields
 */

/*!
 * @name Register CCM_CCGR133, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR133_SETTING0 (0U)       /*!< Bit position for CCM_CCGR133_SETTING0. */
#define BM_CCM_CCGR133_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR133_SETTING0. */
#define BS_CCM_CCGR133_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR133_SETTING0. */

/*! @brief Read current value of the CCM_CCGR133_SETTING0 field. */
#define BR_CCM_CCGR133_SETTING0(x) (HW_CCM_CCGR133(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR133_SETTING0. */
#define BF_CCM_CCGR133_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR133_SETTING0) & BM_CCM_CCGR133_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR133_SETTING0(x, v) (HW_CCM_CCGR133_WR(x, (HW_CCM_CCGR133_RD(x) & ~BM_CCM_CCGR133_SETTING0) | BF_CCM_CCGR133_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR133, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR133_SETTING1 (4U)       /*!< Bit position for CCM_CCGR133_SETTING1. */
#define BM_CCM_CCGR133_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR133_SETTING1. */
#define BS_CCM_CCGR133_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR133_SETTING1. */

/*! @brief Read current value of the CCM_CCGR133_SETTING1 field. */
#define BR_CCM_CCGR133_SETTING1(x) (HW_CCM_CCGR133(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR133_SETTING1. */
#define BF_CCM_CCGR133_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR133_SETTING1) & BM_CCM_CCGR133_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR133_SETTING1(x, v) (HW_CCM_CCGR133_WR(x, (HW_CCM_CCGR133_RD(x) & ~BM_CCM_CCGR133_SETTING1) | BF_CCM_CCGR133_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR133, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR133_SETTING2 (8U)       /*!< Bit position for CCM_CCGR133_SETTING2. */
#define BM_CCM_CCGR133_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR133_SETTING2. */
#define BS_CCM_CCGR133_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR133_SETTING2. */

/*! @brief Read current value of the CCM_CCGR133_SETTING2 field. */
#define BR_CCM_CCGR133_SETTING2(x) (HW_CCM_CCGR133(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR133_SETTING2. */
#define BF_CCM_CCGR133_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR133_SETTING2) & BM_CCM_CCGR133_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR133_SETTING2(x, v) (HW_CCM_CCGR133_WR(x, (HW_CCM_CCGR133_RD(x) & ~BM_CCM_CCGR133_SETTING2) | BF_CCM_CCGR133_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR133, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR133_SETTING3 (12U)      /*!< Bit position for CCM_CCGR133_SETTING3. */
#define BM_CCM_CCGR133_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR133_SETTING3. */
#define BS_CCM_CCGR133_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR133_SETTING3. */

/*! @brief Read current value of the CCM_CCGR133_SETTING3 field. */
#define BR_CCM_CCGR133_SETTING3(x) (HW_CCM_CCGR133(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR133_SETTING3. */
#define BF_CCM_CCGR133_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR133_SETTING3) & BM_CCM_CCGR133_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR133_SETTING3(x, v) (HW_CCM_CCGR133_WR(x, (HW_CCM_CCGR133_RD(x) & ~BM_CCM_CCGR133_SETTING3) | BF_CCM_CCGR133_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR134 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR134 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr134
{
    uint32_t U;
    struct _hw_ccm_ccgr134_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr134_t;

/*!
 * @name Constants and macros for entire CCM_CCGR134 register
 */
/*@{*/
#define HW_CCM_CCGR134_ADDR(x)   ((uintptr_t)(x) + 0x4860U)
#define HW_CCM_CCGR134_SET_ADDR(x) (HW_CCM_CCGR134_ADDR(x) + 0x4U)
#define HW_CCM_CCGR134_CLR_ADDR(x) (HW_CCM_CCGR134_ADDR(x) + 0x8U)
#define HW_CCM_CCGR134_TOG_ADDR(x) (HW_CCM_CCGR134_ADDR(x) + 0xCU)

#define HW_CCM_CCGR134(x)        (*(__IO hw_ccm_ccgr134_t *) HW_CCM_CCGR134_ADDR(x))
#define HW_CCM_CCGR134_RD(x)     (HW_CCM_CCGR134(x).U)
#define HW_CCM_CCGR134_WR(x, v)  (HW_CCM_CCGR134(x).U = (v))
#define HW_CCM_CCGR134_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR134_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR134_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR134_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR134_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR134_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR134 bitfields
 */

/*!
 * @name Register CCM_CCGR134, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR134_SETTING0 (0U)       /*!< Bit position for CCM_CCGR134_SETTING0. */
#define BM_CCM_CCGR134_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR134_SETTING0. */
#define BS_CCM_CCGR134_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR134_SETTING0. */

/*! @brief Read current value of the CCM_CCGR134_SETTING0 field. */
#define BR_CCM_CCGR134_SETTING0(x) (HW_CCM_CCGR134(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR134_SETTING0. */
#define BF_CCM_CCGR134_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR134_SETTING0) & BM_CCM_CCGR134_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR134_SETTING0(x, v) (HW_CCM_CCGR134_WR(x, (HW_CCM_CCGR134_RD(x) & ~BM_CCM_CCGR134_SETTING0) | BF_CCM_CCGR134_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR134, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR134_SETTING1 (4U)       /*!< Bit position for CCM_CCGR134_SETTING1. */
#define BM_CCM_CCGR134_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR134_SETTING1. */
#define BS_CCM_CCGR134_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR134_SETTING1. */

/*! @brief Read current value of the CCM_CCGR134_SETTING1 field. */
#define BR_CCM_CCGR134_SETTING1(x) (HW_CCM_CCGR134(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR134_SETTING1. */
#define BF_CCM_CCGR134_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR134_SETTING1) & BM_CCM_CCGR134_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR134_SETTING1(x, v) (HW_CCM_CCGR134_WR(x, (HW_CCM_CCGR134_RD(x) & ~BM_CCM_CCGR134_SETTING1) | BF_CCM_CCGR134_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR134, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR134_SETTING2 (8U)       /*!< Bit position for CCM_CCGR134_SETTING2. */
#define BM_CCM_CCGR134_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR134_SETTING2. */
#define BS_CCM_CCGR134_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR134_SETTING2. */

/*! @brief Read current value of the CCM_CCGR134_SETTING2 field. */
#define BR_CCM_CCGR134_SETTING2(x) (HW_CCM_CCGR134(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR134_SETTING2. */
#define BF_CCM_CCGR134_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR134_SETTING2) & BM_CCM_CCGR134_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR134_SETTING2(x, v) (HW_CCM_CCGR134_WR(x, (HW_CCM_CCGR134_RD(x) & ~BM_CCM_CCGR134_SETTING2) | BF_CCM_CCGR134_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR134, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR134_SETTING3 (12U)      /*!< Bit position for CCM_CCGR134_SETTING3. */
#define BM_CCM_CCGR134_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR134_SETTING3. */
#define BS_CCM_CCGR134_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR134_SETTING3. */

/*! @brief Read current value of the CCM_CCGR134_SETTING3 field. */
#define BR_CCM_CCGR134_SETTING3(x) (HW_CCM_CCGR134(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR134_SETTING3. */
#define BF_CCM_CCGR134_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR134_SETTING3) & BM_CCM_CCGR134_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR134_SETTING3(x, v) (HW_CCM_CCGR134_WR(x, (HW_CCM_CCGR134_RD(x) & ~BM_CCM_CCGR134_SETTING3) | BF_CCM_CCGR134_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR135 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR135 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr135
{
    uint32_t U;
    struct _hw_ccm_ccgr135_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr135_t;

/*!
 * @name Constants and macros for entire CCM_CCGR135 register
 */
/*@{*/
#define HW_CCM_CCGR135_ADDR(x)   ((uintptr_t)(x) + 0x4870U)
#define HW_CCM_CCGR135_SET_ADDR(x) (HW_CCM_CCGR135_ADDR(x) + 0x4U)
#define HW_CCM_CCGR135_CLR_ADDR(x) (HW_CCM_CCGR135_ADDR(x) + 0x8U)
#define HW_CCM_CCGR135_TOG_ADDR(x) (HW_CCM_CCGR135_ADDR(x) + 0xCU)

#define HW_CCM_CCGR135(x)        (*(__IO hw_ccm_ccgr135_t *) HW_CCM_CCGR135_ADDR(x))
#define HW_CCM_CCGR135_RD(x)     (HW_CCM_CCGR135(x).U)
#define HW_CCM_CCGR135_WR(x, v)  (HW_CCM_CCGR135(x).U = (v))
#define HW_CCM_CCGR135_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR135_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR135_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR135_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR135_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR135_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR135 bitfields
 */

/*!
 * @name Register CCM_CCGR135, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR135_SETTING0 (0U)       /*!< Bit position for CCM_CCGR135_SETTING0. */
#define BM_CCM_CCGR135_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR135_SETTING0. */
#define BS_CCM_CCGR135_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR135_SETTING0. */

/*! @brief Read current value of the CCM_CCGR135_SETTING0 field. */
#define BR_CCM_CCGR135_SETTING0(x) (HW_CCM_CCGR135(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR135_SETTING0. */
#define BF_CCM_CCGR135_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR135_SETTING0) & BM_CCM_CCGR135_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR135_SETTING0(x, v) (HW_CCM_CCGR135_WR(x, (HW_CCM_CCGR135_RD(x) & ~BM_CCM_CCGR135_SETTING0) | BF_CCM_CCGR135_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR135, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR135_SETTING1 (4U)       /*!< Bit position for CCM_CCGR135_SETTING1. */
#define BM_CCM_CCGR135_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR135_SETTING1. */
#define BS_CCM_CCGR135_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR135_SETTING1. */

/*! @brief Read current value of the CCM_CCGR135_SETTING1 field. */
#define BR_CCM_CCGR135_SETTING1(x) (HW_CCM_CCGR135(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR135_SETTING1. */
#define BF_CCM_CCGR135_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR135_SETTING1) & BM_CCM_CCGR135_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR135_SETTING1(x, v) (HW_CCM_CCGR135_WR(x, (HW_CCM_CCGR135_RD(x) & ~BM_CCM_CCGR135_SETTING1) | BF_CCM_CCGR135_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR135, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR135_SETTING2 (8U)       /*!< Bit position for CCM_CCGR135_SETTING2. */
#define BM_CCM_CCGR135_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR135_SETTING2. */
#define BS_CCM_CCGR135_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR135_SETTING2. */

/*! @brief Read current value of the CCM_CCGR135_SETTING2 field. */
#define BR_CCM_CCGR135_SETTING2(x) (HW_CCM_CCGR135(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR135_SETTING2. */
#define BF_CCM_CCGR135_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR135_SETTING2) & BM_CCM_CCGR135_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR135_SETTING2(x, v) (HW_CCM_CCGR135_WR(x, (HW_CCM_CCGR135_RD(x) & ~BM_CCM_CCGR135_SETTING2) | BF_CCM_CCGR135_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR135, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR135_SETTING3 (12U)      /*!< Bit position for CCM_CCGR135_SETTING3. */
#define BM_CCM_CCGR135_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR135_SETTING3. */
#define BS_CCM_CCGR135_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR135_SETTING3. */

/*! @brief Read current value of the CCM_CCGR135_SETTING3 field. */
#define BR_CCM_CCGR135_SETTING3(x) (HW_CCM_CCGR135(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR135_SETTING3. */
#define BF_CCM_CCGR135_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR135_SETTING3) & BM_CCM_CCGR135_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR135_SETTING3(x, v) (HW_CCM_CCGR135_WR(x, (HW_CCM_CCGR135_RD(x) & ~BM_CCM_CCGR135_SETTING3) | BF_CCM_CCGR135_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR136 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR136 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr136
{
    uint32_t U;
    struct _hw_ccm_ccgr136_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr136_t;

/*!
 * @name Constants and macros for entire CCM_CCGR136 register
 */
/*@{*/
#define HW_CCM_CCGR136_ADDR(x)   ((uintptr_t)(x) + 0x4880U)
#define HW_CCM_CCGR136_SET_ADDR(x) (HW_CCM_CCGR136_ADDR(x) + 0x4U)
#define HW_CCM_CCGR136_CLR_ADDR(x) (HW_CCM_CCGR136_ADDR(x) + 0x8U)
#define HW_CCM_CCGR136_TOG_ADDR(x) (HW_CCM_CCGR136_ADDR(x) + 0xCU)

#define HW_CCM_CCGR136(x)        (*(__IO hw_ccm_ccgr136_t *) HW_CCM_CCGR136_ADDR(x))
#define HW_CCM_CCGR136_RD(x)     (HW_CCM_CCGR136(x).U)
#define HW_CCM_CCGR136_WR(x, v)  (HW_CCM_CCGR136(x).U = (v))
#define HW_CCM_CCGR136_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR136_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR136_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR136_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR136_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR136_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR136 bitfields
 */

/*!
 * @name Register CCM_CCGR136, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR136_SETTING0 (0U)       /*!< Bit position for CCM_CCGR136_SETTING0. */
#define BM_CCM_CCGR136_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR136_SETTING0. */
#define BS_CCM_CCGR136_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR136_SETTING0. */

/*! @brief Read current value of the CCM_CCGR136_SETTING0 field. */
#define BR_CCM_CCGR136_SETTING0(x) (HW_CCM_CCGR136(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR136_SETTING0. */
#define BF_CCM_CCGR136_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR136_SETTING0) & BM_CCM_CCGR136_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR136_SETTING0(x, v) (HW_CCM_CCGR136_WR(x, (HW_CCM_CCGR136_RD(x) & ~BM_CCM_CCGR136_SETTING0) | BF_CCM_CCGR136_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR136, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR136_SETTING1 (4U)       /*!< Bit position for CCM_CCGR136_SETTING1. */
#define BM_CCM_CCGR136_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR136_SETTING1. */
#define BS_CCM_CCGR136_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR136_SETTING1. */

/*! @brief Read current value of the CCM_CCGR136_SETTING1 field. */
#define BR_CCM_CCGR136_SETTING1(x) (HW_CCM_CCGR136(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR136_SETTING1. */
#define BF_CCM_CCGR136_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR136_SETTING1) & BM_CCM_CCGR136_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR136_SETTING1(x, v) (HW_CCM_CCGR136_WR(x, (HW_CCM_CCGR136_RD(x) & ~BM_CCM_CCGR136_SETTING1) | BF_CCM_CCGR136_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR136, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR136_SETTING2 (8U)       /*!< Bit position for CCM_CCGR136_SETTING2. */
#define BM_CCM_CCGR136_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR136_SETTING2. */
#define BS_CCM_CCGR136_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR136_SETTING2. */

/*! @brief Read current value of the CCM_CCGR136_SETTING2 field. */
#define BR_CCM_CCGR136_SETTING2(x) (HW_CCM_CCGR136(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR136_SETTING2. */
#define BF_CCM_CCGR136_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR136_SETTING2) & BM_CCM_CCGR136_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR136_SETTING2(x, v) (HW_CCM_CCGR136_WR(x, (HW_CCM_CCGR136_RD(x) & ~BM_CCM_CCGR136_SETTING2) | BF_CCM_CCGR136_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR136, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR136_SETTING3 (12U)      /*!< Bit position for CCM_CCGR136_SETTING3. */
#define BM_CCM_CCGR136_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR136_SETTING3. */
#define BS_CCM_CCGR136_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR136_SETTING3. */

/*! @brief Read current value of the CCM_CCGR136_SETTING3 field. */
#define BR_CCM_CCGR136_SETTING3(x) (HW_CCM_CCGR136(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR136_SETTING3. */
#define BF_CCM_CCGR136_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR136_SETTING3) & BM_CCM_CCGR136_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR136_SETTING3(x, v) (HW_CCM_CCGR136_WR(x, (HW_CCM_CCGR136_RD(x) & ~BM_CCM_CCGR136_SETTING3) | BF_CCM_CCGR136_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR137 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR137 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr137
{
    uint32_t U;
    struct _hw_ccm_ccgr137_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr137_t;

/*!
 * @name Constants and macros for entire CCM_CCGR137 register
 */
/*@{*/
#define HW_CCM_CCGR137_ADDR(x)   ((uintptr_t)(x) + 0x4890U)
#define HW_CCM_CCGR137_SET_ADDR(x) (HW_CCM_CCGR137_ADDR(x) + 0x4U)
#define HW_CCM_CCGR137_CLR_ADDR(x) (HW_CCM_CCGR137_ADDR(x) + 0x8U)
#define HW_CCM_CCGR137_TOG_ADDR(x) (HW_CCM_CCGR137_ADDR(x) + 0xCU)

#define HW_CCM_CCGR137(x)        (*(__IO hw_ccm_ccgr137_t *) HW_CCM_CCGR137_ADDR(x))
#define HW_CCM_CCGR137_RD(x)     (HW_CCM_CCGR137(x).U)
#define HW_CCM_CCGR137_WR(x, v)  (HW_CCM_CCGR137(x).U = (v))
#define HW_CCM_CCGR137_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR137_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR137_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR137_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR137_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR137_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR137 bitfields
 */

/*!
 * @name Register CCM_CCGR137, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR137_SETTING0 (0U)       /*!< Bit position for CCM_CCGR137_SETTING0. */
#define BM_CCM_CCGR137_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR137_SETTING0. */
#define BS_CCM_CCGR137_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR137_SETTING0. */

/*! @brief Read current value of the CCM_CCGR137_SETTING0 field. */
#define BR_CCM_CCGR137_SETTING0(x) (HW_CCM_CCGR137(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR137_SETTING0. */
#define BF_CCM_CCGR137_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR137_SETTING0) & BM_CCM_CCGR137_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR137_SETTING0(x, v) (HW_CCM_CCGR137_WR(x, (HW_CCM_CCGR137_RD(x) & ~BM_CCM_CCGR137_SETTING0) | BF_CCM_CCGR137_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR137, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR137_SETTING1 (4U)       /*!< Bit position for CCM_CCGR137_SETTING1. */
#define BM_CCM_CCGR137_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR137_SETTING1. */
#define BS_CCM_CCGR137_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR137_SETTING1. */

/*! @brief Read current value of the CCM_CCGR137_SETTING1 field. */
#define BR_CCM_CCGR137_SETTING1(x) (HW_CCM_CCGR137(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR137_SETTING1. */
#define BF_CCM_CCGR137_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR137_SETTING1) & BM_CCM_CCGR137_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR137_SETTING1(x, v) (HW_CCM_CCGR137_WR(x, (HW_CCM_CCGR137_RD(x) & ~BM_CCM_CCGR137_SETTING1) | BF_CCM_CCGR137_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR137, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR137_SETTING2 (8U)       /*!< Bit position for CCM_CCGR137_SETTING2. */
#define BM_CCM_CCGR137_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR137_SETTING2. */
#define BS_CCM_CCGR137_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR137_SETTING2. */

/*! @brief Read current value of the CCM_CCGR137_SETTING2 field. */
#define BR_CCM_CCGR137_SETTING2(x) (HW_CCM_CCGR137(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR137_SETTING2. */
#define BF_CCM_CCGR137_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR137_SETTING2) & BM_CCM_CCGR137_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR137_SETTING2(x, v) (HW_CCM_CCGR137_WR(x, (HW_CCM_CCGR137_RD(x) & ~BM_CCM_CCGR137_SETTING2) | BF_CCM_CCGR137_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR137, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR137_SETTING3 (12U)      /*!< Bit position for CCM_CCGR137_SETTING3. */
#define BM_CCM_CCGR137_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR137_SETTING3. */
#define BS_CCM_CCGR137_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR137_SETTING3. */

/*! @brief Read current value of the CCM_CCGR137_SETTING3 field. */
#define BR_CCM_CCGR137_SETTING3(x) (HW_CCM_CCGR137(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR137_SETTING3. */
#define BF_CCM_CCGR137_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR137_SETTING3) & BM_CCM_CCGR137_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR137_SETTING3(x, v) (HW_CCM_CCGR137_WR(x, (HW_CCM_CCGR137_RD(x) & ~BM_CCM_CCGR137_SETTING3) | BF_CCM_CCGR137_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR138 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR138 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr138
{
    uint32_t U;
    struct _hw_ccm_ccgr138_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr138_t;

/*!
 * @name Constants and macros for entire CCM_CCGR138 register
 */
/*@{*/
#define HW_CCM_CCGR138_ADDR(x)   ((uintptr_t)(x) + 0x48A0U)
#define HW_CCM_CCGR138_SET_ADDR(x) (HW_CCM_CCGR138_ADDR(x) + 0x4U)
#define HW_CCM_CCGR138_CLR_ADDR(x) (HW_CCM_CCGR138_ADDR(x) + 0x8U)
#define HW_CCM_CCGR138_TOG_ADDR(x) (HW_CCM_CCGR138_ADDR(x) + 0xCU)

#define HW_CCM_CCGR138(x)        (*(__IO hw_ccm_ccgr138_t *) HW_CCM_CCGR138_ADDR(x))
#define HW_CCM_CCGR138_RD(x)     (HW_CCM_CCGR138(x).U)
#define HW_CCM_CCGR138_WR(x, v)  (HW_CCM_CCGR138(x).U = (v))
#define HW_CCM_CCGR138_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR138_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR138_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR138_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR138_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR138_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR138 bitfields
 */

/*!
 * @name Register CCM_CCGR138, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR138_SETTING0 (0U)       /*!< Bit position for CCM_CCGR138_SETTING0. */
#define BM_CCM_CCGR138_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR138_SETTING0. */
#define BS_CCM_CCGR138_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR138_SETTING0. */

/*! @brief Read current value of the CCM_CCGR138_SETTING0 field. */
#define BR_CCM_CCGR138_SETTING0(x) (HW_CCM_CCGR138(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR138_SETTING0. */
#define BF_CCM_CCGR138_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR138_SETTING0) & BM_CCM_CCGR138_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR138_SETTING0(x, v) (HW_CCM_CCGR138_WR(x, (HW_CCM_CCGR138_RD(x) & ~BM_CCM_CCGR138_SETTING0) | BF_CCM_CCGR138_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR138, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR138_SETTING1 (4U)       /*!< Bit position for CCM_CCGR138_SETTING1. */
#define BM_CCM_CCGR138_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR138_SETTING1. */
#define BS_CCM_CCGR138_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR138_SETTING1. */

/*! @brief Read current value of the CCM_CCGR138_SETTING1 field. */
#define BR_CCM_CCGR138_SETTING1(x) (HW_CCM_CCGR138(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR138_SETTING1. */
#define BF_CCM_CCGR138_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR138_SETTING1) & BM_CCM_CCGR138_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR138_SETTING1(x, v) (HW_CCM_CCGR138_WR(x, (HW_CCM_CCGR138_RD(x) & ~BM_CCM_CCGR138_SETTING1) | BF_CCM_CCGR138_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR138, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR138_SETTING2 (8U)       /*!< Bit position for CCM_CCGR138_SETTING2. */
#define BM_CCM_CCGR138_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR138_SETTING2. */
#define BS_CCM_CCGR138_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR138_SETTING2. */

/*! @brief Read current value of the CCM_CCGR138_SETTING2 field. */
#define BR_CCM_CCGR138_SETTING2(x) (HW_CCM_CCGR138(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR138_SETTING2. */
#define BF_CCM_CCGR138_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR138_SETTING2) & BM_CCM_CCGR138_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR138_SETTING2(x, v) (HW_CCM_CCGR138_WR(x, (HW_CCM_CCGR138_RD(x) & ~BM_CCM_CCGR138_SETTING2) | BF_CCM_CCGR138_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR138, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR138_SETTING3 (12U)      /*!< Bit position for CCM_CCGR138_SETTING3. */
#define BM_CCM_CCGR138_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR138_SETTING3. */
#define BS_CCM_CCGR138_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR138_SETTING3. */

/*! @brief Read current value of the CCM_CCGR138_SETTING3 field. */
#define BR_CCM_CCGR138_SETTING3(x) (HW_CCM_CCGR138(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR138_SETTING3. */
#define BF_CCM_CCGR138_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR138_SETTING3) & BM_CCM_CCGR138_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR138_SETTING3(x, v) (HW_CCM_CCGR138_WR(x, (HW_CCM_CCGR138_RD(x) & ~BM_CCM_CCGR138_SETTING3) | BF_CCM_CCGR138_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR139 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR139 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr139
{
    uint32_t U;
    struct _hw_ccm_ccgr139_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr139_t;

/*!
 * @name Constants and macros for entire CCM_CCGR139 register
 */
/*@{*/
#define HW_CCM_CCGR139_ADDR(x)   ((uintptr_t)(x) + 0x48B0U)
#define HW_CCM_CCGR139_SET_ADDR(x) (HW_CCM_CCGR139_ADDR(x) + 0x4U)
#define HW_CCM_CCGR139_CLR_ADDR(x) (HW_CCM_CCGR139_ADDR(x) + 0x8U)
#define HW_CCM_CCGR139_TOG_ADDR(x) (HW_CCM_CCGR139_ADDR(x) + 0xCU)

#define HW_CCM_CCGR139(x)        (*(__IO hw_ccm_ccgr139_t *) HW_CCM_CCGR139_ADDR(x))
#define HW_CCM_CCGR139_RD(x)     (HW_CCM_CCGR139(x).U)
#define HW_CCM_CCGR139_WR(x, v)  (HW_CCM_CCGR139(x).U = (v))
#define HW_CCM_CCGR139_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR139_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR139_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR139_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR139_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR139_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR139 bitfields
 */

/*!
 * @name Register CCM_CCGR139, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR139_SETTING0 (0U)       /*!< Bit position for CCM_CCGR139_SETTING0. */
#define BM_CCM_CCGR139_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR139_SETTING0. */
#define BS_CCM_CCGR139_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR139_SETTING0. */

/*! @brief Read current value of the CCM_CCGR139_SETTING0 field. */
#define BR_CCM_CCGR139_SETTING0(x) (HW_CCM_CCGR139(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR139_SETTING0. */
#define BF_CCM_CCGR139_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR139_SETTING0) & BM_CCM_CCGR139_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR139_SETTING0(x, v) (HW_CCM_CCGR139_WR(x, (HW_CCM_CCGR139_RD(x) & ~BM_CCM_CCGR139_SETTING0) | BF_CCM_CCGR139_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR139, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR139_SETTING1 (4U)       /*!< Bit position for CCM_CCGR139_SETTING1. */
#define BM_CCM_CCGR139_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR139_SETTING1. */
#define BS_CCM_CCGR139_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR139_SETTING1. */

/*! @brief Read current value of the CCM_CCGR139_SETTING1 field. */
#define BR_CCM_CCGR139_SETTING1(x) (HW_CCM_CCGR139(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR139_SETTING1. */
#define BF_CCM_CCGR139_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR139_SETTING1) & BM_CCM_CCGR139_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR139_SETTING1(x, v) (HW_CCM_CCGR139_WR(x, (HW_CCM_CCGR139_RD(x) & ~BM_CCM_CCGR139_SETTING1) | BF_CCM_CCGR139_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR139, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR139_SETTING2 (8U)       /*!< Bit position for CCM_CCGR139_SETTING2. */
#define BM_CCM_CCGR139_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR139_SETTING2. */
#define BS_CCM_CCGR139_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR139_SETTING2. */

/*! @brief Read current value of the CCM_CCGR139_SETTING2 field. */
#define BR_CCM_CCGR139_SETTING2(x) (HW_CCM_CCGR139(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR139_SETTING2. */
#define BF_CCM_CCGR139_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR139_SETTING2) & BM_CCM_CCGR139_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR139_SETTING2(x, v) (HW_CCM_CCGR139_WR(x, (HW_CCM_CCGR139_RD(x) & ~BM_CCM_CCGR139_SETTING2) | BF_CCM_CCGR139_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR139, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR139_SETTING3 (12U)      /*!< Bit position for CCM_CCGR139_SETTING3. */
#define BM_CCM_CCGR139_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR139_SETTING3. */
#define BS_CCM_CCGR139_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR139_SETTING3. */

/*! @brief Read current value of the CCM_CCGR139_SETTING3 field. */
#define BR_CCM_CCGR139_SETTING3(x) (HW_CCM_CCGR139(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR139_SETTING3. */
#define BF_CCM_CCGR139_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR139_SETTING3) & BM_CCM_CCGR139_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR139_SETTING3(x, v) (HW_CCM_CCGR139_WR(x, (HW_CCM_CCGR139_RD(x) & ~BM_CCM_CCGR139_SETTING3) | BF_CCM_CCGR139_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR140 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR140 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr140
{
    uint32_t U;
    struct _hw_ccm_ccgr140_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr140_t;

/*!
 * @name Constants and macros for entire CCM_CCGR140 register
 */
/*@{*/
#define HW_CCM_CCGR140_ADDR(x)   ((uintptr_t)(x) + 0x48C0U)
#define HW_CCM_CCGR140_SET_ADDR(x) (HW_CCM_CCGR140_ADDR(x) + 0x4U)
#define HW_CCM_CCGR140_CLR_ADDR(x) (HW_CCM_CCGR140_ADDR(x) + 0x8U)
#define HW_CCM_CCGR140_TOG_ADDR(x) (HW_CCM_CCGR140_ADDR(x) + 0xCU)

#define HW_CCM_CCGR140(x)        (*(__IO hw_ccm_ccgr140_t *) HW_CCM_CCGR140_ADDR(x))
#define HW_CCM_CCGR140_RD(x)     (HW_CCM_CCGR140(x).U)
#define HW_CCM_CCGR140_WR(x, v)  (HW_CCM_CCGR140(x).U = (v))
#define HW_CCM_CCGR140_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR140_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR140_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR140_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR140_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR140_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR140 bitfields
 */

/*!
 * @name Register CCM_CCGR140, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR140_SETTING0 (0U)       /*!< Bit position for CCM_CCGR140_SETTING0. */
#define BM_CCM_CCGR140_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR140_SETTING0. */
#define BS_CCM_CCGR140_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR140_SETTING0. */

/*! @brief Read current value of the CCM_CCGR140_SETTING0 field. */
#define BR_CCM_CCGR140_SETTING0(x) (HW_CCM_CCGR140(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR140_SETTING0. */
#define BF_CCM_CCGR140_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR140_SETTING0) & BM_CCM_CCGR140_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR140_SETTING0(x, v) (HW_CCM_CCGR140_WR(x, (HW_CCM_CCGR140_RD(x) & ~BM_CCM_CCGR140_SETTING0) | BF_CCM_CCGR140_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR140, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR140_SETTING1 (4U)       /*!< Bit position for CCM_CCGR140_SETTING1. */
#define BM_CCM_CCGR140_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR140_SETTING1. */
#define BS_CCM_CCGR140_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR140_SETTING1. */

/*! @brief Read current value of the CCM_CCGR140_SETTING1 field. */
#define BR_CCM_CCGR140_SETTING1(x) (HW_CCM_CCGR140(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR140_SETTING1. */
#define BF_CCM_CCGR140_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR140_SETTING1) & BM_CCM_CCGR140_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR140_SETTING1(x, v) (HW_CCM_CCGR140_WR(x, (HW_CCM_CCGR140_RD(x) & ~BM_CCM_CCGR140_SETTING1) | BF_CCM_CCGR140_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR140, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR140_SETTING2 (8U)       /*!< Bit position for CCM_CCGR140_SETTING2. */
#define BM_CCM_CCGR140_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR140_SETTING2. */
#define BS_CCM_CCGR140_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR140_SETTING2. */

/*! @brief Read current value of the CCM_CCGR140_SETTING2 field. */
#define BR_CCM_CCGR140_SETTING2(x) (HW_CCM_CCGR140(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR140_SETTING2. */
#define BF_CCM_CCGR140_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR140_SETTING2) & BM_CCM_CCGR140_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR140_SETTING2(x, v) (HW_CCM_CCGR140_WR(x, (HW_CCM_CCGR140_RD(x) & ~BM_CCM_CCGR140_SETTING2) | BF_CCM_CCGR140_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR140, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR140_SETTING3 (12U)      /*!< Bit position for CCM_CCGR140_SETTING3. */
#define BM_CCM_CCGR140_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR140_SETTING3. */
#define BS_CCM_CCGR140_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR140_SETTING3. */

/*! @brief Read current value of the CCM_CCGR140_SETTING3 field. */
#define BR_CCM_CCGR140_SETTING3(x) (HW_CCM_CCGR140(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR140_SETTING3. */
#define BF_CCM_CCGR140_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR140_SETTING3) & BM_CCM_CCGR140_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR140_SETTING3(x, v) (HW_CCM_CCGR140_WR(x, (HW_CCM_CCGR140_RD(x) & ~BM_CCM_CCGR140_SETTING3) | BF_CCM_CCGR140_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR141 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR141 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr141
{
    uint32_t U;
    struct _hw_ccm_ccgr141_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr141_t;

/*!
 * @name Constants and macros for entire CCM_CCGR141 register
 */
/*@{*/
#define HW_CCM_CCGR141_ADDR(x)   ((uintptr_t)(x) + 0x48D0U)
#define HW_CCM_CCGR141_SET_ADDR(x) (HW_CCM_CCGR141_ADDR(x) + 0x4U)
#define HW_CCM_CCGR141_CLR_ADDR(x) (HW_CCM_CCGR141_ADDR(x) + 0x8U)
#define HW_CCM_CCGR141_TOG_ADDR(x) (HW_CCM_CCGR141_ADDR(x) + 0xCU)

#define HW_CCM_CCGR141(x)        (*(__IO hw_ccm_ccgr141_t *) HW_CCM_CCGR141_ADDR(x))
#define HW_CCM_CCGR141_RD(x)     (HW_CCM_CCGR141(x).U)
#define HW_CCM_CCGR141_WR(x, v)  (HW_CCM_CCGR141(x).U = (v))
#define HW_CCM_CCGR141_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR141_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR141_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR141_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR141_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR141_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR141 bitfields
 */

/*!
 * @name Register CCM_CCGR141, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR141_SETTING0 (0U)       /*!< Bit position for CCM_CCGR141_SETTING0. */
#define BM_CCM_CCGR141_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR141_SETTING0. */
#define BS_CCM_CCGR141_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR141_SETTING0. */

/*! @brief Read current value of the CCM_CCGR141_SETTING0 field. */
#define BR_CCM_CCGR141_SETTING0(x) (HW_CCM_CCGR141(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR141_SETTING0. */
#define BF_CCM_CCGR141_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR141_SETTING0) & BM_CCM_CCGR141_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR141_SETTING0(x, v) (HW_CCM_CCGR141_WR(x, (HW_CCM_CCGR141_RD(x) & ~BM_CCM_CCGR141_SETTING0) | BF_CCM_CCGR141_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR141, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR141_SETTING1 (4U)       /*!< Bit position for CCM_CCGR141_SETTING1. */
#define BM_CCM_CCGR141_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR141_SETTING1. */
#define BS_CCM_CCGR141_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR141_SETTING1. */

/*! @brief Read current value of the CCM_CCGR141_SETTING1 field. */
#define BR_CCM_CCGR141_SETTING1(x) (HW_CCM_CCGR141(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR141_SETTING1. */
#define BF_CCM_CCGR141_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR141_SETTING1) & BM_CCM_CCGR141_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR141_SETTING1(x, v) (HW_CCM_CCGR141_WR(x, (HW_CCM_CCGR141_RD(x) & ~BM_CCM_CCGR141_SETTING1) | BF_CCM_CCGR141_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR141, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR141_SETTING2 (8U)       /*!< Bit position for CCM_CCGR141_SETTING2. */
#define BM_CCM_CCGR141_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR141_SETTING2. */
#define BS_CCM_CCGR141_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR141_SETTING2. */

/*! @brief Read current value of the CCM_CCGR141_SETTING2 field. */
#define BR_CCM_CCGR141_SETTING2(x) (HW_CCM_CCGR141(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR141_SETTING2. */
#define BF_CCM_CCGR141_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR141_SETTING2) & BM_CCM_CCGR141_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR141_SETTING2(x, v) (HW_CCM_CCGR141_WR(x, (HW_CCM_CCGR141_RD(x) & ~BM_CCM_CCGR141_SETTING2) | BF_CCM_CCGR141_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR141, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR141_SETTING3 (12U)      /*!< Bit position for CCM_CCGR141_SETTING3. */
#define BM_CCM_CCGR141_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR141_SETTING3. */
#define BS_CCM_CCGR141_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR141_SETTING3. */

/*! @brief Read current value of the CCM_CCGR141_SETTING3 field. */
#define BR_CCM_CCGR141_SETTING3(x) (HW_CCM_CCGR141(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR141_SETTING3. */
#define BF_CCM_CCGR141_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR141_SETTING3) & BM_CCM_CCGR141_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR141_SETTING3(x, v) (HW_CCM_CCGR141_WR(x, (HW_CCM_CCGR141_RD(x) & ~BM_CCM_CCGR141_SETTING3) | BF_CCM_CCGR141_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR142 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR142 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr142
{
    uint32_t U;
    struct _hw_ccm_ccgr142_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr142_t;

/*!
 * @name Constants and macros for entire CCM_CCGR142 register
 */
/*@{*/
#define HW_CCM_CCGR142_ADDR(x)   ((uintptr_t)(x) + 0x48E0U)
#define HW_CCM_CCGR142_SET_ADDR(x) (HW_CCM_CCGR142_ADDR(x) + 0x4U)
#define HW_CCM_CCGR142_CLR_ADDR(x) (HW_CCM_CCGR142_ADDR(x) + 0x8U)
#define HW_CCM_CCGR142_TOG_ADDR(x) (HW_CCM_CCGR142_ADDR(x) + 0xCU)

#define HW_CCM_CCGR142(x)        (*(__IO hw_ccm_ccgr142_t *) HW_CCM_CCGR142_ADDR(x))
#define HW_CCM_CCGR142_RD(x)     (HW_CCM_CCGR142(x).U)
#define HW_CCM_CCGR142_WR(x, v)  (HW_CCM_CCGR142(x).U = (v))
#define HW_CCM_CCGR142_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR142_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR142_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR142_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR142_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR142_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR142 bitfields
 */

/*!
 * @name Register CCM_CCGR142, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR142_SETTING0 (0U)       /*!< Bit position for CCM_CCGR142_SETTING0. */
#define BM_CCM_CCGR142_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR142_SETTING0. */
#define BS_CCM_CCGR142_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR142_SETTING0. */

/*! @brief Read current value of the CCM_CCGR142_SETTING0 field. */
#define BR_CCM_CCGR142_SETTING0(x) (HW_CCM_CCGR142(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR142_SETTING0. */
#define BF_CCM_CCGR142_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR142_SETTING0) & BM_CCM_CCGR142_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR142_SETTING0(x, v) (HW_CCM_CCGR142_WR(x, (HW_CCM_CCGR142_RD(x) & ~BM_CCM_CCGR142_SETTING0) | BF_CCM_CCGR142_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR142, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR142_SETTING1 (4U)       /*!< Bit position for CCM_CCGR142_SETTING1. */
#define BM_CCM_CCGR142_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR142_SETTING1. */
#define BS_CCM_CCGR142_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR142_SETTING1. */

/*! @brief Read current value of the CCM_CCGR142_SETTING1 field. */
#define BR_CCM_CCGR142_SETTING1(x) (HW_CCM_CCGR142(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR142_SETTING1. */
#define BF_CCM_CCGR142_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR142_SETTING1) & BM_CCM_CCGR142_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR142_SETTING1(x, v) (HW_CCM_CCGR142_WR(x, (HW_CCM_CCGR142_RD(x) & ~BM_CCM_CCGR142_SETTING1) | BF_CCM_CCGR142_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR142, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR142_SETTING2 (8U)       /*!< Bit position for CCM_CCGR142_SETTING2. */
#define BM_CCM_CCGR142_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR142_SETTING2. */
#define BS_CCM_CCGR142_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR142_SETTING2. */

/*! @brief Read current value of the CCM_CCGR142_SETTING2 field. */
#define BR_CCM_CCGR142_SETTING2(x) (HW_CCM_CCGR142(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR142_SETTING2. */
#define BF_CCM_CCGR142_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR142_SETTING2) & BM_CCM_CCGR142_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR142_SETTING2(x, v) (HW_CCM_CCGR142_WR(x, (HW_CCM_CCGR142_RD(x) & ~BM_CCM_CCGR142_SETTING2) | BF_CCM_CCGR142_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR142, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR142_SETTING3 (12U)      /*!< Bit position for CCM_CCGR142_SETTING3. */
#define BM_CCM_CCGR142_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR142_SETTING3. */
#define BS_CCM_CCGR142_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR142_SETTING3. */

/*! @brief Read current value of the CCM_CCGR142_SETTING3 field. */
#define BR_CCM_CCGR142_SETTING3(x) (HW_CCM_CCGR142(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR142_SETTING3. */
#define BF_CCM_CCGR142_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR142_SETTING3) & BM_CCM_CCGR142_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR142_SETTING3(x, v) (HW_CCM_CCGR142_WR(x, (HW_CCM_CCGR142_RD(x) & ~BM_CCM_CCGR142_SETTING3) | BF_CCM_CCGR142_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR143 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR143 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr143
{
    uint32_t U;
    struct _hw_ccm_ccgr143_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr143_t;

/*!
 * @name Constants and macros for entire CCM_CCGR143 register
 */
/*@{*/
#define HW_CCM_CCGR143_ADDR(x)   ((uintptr_t)(x) + 0x48F0U)
#define HW_CCM_CCGR143_SET_ADDR(x) (HW_CCM_CCGR143_ADDR(x) + 0x4U)
#define HW_CCM_CCGR143_CLR_ADDR(x) (HW_CCM_CCGR143_ADDR(x) + 0x8U)
#define HW_CCM_CCGR143_TOG_ADDR(x) (HW_CCM_CCGR143_ADDR(x) + 0xCU)

#define HW_CCM_CCGR143(x)        (*(__IO hw_ccm_ccgr143_t *) HW_CCM_CCGR143_ADDR(x))
#define HW_CCM_CCGR143_RD(x)     (HW_CCM_CCGR143(x).U)
#define HW_CCM_CCGR143_WR(x, v)  (HW_CCM_CCGR143(x).U = (v))
#define HW_CCM_CCGR143_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR143_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR143_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR143_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR143_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR143_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR143 bitfields
 */

/*!
 * @name Register CCM_CCGR143, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR143_SETTING0 (0U)       /*!< Bit position for CCM_CCGR143_SETTING0. */
#define BM_CCM_CCGR143_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR143_SETTING0. */
#define BS_CCM_CCGR143_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR143_SETTING0. */

/*! @brief Read current value of the CCM_CCGR143_SETTING0 field. */
#define BR_CCM_CCGR143_SETTING0(x) (HW_CCM_CCGR143(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR143_SETTING0. */
#define BF_CCM_CCGR143_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR143_SETTING0) & BM_CCM_CCGR143_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR143_SETTING0(x, v) (HW_CCM_CCGR143_WR(x, (HW_CCM_CCGR143_RD(x) & ~BM_CCM_CCGR143_SETTING0) | BF_CCM_CCGR143_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR143, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR143_SETTING1 (4U)       /*!< Bit position for CCM_CCGR143_SETTING1. */
#define BM_CCM_CCGR143_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR143_SETTING1. */
#define BS_CCM_CCGR143_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR143_SETTING1. */

/*! @brief Read current value of the CCM_CCGR143_SETTING1 field. */
#define BR_CCM_CCGR143_SETTING1(x) (HW_CCM_CCGR143(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR143_SETTING1. */
#define BF_CCM_CCGR143_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR143_SETTING1) & BM_CCM_CCGR143_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR143_SETTING1(x, v) (HW_CCM_CCGR143_WR(x, (HW_CCM_CCGR143_RD(x) & ~BM_CCM_CCGR143_SETTING1) | BF_CCM_CCGR143_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR143, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR143_SETTING2 (8U)       /*!< Bit position for CCM_CCGR143_SETTING2. */
#define BM_CCM_CCGR143_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR143_SETTING2. */
#define BS_CCM_CCGR143_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR143_SETTING2. */

/*! @brief Read current value of the CCM_CCGR143_SETTING2 field. */
#define BR_CCM_CCGR143_SETTING2(x) (HW_CCM_CCGR143(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR143_SETTING2. */
#define BF_CCM_CCGR143_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR143_SETTING2) & BM_CCM_CCGR143_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR143_SETTING2(x, v) (HW_CCM_CCGR143_WR(x, (HW_CCM_CCGR143_RD(x) & ~BM_CCM_CCGR143_SETTING2) | BF_CCM_CCGR143_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR143, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR143_SETTING3 (12U)      /*!< Bit position for CCM_CCGR143_SETTING3. */
#define BM_CCM_CCGR143_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR143_SETTING3. */
#define BS_CCM_CCGR143_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR143_SETTING3. */

/*! @brief Read current value of the CCM_CCGR143_SETTING3 field. */
#define BR_CCM_CCGR143_SETTING3(x) (HW_CCM_CCGR143(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR143_SETTING3. */
#define BF_CCM_CCGR143_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR143_SETTING3) & BM_CCM_CCGR143_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR143_SETTING3(x, v) (HW_CCM_CCGR143_WR(x, (HW_CCM_CCGR143_RD(x) & ~BM_CCM_CCGR143_SETTING3) | BF_CCM_CCGR143_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR144 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR144 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr144
{
    uint32_t U;
    struct _hw_ccm_ccgr144_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr144_t;

/*!
 * @name Constants and macros for entire CCM_CCGR144 register
 */
/*@{*/
#define HW_CCM_CCGR144_ADDR(x)   ((uintptr_t)(x) + 0x4900U)
#define HW_CCM_CCGR144_SET_ADDR(x) (HW_CCM_CCGR144_ADDR(x) + 0x4U)
#define HW_CCM_CCGR144_CLR_ADDR(x) (HW_CCM_CCGR144_ADDR(x) + 0x8U)
#define HW_CCM_CCGR144_TOG_ADDR(x) (HW_CCM_CCGR144_ADDR(x) + 0xCU)

#define HW_CCM_CCGR144(x)        (*(__IO hw_ccm_ccgr144_t *) HW_CCM_CCGR144_ADDR(x))
#define HW_CCM_CCGR144_RD(x)     (HW_CCM_CCGR144(x).U)
#define HW_CCM_CCGR144_WR(x, v)  (HW_CCM_CCGR144(x).U = (v))
#define HW_CCM_CCGR144_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR144_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR144_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR144_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR144_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR144_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR144 bitfields
 */

/*!
 * @name Register CCM_CCGR144, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR144_SETTING0 (0U)       /*!< Bit position for CCM_CCGR144_SETTING0. */
#define BM_CCM_CCGR144_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR144_SETTING0. */
#define BS_CCM_CCGR144_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR144_SETTING0. */

/*! @brief Read current value of the CCM_CCGR144_SETTING0 field. */
#define BR_CCM_CCGR144_SETTING0(x) (HW_CCM_CCGR144(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR144_SETTING0. */
#define BF_CCM_CCGR144_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR144_SETTING0) & BM_CCM_CCGR144_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR144_SETTING0(x, v) (HW_CCM_CCGR144_WR(x, (HW_CCM_CCGR144_RD(x) & ~BM_CCM_CCGR144_SETTING0) | BF_CCM_CCGR144_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR144, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR144_SETTING1 (4U)       /*!< Bit position for CCM_CCGR144_SETTING1. */
#define BM_CCM_CCGR144_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR144_SETTING1. */
#define BS_CCM_CCGR144_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR144_SETTING1. */

/*! @brief Read current value of the CCM_CCGR144_SETTING1 field. */
#define BR_CCM_CCGR144_SETTING1(x) (HW_CCM_CCGR144(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR144_SETTING1. */
#define BF_CCM_CCGR144_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR144_SETTING1) & BM_CCM_CCGR144_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR144_SETTING1(x, v) (HW_CCM_CCGR144_WR(x, (HW_CCM_CCGR144_RD(x) & ~BM_CCM_CCGR144_SETTING1) | BF_CCM_CCGR144_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR144, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR144_SETTING2 (8U)       /*!< Bit position for CCM_CCGR144_SETTING2. */
#define BM_CCM_CCGR144_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR144_SETTING2. */
#define BS_CCM_CCGR144_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR144_SETTING2. */

/*! @brief Read current value of the CCM_CCGR144_SETTING2 field. */
#define BR_CCM_CCGR144_SETTING2(x) (HW_CCM_CCGR144(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR144_SETTING2. */
#define BF_CCM_CCGR144_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR144_SETTING2) & BM_CCM_CCGR144_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR144_SETTING2(x, v) (HW_CCM_CCGR144_WR(x, (HW_CCM_CCGR144_RD(x) & ~BM_CCM_CCGR144_SETTING2) | BF_CCM_CCGR144_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR144, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR144_SETTING3 (12U)      /*!< Bit position for CCM_CCGR144_SETTING3. */
#define BM_CCM_CCGR144_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR144_SETTING3. */
#define BS_CCM_CCGR144_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR144_SETTING3. */

/*! @brief Read current value of the CCM_CCGR144_SETTING3 field. */
#define BR_CCM_CCGR144_SETTING3(x) (HW_CCM_CCGR144(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR144_SETTING3. */
#define BF_CCM_CCGR144_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR144_SETTING3) & BM_CCM_CCGR144_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR144_SETTING3(x, v) (HW_CCM_CCGR144_WR(x, (HW_CCM_CCGR144_RD(x) & ~BM_CCM_CCGR144_SETTING3) | BF_CCM_CCGR144_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR145 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR145 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr145
{
    uint32_t U;
    struct _hw_ccm_ccgr145_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr145_t;

/*!
 * @name Constants and macros for entire CCM_CCGR145 register
 */
/*@{*/
#define HW_CCM_CCGR145_ADDR(x)   ((uintptr_t)(x) + 0x4910U)
#define HW_CCM_CCGR145_SET_ADDR(x) (HW_CCM_CCGR145_ADDR(x) + 0x4U)
#define HW_CCM_CCGR145_CLR_ADDR(x) (HW_CCM_CCGR145_ADDR(x) + 0x8U)
#define HW_CCM_CCGR145_TOG_ADDR(x) (HW_CCM_CCGR145_ADDR(x) + 0xCU)

#define HW_CCM_CCGR145(x)        (*(__IO hw_ccm_ccgr145_t *) HW_CCM_CCGR145_ADDR(x))
#define HW_CCM_CCGR145_RD(x)     (HW_CCM_CCGR145(x).U)
#define HW_CCM_CCGR145_WR(x, v)  (HW_CCM_CCGR145(x).U = (v))
#define HW_CCM_CCGR145_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR145_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR145_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR145_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR145_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR145_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR145 bitfields
 */

/*!
 * @name Register CCM_CCGR145, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR145_SETTING0 (0U)       /*!< Bit position for CCM_CCGR145_SETTING0. */
#define BM_CCM_CCGR145_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR145_SETTING0. */
#define BS_CCM_CCGR145_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR145_SETTING0. */

/*! @brief Read current value of the CCM_CCGR145_SETTING0 field. */
#define BR_CCM_CCGR145_SETTING0(x) (HW_CCM_CCGR145(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR145_SETTING0. */
#define BF_CCM_CCGR145_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR145_SETTING0) & BM_CCM_CCGR145_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR145_SETTING0(x, v) (HW_CCM_CCGR145_WR(x, (HW_CCM_CCGR145_RD(x) & ~BM_CCM_CCGR145_SETTING0) | BF_CCM_CCGR145_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR145, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR145_SETTING1 (4U)       /*!< Bit position for CCM_CCGR145_SETTING1. */
#define BM_CCM_CCGR145_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR145_SETTING1. */
#define BS_CCM_CCGR145_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR145_SETTING1. */

/*! @brief Read current value of the CCM_CCGR145_SETTING1 field. */
#define BR_CCM_CCGR145_SETTING1(x) (HW_CCM_CCGR145(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR145_SETTING1. */
#define BF_CCM_CCGR145_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR145_SETTING1) & BM_CCM_CCGR145_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR145_SETTING1(x, v) (HW_CCM_CCGR145_WR(x, (HW_CCM_CCGR145_RD(x) & ~BM_CCM_CCGR145_SETTING1) | BF_CCM_CCGR145_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR145, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR145_SETTING2 (8U)       /*!< Bit position for CCM_CCGR145_SETTING2. */
#define BM_CCM_CCGR145_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR145_SETTING2. */
#define BS_CCM_CCGR145_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR145_SETTING2. */

/*! @brief Read current value of the CCM_CCGR145_SETTING2 field. */
#define BR_CCM_CCGR145_SETTING2(x) (HW_CCM_CCGR145(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR145_SETTING2. */
#define BF_CCM_CCGR145_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR145_SETTING2) & BM_CCM_CCGR145_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR145_SETTING2(x, v) (HW_CCM_CCGR145_WR(x, (HW_CCM_CCGR145_RD(x) & ~BM_CCM_CCGR145_SETTING2) | BF_CCM_CCGR145_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR145, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR145_SETTING3 (12U)      /*!< Bit position for CCM_CCGR145_SETTING3. */
#define BM_CCM_CCGR145_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR145_SETTING3. */
#define BS_CCM_CCGR145_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR145_SETTING3. */

/*! @brief Read current value of the CCM_CCGR145_SETTING3 field. */
#define BR_CCM_CCGR145_SETTING3(x) (HW_CCM_CCGR145(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR145_SETTING3. */
#define BF_CCM_CCGR145_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR145_SETTING3) & BM_CCM_CCGR145_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR145_SETTING3(x, v) (HW_CCM_CCGR145_WR(x, (HW_CCM_CCGR145_RD(x) & ~BM_CCM_CCGR145_SETTING3) | BF_CCM_CCGR145_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR146 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR146 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr146
{
    uint32_t U;
    struct _hw_ccm_ccgr146_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr146_t;

/*!
 * @name Constants and macros for entire CCM_CCGR146 register
 */
/*@{*/
#define HW_CCM_CCGR146_ADDR(x)   ((uintptr_t)(x) + 0x4920U)
#define HW_CCM_CCGR146_SET_ADDR(x) (HW_CCM_CCGR146_ADDR(x) + 0x4U)
#define HW_CCM_CCGR146_CLR_ADDR(x) (HW_CCM_CCGR146_ADDR(x) + 0x8U)
#define HW_CCM_CCGR146_TOG_ADDR(x) (HW_CCM_CCGR146_ADDR(x) + 0xCU)

#define HW_CCM_CCGR146(x)        (*(__IO hw_ccm_ccgr146_t *) HW_CCM_CCGR146_ADDR(x))
#define HW_CCM_CCGR146_RD(x)     (HW_CCM_CCGR146(x).U)
#define HW_CCM_CCGR146_WR(x, v)  (HW_CCM_CCGR146(x).U = (v))
#define HW_CCM_CCGR146_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR146_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR146_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR146_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR146_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR146_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR146 bitfields
 */

/*!
 * @name Register CCM_CCGR146, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR146_SETTING0 (0U)       /*!< Bit position for CCM_CCGR146_SETTING0. */
#define BM_CCM_CCGR146_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR146_SETTING0. */
#define BS_CCM_CCGR146_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR146_SETTING0. */

/*! @brief Read current value of the CCM_CCGR146_SETTING0 field. */
#define BR_CCM_CCGR146_SETTING0(x) (HW_CCM_CCGR146(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR146_SETTING0. */
#define BF_CCM_CCGR146_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR146_SETTING0) & BM_CCM_CCGR146_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR146_SETTING0(x, v) (HW_CCM_CCGR146_WR(x, (HW_CCM_CCGR146_RD(x) & ~BM_CCM_CCGR146_SETTING0) | BF_CCM_CCGR146_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR146, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR146_SETTING1 (4U)       /*!< Bit position for CCM_CCGR146_SETTING1. */
#define BM_CCM_CCGR146_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR146_SETTING1. */
#define BS_CCM_CCGR146_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR146_SETTING1. */

/*! @brief Read current value of the CCM_CCGR146_SETTING1 field. */
#define BR_CCM_CCGR146_SETTING1(x) (HW_CCM_CCGR146(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR146_SETTING1. */
#define BF_CCM_CCGR146_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR146_SETTING1) & BM_CCM_CCGR146_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR146_SETTING1(x, v) (HW_CCM_CCGR146_WR(x, (HW_CCM_CCGR146_RD(x) & ~BM_CCM_CCGR146_SETTING1) | BF_CCM_CCGR146_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR146, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR146_SETTING2 (8U)       /*!< Bit position for CCM_CCGR146_SETTING2. */
#define BM_CCM_CCGR146_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR146_SETTING2. */
#define BS_CCM_CCGR146_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR146_SETTING2. */

/*! @brief Read current value of the CCM_CCGR146_SETTING2 field. */
#define BR_CCM_CCGR146_SETTING2(x) (HW_CCM_CCGR146(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR146_SETTING2. */
#define BF_CCM_CCGR146_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR146_SETTING2) & BM_CCM_CCGR146_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR146_SETTING2(x, v) (HW_CCM_CCGR146_WR(x, (HW_CCM_CCGR146_RD(x) & ~BM_CCM_CCGR146_SETTING2) | BF_CCM_CCGR146_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR146, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR146_SETTING3 (12U)      /*!< Bit position for CCM_CCGR146_SETTING3. */
#define BM_CCM_CCGR146_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR146_SETTING3. */
#define BS_CCM_CCGR146_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR146_SETTING3. */

/*! @brief Read current value of the CCM_CCGR146_SETTING3 field. */
#define BR_CCM_CCGR146_SETTING3(x) (HW_CCM_CCGR146(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR146_SETTING3. */
#define BF_CCM_CCGR146_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR146_SETTING3) & BM_CCM_CCGR146_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR146_SETTING3(x, v) (HW_CCM_CCGR146_WR(x, (HW_CCM_CCGR146_RD(x) & ~BM_CCM_CCGR146_SETTING3) | BF_CCM_CCGR146_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR147 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR147 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr147
{
    uint32_t U;
    struct _hw_ccm_ccgr147_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr147_t;

/*!
 * @name Constants and macros for entire CCM_CCGR147 register
 */
/*@{*/
#define HW_CCM_CCGR147_ADDR(x)   ((uintptr_t)(x) + 0x4930U)
#define HW_CCM_CCGR147_SET_ADDR(x) (HW_CCM_CCGR147_ADDR(x) + 0x4U)
#define HW_CCM_CCGR147_CLR_ADDR(x) (HW_CCM_CCGR147_ADDR(x) + 0x8U)
#define HW_CCM_CCGR147_TOG_ADDR(x) (HW_CCM_CCGR147_ADDR(x) + 0xCU)

#define HW_CCM_CCGR147(x)        (*(__IO hw_ccm_ccgr147_t *) HW_CCM_CCGR147_ADDR(x))
#define HW_CCM_CCGR147_RD(x)     (HW_CCM_CCGR147(x).U)
#define HW_CCM_CCGR147_WR(x, v)  (HW_CCM_CCGR147(x).U = (v))
#define HW_CCM_CCGR147_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR147_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR147_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR147_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR147_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR147_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR147 bitfields
 */

/*!
 * @name Register CCM_CCGR147, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR147_SETTING0 (0U)       /*!< Bit position for CCM_CCGR147_SETTING0. */
#define BM_CCM_CCGR147_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR147_SETTING0. */
#define BS_CCM_CCGR147_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR147_SETTING0. */

/*! @brief Read current value of the CCM_CCGR147_SETTING0 field. */
#define BR_CCM_CCGR147_SETTING0(x) (HW_CCM_CCGR147(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR147_SETTING0. */
#define BF_CCM_CCGR147_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR147_SETTING0) & BM_CCM_CCGR147_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR147_SETTING0(x, v) (HW_CCM_CCGR147_WR(x, (HW_CCM_CCGR147_RD(x) & ~BM_CCM_CCGR147_SETTING0) | BF_CCM_CCGR147_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR147, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR147_SETTING1 (4U)       /*!< Bit position for CCM_CCGR147_SETTING1. */
#define BM_CCM_CCGR147_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR147_SETTING1. */
#define BS_CCM_CCGR147_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR147_SETTING1. */

/*! @brief Read current value of the CCM_CCGR147_SETTING1 field. */
#define BR_CCM_CCGR147_SETTING1(x) (HW_CCM_CCGR147(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR147_SETTING1. */
#define BF_CCM_CCGR147_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR147_SETTING1) & BM_CCM_CCGR147_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR147_SETTING1(x, v) (HW_CCM_CCGR147_WR(x, (HW_CCM_CCGR147_RD(x) & ~BM_CCM_CCGR147_SETTING1) | BF_CCM_CCGR147_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR147, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR147_SETTING2 (8U)       /*!< Bit position for CCM_CCGR147_SETTING2. */
#define BM_CCM_CCGR147_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR147_SETTING2. */
#define BS_CCM_CCGR147_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR147_SETTING2. */

/*! @brief Read current value of the CCM_CCGR147_SETTING2 field. */
#define BR_CCM_CCGR147_SETTING2(x) (HW_CCM_CCGR147(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR147_SETTING2. */
#define BF_CCM_CCGR147_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR147_SETTING2) & BM_CCM_CCGR147_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR147_SETTING2(x, v) (HW_CCM_CCGR147_WR(x, (HW_CCM_CCGR147_RD(x) & ~BM_CCM_CCGR147_SETTING2) | BF_CCM_CCGR147_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR147, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR147_SETTING3 (12U)      /*!< Bit position for CCM_CCGR147_SETTING3. */
#define BM_CCM_CCGR147_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR147_SETTING3. */
#define BS_CCM_CCGR147_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR147_SETTING3. */

/*! @brief Read current value of the CCM_CCGR147_SETTING3 field. */
#define BR_CCM_CCGR147_SETTING3(x) (HW_CCM_CCGR147(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR147_SETTING3. */
#define BF_CCM_CCGR147_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR147_SETTING3) & BM_CCM_CCGR147_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR147_SETTING3(x, v) (HW_CCM_CCGR147_WR(x, (HW_CCM_CCGR147_RD(x) & ~BM_CCM_CCGR147_SETTING3) | BF_CCM_CCGR147_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR148 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR148 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr148
{
    uint32_t U;
    struct _hw_ccm_ccgr148_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr148_t;

/*!
 * @name Constants and macros for entire CCM_CCGR148 register
 */
/*@{*/
#define HW_CCM_CCGR148_ADDR(x)   ((uintptr_t)(x) + 0x4940U)
#define HW_CCM_CCGR148_SET_ADDR(x) (HW_CCM_CCGR148_ADDR(x) + 0x4U)
#define HW_CCM_CCGR148_CLR_ADDR(x) (HW_CCM_CCGR148_ADDR(x) + 0x8U)
#define HW_CCM_CCGR148_TOG_ADDR(x) (HW_CCM_CCGR148_ADDR(x) + 0xCU)

#define HW_CCM_CCGR148(x)        (*(__IO hw_ccm_ccgr148_t *) HW_CCM_CCGR148_ADDR(x))
#define HW_CCM_CCGR148_RD(x)     (HW_CCM_CCGR148(x).U)
#define HW_CCM_CCGR148_WR(x, v)  (HW_CCM_CCGR148(x).U = (v))
#define HW_CCM_CCGR148_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR148_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR148_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR148_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR148_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR148_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR148 bitfields
 */

/*!
 * @name Register CCM_CCGR148, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR148_SETTING0 (0U)       /*!< Bit position for CCM_CCGR148_SETTING0. */
#define BM_CCM_CCGR148_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR148_SETTING0. */
#define BS_CCM_CCGR148_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR148_SETTING0. */

/*! @brief Read current value of the CCM_CCGR148_SETTING0 field. */
#define BR_CCM_CCGR148_SETTING0(x) (HW_CCM_CCGR148(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR148_SETTING0. */
#define BF_CCM_CCGR148_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR148_SETTING0) & BM_CCM_CCGR148_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR148_SETTING0(x, v) (HW_CCM_CCGR148_WR(x, (HW_CCM_CCGR148_RD(x) & ~BM_CCM_CCGR148_SETTING0) | BF_CCM_CCGR148_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR148, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR148_SETTING1 (4U)       /*!< Bit position for CCM_CCGR148_SETTING1. */
#define BM_CCM_CCGR148_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR148_SETTING1. */
#define BS_CCM_CCGR148_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR148_SETTING1. */

/*! @brief Read current value of the CCM_CCGR148_SETTING1 field. */
#define BR_CCM_CCGR148_SETTING1(x) (HW_CCM_CCGR148(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR148_SETTING1. */
#define BF_CCM_CCGR148_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR148_SETTING1) & BM_CCM_CCGR148_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR148_SETTING1(x, v) (HW_CCM_CCGR148_WR(x, (HW_CCM_CCGR148_RD(x) & ~BM_CCM_CCGR148_SETTING1) | BF_CCM_CCGR148_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR148, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR148_SETTING2 (8U)       /*!< Bit position for CCM_CCGR148_SETTING2. */
#define BM_CCM_CCGR148_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR148_SETTING2. */
#define BS_CCM_CCGR148_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR148_SETTING2. */

/*! @brief Read current value of the CCM_CCGR148_SETTING2 field. */
#define BR_CCM_CCGR148_SETTING2(x) (HW_CCM_CCGR148(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR148_SETTING2. */
#define BF_CCM_CCGR148_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR148_SETTING2) & BM_CCM_CCGR148_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR148_SETTING2(x, v) (HW_CCM_CCGR148_WR(x, (HW_CCM_CCGR148_RD(x) & ~BM_CCM_CCGR148_SETTING2) | BF_CCM_CCGR148_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR148, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR148_SETTING3 (12U)      /*!< Bit position for CCM_CCGR148_SETTING3. */
#define BM_CCM_CCGR148_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR148_SETTING3. */
#define BS_CCM_CCGR148_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR148_SETTING3. */

/*! @brief Read current value of the CCM_CCGR148_SETTING3 field. */
#define BR_CCM_CCGR148_SETTING3(x) (HW_CCM_CCGR148(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR148_SETTING3. */
#define BF_CCM_CCGR148_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR148_SETTING3) & BM_CCM_CCGR148_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR148_SETTING3(x, v) (HW_CCM_CCGR148_WR(x, (HW_CCM_CCGR148_RD(x) & ~BM_CCM_CCGR148_SETTING3) | BF_CCM_CCGR148_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR149 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR149 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr149
{
    uint32_t U;
    struct _hw_ccm_ccgr149_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr149_t;

/*!
 * @name Constants and macros for entire CCM_CCGR149 register
 */
/*@{*/
#define HW_CCM_CCGR149_ADDR(x)   ((uintptr_t)(x) + 0x4950U)
#define HW_CCM_CCGR149_SET_ADDR(x) (HW_CCM_CCGR149_ADDR(x) + 0x4U)
#define HW_CCM_CCGR149_CLR_ADDR(x) (HW_CCM_CCGR149_ADDR(x) + 0x8U)
#define HW_CCM_CCGR149_TOG_ADDR(x) (HW_CCM_CCGR149_ADDR(x) + 0xCU)

#define HW_CCM_CCGR149(x)        (*(__IO hw_ccm_ccgr149_t *) HW_CCM_CCGR149_ADDR(x))
#define HW_CCM_CCGR149_RD(x)     (HW_CCM_CCGR149(x).U)
#define HW_CCM_CCGR149_WR(x, v)  (HW_CCM_CCGR149(x).U = (v))
#define HW_CCM_CCGR149_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR149_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR149_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR149_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR149_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR149_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR149 bitfields
 */

/*!
 * @name Register CCM_CCGR149, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR149_SETTING0 (0U)       /*!< Bit position for CCM_CCGR149_SETTING0. */
#define BM_CCM_CCGR149_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR149_SETTING0. */
#define BS_CCM_CCGR149_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR149_SETTING0. */

/*! @brief Read current value of the CCM_CCGR149_SETTING0 field. */
#define BR_CCM_CCGR149_SETTING0(x) (HW_CCM_CCGR149(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR149_SETTING0. */
#define BF_CCM_CCGR149_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR149_SETTING0) & BM_CCM_CCGR149_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR149_SETTING0(x, v) (HW_CCM_CCGR149_WR(x, (HW_CCM_CCGR149_RD(x) & ~BM_CCM_CCGR149_SETTING0) | BF_CCM_CCGR149_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR149, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR149_SETTING1 (4U)       /*!< Bit position for CCM_CCGR149_SETTING1. */
#define BM_CCM_CCGR149_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR149_SETTING1. */
#define BS_CCM_CCGR149_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR149_SETTING1. */

/*! @brief Read current value of the CCM_CCGR149_SETTING1 field. */
#define BR_CCM_CCGR149_SETTING1(x) (HW_CCM_CCGR149(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR149_SETTING1. */
#define BF_CCM_CCGR149_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR149_SETTING1) & BM_CCM_CCGR149_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR149_SETTING1(x, v) (HW_CCM_CCGR149_WR(x, (HW_CCM_CCGR149_RD(x) & ~BM_CCM_CCGR149_SETTING1) | BF_CCM_CCGR149_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR149, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR149_SETTING2 (8U)       /*!< Bit position for CCM_CCGR149_SETTING2. */
#define BM_CCM_CCGR149_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR149_SETTING2. */
#define BS_CCM_CCGR149_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR149_SETTING2. */

/*! @brief Read current value of the CCM_CCGR149_SETTING2 field. */
#define BR_CCM_CCGR149_SETTING2(x) (HW_CCM_CCGR149(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR149_SETTING2. */
#define BF_CCM_CCGR149_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR149_SETTING2) & BM_CCM_CCGR149_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR149_SETTING2(x, v) (HW_CCM_CCGR149_WR(x, (HW_CCM_CCGR149_RD(x) & ~BM_CCM_CCGR149_SETTING2) | BF_CCM_CCGR149_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR149, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR149_SETTING3 (12U)      /*!< Bit position for CCM_CCGR149_SETTING3. */
#define BM_CCM_CCGR149_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR149_SETTING3. */
#define BS_CCM_CCGR149_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR149_SETTING3. */

/*! @brief Read current value of the CCM_CCGR149_SETTING3 field. */
#define BR_CCM_CCGR149_SETTING3(x) (HW_CCM_CCGR149(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR149_SETTING3. */
#define BF_CCM_CCGR149_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR149_SETTING3) & BM_CCM_CCGR149_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR149_SETTING3(x, v) (HW_CCM_CCGR149_WR(x, (HW_CCM_CCGR149_RD(x) & ~BM_CCM_CCGR149_SETTING3) | BF_CCM_CCGR149_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR150 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR150 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr150
{
    uint32_t U;
    struct _hw_ccm_ccgr150_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr150_t;

/*!
 * @name Constants and macros for entire CCM_CCGR150 register
 */
/*@{*/
#define HW_CCM_CCGR150_ADDR(x)   ((uintptr_t)(x) + 0x4960U)
#define HW_CCM_CCGR150_SET_ADDR(x) (HW_CCM_CCGR150_ADDR(x) + 0x4U)
#define HW_CCM_CCGR150_CLR_ADDR(x) (HW_CCM_CCGR150_ADDR(x) + 0x8U)
#define HW_CCM_CCGR150_TOG_ADDR(x) (HW_CCM_CCGR150_ADDR(x) + 0xCU)

#define HW_CCM_CCGR150(x)        (*(__IO hw_ccm_ccgr150_t *) HW_CCM_CCGR150_ADDR(x))
#define HW_CCM_CCGR150_RD(x)     (HW_CCM_CCGR150(x).U)
#define HW_CCM_CCGR150_WR(x, v)  (HW_CCM_CCGR150(x).U = (v))
#define HW_CCM_CCGR150_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR150_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR150_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR150_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR150_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR150_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR150 bitfields
 */

/*!
 * @name Register CCM_CCGR150, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR150_SETTING0 (0U)       /*!< Bit position for CCM_CCGR150_SETTING0. */
#define BM_CCM_CCGR150_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR150_SETTING0. */
#define BS_CCM_CCGR150_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR150_SETTING0. */

/*! @brief Read current value of the CCM_CCGR150_SETTING0 field. */
#define BR_CCM_CCGR150_SETTING0(x) (HW_CCM_CCGR150(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR150_SETTING0. */
#define BF_CCM_CCGR150_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR150_SETTING0) & BM_CCM_CCGR150_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR150_SETTING0(x, v) (HW_CCM_CCGR150_WR(x, (HW_CCM_CCGR150_RD(x) & ~BM_CCM_CCGR150_SETTING0) | BF_CCM_CCGR150_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR150, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR150_SETTING1 (4U)       /*!< Bit position for CCM_CCGR150_SETTING1. */
#define BM_CCM_CCGR150_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR150_SETTING1. */
#define BS_CCM_CCGR150_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR150_SETTING1. */

/*! @brief Read current value of the CCM_CCGR150_SETTING1 field. */
#define BR_CCM_CCGR150_SETTING1(x) (HW_CCM_CCGR150(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR150_SETTING1. */
#define BF_CCM_CCGR150_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR150_SETTING1) & BM_CCM_CCGR150_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR150_SETTING1(x, v) (HW_CCM_CCGR150_WR(x, (HW_CCM_CCGR150_RD(x) & ~BM_CCM_CCGR150_SETTING1) | BF_CCM_CCGR150_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR150, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR150_SETTING2 (8U)       /*!< Bit position for CCM_CCGR150_SETTING2. */
#define BM_CCM_CCGR150_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR150_SETTING2. */
#define BS_CCM_CCGR150_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR150_SETTING2. */

/*! @brief Read current value of the CCM_CCGR150_SETTING2 field. */
#define BR_CCM_CCGR150_SETTING2(x) (HW_CCM_CCGR150(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR150_SETTING2. */
#define BF_CCM_CCGR150_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR150_SETTING2) & BM_CCM_CCGR150_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR150_SETTING2(x, v) (HW_CCM_CCGR150_WR(x, (HW_CCM_CCGR150_RD(x) & ~BM_CCM_CCGR150_SETTING2) | BF_CCM_CCGR150_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR150, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR150_SETTING3 (12U)      /*!< Bit position for CCM_CCGR150_SETTING3. */
#define BM_CCM_CCGR150_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR150_SETTING3. */
#define BS_CCM_CCGR150_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR150_SETTING3. */

/*! @brief Read current value of the CCM_CCGR150_SETTING3 field. */
#define BR_CCM_CCGR150_SETTING3(x) (HW_CCM_CCGR150(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR150_SETTING3. */
#define BF_CCM_CCGR150_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR150_SETTING3) & BM_CCM_CCGR150_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR150_SETTING3(x, v) (HW_CCM_CCGR150_WR(x, (HW_CCM_CCGR150_RD(x) & ~BM_CCM_CCGR150_SETTING3) | BF_CCM_CCGR150_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR151 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR151 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr151
{
    uint32_t U;
    struct _hw_ccm_ccgr151_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr151_t;

/*!
 * @name Constants and macros for entire CCM_CCGR151 register
 */
/*@{*/
#define HW_CCM_CCGR151_ADDR(x)   ((uintptr_t)(x) + 0x4970U)
#define HW_CCM_CCGR151_SET_ADDR(x) (HW_CCM_CCGR151_ADDR(x) + 0x4U)
#define HW_CCM_CCGR151_CLR_ADDR(x) (HW_CCM_CCGR151_ADDR(x) + 0x8U)
#define HW_CCM_CCGR151_TOG_ADDR(x) (HW_CCM_CCGR151_ADDR(x) + 0xCU)

#define HW_CCM_CCGR151(x)        (*(__IO hw_ccm_ccgr151_t *) HW_CCM_CCGR151_ADDR(x))
#define HW_CCM_CCGR151_RD(x)     (HW_CCM_CCGR151(x).U)
#define HW_CCM_CCGR151_WR(x, v)  (HW_CCM_CCGR151(x).U = (v))
#define HW_CCM_CCGR151_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR151_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR151_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR151_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR151_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR151_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR151 bitfields
 */

/*!
 * @name Register CCM_CCGR151, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR151_SETTING0 (0U)       /*!< Bit position for CCM_CCGR151_SETTING0. */
#define BM_CCM_CCGR151_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR151_SETTING0. */
#define BS_CCM_CCGR151_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR151_SETTING0. */

/*! @brief Read current value of the CCM_CCGR151_SETTING0 field. */
#define BR_CCM_CCGR151_SETTING0(x) (HW_CCM_CCGR151(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR151_SETTING0. */
#define BF_CCM_CCGR151_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR151_SETTING0) & BM_CCM_CCGR151_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR151_SETTING0(x, v) (HW_CCM_CCGR151_WR(x, (HW_CCM_CCGR151_RD(x) & ~BM_CCM_CCGR151_SETTING0) | BF_CCM_CCGR151_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR151, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR151_SETTING1 (4U)       /*!< Bit position for CCM_CCGR151_SETTING1. */
#define BM_CCM_CCGR151_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR151_SETTING1. */
#define BS_CCM_CCGR151_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR151_SETTING1. */

/*! @brief Read current value of the CCM_CCGR151_SETTING1 field. */
#define BR_CCM_CCGR151_SETTING1(x) (HW_CCM_CCGR151(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR151_SETTING1. */
#define BF_CCM_CCGR151_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR151_SETTING1) & BM_CCM_CCGR151_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR151_SETTING1(x, v) (HW_CCM_CCGR151_WR(x, (HW_CCM_CCGR151_RD(x) & ~BM_CCM_CCGR151_SETTING1) | BF_CCM_CCGR151_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR151, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR151_SETTING2 (8U)       /*!< Bit position for CCM_CCGR151_SETTING2. */
#define BM_CCM_CCGR151_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR151_SETTING2. */
#define BS_CCM_CCGR151_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR151_SETTING2. */

/*! @brief Read current value of the CCM_CCGR151_SETTING2 field. */
#define BR_CCM_CCGR151_SETTING2(x) (HW_CCM_CCGR151(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR151_SETTING2. */
#define BF_CCM_CCGR151_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR151_SETTING2) & BM_CCM_CCGR151_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR151_SETTING2(x, v) (HW_CCM_CCGR151_WR(x, (HW_CCM_CCGR151_RD(x) & ~BM_CCM_CCGR151_SETTING2) | BF_CCM_CCGR151_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR151, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR151_SETTING3 (12U)      /*!< Bit position for CCM_CCGR151_SETTING3. */
#define BM_CCM_CCGR151_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR151_SETTING3. */
#define BS_CCM_CCGR151_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR151_SETTING3. */

/*! @brief Read current value of the CCM_CCGR151_SETTING3 field. */
#define BR_CCM_CCGR151_SETTING3(x) (HW_CCM_CCGR151(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR151_SETTING3. */
#define BF_CCM_CCGR151_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR151_SETTING3) & BM_CCM_CCGR151_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR151_SETTING3(x, v) (HW_CCM_CCGR151_WR(x, (HW_CCM_CCGR151_RD(x) & ~BM_CCM_CCGR151_SETTING3) | BF_CCM_CCGR151_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR152 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR152 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr152
{
    uint32_t U;
    struct _hw_ccm_ccgr152_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr152_t;

/*!
 * @name Constants and macros for entire CCM_CCGR152 register
 */
/*@{*/
#define HW_CCM_CCGR152_ADDR(x)   ((uintptr_t)(x) + 0x4980U)
#define HW_CCM_CCGR152_SET_ADDR(x) (HW_CCM_CCGR152_ADDR(x) + 0x4U)
#define HW_CCM_CCGR152_CLR_ADDR(x) (HW_CCM_CCGR152_ADDR(x) + 0x8U)
#define HW_CCM_CCGR152_TOG_ADDR(x) (HW_CCM_CCGR152_ADDR(x) + 0xCU)

#define HW_CCM_CCGR152(x)        (*(__IO hw_ccm_ccgr152_t *) HW_CCM_CCGR152_ADDR(x))
#define HW_CCM_CCGR152_RD(x)     (HW_CCM_CCGR152(x).U)
#define HW_CCM_CCGR152_WR(x, v)  (HW_CCM_CCGR152(x).U = (v))
#define HW_CCM_CCGR152_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR152_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR152_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR152_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR152_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR152_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR152 bitfields
 */

/*!
 * @name Register CCM_CCGR152, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR152_SETTING0 (0U)       /*!< Bit position for CCM_CCGR152_SETTING0. */
#define BM_CCM_CCGR152_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR152_SETTING0. */
#define BS_CCM_CCGR152_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR152_SETTING0. */

/*! @brief Read current value of the CCM_CCGR152_SETTING0 field. */
#define BR_CCM_CCGR152_SETTING0(x) (HW_CCM_CCGR152(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR152_SETTING0. */
#define BF_CCM_CCGR152_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR152_SETTING0) & BM_CCM_CCGR152_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR152_SETTING0(x, v) (HW_CCM_CCGR152_WR(x, (HW_CCM_CCGR152_RD(x) & ~BM_CCM_CCGR152_SETTING0) | BF_CCM_CCGR152_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR152, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR152_SETTING1 (4U)       /*!< Bit position for CCM_CCGR152_SETTING1. */
#define BM_CCM_CCGR152_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR152_SETTING1. */
#define BS_CCM_CCGR152_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR152_SETTING1. */

/*! @brief Read current value of the CCM_CCGR152_SETTING1 field. */
#define BR_CCM_CCGR152_SETTING1(x) (HW_CCM_CCGR152(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR152_SETTING1. */
#define BF_CCM_CCGR152_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR152_SETTING1) & BM_CCM_CCGR152_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR152_SETTING1(x, v) (HW_CCM_CCGR152_WR(x, (HW_CCM_CCGR152_RD(x) & ~BM_CCM_CCGR152_SETTING1) | BF_CCM_CCGR152_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR152, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR152_SETTING2 (8U)       /*!< Bit position for CCM_CCGR152_SETTING2. */
#define BM_CCM_CCGR152_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR152_SETTING2. */
#define BS_CCM_CCGR152_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR152_SETTING2. */

/*! @brief Read current value of the CCM_CCGR152_SETTING2 field. */
#define BR_CCM_CCGR152_SETTING2(x) (HW_CCM_CCGR152(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR152_SETTING2. */
#define BF_CCM_CCGR152_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR152_SETTING2) & BM_CCM_CCGR152_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR152_SETTING2(x, v) (HW_CCM_CCGR152_WR(x, (HW_CCM_CCGR152_RD(x) & ~BM_CCM_CCGR152_SETTING2) | BF_CCM_CCGR152_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR152, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR152_SETTING3 (12U)      /*!< Bit position for CCM_CCGR152_SETTING3. */
#define BM_CCM_CCGR152_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR152_SETTING3. */
#define BS_CCM_CCGR152_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR152_SETTING3. */

/*! @brief Read current value of the CCM_CCGR152_SETTING3 field. */
#define BR_CCM_CCGR152_SETTING3(x) (HW_CCM_CCGR152(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR152_SETTING3. */
#define BF_CCM_CCGR152_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR152_SETTING3) & BM_CCM_CCGR152_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR152_SETTING3(x, v) (HW_CCM_CCGR152_WR(x, (HW_CCM_CCGR152_RD(x) & ~BM_CCM_CCGR152_SETTING3) | BF_CCM_CCGR152_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR153 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR153 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr153
{
    uint32_t U;
    struct _hw_ccm_ccgr153_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr153_t;

/*!
 * @name Constants and macros for entire CCM_CCGR153 register
 */
/*@{*/
#define HW_CCM_CCGR153_ADDR(x)   ((uintptr_t)(x) + 0x4990U)
#define HW_CCM_CCGR153_SET_ADDR(x) (HW_CCM_CCGR153_ADDR(x) + 0x4U)
#define HW_CCM_CCGR153_CLR_ADDR(x) (HW_CCM_CCGR153_ADDR(x) + 0x8U)
#define HW_CCM_CCGR153_TOG_ADDR(x) (HW_CCM_CCGR153_ADDR(x) + 0xCU)

#define HW_CCM_CCGR153(x)        (*(__IO hw_ccm_ccgr153_t *) HW_CCM_CCGR153_ADDR(x))
#define HW_CCM_CCGR153_RD(x)     (HW_CCM_CCGR153(x).U)
#define HW_CCM_CCGR153_WR(x, v)  (HW_CCM_CCGR153(x).U = (v))
#define HW_CCM_CCGR153_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR153_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR153_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR153_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR153_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR153_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR153 bitfields
 */

/*!
 * @name Register CCM_CCGR153, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR153_SETTING0 (0U)       /*!< Bit position for CCM_CCGR153_SETTING0. */
#define BM_CCM_CCGR153_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR153_SETTING0. */
#define BS_CCM_CCGR153_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR153_SETTING0. */

/*! @brief Read current value of the CCM_CCGR153_SETTING0 field. */
#define BR_CCM_CCGR153_SETTING0(x) (HW_CCM_CCGR153(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR153_SETTING0. */
#define BF_CCM_CCGR153_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR153_SETTING0) & BM_CCM_CCGR153_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR153_SETTING0(x, v) (HW_CCM_CCGR153_WR(x, (HW_CCM_CCGR153_RD(x) & ~BM_CCM_CCGR153_SETTING0) | BF_CCM_CCGR153_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR153, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR153_SETTING1 (4U)       /*!< Bit position for CCM_CCGR153_SETTING1. */
#define BM_CCM_CCGR153_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR153_SETTING1. */
#define BS_CCM_CCGR153_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR153_SETTING1. */

/*! @brief Read current value of the CCM_CCGR153_SETTING1 field. */
#define BR_CCM_CCGR153_SETTING1(x) (HW_CCM_CCGR153(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR153_SETTING1. */
#define BF_CCM_CCGR153_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR153_SETTING1) & BM_CCM_CCGR153_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR153_SETTING1(x, v) (HW_CCM_CCGR153_WR(x, (HW_CCM_CCGR153_RD(x) & ~BM_CCM_CCGR153_SETTING1) | BF_CCM_CCGR153_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR153, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR153_SETTING2 (8U)       /*!< Bit position for CCM_CCGR153_SETTING2. */
#define BM_CCM_CCGR153_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR153_SETTING2. */
#define BS_CCM_CCGR153_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR153_SETTING2. */

/*! @brief Read current value of the CCM_CCGR153_SETTING2 field. */
#define BR_CCM_CCGR153_SETTING2(x) (HW_CCM_CCGR153(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR153_SETTING2. */
#define BF_CCM_CCGR153_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR153_SETTING2) & BM_CCM_CCGR153_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR153_SETTING2(x, v) (HW_CCM_CCGR153_WR(x, (HW_CCM_CCGR153_RD(x) & ~BM_CCM_CCGR153_SETTING2) | BF_CCM_CCGR153_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR153, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR153_SETTING3 (12U)      /*!< Bit position for CCM_CCGR153_SETTING3. */
#define BM_CCM_CCGR153_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR153_SETTING3. */
#define BS_CCM_CCGR153_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR153_SETTING3. */

/*! @brief Read current value of the CCM_CCGR153_SETTING3 field. */
#define BR_CCM_CCGR153_SETTING3(x) (HW_CCM_CCGR153(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR153_SETTING3. */
#define BF_CCM_CCGR153_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR153_SETTING3) & BM_CCM_CCGR153_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR153_SETTING3(x, v) (HW_CCM_CCGR153_WR(x, (HW_CCM_CCGR153_RD(x) & ~BM_CCM_CCGR153_SETTING3) | BF_CCM_CCGR153_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR154 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR154 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr154
{
    uint32_t U;
    struct _hw_ccm_ccgr154_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr154_t;

/*!
 * @name Constants and macros for entire CCM_CCGR154 register
 */
/*@{*/
#define HW_CCM_CCGR154_ADDR(x)   ((uintptr_t)(x) + 0x49A0U)
#define HW_CCM_CCGR154_SET_ADDR(x) (HW_CCM_CCGR154_ADDR(x) + 0x4U)
#define HW_CCM_CCGR154_CLR_ADDR(x) (HW_CCM_CCGR154_ADDR(x) + 0x8U)
#define HW_CCM_CCGR154_TOG_ADDR(x) (HW_CCM_CCGR154_ADDR(x) + 0xCU)

#define HW_CCM_CCGR154(x)        (*(__IO hw_ccm_ccgr154_t *) HW_CCM_CCGR154_ADDR(x))
#define HW_CCM_CCGR154_RD(x)     (HW_CCM_CCGR154(x).U)
#define HW_CCM_CCGR154_WR(x, v)  (HW_CCM_CCGR154(x).U = (v))
#define HW_CCM_CCGR154_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR154_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR154_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR154_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR154_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR154_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR154 bitfields
 */

/*!
 * @name Register CCM_CCGR154, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR154_SETTING0 (0U)       /*!< Bit position for CCM_CCGR154_SETTING0. */
#define BM_CCM_CCGR154_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR154_SETTING0. */
#define BS_CCM_CCGR154_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR154_SETTING0. */

/*! @brief Read current value of the CCM_CCGR154_SETTING0 field. */
#define BR_CCM_CCGR154_SETTING0(x) (HW_CCM_CCGR154(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR154_SETTING0. */
#define BF_CCM_CCGR154_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR154_SETTING0) & BM_CCM_CCGR154_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR154_SETTING0(x, v) (HW_CCM_CCGR154_WR(x, (HW_CCM_CCGR154_RD(x) & ~BM_CCM_CCGR154_SETTING0) | BF_CCM_CCGR154_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR154, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR154_SETTING1 (4U)       /*!< Bit position for CCM_CCGR154_SETTING1. */
#define BM_CCM_CCGR154_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR154_SETTING1. */
#define BS_CCM_CCGR154_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR154_SETTING1. */

/*! @brief Read current value of the CCM_CCGR154_SETTING1 field. */
#define BR_CCM_CCGR154_SETTING1(x) (HW_CCM_CCGR154(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR154_SETTING1. */
#define BF_CCM_CCGR154_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR154_SETTING1) & BM_CCM_CCGR154_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR154_SETTING1(x, v) (HW_CCM_CCGR154_WR(x, (HW_CCM_CCGR154_RD(x) & ~BM_CCM_CCGR154_SETTING1) | BF_CCM_CCGR154_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR154, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR154_SETTING2 (8U)       /*!< Bit position for CCM_CCGR154_SETTING2. */
#define BM_CCM_CCGR154_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR154_SETTING2. */
#define BS_CCM_CCGR154_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR154_SETTING2. */

/*! @brief Read current value of the CCM_CCGR154_SETTING2 field. */
#define BR_CCM_CCGR154_SETTING2(x) (HW_CCM_CCGR154(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR154_SETTING2. */
#define BF_CCM_CCGR154_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR154_SETTING2) & BM_CCM_CCGR154_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR154_SETTING2(x, v) (HW_CCM_CCGR154_WR(x, (HW_CCM_CCGR154_RD(x) & ~BM_CCM_CCGR154_SETTING2) | BF_CCM_CCGR154_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR154, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR154_SETTING3 (12U)      /*!< Bit position for CCM_CCGR154_SETTING3. */
#define BM_CCM_CCGR154_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR154_SETTING3. */
#define BS_CCM_CCGR154_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR154_SETTING3. */

/*! @brief Read current value of the CCM_CCGR154_SETTING3 field. */
#define BR_CCM_CCGR154_SETTING3(x) (HW_CCM_CCGR154(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR154_SETTING3. */
#define BF_CCM_CCGR154_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR154_SETTING3) & BM_CCM_CCGR154_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR154_SETTING3(x, v) (HW_CCM_CCGR154_WR(x, (HW_CCM_CCGR154_RD(x) & ~BM_CCM_CCGR154_SETTING3) | BF_CCM_CCGR154_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR155 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR155 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr155
{
    uint32_t U;
    struct _hw_ccm_ccgr155_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr155_t;

/*!
 * @name Constants and macros for entire CCM_CCGR155 register
 */
/*@{*/
#define HW_CCM_CCGR155_ADDR(x)   ((uintptr_t)(x) + 0x49B0U)
#define HW_CCM_CCGR155_SET_ADDR(x) (HW_CCM_CCGR155_ADDR(x) + 0x4U)
#define HW_CCM_CCGR155_CLR_ADDR(x) (HW_CCM_CCGR155_ADDR(x) + 0x8U)
#define HW_CCM_CCGR155_TOG_ADDR(x) (HW_CCM_CCGR155_ADDR(x) + 0xCU)

#define HW_CCM_CCGR155(x)        (*(__IO hw_ccm_ccgr155_t *) HW_CCM_CCGR155_ADDR(x))
#define HW_CCM_CCGR155_RD(x)     (HW_CCM_CCGR155(x).U)
#define HW_CCM_CCGR155_WR(x, v)  (HW_CCM_CCGR155(x).U = (v))
#define HW_CCM_CCGR155_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR155_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR155_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR155_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR155_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR155_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR155 bitfields
 */

/*!
 * @name Register CCM_CCGR155, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR155_SETTING0 (0U)       /*!< Bit position for CCM_CCGR155_SETTING0. */
#define BM_CCM_CCGR155_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR155_SETTING0. */
#define BS_CCM_CCGR155_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR155_SETTING0. */

/*! @brief Read current value of the CCM_CCGR155_SETTING0 field. */
#define BR_CCM_CCGR155_SETTING0(x) (HW_CCM_CCGR155(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR155_SETTING0. */
#define BF_CCM_CCGR155_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR155_SETTING0) & BM_CCM_CCGR155_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR155_SETTING0(x, v) (HW_CCM_CCGR155_WR(x, (HW_CCM_CCGR155_RD(x) & ~BM_CCM_CCGR155_SETTING0) | BF_CCM_CCGR155_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR155, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR155_SETTING1 (4U)       /*!< Bit position for CCM_CCGR155_SETTING1. */
#define BM_CCM_CCGR155_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR155_SETTING1. */
#define BS_CCM_CCGR155_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR155_SETTING1. */

/*! @brief Read current value of the CCM_CCGR155_SETTING1 field. */
#define BR_CCM_CCGR155_SETTING1(x) (HW_CCM_CCGR155(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR155_SETTING1. */
#define BF_CCM_CCGR155_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR155_SETTING1) & BM_CCM_CCGR155_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR155_SETTING1(x, v) (HW_CCM_CCGR155_WR(x, (HW_CCM_CCGR155_RD(x) & ~BM_CCM_CCGR155_SETTING1) | BF_CCM_CCGR155_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR155, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR155_SETTING2 (8U)       /*!< Bit position for CCM_CCGR155_SETTING2. */
#define BM_CCM_CCGR155_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR155_SETTING2. */
#define BS_CCM_CCGR155_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR155_SETTING2. */

/*! @brief Read current value of the CCM_CCGR155_SETTING2 field. */
#define BR_CCM_CCGR155_SETTING2(x) (HW_CCM_CCGR155(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR155_SETTING2. */
#define BF_CCM_CCGR155_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR155_SETTING2) & BM_CCM_CCGR155_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR155_SETTING2(x, v) (HW_CCM_CCGR155_WR(x, (HW_CCM_CCGR155_RD(x) & ~BM_CCM_CCGR155_SETTING2) | BF_CCM_CCGR155_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR155, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR155_SETTING3 (12U)      /*!< Bit position for CCM_CCGR155_SETTING3. */
#define BM_CCM_CCGR155_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR155_SETTING3. */
#define BS_CCM_CCGR155_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR155_SETTING3. */

/*! @brief Read current value of the CCM_CCGR155_SETTING3 field. */
#define BR_CCM_CCGR155_SETTING3(x) (HW_CCM_CCGR155(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR155_SETTING3. */
#define BF_CCM_CCGR155_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR155_SETTING3) & BM_CCM_CCGR155_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR155_SETTING3(x, v) (HW_CCM_CCGR155_WR(x, (HW_CCM_CCGR155_RD(x) & ~BM_CCM_CCGR155_SETTING3) | BF_CCM_CCGR155_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR156 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR156 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr156
{
    uint32_t U;
    struct _hw_ccm_ccgr156_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr156_t;

/*!
 * @name Constants and macros for entire CCM_CCGR156 register
 */
/*@{*/
#define HW_CCM_CCGR156_ADDR(x)   ((uintptr_t)(x) + 0x49C0U)
#define HW_CCM_CCGR156_SET_ADDR(x) (HW_CCM_CCGR156_ADDR(x) + 0x4U)
#define HW_CCM_CCGR156_CLR_ADDR(x) (HW_CCM_CCGR156_ADDR(x) + 0x8U)
#define HW_CCM_CCGR156_TOG_ADDR(x) (HW_CCM_CCGR156_ADDR(x) + 0xCU)

#define HW_CCM_CCGR156(x)        (*(__IO hw_ccm_ccgr156_t *) HW_CCM_CCGR156_ADDR(x))
#define HW_CCM_CCGR156_RD(x)     (HW_CCM_CCGR156(x).U)
#define HW_CCM_CCGR156_WR(x, v)  (HW_CCM_CCGR156(x).U = (v))
#define HW_CCM_CCGR156_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR156_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR156_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR156_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR156_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR156_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR156 bitfields
 */

/*!
 * @name Register CCM_CCGR156, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR156_SETTING0 (0U)       /*!< Bit position for CCM_CCGR156_SETTING0. */
#define BM_CCM_CCGR156_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR156_SETTING0. */
#define BS_CCM_CCGR156_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR156_SETTING0. */

/*! @brief Read current value of the CCM_CCGR156_SETTING0 field. */
#define BR_CCM_CCGR156_SETTING0(x) (HW_CCM_CCGR156(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR156_SETTING0. */
#define BF_CCM_CCGR156_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR156_SETTING0) & BM_CCM_CCGR156_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR156_SETTING0(x, v) (HW_CCM_CCGR156_WR(x, (HW_CCM_CCGR156_RD(x) & ~BM_CCM_CCGR156_SETTING0) | BF_CCM_CCGR156_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR156, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR156_SETTING1 (4U)       /*!< Bit position for CCM_CCGR156_SETTING1. */
#define BM_CCM_CCGR156_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR156_SETTING1. */
#define BS_CCM_CCGR156_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR156_SETTING1. */

/*! @brief Read current value of the CCM_CCGR156_SETTING1 field. */
#define BR_CCM_CCGR156_SETTING1(x) (HW_CCM_CCGR156(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR156_SETTING1. */
#define BF_CCM_CCGR156_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR156_SETTING1) & BM_CCM_CCGR156_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR156_SETTING1(x, v) (HW_CCM_CCGR156_WR(x, (HW_CCM_CCGR156_RD(x) & ~BM_CCM_CCGR156_SETTING1) | BF_CCM_CCGR156_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR156, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR156_SETTING2 (8U)       /*!< Bit position for CCM_CCGR156_SETTING2. */
#define BM_CCM_CCGR156_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR156_SETTING2. */
#define BS_CCM_CCGR156_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR156_SETTING2. */

/*! @brief Read current value of the CCM_CCGR156_SETTING2 field. */
#define BR_CCM_CCGR156_SETTING2(x) (HW_CCM_CCGR156(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR156_SETTING2. */
#define BF_CCM_CCGR156_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR156_SETTING2) & BM_CCM_CCGR156_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR156_SETTING2(x, v) (HW_CCM_CCGR156_WR(x, (HW_CCM_CCGR156_RD(x) & ~BM_CCM_CCGR156_SETTING2) | BF_CCM_CCGR156_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR156, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR156_SETTING3 (12U)      /*!< Bit position for CCM_CCGR156_SETTING3. */
#define BM_CCM_CCGR156_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR156_SETTING3. */
#define BS_CCM_CCGR156_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR156_SETTING3. */

/*! @brief Read current value of the CCM_CCGR156_SETTING3 field. */
#define BR_CCM_CCGR156_SETTING3(x) (HW_CCM_CCGR156(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR156_SETTING3. */
#define BF_CCM_CCGR156_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR156_SETTING3) & BM_CCM_CCGR156_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR156_SETTING3(x, v) (HW_CCM_CCGR156_WR(x, (HW_CCM_CCGR156_RD(x) & ~BM_CCM_CCGR156_SETTING3) | BF_CCM_CCGR156_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR157 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR157 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr157
{
    uint32_t U;
    struct _hw_ccm_ccgr157_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr157_t;

/*!
 * @name Constants and macros for entire CCM_CCGR157 register
 */
/*@{*/
#define HW_CCM_CCGR157_ADDR(x)   ((uintptr_t)(x) + 0x49D0U)
#define HW_CCM_CCGR157_SET_ADDR(x) (HW_CCM_CCGR157_ADDR(x) + 0x4U)
#define HW_CCM_CCGR157_CLR_ADDR(x) (HW_CCM_CCGR157_ADDR(x) + 0x8U)
#define HW_CCM_CCGR157_TOG_ADDR(x) (HW_CCM_CCGR157_ADDR(x) + 0xCU)

#define HW_CCM_CCGR157(x)        (*(__IO hw_ccm_ccgr157_t *) HW_CCM_CCGR157_ADDR(x))
#define HW_CCM_CCGR157_RD(x)     (HW_CCM_CCGR157(x).U)
#define HW_CCM_CCGR157_WR(x, v)  (HW_CCM_CCGR157(x).U = (v))
#define HW_CCM_CCGR157_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR157_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR157_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR157_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR157_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR157_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR157 bitfields
 */

/*!
 * @name Register CCM_CCGR157, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR157_SETTING0 (0U)       /*!< Bit position for CCM_CCGR157_SETTING0. */
#define BM_CCM_CCGR157_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR157_SETTING0. */
#define BS_CCM_CCGR157_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR157_SETTING0. */

/*! @brief Read current value of the CCM_CCGR157_SETTING0 field. */
#define BR_CCM_CCGR157_SETTING0(x) (HW_CCM_CCGR157(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR157_SETTING0. */
#define BF_CCM_CCGR157_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR157_SETTING0) & BM_CCM_CCGR157_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR157_SETTING0(x, v) (HW_CCM_CCGR157_WR(x, (HW_CCM_CCGR157_RD(x) & ~BM_CCM_CCGR157_SETTING0) | BF_CCM_CCGR157_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR157, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR157_SETTING1 (4U)       /*!< Bit position for CCM_CCGR157_SETTING1. */
#define BM_CCM_CCGR157_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR157_SETTING1. */
#define BS_CCM_CCGR157_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR157_SETTING1. */

/*! @brief Read current value of the CCM_CCGR157_SETTING1 field. */
#define BR_CCM_CCGR157_SETTING1(x) (HW_CCM_CCGR157(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR157_SETTING1. */
#define BF_CCM_CCGR157_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR157_SETTING1) & BM_CCM_CCGR157_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR157_SETTING1(x, v) (HW_CCM_CCGR157_WR(x, (HW_CCM_CCGR157_RD(x) & ~BM_CCM_CCGR157_SETTING1) | BF_CCM_CCGR157_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR157, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR157_SETTING2 (8U)       /*!< Bit position for CCM_CCGR157_SETTING2. */
#define BM_CCM_CCGR157_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR157_SETTING2. */
#define BS_CCM_CCGR157_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR157_SETTING2. */

/*! @brief Read current value of the CCM_CCGR157_SETTING2 field. */
#define BR_CCM_CCGR157_SETTING2(x) (HW_CCM_CCGR157(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR157_SETTING2. */
#define BF_CCM_CCGR157_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR157_SETTING2) & BM_CCM_CCGR157_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR157_SETTING2(x, v) (HW_CCM_CCGR157_WR(x, (HW_CCM_CCGR157_RD(x) & ~BM_CCM_CCGR157_SETTING2) | BF_CCM_CCGR157_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR157, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR157_SETTING3 (12U)      /*!< Bit position for CCM_CCGR157_SETTING3. */
#define BM_CCM_CCGR157_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR157_SETTING3. */
#define BS_CCM_CCGR157_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR157_SETTING3. */

/*! @brief Read current value of the CCM_CCGR157_SETTING3 field. */
#define BR_CCM_CCGR157_SETTING3(x) (HW_CCM_CCGR157(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR157_SETTING3. */
#define BF_CCM_CCGR157_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR157_SETTING3) & BM_CCM_CCGR157_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR157_SETTING3(x, v) (HW_CCM_CCGR157_WR(x, (HW_CCM_CCGR157_RD(x) & ~BM_CCM_CCGR157_SETTING3) | BF_CCM_CCGR157_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR158 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR158 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr158
{
    uint32_t U;
    struct _hw_ccm_ccgr158_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr158_t;

/*!
 * @name Constants and macros for entire CCM_CCGR158 register
 */
/*@{*/
#define HW_CCM_CCGR158_ADDR(x)   ((uintptr_t)(x) + 0x49E0U)
#define HW_CCM_CCGR158_SET_ADDR(x) (HW_CCM_CCGR158_ADDR(x) + 0x4U)
#define HW_CCM_CCGR158_CLR_ADDR(x) (HW_CCM_CCGR158_ADDR(x) + 0x8U)
#define HW_CCM_CCGR158_TOG_ADDR(x) (HW_CCM_CCGR158_ADDR(x) + 0xCU)

#define HW_CCM_CCGR158(x)        (*(__IO hw_ccm_ccgr158_t *) HW_CCM_CCGR158_ADDR(x))
#define HW_CCM_CCGR158_RD(x)     (HW_CCM_CCGR158(x).U)
#define HW_CCM_CCGR158_WR(x, v)  (HW_CCM_CCGR158(x).U = (v))
#define HW_CCM_CCGR158_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR158_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR158_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR158_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR158_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR158_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR158 bitfields
 */

/*!
 * @name Register CCM_CCGR158, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR158_SETTING0 (0U)       /*!< Bit position for CCM_CCGR158_SETTING0. */
#define BM_CCM_CCGR158_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR158_SETTING0. */
#define BS_CCM_CCGR158_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR158_SETTING0. */

/*! @brief Read current value of the CCM_CCGR158_SETTING0 field. */
#define BR_CCM_CCGR158_SETTING0(x) (HW_CCM_CCGR158(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR158_SETTING0. */
#define BF_CCM_CCGR158_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR158_SETTING0) & BM_CCM_CCGR158_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR158_SETTING0(x, v) (HW_CCM_CCGR158_WR(x, (HW_CCM_CCGR158_RD(x) & ~BM_CCM_CCGR158_SETTING0) | BF_CCM_CCGR158_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR158, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR158_SETTING1 (4U)       /*!< Bit position for CCM_CCGR158_SETTING1. */
#define BM_CCM_CCGR158_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR158_SETTING1. */
#define BS_CCM_CCGR158_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR158_SETTING1. */

/*! @brief Read current value of the CCM_CCGR158_SETTING1 field. */
#define BR_CCM_CCGR158_SETTING1(x) (HW_CCM_CCGR158(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR158_SETTING1. */
#define BF_CCM_CCGR158_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR158_SETTING1) & BM_CCM_CCGR158_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR158_SETTING1(x, v) (HW_CCM_CCGR158_WR(x, (HW_CCM_CCGR158_RD(x) & ~BM_CCM_CCGR158_SETTING1) | BF_CCM_CCGR158_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR158, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR158_SETTING2 (8U)       /*!< Bit position for CCM_CCGR158_SETTING2. */
#define BM_CCM_CCGR158_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR158_SETTING2. */
#define BS_CCM_CCGR158_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR158_SETTING2. */

/*! @brief Read current value of the CCM_CCGR158_SETTING2 field. */
#define BR_CCM_CCGR158_SETTING2(x) (HW_CCM_CCGR158(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR158_SETTING2. */
#define BF_CCM_CCGR158_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR158_SETTING2) & BM_CCM_CCGR158_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR158_SETTING2(x, v) (HW_CCM_CCGR158_WR(x, (HW_CCM_CCGR158_RD(x) & ~BM_CCM_CCGR158_SETTING2) | BF_CCM_CCGR158_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR158, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR158_SETTING3 (12U)      /*!< Bit position for CCM_CCGR158_SETTING3. */
#define BM_CCM_CCGR158_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR158_SETTING3. */
#define BS_CCM_CCGR158_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR158_SETTING3. */

/*! @brief Read current value of the CCM_CCGR158_SETTING3 field. */
#define BR_CCM_CCGR158_SETTING3(x) (HW_CCM_CCGR158(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR158_SETTING3. */
#define BF_CCM_CCGR158_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR158_SETTING3) & BM_CCM_CCGR158_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR158_SETTING3(x, v) (HW_CCM_CCGR158_WR(x, (HW_CCM_CCGR158_RD(x) & ~BM_CCM_CCGR158_SETTING3) | BF_CCM_CCGR158_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR159 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR159 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr159
{
    uint32_t U;
    struct _hw_ccm_ccgr159_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr159_t;

/*!
 * @name Constants and macros for entire CCM_CCGR159 register
 */
/*@{*/
#define HW_CCM_CCGR159_ADDR(x)   ((uintptr_t)(x) + 0x49F0U)
#define HW_CCM_CCGR159_SET_ADDR(x) (HW_CCM_CCGR159_ADDR(x) + 0x4U)
#define HW_CCM_CCGR159_CLR_ADDR(x) (HW_CCM_CCGR159_ADDR(x) + 0x8U)
#define HW_CCM_CCGR159_TOG_ADDR(x) (HW_CCM_CCGR159_ADDR(x) + 0xCU)

#define HW_CCM_CCGR159(x)        (*(__IO hw_ccm_ccgr159_t *) HW_CCM_CCGR159_ADDR(x))
#define HW_CCM_CCGR159_RD(x)     (HW_CCM_CCGR159(x).U)
#define HW_CCM_CCGR159_WR(x, v)  (HW_CCM_CCGR159(x).U = (v))
#define HW_CCM_CCGR159_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR159_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR159_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR159_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR159_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR159_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR159 bitfields
 */

/*!
 * @name Register CCM_CCGR159, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR159_SETTING0 (0U)       /*!< Bit position for CCM_CCGR159_SETTING0. */
#define BM_CCM_CCGR159_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR159_SETTING0. */
#define BS_CCM_CCGR159_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR159_SETTING0. */

/*! @brief Read current value of the CCM_CCGR159_SETTING0 field. */
#define BR_CCM_CCGR159_SETTING0(x) (HW_CCM_CCGR159(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR159_SETTING0. */
#define BF_CCM_CCGR159_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR159_SETTING0) & BM_CCM_CCGR159_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR159_SETTING0(x, v) (HW_CCM_CCGR159_WR(x, (HW_CCM_CCGR159_RD(x) & ~BM_CCM_CCGR159_SETTING0) | BF_CCM_CCGR159_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR159, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR159_SETTING1 (4U)       /*!< Bit position for CCM_CCGR159_SETTING1. */
#define BM_CCM_CCGR159_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR159_SETTING1. */
#define BS_CCM_CCGR159_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR159_SETTING1. */

/*! @brief Read current value of the CCM_CCGR159_SETTING1 field. */
#define BR_CCM_CCGR159_SETTING1(x) (HW_CCM_CCGR159(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR159_SETTING1. */
#define BF_CCM_CCGR159_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR159_SETTING1) & BM_CCM_CCGR159_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR159_SETTING1(x, v) (HW_CCM_CCGR159_WR(x, (HW_CCM_CCGR159_RD(x) & ~BM_CCM_CCGR159_SETTING1) | BF_CCM_CCGR159_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR159, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR159_SETTING2 (8U)       /*!< Bit position for CCM_CCGR159_SETTING2. */
#define BM_CCM_CCGR159_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR159_SETTING2. */
#define BS_CCM_CCGR159_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR159_SETTING2. */

/*! @brief Read current value of the CCM_CCGR159_SETTING2 field. */
#define BR_CCM_CCGR159_SETTING2(x) (HW_CCM_CCGR159(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR159_SETTING2. */
#define BF_CCM_CCGR159_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR159_SETTING2) & BM_CCM_CCGR159_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR159_SETTING2(x, v) (HW_CCM_CCGR159_WR(x, (HW_CCM_CCGR159_RD(x) & ~BM_CCM_CCGR159_SETTING2) | BF_CCM_CCGR159_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR159, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR159_SETTING3 (12U)      /*!< Bit position for CCM_CCGR159_SETTING3. */
#define BM_CCM_CCGR159_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR159_SETTING3. */
#define BS_CCM_CCGR159_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR159_SETTING3. */

/*! @brief Read current value of the CCM_CCGR159_SETTING3 field. */
#define BR_CCM_CCGR159_SETTING3(x) (HW_CCM_CCGR159(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR159_SETTING3. */
#define BF_CCM_CCGR159_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR159_SETTING3) & BM_CCM_CCGR159_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR159_SETTING3(x, v) (HW_CCM_CCGR159_WR(x, (HW_CCM_CCGR159_RD(x) & ~BM_CCM_CCGR159_SETTING3) | BF_CCM_CCGR159_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR160 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR160 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr160
{
    uint32_t U;
    struct _hw_ccm_ccgr160_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr160_t;

/*!
 * @name Constants and macros for entire CCM_CCGR160 register
 */
/*@{*/
#define HW_CCM_CCGR160_ADDR(x)   ((uintptr_t)(x) + 0x4A00U)
#define HW_CCM_CCGR160_SET_ADDR(x) (HW_CCM_CCGR160_ADDR(x) + 0x4U)
#define HW_CCM_CCGR160_CLR_ADDR(x) (HW_CCM_CCGR160_ADDR(x) + 0x8U)
#define HW_CCM_CCGR160_TOG_ADDR(x) (HW_CCM_CCGR160_ADDR(x) + 0xCU)

#define HW_CCM_CCGR160(x)        (*(__IO hw_ccm_ccgr160_t *) HW_CCM_CCGR160_ADDR(x))
#define HW_CCM_CCGR160_RD(x)     (HW_CCM_CCGR160(x).U)
#define HW_CCM_CCGR160_WR(x, v)  (HW_CCM_CCGR160(x).U = (v))
#define HW_CCM_CCGR160_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR160_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR160_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR160_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR160_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR160_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR160 bitfields
 */

/*!
 * @name Register CCM_CCGR160, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR160_SETTING0 (0U)       /*!< Bit position for CCM_CCGR160_SETTING0. */
#define BM_CCM_CCGR160_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR160_SETTING0. */
#define BS_CCM_CCGR160_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR160_SETTING0. */

/*! @brief Read current value of the CCM_CCGR160_SETTING0 field. */
#define BR_CCM_CCGR160_SETTING0(x) (HW_CCM_CCGR160(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR160_SETTING0. */
#define BF_CCM_CCGR160_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR160_SETTING0) & BM_CCM_CCGR160_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR160_SETTING0(x, v) (HW_CCM_CCGR160_WR(x, (HW_CCM_CCGR160_RD(x) & ~BM_CCM_CCGR160_SETTING0) | BF_CCM_CCGR160_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR160, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR160_SETTING1 (4U)       /*!< Bit position for CCM_CCGR160_SETTING1. */
#define BM_CCM_CCGR160_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR160_SETTING1. */
#define BS_CCM_CCGR160_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR160_SETTING1. */

/*! @brief Read current value of the CCM_CCGR160_SETTING1 field. */
#define BR_CCM_CCGR160_SETTING1(x) (HW_CCM_CCGR160(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR160_SETTING1. */
#define BF_CCM_CCGR160_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR160_SETTING1) & BM_CCM_CCGR160_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR160_SETTING1(x, v) (HW_CCM_CCGR160_WR(x, (HW_CCM_CCGR160_RD(x) & ~BM_CCM_CCGR160_SETTING1) | BF_CCM_CCGR160_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR160, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR160_SETTING2 (8U)       /*!< Bit position for CCM_CCGR160_SETTING2. */
#define BM_CCM_CCGR160_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR160_SETTING2. */
#define BS_CCM_CCGR160_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR160_SETTING2. */

/*! @brief Read current value of the CCM_CCGR160_SETTING2 field. */
#define BR_CCM_CCGR160_SETTING2(x) (HW_CCM_CCGR160(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR160_SETTING2. */
#define BF_CCM_CCGR160_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR160_SETTING2) & BM_CCM_CCGR160_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR160_SETTING2(x, v) (HW_CCM_CCGR160_WR(x, (HW_CCM_CCGR160_RD(x) & ~BM_CCM_CCGR160_SETTING2) | BF_CCM_CCGR160_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR160, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR160_SETTING3 (12U)      /*!< Bit position for CCM_CCGR160_SETTING3. */
#define BM_CCM_CCGR160_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR160_SETTING3. */
#define BS_CCM_CCGR160_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR160_SETTING3. */

/*! @brief Read current value of the CCM_CCGR160_SETTING3 field. */
#define BR_CCM_CCGR160_SETTING3(x) (HW_CCM_CCGR160(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR160_SETTING3. */
#define BF_CCM_CCGR160_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR160_SETTING3) & BM_CCM_CCGR160_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR160_SETTING3(x, v) (HW_CCM_CCGR160_WR(x, (HW_CCM_CCGR160_RD(x) & ~BM_CCM_CCGR160_SETTING3) | BF_CCM_CCGR160_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR161 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR161 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr161
{
    uint32_t U;
    struct _hw_ccm_ccgr161_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr161_t;

/*!
 * @name Constants and macros for entire CCM_CCGR161 register
 */
/*@{*/
#define HW_CCM_CCGR161_ADDR(x)   ((uintptr_t)(x) + 0x4A10U)
#define HW_CCM_CCGR161_SET_ADDR(x) (HW_CCM_CCGR161_ADDR(x) + 0x4U)
#define HW_CCM_CCGR161_CLR_ADDR(x) (HW_CCM_CCGR161_ADDR(x) + 0x8U)
#define HW_CCM_CCGR161_TOG_ADDR(x) (HW_CCM_CCGR161_ADDR(x) + 0xCU)

#define HW_CCM_CCGR161(x)        (*(__IO hw_ccm_ccgr161_t *) HW_CCM_CCGR161_ADDR(x))
#define HW_CCM_CCGR161_RD(x)     (HW_CCM_CCGR161(x).U)
#define HW_CCM_CCGR161_WR(x, v)  (HW_CCM_CCGR161(x).U = (v))
#define HW_CCM_CCGR161_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR161_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR161_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR161_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR161_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR161_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR161 bitfields
 */

/*!
 * @name Register CCM_CCGR161, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR161_SETTING0 (0U)       /*!< Bit position for CCM_CCGR161_SETTING0. */
#define BM_CCM_CCGR161_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR161_SETTING0. */
#define BS_CCM_CCGR161_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR161_SETTING0. */

/*! @brief Read current value of the CCM_CCGR161_SETTING0 field. */
#define BR_CCM_CCGR161_SETTING0(x) (HW_CCM_CCGR161(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR161_SETTING0. */
#define BF_CCM_CCGR161_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR161_SETTING0) & BM_CCM_CCGR161_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR161_SETTING0(x, v) (HW_CCM_CCGR161_WR(x, (HW_CCM_CCGR161_RD(x) & ~BM_CCM_CCGR161_SETTING0) | BF_CCM_CCGR161_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR161, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR161_SETTING1 (4U)       /*!< Bit position for CCM_CCGR161_SETTING1. */
#define BM_CCM_CCGR161_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR161_SETTING1. */
#define BS_CCM_CCGR161_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR161_SETTING1. */

/*! @brief Read current value of the CCM_CCGR161_SETTING1 field. */
#define BR_CCM_CCGR161_SETTING1(x) (HW_CCM_CCGR161(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR161_SETTING1. */
#define BF_CCM_CCGR161_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR161_SETTING1) & BM_CCM_CCGR161_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR161_SETTING1(x, v) (HW_CCM_CCGR161_WR(x, (HW_CCM_CCGR161_RD(x) & ~BM_CCM_CCGR161_SETTING1) | BF_CCM_CCGR161_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR161, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR161_SETTING2 (8U)       /*!< Bit position for CCM_CCGR161_SETTING2. */
#define BM_CCM_CCGR161_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR161_SETTING2. */
#define BS_CCM_CCGR161_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR161_SETTING2. */

/*! @brief Read current value of the CCM_CCGR161_SETTING2 field. */
#define BR_CCM_CCGR161_SETTING2(x) (HW_CCM_CCGR161(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR161_SETTING2. */
#define BF_CCM_CCGR161_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR161_SETTING2) & BM_CCM_CCGR161_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR161_SETTING2(x, v) (HW_CCM_CCGR161_WR(x, (HW_CCM_CCGR161_RD(x) & ~BM_CCM_CCGR161_SETTING2) | BF_CCM_CCGR161_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR161, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR161_SETTING3 (12U)      /*!< Bit position for CCM_CCGR161_SETTING3. */
#define BM_CCM_CCGR161_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR161_SETTING3. */
#define BS_CCM_CCGR161_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR161_SETTING3. */

/*! @brief Read current value of the CCM_CCGR161_SETTING3 field. */
#define BR_CCM_CCGR161_SETTING3(x) (HW_CCM_CCGR161(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR161_SETTING3. */
#define BF_CCM_CCGR161_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR161_SETTING3) & BM_CCM_CCGR161_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR161_SETTING3(x, v) (HW_CCM_CCGR161_WR(x, (HW_CCM_CCGR161_RD(x) & ~BM_CCM_CCGR161_SETTING3) | BF_CCM_CCGR161_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR162 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR162 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr162
{
    uint32_t U;
    struct _hw_ccm_ccgr162_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr162_t;

/*!
 * @name Constants and macros for entire CCM_CCGR162 register
 */
/*@{*/
#define HW_CCM_CCGR162_ADDR(x)   ((uintptr_t)(x) + 0x4A20U)
#define HW_CCM_CCGR162_SET_ADDR(x) (HW_CCM_CCGR162_ADDR(x) + 0x4U)
#define HW_CCM_CCGR162_CLR_ADDR(x) (HW_CCM_CCGR162_ADDR(x) + 0x8U)
#define HW_CCM_CCGR162_TOG_ADDR(x) (HW_CCM_CCGR162_ADDR(x) + 0xCU)

#define HW_CCM_CCGR162(x)        (*(__IO hw_ccm_ccgr162_t *) HW_CCM_CCGR162_ADDR(x))
#define HW_CCM_CCGR162_RD(x)     (HW_CCM_CCGR162(x).U)
#define HW_CCM_CCGR162_WR(x, v)  (HW_CCM_CCGR162(x).U = (v))
#define HW_CCM_CCGR162_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR162_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR162_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR162_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR162_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR162_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR162 bitfields
 */

/*!
 * @name Register CCM_CCGR162, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR162_SETTING0 (0U)       /*!< Bit position for CCM_CCGR162_SETTING0. */
#define BM_CCM_CCGR162_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR162_SETTING0. */
#define BS_CCM_CCGR162_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR162_SETTING0. */

/*! @brief Read current value of the CCM_CCGR162_SETTING0 field. */
#define BR_CCM_CCGR162_SETTING0(x) (HW_CCM_CCGR162(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR162_SETTING0. */
#define BF_CCM_CCGR162_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR162_SETTING0) & BM_CCM_CCGR162_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR162_SETTING0(x, v) (HW_CCM_CCGR162_WR(x, (HW_CCM_CCGR162_RD(x) & ~BM_CCM_CCGR162_SETTING0) | BF_CCM_CCGR162_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR162, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR162_SETTING1 (4U)       /*!< Bit position for CCM_CCGR162_SETTING1. */
#define BM_CCM_CCGR162_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR162_SETTING1. */
#define BS_CCM_CCGR162_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR162_SETTING1. */

/*! @brief Read current value of the CCM_CCGR162_SETTING1 field. */
#define BR_CCM_CCGR162_SETTING1(x) (HW_CCM_CCGR162(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR162_SETTING1. */
#define BF_CCM_CCGR162_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR162_SETTING1) & BM_CCM_CCGR162_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR162_SETTING1(x, v) (HW_CCM_CCGR162_WR(x, (HW_CCM_CCGR162_RD(x) & ~BM_CCM_CCGR162_SETTING1) | BF_CCM_CCGR162_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR162, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR162_SETTING2 (8U)       /*!< Bit position for CCM_CCGR162_SETTING2. */
#define BM_CCM_CCGR162_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR162_SETTING2. */
#define BS_CCM_CCGR162_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR162_SETTING2. */

/*! @brief Read current value of the CCM_CCGR162_SETTING2 field. */
#define BR_CCM_CCGR162_SETTING2(x) (HW_CCM_CCGR162(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR162_SETTING2. */
#define BF_CCM_CCGR162_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR162_SETTING2) & BM_CCM_CCGR162_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR162_SETTING2(x, v) (HW_CCM_CCGR162_WR(x, (HW_CCM_CCGR162_RD(x) & ~BM_CCM_CCGR162_SETTING2) | BF_CCM_CCGR162_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR162, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR162_SETTING3 (12U)      /*!< Bit position for CCM_CCGR162_SETTING3. */
#define BM_CCM_CCGR162_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR162_SETTING3. */
#define BS_CCM_CCGR162_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR162_SETTING3. */

/*! @brief Read current value of the CCM_CCGR162_SETTING3 field. */
#define BR_CCM_CCGR162_SETTING3(x) (HW_CCM_CCGR162(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR162_SETTING3. */
#define BF_CCM_CCGR162_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR162_SETTING3) & BM_CCM_CCGR162_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR162_SETTING3(x, v) (HW_CCM_CCGR162_WR(x, (HW_CCM_CCGR162_RD(x) & ~BM_CCM_CCGR162_SETTING3) | BF_CCM_CCGR162_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR163 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR163 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr163
{
    uint32_t U;
    struct _hw_ccm_ccgr163_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr163_t;

/*!
 * @name Constants and macros for entire CCM_CCGR163 register
 */
/*@{*/
#define HW_CCM_CCGR163_ADDR(x)   ((uintptr_t)(x) + 0x4A30U)
#define HW_CCM_CCGR163_SET_ADDR(x) (HW_CCM_CCGR163_ADDR(x) + 0x4U)
#define HW_CCM_CCGR163_CLR_ADDR(x) (HW_CCM_CCGR163_ADDR(x) + 0x8U)
#define HW_CCM_CCGR163_TOG_ADDR(x) (HW_CCM_CCGR163_ADDR(x) + 0xCU)

#define HW_CCM_CCGR163(x)        (*(__IO hw_ccm_ccgr163_t *) HW_CCM_CCGR163_ADDR(x))
#define HW_CCM_CCGR163_RD(x)     (HW_CCM_CCGR163(x).U)
#define HW_CCM_CCGR163_WR(x, v)  (HW_CCM_CCGR163(x).U = (v))
#define HW_CCM_CCGR163_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR163_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR163_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR163_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR163_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR163_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR163 bitfields
 */

/*!
 * @name Register CCM_CCGR163, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR163_SETTING0 (0U)       /*!< Bit position for CCM_CCGR163_SETTING0. */
#define BM_CCM_CCGR163_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR163_SETTING0. */
#define BS_CCM_CCGR163_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR163_SETTING0. */

/*! @brief Read current value of the CCM_CCGR163_SETTING0 field. */
#define BR_CCM_CCGR163_SETTING0(x) (HW_CCM_CCGR163(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR163_SETTING0. */
#define BF_CCM_CCGR163_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR163_SETTING0) & BM_CCM_CCGR163_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR163_SETTING0(x, v) (HW_CCM_CCGR163_WR(x, (HW_CCM_CCGR163_RD(x) & ~BM_CCM_CCGR163_SETTING0) | BF_CCM_CCGR163_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR163, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR163_SETTING1 (4U)       /*!< Bit position for CCM_CCGR163_SETTING1. */
#define BM_CCM_CCGR163_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR163_SETTING1. */
#define BS_CCM_CCGR163_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR163_SETTING1. */

/*! @brief Read current value of the CCM_CCGR163_SETTING1 field. */
#define BR_CCM_CCGR163_SETTING1(x) (HW_CCM_CCGR163(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR163_SETTING1. */
#define BF_CCM_CCGR163_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR163_SETTING1) & BM_CCM_CCGR163_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR163_SETTING1(x, v) (HW_CCM_CCGR163_WR(x, (HW_CCM_CCGR163_RD(x) & ~BM_CCM_CCGR163_SETTING1) | BF_CCM_CCGR163_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR163, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR163_SETTING2 (8U)       /*!< Bit position for CCM_CCGR163_SETTING2. */
#define BM_CCM_CCGR163_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR163_SETTING2. */
#define BS_CCM_CCGR163_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR163_SETTING2. */

/*! @brief Read current value of the CCM_CCGR163_SETTING2 field. */
#define BR_CCM_CCGR163_SETTING2(x) (HW_CCM_CCGR163(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR163_SETTING2. */
#define BF_CCM_CCGR163_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR163_SETTING2) & BM_CCM_CCGR163_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR163_SETTING2(x, v) (HW_CCM_CCGR163_WR(x, (HW_CCM_CCGR163_RD(x) & ~BM_CCM_CCGR163_SETTING2) | BF_CCM_CCGR163_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR163, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR163_SETTING3 (12U)      /*!< Bit position for CCM_CCGR163_SETTING3. */
#define BM_CCM_CCGR163_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR163_SETTING3. */
#define BS_CCM_CCGR163_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR163_SETTING3. */

/*! @brief Read current value of the CCM_CCGR163_SETTING3 field. */
#define BR_CCM_CCGR163_SETTING3(x) (HW_CCM_CCGR163(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR163_SETTING3. */
#define BF_CCM_CCGR163_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR163_SETTING3) & BM_CCM_CCGR163_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR163_SETTING3(x, v) (HW_CCM_CCGR163_WR(x, (HW_CCM_CCGR163_RD(x) & ~BM_CCM_CCGR163_SETTING3) | BF_CCM_CCGR163_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR164 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR164 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr164
{
    uint32_t U;
    struct _hw_ccm_ccgr164_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr164_t;

/*!
 * @name Constants and macros for entire CCM_CCGR164 register
 */
/*@{*/
#define HW_CCM_CCGR164_ADDR(x)   ((uintptr_t)(x) + 0x4A40U)
#define HW_CCM_CCGR164_SET_ADDR(x) (HW_CCM_CCGR164_ADDR(x) + 0x4U)
#define HW_CCM_CCGR164_CLR_ADDR(x) (HW_CCM_CCGR164_ADDR(x) + 0x8U)
#define HW_CCM_CCGR164_TOG_ADDR(x) (HW_CCM_CCGR164_ADDR(x) + 0xCU)

#define HW_CCM_CCGR164(x)        (*(__IO hw_ccm_ccgr164_t *) HW_CCM_CCGR164_ADDR(x))
#define HW_CCM_CCGR164_RD(x)     (HW_CCM_CCGR164(x).U)
#define HW_CCM_CCGR164_WR(x, v)  (HW_CCM_CCGR164(x).U = (v))
#define HW_CCM_CCGR164_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR164_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR164_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR164_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR164_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR164_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR164 bitfields
 */

/*!
 * @name Register CCM_CCGR164, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR164_SETTING0 (0U)       /*!< Bit position for CCM_CCGR164_SETTING0. */
#define BM_CCM_CCGR164_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR164_SETTING0. */
#define BS_CCM_CCGR164_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR164_SETTING0. */

/*! @brief Read current value of the CCM_CCGR164_SETTING0 field. */
#define BR_CCM_CCGR164_SETTING0(x) (HW_CCM_CCGR164(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR164_SETTING0. */
#define BF_CCM_CCGR164_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR164_SETTING0) & BM_CCM_CCGR164_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR164_SETTING0(x, v) (HW_CCM_CCGR164_WR(x, (HW_CCM_CCGR164_RD(x) & ~BM_CCM_CCGR164_SETTING0) | BF_CCM_CCGR164_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR164, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR164_SETTING1 (4U)       /*!< Bit position for CCM_CCGR164_SETTING1. */
#define BM_CCM_CCGR164_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR164_SETTING1. */
#define BS_CCM_CCGR164_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR164_SETTING1. */

/*! @brief Read current value of the CCM_CCGR164_SETTING1 field. */
#define BR_CCM_CCGR164_SETTING1(x) (HW_CCM_CCGR164(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR164_SETTING1. */
#define BF_CCM_CCGR164_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR164_SETTING1) & BM_CCM_CCGR164_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR164_SETTING1(x, v) (HW_CCM_CCGR164_WR(x, (HW_CCM_CCGR164_RD(x) & ~BM_CCM_CCGR164_SETTING1) | BF_CCM_CCGR164_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR164, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR164_SETTING2 (8U)       /*!< Bit position for CCM_CCGR164_SETTING2. */
#define BM_CCM_CCGR164_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR164_SETTING2. */
#define BS_CCM_CCGR164_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR164_SETTING2. */

/*! @brief Read current value of the CCM_CCGR164_SETTING2 field. */
#define BR_CCM_CCGR164_SETTING2(x) (HW_CCM_CCGR164(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR164_SETTING2. */
#define BF_CCM_CCGR164_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR164_SETTING2) & BM_CCM_CCGR164_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR164_SETTING2(x, v) (HW_CCM_CCGR164_WR(x, (HW_CCM_CCGR164_RD(x) & ~BM_CCM_CCGR164_SETTING2) | BF_CCM_CCGR164_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR164, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR164_SETTING3 (12U)      /*!< Bit position for CCM_CCGR164_SETTING3. */
#define BM_CCM_CCGR164_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR164_SETTING3. */
#define BS_CCM_CCGR164_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR164_SETTING3. */

/*! @brief Read current value of the CCM_CCGR164_SETTING3 field. */
#define BR_CCM_CCGR164_SETTING3(x) (HW_CCM_CCGR164(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR164_SETTING3. */
#define BF_CCM_CCGR164_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR164_SETTING3) & BM_CCM_CCGR164_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR164_SETTING3(x, v) (HW_CCM_CCGR164_WR(x, (HW_CCM_CCGR164_RD(x) & ~BM_CCM_CCGR164_SETTING3) | BF_CCM_CCGR164_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR165 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR165 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr165
{
    uint32_t U;
    struct _hw_ccm_ccgr165_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr165_t;

/*!
 * @name Constants and macros for entire CCM_CCGR165 register
 */
/*@{*/
#define HW_CCM_CCGR165_ADDR(x)   ((uintptr_t)(x) + 0x4A50U)
#define HW_CCM_CCGR165_SET_ADDR(x) (HW_CCM_CCGR165_ADDR(x) + 0x4U)
#define HW_CCM_CCGR165_CLR_ADDR(x) (HW_CCM_CCGR165_ADDR(x) + 0x8U)
#define HW_CCM_CCGR165_TOG_ADDR(x) (HW_CCM_CCGR165_ADDR(x) + 0xCU)

#define HW_CCM_CCGR165(x)        (*(__IO hw_ccm_ccgr165_t *) HW_CCM_CCGR165_ADDR(x))
#define HW_CCM_CCGR165_RD(x)     (HW_CCM_CCGR165(x).U)
#define HW_CCM_CCGR165_WR(x, v)  (HW_CCM_CCGR165(x).U = (v))
#define HW_CCM_CCGR165_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR165_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR165_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR165_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR165_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR165_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR165 bitfields
 */

/*!
 * @name Register CCM_CCGR165, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR165_SETTING0 (0U)       /*!< Bit position for CCM_CCGR165_SETTING0. */
#define BM_CCM_CCGR165_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR165_SETTING0. */
#define BS_CCM_CCGR165_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR165_SETTING0. */

/*! @brief Read current value of the CCM_CCGR165_SETTING0 field. */
#define BR_CCM_CCGR165_SETTING0(x) (HW_CCM_CCGR165(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR165_SETTING0. */
#define BF_CCM_CCGR165_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR165_SETTING0) & BM_CCM_CCGR165_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR165_SETTING0(x, v) (HW_CCM_CCGR165_WR(x, (HW_CCM_CCGR165_RD(x) & ~BM_CCM_CCGR165_SETTING0) | BF_CCM_CCGR165_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR165, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR165_SETTING1 (4U)       /*!< Bit position for CCM_CCGR165_SETTING1. */
#define BM_CCM_CCGR165_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR165_SETTING1. */
#define BS_CCM_CCGR165_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR165_SETTING1. */

/*! @brief Read current value of the CCM_CCGR165_SETTING1 field. */
#define BR_CCM_CCGR165_SETTING1(x) (HW_CCM_CCGR165(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR165_SETTING1. */
#define BF_CCM_CCGR165_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR165_SETTING1) & BM_CCM_CCGR165_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR165_SETTING1(x, v) (HW_CCM_CCGR165_WR(x, (HW_CCM_CCGR165_RD(x) & ~BM_CCM_CCGR165_SETTING1) | BF_CCM_CCGR165_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR165, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR165_SETTING2 (8U)       /*!< Bit position for CCM_CCGR165_SETTING2. */
#define BM_CCM_CCGR165_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR165_SETTING2. */
#define BS_CCM_CCGR165_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR165_SETTING2. */

/*! @brief Read current value of the CCM_CCGR165_SETTING2 field. */
#define BR_CCM_CCGR165_SETTING2(x) (HW_CCM_CCGR165(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR165_SETTING2. */
#define BF_CCM_CCGR165_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR165_SETTING2) & BM_CCM_CCGR165_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR165_SETTING2(x, v) (HW_CCM_CCGR165_WR(x, (HW_CCM_CCGR165_RD(x) & ~BM_CCM_CCGR165_SETTING2) | BF_CCM_CCGR165_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR165, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR165_SETTING3 (12U)      /*!< Bit position for CCM_CCGR165_SETTING3. */
#define BM_CCM_CCGR165_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR165_SETTING3. */
#define BS_CCM_CCGR165_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR165_SETTING3. */

/*! @brief Read current value of the CCM_CCGR165_SETTING3 field. */
#define BR_CCM_CCGR165_SETTING3(x) (HW_CCM_CCGR165(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR165_SETTING3. */
#define BF_CCM_CCGR165_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR165_SETTING3) & BM_CCM_CCGR165_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR165_SETTING3(x, v) (HW_CCM_CCGR165_WR(x, (HW_CCM_CCGR165_RD(x) & ~BM_CCM_CCGR165_SETTING3) | BF_CCM_CCGR165_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR166 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR166 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr166
{
    uint32_t U;
    struct _hw_ccm_ccgr166_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr166_t;

/*!
 * @name Constants and macros for entire CCM_CCGR166 register
 */
/*@{*/
#define HW_CCM_CCGR166_ADDR(x)   ((uintptr_t)(x) + 0x4A60U)
#define HW_CCM_CCGR166_SET_ADDR(x) (HW_CCM_CCGR166_ADDR(x) + 0x4U)
#define HW_CCM_CCGR166_CLR_ADDR(x) (HW_CCM_CCGR166_ADDR(x) + 0x8U)
#define HW_CCM_CCGR166_TOG_ADDR(x) (HW_CCM_CCGR166_ADDR(x) + 0xCU)

#define HW_CCM_CCGR166(x)        (*(__IO hw_ccm_ccgr166_t *) HW_CCM_CCGR166_ADDR(x))
#define HW_CCM_CCGR166_RD(x)     (HW_CCM_CCGR166(x).U)
#define HW_CCM_CCGR166_WR(x, v)  (HW_CCM_CCGR166(x).U = (v))
#define HW_CCM_CCGR166_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR166_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR166_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR166_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR166_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR166_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR166 bitfields
 */

/*!
 * @name Register CCM_CCGR166, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR166_SETTING0 (0U)       /*!< Bit position for CCM_CCGR166_SETTING0. */
#define BM_CCM_CCGR166_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR166_SETTING0. */
#define BS_CCM_CCGR166_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR166_SETTING0. */

/*! @brief Read current value of the CCM_CCGR166_SETTING0 field. */
#define BR_CCM_CCGR166_SETTING0(x) (HW_CCM_CCGR166(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR166_SETTING0. */
#define BF_CCM_CCGR166_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR166_SETTING0) & BM_CCM_CCGR166_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR166_SETTING0(x, v) (HW_CCM_CCGR166_WR(x, (HW_CCM_CCGR166_RD(x) & ~BM_CCM_CCGR166_SETTING0) | BF_CCM_CCGR166_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR166, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR166_SETTING1 (4U)       /*!< Bit position for CCM_CCGR166_SETTING1. */
#define BM_CCM_CCGR166_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR166_SETTING1. */
#define BS_CCM_CCGR166_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR166_SETTING1. */

/*! @brief Read current value of the CCM_CCGR166_SETTING1 field. */
#define BR_CCM_CCGR166_SETTING1(x) (HW_CCM_CCGR166(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR166_SETTING1. */
#define BF_CCM_CCGR166_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR166_SETTING1) & BM_CCM_CCGR166_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR166_SETTING1(x, v) (HW_CCM_CCGR166_WR(x, (HW_CCM_CCGR166_RD(x) & ~BM_CCM_CCGR166_SETTING1) | BF_CCM_CCGR166_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR166, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR166_SETTING2 (8U)       /*!< Bit position for CCM_CCGR166_SETTING2. */
#define BM_CCM_CCGR166_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR166_SETTING2. */
#define BS_CCM_CCGR166_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR166_SETTING2. */

/*! @brief Read current value of the CCM_CCGR166_SETTING2 field. */
#define BR_CCM_CCGR166_SETTING2(x) (HW_CCM_CCGR166(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR166_SETTING2. */
#define BF_CCM_CCGR166_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR166_SETTING2) & BM_CCM_CCGR166_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR166_SETTING2(x, v) (HW_CCM_CCGR166_WR(x, (HW_CCM_CCGR166_RD(x) & ~BM_CCM_CCGR166_SETTING2) | BF_CCM_CCGR166_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR166, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR166_SETTING3 (12U)      /*!< Bit position for CCM_CCGR166_SETTING3. */
#define BM_CCM_CCGR166_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR166_SETTING3. */
#define BS_CCM_CCGR166_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR166_SETTING3. */

/*! @brief Read current value of the CCM_CCGR166_SETTING3 field. */
#define BR_CCM_CCGR166_SETTING3(x) (HW_CCM_CCGR166(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR166_SETTING3. */
#define BF_CCM_CCGR166_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR166_SETTING3) & BM_CCM_CCGR166_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR166_SETTING3(x, v) (HW_CCM_CCGR166_WR(x, (HW_CCM_CCGR166_RD(x) & ~BM_CCM_CCGR166_SETTING3) | BF_CCM_CCGR166_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR167 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR167 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr167
{
    uint32_t U;
    struct _hw_ccm_ccgr167_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr167_t;

/*!
 * @name Constants and macros for entire CCM_CCGR167 register
 */
/*@{*/
#define HW_CCM_CCGR167_ADDR(x)   ((uintptr_t)(x) + 0x4A70U)
#define HW_CCM_CCGR167_SET_ADDR(x) (HW_CCM_CCGR167_ADDR(x) + 0x4U)
#define HW_CCM_CCGR167_CLR_ADDR(x) (HW_CCM_CCGR167_ADDR(x) + 0x8U)
#define HW_CCM_CCGR167_TOG_ADDR(x) (HW_CCM_CCGR167_ADDR(x) + 0xCU)

#define HW_CCM_CCGR167(x)        (*(__IO hw_ccm_ccgr167_t *) HW_CCM_CCGR167_ADDR(x))
#define HW_CCM_CCGR167_RD(x)     (HW_CCM_CCGR167(x).U)
#define HW_CCM_CCGR167_WR(x, v)  (HW_CCM_CCGR167(x).U = (v))
#define HW_CCM_CCGR167_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR167_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR167_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR167_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR167_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR167_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR167 bitfields
 */

/*!
 * @name Register CCM_CCGR167, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR167_SETTING0 (0U)       /*!< Bit position for CCM_CCGR167_SETTING0. */
#define BM_CCM_CCGR167_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR167_SETTING0. */
#define BS_CCM_CCGR167_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR167_SETTING0. */

/*! @brief Read current value of the CCM_CCGR167_SETTING0 field. */
#define BR_CCM_CCGR167_SETTING0(x) (HW_CCM_CCGR167(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR167_SETTING0. */
#define BF_CCM_CCGR167_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR167_SETTING0) & BM_CCM_CCGR167_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR167_SETTING0(x, v) (HW_CCM_CCGR167_WR(x, (HW_CCM_CCGR167_RD(x) & ~BM_CCM_CCGR167_SETTING0) | BF_CCM_CCGR167_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR167, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR167_SETTING1 (4U)       /*!< Bit position for CCM_CCGR167_SETTING1. */
#define BM_CCM_CCGR167_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR167_SETTING1. */
#define BS_CCM_CCGR167_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR167_SETTING1. */

/*! @brief Read current value of the CCM_CCGR167_SETTING1 field. */
#define BR_CCM_CCGR167_SETTING1(x) (HW_CCM_CCGR167(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR167_SETTING1. */
#define BF_CCM_CCGR167_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR167_SETTING1) & BM_CCM_CCGR167_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR167_SETTING1(x, v) (HW_CCM_CCGR167_WR(x, (HW_CCM_CCGR167_RD(x) & ~BM_CCM_CCGR167_SETTING1) | BF_CCM_CCGR167_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR167, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR167_SETTING2 (8U)       /*!< Bit position for CCM_CCGR167_SETTING2. */
#define BM_CCM_CCGR167_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR167_SETTING2. */
#define BS_CCM_CCGR167_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR167_SETTING2. */

/*! @brief Read current value of the CCM_CCGR167_SETTING2 field. */
#define BR_CCM_CCGR167_SETTING2(x) (HW_CCM_CCGR167(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR167_SETTING2. */
#define BF_CCM_CCGR167_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR167_SETTING2) & BM_CCM_CCGR167_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR167_SETTING2(x, v) (HW_CCM_CCGR167_WR(x, (HW_CCM_CCGR167_RD(x) & ~BM_CCM_CCGR167_SETTING2) | BF_CCM_CCGR167_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR167, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR167_SETTING3 (12U)      /*!< Bit position for CCM_CCGR167_SETTING3. */
#define BM_CCM_CCGR167_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR167_SETTING3. */
#define BS_CCM_CCGR167_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR167_SETTING3. */

/*! @brief Read current value of the CCM_CCGR167_SETTING3 field. */
#define BR_CCM_CCGR167_SETTING3(x) (HW_CCM_CCGR167(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR167_SETTING3. */
#define BF_CCM_CCGR167_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR167_SETTING3) & BM_CCM_CCGR167_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR167_SETTING3(x, v) (HW_CCM_CCGR167_WR(x, (HW_CCM_CCGR167_RD(x) & ~BM_CCM_CCGR167_SETTING3) | BF_CCM_CCGR167_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR168 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR168 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr168
{
    uint32_t U;
    struct _hw_ccm_ccgr168_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr168_t;

/*!
 * @name Constants and macros for entire CCM_CCGR168 register
 */
/*@{*/
#define HW_CCM_CCGR168_ADDR(x)   ((uintptr_t)(x) + 0x4A80U)
#define HW_CCM_CCGR168_SET_ADDR(x) (HW_CCM_CCGR168_ADDR(x) + 0x4U)
#define HW_CCM_CCGR168_CLR_ADDR(x) (HW_CCM_CCGR168_ADDR(x) + 0x8U)
#define HW_CCM_CCGR168_TOG_ADDR(x) (HW_CCM_CCGR168_ADDR(x) + 0xCU)

#define HW_CCM_CCGR168(x)        (*(__IO hw_ccm_ccgr168_t *) HW_CCM_CCGR168_ADDR(x))
#define HW_CCM_CCGR168_RD(x)     (HW_CCM_CCGR168(x).U)
#define HW_CCM_CCGR168_WR(x, v)  (HW_CCM_CCGR168(x).U = (v))
#define HW_CCM_CCGR168_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR168_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR168_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR168_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR168_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR168_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR168 bitfields
 */

/*!
 * @name Register CCM_CCGR168, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR168_SETTING0 (0U)       /*!< Bit position for CCM_CCGR168_SETTING0. */
#define BM_CCM_CCGR168_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR168_SETTING0. */
#define BS_CCM_CCGR168_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR168_SETTING0. */

/*! @brief Read current value of the CCM_CCGR168_SETTING0 field. */
#define BR_CCM_CCGR168_SETTING0(x) (HW_CCM_CCGR168(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR168_SETTING0. */
#define BF_CCM_CCGR168_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR168_SETTING0) & BM_CCM_CCGR168_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR168_SETTING0(x, v) (HW_CCM_CCGR168_WR(x, (HW_CCM_CCGR168_RD(x) & ~BM_CCM_CCGR168_SETTING0) | BF_CCM_CCGR168_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR168, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR168_SETTING1 (4U)       /*!< Bit position for CCM_CCGR168_SETTING1. */
#define BM_CCM_CCGR168_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR168_SETTING1. */
#define BS_CCM_CCGR168_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR168_SETTING1. */

/*! @brief Read current value of the CCM_CCGR168_SETTING1 field. */
#define BR_CCM_CCGR168_SETTING1(x) (HW_CCM_CCGR168(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR168_SETTING1. */
#define BF_CCM_CCGR168_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR168_SETTING1) & BM_CCM_CCGR168_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR168_SETTING1(x, v) (HW_CCM_CCGR168_WR(x, (HW_CCM_CCGR168_RD(x) & ~BM_CCM_CCGR168_SETTING1) | BF_CCM_CCGR168_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR168, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR168_SETTING2 (8U)       /*!< Bit position for CCM_CCGR168_SETTING2. */
#define BM_CCM_CCGR168_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR168_SETTING2. */
#define BS_CCM_CCGR168_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR168_SETTING2. */

/*! @brief Read current value of the CCM_CCGR168_SETTING2 field. */
#define BR_CCM_CCGR168_SETTING2(x) (HW_CCM_CCGR168(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR168_SETTING2. */
#define BF_CCM_CCGR168_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR168_SETTING2) & BM_CCM_CCGR168_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR168_SETTING2(x, v) (HW_CCM_CCGR168_WR(x, (HW_CCM_CCGR168_RD(x) & ~BM_CCM_CCGR168_SETTING2) | BF_CCM_CCGR168_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR168, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR168_SETTING3 (12U)      /*!< Bit position for CCM_CCGR168_SETTING3. */
#define BM_CCM_CCGR168_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR168_SETTING3. */
#define BS_CCM_CCGR168_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR168_SETTING3. */

/*! @brief Read current value of the CCM_CCGR168_SETTING3 field. */
#define BR_CCM_CCGR168_SETTING3(x) (HW_CCM_CCGR168(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR168_SETTING3. */
#define BF_CCM_CCGR168_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR168_SETTING3) & BM_CCM_CCGR168_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR168_SETTING3(x, v) (HW_CCM_CCGR168_WR(x, (HW_CCM_CCGR168_RD(x) & ~BM_CCM_CCGR168_SETTING3) | BF_CCM_CCGR168_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR169 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR169 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr169
{
    uint32_t U;
    struct _hw_ccm_ccgr169_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr169_t;

/*!
 * @name Constants and macros for entire CCM_CCGR169 register
 */
/*@{*/
#define HW_CCM_CCGR169_ADDR(x)   ((uintptr_t)(x) + 0x4A90U)
#define HW_CCM_CCGR169_SET_ADDR(x) (HW_CCM_CCGR169_ADDR(x) + 0x4U)
#define HW_CCM_CCGR169_CLR_ADDR(x) (HW_CCM_CCGR169_ADDR(x) + 0x8U)
#define HW_CCM_CCGR169_TOG_ADDR(x) (HW_CCM_CCGR169_ADDR(x) + 0xCU)

#define HW_CCM_CCGR169(x)        (*(__IO hw_ccm_ccgr169_t *) HW_CCM_CCGR169_ADDR(x))
#define HW_CCM_CCGR169_RD(x)     (HW_CCM_CCGR169(x).U)
#define HW_CCM_CCGR169_WR(x, v)  (HW_CCM_CCGR169(x).U = (v))
#define HW_CCM_CCGR169_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR169_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR169_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR169_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR169_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR169_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR169 bitfields
 */

/*!
 * @name Register CCM_CCGR169, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR169_SETTING0 (0U)       /*!< Bit position for CCM_CCGR169_SETTING0. */
#define BM_CCM_CCGR169_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR169_SETTING0. */
#define BS_CCM_CCGR169_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR169_SETTING0. */

/*! @brief Read current value of the CCM_CCGR169_SETTING0 field. */
#define BR_CCM_CCGR169_SETTING0(x) (HW_CCM_CCGR169(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR169_SETTING0. */
#define BF_CCM_CCGR169_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR169_SETTING0) & BM_CCM_CCGR169_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR169_SETTING0(x, v) (HW_CCM_CCGR169_WR(x, (HW_CCM_CCGR169_RD(x) & ~BM_CCM_CCGR169_SETTING0) | BF_CCM_CCGR169_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR169, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR169_SETTING1 (4U)       /*!< Bit position for CCM_CCGR169_SETTING1. */
#define BM_CCM_CCGR169_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR169_SETTING1. */
#define BS_CCM_CCGR169_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR169_SETTING1. */

/*! @brief Read current value of the CCM_CCGR169_SETTING1 field. */
#define BR_CCM_CCGR169_SETTING1(x) (HW_CCM_CCGR169(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR169_SETTING1. */
#define BF_CCM_CCGR169_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR169_SETTING1) & BM_CCM_CCGR169_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR169_SETTING1(x, v) (HW_CCM_CCGR169_WR(x, (HW_CCM_CCGR169_RD(x) & ~BM_CCM_CCGR169_SETTING1) | BF_CCM_CCGR169_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR169, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR169_SETTING2 (8U)       /*!< Bit position for CCM_CCGR169_SETTING2. */
#define BM_CCM_CCGR169_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR169_SETTING2. */
#define BS_CCM_CCGR169_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR169_SETTING2. */

/*! @brief Read current value of the CCM_CCGR169_SETTING2 field. */
#define BR_CCM_CCGR169_SETTING2(x) (HW_CCM_CCGR169(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR169_SETTING2. */
#define BF_CCM_CCGR169_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR169_SETTING2) & BM_CCM_CCGR169_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR169_SETTING2(x, v) (HW_CCM_CCGR169_WR(x, (HW_CCM_CCGR169_RD(x) & ~BM_CCM_CCGR169_SETTING2) | BF_CCM_CCGR169_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR169, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR169_SETTING3 (12U)      /*!< Bit position for CCM_CCGR169_SETTING3. */
#define BM_CCM_CCGR169_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR169_SETTING3. */
#define BS_CCM_CCGR169_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR169_SETTING3. */

/*! @brief Read current value of the CCM_CCGR169_SETTING3 field. */
#define BR_CCM_CCGR169_SETTING3(x) (HW_CCM_CCGR169(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR169_SETTING3. */
#define BF_CCM_CCGR169_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR169_SETTING3) & BM_CCM_CCGR169_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR169_SETTING3(x, v) (HW_CCM_CCGR169_WR(x, (HW_CCM_CCGR169_RD(x) & ~BM_CCM_CCGR169_SETTING3) | BF_CCM_CCGR169_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR170 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR170 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr170
{
    uint32_t U;
    struct _hw_ccm_ccgr170_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr170_t;

/*!
 * @name Constants and macros for entire CCM_CCGR170 register
 */
/*@{*/
#define HW_CCM_CCGR170_ADDR(x)   ((uintptr_t)(x) + 0x4AA0U)
#define HW_CCM_CCGR170_SET_ADDR(x) (HW_CCM_CCGR170_ADDR(x) + 0x4U)
#define HW_CCM_CCGR170_CLR_ADDR(x) (HW_CCM_CCGR170_ADDR(x) + 0x8U)
#define HW_CCM_CCGR170_TOG_ADDR(x) (HW_CCM_CCGR170_ADDR(x) + 0xCU)

#define HW_CCM_CCGR170(x)        (*(__IO hw_ccm_ccgr170_t *) HW_CCM_CCGR170_ADDR(x))
#define HW_CCM_CCGR170_RD(x)     (HW_CCM_CCGR170(x).U)
#define HW_CCM_CCGR170_WR(x, v)  (HW_CCM_CCGR170(x).U = (v))
#define HW_CCM_CCGR170_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR170_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR170_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR170_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR170_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR170_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR170 bitfields
 */

/*!
 * @name Register CCM_CCGR170, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR170_SETTING0 (0U)       /*!< Bit position for CCM_CCGR170_SETTING0. */
#define BM_CCM_CCGR170_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR170_SETTING0. */
#define BS_CCM_CCGR170_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR170_SETTING0. */

/*! @brief Read current value of the CCM_CCGR170_SETTING0 field. */
#define BR_CCM_CCGR170_SETTING0(x) (HW_CCM_CCGR170(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR170_SETTING0. */
#define BF_CCM_CCGR170_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR170_SETTING0) & BM_CCM_CCGR170_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR170_SETTING0(x, v) (HW_CCM_CCGR170_WR(x, (HW_CCM_CCGR170_RD(x) & ~BM_CCM_CCGR170_SETTING0) | BF_CCM_CCGR170_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR170, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR170_SETTING1 (4U)       /*!< Bit position for CCM_CCGR170_SETTING1. */
#define BM_CCM_CCGR170_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR170_SETTING1. */
#define BS_CCM_CCGR170_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR170_SETTING1. */

/*! @brief Read current value of the CCM_CCGR170_SETTING1 field. */
#define BR_CCM_CCGR170_SETTING1(x) (HW_CCM_CCGR170(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR170_SETTING1. */
#define BF_CCM_CCGR170_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR170_SETTING1) & BM_CCM_CCGR170_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR170_SETTING1(x, v) (HW_CCM_CCGR170_WR(x, (HW_CCM_CCGR170_RD(x) & ~BM_CCM_CCGR170_SETTING1) | BF_CCM_CCGR170_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR170, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR170_SETTING2 (8U)       /*!< Bit position for CCM_CCGR170_SETTING2. */
#define BM_CCM_CCGR170_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR170_SETTING2. */
#define BS_CCM_CCGR170_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR170_SETTING2. */

/*! @brief Read current value of the CCM_CCGR170_SETTING2 field. */
#define BR_CCM_CCGR170_SETTING2(x) (HW_CCM_CCGR170(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR170_SETTING2. */
#define BF_CCM_CCGR170_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR170_SETTING2) & BM_CCM_CCGR170_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR170_SETTING2(x, v) (HW_CCM_CCGR170_WR(x, (HW_CCM_CCGR170_RD(x) & ~BM_CCM_CCGR170_SETTING2) | BF_CCM_CCGR170_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR170, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR170_SETTING3 (12U)      /*!< Bit position for CCM_CCGR170_SETTING3. */
#define BM_CCM_CCGR170_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR170_SETTING3. */
#define BS_CCM_CCGR170_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR170_SETTING3. */

/*! @brief Read current value of the CCM_CCGR170_SETTING3 field. */
#define BR_CCM_CCGR170_SETTING3(x) (HW_CCM_CCGR170(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR170_SETTING3. */
#define BF_CCM_CCGR170_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR170_SETTING3) & BM_CCM_CCGR170_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR170_SETTING3(x, v) (HW_CCM_CCGR170_WR(x, (HW_CCM_CCGR170_RD(x) & ~BM_CCM_CCGR170_SETTING3) | BF_CCM_CCGR170_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR171 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR171 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr171
{
    uint32_t U;
    struct _hw_ccm_ccgr171_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr171_t;

/*!
 * @name Constants and macros for entire CCM_CCGR171 register
 */
/*@{*/
#define HW_CCM_CCGR171_ADDR(x)   ((uintptr_t)(x) + 0x4AB0U)
#define HW_CCM_CCGR171_SET_ADDR(x) (HW_CCM_CCGR171_ADDR(x) + 0x4U)
#define HW_CCM_CCGR171_CLR_ADDR(x) (HW_CCM_CCGR171_ADDR(x) + 0x8U)
#define HW_CCM_CCGR171_TOG_ADDR(x) (HW_CCM_CCGR171_ADDR(x) + 0xCU)

#define HW_CCM_CCGR171(x)        (*(__IO hw_ccm_ccgr171_t *) HW_CCM_CCGR171_ADDR(x))
#define HW_CCM_CCGR171_RD(x)     (HW_CCM_CCGR171(x).U)
#define HW_CCM_CCGR171_WR(x, v)  (HW_CCM_CCGR171(x).U = (v))
#define HW_CCM_CCGR171_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR171_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR171_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR171_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR171_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR171_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR171 bitfields
 */

/*!
 * @name Register CCM_CCGR171, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR171_SETTING0 (0U)       /*!< Bit position for CCM_CCGR171_SETTING0. */
#define BM_CCM_CCGR171_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR171_SETTING0. */
#define BS_CCM_CCGR171_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR171_SETTING0. */

/*! @brief Read current value of the CCM_CCGR171_SETTING0 field. */
#define BR_CCM_CCGR171_SETTING0(x) (HW_CCM_CCGR171(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR171_SETTING0. */
#define BF_CCM_CCGR171_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR171_SETTING0) & BM_CCM_CCGR171_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR171_SETTING0(x, v) (HW_CCM_CCGR171_WR(x, (HW_CCM_CCGR171_RD(x) & ~BM_CCM_CCGR171_SETTING0) | BF_CCM_CCGR171_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR171, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR171_SETTING1 (4U)       /*!< Bit position for CCM_CCGR171_SETTING1. */
#define BM_CCM_CCGR171_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR171_SETTING1. */
#define BS_CCM_CCGR171_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR171_SETTING1. */

/*! @brief Read current value of the CCM_CCGR171_SETTING1 field. */
#define BR_CCM_CCGR171_SETTING1(x) (HW_CCM_CCGR171(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR171_SETTING1. */
#define BF_CCM_CCGR171_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR171_SETTING1) & BM_CCM_CCGR171_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR171_SETTING1(x, v) (HW_CCM_CCGR171_WR(x, (HW_CCM_CCGR171_RD(x) & ~BM_CCM_CCGR171_SETTING1) | BF_CCM_CCGR171_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR171, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR171_SETTING2 (8U)       /*!< Bit position for CCM_CCGR171_SETTING2. */
#define BM_CCM_CCGR171_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR171_SETTING2. */
#define BS_CCM_CCGR171_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR171_SETTING2. */

/*! @brief Read current value of the CCM_CCGR171_SETTING2 field. */
#define BR_CCM_CCGR171_SETTING2(x) (HW_CCM_CCGR171(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR171_SETTING2. */
#define BF_CCM_CCGR171_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR171_SETTING2) & BM_CCM_CCGR171_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR171_SETTING2(x, v) (HW_CCM_CCGR171_WR(x, (HW_CCM_CCGR171_RD(x) & ~BM_CCM_CCGR171_SETTING2) | BF_CCM_CCGR171_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR171, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR171_SETTING3 (12U)      /*!< Bit position for CCM_CCGR171_SETTING3. */
#define BM_CCM_CCGR171_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR171_SETTING3. */
#define BS_CCM_CCGR171_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR171_SETTING3. */

/*! @brief Read current value of the CCM_CCGR171_SETTING3 field. */
#define BR_CCM_CCGR171_SETTING3(x) (HW_CCM_CCGR171(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR171_SETTING3. */
#define BF_CCM_CCGR171_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR171_SETTING3) & BM_CCM_CCGR171_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR171_SETTING3(x, v) (HW_CCM_CCGR171_WR(x, (HW_CCM_CCGR171_RD(x) & ~BM_CCM_CCGR171_SETTING3) | BF_CCM_CCGR171_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR172 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR172 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr172
{
    uint32_t U;
    struct _hw_ccm_ccgr172_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr172_t;

/*!
 * @name Constants and macros for entire CCM_CCGR172 register
 */
/*@{*/
#define HW_CCM_CCGR172_ADDR(x)   ((uintptr_t)(x) + 0x4AC0U)
#define HW_CCM_CCGR172_SET_ADDR(x) (HW_CCM_CCGR172_ADDR(x) + 0x4U)
#define HW_CCM_CCGR172_CLR_ADDR(x) (HW_CCM_CCGR172_ADDR(x) + 0x8U)
#define HW_CCM_CCGR172_TOG_ADDR(x) (HW_CCM_CCGR172_ADDR(x) + 0xCU)

#define HW_CCM_CCGR172(x)        (*(__IO hw_ccm_ccgr172_t *) HW_CCM_CCGR172_ADDR(x))
#define HW_CCM_CCGR172_RD(x)     (HW_CCM_CCGR172(x).U)
#define HW_CCM_CCGR172_WR(x, v)  (HW_CCM_CCGR172(x).U = (v))
#define HW_CCM_CCGR172_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR172_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR172_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR172_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR172_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR172_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR172 bitfields
 */

/*!
 * @name Register CCM_CCGR172, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR172_SETTING0 (0U)       /*!< Bit position for CCM_CCGR172_SETTING0. */
#define BM_CCM_CCGR172_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR172_SETTING0. */
#define BS_CCM_CCGR172_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR172_SETTING0. */

/*! @brief Read current value of the CCM_CCGR172_SETTING0 field. */
#define BR_CCM_CCGR172_SETTING0(x) (HW_CCM_CCGR172(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR172_SETTING0. */
#define BF_CCM_CCGR172_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR172_SETTING0) & BM_CCM_CCGR172_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR172_SETTING0(x, v) (HW_CCM_CCGR172_WR(x, (HW_CCM_CCGR172_RD(x) & ~BM_CCM_CCGR172_SETTING0) | BF_CCM_CCGR172_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR172, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR172_SETTING1 (4U)       /*!< Bit position for CCM_CCGR172_SETTING1. */
#define BM_CCM_CCGR172_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR172_SETTING1. */
#define BS_CCM_CCGR172_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR172_SETTING1. */

/*! @brief Read current value of the CCM_CCGR172_SETTING1 field. */
#define BR_CCM_CCGR172_SETTING1(x) (HW_CCM_CCGR172(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR172_SETTING1. */
#define BF_CCM_CCGR172_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR172_SETTING1) & BM_CCM_CCGR172_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR172_SETTING1(x, v) (HW_CCM_CCGR172_WR(x, (HW_CCM_CCGR172_RD(x) & ~BM_CCM_CCGR172_SETTING1) | BF_CCM_CCGR172_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR172, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR172_SETTING2 (8U)       /*!< Bit position for CCM_CCGR172_SETTING2. */
#define BM_CCM_CCGR172_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR172_SETTING2. */
#define BS_CCM_CCGR172_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR172_SETTING2. */

/*! @brief Read current value of the CCM_CCGR172_SETTING2 field. */
#define BR_CCM_CCGR172_SETTING2(x) (HW_CCM_CCGR172(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR172_SETTING2. */
#define BF_CCM_CCGR172_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR172_SETTING2) & BM_CCM_CCGR172_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR172_SETTING2(x, v) (HW_CCM_CCGR172_WR(x, (HW_CCM_CCGR172_RD(x) & ~BM_CCM_CCGR172_SETTING2) | BF_CCM_CCGR172_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR172, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR172_SETTING3 (12U)      /*!< Bit position for CCM_CCGR172_SETTING3. */
#define BM_CCM_CCGR172_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR172_SETTING3. */
#define BS_CCM_CCGR172_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR172_SETTING3. */

/*! @brief Read current value of the CCM_CCGR172_SETTING3 field. */
#define BR_CCM_CCGR172_SETTING3(x) (HW_CCM_CCGR172(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR172_SETTING3. */
#define BF_CCM_CCGR172_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR172_SETTING3) & BM_CCM_CCGR172_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR172_SETTING3(x, v) (HW_CCM_CCGR172_WR(x, (HW_CCM_CCGR172_RD(x) & ~BM_CCM_CCGR172_SETTING3) | BF_CCM_CCGR172_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR173 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR173 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr173
{
    uint32_t U;
    struct _hw_ccm_ccgr173_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr173_t;

/*!
 * @name Constants and macros for entire CCM_CCGR173 register
 */
/*@{*/
#define HW_CCM_CCGR173_ADDR(x)   ((uintptr_t)(x) + 0x4AD0U)
#define HW_CCM_CCGR173_SET_ADDR(x) (HW_CCM_CCGR173_ADDR(x) + 0x4U)
#define HW_CCM_CCGR173_CLR_ADDR(x) (HW_CCM_CCGR173_ADDR(x) + 0x8U)
#define HW_CCM_CCGR173_TOG_ADDR(x) (HW_CCM_CCGR173_ADDR(x) + 0xCU)

#define HW_CCM_CCGR173(x)        (*(__IO hw_ccm_ccgr173_t *) HW_CCM_CCGR173_ADDR(x))
#define HW_CCM_CCGR173_RD(x)     (HW_CCM_CCGR173(x).U)
#define HW_CCM_CCGR173_WR(x, v)  (HW_CCM_CCGR173(x).U = (v))
#define HW_CCM_CCGR173_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR173_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR173_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR173_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR173_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR173_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR173 bitfields
 */

/*!
 * @name Register CCM_CCGR173, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR173_SETTING0 (0U)       /*!< Bit position for CCM_CCGR173_SETTING0. */
#define BM_CCM_CCGR173_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR173_SETTING0. */
#define BS_CCM_CCGR173_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR173_SETTING0. */

/*! @brief Read current value of the CCM_CCGR173_SETTING0 field. */
#define BR_CCM_CCGR173_SETTING0(x) (HW_CCM_CCGR173(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR173_SETTING0. */
#define BF_CCM_CCGR173_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR173_SETTING0) & BM_CCM_CCGR173_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR173_SETTING0(x, v) (HW_CCM_CCGR173_WR(x, (HW_CCM_CCGR173_RD(x) & ~BM_CCM_CCGR173_SETTING0) | BF_CCM_CCGR173_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR173, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR173_SETTING1 (4U)       /*!< Bit position for CCM_CCGR173_SETTING1. */
#define BM_CCM_CCGR173_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR173_SETTING1. */
#define BS_CCM_CCGR173_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR173_SETTING1. */

/*! @brief Read current value of the CCM_CCGR173_SETTING1 field. */
#define BR_CCM_CCGR173_SETTING1(x) (HW_CCM_CCGR173(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR173_SETTING1. */
#define BF_CCM_CCGR173_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR173_SETTING1) & BM_CCM_CCGR173_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR173_SETTING1(x, v) (HW_CCM_CCGR173_WR(x, (HW_CCM_CCGR173_RD(x) & ~BM_CCM_CCGR173_SETTING1) | BF_CCM_CCGR173_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR173, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR173_SETTING2 (8U)       /*!< Bit position for CCM_CCGR173_SETTING2. */
#define BM_CCM_CCGR173_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR173_SETTING2. */
#define BS_CCM_CCGR173_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR173_SETTING2. */

/*! @brief Read current value of the CCM_CCGR173_SETTING2 field. */
#define BR_CCM_CCGR173_SETTING2(x) (HW_CCM_CCGR173(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR173_SETTING2. */
#define BF_CCM_CCGR173_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR173_SETTING2) & BM_CCM_CCGR173_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR173_SETTING2(x, v) (HW_CCM_CCGR173_WR(x, (HW_CCM_CCGR173_RD(x) & ~BM_CCM_CCGR173_SETTING2) | BF_CCM_CCGR173_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR173, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR173_SETTING3 (12U)      /*!< Bit position for CCM_CCGR173_SETTING3. */
#define BM_CCM_CCGR173_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR173_SETTING3. */
#define BS_CCM_CCGR173_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR173_SETTING3. */

/*! @brief Read current value of the CCM_CCGR173_SETTING3 field. */
#define BR_CCM_CCGR173_SETTING3(x) (HW_CCM_CCGR173(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR173_SETTING3. */
#define BF_CCM_CCGR173_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR173_SETTING3) & BM_CCM_CCGR173_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR173_SETTING3(x, v) (HW_CCM_CCGR173_WR(x, (HW_CCM_CCGR173_RD(x) & ~BM_CCM_CCGR173_SETTING3) | BF_CCM_CCGR173_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR174 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR174 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr174
{
    uint32_t U;
    struct _hw_ccm_ccgr174_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr174_t;

/*!
 * @name Constants and macros for entire CCM_CCGR174 register
 */
/*@{*/
#define HW_CCM_CCGR174_ADDR(x)   ((uintptr_t)(x) + 0x4AE0U)
#define HW_CCM_CCGR174_SET_ADDR(x) (HW_CCM_CCGR174_ADDR(x) + 0x4U)
#define HW_CCM_CCGR174_CLR_ADDR(x) (HW_CCM_CCGR174_ADDR(x) + 0x8U)
#define HW_CCM_CCGR174_TOG_ADDR(x) (HW_CCM_CCGR174_ADDR(x) + 0xCU)

#define HW_CCM_CCGR174(x)        (*(__IO hw_ccm_ccgr174_t *) HW_CCM_CCGR174_ADDR(x))
#define HW_CCM_CCGR174_RD(x)     (HW_CCM_CCGR174(x).U)
#define HW_CCM_CCGR174_WR(x, v)  (HW_CCM_CCGR174(x).U = (v))
#define HW_CCM_CCGR174_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR174_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR174_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR174_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR174_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR174_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR174 bitfields
 */

/*!
 * @name Register CCM_CCGR174, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR174_SETTING0 (0U)       /*!< Bit position for CCM_CCGR174_SETTING0. */
#define BM_CCM_CCGR174_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR174_SETTING0. */
#define BS_CCM_CCGR174_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR174_SETTING0. */

/*! @brief Read current value of the CCM_CCGR174_SETTING0 field. */
#define BR_CCM_CCGR174_SETTING0(x) (HW_CCM_CCGR174(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR174_SETTING0. */
#define BF_CCM_CCGR174_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR174_SETTING0) & BM_CCM_CCGR174_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR174_SETTING0(x, v) (HW_CCM_CCGR174_WR(x, (HW_CCM_CCGR174_RD(x) & ~BM_CCM_CCGR174_SETTING0) | BF_CCM_CCGR174_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR174, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR174_SETTING1 (4U)       /*!< Bit position for CCM_CCGR174_SETTING1. */
#define BM_CCM_CCGR174_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR174_SETTING1. */
#define BS_CCM_CCGR174_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR174_SETTING1. */

/*! @brief Read current value of the CCM_CCGR174_SETTING1 field. */
#define BR_CCM_CCGR174_SETTING1(x) (HW_CCM_CCGR174(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR174_SETTING1. */
#define BF_CCM_CCGR174_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR174_SETTING1) & BM_CCM_CCGR174_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR174_SETTING1(x, v) (HW_CCM_CCGR174_WR(x, (HW_CCM_CCGR174_RD(x) & ~BM_CCM_CCGR174_SETTING1) | BF_CCM_CCGR174_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR174, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR174_SETTING2 (8U)       /*!< Bit position for CCM_CCGR174_SETTING2. */
#define BM_CCM_CCGR174_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR174_SETTING2. */
#define BS_CCM_CCGR174_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR174_SETTING2. */

/*! @brief Read current value of the CCM_CCGR174_SETTING2 field. */
#define BR_CCM_CCGR174_SETTING2(x) (HW_CCM_CCGR174(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR174_SETTING2. */
#define BF_CCM_CCGR174_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR174_SETTING2) & BM_CCM_CCGR174_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR174_SETTING2(x, v) (HW_CCM_CCGR174_WR(x, (HW_CCM_CCGR174_RD(x) & ~BM_CCM_CCGR174_SETTING2) | BF_CCM_CCGR174_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR174, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR174_SETTING3 (12U)      /*!< Bit position for CCM_CCGR174_SETTING3. */
#define BM_CCM_CCGR174_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR174_SETTING3. */
#define BS_CCM_CCGR174_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR174_SETTING3. */

/*! @brief Read current value of the CCM_CCGR174_SETTING3 field. */
#define BR_CCM_CCGR174_SETTING3(x) (HW_CCM_CCGR174(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR174_SETTING3. */
#define BF_CCM_CCGR174_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR174_SETTING3) & BM_CCM_CCGR174_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR174_SETTING3(x, v) (HW_CCM_CCGR174_WR(x, (HW_CCM_CCGR174_RD(x) & ~BM_CCM_CCGR174_SETTING3) | BF_CCM_CCGR174_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR175 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR175 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr175
{
    uint32_t U;
    struct _hw_ccm_ccgr175_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr175_t;

/*!
 * @name Constants and macros for entire CCM_CCGR175 register
 */
/*@{*/
#define HW_CCM_CCGR175_ADDR(x)   ((uintptr_t)(x) + 0x4AF0U)
#define HW_CCM_CCGR175_SET_ADDR(x) (HW_CCM_CCGR175_ADDR(x) + 0x4U)
#define HW_CCM_CCGR175_CLR_ADDR(x) (HW_CCM_CCGR175_ADDR(x) + 0x8U)
#define HW_CCM_CCGR175_TOG_ADDR(x) (HW_CCM_CCGR175_ADDR(x) + 0xCU)

#define HW_CCM_CCGR175(x)        (*(__IO hw_ccm_ccgr175_t *) HW_CCM_CCGR175_ADDR(x))
#define HW_CCM_CCGR175_RD(x)     (HW_CCM_CCGR175(x).U)
#define HW_CCM_CCGR175_WR(x, v)  (HW_CCM_CCGR175(x).U = (v))
#define HW_CCM_CCGR175_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR175_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR175_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR175_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR175_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR175_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR175 bitfields
 */

/*!
 * @name Register CCM_CCGR175, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR175_SETTING0 (0U)       /*!< Bit position for CCM_CCGR175_SETTING0. */
#define BM_CCM_CCGR175_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR175_SETTING0. */
#define BS_CCM_CCGR175_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR175_SETTING0. */

/*! @brief Read current value of the CCM_CCGR175_SETTING0 field. */
#define BR_CCM_CCGR175_SETTING0(x) (HW_CCM_CCGR175(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR175_SETTING0. */
#define BF_CCM_CCGR175_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR175_SETTING0) & BM_CCM_CCGR175_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR175_SETTING0(x, v) (HW_CCM_CCGR175_WR(x, (HW_CCM_CCGR175_RD(x) & ~BM_CCM_CCGR175_SETTING0) | BF_CCM_CCGR175_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR175, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR175_SETTING1 (4U)       /*!< Bit position for CCM_CCGR175_SETTING1. */
#define BM_CCM_CCGR175_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR175_SETTING1. */
#define BS_CCM_CCGR175_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR175_SETTING1. */

/*! @brief Read current value of the CCM_CCGR175_SETTING1 field. */
#define BR_CCM_CCGR175_SETTING1(x) (HW_CCM_CCGR175(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR175_SETTING1. */
#define BF_CCM_CCGR175_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR175_SETTING1) & BM_CCM_CCGR175_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR175_SETTING1(x, v) (HW_CCM_CCGR175_WR(x, (HW_CCM_CCGR175_RD(x) & ~BM_CCM_CCGR175_SETTING1) | BF_CCM_CCGR175_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR175, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR175_SETTING2 (8U)       /*!< Bit position for CCM_CCGR175_SETTING2. */
#define BM_CCM_CCGR175_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR175_SETTING2. */
#define BS_CCM_CCGR175_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR175_SETTING2. */

/*! @brief Read current value of the CCM_CCGR175_SETTING2 field. */
#define BR_CCM_CCGR175_SETTING2(x) (HW_CCM_CCGR175(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR175_SETTING2. */
#define BF_CCM_CCGR175_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR175_SETTING2) & BM_CCM_CCGR175_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR175_SETTING2(x, v) (HW_CCM_CCGR175_WR(x, (HW_CCM_CCGR175_RD(x) & ~BM_CCM_CCGR175_SETTING2) | BF_CCM_CCGR175_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR175, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR175_SETTING3 (12U)      /*!< Bit position for CCM_CCGR175_SETTING3. */
#define BM_CCM_CCGR175_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR175_SETTING3. */
#define BS_CCM_CCGR175_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR175_SETTING3. */

/*! @brief Read current value of the CCM_CCGR175_SETTING3 field. */
#define BR_CCM_CCGR175_SETTING3(x) (HW_CCM_CCGR175(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR175_SETTING3. */
#define BF_CCM_CCGR175_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR175_SETTING3) & BM_CCM_CCGR175_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR175_SETTING3(x, v) (HW_CCM_CCGR175_WR(x, (HW_CCM_CCGR175_RD(x) & ~BM_CCM_CCGR175_SETTING3) | BF_CCM_CCGR175_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR176 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR176 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr176
{
    uint32_t U;
    struct _hw_ccm_ccgr176_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr176_t;

/*!
 * @name Constants and macros for entire CCM_CCGR176 register
 */
/*@{*/
#define HW_CCM_CCGR176_ADDR(x)   ((uintptr_t)(x) + 0x4B00U)
#define HW_CCM_CCGR176_SET_ADDR(x) (HW_CCM_CCGR176_ADDR(x) + 0x4U)
#define HW_CCM_CCGR176_CLR_ADDR(x) (HW_CCM_CCGR176_ADDR(x) + 0x8U)
#define HW_CCM_CCGR176_TOG_ADDR(x) (HW_CCM_CCGR176_ADDR(x) + 0xCU)

#define HW_CCM_CCGR176(x)        (*(__IO hw_ccm_ccgr176_t *) HW_CCM_CCGR176_ADDR(x))
#define HW_CCM_CCGR176_RD(x)     (HW_CCM_CCGR176(x).U)
#define HW_CCM_CCGR176_WR(x, v)  (HW_CCM_CCGR176(x).U = (v))
#define HW_CCM_CCGR176_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR176_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR176_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR176_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR176_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR176_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR176 bitfields
 */

/*!
 * @name Register CCM_CCGR176, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR176_SETTING0 (0U)       /*!< Bit position for CCM_CCGR176_SETTING0. */
#define BM_CCM_CCGR176_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR176_SETTING0. */
#define BS_CCM_CCGR176_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR176_SETTING0. */

/*! @brief Read current value of the CCM_CCGR176_SETTING0 field. */
#define BR_CCM_CCGR176_SETTING0(x) (HW_CCM_CCGR176(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR176_SETTING0. */
#define BF_CCM_CCGR176_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR176_SETTING0) & BM_CCM_CCGR176_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR176_SETTING0(x, v) (HW_CCM_CCGR176_WR(x, (HW_CCM_CCGR176_RD(x) & ~BM_CCM_CCGR176_SETTING0) | BF_CCM_CCGR176_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR176, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR176_SETTING1 (4U)       /*!< Bit position for CCM_CCGR176_SETTING1. */
#define BM_CCM_CCGR176_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR176_SETTING1. */
#define BS_CCM_CCGR176_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR176_SETTING1. */

/*! @brief Read current value of the CCM_CCGR176_SETTING1 field. */
#define BR_CCM_CCGR176_SETTING1(x) (HW_CCM_CCGR176(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR176_SETTING1. */
#define BF_CCM_CCGR176_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR176_SETTING1) & BM_CCM_CCGR176_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR176_SETTING1(x, v) (HW_CCM_CCGR176_WR(x, (HW_CCM_CCGR176_RD(x) & ~BM_CCM_CCGR176_SETTING1) | BF_CCM_CCGR176_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR176, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR176_SETTING2 (8U)       /*!< Bit position for CCM_CCGR176_SETTING2. */
#define BM_CCM_CCGR176_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR176_SETTING2. */
#define BS_CCM_CCGR176_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR176_SETTING2. */

/*! @brief Read current value of the CCM_CCGR176_SETTING2 field. */
#define BR_CCM_CCGR176_SETTING2(x) (HW_CCM_CCGR176(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR176_SETTING2. */
#define BF_CCM_CCGR176_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR176_SETTING2) & BM_CCM_CCGR176_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR176_SETTING2(x, v) (HW_CCM_CCGR176_WR(x, (HW_CCM_CCGR176_RD(x) & ~BM_CCM_CCGR176_SETTING2) | BF_CCM_CCGR176_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR176, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR176_SETTING3 (12U)      /*!< Bit position for CCM_CCGR176_SETTING3. */
#define BM_CCM_CCGR176_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR176_SETTING3. */
#define BS_CCM_CCGR176_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR176_SETTING3. */

/*! @brief Read current value of the CCM_CCGR176_SETTING3 field. */
#define BR_CCM_CCGR176_SETTING3(x) (HW_CCM_CCGR176(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR176_SETTING3. */
#define BF_CCM_CCGR176_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR176_SETTING3) & BM_CCM_CCGR176_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR176_SETTING3(x, v) (HW_CCM_CCGR176_WR(x, (HW_CCM_CCGR176_RD(x) & ~BM_CCM_CCGR176_SETTING3) | BF_CCM_CCGR176_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR177 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR177 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr177
{
    uint32_t U;
    struct _hw_ccm_ccgr177_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr177_t;

/*!
 * @name Constants and macros for entire CCM_CCGR177 register
 */
/*@{*/
#define HW_CCM_CCGR177_ADDR(x)   ((uintptr_t)(x) + 0x4B10U)
#define HW_CCM_CCGR177_SET_ADDR(x) (HW_CCM_CCGR177_ADDR(x) + 0x4U)
#define HW_CCM_CCGR177_CLR_ADDR(x) (HW_CCM_CCGR177_ADDR(x) + 0x8U)
#define HW_CCM_CCGR177_TOG_ADDR(x) (HW_CCM_CCGR177_ADDR(x) + 0xCU)

#define HW_CCM_CCGR177(x)        (*(__IO hw_ccm_ccgr177_t *) HW_CCM_CCGR177_ADDR(x))
#define HW_CCM_CCGR177_RD(x)     (HW_CCM_CCGR177(x).U)
#define HW_CCM_CCGR177_WR(x, v)  (HW_CCM_CCGR177(x).U = (v))
#define HW_CCM_CCGR177_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR177_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR177_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR177_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR177_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR177_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR177 bitfields
 */

/*!
 * @name Register CCM_CCGR177, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR177_SETTING0 (0U)       /*!< Bit position for CCM_CCGR177_SETTING0. */
#define BM_CCM_CCGR177_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR177_SETTING0. */
#define BS_CCM_CCGR177_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR177_SETTING0. */

/*! @brief Read current value of the CCM_CCGR177_SETTING0 field. */
#define BR_CCM_CCGR177_SETTING0(x) (HW_CCM_CCGR177(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR177_SETTING0. */
#define BF_CCM_CCGR177_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR177_SETTING0) & BM_CCM_CCGR177_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR177_SETTING0(x, v) (HW_CCM_CCGR177_WR(x, (HW_CCM_CCGR177_RD(x) & ~BM_CCM_CCGR177_SETTING0) | BF_CCM_CCGR177_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR177, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR177_SETTING1 (4U)       /*!< Bit position for CCM_CCGR177_SETTING1. */
#define BM_CCM_CCGR177_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR177_SETTING1. */
#define BS_CCM_CCGR177_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR177_SETTING1. */

/*! @brief Read current value of the CCM_CCGR177_SETTING1 field. */
#define BR_CCM_CCGR177_SETTING1(x) (HW_CCM_CCGR177(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR177_SETTING1. */
#define BF_CCM_CCGR177_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR177_SETTING1) & BM_CCM_CCGR177_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR177_SETTING1(x, v) (HW_CCM_CCGR177_WR(x, (HW_CCM_CCGR177_RD(x) & ~BM_CCM_CCGR177_SETTING1) | BF_CCM_CCGR177_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR177, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR177_SETTING2 (8U)       /*!< Bit position for CCM_CCGR177_SETTING2. */
#define BM_CCM_CCGR177_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR177_SETTING2. */
#define BS_CCM_CCGR177_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR177_SETTING2. */

/*! @brief Read current value of the CCM_CCGR177_SETTING2 field. */
#define BR_CCM_CCGR177_SETTING2(x) (HW_CCM_CCGR177(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR177_SETTING2. */
#define BF_CCM_CCGR177_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR177_SETTING2) & BM_CCM_CCGR177_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR177_SETTING2(x, v) (HW_CCM_CCGR177_WR(x, (HW_CCM_CCGR177_RD(x) & ~BM_CCM_CCGR177_SETTING2) | BF_CCM_CCGR177_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR177, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR177_SETTING3 (12U)      /*!< Bit position for CCM_CCGR177_SETTING3. */
#define BM_CCM_CCGR177_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR177_SETTING3. */
#define BS_CCM_CCGR177_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR177_SETTING3. */

/*! @brief Read current value of the CCM_CCGR177_SETTING3 field. */
#define BR_CCM_CCGR177_SETTING3(x) (HW_CCM_CCGR177(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR177_SETTING3. */
#define BF_CCM_CCGR177_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR177_SETTING3) & BM_CCM_CCGR177_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR177_SETTING3(x, v) (HW_CCM_CCGR177_WR(x, (HW_CCM_CCGR177_RD(x) & ~BM_CCM_CCGR177_SETTING3) | BF_CCM_CCGR177_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR178 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR178 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr178
{
    uint32_t U;
    struct _hw_ccm_ccgr178_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr178_t;

/*!
 * @name Constants and macros for entire CCM_CCGR178 register
 */
/*@{*/
#define HW_CCM_CCGR178_ADDR(x)   ((uintptr_t)(x) + 0x4B20U)
#define HW_CCM_CCGR178_SET_ADDR(x) (HW_CCM_CCGR178_ADDR(x) + 0x4U)
#define HW_CCM_CCGR178_CLR_ADDR(x) (HW_CCM_CCGR178_ADDR(x) + 0x8U)
#define HW_CCM_CCGR178_TOG_ADDR(x) (HW_CCM_CCGR178_ADDR(x) + 0xCU)

#define HW_CCM_CCGR178(x)        (*(__IO hw_ccm_ccgr178_t *) HW_CCM_CCGR178_ADDR(x))
#define HW_CCM_CCGR178_RD(x)     (HW_CCM_CCGR178(x).U)
#define HW_CCM_CCGR178_WR(x, v)  (HW_CCM_CCGR178(x).U = (v))
#define HW_CCM_CCGR178_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR178_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR178_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR178_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR178_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR178_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR178 bitfields
 */

/*!
 * @name Register CCM_CCGR178, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR178_SETTING0 (0U)       /*!< Bit position for CCM_CCGR178_SETTING0. */
#define BM_CCM_CCGR178_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR178_SETTING0. */
#define BS_CCM_CCGR178_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR178_SETTING0. */

/*! @brief Read current value of the CCM_CCGR178_SETTING0 field. */
#define BR_CCM_CCGR178_SETTING0(x) (HW_CCM_CCGR178(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR178_SETTING0. */
#define BF_CCM_CCGR178_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR178_SETTING0) & BM_CCM_CCGR178_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR178_SETTING0(x, v) (HW_CCM_CCGR178_WR(x, (HW_CCM_CCGR178_RD(x) & ~BM_CCM_CCGR178_SETTING0) | BF_CCM_CCGR178_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR178, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR178_SETTING1 (4U)       /*!< Bit position for CCM_CCGR178_SETTING1. */
#define BM_CCM_CCGR178_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR178_SETTING1. */
#define BS_CCM_CCGR178_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR178_SETTING1. */

/*! @brief Read current value of the CCM_CCGR178_SETTING1 field. */
#define BR_CCM_CCGR178_SETTING1(x) (HW_CCM_CCGR178(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR178_SETTING1. */
#define BF_CCM_CCGR178_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR178_SETTING1) & BM_CCM_CCGR178_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR178_SETTING1(x, v) (HW_CCM_CCGR178_WR(x, (HW_CCM_CCGR178_RD(x) & ~BM_CCM_CCGR178_SETTING1) | BF_CCM_CCGR178_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR178, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR178_SETTING2 (8U)       /*!< Bit position for CCM_CCGR178_SETTING2. */
#define BM_CCM_CCGR178_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR178_SETTING2. */
#define BS_CCM_CCGR178_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR178_SETTING2. */

/*! @brief Read current value of the CCM_CCGR178_SETTING2 field. */
#define BR_CCM_CCGR178_SETTING2(x) (HW_CCM_CCGR178(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR178_SETTING2. */
#define BF_CCM_CCGR178_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR178_SETTING2) & BM_CCM_CCGR178_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR178_SETTING2(x, v) (HW_CCM_CCGR178_WR(x, (HW_CCM_CCGR178_RD(x) & ~BM_CCM_CCGR178_SETTING2) | BF_CCM_CCGR178_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR178, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR178_SETTING3 (12U)      /*!< Bit position for CCM_CCGR178_SETTING3. */
#define BM_CCM_CCGR178_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR178_SETTING3. */
#define BS_CCM_CCGR178_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR178_SETTING3. */

/*! @brief Read current value of the CCM_CCGR178_SETTING3 field. */
#define BR_CCM_CCGR178_SETTING3(x) (HW_CCM_CCGR178(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR178_SETTING3. */
#define BF_CCM_CCGR178_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR178_SETTING3) & BM_CCM_CCGR178_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR178_SETTING3(x, v) (HW_CCM_CCGR178_WR(x, (HW_CCM_CCGR178_RD(x) & ~BM_CCM_CCGR178_SETTING3) | BF_CCM_CCGR178_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR179 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR179 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr179
{
    uint32_t U;
    struct _hw_ccm_ccgr179_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr179_t;

/*!
 * @name Constants and macros for entire CCM_CCGR179 register
 */
/*@{*/
#define HW_CCM_CCGR179_ADDR(x)   ((uintptr_t)(x) + 0x4B30U)
#define HW_CCM_CCGR179_SET_ADDR(x) (HW_CCM_CCGR179_ADDR(x) + 0x4U)
#define HW_CCM_CCGR179_CLR_ADDR(x) (HW_CCM_CCGR179_ADDR(x) + 0x8U)
#define HW_CCM_CCGR179_TOG_ADDR(x) (HW_CCM_CCGR179_ADDR(x) + 0xCU)

#define HW_CCM_CCGR179(x)        (*(__IO hw_ccm_ccgr179_t *) HW_CCM_CCGR179_ADDR(x))
#define HW_CCM_CCGR179_RD(x)     (HW_CCM_CCGR179(x).U)
#define HW_CCM_CCGR179_WR(x, v)  (HW_CCM_CCGR179(x).U = (v))
#define HW_CCM_CCGR179_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR179_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR179_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR179_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR179_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR179_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR179 bitfields
 */

/*!
 * @name Register CCM_CCGR179, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR179_SETTING0 (0U)       /*!< Bit position for CCM_CCGR179_SETTING0. */
#define BM_CCM_CCGR179_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR179_SETTING0. */
#define BS_CCM_CCGR179_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR179_SETTING0. */

/*! @brief Read current value of the CCM_CCGR179_SETTING0 field. */
#define BR_CCM_CCGR179_SETTING0(x) (HW_CCM_CCGR179(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR179_SETTING0. */
#define BF_CCM_CCGR179_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR179_SETTING0) & BM_CCM_CCGR179_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR179_SETTING0(x, v) (HW_CCM_CCGR179_WR(x, (HW_CCM_CCGR179_RD(x) & ~BM_CCM_CCGR179_SETTING0) | BF_CCM_CCGR179_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR179, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR179_SETTING1 (4U)       /*!< Bit position for CCM_CCGR179_SETTING1. */
#define BM_CCM_CCGR179_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR179_SETTING1. */
#define BS_CCM_CCGR179_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR179_SETTING1. */

/*! @brief Read current value of the CCM_CCGR179_SETTING1 field. */
#define BR_CCM_CCGR179_SETTING1(x) (HW_CCM_CCGR179(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR179_SETTING1. */
#define BF_CCM_CCGR179_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR179_SETTING1) & BM_CCM_CCGR179_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR179_SETTING1(x, v) (HW_CCM_CCGR179_WR(x, (HW_CCM_CCGR179_RD(x) & ~BM_CCM_CCGR179_SETTING1) | BF_CCM_CCGR179_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR179, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR179_SETTING2 (8U)       /*!< Bit position for CCM_CCGR179_SETTING2. */
#define BM_CCM_CCGR179_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR179_SETTING2. */
#define BS_CCM_CCGR179_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR179_SETTING2. */

/*! @brief Read current value of the CCM_CCGR179_SETTING2 field. */
#define BR_CCM_CCGR179_SETTING2(x) (HW_CCM_CCGR179(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR179_SETTING2. */
#define BF_CCM_CCGR179_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR179_SETTING2) & BM_CCM_CCGR179_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR179_SETTING2(x, v) (HW_CCM_CCGR179_WR(x, (HW_CCM_CCGR179_RD(x) & ~BM_CCM_CCGR179_SETTING2) | BF_CCM_CCGR179_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR179, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR179_SETTING3 (12U)      /*!< Bit position for CCM_CCGR179_SETTING3. */
#define BM_CCM_CCGR179_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR179_SETTING3. */
#define BS_CCM_CCGR179_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR179_SETTING3. */

/*! @brief Read current value of the CCM_CCGR179_SETTING3 field. */
#define BR_CCM_CCGR179_SETTING3(x) (HW_CCM_CCGR179(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR179_SETTING3. */
#define BF_CCM_CCGR179_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR179_SETTING3) & BM_CCM_CCGR179_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR179_SETTING3(x, v) (HW_CCM_CCGR179_WR(x, (HW_CCM_CCGR179_RD(x) & ~BM_CCM_CCGR179_SETTING3) | BF_CCM_CCGR179_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR180 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR180 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr180
{
    uint32_t U;
    struct _hw_ccm_ccgr180_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr180_t;

/*!
 * @name Constants and macros for entire CCM_CCGR180 register
 */
/*@{*/
#define HW_CCM_CCGR180_ADDR(x)   ((uintptr_t)(x) + 0x4B40U)
#define HW_CCM_CCGR180_SET_ADDR(x) (HW_CCM_CCGR180_ADDR(x) + 0x4U)
#define HW_CCM_CCGR180_CLR_ADDR(x) (HW_CCM_CCGR180_ADDR(x) + 0x8U)
#define HW_CCM_CCGR180_TOG_ADDR(x) (HW_CCM_CCGR180_ADDR(x) + 0xCU)

#define HW_CCM_CCGR180(x)        (*(__IO hw_ccm_ccgr180_t *) HW_CCM_CCGR180_ADDR(x))
#define HW_CCM_CCGR180_RD(x)     (HW_CCM_CCGR180(x).U)
#define HW_CCM_CCGR180_WR(x, v)  (HW_CCM_CCGR180(x).U = (v))
#define HW_CCM_CCGR180_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR180_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR180_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR180_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR180_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR180_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR180 bitfields
 */

/*!
 * @name Register CCM_CCGR180, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR180_SETTING0 (0U)       /*!< Bit position for CCM_CCGR180_SETTING0. */
#define BM_CCM_CCGR180_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR180_SETTING0. */
#define BS_CCM_CCGR180_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR180_SETTING0. */

/*! @brief Read current value of the CCM_CCGR180_SETTING0 field. */
#define BR_CCM_CCGR180_SETTING0(x) (HW_CCM_CCGR180(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR180_SETTING0. */
#define BF_CCM_CCGR180_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR180_SETTING0) & BM_CCM_CCGR180_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR180_SETTING0(x, v) (HW_CCM_CCGR180_WR(x, (HW_CCM_CCGR180_RD(x) & ~BM_CCM_CCGR180_SETTING0) | BF_CCM_CCGR180_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR180, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR180_SETTING1 (4U)       /*!< Bit position for CCM_CCGR180_SETTING1. */
#define BM_CCM_CCGR180_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR180_SETTING1. */
#define BS_CCM_CCGR180_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR180_SETTING1. */

/*! @brief Read current value of the CCM_CCGR180_SETTING1 field. */
#define BR_CCM_CCGR180_SETTING1(x) (HW_CCM_CCGR180(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR180_SETTING1. */
#define BF_CCM_CCGR180_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR180_SETTING1) & BM_CCM_CCGR180_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR180_SETTING1(x, v) (HW_CCM_CCGR180_WR(x, (HW_CCM_CCGR180_RD(x) & ~BM_CCM_CCGR180_SETTING1) | BF_CCM_CCGR180_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR180, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR180_SETTING2 (8U)       /*!< Bit position for CCM_CCGR180_SETTING2. */
#define BM_CCM_CCGR180_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR180_SETTING2. */
#define BS_CCM_CCGR180_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR180_SETTING2. */

/*! @brief Read current value of the CCM_CCGR180_SETTING2 field. */
#define BR_CCM_CCGR180_SETTING2(x) (HW_CCM_CCGR180(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR180_SETTING2. */
#define BF_CCM_CCGR180_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR180_SETTING2) & BM_CCM_CCGR180_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR180_SETTING2(x, v) (HW_CCM_CCGR180_WR(x, (HW_CCM_CCGR180_RD(x) & ~BM_CCM_CCGR180_SETTING2) | BF_CCM_CCGR180_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR180, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR180_SETTING3 (12U)      /*!< Bit position for CCM_CCGR180_SETTING3. */
#define BM_CCM_CCGR180_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR180_SETTING3. */
#define BS_CCM_CCGR180_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR180_SETTING3. */

/*! @brief Read current value of the CCM_CCGR180_SETTING3 field. */
#define BR_CCM_CCGR180_SETTING3(x) (HW_CCM_CCGR180(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR180_SETTING3. */
#define BF_CCM_CCGR180_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR180_SETTING3) & BM_CCM_CCGR180_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR180_SETTING3(x, v) (HW_CCM_CCGR180_WR(x, (HW_CCM_CCGR180_RD(x) & ~BM_CCM_CCGR180_SETTING3) | BF_CCM_CCGR180_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR181 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR181 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr181
{
    uint32_t U;
    struct _hw_ccm_ccgr181_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr181_t;

/*!
 * @name Constants and macros for entire CCM_CCGR181 register
 */
/*@{*/
#define HW_CCM_CCGR181_ADDR(x)   ((uintptr_t)(x) + 0x4B50U)
#define HW_CCM_CCGR181_SET_ADDR(x) (HW_CCM_CCGR181_ADDR(x) + 0x4U)
#define HW_CCM_CCGR181_CLR_ADDR(x) (HW_CCM_CCGR181_ADDR(x) + 0x8U)
#define HW_CCM_CCGR181_TOG_ADDR(x) (HW_CCM_CCGR181_ADDR(x) + 0xCU)

#define HW_CCM_CCGR181(x)        (*(__IO hw_ccm_ccgr181_t *) HW_CCM_CCGR181_ADDR(x))
#define HW_CCM_CCGR181_RD(x)     (HW_CCM_CCGR181(x).U)
#define HW_CCM_CCGR181_WR(x, v)  (HW_CCM_CCGR181(x).U = (v))
#define HW_CCM_CCGR181_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR181_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR181_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR181_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR181_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR181_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR181 bitfields
 */

/*!
 * @name Register CCM_CCGR181, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR181_SETTING0 (0U)       /*!< Bit position for CCM_CCGR181_SETTING0. */
#define BM_CCM_CCGR181_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR181_SETTING0. */
#define BS_CCM_CCGR181_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR181_SETTING0. */

/*! @brief Read current value of the CCM_CCGR181_SETTING0 field. */
#define BR_CCM_CCGR181_SETTING0(x) (HW_CCM_CCGR181(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR181_SETTING0. */
#define BF_CCM_CCGR181_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR181_SETTING0) & BM_CCM_CCGR181_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR181_SETTING0(x, v) (HW_CCM_CCGR181_WR(x, (HW_CCM_CCGR181_RD(x) & ~BM_CCM_CCGR181_SETTING0) | BF_CCM_CCGR181_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR181, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR181_SETTING1 (4U)       /*!< Bit position for CCM_CCGR181_SETTING1. */
#define BM_CCM_CCGR181_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR181_SETTING1. */
#define BS_CCM_CCGR181_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR181_SETTING1. */

/*! @brief Read current value of the CCM_CCGR181_SETTING1 field. */
#define BR_CCM_CCGR181_SETTING1(x) (HW_CCM_CCGR181(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR181_SETTING1. */
#define BF_CCM_CCGR181_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR181_SETTING1) & BM_CCM_CCGR181_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR181_SETTING1(x, v) (HW_CCM_CCGR181_WR(x, (HW_CCM_CCGR181_RD(x) & ~BM_CCM_CCGR181_SETTING1) | BF_CCM_CCGR181_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR181, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR181_SETTING2 (8U)       /*!< Bit position for CCM_CCGR181_SETTING2. */
#define BM_CCM_CCGR181_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR181_SETTING2. */
#define BS_CCM_CCGR181_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR181_SETTING2. */

/*! @brief Read current value of the CCM_CCGR181_SETTING2 field. */
#define BR_CCM_CCGR181_SETTING2(x) (HW_CCM_CCGR181(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR181_SETTING2. */
#define BF_CCM_CCGR181_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR181_SETTING2) & BM_CCM_CCGR181_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR181_SETTING2(x, v) (HW_CCM_CCGR181_WR(x, (HW_CCM_CCGR181_RD(x) & ~BM_CCM_CCGR181_SETTING2) | BF_CCM_CCGR181_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR181, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR181_SETTING3 (12U)      /*!< Bit position for CCM_CCGR181_SETTING3. */
#define BM_CCM_CCGR181_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR181_SETTING3. */
#define BS_CCM_CCGR181_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR181_SETTING3. */

/*! @brief Read current value of the CCM_CCGR181_SETTING3 field. */
#define BR_CCM_CCGR181_SETTING3(x) (HW_CCM_CCGR181(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR181_SETTING3. */
#define BF_CCM_CCGR181_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR181_SETTING3) & BM_CCM_CCGR181_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR181_SETTING3(x, v) (HW_CCM_CCGR181_WR(x, (HW_CCM_CCGR181_RD(x) & ~BM_CCM_CCGR181_SETTING3) | BF_CCM_CCGR181_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR182 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR182 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr182
{
    uint32_t U;
    struct _hw_ccm_ccgr182_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr182_t;

/*!
 * @name Constants and macros for entire CCM_CCGR182 register
 */
/*@{*/
#define HW_CCM_CCGR182_ADDR(x)   ((uintptr_t)(x) + 0x4B60U)
#define HW_CCM_CCGR182_SET_ADDR(x) (HW_CCM_CCGR182_ADDR(x) + 0x4U)
#define HW_CCM_CCGR182_CLR_ADDR(x) (HW_CCM_CCGR182_ADDR(x) + 0x8U)
#define HW_CCM_CCGR182_TOG_ADDR(x) (HW_CCM_CCGR182_ADDR(x) + 0xCU)

#define HW_CCM_CCGR182(x)        (*(__IO hw_ccm_ccgr182_t *) HW_CCM_CCGR182_ADDR(x))
#define HW_CCM_CCGR182_RD(x)     (HW_CCM_CCGR182(x).U)
#define HW_CCM_CCGR182_WR(x, v)  (HW_CCM_CCGR182(x).U = (v))
#define HW_CCM_CCGR182_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR182_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR182_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR182_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR182_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR182_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR182 bitfields
 */

/*!
 * @name Register CCM_CCGR182, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR182_SETTING0 (0U)       /*!< Bit position for CCM_CCGR182_SETTING0. */
#define BM_CCM_CCGR182_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR182_SETTING0. */
#define BS_CCM_CCGR182_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR182_SETTING0. */

/*! @brief Read current value of the CCM_CCGR182_SETTING0 field. */
#define BR_CCM_CCGR182_SETTING0(x) (HW_CCM_CCGR182(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR182_SETTING0. */
#define BF_CCM_CCGR182_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR182_SETTING0) & BM_CCM_CCGR182_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR182_SETTING0(x, v) (HW_CCM_CCGR182_WR(x, (HW_CCM_CCGR182_RD(x) & ~BM_CCM_CCGR182_SETTING0) | BF_CCM_CCGR182_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR182, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR182_SETTING1 (4U)       /*!< Bit position for CCM_CCGR182_SETTING1. */
#define BM_CCM_CCGR182_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR182_SETTING1. */
#define BS_CCM_CCGR182_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR182_SETTING1. */

/*! @brief Read current value of the CCM_CCGR182_SETTING1 field. */
#define BR_CCM_CCGR182_SETTING1(x) (HW_CCM_CCGR182(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR182_SETTING1. */
#define BF_CCM_CCGR182_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR182_SETTING1) & BM_CCM_CCGR182_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR182_SETTING1(x, v) (HW_CCM_CCGR182_WR(x, (HW_CCM_CCGR182_RD(x) & ~BM_CCM_CCGR182_SETTING1) | BF_CCM_CCGR182_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR182, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR182_SETTING2 (8U)       /*!< Bit position for CCM_CCGR182_SETTING2. */
#define BM_CCM_CCGR182_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR182_SETTING2. */
#define BS_CCM_CCGR182_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR182_SETTING2. */

/*! @brief Read current value of the CCM_CCGR182_SETTING2 field. */
#define BR_CCM_CCGR182_SETTING2(x) (HW_CCM_CCGR182(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR182_SETTING2. */
#define BF_CCM_CCGR182_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR182_SETTING2) & BM_CCM_CCGR182_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR182_SETTING2(x, v) (HW_CCM_CCGR182_WR(x, (HW_CCM_CCGR182_RD(x) & ~BM_CCM_CCGR182_SETTING2) | BF_CCM_CCGR182_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR182, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR182_SETTING3 (12U)      /*!< Bit position for CCM_CCGR182_SETTING3. */
#define BM_CCM_CCGR182_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR182_SETTING3. */
#define BS_CCM_CCGR182_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR182_SETTING3. */

/*! @brief Read current value of the CCM_CCGR182_SETTING3 field. */
#define BR_CCM_CCGR182_SETTING3(x) (HW_CCM_CCGR182(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR182_SETTING3. */
#define BF_CCM_CCGR182_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR182_SETTING3) & BM_CCM_CCGR182_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR182_SETTING3(x, v) (HW_CCM_CCGR182_WR(x, (HW_CCM_CCGR182_RD(x) & ~BM_CCM_CCGR182_SETTING3) | BF_CCM_CCGR182_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR183 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR183 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr183
{
    uint32_t U;
    struct _hw_ccm_ccgr183_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr183_t;

/*!
 * @name Constants and macros for entire CCM_CCGR183 register
 */
/*@{*/
#define HW_CCM_CCGR183_ADDR(x)   ((uintptr_t)(x) + 0x4B70U)
#define HW_CCM_CCGR183_SET_ADDR(x) (HW_CCM_CCGR183_ADDR(x) + 0x4U)
#define HW_CCM_CCGR183_CLR_ADDR(x) (HW_CCM_CCGR183_ADDR(x) + 0x8U)
#define HW_CCM_CCGR183_TOG_ADDR(x) (HW_CCM_CCGR183_ADDR(x) + 0xCU)

#define HW_CCM_CCGR183(x)        (*(__IO hw_ccm_ccgr183_t *) HW_CCM_CCGR183_ADDR(x))
#define HW_CCM_CCGR183_RD(x)     (HW_CCM_CCGR183(x).U)
#define HW_CCM_CCGR183_WR(x, v)  (HW_CCM_CCGR183(x).U = (v))
#define HW_CCM_CCGR183_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR183_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR183_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR183_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR183_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR183_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR183 bitfields
 */

/*!
 * @name Register CCM_CCGR183, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR183_SETTING0 (0U)       /*!< Bit position for CCM_CCGR183_SETTING0. */
#define BM_CCM_CCGR183_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR183_SETTING0. */
#define BS_CCM_CCGR183_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR183_SETTING0. */

/*! @brief Read current value of the CCM_CCGR183_SETTING0 field. */
#define BR_CCM_CCGR183_SETTING0(x) (HW_CCM_CCGR183(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR183_SETTING0. */
#define BF_CCM_CCGR183_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR183_SETTING0) & BM_CCM_CCGR183_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR183_SETTING0(x, v) (HW_CCM_CCGR183_WR(x, (HW_CCM_CCGR183_RD(x) & ~BM_CCM_CCGR183_SETTING0) | BF_CCM_CCGR183_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR183, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR183_SETTING1 (4U)       /*!< Bit position for CCM_CCGR183_SETTING1. */
#define BM_CCM_CCGR183_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR183_SETTING1. */
#define BS_CCM_CCGR183_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR183_SETTING1. */

/*! @brief Read current value of the CCM_CCGR183_SETTING1 field. */
#define BR_CCM_CCGR183_SETTING1(x) (HW_CCM_CCGR183(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR183_SETTING1. */
#define BF_CCM_CCGR183_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR183_SETTING1) & BM_CCM_CCGR183_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR183_SETTING1(x, v) (HW_CCM_CCGR183_WR(x, (HW_CCM_CCGR183_RD(x) & ~BM_CCM_CCGR183_SETTING1) | BF_CCM_CCGR183_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR183, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR183_SETTING2 (8U)       /*!< Bit position for CCM_CCGR183_SETTING2. */
#define BM_CCM_CCGR183_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR183_SETTING2. */
#define BS_CCM_CCGR183_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR183_SETTING2. */

/*! @brief Read current value of the CCM_CCGR183_SETTING2 field. */
#define BR_CCM_CCGR183_SETTING2(x) (HW_CCM_CCGR183(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR183_SETTING2. */
#define BF_CCM_CCGR183_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR183_SETTING2) & BM_CCM_CCGR183_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR183_SETTING2(x, v) (HW_CCM_CCGR183_WR(x, (HW_CCM_CCGR183_RD(x) & ~BM_CCM_CCGR183_SETTING2) | BF_CCM_CCGR183_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR183, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR183_SETTING3 (12U)      /*!< Bit position for CCM_CCGR183_SETTING3. */
#define BM_CCM_CCGR183_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR183_SETTING3. */
#define BS_CCM_CCGR183_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR183_SETTING3. */

/*! @brief Read current value of the CCM_CCGR183_SETTING3 field. */
#define BR_CCM_CCGR183_SETTING3(x) (HW_CCM_CCGR183(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR183_SETTING3. */
#define BF_CCM_CCGR183_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR183_SETTING3) & BM_CCM_CCGR183_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR183_SETTING3(x, v) (HW_CCM_CCGR183_WR(x, (HW_CCM_CCGR183_RD(x) & ~BM_CCM_CCGR183_SETTING3) | BF_CCM_CCGR183_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR184 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR184 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr184
{
    uint32_t U;
    struct _hw_ccm_ccgr184_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr184_t;

/*!
 * @name Constants and macros for entire CCM_CCGR184 register
 */
/*@{*/
#define HW_CCM_CCGR184_ADDR(x)   ((uintptr_t)(x) + 0x4B80U)
#define HW_CCM_CCGR184_SET_ADDR(x) (HW_CCM_CCGR184_ADDR(x) + 0x4U)
#define HW_CCM_CCGR184_CLR_ADDR(x) (HW_CCM_CCGR184_ADDR(x) + 0x8U)
#define HW_CCM_CCGR184_TOG_ADDR(x) (HW_CCM_CCGR184_ADDR(x) + 0xCU)

#define HW_CCM_CCGR184(x)        (*(__IO hw_ccm_ccgr184_t *) HW_CCM_CCGR184_ADDR(x))
#define HW_CCM_CCGR184_RD(x)     (HW_CCM_CCGR184(x).U)
#define HW_CCM_CCGR184_WR(x, v)  (HW_CCM_CCGR184(x).U = (v))
#define HW_CCM_CCGR184_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR184_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR184_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR184_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR184_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR184_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR184 bitfields
 */

/*!
 * @name Register CCM_CCGR184, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR184_SETTING0 (0U)       /*!< Bit position for CCM_CCGR184_SETTING0. */
#define BM_CCM_CCGR184_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR184_SETTING0. */
#define BS_CCM_CCGR184_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR184_SETTING0. */

/*! @brief Read current value of the CCM_CCGR184_SETTING0 field. */
#define BR_CCM_CCGR184_SETTING0(x) (HW_CCM_CCGR184(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR184_SETTING0. */
#define BF_CCM_CCGR184_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR184_SETTING0) & BM_CCM_CCGR184_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR184_SETTING0(x, v) (HW_CCM_CCGR184_WR(x, (HW_CCM_CCGR184_RD(x) & ~BM_CCM_CCGR184_SETTING0) | BF_CCM_CCGR184_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR184, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR184_SETTING1 (4U)       /*!< Bit position for CCM_CCGR184_SETTING1. */
#define BM_CCM_CCGR184_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR184_SETTING1. */
#define BS_CCM_CCGR184_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR184_SETTING1. */

/*! @brief Read current value of the CCM_CCGR184_SETTING1 field. */
#define BR_CCM_CCGR184_SETTING1(x) (HW_CCM_CCGR184(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR184_SETTING1. */
#define BF_CCM_CCGR184_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR184_SETTING1) & BM_CCM_CCGR184_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR184_SETTING1(x, v) (HW_CCM_CCGR184_WR(x, (HW_CCM_CCGR184_RD(x) & ~BM_CCM_CCGR184_SETTING1) | BF_CCM_CCGR184_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR184, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR184_SETTING2 (8U)       /*!< Bit position for CCM_CCGR184_SETTING2. */
#define BM_CCM_CCGR184_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR184_SETTING2. */
#define BS_CCM_CCGR184_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR184_SETTING2. */

/*! @brief Read current value of the CCM_CCGR184_SETTING2 field. */
#define BR_CCM_CCGR184_SETTING2(x) (HW_CCM_CCGR184(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR184_SETTING2. */
#define BF_CCM_CCGR184_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR184_SETTING2) & BM_CCM_CCGR184_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR184_SETTING2(x, v) (HW_CCM_CCGR184_WR(x, (HW_CCM_CCGR184_RD(x) & ~BM_CCM_CCGR184_SETTING2) | BF_CCM_CCGR184_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR184, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR184_SETTING3 (12U)      /*!< Bit position for CCM_CCGR184_SETTING3. */
#define BM_CCM_CCGR184_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR184_SETTING3. */
#define BS_CCM_CCGR184_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR184_SETTING3. */

/*! @brief Read current value of the CCM_CCGR184_SETTING3 field. */
#define BR_CCM_CCGR184_SETTING3(x) (HW_CCM_CCGR184(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR184_SETTING3. */
#define BF_CCM_CCGR184_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR184_SETTING3) & BM_CCM_CCGR184_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR184_SETTING3(x, v) (HW_CCM_CCGR184_WR(x, (HW_CCM_CCGR184_RD(x) & ~BM_CCM_CCGR184_SETTING3) | BF_CCM_CCGR184_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR185 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR185 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr185
{
    uint32_t U;
    struct _hw_ccm_ccgr185_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr185_t;

/*!
 * @name Constants and macros for entire CCM_CCGR185 register
 */
/*@{*/
#define HW_CCM_CCGR185_ADDR(x)   ((uintptr_t)(x) + 0x4B90U)
#define HW_CCM_CCGR185_SET_ADDR(x) (HW_CCM_CCGR185_ADDR(x) + 0x4U)
#define HW_CCM_CCGR185_CLR_ADDR(x) (HW_CCM_CCGR185_ADDR(x) + 0x8U)
#define HW_CCM_CCGR185_TOG_ADDR(x) (HW_CCM_CCGR185_ADDR(x) + 0xCU)

#define HW_CCM_CCGR185(x)        (*(__IO hw_ccm_ccgr185_t *) HW_CCM_CCGR185_ADDR(x))
#define HW_CCM_CCGR185_RD(x)     (HW_CCM_CCGR185(x).U)
#define HW_CCM_CCGR185_WR(x, v)  (HW_CCM_CCGR185(x).U = (v))
#define HW_CCM_CCGR185_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR185_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR185_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR185_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR185_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR185_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR185 bitfields
 */

/*!
 * @name Register CCM_CCGR185, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR185_SETTING0 (0U)       /*!< Bit position for CCM_CCGR185_SETTING0. */
#define BM_CCM_CCGR185_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR185_SETTING0. */
#define BS_CCM_CCGR185_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR185_SETTING0. */

/*! @brief Read current value of the CCM_CCGR185_SETTING0 field. */
#define BR_CCM_CCGR185_SETTING0(x) (HW_CCM_CCGR185(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR185_SETTING0. */
#define BF_CCM_CCGR185_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR185_SETTING0) & BM_CCM_CCGR185_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR185_SETTING0(x, v) (HW_CCM_CCGR185_WR(x, (HW_CCM_CCGR185_RD(x) & ~BM_CCM_CCGR185_SETTING0) | BF_CCM_CCGR185_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR185, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR185_SETTING1 (4U)       /*!< Bit position for CCM_CCGR185_SETTING1. */
#define BM_CCM_CCGR185_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR185_SETTING1. */
#define BS_CCM_CCGR185_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR185_SETTING1. */

/*! @brief Read current value of the CCM_CCGR185_SETTING1 field. */
#define BR_CCM_CCGR185_SETTING1(x) (HW_CCM_CCGR185(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR185_SETTING1. */
#define BF_CCM_CCGR185_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR185_SETTING1) & BM_CCM_CCGR185_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR185_SETTING1(x, v) (HW_CCM_CCGR185_WR(x, (HW_CCM_CCGR185_RD(x) & ~BM_CCM_CCGR185_SETTING1) | BF_CCM_CCGR185_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR185, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR185_SETTING2 (8U)       /*!< Bit position for CCM_CCGR185_SETTING2. */
#define BM_CCM_CCGR185_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR185_SETTING2. */
#define BS_CCM_CCGR185_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR185_SETTING2. */

/*! @brief Read current value of the CCM_CCGR185_SETTING2 field. */
#define BR_CCM_CCGR185_SETTING2(x) (HW_CCM_CCGR185(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR185_SETTING2. */
#define BF_CCM_CCGR185_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR185_SETTING2) & BM_CCM_CCGR185_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR185_SETTING2(x, v) (HW_CCM_CCGR185_WR(x, (HW_CCM_CCGR185_RD(x) & ~BM_CCM_CCGR185_SETTING2) | BF_CCM_CCGR185_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR185, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR185_SETTING3 (12U)      /*!< Bit position for CCM_CCGR185_SETTING3. */
#define BM_CCM_CCGR185_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR185_SETTING3. */
#define BS_CCM_CCGR185_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR185_SETTING3. */

/*! @brief Read current value of the CCM_CCGR185_SETTING3 field. */
#define BR_CCM_CCGR185_SETTING3(x) (HW_CCM_CCGR185(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR185_SETTING3. */
#define BF_CCM_CCGR185_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR185_SETTING3) & BM_CCM_CCGR185_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR185_SETTING3(x, v) (HW_CCM_CCGR185_WR(x, (HW_CCM_CCGR185_RD(x) & ~BM_CCM_CCGR185_SETTING3) | BF_CCM_CCGR185_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR186 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR186 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr186
{
    uint32_t U;
    struct _hw_ccm_ccgr186_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr186_t;

/*!
 * @name Constants and macros for entire CCM_CCGR186 register
 */
/*@{*/
#define HW_CCM_CCGR186_ADDR(x)   ((uintptr_t)(x) + 0x4BA0U)
#define HW_CCM_CCGR186_SET_ADDR(x) (HW_CCM_CCGR186_ADDR(x) + 0x4U)
#define HW_CCM_CCGR186_CLR_ADDR(x) (HW_CCM_CCGR186_ADDR(x) + 0x8U)
#define HW_CCM_CCGR186_TOG_ADDR(x) (HW_CCM_CCGR186_ADDR(x) + 0xCU)

#define HW_CCM_CCGR186(x)        (*(__IO hw_ccm_ccgr186_t *) HW_CCM_CCGR186_ADDR(x))
#define HW_CCM_CCGR186_RD(x)     (HW_CCM_CCGR186(x).U)
#define HW_CCM_CCGR186_WR(x, v)  (HW_CCM_CCGR186(x).U = (v))
#define HW_CCM_CCGR186_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR186_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR186_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR186_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR186_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR186_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR186 bitfields
 */

/*!
 * @name Register CCM_CCGR186, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR186_SETTING0 (0U)       /*!< Bit position for CCM_CCGR186_SETTING0. */
#define BM_CCM_CCGR186_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR186_SETTING0. */
#define BS_CCM_CCGR186_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR186_SETTING0. */

/*! @brief Read current value of the CCM_CCGR186_SETTING0 field. */
#define BR_CCM_CCGR186_SETTING0(x) (HW_CCM_CCGR186(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR186_SETTING0. */
#define BF_CCM_CCGR186_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR186_SETTING0) & BM_CCM_CCGR186_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR186_SETTING0(x, v) (HW_CCM_CCGR186_WR(x, (HW_CCM_CCGR186_RD(x) & ~BM_CCM_CCGR186_SETTING0) | BF_CCM_CCGR186_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR186, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR186_SETTING1 (4U)       /*!< Bit position for CCM_CCGR186_SETTING1. */
#define BM_CCM_CCGR186_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR186_SETTING1. */
#define BS_CCM_CCGR186_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR186_SETTING1. */

/*! @brief Read current value of the CCM_CCGR186_SETTING1 field. */
#define BR_CCM_CCGR186_SETTING1(x) (HW_CCM_CCGR186(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR186_SETTING1. */
#define BF_CCM_CCGR186_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR186_SETTING1) & BM_CCM_CCGR186_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR186_SETTING1(x, v) (HW_CCM_CCGR186_WR(x, (HW_CCM_CCGR186_RD(x) & ~BM_CCM_CCGR186_SETTING1) | BF_CCM_CCGR186_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR186, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR186_SETTING2 (8U)       /*!< Bit position for CCM_CCGR186_SETTING2. */
#define BM_CCM_CCGR186_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR186_SETTING2. */
#define BS_CCM_CCGR186_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR186_SETTING2. */

/*! @brief Read current value of the CCM_CCGR186_SETTING2 field. */
#define BR_CCM_CCGR186_SETTING2(x) (HW_CCM_CCGR186(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR186_SETTING2. */
#define BF_CCM_CCGR186_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR186_SETTING2) & BM_CCM_CCGR186_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR186_SETTING2(x, v) (HW_CCM_CCGR186_WR(x, (HW_CCM_CCGR186_RD(x) & ~BM_CCM_CCGR186_SETTING2) | BF_CCM_CCGR186_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR186, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR186_SETTING3 (12U)      /*!< Bit position for CCM_CCGR186_SETTING3. */
#define BM_CCM_CCGR186_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR186_SETTING3. */
#define BS_CCM_CCGR186_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR186_SETTING3. */

/*! @brief Read current value of the CCM_CCGR186_SETTING3 field. */
#define BR_CCM_CCGR186_SETTING3(x) (HW_CCM_CCGR186(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR186_SETTING3. */
#define BF_CCM_CCGR186_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR186_SETTING3) & BM_CCM_CCGR186_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR186_SETTING3(x, v) (HW_CCM_CCGR186_WR(x, (HW_CCM_CCGR186_RD(x) & ~BM_CCM_CCGR186_SETTING3) | BF_CCM_CCGR186_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR187 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR187 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr187
{
    uint32_t U;
    struct _hw_ccm_ccgr187_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr187_t;

/*!
 * @name Constants and macros for entire CCM_CCGR187 register
 */
/*@{*/
#define HW_CCM_CCGR187_ADDR(x)   ((uintptr_t)(x) + 0x4BB0U)
#define HW_CCM_CCGR187_SET_ADDR(x) (HW_CCM_CCGR187_ADDR(x) + 0x4U)
#define HW_CCM_CCGR187_CLR_ADDR(x) (HW_CCM_CCGR187_ADDR(x) + 0x8U)
#define HW_CCM_CCGR187_TOG_ADDR(x) (HW_CCM_CCGR187_ADDR(x) + 0xCU)

#define HW_CCM_CCGR187(x)        (*(__IO hw_ccm_ccgr187_t *) HW_CCM_CCGR187_ADDR(x))
#define HW_CCM_CCGR187_RD(x)     (HW_CCM_CCGR187(x).U)
#define HW_CCM_CCGR187_WR(x, v)  (HW_CCM_CCGR187(x).U = (v))
#define HW_CCM_CCGR187_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR187_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR187_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR187_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR187_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR187_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR187 bitfields
 */

/*!
 * @name Register CCM_CCGR187, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR187_SETTING0 (0U)       /*!< Bit position for CCM_CCGR187_SETTING0. */
#define BM_CCM_CCGR187_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR187_SETTING0. */
#define BS_CCM_CCGR187_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR187_SETTING0. */

/*! @brief Read current value of the CCM_CCGR187_SETTING0 field. */
#define BR_CCM_CCGR187_SETTING0(x) (HW_CCM_CCGR187(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR187_SETTING0. */
#define BF_CCM_CCGR187_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR187_SETTING0) & BM_CCM_CCGR187_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR187_SETTING0(x, v) (HW_CCM_CCGR187_WR(x, (HW_CCM_CCGR187_RD(x) & ~BM_CCM_CCGR187_SETTING0) | BF_CCM_CCGR187_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR187, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR187_SETTING1 (4U)       /*!< Bit position for CCM_CCGR187_SETTING1. */
#define BM_CCM_CCGR187_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR187_SETTING1. */
#define BS_CCM_CCGR187_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR187_SETTING1. */

/*! @brief Read current value of the CCM_CCGR187_SETTING1 field. */
#define BR_CCM_CCGR187_SETTING1(x) (HW_CCM_CCGR187(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR187_SETTING1. */
#define BF_CCM_CCGR187_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR187_SETTING1) & BM_CCM_CCGR187_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR187_SETTING1(x, v) (HW_CCM_CCGR187_WR(x, (HW_CCM_CCGR187_RD(x) & ~BM_CCM_CCGR187_SETTING1) | BF_CCM_CCGR187_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR187, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR187_SETTING2 (8U)       /*!< Bit position for CCM_CCGR187_SETTING2. */
#define BM_CCM_CCGR187_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR187_SETTING2. */
#define BS_CCM_CCGR187_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR187_SETTING2. */

/*! @brief Read current value of the CCM_CCGR187_SETTING2 field. */
#define BR_CCM_CCGR187_SETTING2(x) (HW_CCM_CCGR187(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR187_SETTING2. */
#define BF_CCM_CCGR187_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR187_SETTING2) & BM_CCM_CCGR187_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR187_SETTING2(x, v) (HW_CCM_CCGR187_WR(x, (HW_CCM_CCGR187_RD(x) & ~BM_CCM_CCGR187_SETTING2) | BF_CCM_CCGR187_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR187, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR187_SETTING3 (12U)      /*!< Bit position for CCM_CCGR187_SETTING3. */
#define BM_CCM_CCGR187_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR187_SETTING3. */
#define BS_CCM_CCGR187_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR187_SETTING3. */

/*! @brief Read current value of the CCM_CCGR187_SETTING3 field. */
#define BR_CCM_CCGR187_SETTING3(x) (HW_CCM_CCGR187(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR187_SETTING3. */
#define BF_CCM_CCGR187_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR187_SETTING3) & BM_CCM_CCGR187_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR187_SETTING3(x, v) (HW_CCM_CCGR187_WR(x, (HW_CCM_CCGR187_RD(x) & ~BM_CCM_CCGR187_SETTING3) | BF_CCM_CCGR187_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR188 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR188 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr188
{
    uint32_t U;
    struct _hw_ccm_ccgr188_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr188_t;

/*!
 * @name Constants and macros for entire CCM_CCGR188 register
 */
/*@{*/
#define HW_CCM_CCGR188_ADDR(x)   ((uintptr_t)(x) + 0x4BC0U)
#define HW_CCM_CCGR188_SET_ADDR(x) (HW_CCM_CCGR188_ADDR(x) + 0x4U)
#define HW_CCM_CCGR188_CLR_ADDR(x) (HW_CCM_CCGR188_ADDR(x) + 0x8U)
#define HW_CCM_CCGR188_TOG_ADDR(x) (HW_CCM_CCGR188_ADDR(x) + 0xCU)

#define HW_CCM_CCGR188(x)        (*(__IO hw_ccm_ccgr188_t *) HW_CCM_CCGR188_ADDR(x))
#define HW_CCM_CCGR188_RD(x)     (HW_CCM_CCGR188(x).U)
#define HW_CCM_CCGR188_WR(x, v)  (HW_CCM_CCGR188(x).U = (v))
#define HW_CCM_CCGR188_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR188_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR188_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR188_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR188_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR188_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR188 bitfields
 */

/*!
 * @name Register CCM_CCGR188, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR188_SETTING0 (0U)       /*!< Bit position for CCM_CCGR188_SETTING0. */
#define BM_CCM_CCGR188_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR188_SETTING0. */
#define BS_CCM_CCGR188_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR188_SETTING0. */

/*! @brief Read current value of the CCM_CCGR188_SETTING0 field. */
#define BR_CCM_CCGR188_SETTING0(x) (HW_CCM_CCGR188(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR188_SETTING0. */
#define BF_CCM_CCGR188_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR188_SETTING0) & BM_CCM_CCGR188_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR188_SETTING0(x, v) (HW_CCM_CCGR188_WR(x, (HW_CCM_CCGR188_RD(x) & ~BM_CCM_CCGR188_SETTING0) | BF_CCM_CCGR188_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR188, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR188_SETTING1 (4U)       /*!< Bit position for CCM_CCGR188_SETTING1. */
#define BM_CCM_CCGR188_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR188_SETTING1. */
#define BS_CCM_CCGR188_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR188_SETTING1. */

/*! @brief Read current value of the CCM_CCGR188_SETTING1 field. */
#define BR_CCM_CCGR188_SETTING1(x) (HW_CCM_CCGR188(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR188_SETTING1. */
#define BF_CCM_CCGR188_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR188_SETTING1) & BM_CCM_CCGR188_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR188_SETTING1(x, v) (HW_CCM_CCGR188_WR(x, (HW_CCM_CCGR188_RD(x) & ~BM_CCM_CCGR188_SETTING1) | BF_CCM_CCGR188_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR188, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR188_SETTING2 (8U)       /*!< Bit position for CCM_CCGR188_SETTING2. */
#define BM_CCM_CCGR188_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR188_SETTING2. */
#define BS_CCM_CCGR188_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR188_SETTING2. */

/*! @brief Read current value of the CCM_CCGR188_SETTING2 field. */
#define BR_CCM_CCGR188_SETTING2(x) (HW_CCM_CCGR188(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR188_SETTING2. */
#define BF_CCM_CCGR188_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR188_SETTING2) & BM_CCM_CCGR188_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR188_SETTING2(x, v) (HW_CCM_CCGR188_WR(x, (HW_CCM_CCGR188_RD(x) & ~BM_CCM_CCGR188_SETTING2) | BF_CCM_CCGR188_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR188, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR188_SETTING3 (12U)      /*!< Bit position for CCM_CCGR188_SETTING3. */
#define BM_CCM_CCGR188_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR188_SETTING3. */
#define BS_CCM_CCGR188_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR188_SETTING3. */

/*! @brief Read current value of the CCM_CCGR188_SETTING3 field. */
#define BR_CCM_CCGR188_SETTING3(x) (HW_CCM_CCGR188(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR188_SETTING3. */
#define BF_CCM_CCGR188_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR188_SETTING3) & BM_CCM_CCGR188_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR188_SETTING3(x, v) (HW_CCM_CCGR188_WR(x, (HW_CCM_CCGR188_RD(x) & ~BM_CCM_CCGR188_SETTING3) | BF_CCM_CCGR188_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR189 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR189 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr189
{
    uint32_t U;
    struct _hw_ccm_ccgr189_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr189_t;

/*!
 * @name Constants and macros for entire CCM_CCGR189 register
 */
/*@{*/
#define HW_CCM_CCGR189_ADDR(x)   ((uintptr_t)(x) + 0x4BD0U)
#define HW_CCM_CCGR189_SET_ADDR(x) (HW_CCM_CCGR189_ADDR(x) + 0x4U)
#define HW_CCM_CCGR189_CLR_ADDR(x) (HW_CCM_CCGR189_ADDR(x) + 0x8U)
#define HW_CCM_CCGR189_TOG_ADDR(x) (HW_CCM_CCGR189_ADDR(x) + 0xCU)

#define HW_CCM_CCGR189(x)        (*(__IO hw_ccm_ccgr189_t *) HW_CCM_CCGR189_ADDR(x))
#define HW_CCM_CCGR189_RD(x)     (HW_CCM_CCGR189(x).U)
#define HW_CCM_CCGR189_WR(x, v)  (HW_CCM_CCGR189(x).U = (v))
#define HW_CCM_CCGR189_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR189_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR189_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR189_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR189_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR189_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR189 bitfields
 */

/*!
 * @name Register CCM_CCGR189, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR189_SETTING0 (0U)       /*!< Bit position for CCM_CCGR189_SETTING0. */
#define BM_CCM_CCGR189_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR189_SETTING0. */
#define BS_CCM_CCGR189_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR189_SETTING0. */

/*! @brief Read current value of the CCM_CCGR189_SETTING0 field. */
#define BR_CCM_CCGR189_SETTING0(x) (HW_CCM_CCGR189(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR189_SETTING0. */
#define BF_CCM_CCGR189_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR189_SETTING0) & BM_CCM_CCGR189_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR189_SETTING0(x, v) (HW_CCM_CCGR189_WR(x, (HW_CCM_CCGR189_RD(x) & ~BM_CCM_CCGR189_SETTING0) | BF_CCM_CCGR189_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR189, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR189_SETTING1 (4U)       /*!< Bit position for CCM_CCGR189_SETTING1. */
#define BM_CCM_CCGR189_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR189_SETTING1. */
#define BS_CCM_CCGR189_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR189_SETTING1. */

/*! @brief Read current value of the CCM_CCGR189_SETTING1 field. */
#define BR_CCM_CCGR189_SETTING1(x) (HW_CCM_CCGR189(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR189_SETTING1. */
#define BF_CCM_CCGR189_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR189_SETTING1) & BM_CCM_CCGR189_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR189_SETTING1(x, v) (HW_CCM_CCGR189_WR(x, (HW_CCM_CCGR189_RD(x) & ~BM_CCM_CCGR189_SETTING1) | BF_CCM_CCGR189_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR189, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR189_SETTING2 (8U)       /*!< Bit position for CCM_CCGR189_SETTING2. */
#define BM_CCM_CCGR189_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR189_SETTING2. */
#define BS_CCM_CCGR189_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR189_SETTING2. */

/*! @brief Read current value of the CCM_CCGR189_SETTING2 field. */
#define BR_CCM_CCGR189_SETTING2(x) (HW_CCM_CCGR189(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR189_SETTING2. */
#define BF_CCM_CCGR189_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR189_SETTING2) & BM_CCM_CCGR189_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR189_SETTING2(x, v) (HW_CCM_CCGR189_WR(x, (HW_CCM_CCGR189_RD(x) & ~BM_CCM_CCGR189_SETTING2) | BF_CCM_CCGR189_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR189, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR189_SETTING3 (12U)      /*!< Bit position for CCM_CCGR189_SETTING3. */
#define BM_CCM_CCGR189_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR189_SETTING3. */
#define BS_CCM_CCGR189_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR189_SETTING3. */

/*! @brief Read current value of the CCM_CCGR189_SETTING3 field. */
#define BR_CCM_CCGR189_SETTING3(x) (HW_CCM_CCGR189(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR189_SETTING3. */
#define BF_CCM_CCGR189_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR189_SETTING3) & BM_CCM_CCGR189_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR189_SETTING3(x, v) (HW_CCM_CCGR189_WR(x, (HW_CCM_CCGR189_RD(x) & ~BM_CCM_CCGR189_SETTING3) | BF_CCM_CCGR189_SETTING3(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_CCGR190 - CCM Clock Gating Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_CCGR190 - CCM Clock Gating Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * Not all CCGRs are mapped. See CCGR Interface for CCGR mapping and clock
 * gating information.
 */
typedef union _hw_ccm_ccgr190
{
    uint32_t U;
    struct _hw_ccm_ccgr190_bitfields
    {
        uint32_t SETTING0 : 2;         /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t SETTING1 : 2;         /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SETTING2 : 2;         /*!< [9:8]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t SETTING3 : 2;         /*!< [13:12]  */
        uint32_t RESERVED3 : 18;       /*!< [31:14]  */
    } B;
} hw_ccm_ccgr190_t;

/*!
 * @name Constants and macros for entire CCM_CCGR190 register
 */
/*@{*/
#define HW_CCM_CCGR190_ADDR(x)   ((uintptr_t)(x) + 0x4BE0U)
#define HW_CCM_CCGR190_SET_ADDR(x) (HW_CCM_CCGR190_ADDR(x) + 0x4U)
#define HW_CCM_CCGR190_CLR_ADDR(x) (HW_CCM_CCGR190_ADDR(x) + 0x8U)
#define HW_CCM_CCGR190_TOG_ADDR(x) (HW_CCM_CCGR190_ADDR(x) + 0xCU)

#define HW_CCM_CCGR190(x)        (*(__IO hw_ccm_ccgr190_t *) HW_CCM_CCGR190_ADDR(x))
#define HW_CCM_CCGR190_RD(x)     (HW_CCM_CCGR190(x).U)
#define HW_CCM_CCGR190_WR(x, v)  (HW_CCM_CCGR190(x).U = (v))
#define HW_CCM_CCGR190_SET(x, v) ((*(uint32_t *) HW_CCM_CCGR190_SET_ADDR(x)) = (v))
#define HW_CCM_CCGR190_CLR(x, v) ((*(uint32_t *) HW_CCM_CCGR190_CLR_ADDR(x)) = (v))
#define HW_CCM_CCGR190_TOG(x, v) ((*(uint32_t *) HW_CCM_CCGR190_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_CCGR190 bitfields
 */

/*!
 * @name Register CCM_CCGR190, field SETTING0[1:0] (RW)
 *
 * Clock gate control setting for domain 0. This field can only be written by
 * domain 0.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR190_SETTING0 (0U)       /*!< Bit position for CCM_CCGR190_SETTING0. */
#define BM_CCM_CCGR190_SETTING0 (0x00000003U) /*!< Bit mask for CCM_CCGR190_SETTING0. */
#define BS_CCM_CCGR190_SETTING0 (2U)       /*!< Bit field size in bits for CCM_CCGR190_SETTING0. */

/*! @brief Read current value of the CCM_CCGR190_SETTING0 field. */
#define BR_CCM_CCGR190_SETTING0(x) (HW_CCM_CCGR190(x).B.SETTING0)

/*! @brief Format value for bitfield CCM_CCGR190_SETTING0. */
#define BF_CCM_CCGR190_SETTING0(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR190_SETTING0) & BM_CCM_CCGR190_SETTING0)

/*! @brief Set the SETTING0 field to a new value. */
#define BW_CCM_CCGR190_SETTING0(x, v) (HW_CCM_CCGR190_WR(x, (HW_CCM_CCGR190_RD(x) & ~BM_CCM_CCGR190_SETTING0) | BF_CCM_CCGR190_SETTING0(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR190, field SETTING1[5:4] (RW)
 *
 * Clock gate control setting for domain 1. This field can only be written by
 * domain 1.
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR190_SETTING1 (4U)       /*!< Bit position for CCM_CCGR190_SETTING1. */
#define BM_CCM_CCGR190_SETTING1 (0x00000030U) /*!< Bit mask for CCM_CCGR190_SETTING1. */
#define BS_CCM_CCGR190_SETTING1 (2U)       /*!< Bit field size in bits for CCM_CCGR190_SETTING1. */

/*! @brief Read current value of the CCM_CCGR190_SETTING1 field. */
#define BR_CCM_CCGR190_SETTING1(x) (HW_CCM_CCGR190(x).B.SETTING1)

/*! @brief Format value for bitfield CCM_CCGR190_SETTING1. */
#define BF_CCM_CCGR190_SETTING1(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR190_SETTING1) & BM_CCM_CCGR190_SETTING1)

/*! @brief Set the SETTING1 field to a new value. */
#define BW_CCM_CCGR190_SETTING1(x, v) (HW_CCM_CCGR190_WR(x, (HW_CCM_CCGR190_RD(x) & ~BM_CCM_CCGR190_SETTING1) | BF_CCM_CCGR190_SETTING1(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR190, field SETTING2[9:8] (RW)
 *
 * Clock gate control setting for domain 2. This field can only be written by
 * domain 2
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR190_SETTING2 (8U)       /*!< Bit position for CCM_CCGR190_SETTING2. */
#define BM_CCM_CCGR190_SETTING2 (0x00000300U) /*!< Bit mask for CCM_CCGR190_SETTING2. */
#define BS_CCM_CCGR190_SETTING2 (2U)       /*!< Bit field size in bits for CCM_CCGR190_SETTING2. */

/*! @brief Read current value of the CCM_CCGR190_SETTING2 field. */
#define BR_CCM_CCGR190_SETTING2(x) (HW_CCM_CCGR190(x).B.SETTING2)

/*! @brief Format value for bitfield CCM_CCGR190_SETTING2. */
#define BF_CCM_CCGR190_SETTING2(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR190_SETTING2) & BM_CCM_CCGR190_SETTING2)

/*! @brief Set the SETTING2 field to a new value. */
#define BW_CCM_CCGR190_SETTING2(x, v) (HW_CCM_CCGR190_WR(x, (HW_CCM_CCGR190_RD(x) & ~BM_CCM_CCGR190_SETTING2) | BF_CCM_CCGR190_SETTING2(v)))
/*@}*/

/*!
 * @name Register CCM_CCGR190, field SETTING3[13:12] (RW)
 *
 * Clock gate control setting for domain 3. This field can only be written by
 * domain 3
 *
 * Values:
 * - 00 - Domain clocks not needed
 * - 01 - Domain clocks needed when in RUN
 * - 10 - Domain clocks needed when in RUN and WAIT
 * - 11 - Domain clocks needed all the time
 */
/*@{*/
#define BP_CCM_CCGR190_SETTING3 (12U)      /*!< Bit position for CCM_CCGR190_SETTING3. */
#define BM_CCM_CCGR190_SETTING3 (0x00003000U) /*!< Bit mask for CCM_CCGR190_SETTING3. */
#define BS_CCM_CCGR190_SETTING3 (2U)       /*!< Bit field size in bits for CCM_CCGR190_SETTING3. */

/*! @brief Read current value of the CCM_CCGR190_SETTING3 field. */
#define BR_CCM_CCGR190_SETTING3(x) (HW_CCM_CCGR190(x).B.SETTING3)

/*! @brief Format value for bitfield CCM_CCGR190_SETTING3. */
#define BF_CCM_CCGR190_SETTING3(v) ((uint32_t)((uint32_t)(v) << BP_CCM_CCGR190_SETTING3) & BM_CCM_CCGR190_SETTING3)

/*! @brief Set the SETTING3 field to a new value. */
#define BW_CCM_CCGR190_SETTING3(x, v) (HW_CCM_CCGR190_WR(x, (HW_CCM_CCGR190_RD(x) & ~BM_CCM_CCGR190_SETTING3) | BF_CCM_CCGR190_SETTING3(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_TARGET_ROOTn - Target Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_TARGET_ROOTn - Target Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * See Target Interface for more information. See Clock Root Selects for clock
 * root offsets and muxing information.
 */
typedef union _hw_ccm_target_rootn
{
    uint32_t U;
    struct _hw_ccm_target_rootn_bitfields
    {
        uint32_t POST_PODF : 6;        /*!< [5:0]  */
        uint32_t RESERVED0 : 10;       /*!< [15:6]  */
        uint32_t PRE_PODF : 3;         /*!< [18:16]  */
        uint32_t RESERVED1 : 5;        /*!< [23:19]  */
        uint32_t MUX : 3;              /*!< [26:24]  */
        uint32_t RESERVED2 : 1;        /*!< [27]  */
        uint32_t ENABLE : 1;           /*!< [28]  */
        uint32_t RESERVED3 : 3;        /*!< [31:29]  */
    } B;
} hw_ccm_target_rootn_t;

/*!
 * @name Constants and macros for entire CCM_TARGET_ROOTn register
 */
/*@{*/
#define HW_CCM_TARGET_ROOTn_COUNT (121U)

#define HW_CCM_TARGET_ROOTn_ADDR(x, n) ((uintptr_t)(x) + 0x8000U + (0x80U * (n)))
#define HW_CCM_TARGET_ROOTn_SET_ADDR(x, n) (HW_CCM_TARGET_ROOTn_ADDR(x, n) + 0x4U)
#define HW_CCM_TARGET_ROOTn_CLR_ADDR(x, n) (HW_CCM_TARGET_ROOTn_ADDR(x, n) + 0x8U)
#define HW_CCM_TARGET_ROOTn_TOG_ADDR(x, n) (HW_CCM_TARGET_ROOTn_ADDR(x, n) + 0xCU)

#define HW_CCM_TARGET_ROOTn(x, n) (*(__IO hw_ccm_target_rootn_t *) HW_CCM_TARGET_ROOTn_ADDR(x, n))
#define HW_CCM_TARGET_ROOTn_RD(x, n) (HW_CCM_TARGET_ROOTn(x, n).U)
#define HW_CCM_TARGET_ROOTn_WR(x, n, v) (HW_CCM_TARGET_ROOTn(x, n).U = (v))
#define HW_CCM_TARGET_ROOTn_SET(x, n, v) ((*(uint32_t *) HW_CCM_TARGET_ROOTn_SET_ADDR(x, n)) = (v))
#define HW_CCM_TARGET_ROOTn_CLR(x, n, v) ((*(uint32_t *) HW_CCM_TARGET_ROOTn_CLR_ADDR(x, n)) = (v))
#define HW_CCM_TARGET_ROOTn_TOG(x, n, v) ((*(uint32_t *) HW_CCM_TARGET_ROOTn_TOG_ADDR(x, n)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_TARGET_ROOTn bitfields
 */

/*!
 * @name Register CCM_TARGET_ROOTn, field POST_PODF[5:0] (RW)
 *
 * Post divider divide number Divider value is n + 1. For CORE, DRAM, this field
 * is 3 bit long. This field does not apply to DRAM_PHYM
 *
 * Values:
 * - 000000 - Divide by 1
 * - 000001 - Divide by 2
 * - 000010 - Divide by 3
 * - 000011 - Divide by 4
 * - 000100 - Divide by 5
 * - 000101 - Divide by 6
 * - 111111 - Divide by 64
 */
/*@{*/
#define BP_CCM_TARGET_ROOTn_POST_PODF (0U) /*!< Bit position for CCM_TARGET_ROOTn_POST_PODF. */
#define BM_CCM_TARGET_ROOTn_POST_PODF (0x0000003FU) /*!< Bit mask for CCM_TARGET_ROOTn_POST_PODF. */
#define BS_CCM_TARGET_ROOTn_POST_PODF (6U) /*!< Bit field size in bits for CCM_TARGET_ROOTn_POST_PODF. */

/*! @brief Read current value of the CCM_TARGET_ROOTn_POST_PODF field. */
#define BR_CCM_TARGET_ROOTn_POST_PODF(x, n) (HW_CCM_TARGET_ROOTn(x, n).B.POST_PODF)

/*! @brief Format value for bitfield CCM_TARGET_ROOTn_POST_PODF. */
#define BF_CCM_TARGET_ROOTn_POST_PODF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_TARGET_ROOTn_POST_PODF) & BM_CCM_TARGET_ROOTn_POST_PODF)

/*! @brief Set the POST_PODF field to a new value. */
#define BW_CCM_TARGET_ROOTn_POST_PODF(x, n, v) (HW_CCM_TARGET_ROOTn_WR(x, n, (HW_CCM_TARGET_ROOTn_RD(x, n) & ~BM_CCM_TARGET_ROOTn_POST_PODF) | BF_CCM_TARGET_ROOTn_POST_PODF(v)))
/*@}*/

/*!
 * @name Register CCM_TARGET_ROOTn, field PRE_PODF[18:16] (RW)
 *
 * Pre divider divide the number Divider value is n+1 This field does not apply
 * for CORE, DRAM, DRAM_PHYM
 *
 * Values:
 * - 000 - Divide by 1
 * - 001 - Divide by 2
 * - 010 - Divide by 3
 * - 011 - Divide by 4
 * - 100 - Divide by 5
 * - 101 - Divide by 6
 * - 110 - Divide by 7
 * - 111 - Divide by 8
 */
/*@{*/
#define BP_CCM_TARGET_ROOTn_PRE_PODF (16U) /*!< Bit position for CCM_TARGET_ROOTn_PRE_PODF. */
#define BM_CCM_TARGET_ROOTn_PRE_PODF (0x00070000U) /*!< Bit mask for CCM_TARGET_ROOTn_PRE_PODF. */
#define BS_CCM_TARGET_ROOTn_PRE_PODF (3U)  /*!< Bit field size in bits for CCM_TARGET_ROOTn_PRE_PODF. */

/*! @brief Read current value of the CCM_TARGET_ROOTn_PRE_PODF field. */
#define BR_CCM_TARGET_ROOTn_PRE_PODF(x, n) (HW_CCM_TARGET_ROOTn(x, n).B.PRE_PODF)

/*! @brief Format value for bitfield CCM_TARGET_ROOTn_PRE_PODF. */
#define BF_CCM_TARGET_ROOTn_PRE_PODF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_TARGET_ROOTn_PRE_PODF) & BM_CCM_TARGET_ROOTn_PRE_PODF)

/*! @brief Set the PRE_PODF field to a new value. */
#define BW_CCM_TARGET_ROOTn_PRE_PODF(x, n, v) (HW_CCM_TARGET_ROOTn_WR(x, n, (HW_CCM_TARGET_ROOTn_RD(x, n) & ~BM_CCM_TARGET_ROOTn_PRE_PODF) | BF_CCM_TARGET_ROOTn_PRE_PODF(v)))
/*@}*/

/*!
 * @name Register CCM_TARGET_ROOTn, field MUX[26:24] (RW)
 *
 * Selection of clock sources This field is 1 bit long for DRAM and DRAM_PHYM
 */
/*@{*/
#define BP_CCM_TARGET_ROOTn_MUX (24U)      /*!< Bit position for CCM_TARGET_ROOTn_MUX. */
#define BM_CCM_TARGET_ROOTn_MUX (0x07000000U) /*!< Bit mask for CCM_TARGET_ROOTn_MUX. */
#define BS_CCM_TARGET_ROOTn_MUX (3U)       /*!< Bit field size in bits for CCM_TARGET_ROOTn_MUX. */

/*! @brief Read current value of the CCM_TARGET_ROOTn_MUX field. */
#define BR_CCM_TARGET_ROOTn_MUX(x, n) (HW_CCM_TARGET_ROOTn(x, n).B.MUX)

/*! @brief Format value for bitfield CCM_TARGET_ROOTn_MUX. */
#define BF_CCM_TARGET_ROOTn_MUX(v) ((uint32_t)((uint32_t)(v) << BP_CCM_TARGET_ROOTn_MUX) & BM_CCM_TARGET_ROOTn_MUX)

/*! @brief Set the MUX field to a new value. */
#define BW_CCM_TARGET_ROOTn_MUX(x, n, v) (HW_CCM_TARGET_ROOTn_WR(x, n, (HW_CCM_TARGET_ROOTn_RD(x, n) & ~BM_CCM_TARGET_ROOTn_MUX) | BF_CCM_TARGET_ROOTn_MUX(v)))
/*@}*/

/*!
 * @name Register CCM_TARGET_ROOTn, field ENABLE[28] (RW)
 *
 * Enable this clock
 *
 * Values:
 * - 0 - clock root is OFF
 * - 1 - clock root is ON
 */
/*@{*/
#define BP_CCM_TARGET_ROOTn_ENABLE (28U)   /*!< Bit position for CCM_TARGET_ROOTn_ENABLE. */
#define BM_CCM_TARGET_ROOTn_ENABLE (0x10000000U) /*!< Bit mask for CCM_TARGET_ROOTn_ENABLE. */
#define BS_CCM_TARGET_ROOTn_ENABLE (1U)    /*!< Bit field size in bits for CCM_TARGET_ROOTn_ENABLE. */

/*! @brief Read current value of the CCM_TARGET_ROOTn_ENABLE field. */
#define BR_CCM_TARGET_ROOTn_ENABLE(x, n) (HW_CCM_TARGET_ROOTn(x, n).B.ENABLE)

/*! @brief Format value for bitfield CCM_TARGET_ROOTn_ENABLE. */
#define BF_CCM_TARGET_ROOTn_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_TARGET_ROOTn_ENABLE) & BM_CCM_TARGET_ROOTn_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_CCM_TARGET_ROOTn_ENABLE(x, n, v) (HW_CCM_TARGET_ROOTn_WR(x, n, (HW_CCM_TARGET_ROOTn_RD(x, n) & ~BM_CCM_TARGET_ROOTn_ENABLE) | BF_CCM_TARGET_ROOTn_ENABLE(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_MISCn - Miscellaneous Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_MISCn - Miscellaneous Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * MISC
 */
typedef union _hw_ccm_miscn
{
    uint32_t U;
    struct _hw_ccm_miscn_bitfields
    {
        uint32_t AUTHEN_FAIL : 1;      /*!< [0]  */
        uint32_t RESERVED0 : 3;        /*!< [3:1]  */
        uint32_t TIMEOUT : 1;          /*!< [4]  */
        uint32_t RESERVED1 : 3;        /*!< [7:5]  */
        uint32_t VIOLATE : 1;          /*!< [8]  */
        uint32_t RESERVED2 : 23;       /*!< [31:9]  */
    } B;
} hw_ccm_miscn_t;

/*!
 * @name Constants and macros for entire CCM_MISCn register
 */
/*@{*/
#define HW_CCM_MISCn_COUNT (121U)

#define HW_CCM_MISCn_ADDR(x, n)  ((uintptr_t)(x) + 0x8010U + (0x80U * (n)))

#define HW_CCM_MISCn(x, n)       (*(__IO hw_ccm_miscn_t *) HW_CCM_MISCn_ADDR(x, n))
#define HW_CCM_MISCn_RD(x, n)    (HW_CCM_MISCn(x, n).U)
#define HW_CCM_MISCn_WR(x, n, v) (HW_CCM_MISCn(x, n).U = (v))
#define HW_CCM_MISCn_SET(x, n, v) (HW_CCM_MISCn_WR(x, n, HW_CCM_MISCn_RD(x, n) |  (v)))
#define HW_CCM_MISCn_CLR(x, n, v) (HW_CCM_MISCn_WR(x, n, HW_CCM_MISCn_RD(x, n) & ~(v)))
#define HW_CCM_MISCn_TOG(x, n, v) (HW_CCM_MISCn_WR(x, n, HW_CCM_MISCn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_MISCn bitfields
 */

/*!
 * @name Register CCM_MISCn, field AUTHEN_FAIL[0] (RW)
 *
 * This sticky bit reflects access restricted by access control of this clock.
 * This bit has internal 4 bits, one for each domain. Authentic fail from other
 * domain is not visible or clearable. This file is cleared to 0 while write 1
 */
/*@{*/
#define BP_CCM_MISCn_AUTHEN_FAIL (0U)      /*!< Bit position for CCM_MISCn_AUTHEN_FAIL. */
#define BM_CCM_MISCn_AUTHEN_FAIL (0x00000001U) /*!< Bit mask for CCM_MISCn_AUTHEN_FAIL. */
#define BS_CCM_MISCn_AUTHEN_FAIL (1U)      /*!< Bit field size in bits for CCM_MISCn_AUTHEN_FAIL. */

/*! @brief Read current value of the CCM_MISCn_AUTHEN_FAIL field. */
#define BR_CCM_MISCn_AUTHEN_FAIL(x, n) (HW_CCM_MISCn(x, n).B.AUTHEN_FAIL)

/*! @brief Format value for bitfield CCM_MISCn_AUTHEN_FAIL. */
#define BF_CCM_MISCn_AUTHEN_FAIL(v) ((uint32_t)((uint32_t)(v) << BP_CCM_MISCn_AUTHEN_FAIL) & BM_CCM_MISCn_AUTHEN_FAIL)

/*! @brief Set the AUTHEN_FAIL field to a new value. */
#define BW_CCM_MISCn_AUTHEN_FAIL(x, n, v) (HW_CCM_MISCn_WR(x, n, (HW_CCM_MISCn_RD(x, n) & ~BM_CCM_MISCn_AUTHEN_FAIL) | BF_CCM_MISCn_AUTHEN_FAIL(v)))
/*@}*/

/*!
 * @name Register CCM_MISCn, field TIMEOUT[4] (RW)
 *
 * This sticky bit reflects time out happened during accessing this clock. This
 * bit has internal 4 bits, one for each domain. Timeout from other domain is not
 * visible or clearable. This file is cleared to 0 while write 1.
 */
/*@{*/
#define BP_CCM_MISCn_TIMEOUT (4U)          /*!< Bit position for CCM_MISCn_TIMEOUT. */
#define BM_CCM_MISCn_TIMEOUT (0x00000010U) /*!< Bit mask for CCM_MISCn_TIMEOUT. */
#define BS_CCM_MISCn_TIMEOUT (1U)          /*!< Bit field size in bits for CCM_MISCn_TIMEOUT. */

/*! @brief Read current value of the CCM_MISCn_TIMEOUT field. */
#define BR_CCM_MISCn_TIMEOUT(x, n) (HW_CCM_MISCn(x, n).B.TIMEOUT)

/*! @brief Format value for bitfield CCM_MISCn_TIMEOUT. */
#define BF_CCM_MISCn_TIMEOUT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_MISCn_TIMEOUT) & BM_CCM_MISCn_TIMEOUT)

/*! @brief Set the TIMEOUT field to a new value. */
#define BW_CCM_MISCn_TIMEOUT(x, n, v) (HW_CCM_MISCn_WR(x, n, (HW_CCM_MISCn_RD(x, n) & ~BM_CCM_MISCn_TIMEOUT) | BF_CCM_MISCn_TIMEOUT(v)))
/*@}*/

/*!
 * @name Register CCM_MISCn, field VIOLATE[8] (RW)
 *
 * This sticky bit reflects access violation in normal interface of this clock.
 * This bit has internal 4 bits, one for each domain. Violation from other domain
 * is not visible or clearable. This file is cleared to 0 while write 1.
 */
/*@{*/
#define BP_CCM_MISCn_VIOLATE (8U)          /*!< Bit position for CCM_MISCn_VIOLATE. */
#define BM_CCM_MISCn_VIOLATE (0x00000100U) /*!< Bit mask for CCM_MISCn_VIOLATE. */
#define BS_CCM_MISCn_VIOLATE (1U)          /*!< Bit field size in bits for CCM_MISCn_VIOLATE. */

/*! @brief Read current value of the CCM_MISCn_VIOLATE field. */
#define BR_CCM_MISCn_VIOLATE(x, n) (HW_CCM_MISCn(x, n).B.VIOLATE)

/*! @brief Format value for bitfield CCM_MISCn_VIOLATE. */
#define BF_CCM_MISCn_VIOLATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_MISCn_VIOLATE) & BM_CCM_MISCn_VIOLATE)

/*! @brief Set the VIOLATE field to a new value. */
#define BW_CCM_MISCn_VIOLATE(x, n, v) (HW_CCM_MISCn_WR(x, n, (HW_CCM_MISCn_RD(x, n) & ~BM_CCM_MISCn_VIOLATE) | BF_CCM_MISCn_VIOLATE(v)))
/*@}*/
/*******************************************************************************
 * HW_CCM_POSTn - Post Divider Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_POSTn - Post Divider Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Post Register
 */
typedef union _hw_ccm_postn
{
    uint32_t U;
    struct _hw_ccm_postn_bitfields
    {
        uint32_t POST_PODF : 6;        /*!< [5:0]  */
        uint32_t RESERVED0 : 1;        /*!< [6]  */
        uint32_t BUSY1 : 1;            /*!< [7]  */
        uint32_t RESERVED1 : 20;       /*!< [27:8]  */
        uint32_t SELECT : 1;           /*!< [28]  */
        uint32_t RESERVED2 : 2;        /*!< [30:29]  */
        uint32_t BUSY2 : 1;            /*!< [31]  */
    } B;
} hw_ccm_postn_t;

/*!
 * @name Constants and macros for entire CCM_POSTn register
 */
/*@{*/
#define HW_CCM_POSTn_COUNT (121U)

#define HW_CCM_POSTn_ADDR(x, n)  ((uintptr_t)(x) + 0x8020U + (0x80U * (n)))

#define HW_CCM_POSTn(x, n)       (*(__IO hw_ccm_postn_t *) HW_CCM_POSTn_ADDR(x, n))
#define HW_CCM_POSTn_RD(x, n)    (HW_CCM_POSTn(x, n).U)
#define HW_CCM_POSTn_WR(x, n, v) (HW_CCM_POSTn(x, n).U = (v))
#define HW_CCM_POSTn_SET(x, n, v) (HW_CCM_POSTn_WR(x, n, HW_CCM_POSTn_RD(x, n) |  (v)))
#define HW_CCM_POSTn_CLR(x, n, v) (HW_CCM_POSTn_WR(x, n, HW_CCM_POSTn_RD(x, n) & ~(v)))
#define HW_CCM_POSTn_TOG(x, n, v) (HW_CCM_POSTn_WR(x, n, HW_CCM_POSTn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_POSTn bitfields
 */

/*!
 * @name Register CCM_POSTn, field POST_PODF[5:0] (RW)
 *
 * Post divider divide the number Divider value is n + 1 For CORE, DRAM, this
 * field is 3 bit long. This field does not apply to DRAM_PHYM
 *
 * Values:
 * - 000000 - Divide by 1
 * - 000001 - Divide by 2
 * - 000010 - Divide by 3
 * - 000011 - Divide by 4
 * - 000100 - Divide by 5
 * - 000101 - Divide by 6
 * - 111111 - Divide by 64
 */
/*@{*/
#define BP_CCM_POSTn_POST_PODF (0U)        /*!< Bit position for CCM_POSTn_POST_PODF. */
#define BM_CCM_POSTn_POST_PODF (0x0000003FU) /*!< Bit mask for CCM_POSTn_POST_PODF. */
#define BS_CCM_POSTn_POST_PODF (6U)        /*!< Bit field size in bits for CCM_POSTn_POST_PODF. */

/*! @brief Read current value of the CCM_POSTn_POST_PODF field. */
#define BR_CCM_POSTn_POST_PODF(x, n) (HW_CCM_POSTn(x, n).B.POST_PODF)

/*! @brief Format value for bitfield CCM_POSTn_POST_PODF. */
#define BF_CCM_POSTn_POST_PODF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_POSTn_POST_PODF) & BM_CCM_POSTn_POST_PODF)

/*! @brief Set the POST_PODF field to a new value. */
#define BW_CCM_POSTn_POST_PODF(x, n, v) (HW_CCM_POSTn_WR(x, n, (HW_CCM_POSTn_RD(x, n) & ~BM_CCM_POSTn_POST_PODF) | BF_CCM_POSTn_POST_PODF(v)))
/*@}*/

/*!
 * @name Register CCM_POSTn, field BUSY1[7] (RO)
 *
 * Post divider is applying new set value
 */
/*@{*/
#define BP_CCM_POSTn_BUSY1   (7U)          /*!< Bit position for CCM_POSTn_BUSY1. */
#define BM_CCM_POSTn_BUSY1   (0x00000080U) /*!< Bit mask for CCM_POSTn_BUSY1. */
#define BS_CCM_POSTn_BUSY1   (1U)          /*!< Bit field size in bits for CCM_POSTn_BUSY1. */

/*! @brief Read current value of the CCM_POSTn_BUSY1 field. */
#define BR_CCM_POSTn_BUSY1(x, n) (HW_CCM_POSTn(x, n).B.BUSY1)
/*@}*/

/*!
 * @name Register CCM_POSTn, field SELECT[28] (RW)
 *
 * Selection of pre clock branches This field is not applied in IP
 *
 * Values:
 * - 0 - select branch A
 * - 1 - select branch B
 */
/*@{*/
#define BP_CCM_POSTn_SELECT  (28U)         /*!< Bit position for CCM_POSTn_SELECT. */
#define BM_CCM_POSTn_SELECT  (0x10000000U) /*!< Bit mask for CCM_POSTn_SELECT. */
#define BS_CCM_POSTn_SELECT  (1U)          /*!< Bit field size in bits for CCM_POSTn_SELECT. */

/*! @brief Read current value of the CCM_POSTn_SELECT field. */
#define BR_CCM_POSTn_SELECT(x, n) (HW_CCM_POSTn(x, n).B.SELECT)

/*! @brief Format value for bitfield CCM_POSTn_SELECT. */
#define BF_CCM_POSTn_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_POSTn_SELECT) & BM_CCM_POSTn_SELECT)

/*! @brief Set the SELECT field to a new value. */
#define BW_CCM_POSTn_SELECT(x, n, v) (HW_CCM_POSTn_WR(x, n, (HW_CCM_POSTn_RD(x, n) & ~BM_CCM_POSTn_SELECT) | BF_CCM_POSTn_SELECT(v)))
/*@}*/

/*!
 * @name Register CCM_POSTn, field BUSY2[31] (RO)
 *
 * Safe multiplexer is applying new setting
 */
/*@{*/
#define BP_CCM_POSTn_BUSY2   (31U)         /*!< Bit position for CCM_POSTn_BUSY2. */
#define BM_CCM_POSTn_BUSY2   (0x80000000U) /*!< Bit mask for CCM_POSTn_BUSY2. */
#define BS_CCM_POSTn_BUSY2   (1U)          /*!< Bit field size in bits for CCM_POSTn_BUSY2. */

/*! @brief Read current value of the CCM_POSTn_BUSY2 field. */
#define BR_CCM_POSTn_BUSY2(x, n) (HW_CCM_POSTn(x, n).B.BUSY2)
/*@}*/
/*******************************************************************************
 * HW_CCM_PREn - Pre Divider Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_PREn - Pre Divider Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Pre Register
 */
typedef union _hw_ccm_pren
{
    uint32_t U;
    struct _hw_ccm_pren_bitfields
    {
        uint32_t PRE_PODF_B : 3;       /*!< [2:0]  */
        uint32_t BUSY0 : 1;            /*!< [3]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t MUX_B : 3;            /*!< [10:8]  */
        uint32_t RESERVED1 : 1;        /*!< [11]  */
        uint32_t EN_B : 1;             /*!< [12]  */
        uint32_t RESERVED2 : 2;        /*!< [14:13]  */
        uint32_t BUSY1 : 1;            /*!< [15]  */
        uint32_t PRE_PODF_A : 3;       /*!< [18:16]  */
        uint32_t BUSY3 : 1;            /*!< [19]  */
        uint32_t RESERVED3 : 4;        /*!< [23:20]  */
        uint32_t MUX_A : 3;            /*!< [26:24]  */
        uint32_t RESERVED4 : 1;        /*!< [27]  */
        uint32_t EN_A : 1;             /*!< [28]  */
        uint32_t RESERVED5 : 2;        /*!< [30:29]  */
        uint32_t BUSY4 : 1;            /*!< [31]  */
    } B;
} hw_ccm_pren_t;

/*!
 * @name Constants and macros for entire CCM_PREn register
 */
/*@{*/
#define HW_CCM_PREn_COUNT (121U)

#define HW_CCM_PREn_ADDR(x, n)   ((uintptr_t)(x) + 0x8030U + (0x80U * (n)))

#define HW_CCM_PREn(x, n)        (*(__IO hw_ccm_pren_t *) HW_CCM_PREn_ADDR(x, n))
#define HW_CCM_PREn_RD(x, n)     (HW_CCM_PREn(x, n).U)
#define HW_CCM_PREn_WR(x, n, v)  (HW_CCM_PREn(x, n).U = (v))
#define HW_CCM_PREn_SET(x, n, v) (HW_CCM_PREn_WR(x, n, HW_CCM_PREn_RD(x, n) |  (v)))
#define HW_CCM_PREn_CLR(x, n, v) (HW_CCM_PREn_WR(x, n, HW_CCM_PREn_RD(x, n) & ~(v)))
#define HW_CCM_PREn_TOG(x, n, v) (HW_CCM_PREn_WR(x, n, HW_CCM_PREn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_PREn bitfields
 */

/*!
 * @name Register CCM_PREn, field PRE_PODF_B[2:0] (RW)
 *
 * Pre divider divide number for branch B Divider value is n + 1. This field
 * does not apply for CORE, IP, DRAM, DRAM_PHYM
 *
 * Values:
 * - 000 - Divide by 1
 * - 001 - Divide by 2
 * - 010 - Divide by 3
 * - 011 - Divide by 4
 * - 100 - Divide by 5
 * - 101 - Divide by 6
 * - 110 - Divide by 7
 * - 111 - Divide by 8
 */
/*@{*/
#define BP_CCM_PREn_PRE_PODF_B (0U)        /*!< Bit position for CCM_PREn_PRE_PODF_B. */
#define BM_CCM_PREn_PRE_PODF_B (0x00000007U) /*!< Bit mask for CCM_PREn_PRE_PODF_B. */
#define BS_CCM_PREn_PRE_PODF_B (3U)        /*!< Bit field size in bits for CCM_PREn_PRE_PODF_B. */

/*! @brief Read current value of the CCM_PREn_PRE_PODF_B field. */
#define BR_CCM_PREn_PRE_PODF_B(x, n) (HW_CCM_PREn(x, n).B.PRE_PODF_B)

/*! @brief Format value for bitfield CCM_PREn_PRE_PODF_B. */
#define BF_CCM_PREn_PRE_PODF_B(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PREn_PRE_PODF_B) & BM_CCM_PREn_PRE_PODF_B)

/*! @brief Set the PRE_PODF_B field to a new value. */
#define BW_CCM_PREn_PRE_PODF_B(x, n, v) (HW_CCM_PREn_WR(x, n, (HW_CCM_PREn_RD(x, n) & ~BM_CCM_PREn_PRE_PODF_B) | BF_CCM_PREn_PRE_PODF_B(v)))
/*@}*/

/*!
 * @name Register CCM_PREn, field BUSY0[3] (RO)
 *
 * Pre divider value for branch a is applying field does not apply for CORE,
 * IP,DRAM, DRAM_PHYM
 */
/*@{*/
#define BP_CCM_PREn_BUSY0    (3U)          /*!< Bit position for CCM_PREn_BUSY0. */
#define BM_CCM_PREn_BUSY0    (0x00000008U) /*!< Bit mask for CCM_PREn_BUSY0. */
#define BS_CCM_PREn_BUSY0    (1U)          /*!< Bit field size in bits for CCM_PREn_BUSY0. */

/*! @brief Read current value of the CCM_PREn_BUSY0 field. */
#define BR_CCM_PREn_BUSY0(x, n) (HW_CCM_PREn(x, n).B.BUSY0)
/*@}*/

/*!
 * @name Register CCM_PREn, field MUX_B[10:8] (RW)
 *
 * Selection control of multiplexer of branch B This field does not apply for
 * CORE, IP,DRAM, DRAM_PHYM
 */
/*@{*/
#define BP_CCM_PREn_MUX_B    (8U)          /*!< Bit position for CCM_PREn_MUX_B. */
#define BM_CCM_PREn_MUX_B    (0x00000700U) /*!< Bit mask for CCM_PREn_MUX_B. */
#define BS_CCM_PREn_MUX_B    (3U)          /*!< Bit field size in bits for CCM_PREn_MUX_B. */

/*! @brief Read current value of the CCM_PREn_MUX_B field. */
#define BR_CCM_PREn_MUX_B(x, n) (HW_CCM_PREn(x, n).B.MUX_B)

/*! @brief Format value for bitfield CCM_PREn_MUX_B. */
#define BF_CCM_PREn_MUX_B(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PREn_MUX_B) & BM_CCM_PREn_MUX_B)

/*! @brief Set the MUX_B field to a new value. */
#define BW_CCM_PREn_MUX_B(x, n, v) (HW_CCM_PREn_WR(x, n, (HW_CCM_PREn_RD(x, n) & ~BM_CCM_PREn_MUX_B) | BF_CCM_PREn_MUX_B(v)))
/*@}*/

/*!
 * @name Register CCM_PREn, field EN_B[12] (RW)
 *
 * Branch B clock gate control This field does not apply for CORE, IP,DRAM,
 * DRAM_PHYM
 *
 * Values:
 * - 0 - Clock shutdown
 * - 1 - Clock ON
 */
/*@{*/
#define BP_CCM_PREn_EN_B     (12U)         /*!< Bit position for CCM_PREn_EN_B. */
#define BM_CCM_PREn_EN_B     (0x00001000U) /*!< Bit mask for CCM_PREn_EN_B. */
#define BS_CCM_PREn_EN_B     (1U)          /*!< Bit field size in bits for CCM_PREn_EN_B. */

/*! @brief Read current value of the CCM_PREn_EN_B field. */
#define BR_CCM_PREn_EN_B(x, n) (HW_CCM_PREn(x, n).B.EN_B)

/*! @brief Format value for bitfield CCM_PREn_EN_B. */
#define BF_CCM_PREn_EN_B(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_PREn_EN_B) & BM_CCM_PREn_EN_B)

/*! @brief Set the EN_B field to a new value. */
#define BW_CCM_PREn_EN_B(x, n, v) (HW_CCM_PREn_WR(x, n, (HW_CCM_PREn_RD(x, n) & ~BM_CCM_PREn_EN_B) | BF_CCM_PREn_EN_B(v)))
/*@}*/

/*!
 * @name Register CCM_PREn, field BUSY1[15] (RO)
 *
 * EN_B is applied to field This field does not apply for CORE, IP,DRAM,
 * DRAM_PHYM
 */
/*@{*/
#define BP_CCM_PREn_BUSY1    (15U)         /*!< Bit position for CCM_PREn_BUSY1. */
#define BM_CCM_PREn_BUSY1    (0x00008000U) /*!< Bit mask for CCM_PREn_BUSY1. */
#define BS_CCM_PREn_BUSY1    (1U)          /*!< Bit field size in bits for CCM_PREn_BUSY1. */

/*! @brief Read current value of the CCM_PREn_BUSY1 field. */
#define BR_CCM_PREn_BUSY1(x, n) (HW_CCM_PREn(x, n).B.BUSY1)
/*@}*/

/*!
 * @name Register CCM_PREn, field PRE_PODF_A[18:16] (RW)
 *
 * Pre divider divide number for branch A Divider value is n + 1. This field
 * does not apply for CORE, DRAM, DRAM_PHYM
 *
 * Values:
 * - 000 - Divide by 1
 * - 001 - Divide by 2
 * - 010 - Divide by 3
 * - 011 - Divide by 4
 * - 100 - Divide by 5
 * - 101 - Divide by 6
 * - 110 - Divide by 7
 * - 111 - Divide by 8
 */
/*@{*/
#define BP_CCM_PREn_PRE_PODF_A (16U)       /*!< Bit position for CCM_PREn_PRE_PODF_A. */
#define BM_CCM_PREn_PRE_PODF_A (0x00070000U) /*!< Bit mask for CCM_PREn_PRE_PODF_A. */
#define BS_CCM_PREn_PRE_PODF_A (3U)        /*!< Bit field size in bits for CCM_PREn_PRE_PODF_A. */

/*! @brief Read current value of the CCM_PREn_PRE_PODF_A field. */
#define BR_CCM_PREn_PRE_PODF_A(x, n) (HW_CCM_PREn(x, n).B.PRE_PODF_A)

/*! @brief Format value for bitfield CCM_PREn_PRE_PODF_A. */
#define BF_CCM_PREn_PRE_PODF_A(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PREn_PRE_PODF_A) & BM_CCM_PREn_PRE_PODF_A)

/*! @brief Set the PRE_PODF_A field to a new value. */
#define BW_CCM_PREn_PRE_PODF_A(x, n, v) (HW_CCM_PREn_WR(x, n, (HW_CCM_PREn_RD(x, n) & ~BM_CCM_PREn_PRE_PODF_A) | BF_CCM_PREn_PRE_PODF_A(v)))
/*@}*/

/*!
 * @name Register CCM_PREn, field BUSY3[19] (RO)
 *
 * Pre divider value for branch A is applied This field applies to DRAM and
 * DRAM_PHYM
 */
/*@{*/
#define BP_CCM_PREn_BUSY3    (19U)         /*!< Bit position for CCM_PREn_BUSY3. */
#define BM_CCM_PREn_BUSY3    (0x00080000U) /*!< Bit mask for CCM_PREn_BUSY3. */
#define BS_CCM_PREn_BUSY3    (1U)          /*!< Bit field size in bits for CCM_PREn_BUSY3. */

/*! @brief Read current value of the CCM_PREn_BUSY3 field. */
#define BR_CCM_PREn_BUSY3(x, n) (HW_CCM_PREn(x, n).B.BUSY3)
/*@}*/

/*!
 * @name Register CCM_PREn, field MUX_A[26:24] (RW)
 *
 * Selection control of multiplexer of branch A This field applies to DRAM and
 * DRAM_PHYM
 */
/*@{*/
#define BP_CCM_PREn_MUX_A    (24U)         /*!< Bit position for CCM_PREn_MUX_A. */
#define BM_CCM_PREn_MUX_A    (0x07000000U) /*!< Bit mask for CCM_PREn_MUX_A. */
#define BS_CCM_PREn_MUX_A    (3U)          /*!< Bit field size in bits for CCM_PREn_MUX_A. */

/*! @brief Read current value of the CCM_PREn_MUX_A field. */
#define BR_CCM_PREn_MUX_A(x, n) (HW_CCM_PREn(x, n).B.MUX_A)

/*! @brief Format value for bitfield CCM_PREn_MUX_A. */
#define BF_CCM_PREn_MUX_A(v) ((uint32_t)((uint32_t)(v) << BP_CCM_PREn_MUX_A) & BM_CCM_PREn_MUX_A)

/*! @brief Set the MUX_A field to a new value. */
#define BW_CCM_PREn_MUX_A(x, n, v) (HW_CCM_PREn_WR(x, n, (HW_CCM_PREn_RD(x, n) & ~BM_CCM_PREn_MUX_A) | BF_CCM_PREn_MUX_A(v)))
/*@}*/

/*!
 * @name Register CCM_PREn, field EN_A[28] (RW)
 *
 * Branch A clock gate control This field applies to DRAM and DRAM_PHYM
 *
 * Values:
 * - 0 - Clock shutdown
 * - 1 - clock ON
 */
/*@{*/
#define BP_CCM_PREn_EN_A     (28U)         /*!< Bit position for CCM_PREn_EN_A. */
#define BM_CCM_PREn_EN_A     (0x10000000U) /*!< Bit mask for CCM_PREn_EN_A. */
#define BS_CCM_PREn_EN_A     (1U)          /*!< Bit field size in bits for CCM_PREn_EN_A. */

/*! @brief Read current value of the CCM_PREn_EN_A field. */
#define BR_CCM_PREn_EN_A(x, n) (HW_CCM_PREn(x, n).B.EN_A)

/*! @brief Format value for bitfield CCM_PREn_EN_A. */
#define BF_CCM_PREn_EN_A(v)  ((uint32_t)((uint32_t)(v) << BP_CCM_PREn_EN_A) & BM_CCM_PREn_EN_A)

/*! @brief Set the EN_A field to a new value. */
#define BW_CCM_PREn_EN_A(x, n, v) (HW_CCM_PREn_WR(x, n, (HW_CCM_PREn_RD(x, n) & ~BM_CCM_PREn_EN_A) | BF_CCM_PREn_EN_A(v)))
/*@}*/

/*!
 * @name Register CCM_PREn, field BUSY4[31] (RO)
 *
 * EN_A field is applied to field This field applies to DRAM and DRAM_PHYM
 */
/*@{*/
#define BP_CCM_PREn_BUSY4    (31U)         /*!< Bit position for CCM_PREn_BUSY4. */
#define BM_CCM_PREn_BUSY4    (0x80000000U) /*!< Bit mask for CCM_PREn_BUSY4. */
#define BS_CCM_PREn_BUSY4    (1U)          /*!< Bit field size in bits for CCM_PREn_BUSY4. */

/*! @brief Read current value of the CCM_PREn_BUSY4 field. */
#define BR_CCM_PREn_BUSY4(x, n) (HW_CCM_PREn(x, n).B.BUSY4)
/*@}*/
/*******************************************************************************
 * HW_CCM_ACCESS_CTRLn - Access Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ACCESS_CTRLn - Access Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Access Control Register
 */
typedef union _hw_ccm_access_ctrln
{
    uint32_t U;
    struct _hw_ccm_access_ctrln_bitfields
    {
        uint32_t DOMAIN0_INFO : 4;     /*!< [3:0]  */
        uint32_t DOMAIN1_INFO : 4;     /*!< [7:4]  */
        uint32_t DOMAIN2_INFO : 4;     /*!< [11:8]  */
        uint32_t DOMAIN3_INFO : 4;     /*!< [15:12]  */
        uint32_t OWNER_ID : 2;         /*!< [17:16]  */
        uint32_t RESERVED0 : 2;        /*!< [19:18]  */
        uint32_t MUTEX : 1;            /*!< [20]  */
        uint32_t RESERVED1 : 3;        /*!< [23:21]  */
        uint32_t DOMAIN0_WHITELIST : 1; /*!< [24]  */
        uint32_t DOMAIN1_WHITELIST : 1; /*!< [25]  */
        uint32_t DOMAIN2_WHITELIST : 1; /*!< [26]  */
        uint32_t DOMAIN3_WHITELIST : 1; /*!< [27]  */
        uint32_t SEMA_EN : 1;          /*!< [28]  */
        uint32_t RESERVED2 : 2;        /*!< [30:29]  */
        uint32_t LOCK : 1;             /*!< [31]  */
    } B;
} hw_ccm_access_ctrln_t;

/*!
 * @name Constants and macros for entire CCM_ACCESS_CTRLn register
 */
/*@{*/
#define HW_CCM_ACCESS_CTRLn_COUNT (121U)

#define HW_CCM_ACCESS_CTRLn_ADDR(x, n) ((uintptr_t)(x) + 0x8070U + (0x80U * (n)))

#define HW_CCM_ACCESS_CTRLn(x, n) (*(__IO hw_ccm_access_ctrln_t *) HW_CCM_ACCESS_CTRLn_ADDR(x, n))
#define HW_CCM_ACCESS_CTRLn_RD(x, n) (HW_CCM_ACCESS_CTRLn(x, n).U)
#define HW_CCM_ACCESS_CTRLn_WR(x, n, v) (HW_CCM_ACCESS_CTRLn(x, n).U = (v))
#define HW_CCM_ACCESS_CTRLn_SET(x, n, v) (HW_CCM_ACCESS_CTRLn_WR(x, n, HW_CCM_ACCESS_CTRLn_RD(x, n) |  (v)))
#define HW_CCM_ACCESS_CTRLn_CLR(x, n, v) (HW_CCM_ACCESS_CTRLn_WR(x, n, HW_CCM_ACCESS_CTRLn_RD(x, n) & ~(v)))
#define HW_CCM_ACCESS_CTRLn_TOG(x, n, v) (HW_CCM_ACCESS_CTRLn_WR(x, n, HW_CCM_ACCESS_CTRLn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_ACCESS_CTRLn bitfields
 */

/*!
 * @name Register CCM_ACCESS_CTRLn, field DOMAIN0_INFO[3:0] (RW)
 *
 * Information from domain 0 to pass to others This field can only be changed by
 * domain 0
 */
/*@{*/
#define BP_CCM_ACCESS_CTRLn_DOMAIN0_INFO (0U) /*!< Bit position for CCM_ACCESS_CTRLn_DOMAIN0_INFO. */
#define BM_CCM_ACCESS_CTRLn_DOMAIN0_INFO (0x0000000FU) /*!< Bit mask for CCM_ACCESS_CTRLn_DOMAIN0_INFO. */
#define BS_CCM_ACCESS_CTRLn_DOMAIN0_INFO (4U) /*!< Bit field size in bits for CCM_ACCESS_CTRLn_DOMAIN0_INFO. */

/*! @brief Read current value of the CCM_ACCESS_CTRLn_DOMAIN0_INFO field. */
#define BR_CCM_ACCESS_CTRLn_DOMAIN0_INFO(x, n) (HW_CCM_ACCESS_CTRLn(x, n).B.DOMAIN0_INFO)

/*! @brief Format value for bitfield CCM_ACCESS_CTRLn_DOMAIN0_INFO. */
#define BF_CCM_ACCESS_CTRLn_DOMAIN0_INFO(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ACCESS_CTRLn_DOMAIN0_INFO) & BM_CCM_ACCESS_CTRLn_DOMAIN0_INFO)

/*! @brief Set the DOMAIN0_INFO field to a new value. */
#define BW_CCM_ACCESS_CTRLn_DOMAIN0_INFO(x, n, v) (HW_CCM_ACCESS_CTRLn_WR(x, n, (HW_CCM_ACCESS_CTRLn_RD(x, n) & ~BM_CCM_ACCESS_CTRLn_DOMAIN0_INFO) | BF_CCM_ACCESS_CTRLn_DOMAIN0_INFO(v)))
/*@}*/

/*!
 * @name Register CCM_ACCESS_CTRLn, field DOMAIN1_INFO[7:4] (RW)
 *
 * Information from domain 1 to pass to others This field can only be changed by
 * domain 1
 */
/*@{*/
#define BP_CCM_ACCESS_CTRLn_DOMAIN1_INFO (4U) /*!< Bit position for CCM_ACCESS_CTRLn_DOMAIN1_INFO. */
#define BM_CCM_ACCESS_CTRLn_DOMAIN1_INFO (0x000000F0U) /*!< Bit mask for CCM_ACCESS_CTRLn_DOMAIN1_INFO. */
#define BS_CCM_ACCESS_CTRLn_DOMAIN1_INFO (4U) /*!< Bit field size in bits for CCM_ACCESS_CTRLn_DOMAIN1_INFO. */

/*! @brief Read current value of the CCM_ACCESS_CTRLn_DOMAIN1_INFO field. */
#define BR_CCM_ACCESS_CTRLn_DOMAIN1_INFO(x, n) (HW_CCM_ACCESS_CTRLn(x, n).B.DOMAIN1_INFO)

/*! @brief Format value for bitfield CCM_ACCESS_CTRLn_DOMAIN1_INFO. */
#define BF_CCM_ACCESS_CTRLn_DOMAIN1_INFO(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ACCESS_CTRLn_DOMAIN1_INFO) & BM_CCM_ACCESS_CTRLn_DOMAIN1_INFO)

/*! @brief Set the DOMAIN1_INFO field to a new value. */
#define BW_CCM_ACCESS_CTRLn_DOMAIN1_INFO(x, n, v) (HW_CCM_ACCESS_CTRLn_WR(x, n, (HW_CCM_ACCESS_CTRLn_RD(x, n) & ~BM_CCM_ACCESS_CTRLn_DOMAIN1_INFO) | BF_CCM_ACCESS_CTRLn_DOMAIN1_INFO(v)))
/*@}*/

/*!
 * @name Register CCM_ACCESS_CTRLn, field DOMAIN2_INFO[11:8] (RW)
 *
 * Information from domain 2 to pass to others This field can only be changed by
 * domain 2
 */
/*@{*/
#define BP_CCM_ACCESS_CTRLn_DOMAIN2_INFO (8U) /*!< Bit position for CCM_ACCESS_CTRLn_DOMAIN2_INFO. */
#define BM_CCM_ACCESS_CTRLn_DOMAIN2_INFO (0x00000F00U) /*!< Bit mask for CCM_ACCESS_CTRLn_DOMAIN2_INFO. */
#define BS_CCM_ACCESS_CTRLn_DOMAIN2_INFO (4U) /*!< Bit field size in bits for CCM_ACCESS_CTRLn_DOMAIN2_INFO. */

/*! @brief Read current value of the CCM_ACCESS_CTRLn_DOMAIN2_INFO field. */
#define BR_CCM_ACCESS_CTRLn_DOMAIN2_INFO(x, n) (HW_CCM_ACCESS_CTRLn(x, n).B.DOMAIN2_INFO)

/*! @brief Format value for bitfield CCM_ACCESS_CTRLn_DOMAIN2_INFO. */
#define BF_CCM_ACCESS_CTRLn_DOMAIN2_INFO(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ACCESS_CTRLn_DOMAIN2_INFO) & BM_CCM_ACCESS_CTRLn_DOMAIN2_INFO)

/*! @brief Set the DOMAIN2_INFO field to a new value. */
#define BW_CCM_ACCESS_CTRLn_DOMAIN2_INFO(x, n, v) (HW_CCM_ACCESS_CTRLn_WR(x, n, (HW_CCM_ACCESS_CTRLn_RD(x, n) & ~BM_CCM_ACCESS_CTRLn_DOMAIN2_INFO) | BF_CCM_ACCESS_CTRLn_DOMAIN2_INFO(v)))
/*@}*/

/*!
 * @name Register CCM_ACCESS_CTRLn, field DOMAIN3_INFO[15:12] (RW)
 *
 * Information from domain 3 to pass to others This field can only be changed by
 * domain 3
 */
/*@{*/
#define BP_CCM_ACCESS_CTRLn_DOMAIN3_INFO (12U) /*!< Bit position for CCM_ACCESS_CTRLn_DOMAIN3_INFO. */
#define BM_CCM_ACCESS_CTRLn_DOMAIN3_INFO (0x0000F000U) /*!< Bit mask for CCM_ACCESS_CTRLn_DOMAIN3_INFO. */
#define BS_CCM_ACCESS_CTRLn_DOMAIN3_INFO (4U) /*!< Bit field size in bits for CCM_ACCESS_CTRLn_DOMAIN3_INFO. */

/*! @brief Read current value of the CCM_ACCESS_CTRLn_DOMAIN3_INFO field. */
#define BR_CCM_ACCESS_CTRLn_DOMAIN3_INFO(x, n) (HW_CCM_ACCESS_CTRLn(x, n).B.DOMAIN3_INFO)

/*! @brief Format value for bitfield CCM_ACCESS_CTRLn_DOMAIN3_INFO. */
#define BF_CCM_ACCESS_CTRLn_DOMAIN3_INFO(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ACCESS_CTRLn_DOMAIN3_INFO) & BM_CCM_ACCESS_CTRLn_DOMAIN3_INFO)

/*! @brief Set the DOMAIN3_INFO field to a new value. */
#define BW_CCM_ACCESS_CTRLn_DOMAIN3_INFO(x, n, v) (HW_CCM_ACCESS_CTRLn_WR(x, n, (HW_CCM_ACCESS_CTRLn_RD(x, n) & ~BM_CCM_ACCESS_CTRLn_DOMAIN3_INFO) | BF_CCM_ACCESS_CTRLn_DOMAIN3_INFO(v)))
/*@}*/

/*!
 * @name Register CCM_ACCESS_CTRLn, field OWNER_ID[17:16] (RO)
 *
 * Current domain that owns semaphore This field is meaningless when MUTEX is 0
 *
 * Values:
 * - 0 - domaino
 * - 1 - domain1
 */
/*@{*/
#define BP_CCM_ACCESS_CTRLn_OWNER_ID (16U) /*!< Bit position for CCM_ACCESS_CTRLn_OWNER_ID. */
#define BM_CCM_ACCESS_CTRLn_OWNER_ID (0x00030000U) /*!< Bit mask for CCM_ACCESS_CTRLn_OWNER_ID. */
#define BS_CCM_ACCESS_CTRLn_OWNER_ID (2U)  /*!< Bit field size in bits for CCM_ACCESS_CTRLn_OWNER_ID. */

/*! @brief Read current value of the CCM_ACCESS_CTRLn_OWNER_ID field. */
#define BR_CCM_ACCESS_CTRLn_OWNER_ID(x, n) (HW_CCM_ACCESS_CTRLn(x, n).B.OWNER_ID)
/*@}*/

/*!
 * @name Register CCM_ACCESS_CTRLn, field MUTEX[20] (RW)
 *
 * Semaphore to control access
 *
 * Values:
 * - 0 - Semaphore is free to take
 * - 1 - Semaphore is taken
 */
/*@{*/
#define BP_CCM_ACCESS_CTRLn_MUTEX (20U)    /*!< Bit position for CCM_ACCESS_CTRLn_MUTEX. */
#define BM_CCM_ACCESS_CTRLn_MUTEX (0x00100000U) /*!< Bit mask for CCM_ACCESS_CTRLn_MUTEX. */
#define BS_CCM_ACCESS_CTRLn_MUTEX (1U)     /*!< Bit field size in bits for CCM_ACCESS_CTRLn_MUTEX. */

/*! @brief Read current value of the CCM_ACCESS_CTRLn_MUTEX field. */
#define BR_CCM_ACCESS_CTRLn_MUTEX(x, n) (HW_CCM_ACCESS_CTRLn(x, n).B.MUTEX)

/*! @brief Format value for bitfield CCM_ACCESS_CTRLn_MUTEX. */
#define BF_CCM_ACCESS_CTRLn_MUTEX(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ACCESS_CTRLn_MUTEX) & BM_CCM_ACCESS_CTRLn_MUTEX)

/*! @brief Set the MUTEX field to a new value. */
#define BW_CCM_ACCESS_CTRLn_MUTEX(x, n, v) (HW_CCM_ACCESS_CTRLn_WR(x, n, (HW_CCM_ACCESS_CTRLn_RD(x, n) & ~BM_CCM_ACCESS_CTRLn_MUTEX) | BF_CCM_ACCESS_CTRLn_MUTEX(v)))
/*@}*/

/*!
 * @name Register CCM_ACCESS_CTRLn, field DOMAIN0_WHITELIST[24] (RW)
 *
 * White list of domains that can change setting of this clock root. Each domain
 * has a corresponding bit.
 *
 * Values:
 * - 0 - Domain cannot change the setting
 * - 1 - Domain can change the setting
 */
/*@{*/
#define BP_CCM_ACCESS_CTRLn_DOMAIN0_WHITELIST (24U) /*!< Bit position for CCM_ACCESS_CTRLn_DOMAIN0_WHITELIST. */
#define BM_CCM_ACCESS_CTRLn_DOMAIN0_WHITELIST (0x01000000U) /*!< Bit mask for CCM_ACCESS_CTRLn_DOMAIN0_WHITELIST. */
#define BS_CCM_ACCESS_CTRLn_DOMAIN0_WHITELIST (1U) /*!< Bit field size in bits for CCM_ACCESS_CTRLn_DOMAIN0_WHITELIST. */

/*! @brief Read current value of the CCM_ACCESS_CTRLn_DOMAIN0_WHITELIST field. */
#define BR_CCM_ACCESS_CTRLn_DOMAIN0_WHITELIST(x, n) (HW_CCM_ACCESS_CTRLn(x, n).B.DOMAIN0_WHITELIST)

/*! @brief Format value for bitfield CCM_ACCESS_CTRLn_DOMAIN0_WHITELIST. */
#define BF_CCM_ACCESS_CTRLn_DOMAIN0_WHITELIST(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ACCESS_CTRLn_DOMAIN0_WHITELIST) & BM_CCM_ACCESS_CTRLn_DOMAIN0_WHITELIST)

/*! @brief Set the DOMAIN0_WHITELIST field to a new value. */
#define BW_CCM_ACCESS_CTRLn_DOMAIN0_WHITELIST(x, n, v) (HW_CCM_ACCESS_CTRLn_WR(x, n, (HW_CCM_ACCESS_CTRLn_RD(x, n) & ~BM_CCM_ACCESS_CTRLn_DOMAIN0_WHITELIST) | BF_CCM_ACCESS_CTRLn_DOMAIN0_WHITELIST(v)))
/*@}*/

/*!
 * @name Register CCM_ACCESS_CTRLn, field DOMAIN1_WHITELIST[25] (RW)
 *
 * White list of domains that can change setting of this clock root. Each domain
 * has a corresponding bit.
 *
 * Values:
 * - 0 - Domain cannot change the setting
 * - 1 - Domain can change the setting
 */
/*@{*/
#define BP_CCM_ACCESS_CTRLn_DOMAIN1_WHITELIST (25U) /*!< Bit position for CCM_ACCESS_CTRLn_DOMAIN1_WHITELIST. */
#define BM_CCM_ACCESS_CTRLn_DOMAIN1_WHITELIST (0x02000000U) /*!< Bit mask for CCM_ACCESS_CTRLn_DOMAIN1_WHITELIST. */
#define BS_CCM_ACCESS_CTRLn_DOMAIN1_WHITELIST (1U) /*!< Bit field size in bits for CCM_ACCESS_CTRLn_DOMAIN1_WHITELIST. */

/*! @brief Read current value of the CCM_ACCESS_CTRLn_DOMAIN1_WHITELIST field. */
#define BR_CCM_ACCESS_CTRLn_DOMAIN1_WHITELIST(x, n) (HW_CCM_ACCESS_CTRLn(x, n).B.DOMAIN1_WHITELIST)

/*! @brief Format value for bitfield CCM_ACCESS_CTRLn_DOMAIN1_WHITELIST. */
#define BF_CCM_ACCESS_CTRLn_DOMAIN1_WHITELIST(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ACCESS_CTRLn_DOMAIN1_WHITELIST) & BM_CCM_ACCESS_CTRLn_DOMAIN1_WHITELIST)

/*! @brief Set the DOMAIN1_WHITELIST field to a new value. */
#define BW_CCM_ACCESS_CTRLn_DOMAIN1_WHITELIST(x, n, v) (HW_CCM_ACCESS_CTRLn_WR(x, n, (HW_CCM_ACCESS_CTRLn_RD(x, n) & ~BM_CCM_ACCESS_CTRLn_DOMAIN1_WHITELIST) | BF_CCM_ACCESS_CTRLn_DOMAIN1_WHITELIST(v)))
/*@}*/

/*!
 * @name Register CCM_ACCESS_CTRLn, field DOMAIN2_WHITELIST[26] (RW)
 *
 * White list of domains that can change setting of this clock root. Each domain
 * has a corresponding bit.
 *
 * Values:
 * - 0 - Domain cannot change the setting
 * - 1 - Domain can change the setting
 */
/*@{*/
#define BP_CCM_ACCESS_CTRLn_DOMAIN2_WHITELIST (26U) /*!< Bit position for CCM_ACCESS_CTRLn_DOMAIN2_WHITELIST. */
#define BM_CCM_ACCESS_CTRLn_DOMAIN2_WHITELIST (0x04000000U) /*!< Bit mask for CCM_ACCESS_CTRLn_DOMAIN2_WHITELIST. */
#define BS_CCM_ACCESS_CTRLn_DOMAIN2_WHITELIST (1U) /*!< Bit field size in bits for CCM_ACCESS_CTRLn_DOMAIN2_WHITELIST. */

/*! @brief Read current value of the CCM_ACCESS_CTRLn_DOMAIN2_WHITELIST field. */
#define BR_CCM_ACCESS_CTRLn_DOMAIN2_WHITELIST(x, n) (HW_CCM_ACCESS_CTRLn(x, n).B.DOMAIN2_WHITELIST)

/*! @brief Format value for bitfield CCM_ACCESS_CTRLn_DOMAIN2_WHITELIST. */
#define BF_CCM_ACCESS_CTRLn_DOMAIN2_WHITELIST(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ACCESS_CTRLn_DOMAIN2_WHITELIST) & BM_CCM_ACCESS_CTRLn_DOMAIN2_WHITELIST)

/*! @brief Set the DOMAIN2_WHITELIST field to a new value. */
#define BW_CCM_ACCESS_CTRLn_DOMAIN2_WHITELIST(x, n, v) (HW_CCM_ACCESS_CTRLn_WR(x, n, (HW_CCM_ACCESS_CTRLn_RD(x, n) & ~BM_CCM_ACCESS_CTRLn_DOMAIN2_WHITELIST) | BF_CCM_ACCESS_CTRLn_DOMAIN2_WHITELIST(v)))
/*@}*/

/*!
 * @name Register CCM_ACCESS_CTRLn, field DOMAIN3_WHITELIST[27] (RW)
 *
 * White list of domains that can change setting of this clock root. Each domain
 * has a corresponding bit.
 *
 * Values:
 * - 0 - Domain cannot change the setting
 * - 1 - Domain can change the setting
 */
/*@{*/
#define BP_CCM_ACCESS_CTRLn_DOMAIN3_WHITELIST (27U) /*!< Bit position for CCM_ACCESS_CTRLn_DOMAIN3_WHITELIST. */
#define BM_CCM_ACCESS_CTRLn_DOMAIN3_WHITELIST (0x08000000U) /*!< Bit mask for CCM_ACCESS_CTRLn_DOMAIN3_WHITELIST. */
#define BS_CCM_ACCESS_CTRLn_DOMAIN3_WHITELIST (1U) /*!< Bit field size in bits for CCM_ACCESS_CTRLn_DOMAIN3_WHITELIST. */

/*! @brief Read current value of the CCM_ACCESS_CTRLn_DOMAIN3_WHITELIST field. */
#define BR_CCM_ACCESS_CTRLn_DOMAIN3_WHITELIST(x, n) (HW_CCM_ACCESS_CTRLn(x, n).B.DOMAIN3_WHITELIST)

/*! @brief Format value for bitfield CCM_ACCESS_CTRLn_DOMAIN3_WHITELIST. */
#define BF_CCM_ACCESS_CTRLn_DOMAIN3_WHITELIST(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ACCESS_CTRLn_DOMAIN3_WHITELIST) & BM_CCM_ACCESS_CTRLn_DOMAIN3_WHITELIST)

/*! @brief Set the DOMAIN3_WHITELIST field to a new value. */
#define BW_CCM_ACCESS_CTRLn_DOMAIN3_WHITELIST(x, n, v) (HW_CCM_ACCESS_CTRLn_WR(x, n, (HW_CCM_ACCESS_CTRLn_RD(x, n) & ~BM_CCM_ACCESS_CTRLn_DOMAIN3_WHITELIST) | BF_CCM_ACCESS_CTRLn_DOMAIN3_WHITELIST(v)))
/*@}*/

/*!
 * @name Register CCM_ACCESS_CTRLn, field SEMA_EN[28] (RW)
 *
 * Enable internal semaphore This field cannot be changed when lock bit is 1
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_CCM_ACCESS_CTRLn_SEMA_EN (28U)  /*!< Bit position for CCM_ACCESS_CTRLn_SEMA_EN. */
#define BM_CCM_ACCESS_CTRLn_SEMA_EN (0x10000000U) /*!< Bit mask for CCM_ACCESS_CTRLn_SEMA_EN. */
#define BS_CCM_ACCESS_CTRLn_SEMA_EN (1U)   /*!< Bit field size in bits for CCM_ACCESS_CTRLn_SEMA_EN. */

/*! @brief Read current value of the CCM_ACCESS_CTRLn_SEMA_EN field. */
#define BR_CCM_ACCESS_CTRLn_SEMA_EN(x, n) (HW_CCM_ACCESS_CTRLn(x, n).B.SEMA_EN)

/*! @brief Format value for bitfield CCM_ACCESS_CTRLn_SEMA_EN. */
#define BF_CCM_ACCESS_CTRLn_SEMA_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ACCESS_CTRLn_SEMA_EN) & BM_CCM_ACCESS_CTRLn_SEMA_EN)

/*! @brief Set the SEMA_EN field to a new value. */
#define BW_CCM_ACCESS_CTRLn_SEMA_EN(x, n, v) (HW_CCM_ACCESS_CTRLn_WR(x, n, (HW_CCM_ACCESS_CTRLn_RD(x, n) & ~BM_CCM_ACCESS_CTRLn_SEMA_EN) | BF_CCM_ACCESS_CTRLn_SEMA_EN(v)))
/*@}*/

/*!
 * @name Register CCM_ACCESS_CTRLn, field LOCK[31] (RW)
 *
 * Lock this clock root to use access control This bit can be set to 1 by
 * software, and can be cleared only by system reset.
 *
 * Values:
 * - 0 - Access control inactive
 * - 1 - Access control active
 */
/*@{*/
#define BP_CCM_ACCESS_CTRLn_LOCK (31U)     /*!< Bit position for CCM_ACCESS_CTRLn_LOCK. */
#define BM_CCM_ACCESS_CTRLn_LOCK (0x80000000U) /*!< Bit mask for CCM_ACCESS_CTRLn_LOCK. */
#define BS_CCM_ACCESS_CTRLn_LOCK (1U)      /*!< Bit field size in bits for CCM_ACCESS_CTRLn_LOCK. */

/*! @brief Read current value of the CCM_ACCESS_CTRLn_LOCK field. */
#define BR_CCM_ACCESS_CTRLn_LOCK(x, n) (HW_CCM_ACCESS_CTRLn(x, n).B.LOCK)

/*! @brief Format value for bitfield CCM_ACCESS_CTRLn_LOCK. */
#define BF_CCM_ACCESS_CTRLn_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ACCESS_CTRLn_LOCK) & BM_CCM_ACCESS_CTRLn_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_CCM_ACCESS_CTRLn_LOCK(x, n, v) (HW_CCM_ACCESS_CTRLn_WR(x, n, (HW_CCM_ACCESS_CTRLn_RD(x, n) & ~BM_CCM_ACCESS_CTRLn_LOCK) | BF_CCM_ACCESS_CTRLn_LOCK(v)))
/*@}*/

/*******************************************************************************
 * hw_ccm_t - module struct
 ******************************************************************************/
/*!
 * @brief All CCM module registers.
 */
#pragma pack(1)
typedef struct _hw_ccm
{
    __IO hw_ccm_gpr0_t GPR0;               /*!< [0x0] General Purpose Register */
    uint8_t _reserved0[2044];
    __IO hw_ccm_pll_ctrl0_t PLL_CTRL0;     /*!< [0x800] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl1_t PLL_CTRL1;     /*!< [0x810] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl2_t PLL_CTRL2;     /*!< [0x820] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl3_t PLL_CTRL3;     /*!< [0x830] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl4_t PLL_CTRL4;     /*!< [0x840] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl5_t PLL_CTRL5;     /*!< [0x850] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl6_t PLL_CTRL6;     /*!< [0x860] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl7_t PLL_CTRL7;     /*!< [0x870] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl8_t PLL_CTRL8;     /*!< [0x880] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl9_t PLL_CTRL9;     /*!< [0x890] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl10_t PLL_CTRL10;   /*!< [0x8A0] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl11_t PLL_CTRL11;   /*!< [0x8B0] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl12_t PLL_CTRL12;   /*!< [0x8C0] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl13_t PLL_CTRL13;   /*!< [0x8D0] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl14_t PLL_CTRL14;   /*!< [0x8E0] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl15_t PLL_CTRL15;   /*!< [0x8F0] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl16_t PLL_CTRL16;   /*!< [0x900] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl17_t PLL_CTRL17;   /*!< [0x910] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl18_t PLL_CTRL18;   /*!< [0x920] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl19_t PLL_CTRL19;   /*!< [0x930] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl20_t PLL_CTRL20;   /*!< [0x940] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl21_t PLL_CTRL21;   /*!< [0x950] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl22_t PLL_CTRL22;   /*!< [0x960] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl23_t PLL_CTRL23;   /*!< [0x970] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl24_t PLL_CTRL24;   /*!< [0x980] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl25_t PLL_CTRL25;   /*!< [0x990] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl26_t PLL_CTRL26;   /*!< [0x9A0] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl27_t PLL_CTRL27;   /*!< [0x9B0] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl28_t PLL_CTRL28;   /*!< [0x9C0] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl29_t PLL_CTRL29;   /*!< [0x9D0] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl30_t PLL_CTRL30;   /*!< [0x9E0] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl31_t PLL_CTRL31;   /*!< [0x9F0] CCM PLL Control Register */
    __IO hw_ccm_pll_ctrl32_t PLL_CTRL32;   /*!< [0xA00] CCM PLL Control Register */
    uint8_t _reserved1[13808];
    __IO hw_ccm_ccgr0_t CCGR0;             /*!< [0x4000] CCM Clock Gating Register */
    __IO hw_ccm_ccgr1_t CCGR1;             /*!< [0x4010] CCM Clock Gating Register */
    __IO hw_ccm_ccgr2_t CCGR2;             /*!< [0x4020] CCM Clock Gating Register */
    __IO hw_ccm_ccgr3_t CCGR3;             /*!< [0x4030] CCM Clock Gating Register */
    __IO hw_ccm_ccgr4_t CCGR4;             /*!< [0x4040] CCM Clock Gating Register */
    __IO hw_ccm_ccgr5_t CCGR5;             /*!< [0x4050] CCM Clock Gating Register */
    __IO hw_ccm_ccgr6_t CCGR6;             /*!< [0x4060] CCM Clock Gating Register */
    __IO hw_ccm_ccgr7_t CCGR7;             /*!< [0x4070] CCM Clock Gating Register */
    __IO hw_ccm_ccgr8_t CCGR8;             /*!< [0x4080] CCM Clock Gating Register */
    __IO hw_ccm_ccgr9_t CCGR9;             /*!< [0x4090] CCM Clock Gating Register */
    __IO hw_ccm_ccgr10_t CCGR10;           /*!< [0x40A0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr11_t CCGR11;           /*!< [0x40B0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr12_t CCGR12;           /*!< [0x40C0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr13_t CCGR13;           /*!< [0x40D0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr14_t CCGR14;           /*!< [0x40E0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr15_t CCGR15;           /*!< [0x40F0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr16_t CCGR16;           /*!< [0x4100] CCM Clock Gating Register */
    __IO hw_ccm_ccgr17_t CCGR17;           /*!< [0x4110] CCM Clock Gating Register */
    __IO hw_ccm_ccgr18_t CCGR18;           /*!< [0x4120] CCM Clock Gating Register */
    __IO hw_ccm_ccgr19_t CCGR19;           /*!< [0x4130] CCM Clock Gating Register */
    __IO hw_ccm_ccgr20_t CCGR20;           /*!< [0x4140] CCM Clock Gating Register */
    __IO hw_ccm_ccgr21_t CCGR21;           /*!< [0x4150] CCM Clock Gating Register */
    __IO hw_ccm_ccgr22_t CCGR22;           /*!< [0x4160] CCM Clock Gating Register */
    __IO hw_ccm_ccgr23_t CCGR23;           /*!< [0x4170] CCM Clock Gating Register */
    __IO hw_ccm_ccgr24_t CCGR24;           /*!< [0x4180] CCM Clock Gating Register */
    __IO hw_ccm_ccgr25_t CCGR25;           /*!< [0x4190] CCM Clock Gating Register */
    __IO hw_ccm_ccgr26_t CCGR26;           /*!< [0x41A0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr27_t CCGR27;           /*!< [0x41B0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr28_t CCGR28;           /*!< [0x41C0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr29_t CCGR29;           /*!< [0x41D0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr30_t CCGR30;           /*!< [0x41E0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr31_t CCGR31;           /*!< [0x41F0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr32_t CCGR32;           /*!< [0x4200] CCM Clock Gating Register */
    __IO hw_ccm_ccgr33_t CCGR33;           /*!< [0x4210] CCM Clock Gating Register */
    __IO hw_ccm_ccgr34_t CCGR34;           /*!< [0x4220] CCM Clock Gating Register */
    __IO hw_ccm_ccgr35_t CCGR35;           /*!< [0x4230] CCM Clock Gating Register */
    __IO hw_ccm_ccgr36_t CCGR36;           /*!< [0x4240] CCM Clock Gating Register */
    __IO hw_ccm_ccgr37_t CCGR37;           /*!< [0x4250] CCM Clock Gating Register */
    __IO hw_ccm_ccgr38_t CCGR38;           /*!< [0x4260] CCM Clock Gating Register */
    __IO hw_ccm_ccgr39_t CCGR39;           /*!< [0x4270] CCM Clock Gating Register */
    __IO hw_ccm_ccgr40_t CCGR40;           /*!< [0x4280] CCM Clock Gating Register */
    __IO hw_ccm_ccgr41_t CCGR41;           /*!< [0x4290] CCM Clock Gating Register */
    __IO hw_ccm_ccgr42_t CCGR42;           /*!< [0x42A0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr43_t CCGR43;           /*!< [0x42B0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr44_t CCGR44;           /*!< [0x42C0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr45_t CCGR45;           /*!< [0x42D0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr46_t CCGR46;           /*!< [0x42E0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr47_t CCGR47;           /*!< [0x42F0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr48_t CCGR48;           /*!< [0x4300] CCM Clock Gating Register */
    __IO hw_ccm_ccgr49_t CCGR49;           /*!< [0x4310] CCM Clock Gating Register */
    __IO hw_ccm_ccgr50_t CCGR50;           /*!< [0x4320] CCM Clock Gating Register */
    __IO hw_ccm_ccgr51_t CCGR51;           /*!< [0x4330] CCM Clock Gating Register */
    __IO hw_ccm_ccgr52_t CCGR52;           /*!< [0x4340] CCM Clock Gating Register */
    __IO hw_ccm_ccgr53_t CCGR53;           /*!< [0x4350] CCM Clock Gating Register */
    __IO hw_ccm_ccgr54_t CCGR54;           /*!< [0x4360] CCM Clock Gating Register */
    __IO hw_ccm_ccgr55_t CCGR55;           /*!< [0x4370] CCM Clock Gating Register */
    __IO hw_ccm_ccgr56_t CCGR56;           /*!< [0x4380] CCM Clock Gating Register */
    __IO hw_ccm_ccgr57_t CCGR57;           /*!< [0x4390] CCM Clock Gating Register */
    __IO hw_ccm_ccgr58_t CCGR58;           /*!< [0x43A0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr59_t CCGR59;           /*!< [0x43B0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr60_t CCGR60;           /*!< [0x43C0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr61_t CCGR61;           /*!< [0x43D0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr62_t CCGR62;           /*!< [0x43E0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr63_t CCGR63;           /*!< [0x43F0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr64_t CCGR64;           /*!< [0x4400] CCM Clock Gating Register */
    __IO hw_ccm_ccgr65_t CCGR65;           /*!< [0x4410] CCM Clock Gating Register */
    __IO hw_ccm_ccgr66_t CCGR66;           /*!< [0x4420] CCM Clock Gating Register */
    __IO hw_ccm_ccgr67_t CCGR67;           /*!< [0x4430] CCM Clock Gating Register */
    __IO hw_ccm_ccgr68_t CCGR68;           /*!< [0x4440] CCM Clock Gating Register */
    __IO hw_ccm_ccgr69_t CCGR69;           /*!< [0x4450] CCM Clock Gating Register */
    __IO hw_ccm_ccgr70_t CCGR70;           /*!< [0x4460] CCM Clock Gating Register */
    __IO hw_ccm_ccgr71_t CCGR71;           /*!< [0x4470] CCM Clock Gating Register */
    __IO hw_ccm_ccgr72_t CCGR72;           /*!< [0x4480] CCM Clock Gating Register */
    __IO hw_ccm_ccgr73_t CCGR73;           /*!< [0x4490] CCM Clock Gating Register */
    __IO hw_ccm_ccgr74_t CCGR74;           /*!< [0x44A0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr75_t CCGR75;           /*!< [0x44B0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr76_t CCGR76;           /*!< [0x44C0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr77_t CCGR77;           /*!< [0x44D0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr78_t CCGR78;           /*!< [0x44E0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr79_t CCGR79;           /*!< [0x44F0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr80_t CCGR80;           /*!< [0x4500] CCM Clock Gating Register */
    __IO hw_ccm_ccgr81_t CCGR81;           /*!< [0x4510] CCM Clock Gating Register */
    __IO hw_ccm_ccgr82_t CCGR82;           /*!< [0x4520] CCM Clock Gating Register */
    __IO hw_ccm_ccgr83_t CCGR83;           /*!< [0x4530] CCM Clock Gating Register */
    __IO hw_ccm_ccgr84_t CCGR84;           /*!< [0x4540] CCM Clock Gating Register */
    __IO hw_ccm_ccgr85_t CCGR85;           /*!< [0x4550] CCM Clock Gating Register */
    __IO hw_ccm_ccgr86_t CCGR86;           /*!< [0x4560] CCM Clock Gating Register */
    __IO hw_ccm_ccgr87_t CCGR87;           /*!< [0x4570] CCM Clock Gating Register */
    __IO hw_ccm_ccgr88_t CCGR88;           /*!< [0x4580] CCM Clock Gating Register */
    __IO hw_ccm_ccgr89_t CCGR89;           /*!< [0x4590] CCM Clock Gating Register */
    __IO hw_ccm_ccgr90_t CCGR90;           /*!< [0x45A0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr91_t CCGR91;           /*!< [0x45B0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr92_t CCGR92;           /*!< [0x45C0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr93_t CCGR93;           /*!< [0x45D0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr94_t CCGR94;           /*!< [0x45E0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr95_t CCGR95;           /*!< [0x45F0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr96_t CCGR96;           /*!< [0x4600] CCM Clock Gating Register */
    __IO hw_ccm_ccgr97_t CCGR97;           /*!< [0x4610] CCM Clock Gating Register */
    __IO hw_ccm_ccgr98_t CCGR98;           /*!< [0x4620] CCM Clock Gating Register */
    __IO hw_ccm_ccgr99_t CCGR99;           /*!< [0x4630] CCM Clock Gating Register */
    __IO hw_ccm_ccgr100_t CCGR100;         /*!< [0x4640] CCM Clock Gating Register */
    __IO hw_ccm_ccgr101_t CCGR101;         /*!< [0x4650] CCM Clock Gating Register */
    __IO hw_ccm_ccgr102_t CCGR102;         /*!< [0x4660] CCM Clock Gating Register */
    __IO hw_ccm_ccgr103_t CCGR103;         /*!< [0x4670] CCM Clock Gating Register */
    __IO hw_ccm_ccgr104_t CCGR104;         /*!< [0x4680] CCM Clock Gating Register */
    __IO hw_ccm_ccgr105_t CCGR105;         /*!< [0x4690] CCM Clock Gating Register */
    __IO hw_ccm_ccgr106_t CCGR106;         /*!< [0x46A0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr107_t CCGR107;         /*!< [0x46B0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr108_t CCGR108;         /*!< [0x46C0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr109_t CCGR109;         /*!< [0x46D0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr110_t CCGR110;         /*!< [0x46E0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr111_t CCGR111;         /*!< [0x46F0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr112_t CCGR112;         /*!< [0x4700] CCM Clock Gating Register */
    __IO hw_ccm_ccgr113_t CCGR113;         /*!< [0x4710] CCM Clock Gating Register */
    __IO hw_ccm_ccgr114_t CCGR114;         /*!< [0x4720] CCM Clock Gating Register */
    __IO hw_ccm_ccgr115_t CCGR115;         /*!< [0x4730] CCM Clock Gating Register */
    __IO hw_ccm_ccgr116_t CCGR116;         /*!< [0x4740] CCM Clock Gating Register */
    __IO hw_ccm_ccgr117_t CCGR117;         /*!< [0x4750] CCM Clock Gating Register */
    __IO hw_ccm_ccgr118_t CCGR118;         /*!< [0x4760] CCM Clock Gating Register */
    __IO hw_ccm_ccgr119_t CCGR119;         /*!< [0x4770] CCM Clock Gating Register */
    __IO hw_ccm_ccgr120_t CCGR120;         /*!< [0x4780] CCM Clock Gating Register */
    __IO hw_ccm_ccgr121_t CCGR121;         /*!< [0x4790] CCM Clock Gating Register */
    __IO hw_ccm_ccgr122_t CCGR122;         /*!< [0x47A0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr123_t CCGR123;         /*!< [0x47B0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr124_t CCGR124;         /*!< [0x47C0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr125_t CCGR125;         /*!< [0x47D0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr126_t CCGR126;         /*!< [0x47E0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr127_t CCGR127;         /*!< [0x47F0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr128_t CCGR128;         /*!< [0x4800] CCM Clock Gating Register */
    __IO hw_ccm_ccgr129_t CCGR129;         /*!< [0x4810] CCM Clock Gating Register */
    __IO hw_ccm_ccgr130_t CCGR130;         /*!< [0x4820] CCM Clock Gating Register */
    __IO hw_ccm_ccgr131_t CCGR131;         /*!< [0x4830] CCM Clock Gating Register */
    __IO hw_ccm_ccgr132_t CCGR132;         /*!< [0x4840] CCM Clock Gating Register */
    __IO hw_ccm_ccgr133_t CCGR133;         /*!< [0x4850] CCM Clock Gating Register */
    __IO hw_ccm_ccgr134_t CCGR134;         /*!< [0x4860] CCM Clock Gating Register */
    __IO hw_ccm_ccgr135_t CCGR135;         /*!< [0x4870] CCM Clock Gating Register */
    __IO hw_ccm_ccgr136_t CCGR136;         /*!< [0x4880] CCM Clock Gating Register */
    __IO hw_ccm_ccgr137_t CCGR137;         /*!< [0x4890] CCM Clock Gating Register */
    __IO hw_ccm_ccgr138_t CCGR138;         /*!< [0x48A0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr139_t CCGR139;         /*!< [0x48B0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr140_t CCGR140;         /*!< [0x48C0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr141_t CCGR141;         /*!< [0x48D0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr142_t CCGR142;         /*!< [0x48E0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr143_t CCGR143;         /*!< [0x48F0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr144_t CCGR144;         /*!< [0x4900] CCM Clock Gating Register */
    __IO hw_ccm_ccgr145_t CCGR145;         /*!< [0x4910] CCM Clock Gating Register */
    __IO hw_ccm_ccgr146_t CCGR146;         /*!< [0x4920] CCM Clock Gating Register */
    __IO hw_ccm_ccgr147_t CCGR147;         /*!< [0x4930] CCM Clock Gating Register */
    __IO hw_ccm_ccgr148_t CCGR148;         /*!< [0x4940] CCM Clock Gating Register */
    __IO hw_ccm_ccgr149_t CCGR149;         /*!< [0x4950] CCM Clock Gating Register */
    __IO hw_ccm_ccgr150_t CCGR150;         /*!< [0x4960] CCM Clock Gating Register */
    __IO hw_ccm_ccgr151_t CCGR151;         /*!< [0x4970] CCM Clock Gating Register */
    __IO hw_ccm_ccgr152_t CCGR152;         /*!< [0x4980] CCM Clock Gating Register */
    __IO hw_ccm_ccgr153_t CCGR153;         /*!< [0x4990] CCM Clock Gating Register */
    __IO hw_ccm_ccgr154_t CCGR154;         /*!< [0x49A0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr155_t CCGR155;         /*!< [0x49B0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr156_t CCGR156;         /*!< [0x49C0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr157_t CCGR157;         /*!< [0x49D0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr158_t CCGR158;         /*!< [0x49E0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr159_t CCGR159;         /*!< [0x49F0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr160_t CCGR160;         /*!< [0x4A00] CCM Clock Gating Register */
    __IO hw_ccm_ccgr161_t CCGR161;         /*!< [0x4A10] CCM Clock Gating Register */
    __IO hw_ccm_ccgr162_t CCGR162;         /*!< [0x4A20] CCM Clock Gating Register */
    __IO hw_ccm_ccgr163_t CCGR163;         /*!< [0x4A30] CCM Clock Gating Register */
    __IO hw_ccm_ccgr164_t CCGR164;         /*!< [0x4A40] CCM Clock Gating Register */
    __IO hw_ccm_ccgr165_t CCGR165;         /*!< [0x4A50] CCM Clock Gating Register */
    __IO hw_ccm_ccgr166_t CCGR166;         /*!< [0x4A60] CCM Clock Gating Register */
    __IO hw_ccm_ccgr167_t CCGR167;         /*!< [0x4A70] CCM Clock Gating Register */
    __IO hw_ccm_ccgr168_t CCGR168;         /*!< [0x4A80] CCM Clock Gating Register */
    __IO hw_ccm_ccgr169_t CCGR169;         /*!< [0x4A90] CCM Clock Gating Register */
    __IO hw_ccm_ccgr170_t CCGR170;         /*!< [0x4AA0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr171_t CCGR171;         /*!< [0x4AB0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr172_t CCGR172;         /*!< [0x4AC0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr173_t CCGR173;         /*!< [0x4AD0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr174_t CCGR174;         /*!< [0x4AE0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr175_t CCGR175;         /*!< [0x4AF0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr176_t CCGR176;         /*!< [0x4B00] CCM Clock Gating Register */
    __IO hw_ccm_ccgr177_t CCGR177;         /*!< [0x4B10] CCM Clock Gating Register */
    __IO hw_ccm_ccgr178_t CCGR178;         /*!< [0x4B20] CCM Clock Gating Register */
    __IO hw_ccm_ccgr179_t CCGR179;         /*!< [0x4B30] CCM Clock Gating Register */
    __IO hw_ccm_ccgr180_t CCGR180;         /*!< [0x4B40] CCM Clock Gating Register */
    __IO hw_ccm_ccgr181_t CCGR181;         /*!< [0x4B50] CCM Clock Gating Register */
    __IO hw_ccm_ccgr182_t CCGR182;         /*!< [0x4B60] CCM Clock Gating Register */
    __IO hw_ccm_ccgr183_t CCGR183;         /*!< [0x4B70] CCM Clock Gating Register */
    __IO hw_ccm_ccgr184_t CCGR184;         /*!< [0x4B80] CCM Clock Gating Register */
    __IO hw_ccm_ccgr185_t CCGR185;         /*!< [0x4B90] CCM Clock Gating Register */
    __IO hw_ccm_ccgr186_t CCGR186;         /*!< [0x4BA0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr187_t CCGR187;         /*!< [0x4BB0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr188_t CCGR188;         /*!< [0x4BC0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr189_t CCGR189;         /*!< [0x4BD0] CCM Clock Gating Register */
    __IO hw_ccm_ccgr190_t CCGR190;         /*!< [0x4BE0] CCM Clock Gating Register */
    uint8_t _reserved2[13328];
    struct {
        __IO hw_ccm_target_rootn_t TARGET_ROOTn; /*!< [0x8000] Target Register */
        uint8_t _reserved0[12];
        __IO hw_ccm_miscn_t MISCn;         /*!< [0x8010] Miscellaneous Register */
        uint8_t _reserved1[12];
        __IO hw_ccm_postn_t POSTn;         /*!< [0x8020] Post Divider Register */
        uint8_t _reserved2[12];
        __IO hw_ccm_pren_t PREn;           /*!< [0x8030] Pre Divider Register */
        uint8_t _reserved3[60];
        __IO hw_ccm_access_ctrln_t ACCESS_CTRLn; /*!< [0x8070] Access Control Register */
        uint8_t _reserved4[12];
    } ROOT[121];
} hw_ccm_t;
#pragma pack()

/*! @brief Macro to access all CCM registers. */
/*! @param x CCM module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_CCM_REGS(CCM_BASE)</code>. */
#define HW_CCM_REGS(x) (*(hw_ccm_t *)(x))

/*
 * iMX7D CCM_ANALOG
 *
 * CCM_ANALOG
 *
 * Registers defined in this header file:
 * - HW_CCM_ANALOG_PLL_ARM - Anadig ARM PLL control Register
 * - HW_CCM_ANALOG_PLL_DDR - Anadig DDR PLL Control Register
 * - HW_CCM_ANALOG_PLL_DDR_SS - DDR PLL Spread Spectrum Register.
 * - HW_CCM_ANALOG_PLL_DDR_NUM - Numerator of DDR PLL Fractional Loop Divider Register
 * - HW_CCM_ANALOG_PLL_DDR_DENOM - Denominator of DDR PLL Fractional Loop Divider Register
 * - HW_CCM_ANALOG_PLL_480 - Anadig 480MHz PLL Control Register
 * - HW_CCM_ANALOG_PFD_480A - 480MHz Clock Phase Fractional Divider Control Register A
 * - HW_CCM_ANALOG_PFD_480B - 480MHz Clock Phase Fractional Divider Control Register B
 * - HW_CCM_ANALOG_PLL_ENET - Anadig ENET PLL Control Register
 * - HW_CCM_ANALOG_PLL_AUDIO - Anadig Audio PLL control Register
 * - HW_CCM_ANALOG_PLL_AUDIO_SS - Audio PLL Spread Spectrum Register.
 * - HW_CCM_ANALOG_PLL_AUDIO_NUM - Numerator of Audio PLL Fractional Loop Divider Register
 * - HW_CCM_ANALOG_PLL_AUDIO_DENOM - Denominator of Audio PLL Fractional Loop Divider Register
 * - HW_CCM_ANALOG_PLL_VIDEO - Anadig Video PLL control Register
 * - HW_CCM_ANALOG_PLL_VIDEO_SS - Video PLL Spread Spectrum Register.
 * - HW_CCM_ANALOG_PLL_VIDEO_NUM - Numerator of Video PLL Fractional Loop Divider Register
 * - HW_CCM_ANALOG_PLL_VIDEO_DENOM - Denominator of Video PLL Fractional Loop Divider Register
 * - HW_CCM_ANALOG_CLK_MISC0 - Miscellaneous0 Analog Clock Control and Status Register
 *
 * - hw_ccm_analog_t - Struct containing all module registers.
 */

#define HW_CCM_ANALOG_INSTANCE_COUNT (1U) /*!< Number of instances of the CCM_ANALOG module. */
#define HW_CCM_ANALOG (0U) /*!< Instance number for CCM_ANALOG. */
#define CCM_ANALOG_BASE       (0x30360060U) /*!< Base address for CCM_ANALOG. */
/*! Array initializer of CCM_ANALOG base addresses. */
#define CCM_ANALOG_BASE_ADDRS { CCM_ANALOG_BASE }

/*******************************************************************************
 * HW_CCM_ANALOG_PLL_ARM - Anadig ARM PLL control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_ARM - Anadig ARM PLL control Register (RW)
 *
 * Reset value: 0x00013042U
 *
 * The control register provides control for the system PLL.
 */
typedef union _hw_ccm_analog_pll_arm
{
    uint32_t U;
    struct _hw_ccm_analog_pll_arm_bitfields
    {
        uint32_t DIV_SELECT : 7;       /*!< [6:0]  */
        uint32_t HALF_LF : 1;          /*!< [7]  */
        uint32_t DOUBLE_LF : 1;        /*!< [8]  */
        uint32_t HALF_CP : 1;          /*!< [9]  */
        uint32_t DOUBLE_CP : 1;        /*!< [10]  */
        uint32_t HOLD_RING_OFF : 1;    /*!< [11]  */
        uint32_t POWERDOWN : 1;        /*!< [12]  */
        uint32_t ENABLE_CLK : 1;       /*!< [13]  */
        uint32_t BYPASS_CLK_SRC : 2;   /*!< [15:14]  */
        uint32_t BYPASS : 1;           /*!< [16]  */
        uint32_t LVDS_SEL : 1;         /*!< [17]  */
        uint32_t LVDS_24MHZ_SEL : 1;   /*!< [18]  */
        uint32_t PLL_SEL : 1;          /*!< [19]  */
        uint32_t PLL_ARM_OVERRIDE : 1; /*!< [20]  */
        uint32_t RSVD0 : 10;           /*!< [30:21]  */
        uint32_t LOCK : 1;             /*!< [31]  */
    } B;
} hw_ccm_analog_pll_arm_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_ARM register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_ARM_ADDR(x) ((uintptr_t)(x) + 0x60U)
#define HW_CCM_ANALOG_PLL_ARM_SET_ADDR(x) (HW_CCM_ANALOG_PLL_ARM_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_PLL_ARM_CLR_ADDR(x) (HW_CCM_ANALOG_PLL_ARM_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_PLL_ARM_TOG_ADDR(x) (HW_CCM_ANALOG_PLL_ARM_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_PLL_ARM(x) (*(__IO hw_ccm_analog_pll_arm_t *) HW_CCM_ANALOG_PLL_ARM_ADDR(x))
#define HW_CCM_ANALOG_PLL_ARM_RD(x) (HW_CCM_ANALOG_PLL_ARM(x).U)
#define HW_CCM_ANALOG_PLL_ARM_WR(x, v) (HW_CCM_ANALOG_PLL_ARM(x).U = (v))
#define HW_CCM_ANALOG_PLL_ARM_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_ARM_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_ARM_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_ARM_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_ARM_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_ARM_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_ARM bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field DIV_SELECT[6:0] (RW)
 *
 * This field controls the pll loop divider. Valid range for divider value:
 * 54-108. Fout = Fin * div_select/2.0.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_DIV_SELECT (0U) /*!< Bit position for CCM_ANALOG_PLL_ARM_DIV_SELECT. */
#define BM_CCM_ANALOG_PLL_ARM_DIV_SELECT (0x0000007FU) /*!< Bit mask for CCM_ANALOG_PLL_ARM_DIV_SELECT. */
#define BS_CCM_ANALOG_PLL_ARM_DIV_SELECT (7U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_DIV_SELECT. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_DIV_SELECT field. */
#define BR_CCM_ANALOG_PLL_ARM_DIV_SELECT(x) (HW_CCM_ANALOG_PLL_ARM(x).B.DIV_SELECT)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_DIV_SELECT. */
#define BF_CCM_ANALOG_PLL_ARM_DIV_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_DIV_SELECT) & BM_CCM_ANALOG_PLL_ARM_DIV_SELECT)

/*! @brief Set the DIV_SELECT field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_DIV_SELECT(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_DIV_SELECT) | BF_CCM_ANALOG_PLL_ARM_DIV_SELECT(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field HALF_LF[7] (RW)
 *
 * Reduces the frequency of the loop filter 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_HALF_LF (7U) /*!< Bit position for CCM_ANALOG_PLL_ARM_HALF_LF. */
#define BM_CCM_ANALOG_PLL_ARM_HALF_LF (0x00000080U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_HALF_LF. */
#define BS_CCM_ANALOG_PLL_ARM_HALF_LF (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_HALF_LF. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_HALF_LF field. */
#define BR_CCM_ANALOG_PLL_ARM_HALF_LF(x) (HW_CCM_ANALOG_PLL_ARM(x).B.HALF_LF)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_HALF_LF. */
#define BF_CCM_ANALOG_PLL_ARM_HALF_LF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_HALF_LF) & BM_CCM_ANALOG_PLL_ARM_HALF_LF)

/*! @brief Set the HALF_LF field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_HALF_LF(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_HALF_LF) | BF_CCM_ANALOG_PLL_ARM_HALF_LF(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field DOUBLE_LF[8] (RW)
 *
 * Increases the frequency of the loop filter 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_DOUBLE_LF (8U) /*!< Bit position for CCM_ANALOG_PLL_ARM_DOUBLE_LF. */
#define BM_CCM_ANALOG_PLL_ARM_DOUBLE_LF (0x00000100U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_DOUBLE_LF. */
#define BS_CCM_ANALOG_PLL_ARM_DOUBLE_LF (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_DOUBLE_LF. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_DOUBLE_LF field. */
#define BR_CCM_ANALOG_PLL_ARM_DOUBLE_LF(x) (HW_CCM_ANALOG_PLL_ARM(x).B.DOUBLE_LF)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_DOUBLE_LF. */
#define BF_CCM_ANALOG_PLL_ARM_DOUBLE_LF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_DOUBLE_LF) & BM_CCM_ANALOG_PLL_ARM_DOUBLE_LF)

/*! @brief Set the DOUBLE_LF field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_DOUBLE_LF(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_DOUBLE_LF) | BF_CCM_ANALOG_PLL_ARM_DOUBLE_LF(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field HALF_CP[9] (RW)
 *
 * Reduces the charge pump gain 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_HALF_CP (9U) /*!< Bit position for CCM_ANALOG_PLL_ARM_HALF_CP. */
#define BM_CCM_ANALOG_PLL_ARM_HALF_CP (0x00000200U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_HALF_CP. */
#define BS_CCM_ANALOG_PLL_ARM_HALF_CP (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_HALF_CP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_HALF_CP field. */
#define BR_CCM_ANALOG_PLL_ARM_HALF_CP(x) (HW_CCM_ANALOG_PLL_ARM(x).B.HALF_CP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_HALF_CP. */
#define BF_CCM_ANALOG_PLL_ARM_HALF_CP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_HALF_CP) & BM_CCM_ANALOG_PLL_ARM_HALF_CP)

/*! @brief Set the HALF_CP field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_HALF_CP(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_HALF_CP) | BF_CCM_ANALOG_PLL_ARM_HALF_CP(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field DOUBLE_CP[10] (RW)
 *
 * Increases the charge pump gain 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_DOUBLE_CP (10U) /*!< Bit position for CCM_ANALOG_PLL_ARM_DOUBLE_CP. */
#define BM_CCM_ANALOG_PLL_ARM_DOUBLE_CP (0x00000400U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_DOUBLE_CP. */
#define BS_CCM_ANALOG_PLL_ARM_DOUBLE_CP (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_DOUBLE_CP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_DOUBLE_CP field. */
#define BR_CCM_ANALOG_PLL_ARM_DOUBLE_CP(x) (HW_CCM_ANALOG_PLL_ARM(x).B.DOUBLE_CP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_DOUBLE_CP. */
#define BF_CCM_ANALOG_PLL_ARM_DOUBLE_CP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_DOUBLE_CP) & BM_CCM_ANALOG_PLL_ARM_DOUBLE_CP)

/*! @brief Set the DOUBLE_CP field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_DOUBLE_CP(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_DOUBLE_CP) | BF_CCM_ANALOG_PLL_ARM_DOUBLE_CP(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field HOLD_RING_OFF[11] (RW)
 *
 * Analog debug bit.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_HOLD_RING_OFF (11U) /*!< Bit position for CCM_ANALOG_PLL_ARM_HOLD_RING_OFF. */
#define BM_CCM_ANALOG_PLL_ARM_HOLD_RING_OFF (0x00000800U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_HOLD_RING_OFF. */
#define BS_CCM_ANALOG_PLL_ARM_HOLD_RING_OFF (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_HOLD_RING_OFF. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_HOLD_RING_OFF field. */
#define BR_CCM_ANALOG_PLL_ARM_HOLD_RING_OFF(x) (HW_CCM_ANALOG_PLL_ARM(x).B.HOLD_RING_OFF)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_HOLD_RING_OFF. */
#define BF_CCM_ANALOG_PLL_ARM_HOLD_RING_OFF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_HOLD_RING_OFF) & BM_CCM_ANALOG_PLL_ARM_HOLD_RING_OFF)

/*! @brief Set the HOLD_RING_OFF field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_HOLD_RING_OFF(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_HOLD_RING_OFF) | BF_CCM_ANALOG_PLL_ARM_HOLD_RING_OFF(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field POWERDOWN[12] (RW)
 *
 * Powers down the PLL.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_POWERDOWN (12U) /*!< Bit position for CCM_ANALOG_PLL_ARM_POWERDOWN. */
#define BM_CCM_ANALOG_PLL_ARM_POWERDOWN (0x00001000U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_POWERDOWN. */
#define BS_CCM_ANALOG_PLL_ARM_POWERDOWN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_POWERDOWN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_POWERDOWN field. */
#define BR_CCM_ANALOG_PLL_ARM_POWERDOWN(x) (HW_CCM_ANALOG_PLL_ARM(x).B.POWERDOWN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_POWERDOWN. */
#define BF_CCM_ANALOG_PLL_ARM_POWERDOWN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_POWERDOWN) & BM_CCM_ANALOG_PLL_ARM_POWERDOWN)

/*! @brief Set the POWERDOWN field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_POWERDOWN(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_POWERDOWN) | BF_CCM_ANALOG_PLL_ARM_POWERDOWN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field ENABLE_CLK[13] (RW)
 *
 * Enable the clock output.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_ENABLE_CLK (13U) /*!< Bit position for CCM_ANALOG_PLL_ARM_ENABLE_CLK. */
#define BM_CCM_ANALOG_PLL_ARM_ENABLE_CLK (0x00002000U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_ENABLE_CLK. */
#define BS_CCM_ANALOG_PLL_ARM_ENABLE_CLK (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_ENABLE_CLK. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_ENABLE_CLK field. */
#define BR_CCM_ANALOG_PLL_ARM_ENABLE_CLK(x) (HW_CCM_ANALOG_PLL_ARM(x).B.ENABLE_CLK)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_ENABLE_CLK. */
#define BF_CCM_ANALOG_PLL_ARM_ENABLE_CLK(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_ENABLE_CLK) & BM_CCM_ANALOG_PLL_ARM_ENABLE_CLK)

/*! @brief Set the ENABLE_CLK field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_ENABLE_CLK(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_ENABLE_CLK) | BF_CCM_ANALOG_PLL_ARM_ENABLE_CLK(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field BYPASS_CLK_SRC[15:14] (RW)
 *
 * Determines the bypass source.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC (14U) /*!< Bit position for CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC. */
#define BM_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC (0x0000C000U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC. */
#define BS_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC field. */
#define BR_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC(x) (HW_CCM_ANALOG_PLL_ARM(x).B.BYPASS_CLK_SRC)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC. */
#define BF_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC) & BM_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC)

/*! @brief Set the BYPASS_CLK_SRC field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC) | BF_CCM_ANALOG_PLL_ARM_BYPASS_CLK_SRC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field BYPASS[16] (RW)
 *
 * Bypass the pll.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_BYPASS (16U) /*!< Bit position for CCM_ANALOG_PLL_ARM_BYPASS. */
#define BM_CCM_ANALOG_PLL_ARM_BYPASS (0x00010000U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_BYPASS. */
#define BS_CCM_ANALOG_PLL_ARM_BYPASS (1U)  /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_BYPASS. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_BYPASS field. */
#define BR_CCM_ANALOG_PLL_ARM_BYPASS(x) (HW_CCM_ANALOG_PLL_ARM(x).B.BYPASS)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_BYPASS. */
#define BF_CCM_ANALOG_PLL_ARM_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_BYPASS) & BM_CCM_ANALOG_PLL_ARM_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_BYPASS(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_BYPASS) | BF_CCM_ANALOG_PLL_ARM_BYPASS(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field LVDS_SEL[17] (RW)
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_LVDS_SEL (17U) /*!< Bit position for CCM_ANALOG_PLL_ARM_LVDS_SEL. */
#define BM_CCM_ANALOG_PLL_ARM_LVDS_SEL (0x00020000U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_LVDS_SEL. */
#define BS_CCM_ANALOG_PLL_ARM_LVDS_SEL (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_LVDS_SEL. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_LVDS_SEL field. */
#define BR_CCM_ANALOG_PLL_ARM_LVDS_SEL(x) (HW_CCM_ANALOG_PLL_ARM(x).B.LVDS_SEL)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_LVDS_SEL. */
#define BF_CCM_ANALOG_PLL_ARM_LVDS_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_LVDS_SEL) & BM_CCM_ANALOG_PLL_ARM_LVDS_SEL)

/*! @brief Set the LVDS_SEL field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_LVDS_SEL(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_LVDS_SEL) | BF_CCM_ANALOG_PLL_ARM_LVDS_SEL(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field LVDS_24MHZ_SEL[18] (RW)
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL (18U) /*!< Bit position for CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL. */
#define BM_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL (0x00040000U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL. */
#define BS_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL field. */
#define BR_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL(x) (HW_CCM_ANALOG_PLL_ARM(x).B.LVDS_24MHZ_SEL)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL. */
#define BF_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL) & BM_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL)

/*! @brief Set the LVDS_24MHZ_SEL field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL) | BF_CCM_ANALOG_PLL_ARM_LVDS_24MHZ_SEL(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field PLL_SEL[19] (RW)
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_PLL_SEL (19U) /*!< Bit position for CCM_ANALOG_PLL_ARM_PLL_SEL. */
#define BM_CCM_ANALOG_PLL_ARM_PLL_SEL (0x00080000U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_PLL_SEL. */
#define BS_CCM_ANALOG_PLL_ARM_PLL_SEL (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_PLL_SEL. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_PLL_SEL field. */
#define BR_CCM_ANALOG_PLL_ARM_PLL_SEL(x) (HW_CCM_ANALOG_PLL_ARM(x).B.PLL_SEL)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_PLL_SEL. */
#define BF_CCM_ANALOG_PLL_ARM_PLL_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_PLL_SEL) & BM_CCM_ANALOG_PLL_ARM_PLL_SEL)

/*! @brief Set the PLL_SEL field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_PLL_SEL(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_PLL_SEL) | BF_CCM_ANALOG_PLL_ARM_PLL_SEL(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field PLL_ARM_OVERRIDE[20] (RW)
 *
 * The OVERRIDE bit allows the clock control module to automatically override
 * portions of the register.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_PLL_ARM_OVERRIDE (20U) /*!< Bit position for CCM_ANALOG_PLL_ARM_PLL_ARM_OVERRIDE. */
#define BM_CCM_ANALOG_PLL_ARM_PLL_ARM_OVERRIDE (0x00100000U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_PLL_ARM_OVERRIDE. */
#define BS_CCM_ANALOG_PLL_ARM_PLL_ARM_OVERRIDE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_PLL_ARM_OVERRIDE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_PLL_ARM_OVERRIDE field. */
#define BR_CCM_ANALOG_PLL_ARM_PLL_ARM_OVERRIDE(x) (HW_CCM_ANALOG_PLL_ARM(x).B.PLL_ARM_OVERRIDE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ARM_PLL_ARM_OVERRIDE. */
#define BF_CCM_ANALOG_PLL_ARM_PLL_ARM_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ARM_PLL_ARM_OVERRIDE) & BM_CCM_ANALOG_PLL_ARM_PLL_ARM_OVERRIDE)

/*! @brief Set the PLL_ARM_OVERRIDE field to a new value. */
#define BW_CCM_ANALOG_PLL_ARM_PLL_ARM_OVERRIDE(x, v) (HW_CCM_ANALOG_PLL_ARM_WR(x, (HW_CCM_ANALOG_PLL_ARM_RD(x) & ~BM_CCM_ANALOG_PLL_ARM_PLL_ARM_OVERRIDE) | BF_CCM_ANALOG_PLL_ARM_PLL_ARM_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field RSVD0[30:21] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_RSVD0 (21U)  /*!< Bit position for CCM_ANALOG_PLL_ARM_RSVD0. */
#define BM_CCM_ANALOG_PLL_ARM_RSVD0 (0x7FE00000U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_RSVD0. */
#define BS_CCM_ANALOG_PLL_ARM_RSVD0 (10U)  /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_RSVD0. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_RSVD0 field. */
#define BR_CCM_ANALOG_PLL_ARM_RSVD0(x) (HW_CCM_ANALOG_PLL_ARM(x).B.RSVD0)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ARM, field LOCK[31] (RO)
 *
 * 1 - PLL is currently locked; 0 - PLL is not currently locked.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ARM_LOCK (31U)   /*!< Bit position for CCM_ANALOG_PLL_ARM_LOCK. */
#define BM_CCM_ANALOG_PLL_ARM_LOCK (0x80000000U) /*!< Bit mask for CCM_ANALOG_PLL_ARM_LOCK. */
#define BS_CCM_ANALOG_PLL_ARM_LOCK (1U)    /*!< Bit field size in bits for CCM_ANALOG_PLL_ARM_LOCK. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ARM_LOCK field. */
#define BR_CCM_ANALOG_PLL_ARM_LOCK(x) (HW_CCM_ANALOG_PLL_ARM(x).B.LOCK)
/*@}*/




/*******************************************************************************
 * HW_CCM_ANALOG_PLL_DDR - Anadig DDR PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_DDR - Anadig DDR PLL Control Register (RW)
 *
 * Reset value: 0x00113021U
 *
 * The control register provides control for the 480MHz PLL.
 */
typedef union _hw_ccm_analog_pll_ddr
{
    uint32_t U;
    struct _hw_ccm_analog_pll_ddr_bitfields
    {
        uint32_t DIV_SELECT : 7;       /*!< [6:0]  */
        uint32_t HALF_LF : 1;          /*!< [7]  */
        uint32_t DOUBLE_LF : 1;        /*!< [8]  */
        uint32_t HALF_CP : 1;          /*!< [9]  */
        uint32_t DOUBLE_CP : 1;        /*!< [10]  */
        uint32_t HOLD_RING_OFF : 1;    /*!< [11]  */
        uint32_t DIV2_ENABLE_CLK : 1;  /*!< [12]  */
        uint32_t ENABLE_CLK : 1;       /*!< [13]  */
        uint32_t BYPASS_CLK_SRC : 2;   /*!< [15:14]  */
        uint32_t BYPASS : 1;           /*!< [16]  */
        uint32_t DITHER_ENABLE : 1;    /*!< [17]  */
        uint32_t PFD_OFFSET_EN : 1;    /*!< [18]  */
        uint32_t PLL_DDR_OVERRIDE : 1; /*!< [19]  */
        uint32_t POWERDOWN : 1;        /*!< [20]  */
        uint32_t TEST_DIV_SELECT : 2;  /*!< [22:21]  */
        uint32_t RSVD1 : 8;            /*!< [30:23]  */
        uint32_t LOCK : 1;             /*!< [31]  */
    } B;
} hw_ccm_analog_pll_ddr_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_DDR register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_DDR_ADDR(x) ((uintptr_t)(x) + 0x70U)
#define HW_CCM_ANALOG_PLL_DDR_SET_ADDR(x) (HW_CCM_ANALOG_PLL_DDR_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_PLL_DDR_CLR_ADDR(x) (HW_CCM_ANALOG_PLL_DDR_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_PLL_DDR_TOG_ADDR(x) (HW_CCM_ANALOG_PLL_DDR_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_PLL_DDR(x) (*(__IO hw_ccm_analog_pll_ddr_t *) HW_CCM_ANALOG_PLL_DDR_ADDR(x))
#define HW_CCM_ANALOG_PLL_DDR_RD(x) (HW_CCM_ANALOG_PLL_DDR(x).U)
#define HW_CCM_ANALOG_PLL_DDR_WR(x, v) (HW_CCM_ANALOG_PLL_DDR(x).U = (v))
#define HW_CCM_ANALOG_PLL_DDR_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_DDR_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_DDR_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_DDR_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_DDR_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_DDR_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_DDR bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_DDR, field DIV_SELECT[6:0] (RW)
 *
 * This field controls the pll loop divider. Valid values for divider: 33 to 44.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_DIV_SELECT (0U) /*!< Bit position for CCM_ANALOG_PLL_DDR_DIV_SELECT. */
#define BM_CCM_ANALOG_PLL_DDR_DIV_SELECT (0x0000007FU) /*!< Bit mask for CCM_ANALOG_PLL_DDR_DIV_SELECT. */
#define BS_CCM_ANALOG_PLL_DDR_DIV_SELECT (7U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_DIV_SELECT. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_DIV_SELECT field. */
#define BR_CCM_ANALOG_PLL_DDR_DIV_SELECT(x) (HW_CCM_ANALOG_PLL_DDR(x).B.DIV_SELECT)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_DIV_SELECT. */
#define BF_CCM_ANALOG_PLL_DDR_DIV_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_DIV_SELECT) & BM_CCM_ANALOG_PLL_DDR_DIV_SELECT)

/*! @brief Set the DIV_SELECT field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_DIV_SELECT(x, v) (HW_CCM_ANALOG_PLL_DDR_WR(x, (HW_CCM_ANALOG_PLL_DDR_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_DIV_SELECT) | BF_CCM_ANALOG_PLL_DDR_DIV_SELECT(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR, field HALF_LF[7] (RW)
 *
 * Reduces the frequency of the loop filter 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_HALF_LF (7U) /*!< Bit position for CCM_ANALOG_PLL_DDR_HALF_LF. */
#define BM_CCM_ANALOG_PLL_DDR_HALF_LF (0x00000080U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_HALF_LF. */
#define BS_CCM_ANALOG_PLL_DDR_HALF_LF (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_HALF_LF. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_HALF_LF field. */
#define BR_CCM_ANALOG_PLL_DDR_HALF_LF(x) (HW_CCM_ANALOG_PLL_DDR(x).B.HALF_LF)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_HALF_LF. */
#define BF_CCM_ANALOG_PLL_DDR_HALF_LF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_HALF_LF) & BM_CCM_ANALOG_PLL_DDR_HALF_LF)

/*! @brief Set the HALF_LF field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_HALF_LF(x, v) (HW_CCM_ANALOG_PLL_DDR_WR(x, (HW_CCM_ANALOG_PLL_DDR_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_HALF_LF) | BF_CCM_ANALOG_PLL_DDR_HALF_LF(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR, field DOUBLE_LF[8] (RW)
 *
 * Increases the frequency of the loop filter 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_DOUBLE_LF (8U) /*!< Bit position for CCM_ANALOG_PLL_DDR_DOUBLE_LF. */
#define BM_CCM_ANALOG_PLL_DDR_DOUBLE_LF (0x00000100U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_DOUBLE_LF. */
#define BS_CCM_ANALOG_PLL_DDR_DOUBLE_LF (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_DOUBLE_LF. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_DOUBLE_LF field. */
#define BR_CCM_ANALOG_PLL_DDR_DOUBLE_LF(x) (HW_CCM_ANALOG_PLL_DDR(x).B.DOUBLE_LF)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_DOUBLE_LF. */
#define BF_CCM_ANALOG_PLL_DDR_DOUBLE_LF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_DOUBLE_LF) & BM_CCM_ANALOG_PLL_DDR_DOUBLE_LF)

/*! @brief Set the DOUBLE_LF field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_DOUBLE_LF(x, v) (HW_CCM_ANALOG_PLL_DDR_WR(x, (HW_CCM_ANALOG_PLL_DDR_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_DOUBLE_LF) | BF_CCM_ANALOG_PLL_DDR_DOUBLE_LF(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR, field HALF_CP[9] (RW)
 *
 * Reduces the charge pump gain 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_HALF_CP (9U) /*!< Bit position for CCM_ANALOG_PLL_DDR_HALF_CP. */
#define BM_CCM_ANALOG_PLL_DDR_HALF_CP (0x00000200U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_HALF_CP. */
#define BS_CCM_ANALOG_PLL_DDR_HALF_CP (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_HALF_CP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_HALF_CP field. */
#define BR_CCM_ANALOG_PLL_DDR_HALF_CP(x) (HW_CCM_ANALOG_PLL_DDR(x).B.HALF_CP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_HALF_CP. */
#define BF_CCM_ANALOG_PLL_DDR_HALF_CP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_HALF_CP) & BM_CCM_ANALOG_PLL_DDR_HALF_CP)

/*! @brief Set the HALF_CP field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_HALF_CP(x, v) (HW_CCM_ANALOG_PLL_DDR_WR(x, (HW_CCM_ANALOG_PLL_DDR_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_HALF_CP) | BF_CCM_ANALOG_PLL_DDR_HALF_CP(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR, field DOUBLE_CP[10] (RW)
 *
 * Increases the charge pump gain 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_DOUBLE_CP (10U) /*!< Bit position for CCM_ANALOG_PLL_DDR_DOUBLE_CP. */
#define BM_CCM_ANALOG_PLL_DDR_DOUBLE_CP (0x00000400U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_DOUBLE_CP. */
#define BS_CCM_ANALOG_PLL_DDR_DOUBLE_CP (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_DOUBLE_CP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_DOUBLE_CP field. */
#define BR_CCM_ANALOG_PLL_DDR_DOUBLE_CP(x) (HW_CCM_ANALOG_PLL_DDR(x).B.DOUBLE_CP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_DOUBLE_CP. */
#define BF_CCM_ANALOG_PLL_DDR_DOUBLE_CP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_DOUBLE_CP) & BM_CCM_ANALOG_PLL_DDR_DOUBLE_CP)

/*! @brief Set the DOUBLE_CP field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_DOUBLE_CP(x, v) (HW_CCM_ANALOG_PLL_DDR_WR(x, (HW_CCM_ANALOG_PLL_DDR_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_DOUBLE_CP) | BF_CCM_ANALOG_PLL_DDR_DOUBLE_CP(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR, field HOLD_RING_OFF[11] (RW)
 *
 * Status of ana_irq2 input from analog block.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_HOLD_RING_OFF (11U) /*!< Bit position for CCM_ANALOG_PLL_DDR_HOLD_RING_OFF. */
#define BM_CCM_ANALOG_PLL_DDR_HOLD_RING_OFF (0x00000800U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_HOLD_RING_OFF. */
#define BS_CCM_ANALOG_PLL_DDR_HOLD_RING_OFF (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_HOLD_RING_OFF. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_HOLD_RING_OFF field. */
#define BR_CCM_ANALOG_PLL_DDR_HOLD_RING_OFF(x) (HW_CCM_ANALOG_PLL_DDR(x).B.HOLD_RING_OFF)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_HOLD_RING_OFF. */
#define BF_CCM_ANALOG_PLL_DDR_HOLD_RING_OFF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_HOLD_RING_OFF) & BM_CCM_ANALOG_PLL_DDR_HOLD_RING_OFF)

/*! @brief Set the HOLD_RING_OFF field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_HOLD_RING_OFF(x, v) (HW_CCM_ANALOG_PLL_DDR_WR(x, (HW_CCM_ANALOG_PLL_DDR_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_HOLD_RING_OFF) | BF_CCM_ANALOG_PLL_DDR_HOLD_RING_OFF(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR, field DIV2_ENABLE_CLK[12] (RW)
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_DIV2_ENABLE_CLK (12U) /*!< Bit position for CCM_ANALOG_PLL_DDR_DIV2_ENABLE_CLK. */
#define BM_CCM_ANALOG_PLL_DDR_DIV2_ENABLE_CLK (0x00001000U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_DIV2_ENABLE_CLK. */
#define BS_CCM_ANALOG_PLL_DDR_DIV2_ENABLE_CLK (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_DIV2_ENABLE_CLK. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_DIV2_ENABLE_CLK field. */
#define BR_CCM_ANALOG_PLL_DDR_DIV2_ENABLE_CLK(x) (HW_CCM_ANALOG_PLL_DDR(x).B.DIV2_ENABLE_CLK)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_DIV2_ENABLE_CLK. */
#define BF_CCM_ANALOG_PLL_DDR_DIV2_ENABLE_CLK(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_DIV2_ENABLE_CLK) & BM_CCM_ANALOG_PLL_DDR_DIV2_ENABLE_CLK)

/*! @brief Set the DIV2_ENABLE_CLK field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_DIV2_ENABLE_CLK(x, v) (HW_CCM_ANALOG_PLL_DDR_WR(x, (HW_CCM_ANALOG_PLL_DDR_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_DIV2_ENABLE_CLK) | BF_CCM_ANALOG_PLL_DDR_DIV2_ENABLE_CLK(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR, field ENABLE_CLK[13] (RW)
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_ENABLE_CLK (13U) /*!< Bit position for CCM_ANALOG_PLL_DDR_ENABLE_CLK. */
#define BM_CCM_ANALOG_PLL_DDR_ENABLE_CLK (0x00002000U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_ENABLE_CLK. */
#define BS_CCM_ANALOG_PLL_DDR_ENABLE_CLK (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_ENABLE_CLK. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_ENABLE_CLK field. */
#define BR_CCM_ANALOG_PLL_DDR_ENABLE_CLK(x) (HW_CCM_ANALOG_PLL_DDR(x).B.ENABLE_CLK)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_ENABLE_CLK. */
#define BF_CCM_ANALOG_PLL_DDR_ENABLE_CLK(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_ENABLE_CLK) & BM_CCM_ANALOG_PLL_DDR_ENABLE_CLK)

/*! @brief Set the ENABLE_CLK field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_ENABLE_CLK(x, v) (HW_CCM_ANALOG_PLL_DDR_WR(x, (HW_CCM_ANALOG_PLL_DDR_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_ENABLE_CLK) | BF_CCM_ANALOG_PLL_DDR_ENABLE_CLK(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR, field BYPASS_CLK_SRC[15:14] (RW)
 *
 * Determines the bypass source.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC (14U) /*!< Bit position for CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC. */
#define BM_CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC (0x0000C000U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC. */
#define BS_CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC field. */
#define BR_CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC(x) (HW_CCM_ANALOG_PLL_DDR(x).B.BYPASS_CLK_SRC)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC. */
#define BF_CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC) & BM_CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC)

/*! @brief Set the BYPASS_CLK_SRC field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC(x, v) (HW_CCM_ANALOG_PLL_DDR_WR(x, (HW_CCM_ANALOG_PLL_DDR_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC) | BF_CCM_ANALOG_PLL_DDR_BYPASS_CLK_SRC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR, field BYPASS[16] (RW)
 *
 * Bypass the pll.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_BYPASS (16U) /*!< Bit position for CCM_ANALOG_PLL_DDR_BYPASS. */
#define BM_CCM_ANALOG_PLL_DDR_BYPASS (0x00010000U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_BYPASS. */
#define BS_CCM_ANALOG_PLL_DDR_BYPASS (1U)  /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_BYPASS. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_BYPASS field. */
#define BR_CCM_ANALOG_PLL_DDR_BYPASS(x) (HW_CCM_ANALOG_PLL_DDR(x).B.BYPASS)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_BYPASS. */
#define BF_CCM_ANALOG_PLL_DDR_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_BYPASS) & BM_CCM_ANALOG_PLL_DDR_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_BYPASS(x, v) (HW_CCM_ANALOG_PLL_DDR_WR(x, (HW_CCM_ANALOG_PLL_DDR_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_BYPASS) | BF_CCM_ANALOG_PLL_DDR_BYPASS(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR, field DITHER_ENABLE[17] (RW)
 *
 * Enables dither in the fractional modulator calculation.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_DITHER_ENABLE (17U) /*!< Bit position for CCM_ANALOG_PLL_DDR_DITHER_ENABLE. */
#define BM_CCM_ANALOG_PLL_DDR_DITHER_ENABLE (0x00020000U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_DITHER_ENABLE. */
#define BS_CCM_ANALOG_PLL_DDR_DITHER_ENABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_DITHER_ENABLE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_DITHER_ENABLE field. */
#define BR_CCM_ANALOG_PLL_DDR_DITHER_ENABLE(x) (HW_CCM_ANALOG_PLL_DDR(x).B.DITHER_ENABLE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_DITHER_ENABLE. */
#define BF_CCM_ANALOG_PLL_DDR_DITHER_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_DITHER_ENABLE) & BM_CCM_ANALOG_PLL_DDR_DITHER_ENABLE)

/*! @brief Set the DITHER_ENABLE field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_DITHER_ENABLE(x, v) (HW_CCM_ANALOG_PLL_DDR_WR(x, (HW_CCM_ANALOG_PLL_DDR_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_DITHER_ENABLE) | BF_CCM_ANALOG_PLL_DDR_DITHER_ENABLE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR, field PFD_OFFSET_EN[18] (RW)
 *
 * Enables an offset in the phase frequency detector.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_PFD_OFFSET_EN (18U) /*!< Bit position for CCM_ANALOG_PLL_DDR_PFD_OFFSET_EN. */
#define BM_CCM_ANALOG_PLL_DDR_PFD_OFFSET_EN (0x00040000U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_PFD_OFFSET_EN. */
#define BS_CCM_ANALOG_PLL_DDR_PFD_OFFSET_EN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_PFD_OFFSET_EN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_PFD_OFFSET_EN field. */
#define BR_CCM_ANALOG_PLL_DDR_PFD_OFFSET_EN(x) (HW_CCM_ANALOG_PLL_DDR(x).B.PFD_OFFSET_EN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_PFD_OFFSET_EN. */
#define BF_CCM_ANALOG_PLL_DDR_PFD_OFFSET_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_PFD_OFFSET_EN) & BM_CCM_ANALOG_PLL_DDR_PFD_OFFSET_EN)

/*! @brief Set the PFD_OFFSET_EN field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_PFD_OFFSET_EN(x, v) (HW_CCM_ANALOG_PLL_DDR_WR(x, (HW_CCM_ANALOG_PLL_DDR_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_PFD_OFFSET_EN) | BF_CCM_ANALOG_PLL_DDR_PFD_OFFSET_EN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR, field PLL_DDR_OVERRIDE[19] (RW)
 *
 * The OVERRIDE bit allows the clock control module to automatically override
 * portions of the register.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_PLL_DDR_OVERRIDE (19U) /*!< Bit position for CCM_ANALOG_PLL_DDR_PLL_DDR_OVERRIDE. */
#define BM_CCM_ANALOG_PLL_DDR_PLL_DDR_OVERRIDE (0x00080000U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_PLL_DDR_OVERRIDE. */
#define BS_CCM_ANALOG_PLL_DDR_PLL_DDR_OVERRIDE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_PLL_DDR_OVERRIDE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_PLL_DDR_OVERRIDE field. */
#define BR_CCM_ANALOG_PLL_DDR_PLL_DDR_OVERRIDE(x) (HW_CCM_ANALOG_PLL_DDR(x).B.PLL_DDR_OVERRIDE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_PLL_DDR_OVERRIDE. */
#define BF_CCM_ANALOG_PLL_DDR_PLL_DDR_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_PLL_DDR_OVERRIDE) & BM_CCM_ANALOG_PLL_DDR_PLL_DDR_OVERRIDE)

/*! @brief Set the PLL_DDR_OVERRIDE field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_PLL_DDR_OVERRIDE(x, v) (HW_CCM_ANALOG_PLL_DDR_WR(x, (HW_CCM_ANALOG_PLL_DDR_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_PLL_DDR_OVERRIDE) | BF_CCM_ANALOG_PLL_DDR_PLL_DDR_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR, field POWERDOWN[20] (RW)
 *
 * Powers down the PLL.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_POWERDOWN (20U) /*!< Bit position for CCM_ANALOG_PLL_DDR_POWERDOWN. */
#define BM_CCM_ANALOG_PLL_DDR_POWERDOWN (0x00100000U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_POWERDOWN. */
#define BS_CCM_ANALOG_PLL_DDR_POWERDOWN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_POWERDOWN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_POWERDOWN field. */
#define BR_CCM_ANALOG_PLL_DDR_POWERDOWN(x) (HW_CCM_ANALOG_PLL_DDR(x).B.POWERDOWN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_POWERDOWN. */
#define BF_CCM_ANALOG_PLL_DDR_POWERDOWN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_POWERDOWN) & BM_CCM_ANALOG_PLL_DDR_POWERDOWN)

/*! @brief Set the POWERDOWN field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_POWERDOWN(x, v) (HW_CCM_ANALOG_PLL_DDR_WR(x, (HW_CCM_ANALOG_PLL_DDR_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_POWERDOWN) | BF_CCM_ANALOG_PLL_DDR_POWERDOWN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR, field TEST_DIV_SELECT[22:21] (RW)
 *
 * Control bits for the post divider for the PLL clk and lvds outputs:
 * 0x0=div-by-4(default), 0x1=div-by-2, 0x2=div-by-1, 0x3=div-by-1
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT (21U) /*!< Bit position for CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT. */
#define BM_CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT (0x00600000U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT. */
#define BS_CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT field. */
#define BR_CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT(x) (HW_CCM_ANALOG_PLL_DDR(x).B.TEST_DIV_SELECT)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT. */
#define BF_CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT) & BM_CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT)

/*! @brief Set the TEST_DIV_SELECT field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT(x, v) (HW_CCM_ANALOG_PLL_DDR_WR(x, (HW_CCM_ANALOG_PLL_DDR_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT) | BF_CCM_ANALOG_PLL_DDR_TEST_DIV_SELECT(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR, field RSVD1[30:23] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_RSVD1 (23U)  /*!< Bit position for CCM_ANALOG_PLL_DDR_RSVD1. */
#define BM_CCM_ANALOG_PLL_DDR_RSVD1 (0x7F800000U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_RSVD1. */
#define BS_CCM_ANALOG_PLL_DDR_RSVD1 (8U)   /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_RSVD1. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_RSVD1 field. */
#define BR_CCM_ANALOG_PLL_DDR_RSVD1(x) (HW_CCM_ANALOG_PLL_DDR(x).B.RSVD1)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR, field LOCK[31] (RO)
 *
 * 1 - PLL is currently locked; 0 - PLL is not currently locked.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_LOCK (31U)   /*!< Bit position for CCM_ANALOG_PLL_DDR_LOCK. */
#define BM_CCM_ANALOG_PLL_DDR_LOCK (0x80000000U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_LOCK. */
#define BS_CCM_ANALOG_PLL_DDR_LOCK (1U)    /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_LOCK. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_LOCK field. */
#define BR_CCM_ANALOG_PLL_DDR_LOCK(x) (HW_CCM_ANALOG_PLL_DDR(x).B.LOCK)
/*@}*/




/*******************************************************************************
 * HW_CCM_ANALOG_PLL_DDR_SS - DDR PLL Spread Spectrum Register.
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_DDR_SS - DDR PLL Spread Spectrum Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the DDR PLL spread spectrum controls.
 */
typedef union _hw_ccm_analog_pll_ddr_ss
{
    uint32_t U;
    struct _hw_ccm_analog_pll_ddr_ss_bitfields
    {
        uint32_t STEP : 15;            /*!< [14:0]  */
        uint32_t ENABLE : 1;           /*!< [15]  */
        uint32_t STOP : 16;            /*!< [31:16]  */
    } B;
} hw_ccm_analog_pll_ddr_ss_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_DDR_SS register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_DDR_SS_ADDR(x) ((uintptr_t)(x) + 0x80U)

#define HW_CCM_ANALOG_PLL_DDR_SS(x) (*(__IO hw_ccm_analog_pll_ddr_ss_t *) HW_CCM_ANALOG_PLL_DDR_SS_ADDR(x))
#define HW_CCM_ANALOG_PLL_DDR_SS_RD(x) (HW_CCM_ANALOG_PLL_DDR_SS(x).U)
#define HW_CCM_ANALOG_PLL_DDR_SS_WR(x, v) (HW_CCM_ANALOG_PLL_DDR_SS(x).U = (v))
#define HW_CCM_ANALOG_PLL_DDR_SS_SET(x, v) (HW_CCM_ANALOG_PLL_DDR_SS_WR(x, HW_CCM_ANALOG_PLL_DDR_SS_RD(x) |  (v)))
#define HW_CCM_ANALOG_PLL_DDR_SS_CLR(x, v) (HW_CCM_ANALOG_PLL_DDR_SS_WR(x, HW_CCM_ANALOG_PLL_DDR_SS_RD(x) & ~(v)))
#define HW_CCM_ANALOG_PLL_DDR_SS_TOG(x, v) (HW_CCM_ANALOG_PLL_DDR_SS_WR(x, HW_CCM_ANALOG_PLL_DDR_SS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_DDR_SS bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_DDR_SS, field STEP[14:0] (RW)
 *
 * The max frequency change = stop/B*24MHz.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_SS_STEP (0U) /*!< Bit position for CCM_ANALOG_PLL_DDR_SS_STEP. */
#define BM_CCM_ANALOG_PLL_DDR_SS_STEP (0x00007FFFU) /*!< Bit mask for CCM_ANALOG_PLL_DDR_SS_STEP. */
#define BS_CCM_ANALOG_PLL_DDR_SS_STEP (15U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_SS_STEP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_SS_STEP field. */
#define BR_CCM_ANALOG_PLL_DDR_SS_STEP(x) (HW_CCM_ANALOG_PLL_DDR_SS(x).B.STEP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_SS_STEP. */
#define BF_CCM_ANALOG_PLL_DDR_SS_STEP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_SS_STEP) & BM_CCM_ANALOG_PLL_DDR_SS_STEP)

/*! @brief Set the STEP field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_SS_STEP(x, v) (HW_CCM_ANALOG_PLL_DDR_SS_WR(x, (HW_CCM_ANALOG_PLL_DDR_SS_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_SS_STEP) | BF_CCM_ANALOG_PLL_DDR_SS_STEP(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR_SS, field ENABLE[15] (RW)
 *
 * This bit enables the spread spectrum modulation.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_SS_ENABLE (15U) /*!< Bit position for CCM_ANALOG_PLL_DDR_SS_ENABLE. */
#define BM_CCM_ANALOG_PLL_DDR_SS_ENABLE (0x00008000U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_SS_ENABLE. */
#define BS_CCM_ANALOG_PLL_DDR_SS_ENABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_SS_ENABLE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_SS_ENABLE field. */
#define BR_CCM_ANALOG_PLL_DDR_SS_ENABLE(x) (HW_CCM_ANALOG_PLL_DDR_SS(x).B.ENABLE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_SS_ENABLE. */
#define BF_CCM_ANALOG_PLL_DDR_SS_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_SS_ENABLE) & BM_CCM_ANALOG_PLL_DDR_SS_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_SS_ENABLE(x, v) (HW_CCM_ANALOG_PLL_DDR_SS_WR(x, (HW_CCM_ANALOG_PLL_DDR_SS_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_SS_ENABLE) | BF_CCM_ANALOG_PLL_DDR_SS_ENABLE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR_SS, field STOP[31:16] (RW)
 *
 * Frequency change = step/B*24MHz.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_SS_STOP (16U) /*!< Bit position for CCM_ANALOG_PLL_DDR_SS_STOP. */
#define BM_CCM_ANALOG_PLL_DDR_SS_STOP (0xFFFF0000U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_SS_STOP. */
#define BS_CCM_ANALOG_PLL_DDR_SS_STOP (16U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_SS_STOP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_SS_STOP field. */
#define BR_CCM_ANALOG_PLL_DDR_SS_STOP(x) (HW_CCM_ANALOG_PLL_DDR_SS(x).B.STOP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_SS_STOP. */
#define BF_CCM_ANALOG_PLL_DDR_SS_STOP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_SS_STOP) & BM_CCM_ANALOG_PLL_DDR_SS_STOP)

/*! @brief Set the STOP field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_SS_STOP(x, v) (HW_CCM_ANALOG_PLL_DDR_SS_WR(x, (HW_CCM_ANALOG_PLL_DDR_SS_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_SS_STOP) | BF_CCM_ANALOG_PLL_DDR_SS_STOP(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_ANALOG_PLL_DDR_NUM - Numerator of DDR PLL Fractional Loop Divider Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_DDR_NUM - Numerator of DDR PLL Fractional Loop Divider Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the numerator of DDR PLL fractional loop divider.
 */
typedef union _hw_ccm_analog_pll_ddr_num
{
    uint32_t U;
    struct _hw_ccm_analog_pll_ddr_num_bitfields
    {
        uint32_t A : 30;               /*!< [29:0]  */
        uint32_t RSVD0 : 2;            /*!< [31:30]  */
    } B;
} hw_ccm_analog_pll_ddr_num_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_DDR_NUM register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_DDR_NUM_ADDR(x) ((uintptr_t)(x) + 0x90U)

#define HW_CCM_ANALOG_PLL_DDR_NUM(x) (*(__IO hw_ccm_analog_pll_ddr_num_t *) HW_CCM_ANALOG_PLL_DDR_NUM_ADDR(x))
#define HW_CCM_ANALOG_PLL_DDR_NUM_RD(x) (HW_CCM_ANALOG_PLL_DDR_NUM(x).U)
#define HW_CCM_ANALOG_PLL_DDR_NUM_WR(x, v) (HW_CCM_ANALOG_PLL_DDR_NUM(x).U = (v))
#define HW_CCM_ANALOG_PLL_DDR_NUM_SET(x, v) (HW_CCM_ANALOG_PLL_DDR_NUM_WR(x, HW_CCM_ANALOG_PLL_DDR_NUM_RD(x) |  (v)))
#define HW_CCM_ANALOG_PLL_DDR_NUM_CLR(x, v) (HW_CCM_ANALOG_PLL_DDR_NUM_WR(x, HW_CCM_ANALOG_PLL_DDR_NUM_RD(x) & ~(v)))
#define HW_CCM_ANALOG_PLL_DDR_NUM_TOG(x, v) (HW_CCM_ANALOG_PLL_DDR_NUM_WR(x, HW_CCM_ANALOG_PLL_DDR_NUM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_DDR_NUM bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_DDR_NUM, field A[29:0] (RW)
 *
 * 30 bit numerator (A) of fractional loop divider (signed integer).
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_NUM_A (0U)   /*!< Bit position for CCM_ANALOG_PLL_DDR_NUM_A. */
#define BM_CCM_ANALOG_PLL_DDR_NUM_A (0x3FFFFFFFU) /*!< Bit mask for CCM_ANALOG_PLL_DDR_NUM_A. */
#define BS_CCM_ANALOG_PLL_DDR_NUM_A (30U)  /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_NUM_A. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_NUM_A field. */
#define BR_CCM_ANALOG_PLL_DDR_NUM_A(x) (HW_CCM_ANALOG_PLL_DDR_NUM(x).B.A)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_NUM_A. */
#define BF_CCM_ANALOG_PLL_DDR_NUM_A(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_NUM_A) & BM_CCM_ANALOG_PLL_DDR_NUM_A)

/*! @brief Set the A field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_NUM_A(x, v) (HW_CCM_ANALOG_PLL_DDR_NUM_WR(x, (HW_CCM_ANALOG_PLL_DDR_NUM_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_NUM_A) | BF_CCM_ANALOG_PLL_DDR_NUM_A(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR_NUM, field RSVD0[31:30] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_NUM_RSVD0 (30U) /*!< Bit position for CCM_ANALOG_PLL_DDR_NUM_RSVD0. */
#define BM_CCM_ANALOG_PLL_DDR_NUM_RSVD0 (0xC0000000U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_NUM_RSVD0. */
#define BS_CCM_ANALOG_PLL_DDR_NUM_RSVD0 (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_NUM_RSVD0. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_NUM_RSVD0 field. */
#define BR_CCM_ANALOG_PLL_DDR_NUM_RSVD0(x) (HW_CCM_ANALOG_PLL_DDR_NUM(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_CCM_ANALOG_PLL_DDR_DENOM - Denominator of DDR PLL Fractional Loop Divider Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_DDR_DENOM - Denominator of DDR PLL Fractional Loop Divider Register (RW)
 *
 * Reset value: 0x00000012U
 *
 * This register contains the Denominator of DDR PLL fractional loop divider.
 */
typedef union _hw_ccm_analog_pll_ddr_denom
{
    uint32_t U;
    struct _hw_ccm_analog_pll_ddr_denom_bitfields
    {
        uint32_t B : 30;               /*!< [29:0]  */
        uint32_t RSVD0 : 2;            /*!< [31:30]  */
    } B;
} hw_ccm_analog_pll_ddr_denom_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_DDR_DENOM register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_DDR_DENOM_ADDR(x) ((uintptr_t)(x) + 0xA0U)

#define HW_CCM_ANALOG_PLL_DDR_DENOM(x) (*(__IO hw_ccm_analog_pll_ddr_denom_t *) HW_CCM_ANALOG_PLL_DDR_DENOM_ADDR(x))
#define HW_CCM_ANALOG_PLL_DDR_DENOM_RD(x) (HW_CCM_ANALOG_PLL_DDR_DENOM(x).U)
#define HW_CCM_ANALOG_PLL_DDR_DENOM_WR(x, v) (HW_CCM_ANALOG_PLL_DDR_DENOM(x).U = (v))
#define HW_CCM_ANALOG_PLL_DDR_DENOM_SET(x, v) (HW_CCM_ANALOG_PLL_DDR_DENOM_WR(x, HW_CCM_ANALOG_PLL_DDR_DENOM_RD(x) |  (v)))
#define HW_CCM_ANALOG_PLL_DDR_DENOM_CLR(x, v) (HW_CCM_ANALOG_PLL_DDR_DENOM_WR(x, HW_CCM_ANALOG_PLL_DDR_DENOM_RD(x) & ~(v)))
#define HW_CCM_ANALOG_PLL_DDR_DENOM_TOG(x, v) (HW_CCM_ANALOG_PLL_DDR_DENOM_WR(x, HW_CCM_ANALOG_PLL_DDR_DENOM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_DDR_DENOM bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_DDR_DENOM, field B[29:0] (RW)
 *
 * 30 bit Denominator (B) of fractional loop divider (signed integer).
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_DENOM_B (0U) /*!< Bit position for CCM_ANALOG_PLL_DDR_DENOM_B. */
#define BM_CCM_ANALOG_PLL_DDR_DENOM_B (0x3FFFFFFFU) /*!< Bit mask for CCM_ANALOG_PLL_DDR_DENOM_B. */
#define BS_CCM_ANALOG_PLL_DDR_DENOM_B (30U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_DENOM_B. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_DENOM_B field. */
#define BR_CCM_ANALOG_PLL_DDR_DENOM_B(x) (HW_CCM_ANALOG_PLL_DDR_DENOM(x).B.B)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_DDR_DENOM_B. */
#define BF_CCM_ANALOG_PLL_DDR_DENOM_B(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_DDR_DENOM_B) & BM_CCM_ANALOG_PLL_DDR_DENOM_B)

/*! @brief Set the B field to a new value. */
#define BW_CCM_ANALOG_PLL_DDR_DENOM_B(x, v) (HW_CCM_ANALOG_PLL_DDR_DENOM_WR(x, (HW_CCM_ANALOG_PLL_DDR_DENOM_RD(x) & ~BM_CCM_ANALOG_PLL_DDR_DENOM_B) | BF_CCM_ANALOG_PLL_DDR_DENOM_B(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_DDR_DENOM, field RSVD0[31:30] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_DDR_DENOM_RSVD0 (30U) /*!< Bit position for CCM_ANALOG_PLL_DDR_DENOM_RSVD0. */
#define BM_CCM_ANALOG_PLL_DDR_DENOM_RSVD0 (0xC0000000U) /*!< Bit mask for CCM_ANALOG_PLL_DDR_DENOM_RSVD0. */
#define BS_CCM_ANALOG_PLL_DDR_DENOM_RSVD0 (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_DDR_DENOM_RSVD0. */

/*! @brief Read current value of the CCM_ANALOG_PLL_DDR_DENOM_RSVD0 field. */
#define BR_CCM_ANALOG_PLL_DDR_DENOM_RSVD0(x) (HW_CCM_ANALOG_PLL_DDR_DENOM(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_CCM_ANALOG_PLL_480 - Anadig 480MHz PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_480 - Anadig 480MHz PLL Control Register (RW)
 *
 * Reset value: 0x00013000U
 *
 * The control register provides control for the 480MHz PLL.
 */
typedef union _hw_ccm_analog_pll_480
{
    uint32_t U;
    struct _hw_ccm_analog_pll_480_bitfields
    {
        uint32_t DIV_SELECT : 1;       /*!< [0]  */
        uint32_t RSVD0 : 3;            /*!< [3:1]  */
        uint32_t MAIN_DIV1_CLKGATE : 1; /*!< [4]  */
        uint32_t MAIN_DIV2_CLKGATE : 1; /*!< [5]  */
        uint32_t MAIN_DIV4_CLKGATE : 1; /*!< [6]  */
        uint32_t HALF_LF : 1;          /*!< [7]  */
        uint32_t DOUBLE_LF : 1;        /*!< [8]  */
        uint32_t HALF_CP : 1;          /*!< [9]  */
        uint32_t DOUBLE_CP : 1;        /*!< [10]  */
        uint32_t HOLD_RING_OFF : 1;    /*!< [11]  */
        uint32_t POWERDOWN : 1;        /*!< [12]  */
        uint32_t ENABLE_CLK : 1;       /*!< [13]  */
        uint32_t BYPASS_CLK_SRC : 2;   /*!< [15:14]  */
        uint32_t BYPASS : 1;           /*!< [16]  */
        uint32_t PLL_480_OVERRIDE : 1; /*!< [17]  */
        uint32_t PFD0_OVERRIDE : 1;    /*!< [18]  */
        uint32_t PFD1_OVERRIDE : 1;    /*!< [19]  */
        uint32_t PFD2_OVERRIDE : 1;    /*!< [20]  */
        uint32_t PFD3_OVERRIDE : 1;    /*!< [21]  */
        uint32_t PFD4_OVERRIDE : 1;    /*!< [22]  */
        uint32_t PFD5_OVERRIDE : 1;    /*!< [23]  */
        uint32_t PFD6_OVERRIDE : 1;    /*!< [24]  */
        uint32_t PFD7_OVERRIDE : 1;    /*!< [25]  */
        uint32_t PFD0_DIV2_CLKGATE : 1; /*!< [26]  */
        uint32_t PFD1_DIV2_CLKGATE : 1; /*!< [27]  */
        uint32_t PFD2_DIV2_CLKGATE : 1; /*!< [28]  */
        uint32_t RSVD1 : 2;            /*!< [30:29]  */
        uint32_t LOCK : 1;             /*!< [31]  */
    } B;
} hw_ccm_analog_pll_480_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_480 register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_480_ADDR(x) ((uintptr_t)(x) + 0xB0U)
#define HW_CCM_ANALOG_PLL_480_SET_ADDR(x) (HW_CCM_ANALOG_PLL_480_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_PLL_480_CLR_ADDR(x) (HW_CCM_ANALOG_PLL_480_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_PLL_480_TOG_ADDR(x) (HW_CCM_ANALOG_PLL_480_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_PLL_480(x) (*(__IO hw_ccm_analog_pll_480_t *) HW_CCM_ANALOG_PLL_480_ADDR(x))
#define HW_CCM_ANALOG_PLL_480_RD(x) (HW_CCM_ANALOG_PLL_480(x).U)
#define HW_CCM_ANALOG_PLL_480_WR(x, v) (HW_CCM_ANALOG_PLL_480(x).U = (v))
#define HW_CCM_ANALOG_PLL_480_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_480_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_480_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_480_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_480_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_480_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_480 bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_480, field DIV_SELECT[0] (RW)
 *
 * This field controls the pll loop divider. 0 - Fout=480MHz; 1 - Fout=528MHz.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_DIV_SELECT (0U) /*!< Bit position for CCM_ANALOG_PLL_480_DIV_SELECT. */
#define BM_CCM_ANALOG_PLL_480_DIV_SELECT (0x00000001U) /*!< Bit mask for CCM_ANALOG_PLL_480_DIV_SELECT. */
#define BS_CCM_ANALOG_PLL_480_DIV_SELECT (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_DIV_SELECT. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_DIV_SELECT field. */
#define BR_CCM_ANALOG_PLL_480_DIV_SELECT(x) (HW_CCM_ANALOG_PLL_480(x).B.DIV_SELECT)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_DIV_SELECT. */
#define BF_CCM_ANALOG_PLL_480_DIV_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_DIV_SELECT) & BM_CCM_ANALOG_PLL_480_DIV_SELECT)

/*! @brief Set the DIV_SELECT field to a new value. */
#define BW_CCM_ANALOG_PLL_480_DIV_SELECT(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_DIV_SELECT) | BF_CCM_ANALOG_PLL_480_DIV_SELECT(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field RSVD0[3:1] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_RSVD0 (1U)   /*!< Bit position for CCM_ANALOG_PLL_480_RSVD0. */
#define BM_CCM_ANALOG_PLL_480_RSVD0 (0x0000000EU) /*!< Bit mask for CCM_ANALOG_PLL_480_RSVD0. */
#define BS_CCM_ANALOG_PLL_480_RSVD0 (3U)   /*!< Bit field size in bits for CCM_ANALOG_PLL_480_RSVD0. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_RSVD0 field. */
#define BR_CCM_ANALOG_PLL_480_RSVD0(x) (HW_CCM_ANALOG_PLL_480(x).B.RSVD0)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field MAIN_DIV1_CLKGATE[4] (RW)
 *
 * If set to 1, pll_sys_main_480m_clk is off (power savings). 0:
 * pll_sys_main_480m_clk is enabled.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_MAIN_DIV1_CLKGATE (4U) /*!< Bit position for CCM_ANALOG_PLL_480_MAIN_DIV1_CLKGATE. */
#define BM_CCM_ANALOG_PLL_480_MAIN_DIV1_CLKGATE (0x00000010U) /*!< Bit mask for CCM_ANALOG_PLL_480_MAIN_DIV1_CLKGATE. */
#define BS_CCM_ANALOG_PLL_480_MAIN_DIV1_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_MAIN_DIV1_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_MAIN_DIV1_CLKGATE field. */
#define BR_CCM_ANALOG_PLL_480_MAIN_DIV1_CLKGATE(x) (HW_CCM_ANALOG_PLL_480(x).B.MAIN_DIV1_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_MAIN_DIV1_CLKGATE. */
#define BF_CCM_ANALOG_PLL_480_MAIN_DIV1_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_MAIN_DIV1_CLKGATE) & BM_CCM_ANALOG_PLL_480_MAIN_DIV1_CLKGATE)

/*! @brief Set the MAIN_DIV1_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PLL_480_MAIN_DIV1_CLKGATE(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_MAIN_DIV1_CLKGATE) | BF_CCM_ANALOG_PLL_480_MAIN_DIV1_CLKGATE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field MAIN_DIV2_CLKGATE[5] (RW)
 *
 * If set to 1, pll_sys_main_240m_clk is off (power savings). 0:
 * pll_sys_main_240m_clk is enabled.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_MAIN_DIV2_CLKGATE (5U) /*!< Bit position for CCM_ANALOG_PLL_480_MAIN_DIV2_CLKGATE. */
#define BM_CCM_ANALOG_PLL_480_MAIN_DIV2_CLKGATE (0x00000020U) /*!< Bit mask for CCM_ANALOG_PLL_480_MAIN_DIV2_CLKGATE. */
#define BS_CCM_ANALOG_PLL_480_MAIN_DIV2_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_MAIN_DIV2_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_MAIN_DIV2_CLKGATE field. */
#define BR_CCM_ANALOG_PLL_480_MAIN_DIV2_CLKGATE(x) (HW_CCM_ANALOG_PLL_480(x).B.MAIN_DIV2_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_MAIN_DIV2_CLKGATE. */
#define BF_CCM_ANALOG_PLL_480_MAIN_DIV2_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_MAIN_DIV2_CLKGATE) & BM_CCM_ANALOG_PLL_480_MAIN_DIV2_CLKGATE)

/*! @brief Set the MAIN_DIV2_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PLL_480_MAIN_DIV2_CLKGATE(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_MAIN_DIV2_CLKGATE) | BF_CCM_ANALOG_PLL_480_MAIN_DIV2_CLKGATE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field MAIN_DIV4_CLKGATE[6] (RW)
 *
 * If set to 1, pll_sys_main_120m_clk is off (power savings). 0:
 * pll_sys_main_120m_clk is enabled.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_MAIN_DIV4_CLKGATE (6U) /*!< Bit position for CCM_ANALOG_PLL_480_MAIN_DIV4_CLKGATE. */
#define BM_CCM_ANALOG_PLL_480_MAIN_DIV4_CLKGATE (0x00000040U) /*!< Bit mask for CCM_ANALOG_PLL_480_MAIN_DIV4_CLKGATE. */
#define BS_CCM_ANALOG_PLL_480_MAIN_DIV4_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_MAIN_DIV4_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_MAIN_DIV4_CLKGATE field. */
#define BR_CCM_ANALOG_PLL_480_MAIN_DIV4_CLKGATE(x) (HW_CCM_ANALOG_PLL_480(x).B.MAIN_DIV4_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_MAIN_DIV4_CLKGATE. */
#define BF_CCM_ANALOG_PLL_480_MAIN_DIV4_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_MAIN_DIV4_CLKGATE) & BM_CCM_ANALOG_PLL_480_MAIN_DIV4_CLKGATE)

/*! @brief Set the MAIN_DIV4_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PLL_480_MAIN_DIV4_CLKGATE(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_MAIN_DIV4_CLKGATE) | BF_CCM_ANALOG_PLL_480_MAIN_DIV4_CLKGATE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field HALF_LF[7] (RW)
 *
 * Reduces the frequency of the loop filter 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_HALF_LF (7U) /*!< Bit position for CCM_ANALOG_PLL_480_HALF_LF. */
#define BM_CCM_ANALOG_PLL_480_HALF_LF (0x00000080U) /*!< Bit mask for CCM_ANALOG_PLL_480_HALF_LF. */
#define BS_CCM_ANALOG_PLL_480_HALF_LF (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_HALF_LF. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_HALF_LF field. */
#define BR_CCM_ANALOG_PLL_480_HALF_LF(x) (HW_CCM_ANALOG_PLL_480(x).B.HALF_LF)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_HALF_LF. */
#define BF_CCM_ANALOG_PLL_480_HALF_LF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_HALF_LF) & BM_CCM_ANALOG_PLL_480_HALF_LF)

/*! @brief Set the HALF_LF field to a new value. */
#define BW_CCM_ANALOG_PLL_480_HALF_LF(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_HALF_LF) | BF_CCM_ANALOG_PLL_480_HALF_LF(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field DOUBLE_LF[8] (RW)
 *
 * Increases the frequency of the loop filter 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_DOUBLE_LF (8U) /*!< Bit position for CCM_ANALOG_PLL_480_DOUBLE_LF. */
#define BM_CCM_ANALOG_PLL_480_DOUBLE_LF (0x00000100U) /*!< Bit mask for CCM_ANALOG_PLL_480_DOUBLE_LF. */
#define BS_CCM_ANALOG_PLL_480_DOUBLE_LF (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_DOUBLE_LF. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_DOUBLE_LF field. */
#define BR_CCM_ANALOG_PLL_480_DOUBLE_LF(x) (HW_CCM_ANALOG_PLL_480(x).B.DOUBLE_LF)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_DOUBLE_LF. */
#define BF_CCM_ANALOG_PLL_480_DOUBLE_LF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_DOUBLE_LF) & BM_CCM_ANALOG_PLL_480_DOUBLE_LF)

/*! @brief Set the DOUBLE_LF field to a new value. */
#define BW_CCM_ANALOG_PLL_480_DOUBLE_LF(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_DOUBLE_LF) | BF_CCM_ANALOG_PLL_480_DOUBLE_LF(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field HALF_CP[9] (RW)
 *
 * Reduces the charge pump gain 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_HALF_CP (9U) /*!< Bit position for CCM_ANALOG_PLL_480_HALF_CP. */
#define BM_CCM_ANALOG_PLL_480_HALF_CP (0x00000200U) /*!< Bit mask for CCM_ANALOG_PLL_480_HALF_CP. */
#define BS_CCM_ANALOG_PLL_480_HALF_CP (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_HALF_CP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_HALF_CP field. */
#define BR_CCM_ANALOG_PLL_480_HALF_CP(x) (HW_CCM_ANALOG_PLL_480(x).B.HALF_CP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_HALF_CP. */
#define BF_CCM_ANALOG_PLL_480_HALF_CP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_HALF_CP) & BM_CCM_ANALOG_PLL_480_HALF_CP)

/*! @brief Set the HALF_CP field to a new value. */
#define BW_CCM_ANALOG_PLL_480_HALF_CP(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_HALF_CP) | BF_CCM_ANALOG_PLL_480_HALF_CP(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field DOUBLE_CP[10] (RW)
 *
 * Increases the charge pump gain 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_DOUBLE_CP (10U) /*!< Bit position for CCM_ANALOG_PLL_480_DOUBLE_CP. */
#define BM_CCM_ANALOG_PLL_480_DOUBLE_CP (0x00000400U) /*!< Bit mask for CCM_ANALOG_PLL_480_DOUBLE_CP. */
#define BS_CCM_ANALOG_PLL_480_DOUBLE_CP (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_DOUBLE_CP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_DOUBLE_CP field. */
#define BR_CCM_ANALOG_PLL_480_DOUBLE_CP(x) (HW_CCM_ANALOG_PLL_480(x).B.DOUBLE_CP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_DOUBLE_CP. */
#define BF_CCM_ANALOG_PLL_480_DOUBLE_CP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_DOUBLE_CP) & BM_CCM_ANALOG_PLL_480_DOUBLE_CP)

/*! @brief Set the DOUBLE_CP field to a new value. */
#define BW_CCM_ANALOG_PLL_480_DOUBLE_CP(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_DOUBLE_CP) | BF_CCM_ANALOG_PLL_480_DOUBLE_CP(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field HOLD_RING_OFF[11] (RW)
 *
 * Analog debug bit.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_HOLD_RING_OFF (11U) /*!< Bit position for CCM_ANALOG_PLL_480_HOLD_RING_OFF. */
#define BM_CCM_ANALOG_PLL_480_HOLD_RING_OFF (0x00000800U) /*!< Bit mask for CCM_ANALOG_PLL_480_HOLD_RING_OFF. */
#define BS_CCM_ANALOG_PLL_480_HOLD_RING_OFF (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_HOLD_RING_OFF. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_HOLD_RING_OFF field. */
#define BR_CCM_ANALOG_PLL_480_HOLD_RING_OFF(x) (HW_CCM_ANALOG_PLL_480(x).B.HOLD_RING_OFF)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_HOLD_RING_OFF. */
#define BF_CCM_ANALOG_PLL_480_HOLD_RING_OFF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_HOLD_RING_OFF) & BM_CCM_ANALOG_PLL_480_HOLD_RING_OFF)

/*! @brief Set the HOLD_RING_OFF field to a new value. */
#define BW_CCM_ANALOG_PLL_480_HOLD_RING_OFF(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_HOLD_RING_OFF) | BF_CCM_ANALOG_PLL_480_HOLD_RING_OFF(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field POWERDOWN[12] (RW)
 *
 * Powers down the PLL.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_POWERDOWN (12U) /*!< Bit position for CCM_ANALOG_PLL_480_POWERDOWN. */
#define BM_CCM_ANALOG_PLL_480_POWERDOWN (0x00001000U) /*!< Bit mask for CCM_ANALOG_PLL_480_POWERDOWN. */
#define BS_CCM_ANALOG_PLL_480_POWERDOWN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_POWERDOWN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_POWERDOWN field. */
#define BR_CCM_ANALOG_PLL_480_POWERDOWN(x) (HW_CCM_ANALOG_PLL_480(x).B.POWERDOWN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_POWERDOWN. */
#define BF_CCM_ANALOG_PLL_480_POWERDOWN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_POWERDOWN) & BM_CCM_ANALOG_PLL_480_POWERDOWN)

/*! @brief Set the POWERDOWN field to a new value. */
#define BW_CCM_ANALOG_PLL_480_POWERDOWN(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_POWERDOWN) | BF_CCM_ANALOG_PLL_480_POWERDOWN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field ENABLE_CLK[13] (RW)
 *
 * Enable the clock output.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_ENABLE_CLK (13U) /*!< Bit position for CCM_ANALOG_PLL_480_ENABLE_CLK. */
#define BM_CCM_ANALOG_PLL_480_ENABLE_CLK (0x00002000U) /*!< Bit mask for CCM_ANALOG_PLL_480_ENABLE_CLK. */
#define BS_CCM_ANALOG_PLL_480_ENABLE_CLK (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_ENABLE_CLK. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_ENABLE_CLK field. */
#define BR_CCM_ANALOG_PLL_480_ENABLE_CLK(x) (HW_CCM_ANALOG_PLL_480(x).B.ENABLE_CLK)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_ENABLE_CLK. */
#define BF_CCM_ANALOG_PLL_480_ENABLE_CLK(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_ENABLE_CLK) & BM_CCM_ANALOG_PLL_480_ENABLE_CLK)

/*! @brief Set the ENABLE_CLK field to a new value. */
#define BW_CCM_ANALOG_PLL_480_ENABLE_CLK(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_ENABLE_CLK) | BF_CCM_ANALOG_PLL_480_ENABLE_CLK(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field BYPASS_CLK_SRC[15:14] (RW)
 *
 * Determines the bypass source.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_BYPASS_CLK_SRC (14U) /*!< Bit position for CCM_ANALOG_PLL_480_BYPASS_CLK_SRC. */
#define BM_CCM_ANALOG_PLL_480_BYPASS_CLK_SRC (0x0000C000U) /*!< Bit mask for CCM_ANALOG_PLL_480_BYPASS_CLK_SRC. */
#define BS_CCM_ANALOG_PLL_480_BYPASS_CLK_SRC (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_BYPASS_CLK_SRC. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_BYPASS_CLK_SRC field. */
#define BR_CCM_ANALOG_PLL_480_BYPASS_CLK_SRC(x) (HW_CCM_ANALOG_PLL_480(x).B.BYPASS_CLK_SRC)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_BYPASS_CLK_SRC. */
#define BF_CCM_ANALOG_PLL_480_BYPASS_CLK_SRC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_BYPASS_CLK_SRC) & BM_CCM_ANALOG_PLL_480_BYPASS_CLK_SRC)

/*! @brief Set the BYPASS_CLK_SRC field to a new value. */
#define BW_CCM_ANALOG_PLL_480_BYPASS_CLK_SRC(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_BYPASS_CLK_SRC) | BF_CCM_ANALOG_PLL_480_BYPASS_CLK_SRC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field BYPASS[16] (RW)
 *
 * Bypass the pll.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_BYPASS (16U) /*!< Bit position for CCM_ANALOG_PLL_480_BYPASS. */
#define BM_CCM_ANALOG_PLL_480_BYPASS (0x00010000U) /*!< Bit mask for CCM_ANALOG_PLL_480_BYPASS. */
#define BS_CCM_ANALOG_PLL_480_BYPASS (1U)  /*!< Bit field size in bits for CCM_ANALOG_PLL_480_BYPASS. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_BYPASS field. */
#define BR_CCM_ANALOG_PLL_480_BYPASS(x) (HW_CCM_ANALOG_PLL_480(x).B.BYPASS)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_BYPASS. */
#define BF_CCM_ANALOG_PLL_480_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_BYPASS) & BM_CCM_ANALOG_PLL_480_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_CCM_ANALOG_PLL_480_BYPASS(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_BYPASS) | BF_CCM_ANALOG_PLL_480_BYPASS(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field PLL_480_OVERRIDE[17] (RW)
 *
 * The OVERRIDE bit allows the clock control module to automatically override
 * portions of the register.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_PLL_480_OVERRIDE (17U) /*!< Bit position for CCM_ANALOG_PLL_480_PLL_480_OVERRIDE. */
#define BM_CCM_ANALOG_PLL_480_PLL_480_OVERRIDE (0x00020000U) /*!< Bit mask for CCM_ANALOG_PLL_480_PLL_480_OVERRIDE. */
#define BS_CCM_ANALOG_PLL_480_PLL_480_OVERRIDE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_PLL_480_OVERRIDE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_PLL_480_OVERRIDE field. */
#define BR_CCM_ANALOG_PLL_480_PLL_480_OVERRIDE(x) (HW_CCM_ANALOG_PLL_480(x).B.PLL_480_OVERRIDE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_PLL_480_OVERRIDE. */
#define BF_CCM_ANALOG_PLL_480_PLL_480_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_PLL_480_OVERRIDE) & BM_CCM_ANALOG_PLL_480_PLL_480_OVERRIDE)

/*! @brief Set the PLL_480_OVERRIDE field to a new value. */
#define BW_CCM_ANALOG_PLL_480_PLL_480_OVERRIDE(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_PLL_480_OVERRIDE) | BF_CCM_ANALOG_PLL_480_PLL_480_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field PFD0_OVERRIDE[18] (RW)
 *
 * The OVERRIDE bit allows the clock control module to automatically override
 * portions of the register.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_PFD0_OVERRIDE (18U) /*!< Bit position for CCM_ANALOG_PLL_480_PFD0_OVERRIDE. */
#define BM_CCM_ANALOG_PLL_480_PFD0_OVERRIDE (0x00040000U) /*!< Bit mask for CCM_ANALOG_PLL_480_PFD0_OVERRIDE. */
#define BS_CCM_ANALOG_PLL_480_PFD0_OVERRIDE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_PFD0_OVERRIDE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_PFD0_OVERRIDE field. */
#define BR_CCM_ANALOG_PLL_480_PFD0_OVERRIDE(x) (HW_CCM_ANALOG_PLL_480(x).B.PFD0_OVERRIDE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_PFD0_OVERRIDE. */
#define BF_CCM_ANALOG_PLL_480_PFD0_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_PFD0_OVERRIDE) & BM_CCM_ANALOG_PLL_480_PFD0_OVERRIDE)

/*! @brief Set the PFD0_OVERRIDE field to a new value. */
#define BW_CCM_ANALOG_PLL_480_PFD0_OVERRIDE(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_PFD0_OVERRIDE) | BF_CCM_ANALOG_PLL_480_PFD0_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field PFD1_OVERRIDE[19] (RW)
 *
 * The OVERRIDE bit allows the clock control module to automatically override
 * portions of the register.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_PFD1_OVERRIDE (19U) /*!< Bit position for CCM_ANALOG_PLL_480_PFD1_OVERRIDE. */
#define BM_CCM_ANALOG_PLL_480_PFD1_OVERRIDE (0x00080000U) /*!< Bit mask for CCM_ANALOG_PLL_480_PFD1_OVERRIDE. */
#define BS_CCM_ANALOG_PLL_480_PFD1_OVERRIDE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_PFD1_OVERRIDE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_PFD1_OVERRIDE field. */
#define BR_CCM_ANALOG_PLL_480_PFD1_OVERRIDE(x) (HW_CCM_ANALOG_PLL_480(x).B.PFD1_OVERRIDE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_PFD1_OVERRIDE. */
#define BF_CCM_ANALOG_PLL_480_PFD1_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_PFD1_OVERRIDE) & BM_CCM_ANALOG_PLL_480_PFD1_OVERRIDE)

/*! @brief Set the PFD1_OVERRIDE field to a new value. */
#define BW_CCM_ANALOG_PLL_480_PFD1_OVERRIDE(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_PFD1_OVERRIDE) | BF_CCM_ANALOG_PLL_480_PFD1_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field PFD2_OVERRIDE[20] (RW)
 *
 * The OVERRIDE bit allows the clock control module to automatically override
 * portions of the register.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_PFD2_OVERRIDE (20U) /*!< Bit position for CCM_ANALOG_PLL_480_PFD2_OVERRIDE. */
#define BM_CCM_ANALOG_PLL_480_PFD2_OVERRIDE (0x00100000U) /*!< Bit mask for CCM_ANALOG_PLL_480_PFD2_OVERRIDE. */
#define BS_CCM_ANALOG_PLL_480_PFD2_OVERRIDE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_PFD2_OVERRIDE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_PFD2_OVERRIDE field. */
#define BR_CCM_ANALOG_PLL_480_PFD2_OVERRIDE(x) (HW_CCM_ANALOG_PLL_480(x).B.PFD2_OVERRIDE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_PFD2_OVERRIDE. */
#define BF_CCM_ANALOG_PLL_480_PFD2_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_PFD2_OVERRIDE) & BM_CCM_ANALOG_PLL_480_PFD2_OVERRIDE)

/*! @brief Set the PFD2_OVERRIDE field to a new value. */
#define BW_CCM_ANALOG_PLL_480_PFD2_OVERRIDE(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_PFD2_OVERRIDE) | BF_CCM_ANALOG_PLL_480_PFD2_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field PFD3_OVERRIDE[21] (RW)
 *
 * The OVERRIDE bit allows the clock control module to automatically override
 * portions of the register.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_PFD3_OVERRIDE (21U) /*!< Bit position for CCM_ANALOG_PLL_480_PFD3_OVERRIDE. */
#define BM_CCM_ANALOG_PLL_480_PFD3_OVERRIDE (0x00200000U) /*!< Bit mask for CCM_ANALOG_PLL_480_PFD3_OVERRIDE. */
#define BS_CCM_ANALOG_PLL_480_PFD3_OVERRIDE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_PFD3_OVERRIDE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_PFD3_OVERRIDE field. */
#define BR_CCM_ANALOG_PLL_480_PFD3_OVERRIDE(x) (HW_CCM_ANALOG_PLL_480(x).B.PFD3_OVERRIDE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_PFD3_OVERRIDE. */
#define BF_CCM_ANALOG_PLL_480_PFD3_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_PFD3_OVERRIDE) & BM_CCM_ANALOG_PLL_480_PFD3_OVERRIDE)

/*! @brief Set the PFD3_OVERRIDE field to a new value. */
#define BW_CCM_ANALOG_PLL_480_PFD3_OVERRIDE(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_PFD3_OVERRIDE) | BF_CCM_ANALOG_PLL_480_PFD3_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field PFD4_OVERRIDE[22] (RW)
 *
 * The OVERRIDE bit allows the clock control module to automatically override
 * portions of the register.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_PFD4_OVERRIDE (22U) /*!< Bit position for CCM_ANALOG_PLL_480_PFD4_OVERRIDE. */
#define BM_CCM_ANALOG_PLL_480_PFD4_OVERRIDE (0x00400000U) /*!< Bit mask for CCM_ANALOG_PLL_480_PFD4_OVERRIDE. */
#define BS_CCM_ANALOG_PLL_480_PFD4_OVERRIDE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_PFD4_OVERRIDE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_PFD4_OVERRIDE field. */
#define BR_CCM_ANALOG_PLL_480_PFD4_OVERRIDE(x) (HW_CCM_ANALOG_PLL_480(x).B.PFD4_OVERRIDE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_PFD4_OVERRIDE. */
#define BF_CCM_ANALOG_PLL_480_PFD4_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_PFD4_OVERRIDE) & BM_CCM_ANALOG_PLL_480_PFD4_OVERRIDE)

/*! @brief Set the PFD4_OVERRIDE field to a new value. */
#define BW_CCM_ANALOG_PLL_480_PFD4_OVERRIDE(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_PFD4_OVERRIDE) | BF_CCM_ANALOG_PLL_480_PFD4_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field PFD5_OVERRIDE[23] (RW)
 *
 * The OVERRIDE bit allows the clock control module to automatically override
 * portions of the register.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_PFD5_OVERRIDE (23U) /*!< Bit position for CCM_ANALOG_PLL_480_PFD5_OVERRIDE. */
#define BM_CCM_ANALOG_PLL_480_PFD5_OVERRIDE (0x00800000U) /*!< Bit mask for CCM_ANALOG_PLL_480_PFD5_OVERRIDE. */
#define BS_CCM_ANALOG_PLL_480_PFD5_OVERRIDE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_PFD5_OVERRIDE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_PFD5_OVERRIDE field. */
#define BR_CCM_ANALOG_PLL_480_PFD5_OVERRIDE(x) (HW_CCM_ANALOG_PLL_480(x).B.PFD5_OVERRIDE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_PFD5_OVERRIDE. */
#define BF_CCM_ANALOG_PLL_480_PFD5_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_PFD5_OVERRIDE) & BM_CCM_ANALOG_PLL_480_PFD5_OVERRIDE)

/*! @brief Set the PFD5_OVERRIDE field to a new value. */
#define BW_CCM_ANALOG_PLL_480_PFD5_OVERRIDE(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_PFD5_OVERRIDE) | BF_CCM_ANALOG_PLL_480_PFD5_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field PFD6_OVERRIDE[24] (RW)
 *
 * The OVERRIDE bit allows the clock control module to automatically override
 * portions of the register.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_PFD6_OVERRIDE (24U) /*!< Bit position for CCM_ANALOG_PLL_480_PFD6_OVERRIDE. */
#define BM_CCM_ANALOG_PLL_480_PFD6_OVERRIDE (0x01000000U) /*!< Bit mask for CCM_ANALOG_PLL_480_PFD6_OVERRIDE. */
#define BS_CCM_ANALOG_PLL_480_PFD6_OVERRIDE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_PFD6_OVERRIDE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_PFD6_OVERRIDE field. */
#define BR_CCM_ANALOG_PLL_480_PFD6_OVERRIDE(x) (HW_CCM_ANALOG_PLL_480(x).B.PFD6_OVERRIDE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_PFD6_OVERRIDE. */
#define BF_CCM_ANALOG_PLL_480_PFD6_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_PFD6_OVERRIDE) & BM_CCM_ANALOG_PLL_480_PFD6_OVERRIDE)

/*! @brief Set the PFD6_OVERRIDE field to a new value. */
#define BW_CCM_ANALOG_PLL_480_PFD6_OVERRIDE(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_PFD6_OVERRIDE) | BF_CCM_ANALOG_PLL_480_PFD6_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field PFD7_OVERRIDE[25] (RW)
 *
 * The OVERRIDE bit allows the clock control module to automatically override
 * portions of the register.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_PFD7_OVERRIDE (25U) /*!< Bit position for CCM_ANALOG_PLL_480_PFD7_OVERRIDE. */
#define BM_CCM_ANALOG_PLL_480_PFD7_OVERRIDE (0x02000000U) /*!< Bit mask for CCM_ANALOG_PLL_480_PFD7_OVERRIDE. */
#define BS_CCM_ANALOG_PLL_480_PFD7_OVERRIDE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_PFD7_OVERRIDE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_PFD7_OVERRIDE field. */
#define BR_CCM_ANALOG_PLL_480_PFD7_OVERRIDE(x) (HW_CCM_ANALOG_PLL_480(x).B.PFD7_OVERRIDE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_PFD7_OVERRIDE. */
#define BF_CCM_ANALOG_PLL_480_PFD7_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_PFD7_OVERRIDE) & BM_CCM_ANALOG_PLL_480_PFD7_OVERRIDE)

/*! @brief Set the PFD7_OVERRIDE field to a new value. */
#define BW_CCM_ANALOG_PLL_480_PFD7_OVERRIDE(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_PFD7_OVERRIDE) | BF_CCM_ANALOG_PLL_480_PFD7_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field PFD0_DIV2_CLKGATE[26] (RW)
 *
 * If set to 1, pll_sys_pfd0_196m_clk is off (power savings). 0:
 * pll_sys_pfd0_196m_clk is enabled.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_PFD0_DIV2_CLKGATE (26U) /*!< Bit position for CCM_ANALOG_PLL_480_PFD0_DIV2_CLKGATE. */
#define BM_CCM_ANALOG_PLL_480_PFD0_DIV2_CLKGATE (0x04000000U) /*!< Bit mask for CCM_ANALOG_PLL_480_PFD0_DIV2_CLKGATE. */
#define BS_CCM_ANALOG_PLL_480_PFD0_DIV2_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_PFD0_DIV2_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_PFD0_DIV2_CLKGATE field. */
#define BR_CCM_ANALOG_PLL_480_PFD0_DIV2_CLKGATE(x) (HW_CCM_ANALOG_PLL_480(x).B.PFD0_DIV2_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_PFD0_DIV2_CLKGATE. */
#define BF_CCM_ANALOG_PLL_480_PFD0_DIV2_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_PFD0_DIV2_CLKGATE) & BM_CCM_ANALOG_PLL_480_PFD0_DIV2_CLKGATE)

/*! @brief Set the PFD0_DIV2_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PLL_480_PFD0_DIV2_CLKGATE(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_PFD0_DIV2_CLKGATE) | BF_CCM_ANALOG_PLL_480_PFD0_DIV2_CLKGATE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field PFD1_DIV2_CLKGATE[27] (RW)
 *
 * If set to 1, pll_sys_pfd1_166m_clk is off (power savings). 0:
 * pll_sys_pfd1_166m_clk is enabled.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_PFD1_DIV2_CLKGATE (27U) /*!< Bit position for CCM_ANALOG_PLL_480_PFD1_DIV2_CLKGATE. */
#define BM_CCM_ANALOG_PLL_480_PFD1_DIV2_CLKGATE (0x08000000U) /*!< Bit mask for CCM_ANALOG_PLL_480_PFD1_DIV2_CLKGATE. */
#define BS_CCM_ANALOG_PLL_480_PFD1_DIV2_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_PFD1_DIV2_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_PFD1_DIV2_CLKGATE field. */
#define BR_CCM_ANALOG_PLL_480_PFD1_DIV2_CLKGATE(x) (HW_CCM_ANALOG_PLL_480(x).B.PFD1_DIV2_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_PFD1_DIV2_CLKGATE. */
#define BF_CCM_ANALOG_PLL_480_PFD1_DIV2_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_PFD1_DIV2_CLKGATE) & BM_CCM_ANALOG_PLL_480_PFD1_DIV2_CLKGATE)

/*! @brief Set the PFD1_DIV2_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PLL_480_PFD1_DIV2_CLKGATE(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_PFD1_DIV2_CLKGATE) | BF_CCM_ANALOG_PLL_480_PFD1_DIV2_CLKGATE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field PFD2_DIV2_CLKGATE[28] (RW)
 *
 * If set to 1, pll_sys_pfd2_135m_clk is off (power savings). 0:
 * pll_sys_pfd2_135m_clk is enabled.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_PFD2_DIV2_CLKGATE (28U) /*!< Bit position for CCM_ANALOG_PLL_480_PFD2_DIV2_CLKGATE. */
#define BM_CCM_ANALOG_PLL_480_PFD2_DIV2_CLKGATE (0x10000000U) /*!< Bit mask for CCM_ANALOG_PLL_480_PFD2_DIV2_CLKGATE. */
#define BS_CCM_ANALOG_PLL_480_PFD2_DIV2_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_480_PFD2_DIV2_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_PFD2_DIV2_CLKGATE field. */
#define BR_CCM_ANALOG_PLL_480_PFD2_DIV2_CLKGATE(x) (HW_CCM_ANALOG_PLL_480(x).B.PFD2_DIV2_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_480_PFD2_DIV2_CLKGATE. */
#define BF_CCM_ANALOG_PLL_480_PFD2_DIV2_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_480_PFD2_DIV2_CLKGATE) & BM_CCM_ANALOG_PLL_480_PFD2_DIV2_CLKGATE)

/*! @brief Set the PFD2_DIV2_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PLL_480_PFD2_DIV2_CLKGATE(x, v) (HW_CCM_ANALOG_PLL_480_WR(x, (HW_CCM_ANALOG_PLL_480_RD(x) & ~BM_CCM_ANALOG_PLL_480_PFD2_DIV2_CLKGATE) | BF_CCM_ANALOG_PLL_480_PFD2_DIV2_CLKGATE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field RSVD1[30:29] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_RSVD1 (29U)  /*!< Bit position for CCM_ANALOG_PLL_480_RSVD1. */
#define BM_CCM_ANALOG_PLL_480_RSVD1 (0x60000000U) /*!< Bit mask for CCM_ANALOG_PLL_480_RSVD1. */
#define BS_CCM_ANALOG_PLL_480_RSVD1 (2U)   /*!< Bit field size in bits for CCM_ANALOG_PLL_480_RSVD1. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_RSVD1 field. */
#define BR_CCM_ANALOG_PLL_480_RSVD1(x) (HW_CCM_ANALOG_PLL_480(x).B.RSVD1)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_480, field LOCK[31] (RO)
 *
 * 1 - PLL is currently locked; 0 - PLL is not currently locked.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_480_LOCK (31U)   /*!< Bit position for CCM_ANALOG_PLL_480_LOCK. */
#define BM_CCM_ANALOG_PLL_480_LOCK (0x80000000U) /*!< Bit mask for CCM_ANALOG_PLL_480_LOCK. */
#define BS_CCM_ANALOG_PLL_480_LOCK (1U)    /*!< Bit field size in bits for CCM_ANALOG_PLL_480_LOCK. */

/*! @brief Read current value of the CCM_ANALOG_PLL_480_LOCK field. */
#define BR_CCM_ANALOG_PLL_480_LOCK(x) (HW_CCM_ANALOG_PLL_480(x).B.LOCK)
/*@}*/




/*******************************************************************************
 * HW_CCM_ANALOG_PFD_480A - 480MHz Clock Phase Fractional Divider Control Register A
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PFD_480A - 480MHz Clock Phase Fractional Divider Control Register A (RW)
 *
 * Reset value: 0x12201A16U
 *
 * This register controls the 4-phase fractional clock dividers. The fractional
 * clock frequencies are a product of the values in these registers.
 */
typedef union _hw_ccm_analog_pfd_480a
{
    uint32_t U;
    struct _hw_ccm_analog_pfd_480a_bitfields
    {
        uint32_t PFD0_FRAC : 6;        /*!< [5:0]  */
        uint32_t PFD0_STABLE : 1;      /*!< [6]  */
        uint32_t PFD0_DIV1_CLKGATE : 1; /*!< [7]  */
        uint32_t PFD1_FRAC : 6;        /*!< [13:8]  */
        uint32_t PFD1_STABLE : 1;      /*!< [14]  */
        uint32_t PFD1_DIV1_CLKGATE : 1; /*!< [15]  */
        uint32_t PFD2_FRAC : 6;        /*!< [21:16]  */
        uint32_t PFD2_STABLE : 1;      /*!< [22]  */
        uint32_t PFD2_DIV1_CLKGATE : 1; /*!< [23]  */
        uint32_t PFD3_FRAC : 6;        /*!< [29:24]  */
        uint32_t PFD3_STABLE : 1;      /*!< [30]  */
        uint32_t PFD3_DIV1_CLKGATE : 1; /*!< [31]  */
    } B;
} hw_ccm_analog_pfd_480a_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PFD_480A register
 */
/*@{*/
#define HW_CCM_ANALOG_PFD_480A_ADDR(x) ((uintptr_t)(x) + 0xC0U)
#define HW_CCM_ANALOG_PFD_480A_SET_ADDR(x) (HW_CCM_ANALOG_PFD_480A_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_PFD_480A_CLR_ADDR(x) (HW_CCM_ANALOG_PFD_480A_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_PFD_480A_TOG_ADDR(x) (HW_CCM_ANALOG_PFD_480A_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_PFD_480A(x) (*(__IO hw_ccm_analog_pfd_480a_t *) HW_CCM_ANALOG_PFD_480A_ADDR(x))
#define HW_CCM_ANALOG_PFD_480A_RD(x) (HW_CCM_ANALOG_PFD_480A(x).U)
#define HW_CCM_ANALOG_PFD_480A_WR(x, v) (HW_CCM_ANALOG_PFD_480A(x).U = (v))
#define HW_CCM_ANALOG_PFD_480A_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PFD_480A_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PFD_480A_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PFD_480A_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PFD_480A_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PFD_480A_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PFD_480A bitfields
 */

/*!
 * @name Register CCM_ANALOG_PFD_480A, field PFD0_FRAC[5:0] (RW)
 *
 * This field controls the fractional divide value. The resulting frequency
 * shall be 480*18/PFD0_FRAC where PFD0_FRAC is in the range 12-35.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480A_PFD0_FRAC (0U) /*!< Bit position for CCM_ANALOG_PFD_480A_PFD0_FRAC. */
#define BM_CCM_ANALOG_PFD_480A_PFD0_FRAC (0x0000003FU) /*!< Bit mask for CCM_ANALOG_PFD_480A_PFD0_FRAC. */
#define BS_CCM_ANALOG_PFD_480A_PFD0_FRAC (6U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480A_PFD0_FRAC. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480A_PFD0_FRAC field. */
#define BR_CCM_ANALOG_PFD_480A_PFD0_FRAC(x) (HW_CCM_ANALOG_PFD_480A(x).B.PFD0_FRAC)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480A_PFD0_FRAC. */
#define BF_CCM_ANALOG_PFD_480A_PFD0_FRAC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480A_PFD0_FRAC) & BM_CCM_ANALOG_PFD_480A_PFD0_FRAC)

/*! @brief Set the PFD0_FRAC field to a new value. */
#define BW_CCM_ANALOG_PFD_480A_PFD0_FRAC(x, v) (HW_CCM_ANALOG_PFD_480A_WR(x, (HW_CCM_ANALOG_PFD_480A_RD(x) & ~BM_CCM_ANALOG_PFD_480A_PFD0_FRAC) | BF_CCM_ANALOG_PFD_480A_PFD0_FRAC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480A, field PFD0_STABLE[6] (RO)
 *
 * This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional
 * divider should become stable quickly enough that this field will never need to
 * be used by either device driver or application code. The value inverts when
 * the new programmed fractional divide value has taken effect. Read this bit,
 * program the new value, and when this bit inverts, the phase divider clock output
 * is stable. Note that the value will not invert when the fractional divider is
 * taken out of or placed into clock-gated state.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480A_PFD0_STABLE (6U) /*!< Bit position for CCM_ANALOG_PFD_480A_PFD0_STABLE. */
#define BM_CCM_ANALOG_PFD_480A_PFD0_STABLE (0x00000040U) /*!< Bit mask for CCM_ANALOG_PFD_480A_PFD0_STABLE. */
#define BS_CCM_ANALOG_PFD_480A_PFD0_STABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480A_PFD0_STABLE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480A_PFD0_STABLE field. */
#define BR_CCM_ANALOG_PFD_480A_PFD0_STABLE(x) (HW_CCM_ANALOG_PFD_480A(x).B.PFD0_STABLE)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480A, field PFD0_DIV1_CLKGATE[7] (RW)
 *
 * If set to 1, the IO fractional divider clock (reference ref_pfd0) is off
 * (power savings). 0: ref_pfd0 fractional divider clock is enabled. If the
 * corresponding override bit is set in the 480MHz PLL control register, this field has no
 * effect.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480A_PFD0_DIV1_CLKGATE (7U) /*!< Bit position for CCM_ANALOG_PFD_480A_PFD0_DIV1_CLKGATE. */
#define BM_CCM_ANALOG_PFD_480A_PFD0_DIV1_CLKGATE (0x00000080U) /*!< Bit mask for CCM_ANALOG_PFD_480A_PFD0_DIV1_CLKGATE. */
#define BS_CCM_ANALOG_PFD_480A_PFD0_DIV1_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480A_PFD0_DIV1_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480A_PFD0_DIV1_CLKGATE field. */
#define BR_CCM_ANALOG_PFD_480A_PFD0_DIV1_CLKGATE(x) (HW_CCM_ANALOG_PFD_480A(x).B.PFD0_DIV1_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480A_PFD0_DIV1_CLKGATE. */
#define BF_CCM_ANALOG_PFD_480A_PFD0_DIV1_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480A_PFD0_DIV1_CLKGATE) & BM_CCM_ANALOG_PFD_480A_PFD0_DIV1_CLKGATE)

/*! @brief Set the PFD0_DIV1_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PFD_480A_PFD0_DIV1_CLKGATE(x, v) (HW_CCM_ANALOG_PFD_480A_WR(x, (HW_CCM_ANALOG_PFD_480A_RD(x) & ~BM_CCM_ANALOG_PFD_480A_PFD0_DIV1_CLKGATE) | BF_CCM_ANALOG_PFD_480A_PFD0_DIV1_CLKGATE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480A, field PFD1_FRAC[13:8] (RW)
 *
 * This field controls the fractional divide value. The resulting frequency
 * shall be 480*18/PFD1_FRAC where PFD1_FRAC is in the range 12-35.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480A_PFD1_FRAC (8U) /*!< Bit position for CCM_ANALOG_PFD_480A_PFD1_FRAC. */
#define BM_CCM_ANALOG_PFD_480A_PFD1_FRAC (0x00003F00U) /*!< Bit mask for CCM_ANALOG_PFD_480A_PFD1_FRAC. */
#define BS_CCM_ANALOG_PFD_480A_PFD1_FRAC (6U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480A_PFD1_FRAC. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480A_PFD1_FRAC field. */
#define BR_CCM_ANALOG_PFD_480A_PFD1_FRAC(x) (HW_CCM_ANALOG_PFD_480A(x).B.PFD1_FRAC)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480A_PFD1_FRAC. */
#define BF_CCM_ANALOG_PFD_480A_PFD1_FRAC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480A_PFD1_FRAC) & BM_CCM_ANALOG_PFD_480A_PFD1_FRAC)

/*! @brief Set the PFD1_FRAC field to a new value. */
#define BW_CCM_ANALOG_PFD_480A_PFD1_FRAC(x, v) (HW_CCM_ANALOG_PFD_480A_WR(x, (HW_CCM_ANALOG_PFD_480A_RD(x) & ~BM_CCM_ANALOG_PFD_480A_PFD1_FRAC) | BF_CCM_ANALOG_PFD_480A_PFD1_FRAC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480A, field PFD1_STABLE[14] (RO)
 *
 * This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional
 * divider should become stable quickly enough that this field will never need to
 * be used by either device driver or application code. The value inverts when
 * the new programmed fractional divide value has taken effect. Read this bit,
 * program the new value, and when this bit inverts, the phase divider clock output
 * is stable. Note that the value will not invert when the fractional divider is
 * taken out of or placed into clock-gated state.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480A_PFD1_STABLE (14U) /*!< Bit position for CCM_ANALOG_PFD_480A_PFD1_STABLE. */
#define BM_CCM_ANALOG_PFD_480A_PFD1_STABLE (0x00004000U) /*!< Bit mask for CCM_ANALOG_PFD_480A_PFD1_STABLE. */
#define BS_CCM_ANALOG_PFD_480A_PFD1_STABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480A_PFD1_STABLE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480A_PFD1_STABLE field. */
#define BR_CCM_ANALOG_PFD_480A_PFD1_STABLE(x) (HW_CCM_ANALOG_PFD_480A(x).B.PFD1_STABLE)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480A, field PFD1_DIV1_CLKGATE[15] (RW)
 *
 * IO Clock Gate. If set to 1, the IO fractional divider clock (reference
 * ref_pfd1) is off (power savings). 0: ref_pfd1 fractional divider clock is enabled.
 * If the corresponding override bit is set in the 480MHz PLL control register,
 * this field has no effect.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480A_PFD1_DIV1_CLKGATE (15U) /*!< Bit position for CCM_ANALOG_PFD_480A_PFD1_DIV1_CLKGATE. */
#define BM_CCM_ANALOG_PFD_480A_PFD1_DIV1_CLKGATE (0x00008000U) /*!< Bit mask for CCM_ANALOG_PFD_480A_PFD1_DIV1_CLKGATE. */
#define BS_CCM_ANALOG_PFD_480A_PFD1_DIV1_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480A_PFD1_DIV1_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480A_PFD1_DIV1_CLKGATE field. */
#define BR_CCM_ANALOG_PFD_480A_PFD1_DIV1_CLKGATE(x) (HW_CCM_ANALOG_PFD_480A(x).B.PFD1_DIV1_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480A_PFD1_DIV1_CLKGATE. */
#define BF_CCM_ANALOG_PFD_480A_PFD1_DIV1_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480A_PFD1_DIV1_CLKGATE) & BM_CCM_ANALOG_PFD_480A_PFD1_DIV1_CLKGATE)

/*! @brief Set the PFD1_DIV1_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PFD_480A_PFD1_DIV1_CLKGATE(x, v) (HW_CCM_ANALOG_PFD_480A_WR(x, (HW_CCM_ANALOG_PFD_480A_RD(x) & ~BM_CCM_ANALOG_PFD_480A_PFD1_DIV1_CLKGATE) | BF_CCM_ANALOG_PFD_480A_PFD1_DIV1_CLKGATE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480A, field PFD2_FRAC[21:16] (RW)
 *
 * This field controls the fractional divide value. The resulting frequency
 * shall be 480*18/PFD2_FRAC where PFD2_FRAC is in the range 12-35.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480A_PFD2_FRAC (16U) /*!< Bit position for CCM_ANALOG_PFD_480A_PFD2_FRAC. */
#define BM_CCM_ANALOG_PFD_480A_PFD2_FRAC (0x003F0000U) /*!< Bit mask for CCM_ANALOG_PFD_480A_PFD2_FRAC. */
#define BS_CCM_ANALOG_PFD_480A_PFD2_FRAC (6U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480A_PFD2_FRAC. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480A_PFD2_FRAC field. */
#define BR_CCM_ANALOG_PFD_480A_PFD2_FRAC(x) (HW_CCM_ANALOG_PFD_480A(x).B.PFD2_FRAC)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480A_PFD2_FRAC. */
#define BF_CCM_ANALOG_PFD_480A_PFD2_FRAC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480A_PFD2_FRAC) & BM_CCM_ANALOG_PFD_480A_PFD2_FRAC)

/*! @brief Set the PFD2_FRAC field to a new value. */
#define BW_CCM_ANALOG_PFD_480A_PFD2_FRAC(x, v) (HW_CCM_ANALOG_PFD_480A_WR(x, (HW_CCM_ANALOG_PFD_480A_RD(x) & ~BM_CCM_ANALOG_PFD_480A_PFD2_FRAC) | BF_CCM_ANALOG_PFD_480A_PFD2_FRAC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480A, field PFD2_STABLE[22] (RO)
 *
 * This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional
 * divider should become stable quickly enough that this field will never need to
 * be used by either device driver or application code. The value inverts when
 * the new programmed fractional divide value has taken effect. Read this bit,
 * program the new value, and when this bit inverts, the phase divider clock output
 * is stable. Note that the value will not invert when the fractional divider is
 * taken out of or placed into clock-gated state.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480A_PFD2_STABLE (22U) /*!< Bit position for CCM_ANALOG_PFD_480A_PFD2_STABLE. */
#define BM_CCM_ANALOG_PFD_480A_PFD2_STABLE (0x00400000U) /*!< Bit mask for CCM_ANALOG_PFD_480A_PFD2_STABLE. */
#define BS_CCM_ANALOG_PFD_480A_PFD2_STABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480A_PFD2_STABLE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480A_PFD2_STABLE field. */
#define BR_CCM_ANALOG_PFD_480A_PFD2_STABLE(x) (HW_CCM_ANALOG_PFD_480A(x).B.PFD2_STABLE)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480A, field PFD2_DIV1_CLKGATE[23] (RW)
 *
 * IO Clock Gate. If set to 1, the IO fractional divider clock (reference
 * ref_pfd2) is off (power savings). 0: ref_pfd2 fractional divider clock is enabled.
 * If the corresponding override bit is set in the 480MHz PLL control register,
 * this field has no effect.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480A_PFD2_DIV1_CLKGATE (23U) /*!< Bit position for CCM_ANALOG_PFD_480A_PFD2_DIV1_CLKGATE. */
#define BM_CCM_ANALOG_PFD_480A_PFD2_DIV1_CLKGATE (0x00800000U) /*!< Bit mask for CCM_ANALOG_PFD_480A_PFD2_DIV1_CLKGATE. */
#define BS_CCM_ANALOG_PFD_480A_PFD2_DIV1_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480A_PFD2_DIV1_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480A_PFD2_DIV1_CLKGATE field. */
#define BR_CCM_ANALOG_PFD_480A_PFD2_DIV1_CLKGATE(x) (HW_CCM_ANALOG_PFD_480A(x).B.PFD2_DIV1_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480A_PFD2_DIV1_CLKGATE. */
#define BF_CCM_ANALOG_PFD_480A_PFD2_DIV1_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480A_PFD2_DIV1_CLKGATE) & BM_CCM_ANALOG_PFD_480A_PFD2_DIV1_CLKGATE)

/*! @brief Set the PFD2_DIV1_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PFD_480A_PFD2_DIV1_CLKGATE(x, v) (HW_CCM_ANALOG_PFD_480A_WR(x, (HW_CCM_ANALOG_PFD_480A_RD(x) & ~BM_CCM_ANALOG_PFD_480A_PFD2_DIV1_CLKGATE) | BF_CCM_ANALOG_PFD_480A_PFD2_DIV1_CLKGATE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480A, field PFD3_FRAC[29:24] (RW)
 *
 * This field controls the fractional divide value. The resulting frequency
 * shall be 480*18/PFD3_FRAC where PFD3_FRAC is in the range 12-35.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480A_PFD3_FRAC (24U) /*!< Bit position for CCM_ANALOG_PFD_480A_PFD3_FRAC. */
#define BM_CCM_ANALOG_PFD_480A_PFD3_FRAC (0x3F000000U) /*!< Bit mask for CCM_ANALOG_PFD_480A_PFD3_FRAC. */
#define BS_CCM_ANALOG_PFD_480A_PFD3_FRAC (6U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480A_PFD3_FRAC. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480A_PFD3_FRAC field. */
#define BR_CCM_ANALOG_PFD_480A_PFD3_FRAC(x) (HW_CCM_ANALOG_PFD_480A(x).B.PFD3_FRAC)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480A_PFD3_FRAC. */
#define BF_CCM_ANALOG_PFD_480A_PFD3_FRAC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480A_PFD3_FRAC) & BM_CCM_ANALOG_PFD_480A_PFD3_FRAC)

/*! @brief Set the PFD3_FRAC field to a new value. */
#define BW_CCM_ANALOG_PFD_480A_PFD3_FRAC(x, v) (HW_CCM_ANALOG_PFD_480A_WR(x, (HW_CCM_ANALOG_PFD_480A_RD(x) & ~BM_CCM_ANALOG_PFD_480A_PFD3_FRAC) | BF_CCM_ANALOG_PFD_480A_PFD3_FRAC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480A, field PFD3_STABLE[30] (RO)
 *
 * This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional
 * divider should become stable quickly enough that this field will never need to
 * be used by either device driver or application code. The value inverts when
 * the new programmed fractional divide value has taken effect. Read this bit,
 * program the new value, and when this bit inverts, the phase divider clock output
 * is stable. Note that the value will not invert when the fractional divider is
 * taken out of or placed into clock-gated state.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480A_PFD3_STABLE (30U) /*!< Bit position for CCM_ANALOG_PFD_480A_PFD3_STABLE. */
#define BM_CCM_ANALOG_PFD_480A_PFD3_STABLE (0x40000000U) /*!< Bit mask for CCM_ANALOG_PFD_480A_PFD3_STABLE. */
#define BS_CCM_ANALOG_PFD_480A_PFD3_STABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480A_PFD3_STABLE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480A_PFD3_STABLE field. */
#define BR_CCM_ANALOG_PFD_480A_PFD3_STABLE(x) (HW_CCM_ANALOG_PFD_480A(x).B.PFD3_STABLE)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480A, field PFD3_DIV1_CLKGATE[31] (RW)
 *
 * IO Clock Gate. If set to 1, the 3rd fractional divider clock (reference
 * ref_pfd3) is off (power savings). 0: ref_pfd3 fractional divider clock is enabled.
 * If the corresponding override bit is set in the 480MHz PLL control register,
 * this field has no effect.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480A_PFD3_DIV1_CLKGATE (31U) /*!< Bit position for CCM_ANALOG_PFD_480A_PFD3_DIV1_CLKGATE. */
#define BM_CCM_ANALOG_PFD_480A_PFD3_DIV1_CLKGATE (0x80000000U) /*!< Bit mask for CCM_ANALOG_PFD_480A_PFD3_DIV1_CLKGATE. */
#define BS_CCM_ANALOG_PFD_480A_PFD3_DIV1_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480A_PFD3_DIV1_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480A_PFD3_DIV1_CLKGATE field. */
#define BR_CCM_ANALOG_PFD_480A_PFD3_DIV1_CLKGATE(x) (HW_CCM_ANALOG_PFD_480A(x).B.PFD3_DIV1_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480A_PFD3_DIV1_CLKGATE. */
#define BF_CCM_ANALOG_PFD_480A_PFD3_DIV1_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480A_PFD3_DIV1_CLKGATE) & BM_CCM_ANALOG_PFD_480A_PFD3_DIV1_CLKGATE)

/*! @brief Set the PFD3_DIV1_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PFD_480A_PFD3_DIV1_CLKGATE(x, v) (HW_CCM_ANALOG_PFD_480A_WR(x, (HW_CCM_ANALOG_PFD_480A_RD(x) & ~BM_CCM_ANALOG_PFD_480A_PFD3_DIV1_CLKGATE) | BF_CCM_ANALOG_PFD_480A_PFD3_DIV1_CLKGATE(v)))
/*@}*/




/*******************************************************************************
 * HW_CCM_ANALOG_PFD_480B - 480MHz Clock Phase Fractional Divider Control Register B
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PFD_480B - 480MHz Clock Phase Fractional Divider Control Register B (RW)
 *
 * Reset value: 0x12121212U
 *
 * This register controls the 4-phase fractional clock dividers. The fractional
 * clock frequencies are a product of the values in these registers.
 */
typedef union _hw_ccm_analog_pfd_480b
{
    uint32_t U;
    struct _hw_ccm_analog_pfd_480b_bitfields
    {
        uint32_t PFD4_FRAC : 6;        /*!< [5:0]  */
        uint32_t PFD4_STABLE : 1;      /*!< [6]  */
        uint32_t PFD4_DIV1_CLKGATE : 1; /*!< [7]  */
        uint32_t PFD5_FRAC : 6;        /*!< [13:8]  */
        uint32_t PFD5_STABLE : 1;      /*!< [14]  */
        uint32_t PFD5_DIV1_CLKGATE : 1; /*!< [15]  */
        uint32_t PFD6_FRAC : 6;        /*!< [21:16]  */
        uint32_t PFD6_STABLE : 1;      /*!< [22]  */
        uint32_t PFD6_DIV1_CLKGATE : 1; /*!< [23]  */
        uint32_t PFD7_FRAC : 6;        /*!< [29:24]  */
        uint32_t PFD7_STABLE : 1;      /*!< [30]  */
        uint32_t PFD7_DIV1_CLKGATE : 1; /*!< [31]  */
    } B;
} hw_ccm_analog_pfd_480b_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PFD_480B register
 */
/*@{*/
#define HW_CCM_ANALOG_PFD_480B_ADDR(x) ((uintptr_t)(x) + 0xD0U)
#define HW_CCM_ANALOG_PFD_480B_SET_ADDR(x) (HW_CCM_ANALOG_PFD_480B_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_PFD_480B_CLR_ADDR(x) (HW_CCM_ANALOG_PFD_480B_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_PFD_480B_TOG_ADDR(x) (HW_CCM_ANALOG_PFD_480B_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_PFD_480B(x) (*(__IO hw_ccm_analog_pfd_480b_t *) HW_CCM_ANALOG_PFD_480B_ADDR(x))
#define HW_CCM_ANALOG_PFD_480B_RD(x) (HW_CCM_ANALOG_PFD_480B(x).U)
#define HW_CCM_ANALOG_PFD_480B_WR(x, v) (HW_CCM_ANALOG_PFD_480B(x).U = (v))
#define HW_CCM_ANALOG_PFD_480B_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PFD_480B_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PFD_480B_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PFD_480B_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PFD_480B_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PFD_480B_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PFD_480B bitfields
 */

/*!
 * @name Register CCM_ANALOG_PFD_480B, field PFD4_FRAC[5:0] (RW)
 *
 * This field controls the fractional divide value. The resulting frequency
 * shall be 480*18/PFD4_FRAC where PFD0_FRAC is in the range 12-35.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480B_PFD4_FRAC (0U) /*!< Bit position for CCM_ANALOG_PFD_480B_PFD4_FRAC. */
#define BM_CCM_ANALOG_PFD_480B_PFD4_FRAC (0x0000003FU) /*!< Bit mask for CCM_ANALOG_PFD_480B_PFD4_FRAC. */
#define BS_CCM_ANALOG_PFD_480B_PFD4_FRAC (6U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480B_PFD4_FRAC. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480B_PFD4_FRAC field. */
#define BR_CCM_ANALOG_PFD_480B_PFD4_FRAC(x) (HW_CCM_ANALOG_PFD_480B(x).B.PFD4_FRAC)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480B_PFD4_FRAC. */
#define BF_CCM_ANALOG_PFD_480B_PFD4_FRAC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480B_PFD4_FRAC) & BM_CCM_ANALOG_PFD_480B_PFD4_FRAC)

/*! @brief Set the PFD4_FRAC field to a new value. */
#define BW_CCM_ANALOG_PFD_480B_PFD4_FRAC(x, v) (HW_CCM_ANALOG_PFD_480B_WR(x, (HW_CCM_ANALOG_PFD_480B_RD(x) & ~BM_CCM_ANALOG_PFD_480B_PFD4_FRAC) | BF_CCM_ANALOG_PFD_480B_PFD4_FRAC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480B, field PFD4_STABLE[6] (RO)
 *
 * This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional
 * divider should become stable quickly enough that this field will never need to
 * be used by either device driver or application code. The value inverts when
 * the new programmed fractional divide value has taken effect. Read this bit,
 * program the new value, and when this bit inverts, the phase divider clock output
 * is stable. Note that the value will not invert when the fractional divider is
 * taken out of or placed into clock-gated state.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480B_PFD4_STABLE (6U) /*!< Bit position for CCM_ANALOG_PFD_480B_PFD4_STABLE. */
#define BM_CCM_ANALOG_PFD_480B_PFD4_STABLE (0x00000040U) /*!< Bit mask for CCM_ANALOG_PFD_480B_PFD4_STABLE. */
#define BS_CCM_ANALOG_PFD_480B_PFD4_STABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480B_PFD4_STABLE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480B_PFD4_STABLE field. */
#define BR_CCM_ANALOG_PFD_480B_PFD4_STABLE(x) (HW_CCM_ANALOG_PFD_480B(x).B.PFD4_STABLE)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480B, field PFD4_DIV1_CLKGATE[7] (RW)
 *
 * If set to 1, the IO fractional divider clock (reference ref_pfd0) is off
 * (power savings). 0: ref_pfd0 fractional divider clock is enabled. If the
 * corresponding override bit is set in the 480MHz PLL control register, this field has no
 * effect.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480B_PFD4_DIV1_CLKGATE (7U) /*!< Bit position for CCM_ANALOG_PFD_480B_PFD4_DIV1_CLKGATE. */
#define BM_CCM_ANALOG_PFD_480B_PFD4_DIV1_CLKGATE (0x00000080U) /*!< Bit mask for CCM_ANALOG_PFD_480B_PFD4_DIV1_CLKGATE. */
#define BS_CCM_ANALOG_PFD_480B_PFD4_DIV1_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480B_PFD4_DIV1_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480B_PFD4_DIV1_CLKGATE field. */
#define BR_CCM_ANALOG_PFD_480B_PFD4_DIV1_CLKGATE(x) (HW_CCM_ANALOG_PFD_480B(x).B.PFD4_DIV1_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480B_PFD4_DIV1_CLKGATE. */
#define BF_CCM_ANALOG_PFD_480B_PFD4_DIV1_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480B_PFD4_DIV1_CLKGATE) & BM_CCM_ANALOG_PFD_480B_PFD4_DIV1_CLKGATE)

/*! @brief Set the PFD4_DIV1_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PFD_480B_PFD4_DIV1_CLKGATE(x, v) (HW_CCM_ANALOG_PFD_480B_WR(x, (HW_CCM_ANALOG_PFD_480B_RD(x) & ~BM_CCM_ANALOG_PFD_480B_PFD4_DIV1_CLKGATE) | BF_CCM_ANALOG_PFD_480B_PFD4_DIV1_CLKGATE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480B, field PFD5_FRAC[13:8] (RW)
 *
 * This field controls the fractional divide value. The resulting frequency
 * shall be 480*18/PFD5_FRAC where PFD1_FRAC is in the range 12-35.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480B_PFD5_FRAC (8U) /*!< Bit position for CCM_ANALOG_PFD_480B_PFD5_FRAC. */
#define BM_CCM_ANALOG_PFD_480B_PFD5_FRAC (0x00003F00U) /*!< Bit mask for CCM_ANALOG_PFD_480B_PFD5_FRAC. */
#define BS_CCM_ANALOG_PFD_480B_PFD5_FRAC (6U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480B_PFD5_FRAC. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480B_PFD5_FRAC field. */
#define BR_CCM_ANALOG_PFD_480B_PFD5_FRAC(x) (HW_CCM_ANALOG_PFD_480B(x).B.PFD5_FRAC)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480B_PFD5_FRAC. */
#define BF_CCM_ANALOG_PFD_480B_PFD5_FRAC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480B_PFD5_FRAC) & BM_CCM_ANALOG_PFD_480B_PFD5_FRAC)

/*! @brief Set the PFD5_FRAC field to a new value. */
#define BW_CCM_ANALOG_PFD_480B_PFD5_FRAC(x, v) (HW_CCM_ANALOG_PFD_480B_WR(x, (HW_CCM_ANALOG_PFD_480B_RD(x) & ~BM_CCM_ANALOG_PFD_480B_PFD5_FRAC) | BF_CCM_ANALOG_PFD_480B_PFD5_FRAC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480B, field PFD5_STABLE[14] (RO)
 *
 * This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional
 * divider should become stable quickly enough that this field will never need to
 * be used by either device driver or application code. The value inverts when
 * the new programmed fractional divide value has taken effect. Read this bit,
 * program the new value, and when this bit inverts, the phase divider clock output
 * is stable. Note that the value will not invert when the fractional divider is
 * taken out of or placed into clock-gated state.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480B_PFD5_STABLE (14U) /*!< Bit position for CCM_ANALOG_PFD_480B_PFD5_STABLE. */
#define BM_CCM_ANALOG_PFD_480B_PFD5_STABLE (0x00004000U) /*!< Bit mask for CCM_ANALOG_PFD_480B_PFD5_STABLE. */
#define BS_CCM_ANALOG_PFD_480B_PFD5_STABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480B_PFD5_STABLE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480B_PFD5_STABLE field. */
#define BR_CCM_ANALOG_PFD_480B_PFD5_STABLE(x) (HW_CCM_ANALOG_PFD_480B(x).B.PFD5_STABLE)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480B, field PFD5_DIV1_CLKGATE[15] (RW)
 *
 * IO Clock Gate. If set to 1, the IO fractional divider clock (reference
 * ref_pfd1) is off (power savings). 0: ref_pfd1 fractional divider clock is enabled.
 * If the corresponding override bit is set in the 480MHz PLL control register,
 * this field has no effect.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480B_PFD5_DIV1_CLKGATE (15U) /*!< Bit position for CCM_ANALOG_PFD_480B_PFD5_DIV1_CLKGATE. */
#define BM_CCM_ANALOG_PFD_480B_PFD5_DIV1_CLKGATE (0x00008000U) /*!< Bit mask for CCM_ANALOG_PFD_480B_PFD5_DIV1_CLKGATE. */
#define BS_CCM_ANALOG_PFD_480B_PFD5_DIV1_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480B_PFD5_DIV1_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480B_PFD5_DIV1_CLKGATE field. */
#define BR_CCM_ANALOG_PFD_480B_PFD5_DIV1_CLKGATE(x) (HW_CCM_ANALOG_PFD_480B(x).B.PFD5_DIV1_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480B_PFD5_DIV1_CLKGATE. */
#define BF_CCM_ANALOG_PFD_480B_PFD5_DIV1_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480B_PFD5_DIV1_CLKGATE) & BM_CCM_ANALOG_PFD_480B_PFD5_DIV1_CLKGATE)

/*! @brief Set the PFD5_DIV1_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PFD_480B_PFD5_DIV1_CLKGATE(x, v) (HW_CCM_ANALOG_PFD_480B_WR(x, (HW_CCM_ANALOG_PFD_480B_RD(x) & ~BM_CCM_ANALOG_PFD_480B_PFD5_DIV1_CLKGATE) | BF_CCM_ANALOG_PFD_480B_PFD5_DIV1_CLKGATE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480B, field PFD6_FRAC[21:16] (RW)
 *
 * This field controls the fractional divide value. The resulting frequency
 * shall be 480*18/PFD6_FRAC where PFD2_FRAC is in the range 12-35.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480B_PFD6_FRAC (16U) /*!< Bit position for CCM_ANALOG_PFD_480B_PFD6_FRAC. */
#define BM_CCM_ANALOG_PFD_480B_PFD6_FRAC (0x003F0000U) /*!< Bit mask for CCM_ANALOG_PFD_480B_PFD6_FRAC. */
#define BS_CCM_ANALOG_PFD_480B_PFD6_FRAC (6U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480B_PFD6_FRAC. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480B_PFD6_FRAC field. */
#define BR_CCM_ANALOG_PFD_480B_PFD6_FRAC(x) (HW_CCM_ANALOG_PFD_480B(x).B.PFD6_FRAC)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480B_PFD6_FRAC. */
#define BF_CCM_ANALOG_PFD_480B_PFD6_FRAC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480B_PFD6_FRAC) & BM_CCM_ANALOG_PFD_480B_PFD6_FRAC)

/*! @brief Set the PFD6_FRAC field to a new value. */
#define BW_CCM_ANALOG_PFD_480B_PFD6_FRAC(x, v) (HW_CCM_ANALOG_PFD_480B_WR(x, (HW_CCM_ANALOG_PFD_480B_RD(x) & ~BM_CCM_ANALOG_PFD_480B_PFD6_FRAC) | BF_CCM_ANALOG_PFD_480B_PFD6_FRAC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480B, field PFD6_STABLE[22] (RO)
 *
 * This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional
 * divider should become stable quickly enough that this field will never need to
 * be used by either device driver or application code. The value inverts when
 * the new programmed fractional divide value has taken effect. Read this bit,
 * program the new value, and when this bit inverts, the phase divider clock output
 * is stable. Note that the value will not invert when the fractional divider is
 * taken out of or placed into clock-gated state.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480B_PFD6_STABLE (22U) /*!< Bit position for CCM_ANALOG_PFD_480B_PFD6_STABLE. */
#define BM_CCM_ANALOG_PFD_480B_PFD6_STABLE (0x00400000U) /*!< Bit mask for CCM_ANALOG_PFD_480B_PFD6_STABLE. */
#define BS_CCM_ANALOG_PFD_480B_PFD6_STABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480B_PFD6_STABLE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480B_PFD6_STABLE field. */
#define BR_CCM_ANALOG_PFD_480B_PFD6_STABLE(x) (HW_CCM_ANALOG_PFD_480B(x).B.PFD6_STABLE)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480B, field PFD6_DIV1_CLKGATE[23] (RW)
 *
 * IO Clock Gate. If set to 1, the IO fractional divider clock (reference
 * ref_pfd2) is off (power savings). 0: ref_pfd2 fractional divider clock is enabled.
 * If the corresponding override bit is set in the 480MHz PLL control register,
 * this field has no effect.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480B_PFD6_DIV1_CLKGATE (23U) /*!< Bit position for CCM_ANALOG_PFD_480B_PFD6_DIV1_CLKGATE. */
#define BM_CCM_ANALOG_PFD_480B_PFD6_DIV1_CLKGATE (0x00800000U) /*!< Bit mask for CCM_ANALOG_PFD_480B_PFD6_DIV1_CLKGATE. */
#define BS_CCM_ANALOG_PFD_480B_PFD6_DIV1_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480B_PFD6_DIV1_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480B_PFD6_DIV1_CLKGATE field. */
#define BR_CCM_ANALOG_PFD_480B_PFD6_DIV1_CLKGATE(x) (HW_CCM_ANALOG_PFD_480B(x).B.PFD6_DIV1_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480B_PFD6_DIV1_CLKGATE. */
#define BF_CCM_ANALOG_PFD_480B_PFD6_DIV1_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480B_PFD6_DIV1_CLKGATE) & BM_CCM_ANALOG_PFD_480B_PFD6_DIV1_CLKGATE)

/*! @brief Set the PFD6_DIV1_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PFD_480B_PFD6_DIV1_CLKGATE(x, v) (HW_CCM_ANALOG_PFD_480B_WR(x, (HW_CCM_ANALOG_PFD_480B_RD(x) & ~BM_CCM_ANALOG_PFD_480B_PFD6_DIV1_CLKGATE) | BF_CCM_ANALOG_PFD_480B_PFD6_DIV1_CLKGATE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480B, field PFD7_FRAC[29:24] (RW)
 *
 * This field controls the fractional divide value. The resulting frequency
 * shall be 480*18/PFD7_FRAC where PFD3_FRAC is in the range 12-35.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480B_PFD7_FRAC (24U) /*!< Bit position for CCM_ANALOG_PFD_480B_PFD7_FRAC. */
#define BM_CCM_ANALOG_PFD_480B_PFD7_FRAC (0x3F000000U) /*!< Bit mask for CCM_ANALOG_PFD_480B_PFD7_FRAC. */
#define BS_CCM_ANALOG_PFD_480B_PFD7_FRAC (6U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480B_PFD7_FRAC. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480B_PFD7_FRAC field. */
#define BR_CCM_ANALOG_PFD_480B_PFD7_FRAC(x) (HW_CCM_ANALOG_PFD_480B(x).B.PFD7_FRAC)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480B_PFD7_FRAC. */
#define BF_CCM_ANALOG_PFD_480B_PFD7_FRAC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480B_PFD7_FRAC) & BM_CCM_ANALOG_PFD_480B_PFD7_FRAC)

/*! @brief Set the PFD7_FRAC field to a new value. */
#define BW_CCM_ANALOG_PFD_480B_PFD7_FRAC(x, v) (HW_CCM_ANALOG_PFD_480B_WR(x, (HW_CCM_ANALOG_PFD_480B_RD(x) & ~BM_CCM_ANALOG_PFD_480B_PFD7_FRAC) | BF_CCM_ANALOG_PFD_480B_PFD7_FRAC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480B, field PFD7_STABLE[30] (RO)
 *
 * This read-only bitfield is for DIAGNOSTIC PURPOSES ONLY since the fractional
 * divider should become stable quickly enough that this field will never need to
 * be used by either device driver or application code. The value inverts when
 * the new programmed fractional divide value has taken effect. Read this bit,
 * program the new value, and when this bit inverts, the phase divider clock output
 * is stable. Note that the value will not invert when the fractional divider is
 * taken out of or placed into clock-gated state.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480B_PFD7_STABLE (30U) /*!< Bit position for CCM_ANALOG_PFD_480B_PFD7_STABLE. */
#define BM_CCM_ANALOG_PFD_480B_PFD7_STABLE (0x40000000U) /*!< Bit mask for CCM_ANALOG_PFD_480B_PFD7_STABLE. */
#define BS_CCM_ANALOG_PFD_480B_PFD7_STABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480B_PFD7_STABLE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480B_PFD7_STABLE field. */
#define BR_CCM_ANALOG_PFD_480B_PFD7_STABLE(x) (HW_CCM_ANALOG_PFD_480B(x).B.PFD7_STABLE)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PFD_480B, field PFD7_DIV1_CLKGATE[31] (RW)
 *
 * IO Clock Gate. If set to 1, the 3rd fractional divider clock (reference
 * ref_pfd7) is off (power savings). 0: ref_pfd3 fractional divider clock is enabled.
 * If the corresponding override bit is set in the 480MHz PLL control register,
 * this field has no effect.
 */
/*@{*/
#define BP_CCM_ANALOG_PFD_480B_PFD7_DIV1_CLKGATE (31U) /*!< Bit position for CCM_ANALOG_PFD_480B_PFD7_DIV1_CLKGATE. */
#define BM_CCM_ANALOG_PFD_480B_PFD7_DIV1_CLKGATE (0x80000000U) /*!< Bit mask for CCM_ANALOG_PFD_480B_PFD7_DIV1_CLKGATE. */
#define BS_CCM_ANALOG_PFD_480B_PFD7_DIV1_CLKGATE (1U) /*!< Bit field size in bits for CCM_ANALOG_PFD_480B_PFD7_DIV1_CLKGATE. */

/*! @brief Read current value of the CCM_ANALOG_PFD_480B_PFD7_DIV1_CLKGATE field. */
#define BR_CCM_ANALOG_PFD_480B_PFD7_DIV1_CLKGATE(x) (HW_CCM_ANALOG_PFD_480B(x).B.PFD7_DIV1_CLKGATE)

/*! @brief Format value for bitfield CCM_ANALOG_PFD_480B_PFD7_DIV1_CLKGATE. */
#define BF_CCM_ANALOG_PFD_480B_PFD7_DIV1_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PFD_480B_PFD7_DIV1_CLKGATE) & BM_CCM_ANALOG_PFD_480B_PFD7_DIV1_CLKGATE)

/*! @brief Set the PFD7_DIV1_CLKGATE field to a new value. */
#define BW_CCM_ANALOG_PFD_480B_PFD7_DIV1_CLKGATE(x, v) (HW_CCM_ANALOG_PFD_480B_WR(x, (HW_CCM_ANALOG_PFD_480B_RD(x) & ~BM_CCM_ANALOG_PFD_480B_PFD7_DIV1_CLKGATE) | BF_CCM_ANALOG_PFD_480B_PFD7_DIV1_CLKGATE(v)))
/*@}*/




/*******************************************************************************
 * HW_CCM_ANALOG_PLL_ENET - Anadig ENET PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_ENET - Anadig ENET PLL Control Register (RW)
 *
 * Reset value: 0x00011FE0U
 *
 * The control register provides control for the ENET PLL.
 */
typedef union _hw_ccm_analog_pll_enet
{
    uint32_t U;
    struct _hw_ccm_analog_pll_enet_bitfields
    {
        uint32_t HALF_LF : 1;          /*!< [0]  */
        uint32_t DOUBLE_LF : 1;        /*!< [1]  */
        uint32_t HALF_CP : 1;          /*!< [2]  */
        uint32_t DOUBLE_CP : 1;        /*!< [3]  */
        uint32_t HOLD_RING_OFF : 1;    /*!< [4]  */
        uint32_t POWERDOWN : 1;        /*!< [5]  */
        uint32_t ENABLE_CLK_25MHZ : 1; /*!< [6]  */
        uint32_t ENABLE_CLK_40MHZ : 1; /*!< [7]  */
        uint32_t ENABLE_CLK_50MHZ : 1; /*!< [8]  */
        uint32_t ENABLE_CLK_100MHZ : 1; /*!< [9]  */
        uint32_t ENABLE_CLK_125MHZ : 1; /*!< [10]  */
        uint32_t ENABLE_CLK_250MHZ : 1; /*!< [11]  */
        uint32_t ENABLE_CLK_500MHZ : 1; /*!< [12]  */
        uint32_t PLL_ENET_OVERRIDE : 1; /*!< [13]  */
        uint32_t BYPASS_CLK_SRC : 2;   /*!< [15:14]  */
        uint32_t BYPASS : 1;           /*!< [16]  */
        uint32_t DITHER_ENABLE : 1;    /*!< [17]  */
        uint32_t PFD_OFFSET_EN : 1;    /*!< [18]  */
        uint32_t RSVD1 : 12;           /*!< [30:19]  */
        uint32_t LOCK : 1;             /*!< [31]  */
    } B;
} hw_ccm_analog_pll_enet_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_ENET register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_ENET_ADDR(x) ((uintptr_t)(x) + 0xE0U)
#define HW_CCM_ANALOG_PLL_ENET_SET_ADDR(x) (HW_CCM_ANALOG_PLL_ENET_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_PLL_ENET_CLR_ADDR(x) (HW_CCM_ANALOG_PLL_ENET_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_PLL_ENET_TOG_ADDR(x) (HW_CCM_ANALOG_PLL_ENET_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_PLL_ENET(x) (*(__IO hw_ccm_analog_pll_enet_t *) HW_CCM_ANALOG_PLL_ENET_ADDR(x))
#define HW_CCM_ANALOG_PLL_ENET_RD(x) (HW_CCM_ANALOG_PLL_ENET(x).U)
#define HW_CCM_ANALOG_PLL_ENET_WR(x, v) (HW_CCM_ANALOG_PLL_ENET(x).U = (v))
#define HW_CCM_ANALOG_PLL_ENET_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_ENET_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_ENET_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_ENET_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_ENET_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_ENET_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_ENET bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field HALF_LF[0] (RW)
 *
 * Reduces the frequency of the loop filter 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_HALF_LF (0U) /*!< Bit position for CCM_ANALOG_PLL_ENET_HALF_LF. */
#define BM_CCM_ANALOG_PLL_ENET_HALF_LF (0x00000001U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_HALF_LF. */
#define BS_CCM_ANALOG_PLL_ENET_HALF_LF (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_HALF_LF. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_HALF_LF field. */
#define BR_CCM_ANALOG_PLL_ENET_HALF_LF(x) (HW_CCM_ANALOG_PLL_ENET(x).B.HALF_LF)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_HALF_LF. */
#define BF_CCM_ANALOG_PLL_ENET_HALF_LF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_HALF_LF) & BM_CCM_ANALOG_PLL_ENET_HALF_LF)

/*! @brief Set the HALF_LF field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_HALF_LF(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_HALF_LF) | BF_CCM_ANALOG_PLL_ENET_HALF_LF(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field DOUBLE_LF[1] (RW)
 *
 * Increases the frequency of the loop filter 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_DOUBLE_LF (1U) /*!< Bit position for CCM_ANALOG_PLL_ENET_DOUBLE_LF. */
#define BM_CCM_ANALOG_PLL_ENET_DOUBLE_LF (0x00000002U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_DOUBLE_LF. */
#define BS_CCM_ANALOG_PLL_ENET_DOUBLE_LF (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_DOUBLE_LF. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_DOUBLE_LF field. */
#define BR_CCM_ANALOG_PLL_ENET_DOUBLE_LF(x) (HW_CCM_ANALOG_PLL_ENET(x).B.DOUBLE_LF)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_DOUBLE_LF. */
#define BF_CCM_ANALOG_PLL_ENET_DOUBLE_LF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_DOUBLE_LF) & BM_CCM_ANALOG_PLL_ENET_DOUBLE_LF)

/*! @brief Set the DOUBLE_LF field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_DOUBLE_LF(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_DOUBLE_LF) | BF_CCM_ANALOG_PLL_ENET_DOUBLE_LF(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field HALF_CP[2] (RW)
 *
 * Reduces the charge pump gain 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_HALF_CP (2U) /*!< Bit position for CCM_ANALOG_PLL_ENET_HALF_CP. */
#define BM_CCM_ANALOG_PLL_ENET_HALF_CP (0x00000004U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_HALF_CP. */
#define BS_CCM_ANALOG_PLL_ENET_HALF_CP (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_HALF_CP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_HALF_CP field. */
#define BR_CCM_ANALOG_PLL_ENET_HALF_CP(x) (HW_CCM_ANALOG_PLL_ENET(x).B.HALF_CP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_HALF_CP. */
#define BF_CCM_ANALOG_PLL_ENET_HALF_CP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_HALF_CP) & BM_CCM_ANALOG_PLL_ENET_HALF_CP)

/*! @brief Set the HALF_CP field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_HALF_CP(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_HALF_CP) | BF_CCM_ANALOG_PLL_ENET_HALF_CP(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field DOUBLE_CP[3] (RW)
 *
 * Increases the charge pump gain 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_DOUBLE_CP (3U) /*!< Bit position for CCM_ANALOG_PLL_ENET_DOUBLE_CP. */
#define BM_CCM_ANALOG_PLL_ENET_DOUBLE_CP (0x00000008U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_DOUBLE_CP. */
#define BS_CCM_ANALOG_PLL_ENET_DOUBLE_CP (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_DOUBLE_CP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_DOUBLE_CP field. */
#define BR_CCM_ANALOG_PLL_ENET_DOUBLE_CP(x) (HW_CCM_ANALOG_PLL_ENET(x).B.DOUBLE_CP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_DOUBLE_CP. */
#define BF_CCM_ANALOG_PLL_ENET_DOUBLE_CP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_DOUBLE_CP) & BM_CCM_ANALOG_PLL_ENET_DOUBLE_CP)

/*! @brief Set the DOUBLE_CP field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_DOUBLE_CP(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_DOUBLE_CP) | BF_CCM_ANALOG_PLL_ENET_DOUBLE_CP(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field HOLD_RING_OFF[4] (RW)
 *
 * Status of ana_irq2 input from analog block.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_HOLD_RING_OFF (4U) /*!< Bit position for CCM_ANALOG_PLL_ENET_HOLD_RING_OFF. */
#define BM_CCM_ANALOG_PLL_ENET_HOLD_RING_OFF (0x00000010U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_HOLD_RING_OFF. */
#define BS_CCM_ANALOG_PLL_ENET_HOLD_RING_OFF (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_HOLD_RING_OFF. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_HOLD_RING_OFF field. */
#define BR_CCM_ANALOG_PLL_ENET_HOLD_RING_OFF(x) (HW_CCM_ANALOG_PLL_ENET(x).B.HOLD_RING_OFF)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_HOLD_RING_OFF. */
#define BF_CCM_ANALOG_PLL_ENET_HOLD_RING_OFF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_HOLD_RING_OFF) & BM_CCM_ANALOG_PLL_ENET_HOLD_RING_OFF)

/*! @brief Set the HOLD_RING_OFF field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_HOLD_RING_OFF(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_HOLD_RING_OFF) | BF_CCM_ANALOG_PLL_ENET_HOLD_RING_OFF(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field POWERDOWN[5] (RW)
 *
 * Powers down the PLL.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_POWERDOWN (5U) /*!< Bit position for CCM_ANALOG_PLL_ENET_POWERDOWN. */
#define BM_CCM_ANALOG_PLL_ENET_POWERDOWN (0x00000020U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_POWERDOWN. */
#define BS_CCM_ANALOG_PLL_ENET_POWERDOWN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_POWERDOWN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_POWERDOWN field. */
#define BR_CCM_ANALOG_PLL_ENET_POWERDOWN(x) (HW_CCM_ANALOG_PLL_ENET(x).B.POWERDOWN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_POWERDOWN. */
#define BF_CCM_ANALOG_PLL_ENET_POWERDOWN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_POWERDOWN) & BM_CCM_ANALOG_PLL_ENET_POWERDOWN)

/*! @brief Set the POWERDOWN field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_POWERDOWN(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_POWERDOWN) | BF_CCM_ANALOG_PLL_ENET_POWERDOWN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field ENABLE_CLK_25MHZ[6] (RW)
 *
 * Enables the ethernet 25MHz clock output.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_ENABLE_CLK_25MHZ (6U) /*!< Bit position for CCM_ANALOG_PLL_ENET_ENABLE_CLK_25MHZ. */
#define BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_25MHZ (0x00000040U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_ENABLE_CLK_25MHZ. */
#define BS_CCM_ANALOG_PLL_ENET_ENABLE_CLK_25MHZ (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_ENABLE_CLK_25MHZ. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_ENABLE_CLK_25MHZ field. */
#define BR_CCM_ANALOG_PLL_ENET_ENABLE_CLK_25MHZ(x) (HW_CCM_ANALOG_PLL_ENET(x).B.ENABLE_CLK_25MHZ)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_ENABLE_CLK_25MHZ. */
#define BF_CCM_ANALOG_PLL_ENET_ENABLE_CLK_25MHZ(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_ENABLE_CLK_25MHZ) & BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_25MHZ)

/*! @brief Set the ENABLE_CLK_25MHZ field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_ENABLE_CLK_25MHZ(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_25MHZ) | BF_CCM_ANALOG_PLL_ENET_ENABLE_CLK_25MHZ(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field ENABLE_CLK_40MHZ[7] (RW)
 *
 * Enables the ethernet 40MHz clock output.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_ENABLE_CLK_40MHZ (7U) /*!< Bit position for CCM_ANALOG_PLL_ENET_ENABLE_CLK_40MHZ. */
#define BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_40MHZ (0x00000080U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_ENABLE_CLK_40MHZ. */
#define BS_CCM_ANALOG_PLL_ENET_ENABLE_CLK_40MHZ (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_ENABLE_CLK_40MHZ. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_ENABLE_CLK_40MHZ field. */
#define BR_CCM_ANALOG_PLL_ENET_ENABLE_CLK_40MHZ(x) (HW_CCM_ANALOG_PLL_ENET(x).B.ENABLE_CLK_40MHZ)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_ENABLE_CLK_40MHZ. */
#define BF_CCM_ANALOG_PLL_ENET_ENABLE_CLK_40MHZ(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_ENABLE_CLK_40MHZ) & BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_40MHZ)

/*! @brief Set the ENABLE_CLK_40MHZ field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_ENABLE_CLK_40MHZ(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_40MHZ) | BF_CCM_ANALOG_PLL_ENET_ENABLE_CLK_40MHZ(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field ENABLE_CLK_50MHZ[8] (RW)
 *
 * Enables the ethernet 50MHz clock output.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_ENABLE_CLK_50MHZ (8U) /*!< Bit position for CCM_ANALOG_PLL_ENET_ENABLE_CLK_50MHZ. */
#define BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_50MHZ (0x00000100U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_ENABLE_CLK_50MHZ. */
#define BS_CCM_ANALOG_PLL_ENET_ENABLE_CLK_50MHZ (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_ENABLE_CLK_50MHZ. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_ENABLE_CLK_50MHZ field. */
#define BR_CCM_ANALOG_PLL_ENET_ENABLE_CLK_50MHZ(x) (HW_CCM_ANALOG_PLL_ENET(x).B.ENABLE_CLK_50MHZ)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_ENABLE_CLK_50MHZ. */
#define BF_CCM_ANALOG_PLL_ENET_ENABLE_CLK_50MHZ(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_ENABLE_CLK_50MHZ) & BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_50MHZ)

/*! @brief Set the ENABLE_CLK_50MHZ field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_ENABLE_CLK_50MHZ(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_50MHZ) | BF_CCM_ANALOG_PLL_ENET_ENABLE_CLK_50MHZ(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field ENABLE_CLK_100MHZ[9] (RW)
 *
 * Enables the ethernet 100MHz clock output.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_ENABLE_CLK_100MHZ (9U) /*!< Bit position for CCM_ANALOG_PLL_ENET_ENABLE_CLK_100MHZ. */
#define BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_100MHZ (0x00000200U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_ENABLE_CLK_100MHZ. */
#define BS_CCM_ANALOG_PLL_ENET_ENABLE_CLK_100MHZ (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_ENABLE_CLK_100MHZ. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_ENABLE_CLK_100MHZ field. */
#define BR_CCM_ANALOG_PLL_ENET_ENABLE_CLK_100MHZ(x) (HW_CCM_ANALOG_PLL_ENET(x).B.ENABLE_CLK_100MHZ)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_ENABLE_CLK_100MHZ. */
#define BF_CCM_ANALOG_PLL_ENET_ENABLE_CLK_100MHZ(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_ENABLE_CLK_100MHZ) & BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_100MHZ)

/*! @brief Set the ENABLE_CLK_100MHZ field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_ENABLE_CLK_100MHZ(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_100MHZ) | BF_CCM_ANALOG_PLL_ENET_ENABLE_CLK_100MHZ(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field ENABLE_CLK_125MHZ[10] (RW)
 *
 * Enables the ethernet 125MHz clock output.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_ENABLE_CLK_125MHZ (10U) /*!< Bit position for CCM_ANALOG_PLL_ENET_ENABLE_CLK_125MHZ. */
#define BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_125MHZ (0x00000400U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_ENABLE_CLK_125MHZ. */
#define BS_CCM_ANALOG_PLL_ENET_ENABLE_CLK_125MHZ (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_ENABLE_CLK_125MHZ. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_ENABLE_CLK_125MHZ field. */
#define BR_CCM_ANALOG_PLL_ENET_ENABLE_CLK_125MHZ(x) (HW_CCM_ANALOG_PLL_ENET(x).B.ENABLE_CLK_125MHZ)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_ENABLE_CLK_125MHZ. */
#define BF_CCM_ANALOG_PLL_ENET_ENABLE_CLK_125MHZ(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_ENABLE_CLK_125MHZ) & BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_125MHZ)

/*! @brief Set the ENABLE_CLK_125MHZ field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_ENABLE_CLK_125MHZ(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_125MHZ) | BF_CCM_ANALOG_PLL_ENET_ENABLE_CLK_125MHZ(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field ENABLE_CLK_250MHZ[11] (RW)
 *
 * Enables the ethernet 250MHz clock output.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_ENABLE_CLK_250MHZ (11U) /*!< Bit position for CCM_ANALOG_PLL_ENET_ENABLE_CLK_250MHZ. */
#define BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_250MHZ (0x00000800U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_ENABLE_CLK_250MHZ. */
#define BS_CCM_ANALOG_PLL_ENET_ENABLE_CLK_250MHZ (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_ENABLE_CLK_250MHZ. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_ENABLE_CLK_250MHZ field. */
#define BR_CCM_ANALOG_PLL_ENET_ENABLE_CLK_250MHZ(x) (HW_CCM_ANALOG_PLL_ENET(x).B.ENABLE_CLK_250MHZ)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_ENABLE_CLK_250MHZ. */
#define BF_CCM_ANALOG_PLL_ENET_ENABLE_CLK_250MHZ(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_ENABLE_CLK_250MHZ) & BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_250MHZ)

/*! @brief Set the ENABLE_CLK_250MHZ field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_ENABLE_CLK_250MHZ(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_250MHZ) | BF_CCM_ANALOG_PLL_ENET_ENABLE_CLK_250MHZ(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field ENABLE_CLK_500MHZ[12] (RW)
 *
 * Enables the ethernet 500MHz clock output.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_ENABLE_CLK_500MHZ (12U) /*!< Bit position for CCM_ANALOG_PLL_ENET_ENABLE_CLK_500MHZ. */
#define BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_500MHZ (0x00001000U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_ENABLE_CLK_500MHZ. */
#define BS_CCM_ANALOG_PLL_ENET_ENABLE_CLK_500MHZ (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_ENABLE_CLK_500MHZ. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_ENABLE_CLK_500MHZ field. */
#define BR_CCM_ANALOG_PLL_ENET_ENABLE_CLK_500MHZ(x) (HW_CCM_ANALOG_PLL_ENET(x).B.ENABLE_CLK_500MHZ)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_ENABLE_CLK_500MHZ. */
#define BF_CCM_ANALOG_PLL_ENET_ENABLE_CLK_500MHZ(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_ENABLE_CLK_500MHZ) & BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_500MHZ)

/*! @brief Set the ENABLE_CLK_500MHZ field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_ENABLE_CLK_500MHZ(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_ENABLE_CLK_500MHZ) | BF_CCM_ANALOG_PLL_ENET_ENABLE_CLK_500MHZ(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field PLL_ENET_OVERRIDE[13] (RW)
 *
 * The OVERRIDE bit allows the clock control module to automatically override
 * portions of the register.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_PLL_ENET_OVERRIDE (13U) /*!< Bit position for CCM_ANALOG_PLL_ENET_PLL_ENET_OVERRIDE. */
#define BM_CCM_ANALOG_PLL_ENET_PLL_ENET_OVERRIDE (0x00002000U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_PLL_ENET_OVERRIDE. */
#define BS_CCM_ANALOG_PLL_ENET_PLL_ENET_OVERRIDE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_PLL_ENET_OVERRIDE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_PLL_ENET_OVERRIDE field. */
#define BR_CCM_ANALOG_PLL_ENET_PLL_ENET_OVERRIDE(x) (HW_CCM_ANALOG_PLL_ENET(x).B.PLL_ENET_OVERRIDE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_PLL_ENET_OVERRIDE. */
#define BF_CCM_ANALOG_PLL_ENET_PLL_ENET_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_PLL_ENET_OVERRIDE) & BM_CCM_ANALOG_PLL_ENET_PLL_ENET_OVERRIDE)

/*! @brief Set the PLL_ENET_OVERRIDE field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_PLL_ENET_OVERRIDE(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_PLL_ENET_OVERRIDE) | BF_CCM_ANALOG_PLL_ENET_PLL_ENET_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field BYPASS_CLK_SRC[15:14] (RW)
 *
 * Determines the bypass source.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC (14U) /*!< Bit position for CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC. */
#define BM_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC (0x0000C000U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC. */
#define BS_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC field. */
#define BR_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC(x) (HW_CCM_ANALOG_PLL_ENET(x).B.BYPASS_CLK_SRC)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC. */
#define BF_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC) & BM_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC)

/*! @brief Set the BYPASS_CLK_SRC field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC) | BF_CCM_ANALOG_PLL_ENET_BYPASS_CLK_SRC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field BYPASS[16] (RW)
 *
 * Bypass the pll.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_BYPASS (16U) /*!< Bit position for CCM_ANALOG_PLL_ENET_BYPASS. */
#define BM_CCM_ANALOG_PLL_ENET_BYPASS (0x00010000U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_BYPASS. */
#define BS_CCM_ANALOG_PLL_ENET_BYPASS (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_BYPASS. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_BYPASS field. */
#define BR_CCM_ANALOG_PLL_ENET_BYPASS(x) (HW_CCM_ANALOG_PLL_ENET(x).B.BYPASS)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_BYPASS. */
#define BF_CCM_ANALOG_PLL_ENET_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_BYPASS) & BM_CCM_ANALOG_PLL_ENET_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_BYPASS(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_BYPASS) | BF_CCM_ANALOG_PLL_ENET_BYPASS(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field DITHER_ENABLE[17] (RW)
 *
 * Enables dither in the fractional modulator calculation.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_DITHER_ENABLE (17U) /*!< Bit position for CCM_ANALOG_PLL_ENET_DITHER_ENABLE. */
#define BM_CCM_ANALOG_PLL_ENET_DITHER_ENABLE (0x00020000U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_DITHER_ENABLE. */
#define BS_CCM_ANALOG_PLL_ENET_DITHER_ENABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_DITHER_ENABLE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_DITHER_ENABLE field. */
#define BR_CCM_ANALOG_PLL_ENET_DITHER_ENABLE(x) (HW_CCM_ANALOG_PLL_ENET(x).B.DITHER_ENABLE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_DITHER_ENABLE. */
#define BF_CCM_ANALOG_PLL_ENET_DITHER_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_DITHER_ENABLE) & BM_CCM_ANALOG_PLL_ENET_DITHER_ENABLE)

/*! @brief Set the DITHER_ENABLE field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_DITHER_ENABLE(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_DITHER_ENABLE) | BF_CCM_ANALOG_PLL_ENET_DITHER_ENABLE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field PFD_OFFSET_EN[18] (RW)
 *
 * Enables an offset in the phase frequency detector.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN (18U) /*!< Bit position for CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN. */
#define BM_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN (0x00040000U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN. */
#define BS_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN field. */
#define BR_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN(x) (HW_CCM_ANALOG_PLL_ENET(x).B.PFD_OFFSET_EN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN. */
#define BF_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN) & BM_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN)

/*! @brief Set the PFD_OFFSET_EN field to a new value. */
#define BW_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN(x, v) (HW_CCM_ANALOG_PLL_ENET_WR(x, (HW_CCM_ANALOG_PLL_ENET_RD(x) & ~BM_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN) | BF_CCM_ANALOG_PLL_ENET_PFD_OFFSET_EN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field RSVD1[30:19] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_RSVD1 (19U) /*!< Bit position for CCM_ANALOG_PLL_ENET_RSVD1. */
#define BM_CCM_ANALOG_PLL_ENET_RSVD1 (0x7FF80000U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_RSVD1. */
#define BS_CCM_ANALOG_PLL_ENET_RSVD1 (12U) /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_RSVD1. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_RSVD1 field. */
#define BR_CCM_ANALOG_PLL_ENET_RSVD1(x) (HW_CCM_ANALOG_PLL_ENET(x).B.RSVD1)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_ENET, field LOCK[31] (RO)
 *
 * 1 - PLL is currently locked; 0 - PLL is not currently locked.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_ENET_LOCK (31U)  /*!< Bit position for CCM_ANALOG_PLL_ENET_LOCK. */
#define BM_CCM_ANALOG_PLL_ENET_LOCK (0x80000000U) /*!< Bit mask for CCM_ANALOG_PLL_ENET_LOCK. */
#define BS_CCM_ANALOG_PLL_ENET_LOCK (1U)   /*!< Bit field size in bits for CCM_ANALOG_PLL_ENET_LOCK. */

/*! @brief Read current value of the CCM_ANALOG_PLL_ENET_LOCK field. */
#define BR_CCM_ANALOG_PLL_ENET_LOCK(x) (HW_CCM_ANALOG_PLL_ENET(x).B.LOCK)
/*@}*/




/*******************************************************************************
 * HW_CCM_ANALOG_PLL_AUDIO - Anadig Audio PLL control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_AUDIO - Anadig Audio PLL control Register (RW)
 *
 * Reset value: 0x0001301BU
 *
 * The control register provides control for the Audio PLL.
 */
typedef union _hw_ccm_analog_pll_audio
{
    uint32_t U;
    struct _hw_ccm_analog_pll_audio_bitfields
    {
        uint32_t DIV_SELECT : 7;       /*!< [6:0]  */
        uint32_t HALF_LF : 1;          /*!< [7]  */
        uint32_t DOUBLE_LF : 1;        /*!< [8]  */
        uint32_t HALF_CP : 1;          /*!< [9]  */
        uint32_t DOUBLE_CP : 1;        /*!< [10]  */
        uint32_t HOLD_RING_OFF : 1;    /*!< [11]  */
        uint32_t POWERDOWN : 1;        /*!< [12]  */
        uint32_t ENABLE_CLK : 1;       /*!< [13]  */
        uint32_t BYPASS_CLK_SRC : 2;   /*!< [15:14]  */
        uint32_t BYPASS : 1;           /*!< [16]  */
        uint32_t DITHER_ENABLE : 1;    /*!< [17]  */
        uint32_t PFD_OFFSET_EN : 1;    /*!< [18]  */
        uint32_t TEST_DIV_SELECT : 2;  /*!< [20:19]  */
        uint32_t RSVD0 : 1;            /*!< [21]  */
        uint32_t POST_DIV_SEL : 2;     /*!< [23:22]  */
        uint32_t PLL_AUDIO_OVERRIDE : 1; /*!< [24]  */
        uint32_t RSVD1 : 6;            /*!< [30:25]  */
        uint32_t LOCK : 1;             /*!< [31]  */
    } B;
} hw_ccm_analog_pll_audio_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_AUDIO register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_AUDIO_ADDR(x) ((uintptr_t)(x) + 0xF0U)
#define HW_CCM_ANALOG_PLL_AUDIO_SET_ADDR(x) (HW_CCM_ANALOG_PLL_AUDIO_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_PLL_AUDIO_CLR_ADDR(x) (HW_CCM_ANALOG_PLL_AUDIO_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_PLL_AUDIO_TOG_ADDR(x) (HW_CCM_ANALOG_PLL_AUDIO_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_PLL_AUDIO(x) (*(__IO hw_ccm_analog_pll_audio_t *) HW_CCM_ANALOG_PLL_AUDIO_ADDR(x))
#define HW_CCM_ANALOG_PLL_AUDIO_RD(x) (HW_CCM_ANALOG_PLL_AUDIO(x).U)
#define HW_CCM_ANALOG_PLL_AUDIO_WR(x, v) (HW_CCM_ANALOG_PLL_AUDIO(x).U = (v))
#define HW_CCM_ANALOG_PLL_AUDIO_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_AUDIO_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_AUDIO_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_AUDIO_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_AUDIO_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_AUDIO_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_AUDIO bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field DIV_SELECT[6:0] (RW)
 *
 * This field controls the pll loop divider. Valid range for DIV_SELECT divider
 * value: 27-54 decimal.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_DIV_SELECT (0U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_DIV_SELECT. */
#define BM_CCM_ANALOG_PLL_AUDIO_DIV_SELECT (0x0000007FU) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_DIV_SELECT. */
#define BS_CCM_ANALOG_PLL_AUDIO_DIV_SELECT (7U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_DIV_SELECT. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_DIV_SELECT field. */
#define BR_CCM_ANALOG_PLL_AUDIO_DIV_SELECT(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.DIV_SELECT)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_DIV_SELECT. */
#define BF_CCM_ANALOG_PLL_AUDIO_DIV_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_DIV_SELECT) & BM_CCM_ANALOG_PLL_AUDIO_DIV_SELECT)

/*! @brief Set the DIV_SELECT field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_DIV_SELECT(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_DIV_SELECT) | BF_CCM_ANALOG_PLL_AUDIO_DIV_SELECT(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field HALF_LF[7] (RW)
 *
 * Reduces the frequency of the loop filter 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_HALF_LF (7U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_HALF_LF. */
#define BM_CCM_ANALOG_PLL_AUDIO_HALF_LF (0x00000080U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_HALF_LF. */
#define BS_CCM_ANALOG_PLL_AUDIO_HALF_LF (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_HALF_LF. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_HALF_LF field. */
#define BR_CCM_ANALOG_PLL_AUDIO_HALF_LF(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.HALF_LF)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_HALF_LF. */
#define BF_CCM_ANALOG_PLL_AUDIO_HALF_LF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_HALF_LF) & BM_CCM_ANALOG_PLL_AUDIO_HALF_LF)

/*! @brief Set the HALF_LF field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_HALF_LF(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_HALF_LF) | BF_CCM_ANALOG_PLL_AUDIO_HALF_LF(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field DOUBLE_LF[8] (RW)
 *
 * Increases the frequency of the loop filter 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_DOUBLE_LF (8U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_DOUBLE_LF. */
#define BM_CCM_ANALOG_PLL_AUDIO_DOUBLE_LF (0x00000100U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_DOUBLE_LF. */
#define BS_CCM_ANALOG_PLL_AUDIO_DOUBLE_LF (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_DOUBLE_LF. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_DOUBLE_LF field. */
#define BR_CCM_ANALOG_PLL_AUDIO_DOUBLE_LF(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.DOUBLE_LF)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_DOUBLE_LF. */
#define BF_CCM_ANALOG_PLL_AUDIO_DOUBLE_LF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_DOUBLE_LF) & BM_CCM_ANALOG_PLL_AUDIO_DOUBLE_LF)

/*! @brief Set the DOUBLE_LF field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_DOUBLE_LF(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_DOUBLE_LF) | BF_CCM_ANALOG_PLL_AUDIO_DOUBLE_LF(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field HALF_CP[9] (RW)
 *
 * Reduces the charge pump gain 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_HALF_CP (9U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_HALF_CP. */
#define BM_CCM_ANALOG_PLL_AUDIO_HALF_CP (0x00000200U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_HALF_CP. */
#define BS_CCM_ANALOG_PLL_AUDIO_HALF_CP (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_HALF_CP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_HALF_CP field. */
#define BR_CCM_ANALOG_PLL_AUDIO_HALF_CP(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.HALF_CP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_HALF_CP. */
#define BF_CCM_ANALOG_PLL_AUDIO_HALF_CP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_HALF_CP) & BM_CCM_ANALOG_PLL_AUDIO_HALF_CP)

/*! @brief Set the HALF_CP field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_HALF_CP(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_HALF_CP) | BF_CCM_ANALOG_PLL_AUDIO_HALF_CP(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field DOUBLE_CP[10] (RW)
 *
 * Increases the charge pump gain 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_DOUBLE_CP (10U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_DOUBLE_CP. */
#define BM_CCM_ANALOG_PLL_AUDIO_DOUBLE_CP (0x00000400U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_DOUBLE_CP. */
#define BS_CCM_ANALOG_PLL_AUDIO_DOUBLE_CP (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_DOUBLE_CP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_DOUBLE_CP field. */
#define BR_CCM_ANALOG_PLL_AUDIO_DOUBLE_CP(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.DOUBLE_CP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_DOUBLE_CP. */
#define BF_CCM_ANALOG_PLL_AUDIO_DOUBLE_CP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_DOUBLE_CP) & BM_CCM_ANALOG_PLL_AUDIO_DOUBLE_CP)

/*! @brief Set the DOUBLE_CP field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_DOUBLE_CP(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_DOUBLE_CP) | BF_CCM_ANALOG_PLL_AUDIO_DOUBLE_CP(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field HOLD_RING_OFF[11] (RW)
 *
 * Status of ana_irq2 input from analog block.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_HOLD_RING_OFF (11U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_HOLD_RING_OFF. */
#define BM_CCM_ANALOG_PLL_AUDIO_HOLD_RING_OFF (0x00000800U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_HOLD_RING_OFF. */
#define BS_CCM_ANALOG_PLL_AUDIO_HOLD_RING_OFF (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_HOLD_RING_OFF. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_HOLD_RING_OFF field. */
#define BR_CCM_ANALOG_PLL_AUDIO_HOLD_RING_OFF(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.HOLD_RING_OFF)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_HOLD_RING_OFF. */
#define BF_CCM_ANALOG_PLL_AUDIO_HOLD_RING_OFF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_HOLD_RING_OFF) & BM_CCM_ANALOG_PLL_AUDIO_HOLD_RING_OFF)

/*! @brief Set the HOLD_RING_OFF field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_HOLD_RING_OFF(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_HOLD_RING_OFF) | BF_CCM_ANALOG_PLL_AUDIO_HOLD_RING_OFF(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field POWERDOWN[12] (RW)
 *
 * Powers down the PLL.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_POWERDOWN (12U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_POWERDOWN. */
#define BM_CCM_ANALOG_PLL_AUDIO_POWERDOWN (0x00001000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_POWERDOWN. */
#define BS_CCM_ANALOG_PLL_AUDIO_POWERDOWN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_POWERDOWN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_POWERDOWN field. */
#define BR_CCM_ANALOG_PLL_AUDIO_POWERDOWN(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.POWERDOWN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_POWERDOWN. */
#define BF_CCM_ANALOG_PLL_AUDIO_POWERDOWN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_POWERDOWN) & BM_CCM_ANALOG_PLL_AUDIO_POWERDOWN)

/*! @brief Set the POWERDOWN field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_POWERDOWN(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_POWERDOWN) | BF_CCM_ANALOG_PLL_AUDIO_POWERDOWN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field ENABLE_CLK[13] (RW)
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_ENABLE_CLK (13U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_ENABLE_CLK. */
#define BM_CCM_ANALOG_PLL_AUDIO_ENABLE_CLK (0x00002000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_ENABLE_CLK. */
#define BS_CCM_ANALOG_PLL_AUDIO_ENABLE_CLK (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_ENABLE_CLK. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_ENABLE_CLK field. */
#define BR_CCM_ANALOG_PLL_AUDIO_ENABLE_CLK(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.ENABLE_CLK)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_ENABLE_CLK. */
#define BF_CCM_ANALOG_PLL_AUDIO_ENABLE_CLK(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_ENABLE_CLK) & BM_CCM_ANALOG_PLL_AUDIO_ENABLE_CLK)

/*! @brief Set the ENABLE_CLK field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_ENABLE_CLK(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_ENABLE_CLK) | BF_CCM_ANALOG_PLL_AUDIO_ENABLE_CLK(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field BYPASS_CLK_SRC[15:14] (RW)
 *
 * Determines the bypass source.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC (14U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC. */
#define BM_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC (0x0000C000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC. */
#define BS_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC field. */
#define BR_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.BYPASS_CLK_SRC)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC. */
#define BF_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC) & BM_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC)

/*! @brief Set the BYPASS_CLK_SRC field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC) | BF_CCM_ANALOG_PLL_AUDIO_BYPASS_CLK_SRC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field BYPASS[16] (RW)
 *
 * Bypass the pll.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_BYPASS (16U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_BYPASS. */
#define BM_CCM_ANALOG_PLL_AUDIO_BYPASS (0x00010000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_BYPASS. */
#define BS_CCM_ANALOG_PLL_AUDIO_BYPASS (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_BYPASS. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_BYPASS field. */
#define BR_CCM_ANALOG_PLL_AUDIO_BYPASS(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.BYPASS)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_BYPASS. */
#define BF_CCM_ANALOG_PLL_AUDIO_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_BYPASS) & BM_CCM_ANALOG_PLL_AUDIO_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_BYPASS(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_BYPASS) | BF_CCM_ANALOG_PLL_AUDIO_BYPASS(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field DITHER_ENABLE[17] (RW)
 *
 * Enables dither in the fractional modulator calculation.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_DITHER_ENABLE (17U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_DITHER_ENABLE. */
#define BM_CCM_ANALOG_PLL_AUDIO_DITHER_ENABLE (0x00020000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_DITHER_ENABLE. */
#define BS_CCM_ANALOG_PLL_AUDIO_DITHER_ENABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_DITHER_ENABLE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_DITHER_ENABLE field. */
#define BR_CCM_ANALOG_PLL_AUDIO_DITHER_ENABLE(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.DITHER_ENABLE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_DITHER_ENABLE. */
#define BF_CCM_ANALOG_PLL_AUDIO_DITHER_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_DITHER_ENABLE) & BM_CCM_ANALOG_PLL_AUDIO_DITHER_ENABLE)

/*! @brief Set the DITHER_ENABLE field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_DITHER_ENABLE(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_DITHER_ENABLE) | BF_CCM_ANALOG_PLL_AUDIO_DITHER_ENABLE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field PFD_OFFSET_EN[18] (RW)
 *
 * Enables an offset in the phase frequency detector.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN (18U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN. */
#define BM_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN (0x00040000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN. */
#define BS_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN field. */
#define BR_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.PFD_OFFSET_EN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN. */
#define BF_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN) & BM_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN)

/*! @brief Set the PFD_OFFSET_EN field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN) | BF_CCM_ANALOG_PLL_AUDIO_PFD_OFFSET_EN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field TEST_DIV_SELECT[20:19] (RW)
 *
 * Control bits for the divider for the PLL clk and lvds outputs:
 * 0x0=div-by-4(default), 0x1=div-by-2, 0x2=div-by-1, 0x3=div-by-1. This divider is placed
 * before the post divider.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT (19U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT. */
#define BM_CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT (0x00180000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT. */
#define BS_CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT field. */
#define BR_CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.TEST_DIV_SELECT)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT. */
#define BF_CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT) & BM_CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT)

/*! @brief Set the TEST_DIV_SELECT field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT) | BF_CCM_ANALOG_PLL_AUDIO_TEST_DIV_SELECT(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field RSVD0[21] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_RSVD0 (21U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_RSVD0. */
#define BM_CCM_ANALOG_PLL_AUDIO_RSVD0 (0x00200000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_RSVD0. */
#define BS_CCM_ANALOG_PLL_AUDIO_RSVD0 (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_RSVD0. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_RSVD0 field. */
#define BR_CCM_ANALOG_PLL_AUDIO_RSVD0(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.RSVD0)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field POST_DIV_SEL[23:22] (RW)
 *
 * Post-divider for audio PLL: 0x0=div-by-1(default), 0x1=div-by-2,
 * 0x2=div-by-1, 0x3=div-by-4. The output clock of the audio PLL should be gated prior to
 * changing this divider to prevent glitches.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL (22U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL. */
#define BM_CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL (0x00C00000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL. */
#define BS_CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL field. */
#define BR_CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.POST_DIV_SEL)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL. */
#define BF_CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL) & BM_CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL)

/*! @brief Set the POST_DIV_SEL field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL) | BF_CCM_ANALOG_PLL_AUDIO_POST_DIV_SEL(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field PLL_AUDIO_OVERRIDE[24] (RW)
 *
 * The OVERRIDE bit allows the clock control module to automatically override
 * portions of the register.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_PLL_AUDIO_OVERRIDE (24U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_PLL_AUDIO_OVERRIDE. */
#define BM_CCM_ANALOG_PLL_AUDIO_PLL_AUDIO_OVERRIDE (0x01000000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_PLL_AUDIO_OVERRIDE. */
#define BS_CCM_ANALOG_PLL_AUDIO_PLL_AUDIO_OVERRIDE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_PLL_AUDIO_OVERRIDE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_PLL_AUDIO_OVERRIDE field. */
#define BR_CCM_ANALOG_PLL_AUDIO_PLL_AUDIO_OVERRIDE(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.PLL_AUDIO_OVERRIDE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_PLL_AUDIO_OVERRIDE. */
#define BF_CCM_ANALOG_PLL_AUDIO_PLL_AUDIO_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_PLL_AUDIO_OVERRIDE) & BM_CCM_ANALOG_PLL_AUDIO_PLL_AUDIO_OVERRIDE)

/*! @brief Set the PLL_AUDIO_OVERRIDE field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_PLL_AUDIO_OVERRIDE(x, v) (HW_CCM_ANALOG_PLL_AUDIO_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_PLL_AUDIO_OVERRIDE) | BF_CCM_ANALOG_PLL_AUDIO_PLL_AUDIO_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field RSVD1[30:25] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_RSVD1 (25U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_RSVD1. */
#define BM_CCM_ANALOG_PLL_AUDIO_RSVD1 (0x7E000000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_RSVD1. */
#define BS_CCM_ANALOG_PLL_AUDIO_RSVD1 (6U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_RSVD1. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_RSVD1 field. */
#define BR_CCM_ANALOG_PLL_AUDIO_RSVD1(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.RSVD1)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO, field LOCK[31] (RO)
 *
 * 1 - PLL is currently locked; 0 - PLL is not currently locked.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_LOCK (31U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_LOCK. */
#define BM_CCM_ANALOG_PLL_AUDIO_LOCK (0x80000000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_LOCK. */
#define BS_CCM_ANALOG_PLL_AUDIO_LOCK (1U)  /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_LOCK. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_LOCK field. */
#define BR_CCM_ANALOG_PLL_AUDIO_LOCK(x) (HW_CCM_ANALOG_PLL_AUDIO(x).B.LOCK)
/*@}*/




/*******************************************************************************
 * HW_CCM_ANALOG_PLL_AUDIO_SS - Audio PLL Spread Spectrum Register.
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_AUDIO_SS - Audio PLL Spread Spectrum Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the Audio PLL spread spectrum controls.
 */
typedef union _hw_ccm_analog_pll_audio_ss
{
    uint32_t U;
    struct _hw_ccm_analog_pll_audio_ss_bitfields
    {
        uint32_t STEP : 15;            /*!< [14:0]  */
        uint32_t ENABLE : 1;           /*!< [15]  */
        uint32_t STOP : 16;            /*!< [31:16]  */
    } B;
} hw_ccm_analog_pll_audio_ss_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_AUDIO_SS register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_AUDIO_SS_ADDR(x) ((uintptr_t)(x) + 0x100U)

#define HW_CCM_ANALOG_PLL_AUDIO_SS(x) (*(__IO hw_ccm_analog_pll_audio_ss_t *) HW_CCM_ANALOG_PLL_AUDIO_SS_ADDR(x))
#define HW_CCM_ANALOG_PLL_AUDIO_SS_RD(x) (HW_CCM_ANALOG_PLL_AUDIO_SS(x).U)
#define HW_CCM_ANALOG_PLL_AUDIO_SS_WR(x, v) (HW_CCM_ANALOG_PLL_AUDIO_SS(x).U = (v))
#define HW_CCM_ANALOG_PLL_AUDIO_SS_SET(x, v) (HW_CCM_ANALOG_PLL_AUDIO_SS_WR(x, HW_CCM_ANALOG_PLL_AUDIO_SS_RD(x) |  (v)))
#define HW_CCM_ANALOG_PLL_AUDIO_SS_CLR(x, v) (HW_CCM_ANALOG_PLL_AUDIO_SS_WR(x, HW_CCM_ANALOG_PLL_AUDIO_SS_RD(x) & ~(v)))
#define HW_CCM_ANALOG_PLL_AUDIO_SS_TOG(x, v) (HW_CCM_ANALOG_PLL_AUDIO_SS_WR(x, HW_CCM_ANALOG_PLL_AUDIO_SS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_AUDIO_SS bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO_SS, field STEP[14:0] (RW)
 *
 * The max frequency change = stop/B*24MHz.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_SS_STEP (0U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_SS_STEP. */
#define BM_CCM_ANALOG_PLL_AUDIO_SS_STEP (0x00007FFFU) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_SS_STEP. */
#define BS_CCM_ANALOG_PLL_AUDIO_SS_STEP (15U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_SS_STEP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_SS_STEP field. */
#define BR_CCM_ANALOG_PLL_AUDIO_SS_STEP(x) (HW_CCM_ANALOG_PLL_AUDIO_SS(x).B.STEP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_SS_STEP. */
#define BF_CCM_ANALOG_PLL_AUDIO_SS_STEP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_SS_STEP) & BM_CCM_ANALOG_PLL_AUDIO_SS_STEP)

/*! @brief Set the STEP field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_SS_STEP(x, v) (HW_CCM_ANALOG_PLL_AUDIO_SS_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_SS_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_SS_STEP) | BF_CCM_ANALOG_PLL_AUDIO_SS_STEP(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO_SS, field ENABLE[15] (RW)
 *
 * This bit enables the spread spectrum modulation.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_SS_ENABLE (15U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_SS_ENABLE. */
#define BM_CCM_ANALOG_PLL_AUDIO_SS_ENABLE (0x00008000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_SS_ENABLE. */
#define BS_CCM_ANALOG_PLL_AUDIO_SS_ENABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_SS_ENABLE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_SS_ENABLE field. */
#define BR_CCM_ANALOG_PLL_AUDIO_SS_ENABLE(x) (HW_CCM_ANALOG_PLL_AUDIO_SS(x).B.ENABLE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_SS_ENABLE. */
#define BF_CCM_ANALOG_PLL_AUDIO_SS_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_SS_ENABLE) & BM_CCM_ANALOG_PLL_AUDIO_SS_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_SS_ENABLE(x, v) (HW_CCM_ANALOG_PLL_AUDIO_SS_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_SS_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_SS_ENABLE) | BF_CCM_ANALOG_PLL_AUDIO_SS_ENABLE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO_SS, field STOP[31:16] (RW)
 *
 * Frequency change = step/B*24MHz.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_SS_STOP (16U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_SS_STOP. */
#define BM_CCM_ANALOG_PLL_AUDIO_SS_STOP (0xFFFF0000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_SS_STOP. */
#define BS_CCM_ANALOG_PLL_AUDIO_SS_STOP (16U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_SS_STOP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_SS_STOP field. */
#define BR_CCM_ANALOG_PLL_AUDIO_SS_STOP(x) (HW_CCM_ANALOG_PLL_AUDIO_SS(x).B.STOP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_SS_STOP. */
#define BF_CCM_ANALOG_PLL_AUDIO_SS_STOP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_SS_STOP) & BM_CCM_ANALOG_PLL_AUDIO_SS_STOP)

/*! @brief Set the STOP field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_SS_STOP(x, v) (HW_CCM_ANALOG_PLL_AUDIO_SS_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_SS_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_SS_STOP) | BF_CCM_ANALOG_PLL_AUDIO_SS_STOP(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_ANALOG_PLL_AUDIO_NUM - Numerator of Audio PLL Fractional Loop Divider Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_AUDIO_NUM - Numerator of Audio PLL Fractional Loop Divider Register (RW)
 *
 * Reset value: 0x05F5E100U
 *
 * This register contains the numerator (A) of Audio PLL fractional loop divider.
 */
typedef union _hw_ccm_analog_pll_audio_num
{
    uint32_t U;
    struct _hw_ccm_analog_pll_audio_num_bitfields
    {
        uint32_t A : 30;               /*!< [29:0]  */
        uint32_t RSVD0 : 2;            /*!< [31:30]  */
    } B;
} hw_ccm_analog_pll_audio_num_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_AUDIO_NUM register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_AUDIO_NUM_ADDR(x) ((uintptr_t)(x) + 0x110U)

#define HW_CCM_ANALOG_PLL_AUDIO_NUM(x) (*(__IO hw_ccm_analog_pll_audio_num_t *) HW_CCM_ANALOG_PLL_AUDIO_NUM_ADDR(x))
#define HW_CCM_ANALOG_PLL_AUDIO_NUM_RD(x) (HW_CCM_ANALOG_PLL_AUDIO_NUM(x).U)
#define HW_CCM_ANALOG_PLL_AUDIO_NUM_WR(x, v) (HW_CCM_ANALOG_PLL_AUDIO_NUM(x).U = (v))
#define HW_CCM_ANALOG_PLL_AUDIO_NUM_SET(x, v) (HW_CCM_ANALOG_PLL_AUDIO_NUM_WR(x, HW_CCM_ANALOG_PLL_AUDIO_NUM_RD(x) |  (v)))
#define HW_CCM_ANALOG_PLL_AUDIO_NUM_CLR(x, v) (HW_CCM_ANALOG_PLL_AUDIO_NUM_WR(x, HW_CCM_ANALOG_PLL_AUDIO_NUM_RD(x) & ~(v)))
#define HW_CCM_ANALOG_PLL_AUDIO_NUM_TOG(x, v) (HW_CCM_ANALOG_PLL_AUDIO_NUM_WR(x, HW_CCM_ANALOG_PLL_AUDIO_NUM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_AUDIO_NUM bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO_NUM, field A[29:0] (RW)
 *
 * 30 bit numerator of fractional loop divider.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_NUM_A (0U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_NUM_A. */
#define BM_CCM_ANALOG_PLL_AUDIO_NUM_A (0x3FFFFFFFU) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_NUM_A. */
#define BS_CCM_ANALOG_PLL_AUDIO_NUM_A (30U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_NUM_A. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_NUM_A field. */
#define BR_CCM_ANALOG_PLL_AUDIO_NUM_A(x) (HW_CCM_ANALOG_PLL_AUDIO_NUM(x).B.A)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_NUM_A. */
#define BF_CCM_ANALOG_PLL_AUDIO_NUM_A(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_NUM_A) & BM_CCM_ANALOG_PLL_AUDIO_NUM_A)

/*! @brief Set the A field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_NUM_A(x, v) (HW_CCM_ANALOG_PLL_AUDIO_NUM_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_NUM_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_NUM_A) | BF_CCM_ANALOG_PLL_AUDIO_NUM_A(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO_NUM, field RSVD0[31:30] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_NUM_RSVD0 (30U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_NUM_RSVD0. */
#define BM_CCM_ANALOG_PLL_AUDIO_NUM_RSVD0 (0xC0000000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_NUM_RSVD0. */
#define BS_CCM_ANALOG_PLL_AUDIO_NUM_RSVD0 (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_NUM_RSVD0. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_NUM_RSVD0 field. */
#define BR_CCM_ANALOG_PLL_AUDIO_NUM_RSVD0(x) (HW_CCM_ANALOG_PLL_AUDIO_NUM(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_CCM_ANALOG_PLL_AUDIO_DENOM - Denominator of Audio PLL Fractional Loop Divider Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_AUDIO_DENOM - Denominator of Audio PLL Fractional Loop Divider Register (RW)
 *
 * Reset value: 0x2964619CU
 *
 * This register contains the Denominator (B) of Audio PLL fractional loop
 * divider.
 */
typedef union _hw_ccm_analog_pll_audio_denom
{
    uint32_t U;
    struct _hw_ccm_analog_pll_audio_denom_bitfields
    {
        uint32_t B : 30;               /*!< [29:0]  */
        uint32_t RSVD0 : 2;            /*!< [31:30]  */
    } B;
} hw_ccm_analog_pll_audio_denom_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_AUDIO_DENOM register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_AUDIO_DENOM_ADDR(x) ((uintptr_t)(x) + 0x120U)

#define HW_CCM_ANALOG_PLL_AUDIO_DENOM(x) (*(__IO hw_ccm_analog_pll_audio_denom_t *) HW_CCM_ANALOG_PLL_AUDIO_DENOM_ADDR(x))
#define HW_CCM_ANALOG_PLL_AUDIO_DENOM_RD(x) (HW_CCM_ANALOG_PLL_AUDIO_DENOM(x).U)
#define HW_CCM_ANALOG_PLL_AUDIO_DENOM_WR(x, v) (HW_CCM_ANALOG_PLL_AUDIO_DENOM(x).U = (v))
#define HW_CCM_ANALOG_PLL_AUDIO_DENOM_SET(x, v) (HW_CCM_ANALOG_PLL_AUDIO_DENOM_WR(x, HW_CCM_ANALOG_PLL_AUDIO_DENOM_RD(x) |  (v)))
#define HW_CCM_ANALOG_PLL_AUDIO_DENOM_CLR(x, v) (HW_CCM_ANALOG_PLL_AUDIO_DENOM_WR(x, HW_CCM_ANALOG_PLL_AUDIO_DENOM_RD(x) & ~(v)))
#define HW_CCM_ANALOG_PLL_AUDIO_DENOM_TOG(x, v) (HW_CCM_ANALOG_PLL_AUDIO_DENOM_WR(x, HW_CCM_ANALOG_PLL_AUDIO_DENOM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_AUDIO_DENOM bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO_DENOM, field B[29:0] (RW)
 *
 * 30 bit Denominator of fractional loop divider.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_DENOM_B (0U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_DENOM_B. */
#define BM_CCM_ANALOG_PLL_AUDIO_DENOM_B (0x3FFFFFFFU) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_DENOM_B. */
#define BS_CCM_ANALOG_PLL_AUDIO_DENOM_B (30U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_DENOM_B. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_DENOM_B field. */
#define BR_CCM_ANALOG_PLL_AUDIO_DENOM_B(x) (HW_CCM_ANALOG_PLL_AUDIO_DENOM(x).B.B)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_AUDIO_DENOM_B. */
#define BF_CCM_ANALOG_PLL_AUDIO_DENOM_B(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_AUDIO_DENOM_B) & BM_CCM_ANALOG_PLL_AUDIO_DENOM_B)

/*! @brief Set the B field to a new value. */
#define BW_CCM_ANALOG_PLL_AUDIO_DENOM_B(x, v) (HW_CCM_ANALOG_PLL_AUDIO_DENOM_WR(x, (HW_CCM_ANALOG_PLL_AUDIO_DENOM_RD(x) & ~BM_CCM_ANALOG_PLL_AUDIO_DENOM_B) | BF_CCM_ANALOG_PLL_AUDIO_DENOM_B(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_AUDIO_DENOM, field RSVD0[31:30] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_AUDIO_DENOM_RSVD0 (30U) /*!< Bit position for CCM_ANALOG_PLL_AUDIO_DENOM_RSVD0. */
#define BM_CCM_ANALOG_PLL_AUDIO_DENOM_RSVD0 (0xC0000000U) /*!< Bit mask for CCM_ANALOG_PLL_AUDIO_DENOM_RSVD0. */
#define BS_CCM_ANALOG_PLL_AUDIO_DENOM_RSVD0 (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_AUDIO_DENOM_RSVD0. */

/*! @brief Read current value of the CCM_ANALOG_PLL_AUDIO_DENOM_RSVD0 field. */
#define BR_CCM_ANALOG_PLL_AUDIO_DENOM_RSVD0(x) (HW_CCM_ANALOG_PLL_AUDIO_DENOM(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_CCM_ANALOG_PLL_VIDEO - Anadig Video PLL control Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_VIDEO - Anadig Video PLL control Register (RW)
 *
 * Reset value: 0x0001301BU
 *
 * The control register provides control for the Video PLL.
 */
typedef union _hw_ccm_analog_pll_video
{
    uint32_t U;
    struct _hw_ccm_analog_pll_video_bitfields
    {
        uint32_t DIV_SELECT : 7;       /*!< [6:0]  */
        uint32_t HALF_LF : 1;          /*!< [7]  */
        uint32_t DOUBLE_LF : 1;        /*!< [8]  */
        uint32_t HALF_CP : 1;          /*!< [9]  */
        uint32_t DOUBLE_CP : 1;        /*!< [10]  */
        uint32_t HOLD_RING_OFF : 1;    /*!< [11]  */
        uint32_t POWERDOWN : 1;        /*!< [12]  */
        uint32_t ENABLE_CLK : 1;       /*!< [13]  */
        uint32_t BYPASS_CLK_SRC : 2;   /*!< [15:14]  */
        uint32_t BYPASS : 1;           /*!< [16]  */
        uint32_t DITHER_ENABLE : 1;    /*!< [17]  */
        uint32_t PFD_OFFSET_EN : 1;    /*!< [18]  */
        uint32_t TEST_DIV_SELECT : 2;  /*!< [20:19]  */
        uint32_t RSVD0 : 1;            /*!< [21]  */
        uint32_t POST_DIV_SEL : 2;     /*!< [23:22]  */
        uint32_t PLL_VIDEO_OVERRIDE : 1; /*!< [24]  */
        uint32_t RSVD1 : 6;            /*!< [30:25]  */
        uint32_t LOCK : 1;             /*!< [31]  */
    } B;
} hw_ccm_analog_pll_video_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_VIDEO register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_VIDEO_ADDR(x) ((uintptr_t)(x) + 0x130U)
#define HW_CCM_ANALOG_PLL_VIDEO_SET_ADDR(x) (HW_CCM_ANALOG_PLL_VIDEO_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_PLL_VIDEO_CLR_ADDR(x) (HW_CCM_ANALOG_PLL_VIDEO_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_PLL_VIDEO_TOG_ADDR(x) (HW_CCM_ANALOG_PLL_VIDEO_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_PLL_VIDEO(x) (*(__IO hw_ccm_analog_pll_video_t *) HW_CCM_ANALOG_PLL_VIDEO_ADDR(x))
#define HW_CCM_ANALOG_PLL_VIDEO_RD(x) (HW_CCM_ANALOG_PLL_VIDEO(x).U)
#define HW_CCM_ANALOG_PLL_VIDEO_WR(x, v) (HW_CCM_ANALOG_PLL_VIDEO(x).U = (v))
#define HW_CCM_ANALOG_PLL_VIDEO_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_VIDEO_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_VIDEO_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_VIDEO_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_PLL_VIDEO_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_PLL_VIDEO_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_VIDEO bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field DIV_SELECT[6:0] (RW)
 *
 * This field controls the pll loop divider. Valid range for DIV_SELECT divider
 * value: 27-54 decimal.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_DIV_SELECT (0U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_DIV_SELECT. */
#define BM_CCM_ANALOG_PLL_VIDEO_DIV_SELECT (0x0000007FU) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_DIV_SELECT. */
#define BS_CCM_ANALOG_PLL_VIDEO_DIV_SELECT (7U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_DIV_SELECT. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_DIV_SELECT field. */
#define BR_CCM_ANALOG_PLL_VIDEO_DIV_SELECT(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.DIV_SELECT)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_DIV_SELECT. */
#define BF_CCM_ANALOG_PLL_VIDEO_DIV_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_DIV_SELECT) & BM_CCM_ANALOG_PLL_VIDEO_DIV_SELECT)

/*! @brief Set the DIV_SELECT field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_DIV_SELECT(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_DIV_SELECT) | BF_CCM_ANALOG_PLL_VIDEO_DIV_SELECT(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field HALF_LF[7] (RW)
 *
 * Reduces the frequency of the loop filter 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_HALF_LF (7U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_HALF_LF. */
#define BM_CCM_ANALOG_PLL_VIDEO_HALF_LF (0x00000080U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_HALF_LF. */
#define BS_CCM_ANALOG_PLL_VIDEO_HALF_LF (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_HALF_LF. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_HALF_LF field. */
#define BR_CCM_ANALOG_PLL_VIDEO_HALF_LF(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.HALF_LF)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_HALF_LF. */
#define BF_CCM_ANALOG_PLL_VIDEO_HALF_LF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_HALF_LF) & BM_CCM_ANALOG_PLL_VIDEO_HALF_LF)

/*! @brief Set the HALF_LF field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_HALF_LF(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_HALF_LF) | BF_CCM_ANALOG_PLL_VIDEO_HALF_LF(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field DOUBLE_LF[8] (RW)
 *
 * Increases the frequency of the loop filter 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_DOUBLE_LF (8U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_DOUBLE_LF. */
#define BM_CCM_ANALOG_PLL_VIDEO_DOUBLE_LF (0x00000100U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_DOUBLE_LF. */
#define BS_CCM_ANALOG_PLL_VIDEO_DOUBLE_LF (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_DOUBLE_LF. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_DOUBLE_LF field. */
#define BR_CCM_ANALOG_PLL_VIDEO_DOUBLE_LF(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.DOUBLE_LF)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_DOUBLE_LF. */
#define BF_CCM_ANALOG_PLL_VIDEO_DOUBLE_LF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_DOUBLE_LF) & BM_CCM_ANALOG_PLL_VIDEO_DOUBLE_LF)

/*! @brief Set the DOUBLE_LF field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_DOUBLE_LF(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_DOUBLE_LF) | BF_CCM_ANALOG_PLL_VIDEO_DOUBLE_LF(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field HALF_CP[9] (RW)
 *
 * Reduces the charge pump gain 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_HALF_CP (9U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_HALF_CP. */
#define BM_CCM_ANALOG_PLL_VIDEO_HALF_CP (0x00000200U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_HALF_CP. */
#define BS_CCM_ANALOG_PLL_VIDEO_HALF_CP (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_HALF_CP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_HALF_CP field. */
#define BR_CCM_ANALOG_PLL_VIDEO_HALF_CP(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.HALF_CP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_HALF_CP. */
#define BF_CCM_ANALOG_PLL_VIDEO_HALF_CP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_HALF_CP) & BM_CCM_ANALOG_PLL_VIDEO_HALF_CP)

/*! @brief Set the HALF_CP field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_HALF_CP(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_HALF_CP) | BF_CCM_ANALOG_PLL_VIDEO_HALF_CP(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field DOUBLE_CP[10] (RW)
 *
 * Increases the charge pump gain 2x.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_DOUBLE_CP (10U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_DOUBLE_CP. */
#define BM_CCM_ANALOG_PLL_VIDEO_DOUBLE_CP (0x00000400U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_DOUBLE_CP. */
#define BS_CCM_ANALOG_PLL_VIDEO_DOUBLE_CP (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_DOUBLE_CP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_DOUBLE_CP field. */
#define BR_CCM_ANALOG_PLL_VIDEO_DOUBLE_CP(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.DOUBLE_CP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_DOUBLE_CP. */
#define BF_CCM_ANALOG_PLL_VIDEO_DOUBLE_CP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_DOUBLE_CP) & BM_CCM_ANALOG_PLL_VIDEO_DOUBLE_CP)

/*! @brief Set the DOUBLE_CP field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_DOUBLE_CP(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_DOUBLE_CP) | BF_CCM_ANALOG_PLL_VIDEO_DOUBLE_CP(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field HOLD_RING_OFF[11] (RW)
 *
 * Status of ana_irq2 input from analog block.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_HOLD_RING_OFF (11U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_HOLD_RING_OFF. */
#define BM_CCM_ANALOG_PLL_VIDEO_HOLD_RING_OFF (0x00000800U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_HOLD_RING_OFF. */
#define BS_CCM_ANALOG_PLL_VIDEO_HOLD_RING_OFF (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_HOLD_RING_OFF. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_HOLD_RING_OFF field. */
#define BR_CCM_ANALOG_PLL_VIDEO_HOLD_RING_OFF(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.HOLD_RING_OFF)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_HOLD_RING_OFF. */
#define BF_CCM_ANALOG_PLL_VIDEO_HOLD_RING_OFF(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_HOLD_RING_OFF) & BM_CCM_ANALOG_PLL_VIDEO_HOLD_RING_OFF)

/*! @brief Set the HOLD_RING_OFF field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_HOLD_RING_OFF(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_HOLD_RING_OFF) | BF_CCM_ANALOG_PLL_VIDEO_HOLD_RING_OFF(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field POWERDOWN[12] (RW)
 *
 * Powers down the PLL.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_POWERDOWN (12U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_POWERDOWN. */
#define BM_CCM_ANALOG_PLL_VIDEO_POWERDOWN (0x00001000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_POWERDOWN. */
#define BS_CCM_ANALOG_PLL_VIDEO_POWERDOWN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_POWERDOWN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_POWERDOWN field. */
#define BR_CCM_ANALOG_PLL_VIDEO_POWERDOWN(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.POWERDOWN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_POWERDOWN. */
#define BF_CCM_ANALOG_PLL_VIDEO_POWERDOWN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_POWERDOWN) & BM_CCM_ANALOG_PLL_VIDEO_POWERDOWN)

/*! @brief Set the POWERDOWN field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_POWERDOWN(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_POWERDOWN) | BF_CCM_ANALOG_PLL_VIDEO_POWERDOWN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field ENABLE_CLK[13] (RW)
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_ENABLE_CLK (13U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_ENABLE_CLK. */
#define BM_CCM_ANALOG_PLL_VIDEO_ENABLE_CLK (0x00002000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_ENABLE_CLK. */
#define BS_CCM_ANALOG_PLL_VIDEO_ENABLE_CLK (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_ENABLE_CLK. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_ENABLE_CLK field. */
#define BR_CCM_ANALOG_PLL_VIDEO_ENABLE_CLK(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.ENABLE_CLK)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_ENABLE_CLK. */
#define BF_CCM_ANALOG_PLL_VIDEO_ENABLE_CLK(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_ENABLE_CLK) & BM_CCM_ANALOG_PLL_VIDEO_ENABLE_CLK)

/*! @brief Set the ENABLE_CLK field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_ENABLE_CLK(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_ENABLE_CLK) | BF_CCM_ANALOG_PLL_VIDEO_ENABLE_CLK(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field BYPASS_CLK_SRC[15:14] (RW)
 *
 * Determines the bypass source.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC (14U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC. */
#define BM_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC (0x0000C000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC. */
#define BS_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC field. */
#define BR_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.BYPASS_CLK_SRC)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC. */
#define BF_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC) & BM_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC)

/*! @brief Set the BYPASS_CLK_SRC field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC) | BF_CCM_ANALOG_PLL_VIDEO_BYPASS_CLK_SRC(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field BYPASS[16] (RW)
 *
 * Bypass the pll.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_BYPASS (16U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_BYPASS. */
#define BM_CCM_ANALOG_PLL_VIDEO_BYPASS (0x00010000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_BYPASS. */
#define BS_CCM_ANALOG_PLL_VIDEO_BYPASS (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_BYPASS. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_BYPASS field. */
#define BR_CCM_ANALOG_PLL_VIDEO_BYPASS(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.BYPASS)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_BYPASS. */
#define BF_CCM_ANALOG_PLL_VIDEO_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_BYPASS) & BM_CCM_ANALOG_PLL_VIDEO_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_BYPASS(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_BYPASS) | BF_CCM_ANALOG_PLL_VIDEO_BYPASS(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field DITHER_ENABLE[17] (RW)
 *
 * Enables dither in the fractional modulator calculation.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_DITHER_ENABLE (17U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_DITHER_ENABLE. */
#define BM_CCM_ANALOG_PLL_VIDEO_DITHER_ENABLE (0x00020000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_DITHER_ENABLE. */
#define BS_CCM_ANALOG_PLL_VIDEO_DITHER_ENABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_DITHER_ENABLE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_DITHER_ENABLE field. */
#define BR_CCM_ANALOG_PLL_VIDEO_DITHER_ENABLE(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.DITHER_ENABLE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_DITHER_ENABLE. */
#define BF_CCM_ANALOG_PLL_VIDEO_DITHER_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_DITHER_ENABLE) & BM_CCM_ANALOG_PLL_VIDEO_DITHER_ENABLE)

/*! @brief Set the DITHER_ENABLE field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_DITHER_ENABLE(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_DITHER_ENABLE) | BF_CCM_ANALOG_PLL_VIDEO_DITHER_ENABLE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field PFD_OFFSET_EN[18] (RW)
 *
 * Enables an offset in the phase frequency detector.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN (18U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN. */
#define BM_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN (0x00040000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN. */
#define BS_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN field. */
#define BR_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.PFD_OFFSET_EN)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN. */
#define BF_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN) & BM_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN)

/*! @brief Set the PFD_OFFSET_EN field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN) | BF_CCM_ANALOG_PLL_VIDEO_PFD_OFFSET_EN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field TEST_DIV_SELECT[20:19] (RW)
 *
 * Control bits for the divider for the PLL clk and lvds outputs:
 * 0x0=div-by-4(default), 0x1=div-by-2, 0x2=div-by-1, 0x3=div-by-1. This divider is placed
 * before the post divider.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT (19U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT. */
#define BM_CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT (0x00180000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT. */
#define BS_CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT field. */
#define BR_CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.TEST_DIV_SELECT)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT. */
#define BF_CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT) & BM_CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT)

/*! @brief Set the TEST_DIV_SELECT field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT) | BF_CCM_ANALOG_PLL_VIDEO_TEST_DIV_SELECT(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field RSVD0[21] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_RSVD0 (21U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_RSVD0. */
#define BM_CCM_ANALOG_PLL_VIDEO_RSVD0 (0x00200000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_RSVD0. */
#define BS_CCM_ANALOG_PLL_VIDEO_RSVD0 (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_RSVD0. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_RSVD0 field. */
#define BR_CCM_ANALOG_PLL_VIDEO_RSVD0(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.RSVD0)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field POST_DIV_SEL[23:22] (RW)
 *
 * Post-divider for video PLL: 0x0=div-by-1(default), 0x1=div-by-2,
 * 0x2=div-by-1, 0x3=div-by-4. The output clock of the video PLL should be gated prior to
 * changing this divider to prevent glitches.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL (22U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL. */
#define BM_CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL (0x00C00000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL. */
#define BS_CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL field. */
#define BR_CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.POST_DIV_SEL)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL. */
#define BF_CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL) & BM_CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL)

/*! @brief Set the POST_DIV_SEL field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL) | BF_CCM_ANALOG_PLL_VIDEO_POST_DIV_SEL(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field PLL_VIDEO_OVERRIDE[24] (RW)
 *
 * The OVERRIDE bit allows the clock control module to automatically override
 * portions of the register.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_PLL_VIDEO_OVERRIDE (24U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_PLL_VIDEO_OVERRIDE. */
#define BM_CCM_ANALOG_PLL_VIDEO_PLL_VIDEO_OVERRIDE (0x01000000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_PLL_VIDEO_OVERRIDE. */
#define BS_CCM_ANALOG_PLL_VIDEO_PLL_VIDEO_OVERRIDE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_PLL_VIDEO_OVERRIDE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_PLL_VIDEO_OVERRIDE field. */
#define BR_CCM_ANALOG_PLL_VIDEO_PLL_VIDEO_OVERRIDE(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.PLL_VIDEO_OVERRIDE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_PLL_VIDEO_OVERRIDE. */
#define BF_CCM_ANALOG_PLL_VIDEO_PLL_VIDEO_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_PLL_VIDEO_OVERRIDE) & BM_CCM_ANALOG_PLL_VIDEO_PLL_VIDEO_OVERRIDE)

/*! @brief Set the PLL_VIDEO_OVERRIDE field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_PLL_VIDEO_OVERRIDE(x, v) (HW_CCM_ANALOG_PLL_VIDEO_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_PLL_VIDEO_OVERRIDE) | BF_CCM_ANALOG_PLL_VIDEO_PLL_VIDEO_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field RSVD1[30:25] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_RSVD1 (25U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_RSVD1. */
#define BM_CCM_ANALOG_PLL_VIDEO_RSVD1 (0x7E000000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_RSVD1. */
#define BS_CCM_ANALOG_PLL_VIDEO_RSVD1 (6U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_RSVD1. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_RSVD1 field. */
#define BR_CCM_ANALOG_PLL_VIDEO_RSVD1(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.RSVD1)
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO, field LOCK[31] (RO)
 *
 * 1 - PLL is currently locked; 0 - PLL is not currently locked.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_LOCK (31U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_LOCK. */
#define BM_CCM_ANALOG_PLL_VIDEO_LOCK (0x80000000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_LOCK. */
#define BS_CCM_ANALOG_PLL_VIDEO_LOCK (1U)  /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_LOCK. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_LOCK field. */
#define BR_CCM_ANALOG_PLL_VIDEO_LOCK(x) (HW_CCM_ANALOG_PLL_VIDEO(x).B.LOCK)
/*@}*/




/*******************************************************************************
 * HW_CCM_ANALOG_PLL_VIDEO_SS - Video PLL Spread Spectrum Register.
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_VIDEO_SS - Video PLL Spread Spectrum Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the Video PLL spread spectrum controls.
 */
typedef union _hw_ccm_analog_pll_video_ss
{
    uint32_t U;
    struct _hw_ccm_analog_pll_video_ss_bitfields
    {
        uint32_t STEP : 15;            /*!< [14:0]  */
        uint32_t ENABLE : 1;           /*!< [15]  */
        uint32_t STOP : 16;            /*!< [31:16]  */
    } B;
} hw_ccm_analog_pll_video_ss_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_VIDEO_SS register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_VIDEO_SS_ADDR(x) ((uintptr_t)(x) + 0x140U)

#define HW_CCM_ANALOG_PLL_VIDEO_SS(x) (*(__IO hw_ccm_analog_pll_video_ss_t *) HW_CCM_ANALOG_PLL_VIDEO_SS_ADDR(x))
#define HW_CCM_ANALOG_PLL_VIDEO_SS_RD(x) (HW_CCM_ANALOG_PLL_VIDEO_SS(x).U)
#define HW_CCM_ANALOG_PLL_VIDEO_SS_WR(x, v) (HW_CCM_ANALOG_PLL_VIDEO_SS(x).U = (v))
#define HW_CCM_ANALOG_PLL_VIDEO_SS_SET(x, v) (HW_CCM_ANALOG_PLL_VIDEO_SS_WR(x, HW_CCM_ANALOG_PLL_VIDEO_SS_RD(x) |  (v)))
#define HW_CCM_ANALOG_PLL_VIDEO_SS_CLR(x, v) (HW_CCM_ANALOG_PLL_VIDEO_SS_WR(x, HW_CCM_ANALOG_PLL_VIDEO_SS_RD(x) & ~(v)))
#define HW_CCM_ANALOG_PLL_VIDEO_SS_TOG(x, v) (HW_CCM_ANALOG_PLL_VIDEO_SS_WR(x, HW_CCM_ANALOG_PLL_VIDEO_SS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_VIDEO_SS bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO_SS, field STEP[14:0] (RW)
 *
 * The max frequency change = stop/B*24MHz.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_SS_STEP (0U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_SS_STEP. */
#define BM_CCM_ANALOG_PLL_VIDEO_SS_STEP (0x00007FFFU) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_SS_STEP. */
#define BS_CCM_ANALOG_PLL_VIDEO_SS_STEP (15U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_SS_STEP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_SS_STEP field. */
#define BR_CCM_ANALOG_PLL_VIDEO_SS_STEP(x) (HW_CCM_ANALOG_PLL_VIDEO_SS(x).B.STEP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_SS_STEP. */
#define BF_CCM_ANALOG_PLL_VIDEO_SS_STEP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_SS_STEP) & BM_CCM_ANALOG_PLL_VIDEO_SS_STEP)

/*! @brief Set the STEP field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_SS_STEP(x, v) (HW_CCM_ANALOG_PLL_VIDEO_SS_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_SS_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_SS_STEP) | BF_CCM_ANALOG_PLL_VIDEO_SS_STEP(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO_SS, field ENABLE[15] (RW)
 *
 * This bit enables the spread spectrum modulation.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_SS_ENABLE (15U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_SS_ENABLE. */
#define BM_CCM_ANALOG_PLL_VIDEO_SS_ENABLE (0x00008000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_SS_ENABLE. */
#define BS_CCM_ANALOG_PLL_VIDEO_SS_ENABLE (1U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_SS_ENABLE. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_SS_ENABLE field. */
#define BR_CCM_ANALOG_PLL_VIDEO_SS_ENABLE(x) (HW_CCM_ANALOG_PLL_VIDEO_SS(x).B.ENABLE)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_SS_ENABLE. */
#define BF_CCM_ANALOG_PLL_VIDEO_SS_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_SS_ENABLE) & BM_CCM_ANALOG_PLL_VIDEO_SS_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_SS_ENABLE(x, v) (HW_CCM_ANALOG_PLL_VIDEO_SS_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_SS_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_SS_ENABLE) | BF_CCM_ANALOG_PLL_VIDEO_SS_ENABLE(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO_SS, field STOP[31:16] (RW)
 *
 * Frequency change = step/B*24MHz.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_SS_STOP (16U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_SS_STOP. */
#define BM_CCM_ANALOG_PLL_VIDEO_SS_STOP (0xFFFF0000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_SS_STOP. */
#define BS_CCM_ANALOG_PLL_VIDEO_SS_STOP (16U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_SS_STOP. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_SS_STOP field. */
#define BR_CCM_ANALOG_PLL_VIDEO_SS_STOP(x) (HW_CCM_ANALOG_PLL_VIDEO_SS(x).B.STOP)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_SS_STOP. */
#define BF_CCM_ANALOG_PLL_VIDEO_SS_STOP(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_SS_STOP) & BM_CCM_ANALOG_PLL_VIDEO_SS_STOP)

/*! @brief Set the STOP field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_SS_STOP(x, v) (HW_CCM_ANALOG_PLL_VIDEO_SS_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_SS_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_SS_STOP) | BF_CCM_ANALOG_PLL_VIDEO_SS_STOP(v)))
/*@}*/

/*******************************************************************************
 * HW_CCM_ANALOG_PLL_VIDEO_NUM - Numerator of Video PLL Fractional Loop Divider Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_VIDEO_NUM - Numerator of Video PLL Fractional Loop Divider Register (RW)
 *
 * Reset value: 0x05F5E100U
 *
 * This register contains the numerator (A) of Video PLL fractional loop divider.
 */
typedef union _hw_ccm_analog_pll_video_num
{
    uint32_t U;
    struct _hw_ccm_analog_pll_video_num_bitfields
    {
        uint32_t A : 30;               /*!< [29:0]  */
        uint32_t RSVD0 : 2;            /*!< [31:30]  */
    } B;
} hw_ccm_analog_pll_video_num_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_VIDEO_NUM register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_VIDEO_NUM_ADDR(x) ((uintptr_t)(x) + 0x150U)

#define HW_CCM_ANALOG_PLL_VIDEO_NUM(x) (*(__IO hw_ccm_analog_pll_video_num_t *) HW_CCM_ANALOG_PLL_VIDEO_NUM_ADDR(x))
#define HW_CCM_ANALOG_PLL_VIDEO_NUM_RD(x) (HW_CCM_ANALOG_PLL_VIDEO_NUM(x).U)
#define HW_CCM_ANALOG_PLL_VIDEO_NUM_WR(x, v) (HW_CCM_ANALOG_PLL_VIDEO_NUM(x).U = (v))
#define HW_CCM_ANALOG_PLL_VIDEO_NUM_SET(x, v) (HW_CCM_ANALOG_PLL_VIDEO_NUM_WR(x, HW_CCM_ANALOG_PLL_VIDEO_NUM_RD(x) |  (v)))
#define HW_CCM_ANALOG_PLL_VIDEO_NUM_CLR(x, v) (HW_CCM_ANALOG_PLL_VIDEO_NUM_WR(x, HW_CCM_ANALOG_PLL_VIDEO_NUM_RD(x) & ~(v)))
#define HW_CCM_ANALOG_PLL_VIDEO_NUM_TOG(x, v) (HW_CCM_ANALOG_PLL_VIDEO_NUM_WR(x, HW_CCM_ANALOG_PLL_VIDEO_NUM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_VIDEO_NUM bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO_NUM, field A[29:0] (RW)
 *
 * 30 bit numerator of fractional loop divider.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_NUM_A (0U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_NUM_A. */
#define BM_CCM_ANALOG_PLL_VIDEO_NUM_A (0x3FFFFFFFU) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_NUM_A. */
#define BS_CCM_ANALOG_PLL_VIDEO_NUM_A (30U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_NUM_A. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_NUM_A field. */
#define BR_CCM_ANALOG_PLL_VIDEO_NUM_A(x) (HW_CCM_ANALOG_PLL_VIDEO_NUM(x).B.A)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_NUM_A. */
#define BF_CCM_ANALOG_PLL_VIDEO_NUM_A(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_NUM_A) & BM_CCM_ANALOG_PLL_VIDEO_NUM_A)

/*! @brief Set the A field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_NUM_A(x, v) (HW_CCM_ANALOG_PLL_VIDEO_NUM_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_NUM_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_NUM_A) | BF_CCM_ANALOG_PLL_VIDEO_NUM_A(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO_NUM, field RSVD0[31:30] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_NUM_RSVD0 (30U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_NUM_RSVD0. */
#define BM_CCM_ANALOG_PLL_VIDEO_NUM_RSVD0 (0xC0000000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_NUM_RSVD0. */
#define BS_CCM_ANALOG_PLL_VIDEO_NUM_RSVD0 (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_NUM_RSVD0. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_NUM_RSVD0 field. */
#define BR_CCM_ANALOG_PLL_VIDEO_NUM_RSVD0(x) (HW_CCM_ANALOG_PLL_VIDEO_NUM(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_CCM_ANALOG_PLL_VIDEO_DENOM - Denominator of Video PLL Fractional Loop Divider Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_PLL_VIDEO_DENOM - Denominator of Video PLL Fractional Loop Divider Register (RW)
 *
 * Reset value: 0x10A24447U
 *
 * This register contains the Denominator (B) of Video PLL fractional loop
 * divider.
 */
typedef union _hw_ccm_analog_pll_video_denom
{
    uint32_t U;
    struct _hw_ccm_analog_pll_video_denom_bitfields
    {
        uint32_t B : 30;               /*!< [29:0]  */
        uint32_t RSVD0 : 2;            /*!< [31:30]  */
    } B;
} hw_ccm_analog_pll_video_denom_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_PLL_VIDEO_DENOM register
 */
/*@{*/
#define HW_CCM_ANALOG_PLL_VIDEO_DENOM_ADDR(x) ((uintptr_t)(x) + 0x160U)

#define HW_CCM_ANALOG_PLL_VIDEO_DENOM(x) (*(__IO hw_ccm_analog_pll_video_denom_t *) HW_CCM_ANALOG_PLL_VIDEO_DENOM_ADDR(x))
#define HW_CCM_ANALOG_PLL_VIDEO_DENOM_RD(x) (HW_CCM_ANALOG_PLL_VIDEO_DENOM(x).U)
#define HW_CCM_ANALOG_PLL_VIDEO_DENOM_WR(x, v) (HW_CCM_ANALOG_PLL_VIDEO_DENOM(x).U = (v))
#define HW_CCM_ANALOG_PLL_VIDEO_DENOM_SET(x, v) (HW_CCM_ANALOG_PLL_VIDEO_DENOM_WR(x, HW_CCM_ANALOG_PLL_VIDEO_DENOM_RD(x) |  (v)))
#define HW_CCM_ANALOG_PLL_VIDEO_DENOM_CLR(x, v) (HW_CCM_ANALOG_PLL_VIDEO_DENOM_WR(x, HW_CCM_ANALOG_PLL_VIDEO_DENOM_RD(x) & ~(v)))
#define HW_CCM_ANALOG_PLL_VIDEO_DENOM_TOG(x, v) (HW_CCM_ANALOG_PLL_VIDEO_DENOM_WR(x, HW_CCM_ANALOG_PLL_VIDEO_DENOM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_PLL_VIDEO_DENOM bitfields
 */

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO_DENOM, field B[29:0] (RW)
 *
 * 30 bit Denominator of fractional loop divider.
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_DENOM_B (0U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_DENOM_B. */
#define BM_CCM_ANALOG_PLL_VIDEO_DENOM_B (0x3FFFFFFFU) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_DENOM_B. */
#define BS_CCM_ANALOG_PLL_VIDEO_DENOM_B (30U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_DENOM_B. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_DENOM_B field. */
#define BR_CCM_ANALOG_PLL_VIDEO_DENOM_B(x) (HW_CCM_ANALOG_PLL_VIDEO_DENOM(x).B.B)

/*! @brief Format value for bitfield CCM_ANALOG_PLL_VIDEO_DENOM_B. */
#define BF_CCM_ANALOG_PLL_VIDEO_DENOM_B(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_PLL_VIDEO_DENOM_B) & BM_CCM_ANALOG_PLL_VIDEO_DENOM_B)

/*! @brief Set the B field to a new value. */
#define BW_CCM_ANALOG_PLL_VIDEO_DENOM_B(x, v) (HW_CCM_ANALOG_PLL_VIDEO_DENOM_WR(x, (HW_CCM_ANALOG_PLL_VIDEO_DENOM_RD(x) & ~BM_CCM_ANALOG_PLL_VIDEO_DENOM_B) | BF_CCM_ANALOG_PLL_VIDEO_DENOM_B(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_PLL_VIDEO_DENOM, field RSVD0[31:30] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_CCM_ANALOG_PLL_VIDEO_DENOM_RSVD0 (30U) /*!< Bit position for CCM_ANALOG_PLL_VIDEO_DENOM_RSVD0. */
#define BM_CCM_ANALOG_PLL_VIDEO_DENOM_RSVD0 (0xC0000000U) /*!< Bit mask for CCM_ANALOG_PLL_VIDEO_DENOM_RSVD0. */
#define BS_CCM_ANALOG_PLL_VIDEO_DENOM_RSVD0 (2U) /*!< Bit field size in bits for CCM_ANALOG_PLL_VIDEO_DENOM_RSVD0. */

/*! @brief Read current value of the CCM_ANALOG_PLL_VIDEO_DENOM_RSVD0 field. */
#define BR_CCM_ANALOG_PLL_VIDEO_DENOM_RSVD0(x) (HW_CCM_ANALOG_PLL_VIDEO_DENOM(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_CCM_ANALOG_CLK_MISC0 - Miscellaneous0 Analog Clock Control and Status Register
 ******************************************************************************/

/*!
 * @brief HW_CCM_ANALOG_CLK_MISC0 - Miscellaneous0 Analog Clock Control and Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control and status bits for miscellaneous analog
 * blocks. The lvds1 and lvds2 controls control the behavior of the anaclk1/1b and
 * anaclk2/2b lvds IO's.
 */
typedef union _hw_ccm_analog_clk_misc0
{
    uint32_t U;
    struct _hw_ccm_analog_clk_misc0_bitfields
    {
        uint32_t LVDS1_CLK_SEL : 5;    /*!< [4:0]  */
        uint32_t LVDSCLK1_OBEN : 1;    /*!< [5]  */
        uint32_t LVDSCLK1_IBEN : 1;    /*!< [6]  */
        uint32_t ACLK2_PREDIV : 1;     /*!< [7]  */
        uint32_t RSVD0 : 24;           /*!< [31:8]  */
    } B;
} hw_ccm_analog_clk_misc0_t;

/*!
 * @name Constants and macros for entire CCM_ANALOG_CLK_MISC0 register
 */
/*@{*/
#define HW_CCM_ANALOG_CLK_MISC0_ADDR(x) ((uintptr_t)(x) + 0x170U)
#define HW_CCM_ANALOG_CLK_MISC0_SET_ADDR(x) (HW_CCM_ANALOG_CLK_MISC0_ADDR(x) + 0x4U)
#define HW_CCM_ANALOG_CLK_MISC0_CLR_ADDR(x) (HW_CCM_ANALOG_CLK_MISC0_ADDR(x) + 0x8U)
#define HW_CCM_ANALOG_CLK_MISC0_TOG_ADDR(x) (HW_CCM_ANALOG_CLK_MISC0_ADDR(x) + 0xCU)

#define HW_CCM_ANALOG_CLK_MISC0(x) (*(__IO hw_ccm_analog_clk_misc0_t *) HW_CCM_ANALOG_CLK_MISC0_ADDR(x))
#define HW_CCM_ANALOG_CLK_MISC0_RD(x) (HW_CCM_ANALOG_CLK_MISC0(x).U)
#define HW_CCM_ANALOG_CLK_MISC0_WR(x, v) (HW_CCM_ANALOG_CLK_MISC0(x).U = (v))
#define HW_CCM_ANALOG_CLK_MISC0_SET(x, v) ((*(uint32_t *) HW_CCM_ANALOG_CLK_MISC0_SET_ADDR(x)) = (v))
#define HW_CCM_ANALOG_CLK_MISC0_CLR(x, v) ((*(uint32_t *) HW_CCM_ANALOG_CLK_MISC0_CLR_ADDR(x)) = (v))
#define HW_CCM_ANALOG_CLK_MISC0_TOG(x, v) ((*(uint32_t *) HW_CCM_ANALOG_CLK_MISC0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual CCM_ANALOG_CLK_MISC0 bitfields
 */

/*!
 * @name Register CCM_ANALOG_CLK_MISC0, field LVDS1_CLK_SEL[4:0] (RW)
 *
 * This field selects the clock to be routed to anaclk1/1b 0x00 - Arm PLL; 0x01
 * - 480 PLL; 0x02 - pfd0; 0x03 - pfd1; 0x04 - pfd2; 0x05 - pfd3; 0x06 - pfd4;
 * 0x07 - pfd5; 0x08 - pfd6; 0x09 - pfd7; 0x0A - Audio PLL; 0x0B - Video PLL; 0x0C
 * - pll_enet_div2 (500MHz); 0x0D - pll_enet_div4 (250MHz); 0x0E - pll_enet_div8
 * (125MHz); 0x0F - pll_enet_div10 (100MHz); 0x10 - pll_enet_div20 (50MHz); 0x11
 * - pll_enet_div25 (40MHz); 0x12 - pll_enet_div40 (25MHz); 0x13 - pll_ddr; 0x14
 * - RC_OSC24; 0x15 - clk24mhz; 0x16 - anatest ring oscillators; 0x17 -
 * aclk2_loopback; 0x18-0x1F - Reserved.
 */
/*@{*/
#define BP_CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL (0U) /*!< Bit position for CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL. */
#define BM_CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL (0x0000001FU) /*!< Bit mask for CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL. */
#define BS_CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL (5U) /*!< Bit field size in bits for CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL. */

/*! @brief Read current value of the CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL field. */
#define BR_CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL(x) (HW_CCM_ANALOG_CLK_MISC0(x).B.LVDS1_CLK_SEL)

/*! @brief Format value for bitfield CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL. */
#define BF_CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL) & BM_CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL)

/*! @brief Set the LVDS1_CLK_SEL field to a new value. */
#define BW_CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL(x, v) (HW_CCM_ANALOG_CLK_MISC0_WR(x, (HW_CCM_ANALOG_CLK_MISC0_RD(x) & ~BM_CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL) | BF_CCM_ANALOG_CLK_MISC0_LVDS1_CLK_SEL(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_CLK_MISC0, field LVDSCLK1_OBEN[5] (RW)
 *
 * This enables the lvds output buffer for anaclk1/1b. Do not enable input and
 * output buffers simutaneously.
 */
/*@{*/
#define BP_CCM_ANALOG_CLK_MISC0_LVDSCLK1_OBEN (5U) /*!< Bit position for CCM_ANALOG_CLK_MISC0_LVDSCLK1_OBEN. */
#define BM_CCM_ANALOG_CLK_MISC0_LVDSCLK1_OBEN (0x00000020U) /*!< Bit mask for CCM_ANALOG_CLK_MISC0_LVDSCLK1_OBEN. */
#define BS_CCM_ANALOG_CLK_MISC0_LVDSCLK1_OBEN (1U) /*!< Bit field size in bits for CCM_ANALOG_CLK_MISC0_LVDSCLK1_OBEN. */

/*! @brief Read current value of the CCM_ANALOG_CLK_MISC0_LVDSCLK1_OBEN field. */
#define BR_CCM_ANALOG_CLK_MISC0_LVDSCLK1_OBEN(x) (HW_CCM_ANALOG_CLK_MISC0(x).B.LVDSCLK1_OBEN)

/*! @brief Format value for bitfield CCM_ANALOG_CLK_MISC0_LVDSCLK1_OBEN. */
#define BF_CCM_ANALOG_CLK_MISC0_LVDSCLK1_OBEN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_CLK_MISC0_LVDSCLK1_OBEN) & BM_CCM_ANALOG_CLK_MISC0_LVDSCLK1_OBEN)

/*! @brief Set the LVDSCLK1_OBEN field to a new value. */
#define BW_CCM_ANALOG_CLK_MISC0_LVDSCLK1_OBEN(x, v) (HW_CCM_ANALOG_CLK_MISC0_WR(x, (HW_CCM_ANALOG_CLK_MISC0_RD(x) & ~BM_CCM_ANALOG_CLK_MISC0_LVDSCLK1_OBEN) | BF_CCM_ANALOG_CLK_MISC0_LVDSCLK1_OBEN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_CLK_MISC0, field LVDSCLK1_IBEN[6] (RW)
 *
 * This enables the lvds input buffer for anaclk1/1b. Do not enable input and
 * output buffers simutaneously.
 */
/*@{*/
#define BP_CCM_ANALOG_CLK_MISC0_LVDSCLK1_IBEN (6U) /*!< Bit position for CCM_ANALOG_CLK_MISC0_LVDSCLK1_IBEN. */
#define BM_CCM_ANALOG_CLK_MISC0_LVDSCLK1_IBEN (0x00000040U) /*!< Bit mask for CCM_ANALOG_CLK_MISC0_LVDSCLK1_IBEN. */
#define BS_CCM_ANALOG_CLK_MISC0_LVDSCLK1_IBEN (1U) /*!< Bit field size in bits for CCM_ANALOG_CLK_MISC0_LVDSCLK1_IBEN. */

/*! @brief Read current value of the CCM_ANALOG_CLK_MISC0_LVDSCLK1_IBEN field. */
#define BR_CCM_ANALOG_CLK_MISC0_LVDSCLK1_IBEN(x) (HW_CCM_ANALOG_CLK_MISC0(x).B.LVDSCLK1_IBEN)

/*! @brief Format value for bitfield CCM_ANALOG_CLK_MISC0_LVDSCLK1_IBEN. */
#define BF_CCM_ANALOG_CLK_MISC0_LVDSCLK1_IBEN(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_CLK_MISC0_LVDSCLK1_IBEN) & BM_CCM_ANALOG_CLK_MISC0_LVDSCLK1_IBEN)

/*! @brief Set the LVDSCLK1_IBEN field to a new value. */
#define BW_CCM_ANALOG_CLK_MISC0_LVDSCLK1_IBEN(x, v) (HW_CCM_ANALOG_CLK_MISC0_WR(x, (HW_CCM_ANALOG_CLK_MISC0_RD(x) & ~BM_CCM_ANALOG_CLK_MISC0_LVDSCLK1_IBEN) | BF_CCM_ANALOG_CLK_MISC0_LVDSCLK1_IBEN(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_CLK_MISC0, field ACLK2_PREDIV[7] (RW)
 *
 * Predivider ACLK2 source/reference clock of the PLL's. 0 - divide by 1; 1 -
 * divide by 2. Please see PLL programming registers to select this source as the
 * reference clock to the desired PLL
 */
/*@{*/
#define BP_CCM_ANALOG_CLK_MISC0_ACLK2_PREDIV (7U) /*!< Bit position for CCM_ANALOG_CLK_MISC0_ACLK2_PREDIV. */
#define BM_CCM_ANALOG_CLK_MISC0_ACLK2_PREDIV (0x00000080U) /*!< Bit mask for CCM_ANALOG_CLK_MISC0_ACLK2_PREDIV. */
#define BS_CCM_ANALOG_CLK_MISC0_ACLK2_PREDIV (1U) /*!< Bit field size in bits for CCM_ANALOG_CLK_MISC0_ACLK2_PREDIV. */

/*! @brief Read current value of the CCM_ANALOG_CLK_MISC0_ACLK2_PREDIV field. */
#define BR_CCM_ANALOG_CLK_MISC0_ACLK2_PREDIV(x) (HW_CCM_ANALOG_CLK_MISC0(x).B.ACLK2_PREDIV)

/*! @brief Format value for bitfield CCM_ANALOG_CLK_MISC0_ACLK2_PREDIV. */
#define BF_CCM_ANALOG_CLK_MISC0_ACLK2_PREDIV(v) ((uint32_t)((uint32_t)(v) << BP_CCM_ANALOG_CLK_MISC0_ACLK2_PREDIV) & BM_CCM_ANALOG_CLK_MISC0_ACLK2_PREDIV)

/*! @brief Set the ACLK2_PREDIV field to a new value. */
#define BW_CCM_ANALOG_CLK_MISC0_ACLK2_PREDIV(x, v) (HW_CCM_ANALOG_CLK_MISC0_WR(x, (HW_CCM_ANALOG_CLK_MISC0_RD(x) & ~BM_CCM_ANALOG_CLK_MISC0_ACLK2_PREDIV) | BF_CCM_ANALOG_CLK_MISC0_ACLK2_PREDIV(v)))
/*@}*/

/*!
 * @name Register CCM_ANALOG_CLK_MISC0, field RSVD0[31:8] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_CCM_ANALOG_CLK_MISC0_RSVD0 (8U) /*!< Bit position for CCM_ANALOG_CLK_MISC0_RSVD0. */
#define BM_CCM_ANALOG_CLK_MISC0_RSVD0 (0xFFFFFF00U) /*!< Bit mask for CCM_ANALOG_CLK_MISC0_RSVD0. */
#define BS_CCM_ANALOG_CLK_MISC0_RSVD0 (24U) /*!< Bit field size in bits for CCM_ANALOG_CLK_MISC0_RSVD0. */

/*! @brief Read current value of the CCM_ANALOG_CLK_MISC0_RSVD0 field. */
#define BR_CCM_ANALOG_CLK_MISC0_RSVD0(x) (HW_CCM_ANALOG_CLK_MISC0(x).B.RSVD0)
/*@}*/




/*******************************************************************************
 * hw_ccm_analog_t - module struct
 ******************************************************************************/
/*!
 * @brief All CCM_ANALOG module registers.
 */
#pragma pack(1)
typedef struct _hw_ccm_analog
{
    uint8_t _reserved0[96];
    __IO hw_ccm_analog_pll_arm_t PLL_ARM;  /*!< [0x60] Anadig ARM PLL control Register */
    uint8_t _reserved1[12];
    __IO hw_ccm_analog_pll_ddr_t PLL_DDR;  /*!< [0x70] Anadig DDR PLL Control Register */
    uint8_t _reserved2[12];
    __IO hw_ccm_analog_pll_ddr_ss_t PLL_DDR_SS; /*!< [0x80] DDR PLL Spread Spectrum Register. */
    uint8_t _reserved3[12];
    __IO hw_ccm_analog_pll_ddr_num_t PLL_DDR_NUM; /*!< [0x90] Numerator of DDR PLL Fractional Loop Divider Register */
    uint8_t _reserved4[12];
    __IO hw_ccm_analog_pll_ddr_denom_t PLL_DDR_DENOM; /*!< [0xA0] Denominator of DDR PLL Fractional Loop Divider Register */
    uint8_t _reserved5[12];
    __IO hw_ccm_analog_pll_480_t PLL_480;  /*!< [0xB0] Anadig 480MHz PLL Control Register */
    uint8_t _reserved6[12];
    __IO hw_ccm_analog_pfd_480a_t PFD_480A; /*!< [0xC0] 480MHz Clock Phase Fractional Divider Control Register A */
    uint8_t _reserved7[12];
    __IO hw_ccm_analog_pfd_480b_t PFD_480B; /*!< [0xD0] 480MHz Clock Phase Fractional Divider Control Register B */
    uint8_t _reserved8[12];
    __IO hw_ccm_analog_pll_enet_t PLL_ENET; /*!< [0xE0] Anadig ENET PLL Control Register */
    uint8_t _reserved9[12];
    __IO hw_ccm_analog_pll_audio_t PLL_AUDIO; /*!< [0xF0] Anadig Audio PLL control Register */
    uint8_t _reserved10[12];
    __IO hw_ccm_analog_pll_audio_ss_t PLL_AUDIO_SS; /*!< [0x100] Audio PLL Spread Spectrum Register. */
    uint8_t _reserved11[12];
    __IO hw_ccm_analog_pll_audio_num_t PLL_AUDIO_NUM; /*!< [0x110] Numerator of Audio PLL Fractional Loop Divider Register */
    uint8_t _reserved12[12];
    __IO hw_ccm_analog_pll_audio_denom_t PLL_AUDIO_DENOM; /*!< [0x120] Denominator of Audio PLL Fractional Loop Divider Register */
    uint8_t _reserved13[12];
    __IO hw_ccm_analog_pll_video_t PLL_VIDEO; /*!< [0x130] Anadig Video PLL control Register */
    uint8_t _reserved14[12];
    __IO hw_ccm_analog_pll_video_ss_t PLL_VIDEO_SS; /*!< [0x140] Video PLL Spread Spectrum Register. */
    uint8_t _reserved15[12];
    __IO hw_ccm_analog_pll_video_num_t PLL_VIDEO_NUM; /*!< [0x150] Numerator of Video PLL Fractional Loop Divider Register */
    uint8_t _reserved16[12];
    __IO hw_ccm_analog_pll_video_denom_t PLL_VIDEO_DENOM; /*!< [0x160] Denominator of Video PLL Fractional Loop Divider Register */
    uint8_t _reserved17[12];
    __IO hw_ccm_analog_clk_misc0_t CLK_MISC0; /*!< [0x170] Miscellaneous0 Analog Clock Control and Status Register */
} hw_ccm_analog_t;
#pragma pack()

/*! @brief Macro to access all CCM_ANALOG registers. */
/*! @param x CCM_ANALOG module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_CCM_ANALOG_REGS(CCM_ANALOG_BASE)</code>. */
#define HW_CCM_ANALOG_REGS(x) (*(hw_ccm_analog_t *)(x))

/*
 * iMX7D CSI
 *
 * CSI
 *
 * Registers defined in this header file:
 * - HW_CSI_CSICR1 - CSI Control Register 1
 * - HW_CSI_CSICR2 - CSI Control Register 2
 * - HW_CSI_CSICR3 - CSI Control Register 3
 * - HW_CSI_CSISTATFIFO - CSI Statistic FIFO Register
 * - HW_CSI_CSIRFIFO - CSI RX FIFO Register
 * - HW_CSI_CSIRXCNT - CSI RX Count Register
 * - HW_CSI_CSISR - CSI Status Register
 * - HW_CSI_CSIDMASA_STATFIFO - CSI DMA Start Address Register - for STATFIFO
 * - HW_CSI_CSIDMATS_STATFIFO - CSI DMA Transfer Size Register - for STATFIFO
 * - HW_CSI_CSIDMASA_FB1 - CSI DMA Start Address Register - for Frame Buffer1
 * - HW_CSI_CSIDMASA_FB2 - CSI DMA Transfer Size Register - for Frame Buffer2
 * - HW_CSI_CSIFBUF_PARA - CSI Frame Buffer Parameter Register
 * - HW_CSI_CSIIMAG_PARA - CSI Image Parameter Register
 * - HW_CSI_CSICR18 - CSI Control Register 18
 *
 * - hw_csi_t - Struct containing all module registers.
 */

#define HW_CSI_INSTANCE_COUNT (1U) /*!< Number of instances of the CSI module. */
#define HW_CSI (0U) /*!< Instance number for CSI. */
#define CSI_BASE              (0x30710000U) /*!< Base address for CSI. */
/*! Array initializer of CSI base addresses. */
#define CSI_BASE_ADDRS        { CSI_BASE }

/*******************************************************************************
 * HW_CSI_CSICR1 - CSI Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSICR1 - CSI Control Register 1 (RW)
 *
 * Reset value: 0x40000800U
 *
 * This register controls the sensor interface timing and interrupt generation.
 * The interrupt enable bits in this register control the interrupt signals and
 * the status bits. That means status bits will only function when the
 * corresponding interrupt bits are enabled.
 */
typedef union _hw_csi_csicr1
{
    uint32_t U;
    struct _hw_csi_csicr1_bitfields
    {
        uint32_t PIXEL_BIT : 1;        /*!< [0]  */
        uint32_t REDGE : 1;            /*!< [1]  */
        uint32_t INV_PCLK : 1;         /*!< [2]  */
        uint32_t INV_DATA : 1;         /*!< [3]  */
        uint32_t GCLK_MODE : 1;        /*!< [4]  */
        uint32_t CLR_RXFIFO : 1;       /*!< [5]  */
        uint32_t CLR_STATFIFO : 1;     /*!< [6]  */
        uint32_t PACK_DIR : 1;         /*!< [7]  */
        uint32_t FCC : 1;              /*!< [8]  */
        uint32_t RESERVED0 : 1;        /*!< [9]  */
        uint32_t CCIR_EN : 1;          /*!< [10]  */
        uint32_t HSYNC_POL : 1;        /*!< [11]  */
        uint32_t RESERVED1 : 4;        /*!< [15:12]  */
        uint32_t SOF_INTEN : 1;        /*!< [16]  */
        uint32_t SOF_POL : 1;          /*!< [17]  */
        uint32_t RXFF_INTEN : 1;       /*!< [18]  */
        uint32_t FB1_DMA_DONE_INTEN : 1; /*!< [19]  */
        uint32_t FB2_DMA_DONE_INTEN : 1; /*!< [20]  */
        uint32_t STATFF_INTEN : 1;     /*!< [21]  */
        uint32_t SFF_DMA_DONE_INTEN : 1; /*!< [22]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t RF_OR_INTEN : 1;      /*!< [24]  */
        uint32_t SF_OR_INTEN : 1;      /*!< [25]  */
        uint32_t COF_INT_EN : 1;       /*!< [26]  */
        uint32_t VIDEO_MODE : 1;       /*!< [27]  */
        uint32_t PrP_IF_EN : 1;        /*!< [28]  */
        uint32_t EOF_INT_EN : 1;       /*!< [29]  */
        uint32_t EXT_VSYNC : 1;        /*!< [30]  */
        uint32_t SWAP16_EN : 1;        /*!< [31]  */
    } B;
} hw_csi_csicr1_t;

/*!
 * @name Constants and macros for entire CSI_CSICR1 register
 */
/*@{*/
#define HW_CSI_CSICR1_ADDR(x)    ((uintptr_t)(x) + 0x0U)

#define HW_CSI_CSICR1(x)         (*(__IO hw_csi_csicr1_t *) HW_CSI_CSICR1_ADDR(x))
#define HW_CSI_CSICR1_RD(x)      (HW_CSI_CSICR1(x).U)
#define HW_CSI_CSICR1_WR(x, v)   (HW_CSI_CSICR1(x).U = (v))
#define HW_CSI_CSICR1_SET(x, v)  (HW_CSI_CSICR1_WR(x, HW_CSI_CSICR1_RD(x) |  (v)))
#define HW_CSI_CSICR1_CLR(x, v)  (HW_CSI_CSICR1_WR(x, HW_CSI_CSICR1_RD(x) & ~(v)))
#define HW_CSI_CSICR1_TOG(x, v)  (HW_CSI_CSICR1_WR(x, HW_CSI_CSICR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSICR1 bitfields
 */

/*!
 * @name Register CSI_CSICR1, field PIXEL_BIT[0] (RW)
 *
 * Pixel Bit. This bit indicates the bayer data width for each pixel. This bit
 * should be configured before activating or re-starting the embedded DMA
 * controller.
 *
 * Values:
 * - 0 - 8-bit data for each pixel
 * - 1 - 10-bit data for each pixel
 */
/*@{*/
#define BP_CSI_CSICR1_PIXEL_BIT (0U)       /*!< Bit position for CSI_CSICR1_PIXEL_BIT. */
#define BM_CSI_CSICR1_PIXEL_BIT (0x00000001U) /*!< Bit mask for CSI_CSICR1_PIXEL_BIT. */
#define BS_CSI_CSICR1_PIXEL_BIT (1U)       /*!< Bit field size in bits for CSI_CSICR1_PIXEL_BIT. */

/*! @brief Read current value of the CSI_CSICR1_PIXEL_BIT field. */
#define BR_CSI_CSICR1_PIXEL_BIT(x) (HW_CSI_CSICR1(x).B.PIXEL_BIT)

/*! @brief Format value for bitfield CSI_CSICR1_PIXEL_BIT. */
#define BF_CSI_CSICR1_PIXEL_BIT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_PIXEL_BIT) & BM_CSI_CSICR1_PIXEL_BIT)

/*! @brief Set the PIXEL_BIT field to a new value. */
#define BW_CSI_CSICR1_PIXEL_BIT(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_PIXEL_BIT) | BF_CSI_CSICR1_PIXEL_BIT(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field REDGE[1] (RW)
 *
 * Valid Pixel Clock Edge Select. Selects which edge of the CSI_PIXCLK is used
 * to latch the pixel data.
 *
 * Values:
 * - 0 - Pixel data is latched at the falling edge of CSI_PIXCLK
 * - 1 - Pixel data is latched at the rising edge of CSI_PIXCLK
 */
/*@{*/
#define BP_CSI_CSICR1_REDGE  (1U)          /*!< Bit position for CSI_CSICR1_REDGE. */
#define BM_CSI_CSICR1_REDGE  (0x00000002U) /*!< Bit mask for CSI_CSICR1_REDGE. */
#define BS_CSI_CSICR1_REDGE  (1U)          /*!< Bit field size in bits for CSI_CSICR1_REDGE. */

/*! @brief Read current value of the CSI_CSICR1_REDGE field. */
#define BR_CSI_CSICR1_REDGE(x) (HW_CSI_CSICR1(x).B.REDGE)

/*! @brief Format value for bitfield CSI_CSICR1_REDGE. */
#define BF_CSI_CSICR1_REDGE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_REDGE) & BM_CSI_CSICR1_REDGE)

/*! @brief Set the REDGE field to a new value. */
#define BW_CSI_CSICR1_REDGE(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_REDGE) | BF_CSI_CSICR1_REDGE(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field INV_PCLK[2] (RW)
 *
 * Invert Pixel Clock Input. This bit determines if the Pixel Clock (CSI_PIXCLK)
 * is inverted before it is applied to the CSI module.
 *
 * Values:
 * - 0 - CSI_PIXCLK is directly applied to internal circuitry
 * - 1 - CSI_PIXCLK is inverted before applied to internal circuitry
 */
/*@{*/
#define BP_CSI_CSICR1_INV_PCLK (2U)        /*!< Bit position for CSI_CSICR1_INV_PCLK. */
#define BM_CSI_CSICR1_INV_PCLK (0x00000004U) /*!< Bit mask for CSI_CSICR1_INV_PCLK. */
#define BS_CSI_CSICR1_INV_PCLK (1U)        /*!< Bit field size in bits for CSI_CSICR1_INV_PCLK. */

/*! @brief Read current value of the CSI_CSICR1_INV_PCLK field. */
#define BR_CSI_CSICR1_INV_PCLK(x) (HW_CSI_CSICR1(x).B.INV_PCLK)

/*! @brief Format value for bitfield CSI_CSICR1_INV_PCLK. */
#define BF_CSI_CSICR1_INV_PCLK(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_INV_PCLK) & BM_CSI_CSICR1_INV_PCLK)

/*! @brief Set the INV_PCLK field to a new value. */
#define BW_CSI_CSICR1_INV_PCLK(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_INV_PCLK) | BF_CSI_CSICR1_INV_PCLK(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field INV_DATA[3] (RW)
 *
 * Invert Data Input. This bit enables or disables internal inverters on the
 * data lines.
 *
 * Values:
 * - 0 - CSI_D[7:0] data lines are directly applied to internal circuitry
 * - 1 - CSI_D[7:0] data lines are inverted before applied to internal circuitry
 */
/*@{*/
#define BP_CSI_CSICR1_INV_DATA (3U)        /*!< Bit position for CSI_CSICR1_INV_DATA. */
#define BM_CSI_CSICR1_INV_DATA (0x00000008U) /*!< Bit mask for CSI_CSICR1_INV_DATA. */
#define BS_CSI_CSICR1_INV_DATA (1U)        /*!< Bit field size in bits for CSI_CSICR1_INV_DATA. */

/*! @brief Read current value of the CSI_CSICR1_INV_DATA field. */
#define BR_CSI_CSICR1_INV_DATA(x) (HW_CSI_CSICR1(x).B.INV_DATA)

/*! @brief Format value for bitfield CSI_CSICR1_INV_DATA. */
#define BF_CSI_CSICR1_INV_DATA(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_INV_DATA) & BM_CSI_CSICR1_INV_DATA)

/*! @brief Set the INV_DATA field to a new value. */
#define BW_CSI_CSICR1_INV_DATA(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_INV_DATA) | BF_CSI_CSICR1_INV_DATA(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field GCLK_MODE[4] (RW)
 *
 * Gated Clock Mode Enable. Controls if CSI is working in gated or non-gated
 * mode. This bit works only in traditional mode-that is, CCIR_EN = 0. Otherwise
 * this bit is ignored.
 *
 * Values:
 * - 0 - Non-gated clock mode. All incoming pixel clocks are valid. HSYNC is
 *     ignored.
 * - 1 - Gated clock mode. Pixel clock signal is valid only when HSYNC is active.
 */
/*@{*/
#define BP_CSI_CSICR1_GCLK_MODE (4U)       /*!< Bit position for CSI_CSICR1_GCLK_MODE. */
#define BM_CSI_CSICR1_GCLK_MODE (0x00000010U) /*!< Bit mask for CSI_CSICR1_GCLK_MODE. */
#define BS_CSI_CSICR1_GCLK_MODE (1U)       /*!< Bit field size in bits for CSI_CSICR1_GCLK_MODE. */

/*! @brief Read current value of the CSI_CSICR1_GCLK_MODE field. */
#define BR_CSI_CSICR1_GCLK_MODE(x) (HW_CSI_CSICR1(x).B.GCLK_MODE)

/*! @brief Format value for bitfield CSI_CSICR1_GCLK_MODE. */
#define BF_CSI_CSICR1_GCLK_MODE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_GCLK_MODE) & BM_CSI_CSICR1_GCLK_MODE)

/*! @brief Set the GCLK_MODE field to a new value. */
#define BW_CSI_CSICR1_GCLK_MODE(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_GCLK_MODE) | BF_CSI_CSICR1_GCLK_MODE(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field CLR_RXFIFO[5] (RW)
 *
 * Asynchronous RXFIFO Clear. This bit clears the RXFIFO. This bit works only in
 * async FIFO clear mode-that is, FCC = 0. Otherwise this bit is ignored.
 * Writing 1 clears the RXFIFO immediately, RXFIFO restarts immediately after that. The
 * bit is restored to 0 automatically after finish. Normally reads 0.
 */
/*@{*/
#define BP_CSI_CSICR1_CLR_RXFIFO (5U)      /*!< Bit position for CSI_CSICR1_CLR_RXFIFO. */
#define BM_CSI_CSICR1_CLR_RXFIFO (0x00000020U) /*!< Bit mask for CSI_CSICR1_CLR_RXFIFO. */
#define BS_CSI_CSICR1_CLR_RXFIFO (1U)      /*!< Bit field size in bits for CSI_CSICR1_CLR_RXFIFO. */

/*! @brief Read current value of the CSI_CSICR1_CLR_RXFIFO field. */
#define BR_CSI_CSICR1_CLR_RXFIFO(x) (HW_CSI_CSICR1(x).B.CLR_RXFIFO)

/*! @brief Format value for bitfield CSI_CSICR1_CLR_RXFIFO. */
#define BF_CSI_CSICR1_CLR_RXFIFO(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_CLR_RXFIFO) & BM_CSI_CSICR1_CLR_RXFIFO)

/*! @brief Set the CLR_RXFIFO field to a new value. */
#define BW_CSI_CSICR1_CLR_RXFIFO(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_CLR_RXFIFO) | BF_CSI_CSICR1_CLR_RXFIFO(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field CLR_STATFIFO[6] (RW)
 *
 * Asynchronous STATFIFO Clear. This bit clears the STATFIFO and Reset STAT
 * block. This bit works only in async FIFO clear mode-that is, FCC = 0. Otherwise
 * this bit is ignored. Writing 1 will clear STATFIFO and reset STAT block
 * immediately, STATFIFO and STAT block then wait and restart after the arrival of next
 * SOF. The bit is restored to 0 automatically after finish. Normally reads 0.
 */
/*@{*/
#define BP_CSI_CSICR1_CLR_STATFIFO (6U)    /*!< Bit position for CSI_CSICR1_CLR_STATFIFO. */
#define BM_CSI_CSICR1_CLR_STATFIFO (0x00000040U) /*!< Bit mask for CSI_CSICR1_CLR_STATFIFO. */
#define BS_CSI_CSICR1_CLR_STATFIFO (1U)    /*!< Bit field size in bits for CSI_CSICR1_CLR_STATFIFO. */

/*! @brief Read current value of the CSI_CSICR1_CLR_STATFIFO field. */
#define BR_CSI_CSICR1_CLR_STATFIFO(x) (HW_CSI_CSICR1(x).B.CLR_STATFIFO)

/*! @brief Format value for bitfield CSI_CSICR1_CLR_STATFIFO. */
#define BF_CSI_CSICR1_CLR_STATFIFO(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_CLR_STATFIFO) & BM_CSI_CSICR1_CLR_STATFIFO)

/*! @brief Set the CLR_STATFIFO field to a new value. */
#define BW_CSI_CSICR1_CLR_STATFIFO(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_CLR_STATFIFO) | BF_CSI_CSICR1_CLR_STATFIFO(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field PACK_DIR[7] (RW)
 *
 * Data Packing Direction. This bit Controls how 8-bit/10-bit image data is
 * packed into 32-bit RX FIFO, and how 16-bit statistical data is packed into 32-bit
 * STAT FIFO.
 *
 * Values:
 * - 0 - Pack from LSB first. For image data, 0x11, 0x22, 0x33, 0x44, it will
 *     appear as 0x44332211 in RX FIFO. For stat data, 0xAAAA, 0xBBBB, it will
 *     appear as 0xBBBBAAAA in STAT FIFO.
 * - 1 - Pack from MSB first. For image data, 0x11, 0x22, 0x33, 0x44, it will
 *     appear as 0x11223344 in RX FIFO. For stat data, 0xAAAA, 0xBBBB, it will
 *     appear as 0xAAAABBBB in STAT FIFO.
 */
/*@{*/
#define BP_CSI_CSICR1_PACK_DIR (7U)        /*!< Bit position for CSI_CSICR1_PACK_DIR. */
#define BM_CSI_CSICR1_PACK_DIR (0x00000080U) /*!< Bit mask for CSI_CSICR1_PACK_DIR. */
#define BS_CSI_CSICR1_PACK_DIR (1U)        /*!< Bit field size in bits for CSI_CSICR1_PACK_DIR. */

/*! @brief Read current value of the CSI_CSICR1_PACK_DIR field. */
#define BR_CSI_CSICR1_PACK_DIR(x) (HW_CSI_CSICR1(x).B.PACK_DIR)

/*! @brief Format value for bitfield CSI_CSICR1_PACK_DIR. */
#define BF_CSI_CSICR1_PACK_DIR(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_PACK_DIR) & BM_CSI_CSICR1_PACK_DIR)

/*! @brief Set the PACK_DIR field to a new value. */
#define BW_CSI_CSICR1_PACK_DIR(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_PACK_DIR) | BF_CSI_CSICR1_PACK_DIR(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field FCC[8] (RW)
 *
 * FIFO Clear Control. This bit determines how the RXFIFO and STATFIFO are
 * cleared. When Synchronous FIFO clear is selected the RXFIFO and STATFIFO are
 * cleared, and STAT block is reset, on every SOF. FIFOs and STAT block restarts
 * immediately after reset. For information on the operation when Asynchronous FIFO
 * clear is selected, refer to the descriptions for the CLR_RXFIFO and CLR_STATFIFO
 * bits.
 *
 * Values:
 * - 0 - Asynchronous FIFO clear is selected.
 * - 1 - Synchronous FIFO clear is selected.
 */
/*@{*/
#define BP_CSI_CSICR1_FCC    (8U)          /*!< Bit position for CSI_CSICR1_FCC. */
#define BM_CSI_CSICR1_FCC    (0x00000100U) /*!< Bit mask for CSI_CSICR1_FCC. */
#define BS_CSI_CSICR1_FCC    (1U)          /*!< Bit field size in bits for CSI_CSICR1_FCC. */

/*! @brief Read current value of the CSI_CSICR1_FCC field. */
#define BR_CSI_CSICR1_FCC(x) (HW_CSI_CSICR1(x).B.FCC)

/*! @brief Format value for bitfield CSI_CSICR1_FCC. */
#define BF_CSI_CSICR1_FCC(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_FCC) & BM_CSI_CSICR1_FCC)

/*! @brief Set the FCC field to a new value. */
#define BW_CSI_CSICR1_FCC(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_FCC) | BF_CSI_CSICR1_FCC(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field CCIR_EN[10] (RW)
 *
 * CCIR656 Interface Enable. This bit selects the type of interface used. When
 * the CCIR656 timing decoder is enabled, it replaces the function of timing
 * interface logic.
 *
 * Values:
 * - 0 - Traditional interface is selected. Timing interface logic is used to
 *     latch data.
 * - 1 - CCIR656 interface is selected.
 */
/*@{*/
#define BP_CSI_CSICR1_CCIR_EN (10U)        /*!< Bit position for CSI_CSICR1_CCIR_EN. */
#define BM_CSI_CSICR1_CCIR_EN (0x00000400U) /*!< Bit mask for CSI_CSICR1_CCIR_EN. */
#define BS_CSI_CSICR1_CCIR_EN (1U)         /*!< Bit field size in bits for CSI_CSICR1_CCIR_EN. */

/*! @brief Read current value of the CSI_CSICR1_CCIR_EN field. */
#define BR_CSI_CSICR1_CCIR_EN(x) (HW_CSI_CSICR1(x).B.CCIR_EN)

/*! @brief Format value for bitfield CSI_CSICR1_CCIR_EN. */
#define BF_CSI_CSICR1_CCIR_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_CCIR_EN) & BM_CSI_CSICR1_CCIR_EN)

/*! @brief Set the CCIR_EN field to a new value. */
#define BW_CSI_CSICR1_CCIR_EN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_CCIR_EN) | BF_CSI_CSICR1_CCIR_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field HSYNC_POL[11] (RW)
 *
 * HSYNC Polarity Select. This bit controls the polarity of HSYNC. This bit only
 * works in gated-clock-that is, GCLK_MODE = 1 and CCIR_EN = 0.
 *
 * Values:
 * - 0 - HSYNC is active low
 * - 1 - HSYNC is active high
 */
/*@{*/
#define BP_CSI_CSICR1_HSYNC_POL (11U)      /*!< Bit position for CSI_CSICR1_HSYNC_POL. */
#define BM_CSI_CSICR1_HSYNC_POL (0x00000800U) /*!< Bit mask for CSI_CSICR1_HSYNC_POL. */
#define BS_CSI_CSICR1_HSYNC_POL (1U)       /*!< Bit field size in bits for CSI_CSICR1_HSYNC_POL. */

/*! @brief Read current value of the CSI_CSICR1_HSYNC_POL field. */
#define BR_CSI_CSICR1_HSYNC_POL(x) (HW_CSI_CSICR1(x).B.HSYNC_POL)

/*! @brief Format value for bitfield CSI_CSICR1_HSYNC_POL. */
#define BF_CSI_CSICR1_HSYNC_POL(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_HSYNC_POL) & BM_CSI_CSICR1_HSYNC_POL)

/*! @brief Set the HSYNC_POL field to a new value. */
#define BW_CSI_CSICR1_HSYNC_POL(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_HSYNC_POL) | BF_CSI_CSICR1_HSYNC_POL(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field SOF_INTEN[16] (RW)
 *
 * Start Of Frame (SOF) Interrupt Enable. This bit enables the SOF interrupt.
 *
 * Values:
 * - 0 - SOF interrupt disable
 * - 1 - SOF interrupt enable
 */
/*@{*/
#define BP_CSI_CSICR1_SOF_INTEN (16U)      /*!< Bit position for CSI_CSICR1_SOF_INTEN. */
#define BM_CSI_CSICR1_SOF_INTEN (0x00010000U) /*!< Bit mask for CSI_CSICR1_SOF_INTEN. */
#define BS_CSI_CSICR1_SOF_INTEN (1U)       /*!< Bit field size in bits for CSI_CSICR1_SOF_INTEN. */

/*! @brief Read current value of the CSI_CSICR1_SOF_INTEN field. */
#define BR_CSI_CSICR1_SOF_INTEN(x) (HW_CSI_CSICR1(x).B.SOF_INTEN)

/*! @brief Format value for bitfield CSI_CSICR1_SOF_INTEN. */
#define BF_CSI_CSICR1_SOF_INTEN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_SOF_INTEN) & BM_CSI_CSICR1_SOF_INTEN)

/*! @brief Set the SOF_INTEN field to a new value. */
#define BW_CSI_CSICR1_SOF_INTEN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_SOF_INTEN) | BF_CSI_CSICR1_SOF_INTEN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field SOF_POL[17] (RW)
 *
 * SOF Interrupt Polarity. This bit controls the condition that generates an SOF
 * interrupt.
 *
 * Values:
 * - 0 - SOF interrupt is generated on SOF falling edge
 * - 1 - SOF interrupt is generated on SOF rising edge
 */
/*@{*/
#define BP_CSI_CSICR1_SOF_POL (17U)        /*!< Bit position for CSI_CSICR1_SOF_POL. */
#define BM_CSI_CSICR1_SOF_POL (0x00020000U) /*!< Bit mask for CSI_CSICR1_SOF_POL. */
#define BS_CSI_CSICR1_SOF_POL (1U)         /*!< Bit field size in bits for CSI_CSICR1_SOF_POL. */

/*! @brief Read current value of the CSI_CSICR1_SOF_POL field. */
#define BR_CSI_CSICR1_SOF_POL(x) (HW_CSI_CSICR1(x).B.SOF_POL)

/*! @brief Format value for bitfield CSI_CSICR1_SOF_POL. */
#define BF_CSI_CSICR1_SOF_POL(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_SOF_POL) & BM_CSI_CSICR1_SOF_POL)

/*! @brief Set the SOF_POL field to a new value. */
#define BW_CSI_CSICR1_SOF_POL(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_SOF_POL) | BF_CSI_CSICR1_SOF_POL(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field RXFF_INTEN[18] (RW)
 *
 * RxFIFO Full Interrupt Enable. This bit enables the RxFIFO full interrupt.
 *
 * Values:
 * - 0 - RxFIFO full interrupt disable
 * - 1 - RxFIFO full interrupt enable
 */
/*@{*/
#define BP_CSI_CSICR1_RXFF_INTEN (18U)     /*!< Bit position for CSI_CSICR1_RXFF_INTEN. */
#define BM_CSI_CSICR1_RXFF_INTEN (0x00040000U) /*!< Bit mask for CSI_CSICR1_RXFF_INTEN. */
#define BS_CSI_CSICR1_RXFF_INTEN (1U)      /*!< Bit field size in bits for CSI_CSICR1_RXFF_INTEN. */

/*! @brief Read current value of the CSI_CSICR1_RXFF_INTEN field. */
#define BR_CSI_CSICR1_RXFF_INTEN(x) (HW_CSI_CSICR1(x).B.RXFF_INTEN)

/*! @brief Format value for bitfield CSI_CSICR1_RXFF_INTEN. */
#define BF_CSI_CSICR1_RXFF_INTEN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_RXFF_INTEN) & BM_CSI_CSICR1_RXFF_INTEN)

/*! @brief Set the RXFF_INTEN field to a new value. */
#define BW_CSI_CSICR1_RXFF_INTEN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_RXFF_INTEN) | BF_CSI_CSICR1_RXFF_INTEN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field FB1_DMA_DONE_INTEN[19] (RW)
 *
 * Frame Buffer1 DMA Transfer Done Interrupt Enable. This bit enables the
 * interrupt of Frame Buffer1 DMA transfer done.
 *
 * Values:
 * - 0 - Frame Buffer1 DMA Transfer Done interrupt disable
 * - 1 - Frame Buffer1 DMA Transfer Done interrupt enable
 */
/*@{*/
#define BP_CSI_CSICR1_FB1_DMA_DONE_INTEN (19U) /*!< Bit position for CSI_CSICR1_FB1_DMA_DONE_INTEN. */
#define BM_CSI_CSICR1_FB1_DMA_DONE_INTEN (0x00080000U) /*!< Bit mask for CSI_CSICR1_FB1_DMA_DONE_INTEN. */
#define BS_CSI_CSICR1_FB1_DMA_DONE_INTEN (1U) /*!< Bit field size in bits for CSI_CSICR1_FB1_DMA_DONE_INTEN. */

/*! @brief Read current value of the CSI_CSICR1_FB1_DMA_DONE_INTEN field. */
#define BR_CSI_CSICR1_FB1_DMA_DONE_INTEN(x) (HW_CSI_CSICR1(x).B.FB1_DMA_DONE_INTEN)

/*! @brief Format value for bitfield CSI_CSICR1_FB1_DMA_DONE_INTEN. */
#define BF_CSI_CSICR1_FB1_DMA_DONE_INTEN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_FB1_DMA_DONE_INTEN) & BM_CSI_CSICR1_FB1_DMA_DONE_INTEN)

/*! @brief Set the FB1_DMA_DONE_INTEN field to a new value. */
#define BW_CSI_CSICR1_FB1_DMA_DONE_INTEN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_FB1_DMA_DONE_INTEN) | BF_CSI_CSICR1_FB1_DMA_DONE_INTEN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field FB2_DMA_DONE_INTEN[20] (RW)
 *
 * Frame Buffer2 DMA Transfer Done Interrupt Enable. This bit enables the
 * interrupt of Frame Buffer2 DMA transfer done.
 *
 * Values:
 * - 0 - Frame Buffer2 DMA Transfer Done interrupt disable
 * - 1 - Frame Buffer2 DMA Transfer Done interrupt enable
 */
/*@{*/
#define BP_CSI_CSICR1_FB2_DMA_DONE_INTEN (20U) /*!< Bit position for CSI_CSICR1_FB2_DMA_DONE_INTEN. */
#define BM_CSI_CSICR1_FB2_DMA_DONE_INTEN (0x00100000U) /*!< Bit mask for CSI_CSICR1_FB2_DMA_DONE_INTEN. */
#define BS_CSI_CSICR1_FB2_DMA_DONE_INTEN (1U) /*!< Bit field size in bits for CSI_CSICR1_FB2_DMA_DONE_INTEN. */

/*! @brief Read current value of the CSI_CSICR1_FB2_DMA_DONE_INTEN field. */
#define BR_CSI_CSICR1_FB2_DMA_DONE_INTEN(x) (HW_CSI_CSICR1(x).B.FB2_DMA_DONE_INTEN)

/*! @brief Format value for bitfield CSI_CSICR1_FB2_DMA_DONE_INTEN. */
#define BF_CSI_CSICR1_FB2_DMA_DONE_INTEN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_FB2_DMA_DONE_INTEN) & BM_CSI_CSICR1_FB2_DMA_DONE_INTEN)

/*! @brief Set the FB2_DMA_DONE_INTEN field to a new value. */
#define BW_CSI_CSICR1_FB2_DMA_DONE_INTEN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_FB2_DMA_DONE_INTEN) | BF_CSI_CSICR1_FB2_DMA_DONE_INTEN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field STATFF_INTEN[21] (RW)
 *
 * STATFIFO Full Interrupt Enable. This bit enables the STAT FIFO interrupt.
 *
 * Values:
 * - 0 - STATFIFO full interrupt disable
 * - 1 - STATFIFO full interrupt enable
 */
/*@{*/
#define BP_CSI_CSICR1_STATFF_INTEN (21U)   /*!< Bit position for CSI_CSICR1_STATFF_INTEN. */
#define BM_CSI_CSICR1_STATFF_INTEN (0x00200000U) /*!< Bit mask for CSI_CSICR1_STATFF_INTEN. */
#define BS_CSI_CSICR1_STATFF_INTEN (1U)    /*!< Bit field size in bits for CSI_CSICR1_STATFF_INTEN. */

/*! @brief Read current value of the CSI_CSICR1_STATFF_INTEN field. */
#define BR_CSI_CSICR1_STATFF_INTEN(x) (HW_CSI_CSICR1(x).B.STATFF_INTEN)

/*! @brief Format value for bitfield CSI_CSICR1_STATFF_INTEN. */
#define BF_CSI_CSICR1_STATFF_INTEN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_STATFF_INTEN) & BM_CSI_CSICR1_STATFF_INTEN)

/*! @brief Set the STATFF_INTEN field to a new value. */
#define BW_CSI_CSICR1_STATFF_INTEN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_STATFF_INTEN) | BF_CSI_CSICR1_STATFF_INTEN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field SFF_DMA_DONE_INTEN[22] (RW)
 *
 * STATFIFO DMA Transfer Done Interrupt Enable. This bit enables the interrupt
 * of STATFIFO DMA transfer done.
 *
 * Values:
 * - 0 - STATFIFO DMA Transfer Done interrupt disable
 * - 1 - STATFIFO DMA Transfer Done interrupt enable
 */
/*@{*/
#define BP_CSI_CSICR1_SFF_DMA_DONE_INTEN (22U) /*!< Bit position for CSI_CSICR1_SFF_DMA_DONE_INTEN. */
#define BM_CSI_CSICR1_SFF_DMA_DONE_INTEN (0x00400000U) /*!< Bit mask for CSI_CSICR1_SFF_DMA_DONE_INTEN. */
#define BS_CSI_CSICR1_SFF_DMA_DONE_INTEN (1U) /*!< Bit field size in bits for CSI_CSICR1_SFF_DMA_DONE_INTEN. */

/*! @brief Read current value of the CSI_CSICR1_SFF_DMA_DONE_INTEN field. */
#define BR_CSI_CSICR1_SFF_DMA_DONE_INTEN(x) (HW_CSI_CSICR1(x).B.SFF_DMA_DONE_INTEN)

/*! @brief Format value for bitfield CSI_CSICR1_SFF_DMA_DONE_INTEN. */
#define BF_CSI_CSICR1_SFF_DMA_DONE_INTEN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_SFF_DMA_DONE_INTEN) & BM_CSI_CSICR1_SFF_DMA_DONE_INTEN)

/*! @brief Set the SFF_DMA_DONE_INTEN field to a new value. */
#define BW_CSI_CSICR1_SFF_DMA_DONE_INTEN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_SFF_DMA_DONE_INTEN) | BF_CSI_CSICR1_SFF_DMA_DONE_INTEN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field RF_OR_INTEN[24] (RW)
 *
 * RxFIFO Overrun Interrupt Enable. This bit enables the RX FIFO overrun
 * interrupt.
 *
 * Values:
 * - 0 - RxFIFO overrun interrupt is disabled
 * - 1 - RxFIFO overrun interrupt is enabled
 */
/*@{*/
#define BP_CSI_CSICR1_RF_OR_INTEN (24U)    /*!< Bit position for CSI_CSICR1_RF_OR_INTEN. */
#define BM_CSI_CSICR1_RF_OR_INTEN (0x01000000U) /*!< Bit mask for CSI_CSICR1_RF_OR_INTEN. */
#define BS_CSI_CSICR1_RF_OR_INTEN (1U)     /*!< Bit field size in bits for CSI_CSICR1_RF_OR_INTEN. */

/*! @brief Read current value of the CSI_CSICR1_RF_OR_INTEN field. */
#define BR_CSI_CSICR1_RF_OR_INTEN(x) (HW_CSI_CSICR1(x).B.RF_OR_INTEN)

/*! @brief Format value for bitfield CSI_CSICR1_RF_OR_INTEN. */
#define BF_CSI_CSICR1_RF_OR_INTEN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_RF_OR_INTEN) & BM_CSI_CSICR1_RF_OR_INTEN)

/*! @brief Set the RF_OR_INTEN field to a new value. */
#define BW_CSI_CSICR1_RF_OR_INTEN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_RF_OR_INTEN) | BF_CSI_CSICR1_RF_OR_INTEN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field SF_OR_INTEN[25] (RW)
 *
 * STAT FIFO Overrun Interrupt Enable. This bit enables the STATFIFO overrun
 * interrupt.
 *
 * Values:
 * - 0 - STATFIFO overrun interrupt is disabled
 * - 1 - STATFIFO overrun interrupt is enabled
 */
/*@{*/
#define BP_CSI_CSICR1_SF_OR_INTEN (25U)    /*!< Bit position for CSI_CSICR1_SF_OR_INTEN. */
#define BM_CSI_CSICR1_SF_OR_INTEN (0x02000000U) /*!< Bit mask for CSI_CSICR1_SF_OR_INTEN. */
#define BS_CSI_CSICR1_SF_OR_INTEN (1U)     /*!< Bit field size in bits for CSI_CSICR1_SF_OR_INTEN. */

/*! @brief Read current value of the CSI_CSICR1_SF_OR_INTEN field. */
#define BR_CSI_CSICR1_SF_OR_INTEN(x) (HW_CSI_CSICR1(x).B.SF_OR_INTEN)

/*! @brief Format value for bitfield CSI_CSICR1_SF_OR_INTEN. */
#define BF_CSI_CSICR1_SF_OR_INTEN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_SF_OR_INTEN) & BM_CSI_CSICR1_SF_OR_INTEN)

/*! @brief Set the SF_OR_INTEN field to a new value. */
#define BW_CSI_CSICR1_SF_OR_INTEN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_SF_OR_INTEN) | BF_CSI_CSICR1_SF_OR_INTEN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field COF_INT_EN[26] (RW)
 *
 * Change Of Image Field (COF) Interrupt Enable. This bit enables the COF
 * interrupt. This bit works only in CCIR interlace mode which is when CCIR_EN = 1 and
 * CCIR_MODE = 1.
 *
 * Values:
 * - 0 - COF interrupt is disabled
 * - 1 - COF interrupt is enabled
 */
/*@{*/
#define BP_CSI_CSICR1_COF_INT_EN (26U)     /*!< Bit position for CSI_CSICR1_COF_INT_EN. */
#define BM_CSI_CSICR1_COF_INT_EN (0x04000000U) /*!< Bit mask for CSI_CSICR1_COF_INT_EN. */
#define BS_CSI_CSICR1_COF_INT_EN (1U)      /*!< Bit field size in bits for CSI_CSICR1_COF_INT_EN. */

/*! @brief Read current value of the CSI_CSICR1_COF_INT_EN field. */
#define BR_CSI_CSICR1_COF_INT_EN(x) (HW_CSI_CSICR1(x).B.COF_INT_EN)

/*! @brief Format value for bitfield CSI_CSICR1_COF_INT_EN. */
#define BF_CSI_CSICR1_COF_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_COF_INT_EN) & BM_CSI_CSICR1_COF_INT_EN)

/*! @brief Set the COF_INT_EN field to a new value. */
#define BW_CSI_CSICR1_COF_INT_EN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_COF_INT_EN) | BF_CSI_CSICR1_COF_INT_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field VIDEO_MODE[27] (RW)
 *
 * Video mode select. This bit controls the video mode in CCIR mode and TV
 * decoder input.
 *
 * Values:
 * - 0 - Progressive mode is selected
 * - 1 - Interlace mode is selected
 */
/*@{*/
#define BP_CSI_CSICR1_VIDEO_MODE (27U)     /*!< Bit position for CSI_CSICR1_VIDEO_MODE. */
#define BM_CSI_CSICR1_VIDEO_MODE (0x08000000U) /*!< Bit mask for CSI_CSICR1_VIDEO_MODE. */
#define BS_CSI_CSICR1_VIDEO_MODE (1U)      /*!< Bit field size in bits for CSI_CSICR1_VIDEO_MODE. */

/*! @brief Read current value of the CSI_CSICR1_VIDEO_MODE field. */
#define BR_CSI_CSICR1_VIDEO_MODE(x) (HW_CSI_CSICR1(x).B.VIDEO_MODE)

/*! @brief Format value for bitfield CSI_CSICR1_VIDEO_MODE. */
#define BF_CSI_CSICR1_VIDEO_MODE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_VIDEO_MODE) & BM_CSI_CSICR1_VIDEO_MODE)

/*! @brief Set the VIDEO_MODE field to a new value. */
#define BW_CSI_CSICR1_VIDEO_MODE(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_VIDEO_MODE) | BF_CSI_CSICR1_VIDEO_MODE(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field PrP_IF_EN[28] (RW)
 *
 * CSI-PrP Interface Enable. This bit controls the CSI to PrP bus. When enabled
 * the RxFIFO is detached from the AHB bus and connected to PrP. All CPU reads or
 * DMA accesses to the RxFIFO register are ignored. All CSI interrupts are also
 * masked.
 *
 * Values:
 * - 0 - CSI to PrP bus is disabled
 * - 1 - CSI to PrP bus is enabled
 */
/*@{*/
#define BP_CSI_CSICR1_PrP_IF_EN (28U)      /*!< Bit position for CSI_CSICR1_PrP_IF_EN. */
#define BM_CSI_CSICR1_PrP_IF_EN (0x10000000U) /*!< Bit mask for CSI_CSICR1_PrP_IF_EN. */
#define BS_CSI_CSICR1_PrP_IF_EN (1U)       /*!< Bit field size in bits for CSI_CSICR1_PrP_IF_EN. */

/*! @brief Read current value of the CSI_CSICR1_PrP_IF_EN field. */
#define BR_CSI_CSICR1_PrP_IF_EN(x) (HW_CSI_CSICR1(x).B.PrP_IF_EN)

/*! @brief Format value for bitfield CSI_CSICR1_PrP_IF_EN. */
#define BF_CSI_CSICR1_PrP_IF_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_PrP_IF_EN) & BM_CSI_CSICR1_PrP_IF_EN)

/*! @brief Set the PrP_IF_EN field to a new value. */
#define BW_CSI_CSICR1_PrP_IF_EN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_PrP_IF_EN) | BF_CSI_CSICR1_PrP_IF_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field EOF_INT_EN[29] (RW)
 *
 * End-of-Frame Interrupt Enable. This bit enables and disables the EOF
 * interrupt.
 *
 * Values:
 * - 0 - EOF interrupt is disabled.
 * - 1 - EOF interrupt is generated when RX count value is reached.
 */
/*@{*/
#define BP_CSI_CSICR1_EOF_INT_EN (29U)     /*!< Bit position for CSI_CSICR1_EOF_INT_EN. */
#define BM_CSI_CSICR1_EOF_INT_EN (0x20000000U) /*!< Bit mask for CSI_CSICR1_EOF_INT_EN. */
#define BS_CSI_CSICR1_EOF_INT_EN (1U)      /*!< Bit field size in bits for CSI_CSICR1_EOF_INT_EN. */

/*! @brief Read current value of the CSI_CSICR1_EOF_INT_EN field. */
#define BR_CSI_CSICR1_EOF_INT_EN(x) (HW_CSI_CSICR1(x).B.EOF_INT_EN)

/*! @brief Format value for bitfield CSI_CSICR1_EOF_INT_EN. */
#define BF_CSI_CSICR1_EOF_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_EOF_INT_EN) & BM_CSI_CSICR1_EOF_INT_EN)

/*! @brief Set the EOF_INT_EN field to a new value. */
#define BW_CSI_CSICR1_EOF_INT_EN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_EOF_INT_EN) | BF_CSI_CSICR1_EOF_INT_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field EXT_VSYNC[30] (RW)
 *
 * External VSYNC Enable. This bit controls the operational VSYNC mode. This
 * only works when the CSI is in CCIR progressive mode.
 *
 * Values:
 * - 0 - Internal VSYNC mode
 * - 1 - External VSYNC mode
 */
/*@{*/
#define BP_CSI_CSICR1_EXT_VSYNC (30U)      /*!< Bit position for CSI_CSICR1_EXT_VSYNC. */
#define BM_CSI_CSICR1_EXT_VSYNC (0x40000000U) /*!< Bit mask for CSI_CSICR1_EXT_VSYNC. */
#define BS_CSI_CSICR1_EXT_VSYNC (1U)       /*!< Bit field size in bits for CSI_CSICR1_EXT_VSYNC. */

/*! @brief Read current value of the CSI_CSICR1_EXT_VSYNC field. */
#define BR_CSI_CSICR1_EXT_VSYNC(x) (HW_CSI_CSICR1(x).B.EXT_VSYNC)

/*! @brief Format value for bitfield CSI_CSICR1_EXT_VSYNC. */
#define BF_CSI_CSICR1_EXT_VSYNC(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_EXT_VSYNC) & BM_CSI_CSICR1_EXT_VSYNC)

/*! @brief Set the EXT_VSYNC field to a new value. */
#define BW_CSI_CSICR1_EXT_VSYNC(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_EXT_VSYNC) | BF_CSI_CSICR1_EXT_VSYNC(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR1, field SWAP16_EN[31] (RW)
 *
 * SWAP 16-Bit Enable. This bit enables the swapping of 16-bit data. Data is
 * packed from 8-bit or 10-bit to 32-bit first (according to the setting of
 * PACK_DIR) and then swapped as 16-bit words before being put into the RX FIFO. The
 * action of the bit only affects the RX FIFO and has no affect on the STAT FIFO.
 * Example of swapping enabled: Data input to FIFO = 0x11223344 Data in RX FIFO = 0x
 * 33441122 Example of swapping disabled: Data input to FIFO = 0x11223344 Data
 * in RX FIFO = 0x11223344
 *
 * Values:
 * - 0 - Disable swapping
 * - 1 - Enable swapping
 */
/*@{*/
#define BP_CSI_CSICR1_SWAP16_EN (31U)      /*!< Bit position for CSI_CSICR1_SWAP16_EN. */
#define BM_CSI_CSICR1_SWAP16_EN (0x80000000U) /*!< Bit mask for CSI_CSICR1_SWAP16_EN. */
#define BS_CSI_CSICR1_SWAP16_EN (1U)       /*!< Bit field size in bits for CSI_CSICR1_SWAP16_EN. */

/*! @brief Read current value of the CSI_CSICR1_SWAP16_EN field. */
#define BR_CSI_CSICR1_SWAP16_EN(x) (HW_CSI_CSICR1(x).B.SWAP16_EN)

/*! @brief Format value for bitfield CSI_CSICR1_SWAP16_EN. */
#define BF_CSI_CSICR1_SWAP16_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR1_SWAP16_EN) & BM_CSI_CSICR1_SWAP16_EN)

/*! @brief Set the SWAP16_EN field to a new value. */
#define BW_CSI_CSICR1_SWAP16_EN(x, v) (HW_CSI_CSICR1_WR(x, (HW_CSI_CSICR1_RD(x) & ~BM_CSI_CSICR1_SWAP16_EN) | BF_CSI_CSICR1_SWAP16_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSICR2 - CSI Control Register 2
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSICR2 - CSI Control Register 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the statistic block with data about which live view
 * resolution is being used, and the starting sensor pixel of the Bayer pattern. It
 * also contains the horizontal and vertical count used to determine the number
 * of pixels to skip between the 64 x 64 blocks of statistics when generating
 * statistics on live view image that are greater than 512 x 384.
 */
typedef union _hw_csi_csicr2
{
    uint32_t U;
    struct _hw_csi_csicr2_bitfields
    {
        uint32_t HSC : 8;              /*!< [7:0]  */
        uint32_t VSC : 8;              /*!< [15:8]  */
        uint32_t LVRM : 3;             /*!< [18:16]  */
        uint32_t BTS : 2;              /*!< [20:19]  */
        uint32_t RESERVED0 : 2;        /*!< [22:21]  */
        uint32_t SCE : 1;              /*!< [23]  */
        uint32_t AFS : 2;              /*!< [25:24]  */
        uint32_t DRM : 1;              /*!< [26]  */
        uint32_t RESERVED1 : 1;        /*!< [27]  */
        uint32_t DMA_BURST_TYPE_SFF : 2; /*!< [29:28]  */
        uint32_t DMA_BURST_TYPE_RFF : 2; /*!< [31:30]  */
    } B;
} hw_csi_csicr2_t;

/*!
 * @name Constants and macros for entire CSI_CSICR2 register
 */
/*@{*/
#define HW_CSI_CSICR2_ADDR(x)    ((uintptr_t)(x) + 0x4U)

#define HW_CSI_CSICR2(x)         (*(__IO hw_csi_csicr2_t *) HW_CSI_CSICR2_ADDR(x))
#define HW_CSI_CSICR2_RD(x)      (HW_CSI_CSICR2(x).U)
#define HW_CSI_CSICR2_WR(x, v)   (HW_CSI_CSICR2(x).U = (v))
#define HW_CSI_CSICR2_SET(x, v)  (HW_CSI_CSICR2_WR(x, HW_CSI_CSICR2_RD(x) |  (v)))
#define HW_CSI_CSICR2_CLR(x, v)  (HW_CSI_CSICR2_WR(x, HW_CSI_CSICR2_RD(x) & ~(v)))
#define HW_CSI_CSICR2_TOG(x, v)  (HW_CSI_CSICR2_WR(x, HW_CSI_CSICR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSICR2 bitfields
 */

/*!
 * @name Register CSI_CSICR2, field HSC[7:0] (RW)
 *
 * Horizontal Skip Count. Contains the number of pixels to skip. SCE must be 1,
 * otherwise HSC is ignored.
 */
/*@{*/
#define BP_CSI_CSICR2_HSC    (0U)          /*!< Bit position for CSI_CSICR2_HSC. */
#define BM_CSI_CSICR2_HSC    (0x000000FFU) /*!< Bit mask for CSI_CSICR2_HSC. */
#define BS_CSI_CSICR2_HSC    (8U)          /*!< Bit field size in bits for CSI_CSICR2_HSC. */

/*! @brief Read current value of the CSI_CSICR2_HSC field. */
#define BR_CSI_CSICR2_HSC(x) (HW_CSI_CSICR2(x).B.HSC)

/*! @brief Format value for bitfield CSI_CSICR2_HSC. */
#define BF_CSI_CSICR2_HSC(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR2_HSC) & BM_CSI_CSICR2_HSC)

/*! @brief Set the HSC field to a new value. */
#define BW_CSI_CSICR2_HSC(x, v) (HW_CSI_CSICR2_WR(x, (HW_CSI_CSICR2_RD(x) & ~BM_CSI_CSICR2_HSC) | BF_CSI_CSICR2_HSC(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR2, field VSC[15:8] (RW)
 *
 * Vertical Skip Count. Contains the number of rows to skip. SCE must be 1,
 * otherwise VSC is ignored.
 */
/*@{*/
#define BP_CSI_CSICR2_VSC    (8U)          /*!< Bit position for CSI_CSICR2_VSC. */
#define BM_CSI_CSICR2_VSC    (0x0000FF00U) /*!< Bit mask for CSI_CSICR2_VSC. */
#define BS_CSI_CSICR2_VSC    (8U)          /*!< Bit field size in bits for CSI_CSICR2_VSC. */

/*! @brief Read current value of the CSI_CSICR2_VSC field. */
#define BR_CSI_CSICR2_VSC(x) (HW_CSI_CSICR2(x).B.VSC)

/*! @brief Format value for bitfield CSI_CSICR2_VSC. */
#define BF_CSI_CSICR2_VSC(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR2_VSC) & BM_CSI_CSICR2_VSC)

/*! @brief Set the VSC field to a new value. */
#define BW_CSI_CSICR2_VSC(x, v) (HW_CSI_CSICR2_WR(x, (HW_CSI_CSICR2_RD(x) & ~BM_CSI_CSICR2_VSC) | BF_CSI_CSICR2_VSC(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR2, field LVRM[18:16] (RW)
 *
 * Live View Resolution Mode. Selects the grid size used for live view
 * resolution.
 *
 * Values:
 * - 0 - 512 x 384
 * - 1 - 448 x 336
 */
/*@{*/
#define BP_CSI_CSICR2_LVRM   (16U)         /*!< Bit position for CSI_CSICR2_LVRM. */
#define BM_CSI_CSICR2_LVRM   (0x00070000U) /*!< Bit mask for CSI_CSICR2_LVRM. */
#define BS_CSI_CSICR2_LVRM   (3U)          /*!< Bit field size in bits for CSI_CSICR2_LVRM. */

/*! @brief Read current value of the CSI_CSICR2_LVRM field. */
#define BR_CSI_CSICR2_LVRM(x) (HW_CSI_CSICR2(x).B.LVRM)

/*! @brief Format value for bitfield CSI_CSICR2_LVRM. */
#define BF_CSI_CSICR2_LVRM(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR2_LVRM) & BM_CSI_CSICR2_LVRM)

/*! @brief Set the LVRM field to a new value. */
#define BW_CSI_CSICR2_LVRM(x, v) (HW_CSI_CSICR2_WR(x, (HW_CSI_CSICR2_RD(x) & ~BM_CSI_CSICR2_LVRM) | BF_CSI_CSICR2_LVRM(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR2, field BTS[20:19] (RW)
 *
 * Bayer Tile Start. Controls the Bayer pattern starting point.
 *
 * Values:
 * - 00 - GR
 * - 01 - RG
 * - 10 - BG
 * - 11 - GB
 */
/*@{*/
#define BP_CSI_CSICR2_BTS    (19U)         /*!< Bit position for CSI_CSICR2_BTS. */
#define BM_CSI_CSICR2_BTS    (0x00180000U) /*!< Bit mask for CSI_CSICR2_BTS. */
#define BS_CSI_CSICR2_BTS    (2U)          /*!< Bit field size in bits for CSI_CSICR2_BTS. */

/*! @brief Read current value of the CSI_CSICR2_BTS field. */
#define BR_CSI_CSICR2_BTS(x) (HW_CSI_CSICR2(x).B.BTS)

/*! @brief Format value for bitfield CSI_CSICR2_BTS. */
#define BF_CSI_CSICR2_BTS(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR2_BTS) & BM_CSI_CSICR2_BTS)

/*! @brief Set the BTS field to a new value. */
#define BW_CSI_CSICR2_BTS(x, v) (HW_CSI_CSICR2_WR(x, (HW_CSI_CSICR2_RD(x) & ~BM_CSI_CSICR2_BTS) | BF_CSI_CSICR2_BTS(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR2, field SCE[23] (RW)
 *
 * Skip Count Enable. Enables or disables the skip count feature.
 *
 * Values:
 * - 0 - Skip count disable
 * - 1 - Skip count enable
 */
/*@{*/
#define BP_CSI_CSICR2_SCE    (23U)         /*!< Bit position for CSI_CSICR2_SCE. */
#define BM_CSI_CSICR2_SCE    (0x00800000U) /*!< Bit mask for CSI_CSICR2_SCE. */
#define BS_CSI_CSICR2_SCE    (1U)          /*!< Bit field size in bits for CSI_CSICR2_SCE. */

/*! @brief Read current value of the CSI_CSICR2_SCE field. */
#define BR_CSI_CSICR2_SCE(x) (HW_CSI_CSICR2(x).B.SCE)

/*! @brief Format value for bitfield CSI_CSICR2_SCE. */
#define BF_CSI_CSICR2_SCE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR2_SCE) & BM_CSI_CSICR2_SCE)

/*! @brief Set the SCE field to a new value. */
#define BW_CSI_CSICR2_SCE(x, v) (HW_CSI_CSICR2_WR(x, (HW_CSI_CSICR2_RD(x) & ~BM_CSI_CSICR2_SCE) | BF_CSI_CSICR2_SCE(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR2, field AFS[25:24] (RW)
 *
 * Auto Focus Spread. Selects which green pixels are used for auto-focus.
 *
 * Values:
 * - 00 - Abs Diff on consecutive green pixels
 * - 01 - Abs Diff on every third green pixels
 * - 1x - Abs Diff on every four green pixels
 */
/*@{*/
#define BP_CSI_CSICR2_AFS    (24U)         /*!< Bit position for CSI_CSICR2_AFS. */
#define BM_CSI_CSICR2_AFS    (0x03000000U) /*!< Bit mask for CSI_CSICR2_AFS. */
#define BS_CSI_CSICR2_AFS    (2U)          /*!< Bit field size in bits for CSI_CSICR2_AFS. */

/*! @brief Read current value of the CSI_CSICR2_AFS field. */
#define BR_CSI_CSICR2_AFS(x) (HW_CSI_CSICR2(x).B.AFS)

/*! @brief Format value for bitfield CSI_CSICR2_AFS. */
#define BF_CSI_CSICR2_AFS(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR2_AFS) & BM_CSI_CSICR2_AFS)

/*! @brief Set the AFS field to a new value. */
#define BW_CSI_CSICR2_AFS(x, v) (HW_CSI_CSICR2_WR(x, (HW_CSI_CSICR2_RD(x) & ~BM_CSI_CSICR2_AFS) | BF_CSI_CSICR2_AFS(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR2, field DRM[26] (RW)
 *
 * Double Resolution Mode. Controls size of statistics grid.
 *
 * Values:
 * - 0 - Stats grid of 8 x 6
 * - 1 - Stats grid of 8 x 12
 */
/*@{*/
#define BP_CSI_CSICR2_DRM    (26U)         /*!< Bit position for CSI_CSICR2_DRM. */
#define BM_CSI_CSICR2_DRM    (0x04000000U) /*!< Bit mask for CSI_CSICR2_DRM. */
#define BS_CSI_CSICR2_DRM    (1U)          /*!< Bit field size in bits for CSI_CSICR2_DRM. */

/*! @brief Read current value of the CSI_CSICR2_DRM field. */
#define BR_CSI_CSICR2_DRM(x) (HW_CSI_CSICR2(x).B.DRM)

/*! @brief Format value for bitfield CSI_CSICR2_DRM. */
#define BF_CSI_CSICR2_DRM(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR2_DRM) & BM_CSI_CSICR2_DRM)

/*! @brief Set the DRM field to a new value. */
#define BW_CSI_CSICR2_DRM(x, v) (HW_CSI_CSICR2_WR(x, (HW_CSI_CSICR2_RD(x) & ~BM_CSI_CSICR2_DRM) | BF_CSI_CSICR2_DRM(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR2, field DMA_BURST_TYPE_SFF[29:28] (RW)
 *
 * Burst Type of DMA Transfer from STATFIFO. Selects the burst type of DMA
 * transfer from STATFIFO.
 *
 * Values:
 * - 01 - INCR4
 * - 11 - INCR16
 */
/*@{*/
#define BP_CSI_CSICR2_DMA_BURST_TYPE_SFF (28U) /*!< Bit position for CSI_CSICR2_DMA_BURST_TYPE_SFF. */
#define BM_CSI_CSICR2_DMA_BURST_TYPE_SFF (0x30000000U) /*!< Bit mask for CSI_CSICR2_DMA_BURST_TYPE_SFF. */
#define BS_CSI_CSICR2_DMA_BURST_TYPE_SFF (2U) /*!< Bit field size in bits for CSI_CSICR2_DMA_BURST_TYPE_SFF. */

/*! @brief Read current value of the CSI_CSICR2_DMA_BURST_TYPE_SFF field. */
#define BR_CSI_CSICR2_DMA_BURST_TYPE_SFF(x) (HW_CSI_CSICR2(x).B.DMA_BURST_TYPE_SFF)

/*! @brief Format value for bitfield CSI_CSICR2_DMA_BURST_TYPE_SFF. */
#define BF_CSI_CSICR2_DMA_BURST_TYPE_SFF(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR2_DMA_BURST_TYPE_SFF) & BM_CSI_CSICR2_DMA_BURST_TYPE_SFF)

/*! @brief Set the DMA_BURST_TYPE_SFF field to a new value. */
#define BW_CSI_CSICR2_DMA_BURST_TYPE_SFF(x, v) (HW_CSI_CSICR2_WR(x, (HW_CSI_CSICR2_RD(x) & ~BM_CSI_CSICR2_DMA_BURST_TYPE_SFF) | BF_CSI_CSICR2_DMA_BURST_TYPE_SFF(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR2, field DMA_BURST_TYPE_RFF[31:30] (RW)
 *
 * Burst Type of DMA Transfer from RxFIFO. Selects the burst type of DMA
 * transfer from RxFIFO.
 *
 * Values:
 * - 01 - INCR4
 * - 11 - INCR16
 */
/*@{*/
#define BP_CSI_CSICR2_DMA_BURST_TYPE_RFF (30U) /*!< Bit position for CSI_CSICR2_DMA_BURST_TYPE_RFF. */
#define BM_CSI_CSICR2_DMA_BURST_TYPE_RFF (0xC0000000U) /*!< Bit mask for CSI_CSICR2_DMA_BURST_TYPE_RFF. */
#define BS_CSI_CSICR2_DMA_BURST_TYPE_RFF (2U) /*!< Bit field size in bits for CSI_CSICR2_DMA_BURST_TYPE_RFF. */

/*! @brief Read current value of the CSI_CSICR2_DMA_BURST_TYPE_RFF field. */
#define BR_CSI_CSICR2_DMA_BURST_TYPE_RFF(x) (HW_CSI_CSICR2(x).B.DMA_BURST_TYPE_RFF)

/*! @brief Format value for bitfield CSI_CSICR2_DMA_BURST_TYPE_RFF. */
#define BF_CSI_CSICR2_DMA_BURST_TYPE_RFF(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR2_DMA_BURST_TYPE_RFF) & BM_CSI_CSICR2_DMA_BURST_TYPE_RFF)

/*! @brief Set the DMA_BURST_TYPE_RFF field to a new value. */
#define BW_CSI_CSICR2_DMA_BURST_TYPE_RFF(x, v) (HW_CSI_CSICR2_WR(x, (HW_CSI_CSICR2_RD(x) & ~BM_CSI_CSICR2_DMA_BURST_TYPE_RFF) | BF_CSI_CSICR2_DMA_BURST_TYPE_RFF(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSICR3 - CSI Control Register 3
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSICR3 - CSI Control Register 3 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This read/write register acts as an extension of the functionality of the CSI
 * Control register 1, adding additional control and features.
 */
typedef union _hw_csi_csicr3
{
    uint32_t U;
    struct _hw_csi_csicr3_bitfields
    {
        uint32_t ECC_AUTO_EN : 1;      /*!< [0]  */
        uint32_t ECC_INT_EN : 1;       /*!< [1]  */
        uint32_t ZERO_PACK_EN : 1;     /*!< [2]  */
        uint32_t TWO_8BIT_SENSOR : 1;  /*!< [3]  */
        uint32_t RxFF_LEVEL : 3;       /*!< [6:4]  */
        uint32_t HRESP_ERR_EN : 1;     /*!< [7]  */
        uint32_t STATFF_LEVEL : 3;     /*!< [10:8]  */
        uint32_t DMA_REQ_EN_SFF : 1;   /*!< [11]  */
        uint32_t DMA_REQ_EN_RFF : 1;   /*!< [12]  */
        uint32_t DMA_REFLASH_SFF : 1;  /*!< [13]  */
        uint32_t DMA_REFLASH_RFF : 1;  /*!< [14]  */
        uint32_t FRMCNT_RST : 1;       /*!< [15]  */
        uint32_t FRMCNT : 16;          /*!< [31:16]  */
    } B;
} hw_csi_csicr3_t;

/*!
 * @name Constants and macros for entire CSI_CSICR3 register
 */
/*@{*/
#define HW_CSI_CSICR3_ADDR(x)    ((uintptr_t)(x) + 0x8U)

#define HW_CSI_CSICR3(x)         (*(__IO hw_csi_csicr3_t *) HW_CSI_CSICR3_ADDR(x))
#define HW_CSI_CSICR3_RD(x)      (HW_CSI_CSICR3(x).U)
#define HW_CSI_CSICR3_WR(x, v)   (HW_CSI_CSICR3(x).U = (v))
#define HW_CSI_CSICR3_SET(x, v)  (HW_CSI_CSICR3_WR(x, HW_CSI_CSICR3_RD(x) |  (v)))
#define HW_CSI_CSICR3_CLR(x, v)  (HW_CSI_CSICR3_WR(x, HW_CSI_CSICR3_RD(x) & ~(v)))
#define HW_CSI_CSICR3_TOG(x, v)  (HW_CSI_CSICR3_WR(x, HW_CSI_CSICR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSICR3 bitfields
 */

/*!
 * @name Register CSI_CSICR3, field ECC_AUTO_EN[0] (RW)
 *
 * Automatic Error Correction Enable. This bit enables and disables the
 * automatic error correction. If an error occurs and error correction is disabled only
 * the ECC_INT status bit is set. This feature only works in CCIR interlace mode.
 *
 * Values:
 * - 0 - Auto Error correction is disabled.
 * - 1 - Auto Error correction is enabled.
 */
/*@{*/
#define BP_CSI_CSICR3_ECC_AUTO_EN (0U)     /*!< Bit position for CSI_CSICR3_ECC_AUTO_EN. */
#define BM_CSI_CSICR3_ECC_AUTO_EN (0x00000001U) /*!< Bit mask for CSI_CSICR3_ECC_AUTO_EN. */
#define BS_CSI_CSICR3_ECC_AUTO_EN (1U)     /*!< Bit field size in bits for CSI_CSICR3_ECC_AUTO_EN. */

/*! @brief Read current value of the CSI_CSICR3_ECC_AUTO_EN field. */
#define BR_CSI_CSICR3_ECC_AUTO_EN(x) (HW_CSI_CSICR3(x).B.ECC_AUTO_EN)

/*! @brief Format value for bitfield CSI_CSICR3_ECC_AUTO_EN. */
#define BF_CSI_CSICR3_ECC_AUTO_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_ECC_AUTO_EN) & BM_CSI_CSICR3_ECC_AUTO_EN)

/*! @brief Set the ECC_AUTO_EN field to a new value. */
#define BW_CSI_CSICR3_ECC_AUTO_EN(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_ECC_AUTO_EN) | BF_CSI_CSICR3_ECC_AUTO_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field ECC_INT_EN[1] (RW)
 *
 * Error Detection Interrupt Enable. This bit enables and disables the error
 * detection interrupt. This feature only works in CCIR interlace mode.
 *
 * Values:
 * - 0 - No interrupt is generated when error is detected. Only the status bit
 *     ECC_INT is set.
 * - 1 - Interrupt is generated when error is detected.
 */
/*@{*/
#define BP_CSI_CSICR3_ECC_INT_EN (1U)      /*!< Bit position for CSI_CSICR3_ECC_INT_EN. */
#define BM_CSI_CSICR3_ECC_INT_EN (0x00000002U) /*!< Bit mask for CSI_CSICR3_ECC_INT_EN. */
#define BS_CSI_CSICR3_ECC_INT_EN (1U)      /*!< Bit field size in bits for CSI_CSICR3_ECC_INT_EN. */

/*! @brief Read current value of the CSI_CSICR3_ECC_INT_EN field. */
#define BR_CSI_CSICR3_ECC_INT_EN(x) (HW_CSI_CSICR3(x).B.ECC_INT_EN)

/*! @brief Format value for bitfield CSI_CSICR3_ECC_INT_EN. */
#define BF_CSI_CSICR3_ECC_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_ECC_INT_EN) & BM_CSI_CSICR3_ECC_INT_EN)

/*! @brief Set the ECC_INT_EN field to a new value. */
#define BW_CSI_CSICR3_ECC_INT_EN(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_ECC_INT_EN) | BF_CSI_CSICR3_ECC_INT_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field ZERO_PACK_EN[2] (RW)
 *
 * Dummy Zero Packing Enable. This bit causes a dummy zero to be packed with
 * every 3 incoming bytes, forming a 32-bit word. The dummy zero is always packed to
 * the LSB position. This packing function is only available in 8-bit/pixel mode.
 *
 * Values:
 * - 0 - Zero packing disabled
 * - 1 - Zero packing enabled
 */
/*@{*/
#define BP_CSI_CSICR3_ZERO_PACK_EN (2U)    /*!< Bit position for CSI_CSICR3_ZERO_PACK_EN. */
#define BM_CSI_CSICR3_ZERO_PACK_EN (0x00000004U) /*!< Bit mask for CSI_CSICR3_ZERO_PACK_EN. */
#define BS_CSI_CSICR3_ZERO_PACK_EN (1U)    /*!< Bit field size in bits for CSI_CSICR3_ZERO_PACK_EN. */

/*! @brief Read current value of the CSI_CSICR3_ZERO_PACK_EN field. */
#define BR_CSI_CSICR3_ZERO_PACK_EN(x) (HW_CSI_CSICR3(x).B.ZERO_PACK_EN)

/*! @brief Format value for bitfield CSI_CSICR3_ZERO_PACK_EN. */
#define BF_CSI_CSICR3_ZERO_PACK_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_ZERO_PACK_EN) & BM_CSI_CSICR3_ZERO_PACK_EN)

/*! @brief Set the ZERO_PACK_EN field to a new value. */
#define BW_CSI_CSICR3_ZERO_PACK_EN(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_ZERO_PACK_EN) | BF_CSI_CSICR3_ZERO_PACK_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field TWO_8BIT_SENSOR[3] (RW)
 *
 * Two 8-bit Sensor Mode. This bit indicates one 16-bit sensor or two 8-bit
 * sensors are connected to the 16-bit data ports. This bit should be set if there is
 * one 16-bit sensor or two 8-bit sensors are connected. This bit should be
 * configured before activating or restarting the embedded DMA controller.
 *
 * Values:
 * - 0 - Only one sensor is connected.
 * - 1 - Two 8-bit sensors are connected or one 16-bit sensor is connected.
 */
/*@{*/
#define BP_CSI_CSICR3_TWO_8BIT_SENSOR (3U) /*!< Bit position for CSI_CSICR3_TWO_8BIT_SENSOR. */
#define BM_CSI_CSICR3_TWO_8BIT_SENSOR (0x00000008U) /*!< Bit mask for CSI_CSICR3_TWO_8BIT_SENSOR. */
#define BS_CSI_CSICR3_TWO_8BIT_SENSOR (1U) /*!< Bit field size in bits for CSI_CSICR3_TWO_8BIT_SENSOR. */

/*! @brief Read current value of the CSI_CSICR3_TWO_8BIT_SENSOR field. */
#define BR_CSI_CSICR3_TWO_8BIT_SENSOR(x) (HW_CSI_CSICR3(x).B.TWO_8BIT_SENSOR)

/*! @brief Format value for bitfield CSI_CSICR3_TWO_8BIT_SENSOR. */
#define BF_CSI_CSICR3_TWO_8BIT_SENSOR(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_TWO_8BIT_SENSOR) & BM_CSI_CSICR3_TWO_8BIT_SENSOR)

/*! @brief Set the TWO_8BIT_SENSOR field to a new value. */
#define BW_CSI_CSICR3_TWO_8BIT_SENSOR(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_TWO_8BIT_SENSOR) | BF_CSI_CSICR3_TWO_8BIT_SENSOR(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field RxFF_LEVEL[6:4] (RW)
 *
 * RxFIFO Full Level. When the number of data in RxFIFO reaches this level, a
 * RxFIFO full interrupt is generated, or an RXFIFO DMA request is sent.
 *
 * Values:
 * - 000 - 4 Double words
 * - 001 - 8 Double words
 * - 010 - 16 Double words
 * - 011 - 24 Double words
 * - 100 - 32 Double words
 * - 101 - 48 Double words
 * - 110 - 64 Double words
 * - 111 - 96 Double words
 */
/*@{*/
#define BP_CSI_CSICR3_RxFF_LEVEL (4U)      /*!< Bit position for CSI_CSICR3_RxFF_LEVEL. */
#define BM_CSI_CSICR3_RxFF_LEVEL (0x00000070U) /*!< Bit mask for CSI_CSICR3_RxFF_LEVEL. */
#define BS_CSI_CSICR3_RxFF_LEVEL (3U)      /*!< Bit field size in bits for CSI_CSICR3_RxFF_LEVEL. */

/*! @brief Read current value of the CSI_CSICR3_RxFF_LEVEL field. */
#define BR_CSI_CSICR3_RxFF_LEVEL(x) (HW_CSI_CSICR3(x).B.RxFF_LEVEL)

/*! @brief Format value for bitfield CSI_CSICR3_RxFF_LEVEL. */
#define BF_CSI_CSICR3_RxFF_LEVEL(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_RxFF_LEVEL) & BM_CSI_CSICR3_RxFF_LEVEL)

/*! @brief Set the RxFF_LEVEL field to a new value. */
#define BW_CSI_CSICR3_RxFF_LEVEL(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_RxFF_LEVEL) | BF_CSI_CSICR3_RxFF_LEVEL(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field HRESP_ERR_EN[7] (RW)
 *
 * Hresponse Error Enable. This bit enables the hresponse error interrupt.
 *
 * Values:
 * - 0 - Disable hresponse error interrupt
 * - 1 - Enable hresponse error interrupt
 */
/*@{*/
#define BP_CSI_CSICR3_HRESP_ERR_EN (7U)    /*!< Bit position for CSI_CSICR3_HRESP_ERR_EN. */
#define BM_CSI_CSICR3_HRESP_ERR_EN (0x00000080U) /*!< Bit mask for CSI_CSICR3_HRESP_ERR_EN. */
#define BS_CSI_CSICR3_HRESP_ERR_EN (1U)    /*!< Bit field size in bits for CSI_CSICR3_HRESP_ERR_EN. */

/*! @brief Read current value of the CSI_CSICR3_HRESP_ERR_EN field. */
#define BR_CSI_CSICR3_HRESP_ERR_EN(x) (HW_CSI_CSICR3(x).B.HRESP_ERR_EN)

/*! @brief Format value for bitfield CSI_CSICR3_HRESP_ERR_EN. */
#define BF_CSI_CSICR3_HRESP_ERR_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_HRESP_ERR_EN) & BM_CSI_CSICR3_HRESP_ERR_EN)

/*! @brief Set the HRESP_ERR_EN field to a new value. */
#define BW_CSI_CSICR3_HRESP_ERR_EN(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_HRESP_ERR_EN) | BF_CSI_CSICR3_HRESP_ERR_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field STATFF_LEVEL[10:8] (RW)
 *
 * STATFIFO Full Level. When the number of data in STATFIFO reach this level,
 * STATFIFO full interrupt is generated, or STATFIFO DMA request is sent.
 *
 * Values:
 * - 000 - 4 Double words
 * - 001 - 8 Double words
 * - 010 - 12 Double words
 * - 011 - 16 Double words
 * - 100 - 24 Double words
 * - 101 - 32 Double words
 * - 110 - 48 Double words
 * - 111 - 64 Double words
 */
/*@{*/
#define BP_CSI_CSICR3_STATFF_LEVEL (8U)    /*!< Bit position for CSI_CSICR3_STATFF_LEVEL. */
#define BM_CSI_CSICR3_STATFF_LEVEL (0x00000700U) /*!< Bit mask for CSI_CSICR3_STATFF_LEVEL. */
#define BS_CSI_CSICR3_STATFF_LEVEL (3U)    /*!< Bit field size in bits for CSI_CSICR3_STATFF_LEVEL. */

/*! @brief Read current value of the CSI_CSICR3_STATFF_LEVEL field. */
#define BR_CSI_CSICR3_STATFF_LEVEL(x) (HW_CSI_CSICR3(x).B.STATFF_LEVEL)

/*! @brief Format value for bitfield CSI_CSICR3_STATFF_LEVEL. */
#define BF_CSI_CSICR3_STATFF_LEVEL(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_STATFF_LEVEL) & BM_CSI_CSICR3_STATFF_LEVEL)

/*! @brief Set the STATFF_LEVEL field to a new value. */
#define BW_CSI_CSICR3_STATFF_LEVEL(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_STATFF_LEVEL) | BF_CSI_CSICR3_STATFF_LEVEL(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field DMA_REQ_EN_SFF[11] (RW)
 *
 * DMA Request Enable for STATFIFO. This bit enables the dma request from
 * STATFIFO to the embedded DMA controller.
 *
 * Values:
 * - 0 - Disable the dma request
 * - 1 - Enable the dma request
 */
/*@{*/
#define BP_CSI_CSICR3_DMA_REQ_EN_SFF (11U) /*!< Bit position for CSI_CSICR3_DMA_REQ_EN_SFF. */
#define BM_CSI_CSICR3_DMA_REQ_EN_SFF (0x00000800U) /*!< Bit mask for CSI_CSICR3_DMA_REQ_EN_SFF. */
#define BS_CSI_CSICR3_DMA_REQ_EN_SFF (1U)  /*!< Bit field size in bits for CSI_CSICR3_DMA_REQ_EN_SFF. */

/*! @brief Read current value of the CSI_CSICR3_DMA_REQ_EN_SFF field. */
#define BR_CSI_CSICR3_DMA_REQ_EN_SFF(x) (HW_CSI_CSICR3(x).B.DMA_REQ_EN_SFF)

/*! @brief Format value for bitfield CSI_CSICR3_DMA_REQ_EN_SFF. */
#define BF_CSI_CSICR3_DMA_REQ_EN_SFF(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_DMA_REQ_EN_SFF) & BM_CSI_CSICR3_DMA_REQ_EN_SFF)

/*! @brief Set the DMA_REQ_EN_SFF field to a new value. */
#define BW_CSI_CSICR3_DMA_REQ_EN_SFF(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_DMA_REQ_EN_SFF) | BF_CSI_CSICR3_DMA_REQ_EN_SFF(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field DMA_REQ_EN_RFF[12] (RW)
 *
 * DMA Request Enable for RxFIFO. This bit enables the dma request from RxFIFO
 * to the embedded DMA controller.
 *
 * Values:
 * - 0 - Disable the dma request
 * - 1 - Enable the dma request
 */
/*@{*/
#define BP_CSI_CSICR3_DMA_REQ_EN_RFF (12U) /*!< Bit position for CSI_CSICR3_DMA_REQ_EN_RFF. */
#define BM_CSI_CSICR3_DMA_REQ_EN_RFF (0x00001000U) /*!< Bit mask for CSI_CSICR3_DMA_REQ_EN_RFF. */
#define BS_CSI_CSICR3_DMA_REQ_EN_RFF (1U)  /*!< Bit field size in bits for CSI_CSICR3_DMA_REQ_EN_RFF. */

/*! @brief Read current value of the CSI_CSICR3_DMA_REQ_EN_RFF field. */
#define BR_CSI_CSICR3_DMA_REQ_EN_RFF(x) (HW_CSI_CSICR3(x).B.DMA_REQ_EN_RFF)

/*! @brief Format value for bitfield CSI_CSICR3_DMA_REQ_EN_RFF. */
#define BF_CSI_CSICR3_DMA_REQ_EN_RFF(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_DMA_REQ_EN_RFF) & BM_CSI_CSICR3_DMA_REQ_EN_RFF)

/*! @brief Set the DMA_REQ_EN_RFF field to a new value. */
#define BW_CSI_CSICR3_DMA_REQ_EN_RFF(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_DMA_REQ_EN_RFF) | BF_CSI_CSICR3_DMA_REQ_EN_RFF(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field DMA_REFLASH_SFF[13] (RW)
 *
 * Reflash DMA Controller for STATFIFO. This bit reflash the embedded DMA
 * controller for STATFIFO. It should be reflashed before the embedded DMA controller
 * starts to work. (Cleared automatically after reflashing is done)
 *
 * Values:
 * - 0 - No reflashing
 * - 1 - Reflash the embedded DMA controller
 */
/*@{*/
#define BP_CSI_CSICR3_DMA_REFLASH_SFF (13U) /*!< Bit position for CSI_CSICR3_DMA_REFLASH_SFF. */
#define BM_CSI_CSICR3_DMA_REFLASH_SFF (0x00002000U) /*!< Bit mask for CSI_CSICR3_DMA_REFLASH_SFF. */
#define BS_CSI_CSICR3_DMA_REFLASH_SFF (1U) /*!< Bit field size in bits for CSI_CSICR3_DMA_REFLASH_SFF. */

/*! @brief Read current value of the CSI_CSICR3_DMA_REFLASH_SFF field. */
#define BR_CSI_CSICR3_DMA_REFLASH_SFF(x) (HW_CSI_CSICR3(x).B.DMA_REFLASH_SFF)

/*! @brief Format value for bitfield CSI_CSICR3_DMA_REFLASH_SFF. */
#define BF_CSI_CSICR3_DMA_REFLASH_SFF(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_DMA_REFLASH_SFF) & BM_CSI_CSICR3_DMA_REFLASH_SFF)

/*! @brief Set the DMA_REFLASH_SFF field to a new value. */
#define BW_CSI_CSICR3_DMA_REFLASH_SFF(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_DMA_REFLASH_SFF) | BF_CSI_CSICR3_DMA_REFLASH_SFF(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field DMA_REFLASH_RFF[14] (RW)
 *
 * Reflash DMA Controller for RxFIFO. This bit reflash the embedded DMA
 * controller for RxFIFO. It should be reflashed before the embedded DMA controller
 * starts to work. (Cleared automatically after reflashing is done)
 *
 * Values:
 * - 0 - No reflashing
 * - 1 - Reflash the embedded DMA controller
 */
/*@{*/
#define BP_CSI_CSICR3_DMA_REFLASH_RFF (14U) /*!< Bit position for CSI_CSICR3_DMA_REFLASH_RFF. */
#define BM_CSI_CSICR3_DMA_REFLASH_RFF (0x00004000U) /*!< Bit mask for CSI_CSICR3_DMA_REFLASH_RFF. */
#define BS_CSI_CSICR3_DMA_REFLASH_RFF (1U) /*!< Bit field size in bits for CSI_CSICR3_DMA_REFLASH_RFF. */

/*! @brief Read current value of the CSI_CSICR3_DMA_REFLASH_RFF field. */
#define BR_CSI_CSICR3_DMA_REFLASH_RFF(x) (HW_CSI_CSICR3(x).B.DMA_REFLASH_RFF)

/*! @brief Format value for bitfield CSI_CSICR3_DMA_REFLASH_RFF. */
#define BF_CSI_CSICR3_DMA_REFLASH_RFF(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_DMA_REFLASH_RFF) & BM_CSI_CSICR3_DMA_REFLASH_RFF)

/*! @brief Set the DMA_REFLASH_RFF field to a new value. */
#define BW_CSI_CSICR3_DMA_REFLASH_RFF(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_DMA_REFLASH_RFF) | BF_CSI_CSICR3_DMA_REFLASH_RFF(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field FRMCNT_RST[15] (RW)
 *
 * Frame Count Reset. Resets the Frame Counter. (Cleared automatically after
 * reset is done)
 *
 * Values:
 * - 0 - Do not reset
 * - 1 - Reset frame counter immediately
 */
/*@{*/
#define BP_CSI_CSICR3_FRMCNT_RST (15U)     /*!< Bit position for CSI_CSICR3_FRMCNT_RST. */
#define BM_CSI_CSICR3_FRMCNT_RST (0x00008000U) /*!< Bit mask for CSI_CSICR3_FRMCNT_RST. */
#define BS_CSI_CSICR3_FRMCNT_RST (1U)      /*!< Bit field size in bits for CSI_CSICR3_FRMCNT_RST. */

/*! @brief Read current value of the CSI_CSICR3_FRMCNT_RST field. */
#define BR_CSI_CSICR3_FRMCNT_RST(x) (HW_CSI_CSICR3(x).B.FRMCNT_RST)

/*! @brief Format value for bitfield CSI_CSICR3_FRMCNT_RST. */
#define BF_CSI_CSICR3_FRMCNT_RST(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_FRMCNT_RST) & BM_CSI_CSICR3_FRMCNT_RST)

/*! @brief Set the FRMCNT_RST field to a new value. */
#define BW_CSI_CSICR3_FRMCNT_RST(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_FRMCNT_RST) | BF_CSI_CSICR3_FRMCNT_RST(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR3, field FRMCNT[31:16] (RW)
 *
 * Frame Counter. This is a 16-bit Frame Counter (Wraps around automatically
 * after reaching the maximum)
 */
/*@{*/
#define BP_CSI_CSICR3_FRMCNT (16U)         /*!< Bit position for CSI_CSICR3_FRMCNT. */
#define BM_CSI_CSICR3_FRMCNT (0xFFFF0000U) /*!< Bit mask for CSI_CSICR3_FRMCNT. */
#define BS_CSI_CSICR3_FRMCNT (16U)         /*!< Bit field size in bits for CSI_CSICR3_FRMCNT. */

/*! @brief Read current value of the CSI_CSICR3_FRMCNT field. */
#define BR_CSI_CSICR3_FRMCNT(x) (HW_CSI_CSICR3(x).B.FRMCNT)

/*! @brief Format value for bitfield CSI_CSICR3_FRMCNT. */
#define BF_CSI_CSICR3_FRMCNT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR3_FRMCNT) & BM_CSI_CSICR3_FRMCNT)

/*! @brief Set the FRMCNT field to a new value. */
#define BW_CSI_CSICR3_FRMCNT(x, v) (HW_CSI_CSICR3_WR(x, (HW_CSI_CSICR3_RD(x) & ~BM_CSI_CSICR3_FRMCNT) | BF_CSI_CSICR3_FRMCNT(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSISTATFIFO - CSI Statistic FIFO Register
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSISTATFIFO - CSI Statistic FIFO Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The StatFIFO is a read-only register containing statistic data from the
 * sensor. Writing to this register has no effect.
 */
typedef union _hw_csi_csistatfifo
{
    uint32_t U;
    struct _hw_csi_csistatfifo_bitfields
    {
        uint32_t STAT : 32;            /*!< [31:0]  */
    } B;
} hw_csi_csistatfifo_t;

/*!
 * @name Constants and macros for entire CSI_CSISTATFIFO register
 */
/*@{*/
#define HW_CSI_CSISTATFIFO_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_CSI_CSISTATFIFO(x)    (*(__I hw_csi_csistatfifo_t *) HW_CSI_CSISTATFIFO_ADDR(x))
#define HW_CSI_CSISTATFIFO_RD(x) (HW_CSI_CSISTATFIFO(x).U)
/*@}*/

/*
 * Constants & macros for individual CSI_CSISTATFIFO bitfields
 */

/*!
 * @name Register CSI_CSISTATFIFO, field STAT[31:0] (RO)
 *
 * Static data from sensor
 */
/*@{*/
#define BP_CSI_CSISTATFIFO_STAT (0U)       /*!< Bit position for CSI_CSISTATFIFO_STAT. */
#define BM_CSI_CSISTATFIFO_STAT (0xFFFFFFFFU) /*!< Bit mask for CSI_CSISTATFIFO_STAT. */
#define BS_CSI_CSISTATFIFO_STAT (32U)      /*!< Bit field size in bits for CSI_CSISTATFIFO_STAT. */

/*! @brief Read current value of the CSI_CSISTATFIFO_STAT field. */
#define BR_CSI_CSISTATFIFO_STAT(x) (HW_CSI_CSISTATFIFO(x).U)
/*@}*/

/*******************************************************************************
 * HW_CSI_CSIRFIFO - CSI RX FIFO Register
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSIRFIFO - CSI RX FIFO Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This read-only register contains received image data. Writing to this
 * register has no effect.
 */
typedef union _hw_csi_csirfifo
{
    uint32_t U;
    struct _hw_csi_csirfifo_bitfields
    {
        uint32_t IMAGE : 32;           /*!< [31:0]  */
    } B;
} hw_csi_csirfifo_t;

/*!
 * @name Constants and macros for entire CSI_CSIRFIFO register
 */
/*@{*/
#define HW_CSI_CSIRFIFO_ADDR(x)  ((uintptr_t)(x) + 0x10U)

#define HW_CSI_CSIRFIFO(x)       (*(__I hw_csi_csirfifo_t *) HW_CSI_CSIRFIFO_ADDR(x))
#define HW_CSI_CSIRFIFO_RD(x)    (HW_CSI_CSIRFIFO(x).U)
/*@}*/

/*
 * Constants & macros for individual CSI_CSIRFIFO bitfields
 */

/*!
 * @name Register CSI_CSIRFIFO, field IMAGE[31:0] (RO)
 *
 * Received image data
 */
/*@{*/
#define BP_CSI_CSIRFIFO_IMAGE (0U)         /*!< Bit position for CSI_CSIRFIFO_IMAGE. */
#define BM_CSI_CSIRFIFO_IMAGE (0xFFFFFFFFU) /*!< Bit mask for CSI_CSIRFIFO_IMAGE. */
#define BS_CSI_CSIRFIFO_IMAGE (32U)        /*!< Bit field size in bits for CSI_CSIRFIFO_IMAGE. */

/*! @brief Read current value of the CSI_CSIRFIFO_IMAGE field. */
#define BR_CSI_CSIRFIFO_IMAGE(x) (HW_CSI_CSIRFIFO(x).U)
/*@}*/

/*******************************************************************************
 * HW_CSI_CSIRXCNT - CSI RX Count Register
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSIRXCNT - CSI RX Count Register (RW)
 *
 * Reset value: 0x00009600U
 *
 * This register works for EOF interrupt generation. It should be set to the
 * number of words to receive that would generate an EOF interrupt. There is an
 * internal counter that counts the number of words read from the RX FIFO. Whenever
 * the RX FIFO is being read, by either the CPU or the embedded DMA controller,
 * the counter value is updated and compared with this register. If the values
 * match, then an EOF interrupt is triggered.
 */
typedef union _hw_csi_csirxcnt
{
    uint32_t U;
    struct _hw_csi_csirxcnt_bitfields
    {
        uint32_t RXCNT : 22;           /*!< [21:0]  */
        uint32_t RESERVED0 : 10;       /*!< [31:22]  */
    } B;
} hw_csi_csirxcnt_t;

/*!
 * @name Constants and macros for entire CSI_CSIRXCNT register
 */
/*@{*/
#define HW_CSI_CSIRXCNT_ADDR(x)  ((uintptr_t)(x) + 0x14U)

#define HW_CSI_CSIRXCNT(x)       (*(__IO hw_csi_csirxcnt_t *) HW_CSI_CSIRXCNT_ADDR(x))
#define HW_CSI_CSIRXCNT_RD(x)    (HW_CSI_CSIRXCNT(x).U)
#define HW_CSI_CSIRXCNT_WR(x, v) (HW_CSI_CSIRXCNT(x).U = (v))
#define HW_CSI_CSIRXCNT_SET(x, v) (HW_CSI_CSIRXCNT_WR(x, HW_CSI_CSIRXCNT_RD(x) |  (v)))
#define HW_CSI_CSIRXCNT_CLR(x, v) (HW_CSI_CSIRXCNT_WR(x, HW_CSI_CSIRXCNT_RD(x) & ~(v)))
#define HW_CSI_CSIRXCNT_TOG(x, v) (HW_CSI_CSIRXCNT_WR(x, HW_CSI_CSIRXCNT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSIRXCNT bitfields
 */

/*!
 * @name Register CSI_CSIRXCNT, field RXCNT[21:0] (RW)
 *
 * RxFIFO Count. This 22-bit counter for RXFIFO is updated each time the RXFIFO
 * is read by CPU or DMA.This counter should be set to the expected number of
 * words to receive that would generate an EOF interrupt.
 */
/*@{*/
#define BP_CSI_CSIRXCNT_RXCNT (0U)         /*!< Bit position for CSI_CSIRXCNT_RXCNT. */
#define BM_CSI_CSIRXCNT_RXCNT (0x003FFFFFU) /*!< Bit mask for CSI_CSIRXCNT_RXCNT. */
#define BS_CSI_CSIRXCNT_RXCNT (22U)        /*!< Bit field size in bits for CSI_CSIRXCNT_RXCNT. */

/*! @brief Read current value of the CSI_CSIRXCNT_RXCNT field. */
#define BR_CSI_CSIRXCNT_RXCNT(x) (HW_CSI_CSIRXCNT(x).B.RXCNT)

/*! @brief Format value for bitfield CSI_CSIRXCNT_RXCNT. */
#define BF_CSI_CSIRXCNT_RXCNT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSIRXCNT_RXCNT) & BM_CSI_CSIRXCNT_RXCNT)

/*! @brief Set the RXCNT field to a new value. */
#define BW_CSI_CSIRXCNT_RXCNT(x, v) (HW_CSI_CSIRXCNT_WR(x, (HW_CSI_CSIRXCNT_RD(x) & ~BM_CSI_CSIRXCNT_RXCNT) | BF_CSI_CSIRXCNT_RXCNT(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSISR - CSI Status Register
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSISR - CSI Status Register (RW)
 *
 * Reset value: 0x00004000U
 *
 * This read/write register shows sensor interface status, and which kind of
 * interrupt is being generated. The corresponding interrupt bits must be set for
 * the status bit to function. Status bits should function normally even if the
 * corresponding interrupt enable bits are not enabled.
 */
typedef union _hw_csi_csisr
{
    uint32_t U;
    struct _hw_csi_csisr_bitfields
    {
        uint32_t DRDY : 1;             /*!< [0]  */
        uint32_t ECC_INT : 1;          /*!< [1]  */
        uint32_t RESERVED0 : 5;        /*!< [6:2]  */
        uint32_t HRESP_ERR_INT : 1;    /*!< [7]  */
        uint32_t RESERVED1 : 5;        /*!< [12:8]  */
        uint32_t COF_INT : 1;          /*!< [13]  */
        uint32_t F1_INT : 1;           /*!< [14]  */
        uint32_t F2_INT : 1;           /*!< [15]  */
        uint32_t SOF_INT : 1;          /*!< [16]  */
        uint32_t EOF_INT : 1;          /*!< [17]  */
        uint32_t RxFF_INT : 1;         /*!< [18]  */
        uint32_t DMA_TSF_DONE_FB1 : 1; /*!< [19]  */
        uint32_t DMA_TSF_DONE_FB2 : 1; /*!< [20]  */
        uint32_t STATFF_INT : 1;       /*!< [21]  */
        uint32_t DMA_TSF_DONE_SFF : 1; /*!< [22]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t RF_OR_INT : 1;        /*!< [24]  */
        uint32_t SF_OR_INT : 1;        /*!< [25]  */
        uint32_t DMA_FIELD1_DONE : 1;  /*!< [26]  */
        uint32_t DMA_FIELD0_DONE : 1;  /*!< [27]  */
        uint32_t BASEADDR_CHHANGE_ERROR : 1; /*!< [28]  */
        uint32_t RESERVED3 : 3;        /*!< [31:29]  */
    } B;
} hw_csi_csisr_t;

/*!
 * @name Constants and macros for entire CSI_CSISR register
 */
/*@{*/
#define HW_CSI_CSISR_ADDR(x)     ((uintptr_t)(x) + 0x18U)

#define HW_CSI_CSISR(x)          (*(__IO hw_csi_csisr_t *) HW_CSI_CSISR_ADDR(x))
#define HW_CSI_CSISR_RD(x)       (HW_CSI_CSISR(x).U)
#define HW_CSI_CSISR_WR(x, v)    (HW_CSI_CSISR(x).U = (v))
#define HW_CSI_CSISR_SET(x, v)   (HW_CSI_CSISR_WR(x, HW_CSI_CSISR_RD(x) |  (v)))
#define HW_CSI_CSISR_CLR(x, v)   (HW_CSI_CSISR_WR(x, HW_CSI_CSISR_RD(x) & ~(v)))
#define HW_CSI_CSISR_TOG(x, v)   (HW_CSI_CSISR_WR(x, HW_CSI_CSISR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSISR bitfields
 */

/*!
 * @name Register CSI_CSISR, field DRDY[0] (RW)
 *
 * RXFIFO Data Ready. Indicates the presence of data that is ready for transfer
 * in the RxFIFO. (Cleared automatically by reading FIFO)
 *
 * Values:
 * - 0 - No data (word) is ready
 * - 1 - At least 1 datum (word) is ready in RXFIFO.
 */
/*@{*/
#define BP_CSI_CSISR_DRDY    (0U)          /*!< Bit position for CSI_CSISR_DRDY. */
#define BM_CSI_CSISR_DRDY    (0x00000001U) /*!< Bit mask for CSI_CSISR_DRDY. */
#define BS_CSI_CSISR_DRDY    (1U)          /*!< Bit field size in bits for CSI_CSISR_DRDY. */

/*! @brief Read current value of the CSI_CSISR_DRDY field. */
#define BR_CSI_CSISR_DRDY(x) (HW_CSI_CSISR(x).B.DRDY)

/*! @brief Format value for bitfield CSI_CSISR_DRDY. */
#define BF_CSI_CSISR_DRDY(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_DRDY) & BM_CSI_CSISR_DRDY)

/*! @brief Set the DRDY field to a new value. */
#define BW_CSI_CSISR_DRDY(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_DRDY) | BF_CSI_CSISR_DRDY(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field ECC_INT[1] (RW)
 *
 * CCIR Error Interrupt. This bit indicates an error has occurred. This only
 * works in CCIR Interlace mode. (Cleared by writing 1)
 *
 * Values:
 * - 0 - No error detected
 * - 1 - Error is detected in CCIR coding
 */
/*@{*/
#define BP_CSI_CSISR_ECC_INT (1U)          /*!< Bit position for CSI_CSISR_ECC_INT. */
#define BM_CSI_CSISR_ECC_INT (0x00000002U) /*!< Bit mask for CSI_CSISR_ECC_INT. */
#define BS_CSI_CSISR_ECC_INT (1U)          /*!< Bit field size in bits for CSI_CSISR_ECC_INT. */

/*! @brief Read current value of the CSI_CSISR_ECC_INT field. */
#define BR_CSI_CSISR_ECC_INT(x) (HW_CSI_CSISR(x).B.ECC_INT)

/*! @brief Format value for bitfield CSI_CSISR_ECC_INT. */
#define BF_CSI_CSISR_ECC_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_ECC_INT) & BM_CSI_CSISR_ECC_INT)

/*! @brief Set the ECC_INT field to a new value. */
#define BW_CSI_CSISR_ECC_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_ECC_INT) | BF_CSI_CSISR_ECC_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field HRESP_ERR_INT[7] (RW)
 *
 * Hresponse Error Interrupt Status. Indicates that a hresponse error has been
 * detected. (Cleared by writing 1)
 *
 * Values:
 * - 0 - No hresponse error.
 * - 1 - Hresponse error is detected.
 */
/*@{*/
#define BP_CSI_CSISR_HRESP_ERR_INT (7U)    /*!< Bit position for CSI_CSISR_HRESP_ERR_INT. */
#define BM_CSI_CSISR_HRESP_ERR_INT (0x00000080U) /*!< Bit mask for CSI_CSISR_HRESP_ERR_INT. */
#define BS_CSI_CSISR_HRESP_ERR_INT (1U)    /*!< Bit field size in bits for CSI_CSISR_HRESP_ERR_INT. */

/*! @brief Read current value of the CSI_CSISR_HRESP_ERR_INT field. */
#define BR_CSI_CSISR_HRESP_ERR_INT(x) (HW_CSI_CSISR(x).B.HRESP_ERR_INT)

/*! @brief Format value for bitfield CSI_CSISR_HRESP_ERR_INT. */
#define BF_CSI_CSISR_HRESP_ERR_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_HRESP_ERR_INT) & BM_CSI_CSISR_HRESP_ERR_INT)

/*! @brief Set the HRESP_ERR_INT field to a new value. */
#define BW_CSI_CSISR_HRESP_ERR_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_HRESP_ERR_INT) | BF_CSI_CSISR_HRESP_ERR_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field COF_INT[13] (RW)
 *
 * Change Of Field Interrupt Status. Indicates that a change of the video field
 * has been detected. Only works in CCIR Interlace mode. Software should read
 * this bit first and then dispatch the new field from F1_INT and F2_INT. (Cleared
 * by writing 1)
 *
 * Values:
 * - 0 - Video field has no change.
 * - 1 - Change of video field is detected.
 */
/*@{*/
#define BP_CSI_CSISR_COF_INT (13U)         /*!< Bit position for CSI_CSISR_COF_INT. */
#define BM_CSI_CSISR_COF_INT (0x00002000U) /*!< Bit mask for CSI_CSISR_COF_INT. */
#define BS_CSI_CSISR_COF_INT (1U)          /*!< Bit field size in bits for CSI_CSISR_COF_INT. */

/*! @brief Read current value of the CSI_CSISR_COF_INT field. */
#define BR_CSI_CSISR_COF_INT(x) (HW_CSI_CSISR(x).B.COF_INT)

/*! @brief Format value for bitfield CSI_CSISR_COF_INT. */
#define BF_CSI_CSISR_COF_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_COF_INT) & BM_CSI_CSISR_COF_INT)

/*! @brief Set the COF_INT field to a new value. */
#define BW_CSI_CSISR_COF_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_COF_INT) | BF_CSI_CSISR_COF_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field F1_INT[14] (RW)
 *
 * CCIR Field 1 Interrupt Status. Indicates the presence of field 1 of video in
 * CCIR mode. (Cleared automatically when current field does not match) Only
 * works in CCIR Interlace mode.
 *
 * Values:
 * - 0 - Field 1 of video is not detected.
 * - 1 - Field 1 of video is about to start.
 */
/*@{*/
#define BP_CSI_CSISR_F1_INT  (14U)         /*!< Bit position for CSI_CSISR_F1_INT. */
#define BM_CSI_CSISR_F1_INT  (0x00004000U) /*!< Bit mask for CSI_CSISR_F1_INT. */
#define BS_CSI_CSISR_F1_INT  (1U)          /*!< Bit field size in bits for CSI_CSISR_F1_INT. */

/*! @brief Read current value of the CSI_CSISR_F1_INT field. */
#define BR_CSI_CSISR_F1_INT(x) (HW_CSI_CSISR(x).B.F1_INT)

/*! @brief Format value for bitfield CSI_CSISR_F1_INT. */
#define BF_CSI_CSISR_F1_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_F1_INT) & BM_CSI_CSISR_F1_INT)

/*! @brief Set the F1_INT field to a new value. */
#define BW_CSI_CSISR_F1_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_F1_INT) | BF_CSI_CSISR_F1_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field F2_INT[15] (RW)
 *
 * CCIR Field 2 Interrupt Status. Indicates the presence of field 2 of video in
 * CCIR mode. (Cleared automatically when current field does not match) Only
 * works in CCIR Interlace mode.
 *
 * Values:
 * - 0 - Field 2 of video is not detected
 * - 1 - Field 2 of video is about to start
 */
/*@{*/
#define BP_CSI_CSISR_F2_INT  (15U)         /*!< Bit position for CSI_CSISR_F2_INT. */
#define BM_CSI_CSISR_F2_INT  (0x00008000U) /*!< Bit mask for CSI_CSISR_F2_INT. */
#define BS_CSI_CSISR_F2_INT  (1U)          /*!< Bit field size in bits for CSI_CSISR_F2_INT. */

/*! @brief Read current value of the CSI_CSISR_F2_INT field. */
#define BR_CSI_CSISR_F2_INT(x) (HW_CSI_CSISR(x).B.F2_INT)

/*! @brief Format value for bitfield CSI_CSISR_F2_INT. */
#define BF_CSI_CSISR_F2_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_F2_INT) & BM_CSI_CSISR_F2_INT)

/*! @brief Set the F2_INT field to a new value. */
#define BW_CSI_CSISR_F2_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_F2_INT) | BF_CSI_CSISR_F2_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field SOF_INT[16] (RW)
 *
 * Start of Frame Interrupt Status. Indicates when SOF is detected. (Cleared by
 * writing 1)
 *
 * Values:
 * - 0 - SOF is not detected.
 * - 1 - SOF is detected.
 */
/*@{*/
#define BP_CSI_CSISR_SOF_INT (16U)         /*!< Bit position for CSI_CSISR_SOF_INT. */
#define BM_CSI_CSISR_SOF_INT (0x00010000U) /*!< Bit mask for CSI_CSISR_SOF_INT. */
#define BS_CSI_CSISR_SOF_INT (1U)          /*!< Bit field size in bits for CSI_CSISR_SOF_INT. */

/*! @brief Read current value of the CSI_CSISR_SOF_INT field. */
#define BR_CSI_CSISR_SOF_INT(x) (HW_CSI_CSISR(x).B.SOF_INT)

/*! @brief Format value for bitfield CSI_CSISR_SOF_INT. */
#define BF_CSI_CSISR_SOF_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_SOF_INT) & BM_CSI_CSISR_SOF_INT)

/*! @brief Set the SOF_INT field to a new value. */
#define BW_CSI_CSISR_SOF_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_SOF_INT) | BF_CSI_CSISR_SOF_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field EOF_INT[17] (RW)
 *
 * End of Frame (EOF) Interrupt Status. Indicates when EOF is detected. (Cleared
 * by writing 1)
 *
 * Values:
 * - 0 - EOF is not detected.
 * - 1 - EOF is detected.
 */
/*@{*/
#define BP_CSI_CSISR_EOF_INT (17U)         /*!< Bit position for CSI_CSISR_EOF_INT. */
#define BM_CSI_CSISR_EOF_INT (0x00020000U) /*!< Bit mask for CSI_CSISR_EOF_INT. */
#define BS_CSI_CSISR_EOF_INT (1U)          /*!< Bit field size in bits for CSI_CSISR_EOF_INT. */

/*! @brief Read current value of the CSI_CSISR_EOF_INT field. */
#define BR_CSI_CSISR_EOF_INT(x) (HW_CSI_CSISR(x).B.EOF_INT)

/*! @brief Format value for bitfield CSI_CSISR_EOF_INT. */
#define BF_CSI_CSISR_EOF_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_EOF_INT) & BM_CSI_CSISR_EOF_INT)

/*! @brief Set the EOF_INT field to a new value. */
#define BW_CSI_CSISR_EOF_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_EOF_INT) | BF_CSI_CSISR_EOF_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field RxFF_INT[18] (RW)
 *
 * RXFIFO Full Interrupt Status. Indicates the number of data in the RxFIFO
 * reaches the trigger level. (this bit is cleared automatically by reading the
 * RxFIFO)
 *
 * Values:
 * - 0 - RxFIFO is not full.
 * - 1 - RxFIFO is full.
 */
/*@{*/
#define BP_CSI_CSISR_RxFF_INT (18U)        /*!< Bit position for CSI_CSISR_RxFF_INT. */
#define BM_CSI_CSISR_RxFF_INT (0x00040000U) /*!< Bit mask for CSI_CSISR_RxFF_INT. */
#define BS_CSI_CSISR_RxFF_INT (1U)         /*!< Bit field size in bits for CSI_CSISR_RxFF_INT. */

/*! @brief Read current value of the CSI_CSISR_RxFF_INT field. */
#define BR_CSI_CSISR_RxFF_INT(x) (HW_CSI_CSISR(x).B.RxFF_INT)

/*! @brief Format value for bitfield CSI_CSISR_RxFF_INT. */
#define BF_CSI_CSISR_RxFF_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_RxFF_INT) & BM_CSI_CSISR_RxFF_INT)

/*! @brief Set the RxFF_INT field to a new value. */
#define BW_CSI_CSISR_RxFF_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_RxFF_INT) | BF_CSI_CSISR_RxFF_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field DMA_TSF_DONE_FB1[19] (RW)
 *
 * DMA Transfer Done in Frame Buffer1. Indicates that the DMA transfer from
 * RxFIFO to Frame Buffer1 is completed. It can trigger an interrupt if the
 * corresponding enable bit is set in CSICR1. This bit can be cleared by by writting 1 or
 * reflashing the RxFIFO dma controller in CSICR3. (Cleared by writing 1)
 *
 * Values:
 * - 0 - DMA transfer is not completed.
 * - 1 - DMA transfer is completed.
 */
/*@{*/
#define BP_CSI_CSISR_DMA_TSF_DONE_FB1 (19U) /*!< Bit position for CSI_CSISR_DMA_TSF_DONE_FB1. */
#define BM_CSI_CSISR_DMA_TSF_DONE_FB1 (0x00080000U) /*!< Bit mask for CSI_CSISR_DMA_TSF_DONE_FB1. */
#define BS_CSI_CSISR_DMA_TSF_DONE_FB1 (1U) /*!< Bit field size in bits for CSI_CSISR_DMA_TSF_DONE_FB1. */

/*! @brief Read current value of the CSI_CSISR_DMA_TSF_DONE_FB1 field. */
#define BR_CSI_CSISR_DMA_TSF_DONE_FB1(x) (HW_CSI_CSISR(x).B.DMA_TSF_DONE_FB1)

/*! @brief Format value for bitfield CSI_CSISR_DMA_TSF_DONE_FB1. */
#define BF_CSI_CSISR_DMA_TSF_DONE_FB1(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_DMA_TSF_DONE_FB1) & BM_CSI_CSISR_DMA_TSF_DONE_FB1)

/*! @brief Set the DMA_TSF_DONE_FB1 field to a new value. */
#define BW_CSI_CSISR_DMA_TSF_DONE_FB1(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_DMA_TSF_DONE_FB1) | BF_CSI_CSISR_DMA_TSF_DONE_FB1(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field DMA_TSF_DONE_FB2[20] (RW)
 *
 * DMA Transfer Done in Frame Buffer2. Indicates that the DMA transfer from
 * RxFIFO to Frame Buffer2 is completed. It can trigger an interrupt if the
 * corresponding enable bit is set in CSICR1. This bit can be cleared by by writting 1 or
 * reflashing the RxFIFO dma controller in CSICR3. (Cleared by writing 1)
 *
 * Values:
 * - 0 - DMA transfer is not completed.
 * - 1 - DMA transfer is completed.
 */
/*@{*/
#define BP_CSI_CSISR_DMA_TSF_DONE_FB2 (20U) /*!< Bit position for CSI_CSISR_DMA_TSF_DONE_FB2. */
#define BM_CSI_CSISR_DMA_TSF_DONE_FB2 (0x00100000U) /*!< Bit mask for CSI_CSISR_DMA_TSF_DONE_FB2. */
#define BS_CSI_CSISR_DMA_TSF_DONE_FB2 (1U) /*!< Bit field size in bits for CSI_CSISR_DMA_TSF_DONE_FB2. */

/*! @brief Read current value of the CSI_CSISR_DMA_TSF_DONE_FB2 field. */
#define BR_CSI_CSISR_DMA_TSF_DONE_FB2(x) (HW_CSI_CSISR(x).B.DMA_TSF_DONE_FB2)

/*! @brief Format value for bitfield CSI_CSISR_DMA_TSF_DONE_FB2. */
#define BF_CSI_CSISR_DMA_TSF_DONE_FB2(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_DMA_TSF_DONE_FB2) & BM_CSI_CSISR_DMA_TSF_DONE_FB2)

/*! @brief Set the DMA_TSF_DONE_FB2 field to a new value. */
#define BW_CSI_CSISR_DMA_TSF_DONE_FB2(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_DMA_TSF_DONE_FB2) | BF_CSI_CSISR_DMA_TSF_DONE_FB2(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field STATFF_INT[21] (RW)
 *
 * STATFIFO Full Interrupt Status. Indicates the number of data in the STATFIFO
 * reaches the trigger level. (this bit is cleared automatically by reading the
 * STATFIFO)
 *
 * Values:
 * - 0 - STATFIFO is not full.
 * - 1 - STATFIFO is full.
 */
/*@{*/
#define BP_CSI_CSISR_STATFF_INT (21U)      /*!< Bit position for CSI_CSISR_STATFF_INT. */
#define BM_CSI_CSISR_STATFF_INT (0x00200000U) /*!< Bit mask for CSI_CSISR_STATFF_INT. */
#define BS_CSI_CSISR_STATFF_INT (1U)       /*!< Bit field size in bits for CSI_CSISR_STATFF_INT. */

/*! @brief Read current value of the CSI_CSISR_STATFF_INT field. */
#define BR_CSI_CSISR_STATFF_INT(x) (HW_CSI_CSISR(x).B.STATFF_INT)

/*! @brief Format value for bitfield CSI_CSISR_STATFF_INT. */
#define BF_CSI_CSISR_STATFF_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_STATFF_INT) & BM_CSI_CSISR_STATFF_INT)

/*! @brief Set the STATFF_INT field to a new value. */
#define BW_CSI_CSISR_STATFF_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_STATFF_INT) | BF_CSI_CSISR_STATFF_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field DMA_TSF_DONE_SFF[22] (RW)
 *
 * DMA Transfer Done from StatFIFO. Indicates that the dma transfer from
 * StatFIFO is completed. It can trigger an interrupt if the corresponding enable bit is
 * set in CSICR1. This bit can be cleared by writting 1 or reflashing the
 * StatFIFO dma controller in CSICR3.(Cleared by writing 1)
 *
 * Values:
 * - 0 - DMA transfer is not completed.
 * - 1 - DMA transfer is completed.
 */
/*@{*/
#define BP_CSI_CSISR_DMA_TSF_DONE_SFF (22U) /*!< Bit position for CSI_CSISR_DMA_TSF_DONE_SFF. */
#define BM_CSI_CSISR_DMA_TSF_DONE_SFF (0x00400000U) /*!< Bit mask for CSI_CSISR_DMA_TSF_DONE_SFF. */
#define BS_CSI_CSISR_DMA_TSF_DONE_SFF (1U) /*!< Bit field size in bits for CSI_CSISR_DMA_TSF_DONE_SFF. */

/*! @brief Read current value of the CSI_CSISR_DMA_TSF_DONE_SFF field. */
#define BR_CSI_CSISR_DMA_TSF_DONE_SFF(x) (HW_CSI_CSISR(x).B.DMA_TSF_DONE_SFF)

/*! @brief Format value for bitfield CSI_CSISR_DMA_TSF_DONE_SFF. */
#define BF_CSI_CSISR_DMA_TSF_DONE_SFF(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_DMA_TSF_DONE_SFF) & BM_CSI_CSISR_DMA_TSF_DONE_SFF)

/*! @brief Set the DMA_TSF_DONE_SFF field to a new value. */
#define BW_CSI_CSISR_DMA_TSF_DONE_SFF(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_DMA_TSF_DONE_SFF) | BF_CSI_CSISR_DMA_TSF_DONE_SFF(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field RF_OR_INT[24] (RW)
 *
 * RxFIFO Overrun Interrupt Status. Indicates the overflow status of the RxFIFO
 * register. (Cleared by writing 1)
 *
 * Values:
 * - 0 - RXFIFO has not overflowed.
 * - 1 - RXFIFO has overflowed.
 */
/*@{*/
#define BP_CSI_CSISR_RF_OR_INT (24U)       /*!< Bit position for CSI_CSISR_RF_OR_INT. */
#define BM_CSI_CSISR_RF_OR_INT (0x01000000U) /*!< Bit mask for CSI_CSISR_RF_OR_INT. */
#define BS_CSI_CSISR_RF_OR_INT (1U)        /*!< Bit field size in bits for CSI_CSISR_RF_OR_INT. */

/*! @brief Read current value of the CSI_CSISR_RF_OR_INT field. */
#define BR_CSI_CSISR_RF_OR_INT(x) (HW_CSI_CSISR(x).B.RF_OR_INT)

/*! @brief Format value for bitfield CSI_CSISR_RF_OR_INT. */
#define BF_CSI_CSISR_RF_OR_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_RF_OR_INT) & BM_CSI_CSISR_RF_OR_INT)

/*! @brief Set the RF_OR_INT field to a new value. */
#define BW_CSI_CSISR_RF_OR_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_RF_OR_INT) | BF_CSI_CSISR_RF_OR_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field SF_OR_INT[25] (RW)
 *
 * STATFIFO Overrun Interrupt Status. Indicates the overflow status of the
 * STATFIFO register. (Cleared by writing 1)
 *
 * Values:
 * - 0 - STATFIFO has not overflowed.
 * - 1 - STATFIFO has overflowed.
 */
/*@{*/
#define BP_CSI_CSISR_SF_OR_INT (25U)       /*!< Bit position for CSI_CSISR_SF_OR_INT. */
#define BM_CSI_CSISR_SF_OR_INT (0x02000000U) /*!< Bit mask for CSI_CSISR_SF_OR_INT. */
#define BS_CSI_CSISR_SF_OR_INT (1U)        /*!< Bit field size in bits for CSI_CSISR_SF_OR_INT. */

/*! @brief Read current value of the CSI_CSISR_SF_OR_INT field. */
#define BR_CSI_CSISR_SF_OR_INT(x) (HW_CSI_CSISR(x).B.SF_OR_INT)

/*! @brief Format value for bitfield CSI_CSISR_SF_OR_INT. */
#define BF_CSI_CSISR_SF_OR_INT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_SF_OR_INT) & BM_CSI_CSISR_SF_OR_INT)

/*! @brief Set the SF_OR_INT field to a new value. */
#define BW_CSI_CSISR_SF_OR_INT(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_SF_OR_INT) | BF_CSI_CSISR_SF_OR_INT(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field DMA_FIELD1_DONE[26] (RW)
 *
 * When DMA field 0 is complete, this bit will be set to 1(clear by writing 1).
 */
/*@{*/
#define BP_CSI_CSISR_DMA_FIELD1_DONE (26U) /*!< Bit position for CSI_CSISR_DMA_FIELD1_DONE. */
#define BM_CSI_CSISR_DMA_FIELD1_DONE (0x04000000U) /*!< Bit mask for CSI_CSISR_DMA_FIELD1_DONE. */
#define BS_CSI_CSISR_DMA_FIELD1_DONE (1U)  /*!< Bit field size in bits for CSI_CSISR_DMA_FIELD1_DONE. */

/*! @brief Read current value of the CSI_CSISR_DMA_FIELD1_DONE field. */
#define BR_CSI_CSISR_DMA_FIELD1_DONE(x) (HW_CSI_CSISR(x).B.DMA_FIELD1_DONE)

/*! @brief Format value for bitfield CSI_CSISR_DMA_FIELD1_DONE. */
#define BF_CSI_CSISR_DMA_FIELD1_DONE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_DMA_FIELD1_DONE) & BM_CSI_CSISR_DMA_FIELD1_DONE)

/*! @brief Set the DMA_FIELD1_DONE field to a new value. */
#define BW_CSI_CSISR_DMA_FIELD1_DONE(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_DMA_FIELD1_DONE) | BF_CSI_CSISR_DMA_FIELD1_DONE(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field DMA_FIELD0_DONE[27] (RW)
 *
 * When DMA field 0 is complete, this bit will be set to 1(clear by writing 1).
 */
/*@{*/
#define BP_CSI_CSISR_DMA_FIELD0_DONE (27U) /*!< Bit position for CSI_CSISR_DMA_FIELD0_DONE. */
#define BM_CSI_CSISR_DMA_FIELD0_DONE (0x08000000U) /*!< Bit mask for CSI_CSISR_DMA_FIELD0_DONE. */
#define BS_CSI_CSISR_DMA_FIELD0_DONE (1U)  /*!< Bit field size in bits for CSI_CSISR_DMA_FIELD0_DONE. */

/*! @brief Read current value of the CSI_CSISR_DMA_FIELD0_DONE field. */
#define BR_CSI_CSISR_DMA_FIELD0_DONE(x) (HW_CSI_CSISR(x).B.DMA_FIELD0_DONE)

/*! @brief Format value for bitfield CSI_CSISR_DMA_FIELD0_DONE. */
#define BF_CSI_CSISR_DMA_FIELD0_DONE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_DMA_FIELD0_DONE) & BM_CSI_CSISR_DMA_FIELD0_DONE)

/*! @brief Set the DMA_FIELD0_DONE field to a new value. */
#define BW_CSI_CSISR_DMA_FIELD0_DONE(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_DMA_FIELD0_DONE) | BF_CSI_CSISR_DMA_FIELD0_DONE(v)))
/*@}*/

/*!
 * @name Register CSI_CSISR, field BASEADDR_CHHANGE_ERROR[28] (RW)
 *
 * When using base address switching enable, this bit will be 1 when switching
 * occur before DMA complete. This bit will be clear by writing 1. When this
 * interrupt happens, follow the steps listed below. Unassert the CSI enable,
 * CSIx_CSICR18 bit31, Reflash the DMA, assert the CSIX_CSICR3 bit 14, Assert the CSI
 * enable, CSIx_CSICR18 bit31.
 */
/*@{*/
#define BP_CSI_CSISR_BASEADDR_CHHANGE_ERROR (28U) /*!< Bit position for CSI_CSISR_BASEADDR_CHHANGE_ERROR. */
#define BM_CSI_CSISR_BASEADDR_CHHANGE_ERROR (0x10000000U) /*!< Bit mask for CSI_CSISR_BASEADDR_CHHANGE_ERROR. */
#define BS_CSI_CSISR_BASEADDR_CHHANGE_ERROR (1U) /*!< Bit field size in bits for CSI_CSISR_BASEADDR_CHHANGE_ERROR. */

/*! @brief Read current value of the CSI_CSISR_BASEADDR_CHHANGE_ERROR field. */
#define BR_CSI_CSISR_BASEADDR_CHHANGE_ERROR(x) (HW_CSI_CSISR(x).B.BASEADDR_CHHANGE_ERROR)

/*! @brief Format value for bitfield CSI_CSISR_BASEADDR_CHHANGE_ERROR. */
#define BF_CSI_CSISR_BASEADDR_CHHANGE_ERROR(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSISR_BASEADDR_CHHANGE_ERROR) & BM_CSI_CSISR_BASEADDR_CHHANGE_ERROR)

/*! @brief Set the BASEADDR_CHHANGE_ERROR field to a new value. */
#define BW_CSI_CSISR_BASEADDR_CHHANGE_ERROR(x, v) (HW_CSI_CSISR_WR(x, (HW_CSI_CSISR_RD(x) & ~BM_CSI_CSISR_BASEADDR_CHHANGE_ERROR) | BF_CSI_CSISR_BASEADDR_CHHANGE_ERROR(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSIDMASA_STATFIFO - CSI DMA Start Address Register - for STATFIFO
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSIDMASA_STATFIFO - CSI DMA Start Address Register - for STATFIFO (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the start address for the embedded DMA controller of
 * STATFIFO. The embedded DMA controller will read data from STATFIFO and write it
 * to the external memory from the start address. This register should be
 * configured before activating or restarting the embedded DMA controller.
 */
typedef union _hw_csi_csidmasa_statfifo
{
    uint32_t U;
    struct _hw_csi_csidmasa_statfifo_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t DMA_START_ADDR_SFF : 30; /*!< [31:2]  */
    } B;
} hw_csi_csidmasa_statfifo_t;

/*!
 * @name Constants and macros for entire CSI_CSIDMASA_STATFIFO register
 */
/*@{*/
#define HW_CSI_CSIDMASA_STATFIFO_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_CSI_CSIDMASA_STATFIFO(x) (*(__IO hw_csi_csidmasa_statfifo_t *) HW_CSI_CSIDMASA_STATFIFO_ADDR(x))
#define HW_CSI_CSIDMASA_STATFIFO_RD(x) (HW_CSI_CSIDMASA_STATFIFO(x).U)
#define HW_CSI_CSIDMASA_STATFIFO_WR(x, v) (HW_CSI_CSIDMASA_STATFIFO(x).U = (v))
#define HW_CSI_CSIDMASA_STATFIFO_SET(x, v) (HW_CSI_CSIDMASA_STATFIFO_WR(x, HW_CSI_CSIDMASA_STATFIFO_RD(x) |  (v)))
#define HW_CSI_CSIDMASA_STATFIFO_CLR(x, v) (HW_CSI_CSIDMASA_STATFIFO_WR(x, HW_CSI_CSIDMASA_STATFIFO_RD(x) & ~(v)))
#define HW_CSI_CSIDMASA_STATFIFO_TOG(x, v) (HW_CSI_CSIDMASA_STATFIFO_WR(x, HW_CSI_CSIDMASA_STATFIFO_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSIDMASA_STATFIFO bitfields
 */

/*!
 * @name Register CSI_CSIDMASA_STATFIFO, field DMA_START_ADDR_SFF[31:2] (RW)
 *
 * DMA Start Address for STATFIFO. Indicates the start address to write data.
 * The embedded DMA controller will read data from STATFIFO and write it from this
 * address through AHB bus. The address should be double words aligned.
 */
/*@{*/
#define BP_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF (2U) /*!< Bit position for CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF. */
#define BM_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF (0xFFFFFFFCU) /*!< Bit mask for CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF. */
#define BS_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF (30U) /*!< Bit field size in bits for CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF. */

/*! @brief Read current value of the CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF field. */
#define BR_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF(x) (HW_CSI_CSIDMASA_STATFIFO(x).B.DMA_START_ADDR_SFF)

/*! @brief Format value for bitfield CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF. */
#define BF_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF) & BM_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF)

/*! @brief Set the DMA_START_ADDR_SFF field to a new value. */
#define BW_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF(x, v) (HW_CSI_CSIDMASA_STATFIFO_WR(x, (HW_CSI_CSIDMASA_STATFIFO_RD(x) & ~BM_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF) | BF_CSI_CSIDMASA_STATFIFO_DMA_START_ADDR_SFF(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSIDMATS_STATFIFO - CSI DMA Transfer Size Register - for STATFIFO
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSIDMATS_STATFIFO - CSI DMA Transfer Size Register - for STATFIFO (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the total transfer size for the embedded DMA
 * controller of STATFIFO. This register should be configured before activating or
 * restarting the embedded DMA controller.
 */
typedef union _hw_csi_csidmats_statfifo
{
    uint32_t U;
    struct _hw_csi_csidmats_statfifo_bitfields
    {
        uint32_t DMA_TSF_SIZE_SFF : 32; /*!< [31:0]  */
    } B;
} hw_csi_csidmats_statfifo_t;

/*!
 * @name Constants and macros for entire CSI_CSIDMATS_STATFIFO register
 */
/*@{*/
#define HW_CSI_CSIDMATS_STATFIFO_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_CSI_CSIDMATS_STATFIFO(x) (*(__IO hw_csi_csidmats_statfifo_t *) HW_CSI_CSIDMATS_STATFIFO_ADDR(x))
#define HW_CSI_CSIDMATS_STATFIFO_RD(x) (HW_CSI_CSIDMATS_STATFIFO(x).U)
#define HW_CSI_CSIDMATS_STATFIFO_WR(x, v) (HW_CSI_CSIDMATS_STATFIFO(x).U = (v))
#define HW_CSI_CSIDMATS_STATFIFO_SET(x, v) (HW_CSI_CSIDMATS_STATFIFO_WR(x, HW_CSI_CSIDMATS_STATFIFO_RD(x) |  (v)))
#define HW_CSI_CSIDMATS_STATFIFO_CLR(x, v) (HW_CSI_CSIDMATS_STATFIFO_WR(x, HW_CSI_CSIDMATS_STATFIFO_RD(x) & ~(v)))
#define HW_CSI_CSIDMATS_STATFIFO_TOG(x, v) (HW_CSI_CSIDMATS_STATFIFO_WR(x, HW_CSI_CSIDMATS_STATFIFO_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSIDMATS_STATFIFO bitfields
 */

/*!
 * @name Register CSI_CSIDMATS_STATFIFO, field DMA_TSF_SIZE_SFF[31:0] (RW)
 *
 * DMA Transfer Size for STATFIFO. Indicates how many words to be transfered by
 * the embedded DMA controller. The size should be double words aligned.
 */
/*@{*/
#define BP_CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF (0U) /*!< Bit position for CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF. */
#define BM_CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF (0xFFFFFFFFU) /*!< Bit mask for CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF. */
#define BS_CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF (32U) /*!< Bit field size in bits for CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF. */

/*! @brief Read current value of the CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF field. */
#define BR_CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF(x) (HW_CSI_CSIDMATS_STATFIFO(x).U)

/*! @brief Format value for bitfield CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF. */
#define BF_CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF) & BM_CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF)

/*! @brief Set the DMA_TSF_SIZE_SFF field to a new value. */
#define BW_CSI_CSIDMATS_STATFIFO_DMA_TSF_SIZE_SFF(x, v) (HW_CSI_CSIDMATS_STATFIFO_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSIDMASA_FB1 - CSI DMA Start Address Register - for Frame Buffer1
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSIDMASA_FB1 - CSI DMA Start Address Register - for Frame Buffer1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the start address in the frame buffer1 for the
 * embedded DMA controller of RxFIFO. The embedded DMA controller will read data from
 * RxFIFO and write it to the frame buffer1 from the start address. This register
 * should be configured before activating or restarting the embedded DMA
 * controller.
 */
typedef union _hw_csi_csidmasa_fb1
{
    uint32_t U;
    struct _hw_csi_csidmasa_fb1_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t DMA_START_ADDR_FB1 : 30; /*!< [31:2]  */
    } B;
} hw_csi_csidmasa_fb1_t;

/*!
 * @name Constants and macros for entire CSI_CSIDMASA_FB1 register
 */
/*@{*/
#define HW_CSI_CSIDMASA_FB1_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_CSI_CSIDMASA_FB1(x)   (*(__IO hw_csi_csidmasa_fb1_t *) HW_CSI_CSIDMASA_FB1_ADDR(x))
#define HW_CSI_CSIDMASA_FB1_RD(x) (HW_CSI_CSIDMASA_FB1(x).U)
#define HW_CSI_CSIDMASA_FB1_WR(x, v) (HW_CSI_CSIDMASA_FB1(x).U = (v))
#define HW_CSI_CSIDMASA_FB1_SET(x, v) (HW_CSI_CSIDMASA_FB1_WR(x, HW_CSI_CSIDMASA_FB1_RD(x) |  (v)))
#define HW_CSI_CSIDMASA_FB1_CLR(x, v) (HW_CSI_CSIDMASA_FB1_WR(x, HW_CSI_CSIDMASA_FB1_RD(x) & ~(v)))
#define HW_CSI_CSIDMASA_FB1_TOG(x, v) (HW_CSI_CSIDMASA_FB1_WR(x, HW_CSI_CSIDMASA_FB1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSIDMASA_FB1 bitfields
 */

/*!
 * @name Register CSI_CSIDMASA_FB1, field DMA_START_ADDR_FB1[31:2] (RW)
 *
 * DMA Start Address in Frame Buffer1. Indicates the start address to write
 * data. The embedded DMA controller will read data from RxFIFO and write it from
 * this address through AHB bus. The address should be double words aligned.
 */
/*@{*/
#define BP_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1 (2U) /*!< Bit position for CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1. */
#define BM_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1 (0xFFFFFFFCU) /*!< Bit mask for CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1. */
#define BS_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1 (30U) /*!< Bit field size in bits for CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1. */

/*! @brief Read current value of the CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1 field. */
#define BR_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1(x) (HW_CSI_CSIDMASA_FB1(x).B.DMA_START_ADDR_FB1)

/*! @brief Format value for bitfield CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1. */
#define BF_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1) & BM_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1)

/*! @brief Set the DMA_START_ADDR_FB1 field to a new value. */
#define BW_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1(x, v) (HW_CSI_CSIDMASA_FB1_WR(x, (HW_CSI_CSIDMASA_FB1_RD(x) & ~BM_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1) | BF_CSI_CSIDMASA_FB1_DMA_START_ADDR_FB1(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSIDMASA_FB2 - CSI DMA Transfer Size Register - for Frame Buffer2
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSIDMASA_FB2 - CSI DMA Transfer Size Register - for Frame Buffer2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the start address in the frame buffer2 for the
 * embedded DMA controller of RxFIFO. The embedded DMA controller will read data from
 * RxFIFO and write it to the frame buffer2 from the start address. This register
 * should be configured before activating or restarting the embedded DMA
 * controller.
 */
typedef union _hw_csi_csidmasa_fb2
{
    uint32_t U;
    struct _hw_csi_csidmasa_fb2_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t DMA_START_ADDR_FB2 : 30; /*!< [31:2]  */
    } B;
} hw_csi_csidmasa_fb2_t;

/*!
 * @name Constants and macros for entire CSI_CSIDMASA_FB2 register
 */
/*@{*/
#define HW_CSI_CSIDMASA_FB2_ADDR(x) ((uintptr_t)(x) + 0x2CU)

#define HW_CSI_CSIDMASA_FB2(x)   (*(__IO hw_csi_csidmasa_fb2_t *) HW_CSI_CSIDMASA_FB2_ADDR(x))
#define HW_CSI_CSIDMASA_FB2_RD(x) (HW_CSI_CSIDMASA_FB2(x).U)
#define HW_CSI_CSIDMASA_FB2_WR(x, v) (HW_CSI_CSIDMASA_FB2(x).U = (v))
#define HW_CSI_CSIDMASA_FB2_SET(x, v) (HW_CSI_CSIDMASA_FB2_WR(x, HW_CSI_CSIDMASA_FB2_RD(x) |  (v)))
#define HW_CSI_CSIDMASA_FB2_CLR(x, v) (HW_CSI_CSIDMASA_FB2_WR(x, HW_CSI_CSIDMASA_FB2_RD(x) & ~(v)))
#define HW_CSI_CSIDMASA_FB2_TOG(x, v) (HW_CSI_CSIDMASA_FB2_WR(x, HW_CSI_CSIDMASA_FB2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSIDMASA_FB2 bitfields
 */

/*!
 * @name Register CSI_CSIDMASA_FB2, field DMA_START_ADDR_FB2[31:2] (RW)
 *
 * DMA Start Address in Frame Buffer2. Indicates the start address to write
 * data. The embedded DMA controller will read data from RxFIFO and write it from
 * this address through AHB bus. The address should be double words aligned.
 */
/*@{*/
#define BP_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2 (2U) /*!< Bit position for CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2. */
#define BM_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2 (0xFFFFFFFCU) /*!< Bit mask for CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2. */
#define BS_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2 (30U) /*!< Bit field size in bits for CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2. */

/*! @brief Read current value of the CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2 field. */
#define BR_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2(x) (HW_CSI_CSIDMASA_FB2(x).B.DMA_START_ADDR_FB2)

/*! @brief Format value for bitfield CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2. */
#define BF_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2) & BM_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2)

/*! @brief Set the DMA_START_ADDR_FB2 field to a new value. */
#define BW_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2(x, v) (HW_CSI_CSIDMASA_FB2_WR(x, (HW_CSI_CSIDMASA_FB2_RD(x) & ~BM_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2) | BF_CSI_CSIDMASA_FB2_DMA_START_ADDR_FB2(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSIFBUF_PARA - CSI Frame Buffer Parameter Register
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSIFBUF_PARA - CSI Frame Buffer Parameter Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the stride of the frame buffer to show how many words
 * to skip before starting to write the next row of the image. The width of the
 * frame buffer minus the width of the image is the stride. This register should
 * be configured before activating or restarting the embedded DMA controller.
 */
typedef union _hw_csi_csifbuf_para
{
    uint32_t U;
    struct _hw_csi_csifbuf_para_bitfields
    {
        uint32_t FBUF_STRIDE : 16;     /*!< [15:0]  */
        uint32_t DEINTERLACE_STRIDE : 16; /*!< [31:16]  */
    } B;
} hw_csi_csifbuf_para_t;

/*!
 * @name Constants and macros for entire CSI_CSIFBUF_PARA register
 */
/*@{*/
#define HW_CSI_CSIFBUF_PARA_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_CSI_CSIFBUF_PARA(x)   (*(__IO hw_csi_csifbuf_para_t *) HW_CSI_CSIFBUF_PARA_ADDR(x))
#define HW_CSI_CSIFBUF_PARA_RD(x) (HW_CSI_CSIFBUF_PARA(x).U)
#define HW_CSI_CSIFBUF_PARA_WR(x, v) (HW_CSI_CSIFBUF_PARA(x).U = (v))
#define HW_CSI_CSIFBUF_PARA_SET(x, v) (HW_CSI_CSIFBUF_PARA_WR(x, HW_CSI_CSIFBUF_PARA_RD(x) |  (v)))
#define HW_CSI_CSIFBUF_PARA_CLR(x, v) (HW_CSI_CSIFBUF_PARA_WR(x, HW_CSI_CSIFBUF_PARA_RD(x) & ~(v)))
#define HW_CSI_CSIFBUF_PARA_TOG(x, v) (HW_CSI_CSIFBUF_PARA_WR(x, HW_CSI_CSIFBUF_PARA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSIFBUF_PARA bitfields
 */

/*!
 * @name Register CSI_CSIFBUF_PARA, field FBUF_STRIDE[15:0] (RW)
 *
 * Frame Buffer Parameter. Indicates the stride of the frame buffer. The width
 * of the frame buffer(in double words) minus the width of the image(in double
 * words) is the stride. The stride should be double words aligned. The embedded DMA
 * controller will skip the stride before starting to write the next row of the
 * image.
 */
/*@{*/
#define BP_CSI_CSIFBUF_PARA_FBUF_STRIDE (0U) /*!< Bit position for CSI_CSIFBUF_PARA_FBUF_STRIDE. */
#define BM_CSI_CSIFBUF_PARA_FBUF_STRIDE (0x0000FFFFU) /*!< Bit mask for CSI_CSIFBUF_PARA_FBUF_STRIDE. */
#define BS_CSI_CSIFBUF_PARA_FBUF_STRIDE (16U) /*!< Bit field size in bits for CSI_CSIFBUF_PARA_FBUF_STRIDE. */

/*! @brief Read current value of the CSI_CSIFBUF_PARA_FBUF_STRIDE field. */
#define BR_CSI_CSIFBUF_PARA_FBUF_STRIDE(x) (HW_CSI_CSIFBUF_PARA(x).B.FBUF_STRIDE)

/*! @brief Format value for bitfield CSI_CSIFBUF_PARA_FBUF_STRIDE. */
#define BF_CSI_CSIFBUF_PARA_FBUF_STRIDE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSIFBUF_PARA_FBUF_STRIDE) & BM_CSI_CSIFBUF_PARA_FBUF_STRIDE)

/*! @brief Set the FBUF_STRIDE field to a new value. */
#define BW_CSI_CSIFBUF_PARA_FBUF_STRIDE(x, v) (HW_CSI_CSIFBUF_PARA_WR(x, (HW_CSI_CSIFBUF_PARA_RD(x) & ~BM_CSI_CSIFBUF_PARA_FBUF_STRIDE) | BF_CSI_CSIFBUF_PARA_FBUF_STRIDE(v)))
/*@}*/

/*!
 * @name Register CSI_CSIFBUF_PARA, field DEINTERLACE_STRIDE[31:16] (RW)
 *
 * DEINTERLACE_STRIDE is only used in the deinterlace mode. If line stride
 * feature is supported in deinterlace mode, FBUF_STRIDE and DEINTERLACE_STRIDE need
 * to be configured at the same time. DEINTERLACE_STRIDE is configured the same as
 * line width. In normal line stride feature, only FBUF_STRIDE needs to be
 * configured.
 */
/*@{*/
#define BP_CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE (16U) /*!< Bit position for CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE. */
#define BM_CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE (0xFFFF0000U) /*!< Bit mask for CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE. */
#define BS_CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE (16U) /*!< Bit field size in bits for CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE. */

/*! @brief Read current value of the CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE field. */
#define BR_CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE(x) (HW_CSI_CSIFBUF_PARA(x).B.DEINTERLACE_STRIDE)

/*! @brief Format value for bitfield CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE. */
#define BF_CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE) & BM_CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE)

/*! @brief Set the DEINTERLACE_STRIDE field to a new value. */
#define BW_CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE(x, v) (HW_CSI_CSIFBUF_PARA_WR(x, (HW_CSI_CSIFBUF_PARA_RD(x) & ~BM_CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE) | BF_CSI_CSIFBUF_PARA_DEINTERLACE_STRIDE(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSIIMAG_PARA - CSI Image Parameter Register
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSIIMAG_PARA - CSI Image Parameter Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the width and the height of the image from the sensor.
 * The width and height should be aligned in pixel. The width of the image
 * multiplied by the height is the total pixel size that will be transfered in a frame
 * by the embedded DMA controller. This register should be configured before
 * activating or restarting the embedded DMA controller.
 */
typedef union _hw_csi_csiimag_para
{
    uint32_t U;
    struct _hw_csi_csiimag_para_bitfields
    {
        uint32_t IMAGE_HEIGHT : 16;    /*!< [15:0]  */
        uint32_t IMAGE_WIDTH : 16;     /*!< [31:16]  */
    } B;
} hw_csi_csiimag_para_t;

/*!
 * @name Constants and macros for entire CSI_CSIIMAG_PARA register
 */
/*@{*/
#define HW_CSI_CSIIMAG_PARA_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_CSI_CSIIMAG_PARA(x)   (*(__IO hw_csi_csiimag_para_t *) HW_CSI_CSIIMAG_PARA_ADDR(x))
#define HW_CSI_CSIIMAG_PARA_RD(x) (HW_CSI_CSIIMAG_PARA(x).U)
#define HW_CSI_CSIIMAG_PARA_WR(x, v) (HW_CSI_CSIIMAG_PARA(x).U = (v))
#define HW_CSI_CSIIMAG_PARA_SET(x, v) (HW_CSI_CSIIMAG_PARA_WR(x, HW_CSI_CSIIMAG_PARA_RD(x) |  (v)))
#define HW_CSI_CSIIMAG_PARA_CLR(x, v) (HW_CSI_CSIIMAG_PARA_WR(x, HW_CSI_CSIIMAG_PARA_RD(x) & ~(v)))
#define HW_CSI_CSIIMAG_PARA_TOG(x, v) (HW_CSI_CSIIMAG_PARA_WR(x, HW_CSI_CSIIMAG_PARA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSIIMAG_PARA bitfields
 */

/*!
 * @name Register CSI_CSIIMAG_PARA, field IMAGE_HEIGHT[15:0] (RW)
 *
 * Image Height. Indicates how many pixels in a column of the image from the
 * sensor.
 */
/*@{*/
#define BP_CSI_CSIIMAG_PARA_IMAGE_HEIGHT (0U) /*!< Bit position for CSI_CSIIMAG_PARA_IMAGE_HEIGHT. */
#define BM_CSI_CSIIMAG_PARA_IMAGE_HEIGHT (0x0000FFFFU) /*!< Bit mask for CSI_CSIIMAG_PARA_IMAGE_HEIGHT. */
#define BS_CSI_CSIIMAG_PARA_IMAGE_HEIGHT (16U) /*!< Bit field size in bits for CSI_CSIIMAG_PARA_IMAGE_HEIGHT. */

/*! @brief Read current value of the CSI_CSIIMAG_PARA_IMAGE_HEIGHT field. */
#define BR_CSI_CSIIMAG_PARA_IMAGE_HEIGHT(x) (HW_CSI_CSIIMAG_PARA(x).B.IMAGE_HEIGHT)

/*! @brief Format value for bitfield CSI_CSIIMAG_PARA_IMAGE_HEIGHT. */
#define BF_CSI_CSIIMAG_PARA_IMAGE_HEIGHT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSIIMAG_PARA_IMAGE_HEIGHT) & BM_CSI_CSIIMAG_PARA_IMAGE_HEIGHT)

/*! @brief Set the IMAGE_HEIGHT field to a new value. */
#define BW_CSI_CSIIMAG_PARA_IMAGE_HEIGHT(x, v) (HW_CSI_CSIIMAG_PARA_WR(x, (HW_CSI_CSIIMAG_PARA_RD(x) & ~BM_CSI_CSIIMAG_PARA_IMAGE_HEIGHT) | BF_CSI_CSIIMAG_PARA_IMAGE_HEIGHT(v)))
/*@}*/

/*!
 * @name Register CSI_CSIIMAG_PARA, field IMAGE_WIDTH[31:16] (RW)
 *
 * Image Width. Indicates how many pixels in a line of the image from the
 * sensor. If the input data from the sensor is 8-bit/pixel format, the IMAGE_WIDTH
 * should be a multiple of 8 pixels. If the input data from the sensor is
 * 10-bit/pixel or 16-bit/pixel format, the IMAGE_WIDTH should be a multiple of 2 pixels.
 */
/*@{*/
#define BP_CSI_CSIIMAG_PARA_IMAGE_WIDTH (16U) /*!< Bit position for CSI_CSIIMAG_PARA_IMAGE_WIDTH. */
#define BM_CSI_CSIIMAG_PARA_IMAGE_WIDTH (0xFFFF0000U) /*!< Bit mask for CSI_CSIIMAG_PARA_IMAGE_WIDTH. */
#define BS_CSI_CSIIMAG_PARA_IMAGE_WIDTH (16U) /*!< Bit field size in bits for CSI_CSIIMAG_PARA_IMAGE_WIDTH. */

/*! @brief Read current value of the CSI_CSIIMAG_PARA_IMAGE_WIDTH field. */
#define BR_CSI_CSIIMAG_PARA_IMAGE_WIDTH(x) (HW_CSI_CSIIMAG_PARA(x).B.IMAGE_WIDTH)

/*! @brief Format value for bitfield CSI_CSIIMAG_PARA_IMAGE_WIDTH. */
#define BF_CSI_CSIIMAG_PARA_IMAGE_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSIIMAG_PARA_IMAGE_WIDTH) & BM_CSI_CSIIMAG_PARA_IMAGE_WIDTH)

/*! @brief Set the IMAGE_WIDTH field to a new value. */
#define BW_CSI_CSIIMAG_PARA_IMAGE_WIDTH(x, v) (HW_CSI_CSIIMAG_PARA_WR(x, (HW_CSI_CSIIMAG_PARA_RD(x) & ~BM_CSI_CSIIMAG_PARA_IMAGE_WIDTH) | BF_CSI_CSIIMAG_PARA_IMAGE_WIDTH(v)))
/*@}*/

/*******************************************************************************
 * HW_CSI_CSICR18 - CSI Control Register 18
 ******************************************************************************/

/*!
 * @brief HW_CSI_CSICR18 - CSI Control Register 18 (RW)
 *
 * Reset value: 0x0002D000U
 *
 * This read/write register acts as an extension of the functionality of the CSI
 * Control register 1
 */
typedef union _hw_csi_csicr18
{
    uint32_t U;
    struct _hw_csi_csicr18_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t DEINTERLACE_EN : 1;   /*!< [2]  */
        uint32_t PARALLEL24_EN : 1;    /*!< [3]  */
        uint32_t BASEADDR_SWITCH_EN : 1; /*!< [4]  */
        uint32_t BASEADDR_SWITCH_SEL : 1; /*!< [5]  */
        uint32_t FIELD0_DONE_IE : 1;   /*!< [6]  */
        uint32_t DMA_FIELD1_DONE_IE : 1; /*!< [7]  */
        uint32_t LAST_DMA_REQ_SEL : 1; /*!< [8]  */
        uint32_t BASEADDR_CHANGE_ERROR_IE : 1; /*!< [9]  */
        uint32_t RGB888A_FORMAT_SEL : 1; /*!< [10]  */
        uint32_t RESERVED1 : 1;        /*!< [11]  */
        uint32_t AHB_HPROT : 4;        /*!< [15:12]  */
        uint32_t CSI_LCDIF_BUFFER_LINES : 2; /*!< [17:16]  */
        uint32_t MASK_OPTION : 2;      /*!< [19:18]  */
        uint32_t MIPI_DOUBLE_CMPNT : 1; /*!< [20]  */
        uint32_t MIPI_YU_SWAP : 1;     /*!< [21] It only works in MIPI CSI YUV422
                                        * double component mode. */
        uint32_t DATA_FROM_MIPI : 1;   /*!< [22]  */
        uint32_t RESERVED2 : 1;        /*!< [23] Reserved */
        uint32_t LINE_STRIDE_EN : 1;   /*!< [24]  */
        uint32_t MIPI_DATA_FORMAT : 6; /*!< [30:25] Image Data Format */
        uint32_t CSI_ENABLE : 1;       /*!< [31]  */
    } B;
} hw_csi_csicr18_t;

/*!
 * @name Constants and macros for entire CSI_CSICR18 register
 */
/*@{*/
#define HW_CSI_CSICR18_ADDR(x)   ((uintptr_t)(x) + 0x48U)

#define HW_CSI_CSICR18(x)        (*(__IO hw_csi_csicr18_t *) HW_CSI_CSICR18_ADDR(x))
#define HW_CSI_CSICR18_RD(x)     (HW_CSI_CSICR18(x).U)
#define HW_CSI_CSICR18_WR(x, v)  (HW_CSI_CSICR18(x).U = (v))
#define HW_CSI_CSICR18_SET(x, v) (HW_CSI_CSICR18_WR(x, HW_CSI_CSICR18_RD(x) |  (v)))
#define HW_CSI_CSICR18_CLR(x, v) (HW_CSI_CSICR18_WR(x, HW_CSI_CSICR18_RD(x) & ~(v)))
#define HW_CSI_CSICR18_TOG(x, v) (HW_CSI_CSICR18_WR(x, HW_CSI_CSICR18_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CSI_CSICR18 bitfields
 */

/*!
 * @name Register CSI_CSICR18, field DEINTERLACE_EN[2] (RW)
 *
 * This bit is used to select the output method When input is standard CCIR656
 * video.
 *
 * Values:
 * - 0 - Deinterlace disabled
 * - 1 - Deinterlace enabled
 */
/*@{*/
#define BP_CSI_CSICR18_DEINTERLACE_EN (2U) /*!< Bit position for CSI_CSICR18_DEINTERLACE_EN. */
#define BM_CSI_CSICR18_DEINTERLACE_EN (0x00000004U) /*!< Bit mask for CSI_CSICR18_DEINTERLACE_EN. */
#define BS_CSI_CSICR18_DEINTERLACE_EN (1U) /*!< Bit field size in bits for CSI_CSICR18_DEINTERLACE_EN. */

/*! @brief Read current value of the CSI_CSICR18_DEINTERLACE_EN field. */
#define BR_CSI_CSICR18_DEINTERLACE_EN(x) (HW_CSI_CSICR18(x).B.DEINTERLACE_EN)

/*! @brief Format value for bitfield CSI_CSICR18_DEINTERLACE_EN. */
#define BF_CSI_CSICR18_DEINTERLACE_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_DEINTERLACE_EN) & BM_CSI_CSICR18_DEINTERLACE_EN)

/*! @brief Set the DEINTERLACE_EN field to a new value. */
#define BW_CSI_CSICR18_DEINTERLACE_EN(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_DEINTERLACE_EN) | BF_CSI_CSICR18_DEINTERLACE_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field PARALLEL24_EN[3] (RW)
 *
 * When input is parallel rgb888/yuv444 24bit, this bit can be enabled.
 */
/*@{*/
#define BP_CSI_CSICR18_PARALLEL24_EN (3U)  /*!< Bit position for CSI_CSICR18_PARALLEL24_EN. */
#define BM_CSI_CSICR18_PARALLEL24_EN (0x00000008U) /*!< Bit mask for CSI_CSICR18_PARALLEL24_EN. */
#define BS_CSI_CSICR18_PARALLEL24_EN (1U)  /*!< Bit field size in bits for CSI_CSICR18_PARALLEL24_EN. */

/*! @brief Read current value of the CSI_CSICR18_PARALLEL24_EN field. */
#define BR_CSI_CSICR18_PARALLEL24_EN(x) (HW_CSI_CSICR18(x).B.PARALLEL24_EN)

/*! @brief Format value for bitfield CSI_CSICR18_PARALLEL24_EN. */
#define BF_CSI_CSICR18_PARALLEL24_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_PARALLEL24_EN) & BM_CSI_CSICR18_PARALLEL24_EN)

/*! @brief Set the PARALLEL24_EN field to a new value. */
#define BW_CSI_CSICR18_PARALLEL24_EN(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_PARALLEL24_EN) | BF_CSI_CSICR18_PARALLEL24_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field BASEADDR_SWITCH_EN[4] (RW)
 *
 * When this bit is enabled, CSI DMA will switch the base address according to
 * BASEADDR_SWITCH_SEL rather than atomically by DMA completed.
 */
/*@{*/
#define BP_CSI_CSICR18_BASEADDR_SWITCH_EN (4U) /*!< Bit position for CSI_CSICR18_BASEADDR_SWITCH_EN. */
#define BM_CSI_CSICR18_BASEADDR_SWITCH_EN (0x00000010U) /*!< Bit mask for CSI_CSICR18_BASEADDR_SWITCH_EN. */
#define BS_CSI_CSICR18_BASEADDR_SWITCH_EN (1U) /*!< Bit field size in bits for CSI_CSICR18_BASEADDR_SWITCH_EN. */

/*! @brief Read current value of the CSI_CSICR18_BASEADDR_SWITCH_EN field. */
#define BR_CSI_CSICR18_BASEADDR_SWITCH_EN(x) (HW_CSI_CSICR18(x).B.BASEADDR_SWITCH_EN)

/*! @brief Format value for bitfield CSI_CSICR18_BASEADDR_SWITCH_EN. */
#define BF_CSI_CSICR18_BASEADDR_SWITCH_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_BASEADDR_SWITCH_EN) & BM_CSI_CSICR18_BASEADDR_SWITCH_EN)

/*! @brief Set the BASEADDR_SWITCH_EN field to a new value. */
#define BW_CSI_CSICR18_BASEADDR_SWITCH_EN(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_BASEADDR_SWITCH_EN) | BF_CSI_CSICR18_BASEADDR_SWITCH_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field BASEADDR_SWITCH_SEL[5] (RW)
 *
 * CSI 2 base addresses switching method. When using this bit,
 * BASEADDR_SWITCH_EN is 1.
 *
 * Values:
 * - 0 - Switching base address at the edge of the vsync
 * - 1 - Switching base address at the edge of the first data of each frame
 */
/*@{*/
#define BP_CSI_CSICR18_BASEADDR_SWITCH_SEL (5U) /*!< Bit position for CSI_CSICR18_BASEADDR_SWITCH_SEL. */
#define BM_CSI_CSICR18_BASEADDR_SWITCH_SEL (0x00000020U) /*!< Bit mask for CSI_CSICR18_BASEADDR_SWITCH_SEL. */
#define BS_CSI_CSICR18_BASEADDR_SWITCH_SEL (1U) /*!< Bit field size in bits for CSI_CSICR18_BASEADDR_SWITCH_SEL. */

/*! @brief Read current value of the CSI_CSICR18_BASEADDR_SWITCH_SEL field. */
#define BR_CSI_CSICR18_BASEADDR_SWITCH_SEL(x) (HW_CSI_CSICR18(x).B.BASEADDR_SWITCH_SEL)

/*! @brief Format value for bitfield CSI_CSICR18_BASEADDR_SWITCH_SEL. */
#define BF_CSI_CSICR18_BASEADDR_SWITCH_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_BASEADDR_SWITCH_SEL) & BM_CSI_CSICR18_BASEADDR_SWITCH_SEL)

/*! @brief Set the BASEADDR_SWITCH_SEL field to a new value. */
#define BW_CSI_CSICR18_BASEADDR_SWITCH_SEL(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_BASEADDR_SWITCH_SEL) | BF_CSI_CSICR18_BASEADDR_SWITCH_SEL(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field FIELD0_DONE_IE[6] (RW)
 *
 * In interlace mode, fileld 0 means interrupt enabled.
 *
 * Values:
 * - 0 - Interrupt disabled
 * - 1 - Interrupt enabled
 */
/*@{*/
#define BP_CSI_CSICR18_FIELD0_DONE_IE (6U) /*!< Bit position for CSI_CSICR18_FIELD0_DONE_IE. */
#define BM_CSI_CSICR18_FIELD0_DONE_IE (0x00000040U) /*!< Bit mask for CSI_CSICR18_FIELD0_DONE_IE. */
#define BS_CSI_CSICR18_FIELD0_DONE_IE (1U) /*!< Bit field size in bits for CSI_CSICR18_FIELD0_DONE_IE. */

/*! @brief Read current value of the CSI_CSICR18_FIELD0_DONE_IE field. */
#define BR_CSI_CSICR18_FIELD0_DONE_IE(x) (HW_CSI_CSICR18(x).B.FIELD0_DONE_IE)

/*! @brief Format value for bitfield CSI_CSICR18_FIELD0_DONE_IE. */
#define BF_CSI_CSICR18_FIELD0_DONE_IE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_FIELD0_DONE_IE) & BM_CSI_CSICR18_FIELD0_DONE_IE)

/*! @brief Set the FIELD0_DONE_IE field to a new value. */
#define BW_CSI_CSICR18_FIELD0_DONE_IE(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_FIELD0_DONE_IE) | BF_CSI_CSICR18_FIELD0_DONE_IE(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field DMA_FIELD1_DONE_IE[7] (RW)
 *
 * When in interlace mode, field 1 done interrupt enable.
 *
 * Values:
 * - 0 - Interrupt disabled
 * - 1 - Interrupt enabled
 */
/*@{*/
#define BP_CSI_CSICR18_DMA_FIELD1_DONE_IE (7U) /*!< Bit position for CSI_CSICR18_DMA_FIELD1_DONE_IE. */
#define BM_CSI_CSICR18_DMA_FIELD1_DONE_IE (0x00000080U) /*!< Bit mask for CSI_CSICR18_DMA_FIELD1_DONE_IE. */
#define BS_CSI_CSICR18_DMA_FIELD1_DONE_IE (1U) /*!< Bit field size in bits for CSI_CSICR18_DMA_FIELD1_DONE_IE. */

/*! @brief Read current value of the CSI_CSICR18_DMA_FIELD1_DONE_IE field. */
#define BR_CSI_CSICR18_DMA_FIELD1_DONE_IE(x) (HW_CSI_CSICR18(x).B.DMA_FIELD1_DONE_IE)

/*! @brief Format value for bitfield CSI_CSICR18_DMA_FIELD1_DONE_IE. */
#define BF_CSI_CSICR18_DMA_FIELD1_DONE_IE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_DMA_FIELD1_DONE_IE) & BM_CSI_CSICR18_DMA_FIELD1_DONE_IE)

/*! @brief Set the DMA_FIELD1_DONE_IE field to a new value. */
#define BW_CSI_CSICR18_DMA_FIELD1_DONE_IE(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_DMA_FIELD1_DONE_IE) | BF_CSI_CSICR18_DMA_FIELD1_DONE_IE(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field LAST_DMA_REQ_SEL[8] (RW)
 *
 * Choosing the last DMA request condition.
 *
 * Values:
 * - 0 - fifo_full_level
 * - 1 - hburst_length
 */
/*@{*/
#define BP_CSI_CSICR18_LAST_DMA_REQ_SEL (8U) /*!< Bit position for CSI_CSICR18_LAST_DMA_REQ_SEL. */
#define BM_CSI_CSICR18_LAST_DMA_REQ_SEL (0x00000100U) /*!< Bit mask for CSI_CSICR18_LAST_DMA_REQ_SEL. */
#define BS_CSI_CSICR18_LAST_DMA_REQ_SEL (1U) /*!< Bit field size in bits for CSI_CSICR18_LAST_DMA_REQ_SEL. */

/*! @brief Read current value of the CSI_CSICR18_LAST_DMA_REQ_SEL field. */
#define BR_CSI_CSICR18_LAST_DMA_REQ_SEL(x) (HW_CSI_CSICR18(x).B.LAST_DMA_REQ_SEL)

/*! @brief Format value for bitfield CSI_CSICR18_LAST_DMA_REQ_SEL. */
#define BF_CSI_CSICR18_LAST_DMA_REQ_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_LAST_DMA_REQ_SEL) & BM_CSI_CSICR18_LAST_DMA_REQ_SEL)

/*! @brief Set the LAST_DMA_REQ_SEL field to a new value. */
#define BW_CSI_CSICR18_LAST_DMA_REQ_SEL(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_LAST_DMA_REQ_SEL) | BF_CSI_CSICR18_LAST_DMA_REQ_SEL(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field BASEADDR_CHANGE_ERROR_IE[9] (RW)
 *
 * Base address change error interrupt enable signal.
 */
/*@{*/
#define BP_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE (9U) /*!< Bit position for CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE. */
#define BM_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE (0x00000200U) /*!< Bit mask for CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE. */
#define BS_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE (1U) /*!< Bit field size in bits for CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE. */

/*! @brief Read current value of the CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE field. */
#define BR_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE(x) (HW_CSI_CSICR18(x).B.BASEADDR_CHANGE_ERROR_IE)

/*! @brief Format value for bitfield CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE. */
#define BF_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE) & BM_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE)

/*! @brief Set the BASEADDR_CHANGE_ERROR_IE field to a new value. */
#define BW_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE) | BF_CSI_CSICR18_BASEADDR_CHANGE_ERROR_IE(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field RGB888A_FORMAT_SEL[10] (RW)
 *
 * Output is 32-bit format.
 *
 * Values:
 * - 0 - {8'h0, data[23:0]}
 * - 1 - {data[23:0], 8'h0}
 */
/*@{*/
#define BP_CSI_CSICR18_RGB888A_FORMAT_SEL (10U) /*!< Bit position for CSI_CSICR18_RGB888A_FORMAT_SEL. */
#define BM_CSI_CSICR18_RGB888A_FORMAT_SEL (0x00000400U) /*!< Bit mask for CSI_CSICR18_RGB888A_FORMAT_SEL. */
#define BS_CSI_CSICR18_RGB888A_FORMAT_SEL (1U) /*!< Bit field size in bits for CSI_CSICR18_RGB888A_FORMAT_SEL. */

/*! @brief Read current value of the CSI_CSICR18_RGB888A_FORMAT_SEL field. */
#define BR_CSI_CSICR18_RGB888A_FORMAT_SEL(x) (HW_CSI_CSICR18(x).B.RGB888A_FORMAT_SEL)

/*! @brief Format value for bitfield CSI_CSICR18_RGB888A_FORMAT_SEL. */
#define BF_CSI_CSICR18_RGB888A_FORMAT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_RGB888A_FORMAT_SEL) & BM_CSI_CSICR18_RGB888A_FORMAT_SEL)

/*! @brief Set the RGB888A_FORMAT_SEL field to a new value. */
#define BW_CSI_CSICR18_RGB888A_FORMAT_SEL(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_RGB888A_FORMAT_SEL) | BF_CSI_CSICR18_RGB888A_FORMAT_SEL(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field AHB_HPROT[15:12] (RW)
 *
 * Hprot value in AHB bus protocol.
 */
/*@{*/
#define BP_CSI_CSICR18_AHB_HPROT (12U)     /*!< Bit position for CSI_CSICR18_AHB_HPROT. */
#define BM_CSI_CSICR18_AHB_HPROT (0x0000F000U) /*!< Bit mask for CSI_CSICR18_AHB_HPROT. */
#define BS_CSI_CSICR18_AHB_HPROT (4U)      /*!< Bit field size in bits for CSI_CSICR18_AHB_HPROT. */

/*! @brief Read current value of the CSI_CSICR18_AHB_HPROT field. */
#define BR_CSI_CSICR18_AHB_HPROT(x) (HW_CSI_CSICR18(x).B.AHB_HPROT)

/*! @brief Format value for bitfield CSI_CSICR18_AHB_HPROT. */
#define BF_CSI_CSICR18_AHB_HPROT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_AHB_HPROT) & BM_CSI_CSICR18_AHB_HPROT)

/*! @brief Set the AHB_HPROT field to a new value. */
#define BW_CSI_CSICR18_AHB_HPROT(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_AHB_HPROT) | BF_CSI_CSICR18_AHB_HPROT(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field CSI_LCDIF_BUFFER_LINES[17:16] (RW)
 *
 * The number of lines are used in handshake mode with LCDIF.
 *
 * Values:
 * - 00 - 4 lines
 * - 01 - 8 lines
 */
/*@{*/
#define BP_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES (16U) /*!< Bit position for CSI_CSICR18_CSI_LCDIF_BUFFER_LINES. */
#define BM_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES (0x00030000U) /*!< Bit mask for CSI_CSICR18_CSI_LCDIF_BUFFER_LINES. */
#define BS_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES (2U) /*!< Bit field size in bits for CSI_CSICR18_CSI_LCDIF_BUFFER_LINES. */

/*! @brief Read current value of the CSI_CSICR18_CSI_LCDIF_BUFFER_LINES field. */
#define BR_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES(x) (HW_CSI_CSICR18(x).B.CSI_LCDIF_BUFFER_LINES)

/*! @brief Format value for bitfield CSI_CSICR18_CSI_LCDIF_BUFFER_LINES. */
#define BF_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES) & BM_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES)

/*! @brief Set the CSI_LCDIF_BUFFER_LINES field to a new value. */
#define BW_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES) | BF_CSI_CSICR18_CSI_LCDIF_BUFFER_LINES(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field MASK_OPTION[19:18] (RW)
 *
 * These bits used to choose the method to mask the CSI input.
 *
 * Values:
 * - 00 - Writing to memory from first completely frame, when using this option,
 *     the CSI_ENABLE should be 1.
 * - 01 - Writing to memory when CSI_ENABLE is 1.
 */
/*@{*/
#define BP_CSI_CSICR18_MASK_OPTION (18U)   /*!< Bit position for CSI_CSICR18_MASK_OPTION. */
#define BM_CSI_CSICR18_MASK_OPTION (0x000C0000U) /*!< Bit mask for CSI_CSICR18_MASK_OPTION. */
#define BS_CSI_CSICR18_MASK_OPTION (2U)    /*!< Bit field size in bits for CSI_CSICR18_MASK_OPTION. */

/*! @brief Read current value of the CSI_CSICR18_MASK_OPTION field. */
#define BR_CSI_CSICR18_MASK_OPTION(x) (HW_CSI_CSICR18(x).B.MASK_OPTION)

/*! @brief Format value for bitfield CSI_CSICR18_MASK_OPTION. */
#define BF_CSI_CSICR18_MASK_OPTION(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_MASK_OPTION) & BM_CSI_CSICR18_MASK_OPTION)

/*! @brief Set the MASK_OPTION field to a new value. */
#define BW_CSI_CSICR18_MASK_OPTION(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_MASK_OPTION) | BF_CSI_CSICR18_MASK_OPTION(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field MIPI_DOUBLE_CMPNT[20] (RW)
 *
 * Double component per clock cycle in YUV422 formats.
 *
 * Values:
 * - 0 - Single component per clock cycle (half pixel per clock cycle)
 * - 1 - Double component per clock cycle (a pixel per clock cycle)
 */
/*@{*/
#define BP_CSI_CSICR18_MIPI_DOUBLE_CMPNT (20U) /*!< Bit position for CSI_CSICR18_MIPI_DOUBLE_CMPNT. */
#define BM_CSI_CSICR18_MIPI_DOUBLE_CMPNT (0x00100000U) /*!< Bit mask for CSI_CSICR18_MIPI_DOUBLE_CMPNT. */
#define BS_CSI_CSICR18_MIPI_DOUBLE_CMPNT (1U) /*!< Bit field size in bits for CSI_CSICR18_MIPI_DOUBLE_CMPNT. */

/*! @brief Read current value of the CSI_CSICR18_MIPI_DOUBLE_CMPNT field. */
#define BR_CSI_CSICR18_MIPI_DOUBLE_CMPNT(x) (HW_CSI_CSICR18(x).B.MIPI_DOUBLE_CMPNT)

/*! @brief Format value for bitfield CSI_CSICR18_MIPI_DOUBLE_CMPNT. */
#define BF_CSI_CSICR18_MIPI_DOUBLE_CMPNT(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_MIPI_DOUBLE_CMPNT) & BM_CSI_CSICR18_MIPI_DOUBLE_CMPNT)

/*! @brief Set the MIPI_DOUBLE_CMPNT field to a new value. */
#define BW_CSI_CSICR18_MIPI_DOUBLE_CMPNT(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_MIPI_DOUBLE_CMPNT) | BF_CSI_CSICR18_MIPI_DOUBLE_CMPNT(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field MIPI_YU_SWAP[21] (RW)
 */
/*@{*/
#define BP_CSI_CSICR18_MIPI_YU_SWAP (21U)  /*!< Bit position for CSI_CSICR18_MIPI_YU_SWAP. */
#define BM_CSI_CSICR18_MIPI_YU_SWAP (0x00200000U) /*!< Bit mask for CSI_CSICR18_MIPI_YU_SWAP. */
#define BS_CSI_CSICR18_MIPI_YU_SWAP (1U)   /*!< Bit field size in bits for CSI_CSICR18_MIPI_YU_SWAP. */

/*! @brief Read current value of the CSI_CSICR18_MIPI_YU_SWAP field. */
#define BR_CSI_CSICR18_MIPI_YU_SWAP(x) (HW_CSI_CSICR18(x).B.MIPI_YU_SWAP)

/*! @brief Format value for bitfield CSI_CSICR18_MIPI_YU_SWAP. */
#define BF_CSI_CSICR18_MIPI_YU_SWAP(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_MIPI_YU_SWAP) & BM_CSI_CSICR18_MIPI_YU_SWAP)

/*! @brief Set the MIPI_YU_SWAP field to a new value. */
#define BW_CSI_CSICR18_MIPI_YU_SWAP(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_MIPI_YU_SWAP) | BF_CSI_CSICR18_MIPI_YU_SWAP(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field DATA_FROM_MIPI[22] (RW)
 *
 * Values:
 * - 0 - Data from parallel sensor
 * - 1 - Data from MIPI
 */
/*@{*/
#define BP_CSI_CSICR18_DATA_FROM_MIPI (22U) /*!< Bit position for CSI_CSICR18_DATA_FROM_MIPI. */
#define BM_CSI_CSICR18_DATA_FROM_MIPI (0x00400000U) /*!< Bit mask for CSI_CSICR18_DATA_FROM_MIPI. */
#define BS_CSI_CSICR18_DATA_FROM_MIPI (1U) /*!< Bit field size in bits for CSI_CSICR18_DATA_FROM_MIPI. */

/*! @brief Read current value of the CSI_CSICR18_DATA_FROM_MIPI field. */
#define BR_CSI_CSICR18_DATA_FROM_MIPI(x) (HW_CSI_CSICR18(x).B.DATA_FROM_MIPI)

/*! @brief Format value for bitfield CSI_CSICR18_DATA_FROM_MIPI. */
#define BF_CSI_CSICR18_DATA_FROM_MIPI(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_DATA_FROM_MIPI) & BM_CSI_CSICR18_DATA_FROM_MIPI)

/*! @brief Set the DATA_FROM_MIPI field to a new value. */
#define BW_CSI_CSICR18_DATA_FROM_MIPI(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_DATA_FROM_MIPI) | BF_CSI_CSICR18_DATA_FROM_MIPI(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field LINE_STRIDE_EN[24] (RW)
 *
 * When the line width are not the multiple of the burst length, assert this bit.
 */
/*@{*/
#define BP_CSI_CSICR18_LINE_STRIDE_EN (24U) /*!< Bit position for CSI_CSICR18_LINE_STRIDE_EN. */
#define BM_CSI_CSICR18_LINE_STRIDE_EN (0x01000000U) /*!< Bit mask for CSI_CSICR18_LINE_STRIDE_EN. */
#define BS_CSI_CSICR18_LINE_STRIDE_EN (1U) /*!< Bit field size in bits for CSI_CSICR18_LINE_STRIDE_EN. */

/*! @brief Read current value of the CSI_CSICR18_LINE_STRIDE_EN field. */
#define BR_CSI_CSICR18_LINE_STRIDE_EN(x) (HW_CSI_CSICR18(x).B.LINE_STRIDE_EN)

/*! @brief Format value for bitfield CSI_CSICR18_LINE_STRIDE_EN. */
#define BF_CSI_CSICR18_LINE_STRIDE_EN(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_LINE_STRIDE_EN) & BM_CSI_CSICR18_LINE_STRIDE_EN)

/*! @brief Set the LINE_STRIDE_EN field to a new value. */
#define BW_CSI_CSICR18_LINE_STRIDE_EN(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_LINE_STRIDE_EN) | BF_CSI_CSICR18_LINE_STRIDE_EN(v)))
/*@}*/

/*!
 * @name Register CSI_CSICR18, field MIPI_DATA_FORMAT[30:25] (RO)
 *
 * Generic Short Packet: 0x08 ~ 0x0F Embedded 8-bit non Image: 0x12
 */
/*@{*/
#define BP_CSI_CSICR18_MIPI_DATA_FORMAT (25U) /*!< Bit position for CSI_CSICR18_MIPI_DATA_FORMAT. */
#define BM_CSI_CSICR18_MIPI_DATA_FORMAT (0x7E000000U) /*!< Bit mask for CSI_CSICR18_MIPI_DATA_FORMAT. */
#define BS_CSI_CSICR18_MIPI_DATA_FORMAT (6U) /*!< Bit field size in bits for CSI_CSICR18_MIPI_DATA_FORMAT. */

/*! @brief Read current value of the CSI_CSICR18_MIPI_DATA_FORMAT field. */
#define BR_CSI_CSICR18_MIPI_DATA_FORMAT(x) (HW_CSI_CSICR18(x).B.MIPI_DATA_FORMAT)
/*@}*/

/*!
 * @name Register CSI_CSICR18, field CSI_ENABLE[31] (RW)
 *
 * CSI global enable signal. Only when this bit is 1, CSI can start to receive
 * the data and store to memory.
 */
/*@{*/
#define BP_CSI_CSICR18_CSI_ENABLE (31U)    /*!< Bit position for CSI_CSICR18_CSI_ENABLE. */
#define BM_CSI_CSICR18_CSI_ENABLE (0x80000000U) /*!< Bit mask for CSI_CSICR18_CSI_ENABLE. */
#define BS_CSI_CSICR18_CSI_ENABLE (1U)     /*!< Bit field size in bits for CSI_CSICR18_CSI_ENABLE. */

/*! @brief Read current value of the CSI_CSICR18_CSI_ENABLE field. */
#define BR_CSI_CSICR18_CSI_ENABLE(x) (HW_CSI_CSICR18(x).B.CSI_ENABLE)

/*! @brief Format value for bitfield CSI_CSICR18_CSI_ENABLE. */
#define BF_CSI_CSICR18_CSI_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_CSI_CSICR18_CSI_ENABLE) & BM_CSI_CSICR18_CSI_ENABLE)

/*! @brief Set the CSI_ENABLE field to a new value. */
#define BW_CSI_CSICR18_CSI_ENABLE(x, v) (HW_CSI_CSICR18_WR(x, (HW_CSI_CSICR18_RD(x) & ~BM_CSI_CSICR18_CSI_ENABLE) | BF_CSI_CSICR18_CSI_ENABLE(v)))
/*@}*/

/*******************************************************************************
 * hw_csi_t - module struct
 ******************************************************************************/
/*!
 * @brief All CSI module registers.
 */
#pragma pack(1)
typedef struct _hw_csi
{
    __IO hw_csi_csicr1_t CSICR1;           /*!< [0x0] CSI Control Register 1 */
    __IO hw_csi_csicr2_t CSICR2;           /*!< [0x4] CSI Control Register 2 */
    __IO hw_csi_csicr3_t CSICR3;           /*!< [0x8] CSI Control Register 3 */
    __I hw_csi_csistatfifo_t CSISTATFIFO;  /*!< [0xC] CSI Statistic FIFO Register */
    __I hw_csi_csirfifo_t CSIRFIFO;        /*!< [0x10] CSI RX FIFO Register */
    __IO hw_csi_csirxcnt_t CSIRXCNT;       /*!< [0x14] CSI RX Count Register */
    __IO hw_csi_csisr_t CSISR;             /*!< [0x18] CSI Status Register */
    uint8_t _reserved0[4];
    __IO hw_csi_csidmasa_statfifo_t CSIDMASA_STATFIFO; /*!< [0x20] CSI DMA Start Address Register - for STATFIFO */
    __IO hw_csi_csidmats_statfifo_t CSIDMATS_STATFIFO; /*!< [0x24] CSI DMA Transfer Size Register - for STATFIFO */
    __IO hw_csi_csidmasa_fb1_t CSIDMASA_FB1; /*!< [0x28] CSI DMA Start Address Register - for Frame Buffer1 */
    __IO hw_csi_csidmasa_fb2_t CSIDMASA_FB2; /*!< [0x2C] CSI DMA Transfer Size Register - for Frame Buffer2 */
    __IO hw_csi_csifbuf_para_t CSIFBUF_PARA; /*!< [0x30] CSI Frame Buffer Parameter Register */
    __IO hw_csi_csiimag_para_t CSIIMAG_PARA; /*!< [0x34] CSI Image Parameter Register */
    uint8_t _reserved1[16];
    __IO hw_csi_csicr18_t CSICR18;         /*!< [0x48] CSI Control Register 18 */
} hw_csi_t;
#pragma pack()

/*! @brief Macro to access all CSI registers. */
/*! @param x CSI module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_CSI_REGS(CSI_BASE)</code>. */
#define HW_CSI_REGS(x) (*(hw_csi_t *)(x))

/*
 * iMX7D DDRC
 *
 * DDRC DDR Control Registers
 *
 * Registers defined in this header file:
 * - HW_DDRC_MSTR - Master Register
 * - HW_DDRC_STAT - Operating Mode Status Register
 * - HW_DDRC_MRCTRL0 - Mode Register Read / Write Control Register 0
 * - HW_DDRC_MRCTRL1 - Mode Register Read / Write Control Register 1
 * - HW_DDRC_MRSTAT - Mode Register Read / Write Status Register
 * - HW_DDRC_DERATEEN - Temperature Derate Enable Register
 * - HW_DDRC_DERATEINT - Temperature Derate Interval Register
 * - HW_DDRC_PWRCTL - Low Power Control Register
 * - HW_DDRC_PWRTMG - Low Power Timing Register
 * - HW_DDRC_HWLPCTL - Hardware Low Power Control Register
 * - HW_DDRC_RFSHCTL0 - Refresh Control Register 0
 * - HW_DDRC_RFSHCTL1 - Refresh Control Register 1
 * - HW_DDRC_RFSHCTL3 - Refresh Control Register 0
 * - HW_DDRC_RFSHTMG - Refresh Timing Register
 * - HW_DDRC_INIT0 - SDRAM Initialization Register 0
 * - HW_DDRC_INIT1 - SDRAM Initialization Register 1
 * - HW_DDRC_INIT2 - SDRAM Initialization Register 2
 * - HW_DDRC_INIT3 - SDRAM Initialization Register 3
 * - HW_DDRC_INIT4 - SDRAM Initialization Register 4
 * - HW_DDRC_INIT5 - SDRAM Initialization Register 5
 * - HW_DDRC_RANKCTL - Rank Control Register
 * - HW_DDRC_DRAMTMG0 - SDRAM Timing Register 0
 * - HW_DDRC_DRAMTMG1 - SDRAM Timing Register 1
 * - HW_DDRC_DRAMTMG2 - SDRAM Timing Register 2
 * - HW_DDRC_DRAMTMG3 - SDRAM Timing Register 3
 * - HW_DDRC_DRAMTMG4 - SDRAM Timing Register 4
 * - HW_DDRC_DRAMTMG5 - SDRAM Timing Register5
 * - HW_DDRC_DRAMTMG6 - SDRAM Timing Register 6
 * - HW_DDRC_DRAMTMG7 - SDRAM Timing Register 7
 * - HW_DDRC_DRAMTMG8 - SDRAM Timing Register 8
 * - HW_DDRC_ZQCTL0 - ZQ Control Register 0
 * - HW_DDRC_ZQCTL1 - ZQ Control Register 1
 * - HW_DDRC_ZQCTL2 - ZQ Control Register 2
 * - HW_DDRC_ZQSTAT - ZQ Status Register
 * - HW_DDRC_DFITMG0 - DFI Timing Register 0
 * - HW_DDRC_DFITMG1 - DFI Timing Register 1
 * - HW_DDRC_DFILPCFG0 - DFI Low Power Configuration Register 0
 * - HW_DDRC_DFIUPD0 - DFI Update Register 0
 * - HW_DDRC_DFIUPD1 - DFI Update Register 1
 * - HW_DDRC_DFIUPD2 - DFI Update Register 2
 * - HW_DDRC_DFIUPD3 - DFI Update Register 3
 * - HW_DDRC_DFIMISC - DFI Miscellaneous Control Register
 * - HW_DDRC_ADDRMAP0 - Address Map Register 0
 * - HW_DDRC_ADDRMAP1 - Address Map Register 1
 * - HW_DDRC_ADDRMAP2 - Address Map Register 2
 * - HW_DDRC_ADDRMAP3 - Address Map Register 3
 * - HW_DDRC_ADDRMAP4 - Address Map Register 4
 * - HW_DDRC_ADDRMAP5 - Address Map Register 5
 * - HW_DDRC_ADDRMAP6 - Address Map Register 6
 * - HW_DDRC_ODTCFG - ODT Configuration Register
 * - HW_DDRC_ODTMAP - ODT / Rank Map Register
 * - HW_DDRC_SCHED - Scheduler Control Register
 * - HW_DDRC_SCHED1 - Scheduler Control Register 1
 * - HW_DDRC_PERFHPR1 - High Priority Read CAM Register 1
 * - HW_DDRC_PERFLPR1 - Low Priority Read CAM Register 1
 * - HW_DDRC_PERFWR1 - Write CAM Register 1
 * - HW_DDRC_PERFVPR1 - Variable Priority Read CAM Register 1
 * - HW_DDRC_PERFVPW1 - Variable Priority Write CAM Register 1
 * - HW_DDRC_DBG0 - Debug Register 0
 * - HW_DDRC_DBG1 - Debug Register 1
 * - HW_DDRC_DBGCAM - CAM Debug Register
 * - HW_DDRC_DBGCMD - Command Debug Register
 * - HW_DDRC_DBGSTAT - Status Debug Register
 * - HW_DDRC_SWCTL - Software Register Programming Control Enable
 * - HW_DDRC_SWSTAT - Software Register Programming Control Status
 *
 * - hw_ddrc_t - Struct containing all module registers.
 */

#define HW_DDRC_INSTANCE_COUNT (1U) /*!< Number of instances of the DDRC module. */
#define HW_DDRC (0U) /*!< Instance number for DDRC. */
#define DDRC_BASE             (0x307A0000U) /*!< Base address for DDRC. */
/*! Array initializer of DDRC base addresses. */
#define DDRC_BASE_ADDRS       { DDRC_BASE }

/*******************************************************************************
 * HW_DDRC_MSTR - Master Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_MSTR - Master Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_mstr
{
    uint32_t U;
    struct _hw_ddrc_mstr_bitfields
    {
        uint32_t DDR3 : 1;             /*!< [0]  */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t LPDDR2 : 1;           /*!< [2] Select LPDDR2 SDRAM */
        uint32_t LPDDR3 : 1;           /*!< [3] Select LPDDR3 SDRAM */
        uint32_t RESERVED1 : 4;        /*!< [7:4]  */
        uint32_t BURST_MODE : 1;       /*!< [8] Indicates Burst Mode */
        uint32_t BURSTCHOP : 1;        /*!< [9]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t DATA_BUS_WIDTH : 2;   /*!< [13:12]  */
        uint32_t RESERVED3 : 1;        /*!< [14]  */
        uint32_t DLL_OFF_MODE : 1;     /*!< [15]  */
        uint32_t BURST_RDWR : 4;       /*!< [19:16]  */
        uint32_t RESERVED4 : 4;        /*!< [23:20]  */
        uint32_t ACTIVE_RANKS : 4;     /*!< [27:24]  */
        uint32_t RESERVED5 : 4;        /*!< [31:28]  */
    } B;
} hw_ddrc_mstr_t;

/*!
 * @name Constants and macros for entire DDRC_MSTR register
 */
/*@{*/
#define HW_DDRC_MSTR_ADDR(x)     ((uintptr_t)(x) + 0x0U)

#define HW_DDRC_MSTR(x)          (*(__IO hw_ddrc_mstr_t *) HW_DDRC_MSTR_ADDR(x))
#define HW_DDRC_MSTR_RD(x)       (HW_DDRC_MSTR(x).U)
#define HW_DDRC_MSTR_WR(x, v)    (HW_DDRC_MSTR(x).U = (v))
#define HW_DDRC_MSTR_SET(x, v)   (HW_DDRC_MSTR_WR(x, HW_DDRC_MSTR_RD(x) |  (v)))
#define HW_DDRC_MSTR_CLR(x, v)   (HW_DDRC_MSTR_WR(x, HW_DDRC_MSTR_RD(x) & ~(v)))
#define HW_DDRC_MSTR_TOG(x, v)   (HW_DDRC_MSTR_WR(x, HW_DDRC_MSTR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_MSTR bitfields
 */

/*!
 * @name Register DDRC_MSTR, field DDR3[0] (RW)
 *
 * Only present in design that support DDR3. Value After Reset: "(MEMC_DDR3 ==
 * 1) ? 0x1 : 0x0" Exists:MEMC_DDR3 == 1 Select DDR3 SDRAM
 *
 * Values:
 * - 1 - DDR3 SDRAM device in use
 * - 0 - Non-DDR3 device in use
 */
/*@{*/
#define BP_DDRC_MSTR_DDR3    (0U)          /*!< Bit position for DDRC_MSTR_DDR3. */
#define BM_DDRC_MSTR_DDR3    (0x00000001U) /*!< Bit mask for DDRC_MSTR_DDR3. */
#define BS_DDRC_MSTR_DDR3    (1U)          /*!< Bit field size in bits for DDRC_MSTR_DDR3. */

/*! @brief Read current value of the DDRC_MSTR_DDR3 field. */
#define BR_DDRC_MSTR_DDR3(x) (HW_DDRC_MSTR(x).B.DDR3)

/*! @brief Format value for bitfield DDRC_MSTR_DDR3. */
#define BF_DDRC_MSTR_DDR3(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MSTR_DDR3) & BM_DDRC_MSTR_DDR3)

/*! @brief Set the DDR3 field to a new value. */
#define BW_DDRC_MSTR_DDR3(x, v) (HW_DDRC_MSTR_WR(x, (HW_DDRC_MSTR_RD(x) & ~BM_DDRC_MSTR_DDR3) | BF_DDRC_MSTR_DDR3(v)))
/*@}*/

/*!
 * @name Register DDRC_MSTR, field LPDDR2[2] (RW)
 *
 * Present only in designs configured to support LPDDR2. Value After Reset: 0x0
 * Exists:MEMC_LPDDR2 == 1
 *
 * Values:
 * - 1 - LPDDR2 SDRAM device in use
 * - 0 - Non-LPDDR2 device in use
 */
/*@{*/
#define BP_DDRC_MSTR_LPDDR2  (2U)          /*!< Bit position for DDRC_MSTR_LPDDR2. */
#define BM_DDRC_MSTR_LPDDR2  (0x00000004U) /*!< Bit mask for DDRC_MSTR_LPDDR2. */
#define BS_DDRC_MSTR_LPDDR2  (1U)          /*!< Bit field size in bits for DDRC_MSTR_LPDDR2. */

/*! @brief Read current value of the DDRC_MSTR_LPDDR2 field. */
#define BR_DDRC_MSTR_LPDDR2(x) (HW_DDRC_MSTR(x).B.LPDDR2)

/*! @brief Format value for bitfield DDRC_MSTR_LPDDR2. */
#define BF_DDRC_MSTR_LPDDR2(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MSTR_LPDDR2) & BM_DDRC_MSTR_LPDDR2)

/*! @brief Set the LPDDR2 field to a new value. */
#define BW_DDRC_MSTR_LPDDR2(x, v) (HW_DDRC_MSTR_WR(x, (HW_DDRC_MSTR_RD(x) & ~BM_DDRC_MSTR_LPDDR2) | BF_DDRC_MSTR_LPDDR2(v)))
/*@}*/

/*!
 * @name Register DDRC_MSTR, field LPDDR3[3] (RW)
 *
 * Present only in designs configured to support LPDDR3. Value After Reset: 0x0
 * Exists:MEMC_LPDDR3 == 1
 *
 * Values:
 * - 1 - LPDDR3 SDRAM device in use
 * - 0 - Non-LPDDR3 device in use
 */
/*@{*/
#define BP_DDRC_MSTR_LPDDR3  (3U)          /*!< Bit position for DDRC_MSTR_LPDDR3. */
#define BM_DDRC_MSTR_LPDDR3  (0x00000008U) /*!< Bit mask for DDRC_MSTR_LPDDR3. */
#define BS_DDRC_MSTR_LPDDR3  (1U)          /*!< Bit field size in bits for DDRC_MSTR_LPDDR3. */

/*! @brief Read current value of the DDRC_MSTR_LPDDR3 field. */
#define BR_DDRC_MSTR_LPDDR3(x) (HW_DDRC_MSTR(x).B.LPDDR3)

/*! @brief Format value for bitfield DDRC_MSTR_LPDDR3. */
#define BF_DDRC_MSTR_LPDDR3(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MSTR_LPDDR3) & BM_DDRC_MSTR_LPDDR3)

/*! @brief Set the LPDDR3 field to a new value. */
#define BW_DDRC_MSTR_LPDDR3(x, v) (HW_DDRC_MSTR_WR(x, (HW_DDRC_MSTR_RD(x) & ~BM_DDRC_MSTR_LPDDR3) | BF_DDRC_MSTR_LPDDR3(v)))
/*@}*/

/*!
 * @name Register DDRC_MSTR, field BURST_MODE[8] (RW)
 *
 * Value After Reset: 0x0 Exists: DDRC_INCL_ARB == 0
 *
 * Values:
 * - 0 - Sequential burst mode
 * - 1 - Interleaved burst mode
 */
/*@{*/
#define BP_DDRC_MSTR_BURST_MODE (8U)       /*!< Bit position for DDRC_MSTR_BURST_MODE. */
#define BM_DDRC_MSTR_BURST_MODE (0x00000100U) /*!< Bit mask for DDRC_MSTR_BURST_MODE. */
#define BS_DDRC_MSTR_BURST_MODE (1U)       /*!< Bit field size in bits for DDRC_MSTR_BURST_MODE. */

/*! @brief Read current value of the DDRC_MSTR_BURST_MODE field. */
#define BR_DDRC_MSTR_BURST_MODE(x) (HW_DDRC_MSTR(x).B.BURST_MODE)

/*! @brief Format value for bitfield DDRC_MSTR_BURST_MODE. */
#define BF_DDRC_MSTR_BURST_MODE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MSTR_BURST_MODE) & BM_DDRC_MSTR_BURST_MODE)

/*! @brief Set the BURST_MODE field to a new value. */
#define BW_DDRC_MSTR_BURST_MODE(x, v) (HW_DDRC_MSTR_WR(x, (HW_DDRC_MSTR_RD(x) & ~BM_DDRC_MSTR_BURST_MODE) | BF_DDRC_MSTR_BURST_MODE(v)))
/*@}*/

/*!
 * @name Register DDRC_MSTR, field BURSTCHOP[9] (RW)
 *
 * When set, enable burst-chop in DDR3. This is only supported in HIF
 * configurations (DDRC_INCL_ARB not set) using full bus width mode (MSTR.data_bus_width =
 * 00). Value After Reset: 0x0 Exists: MEMC_DDR3 == 1
 */
/*@{*/
#define BP_DDRC_MSTR_BURSTCHOP (9U)        /*!< Bit position for DDRC_MSTR_BURSTCHOP. */
#define BM_DDRC_MSTR_BURSTCHOP (0x00000200U) /*!< Bit mask for DDRC_MSTR_BURSTCHOP. */
#define BS_DDRC_MSTR_BURSTCHOP (1U)        /*!< Bit field size in bits for DDRC_MSTR_BURSTCHOP. */

/*! @brief Read current value of the DDRC_MSTR_BURSTCHOP field. */
#define BR_DDRC_MSTR_BURSTCHOP(x) (HW_DDRC_MSTR(x).B.BURSTCHOP)

/*! @brief Format value for bitfield DDRC_MSTR_BURSTCHOP. */
#define BF_DDRC_MSTR_BURSTCHOP(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MSTR_BURSTCHOP) & BM_DDRC_MSTR_BURSTCHOP)

/*! @brief Set the BURSTCHOP field to a new value. */
#define BW_DDRC_MSTR_BURSTCHOP(x, v) (HW_DDRC_MSTR_WR(x, (HW_DDRC_MSTR_RD(x) & ~BM_DDRC_MSTR_BURSTCHOP) | BF_DDRC_MSTR_BURSTCHOP(v)))
/*@}*/

/*!
 * @name Register DDRC_MSTR, field DATA_BUS_WIDTH[13:12] (RW)
 *
 * Note that half bus width mode is only supported when the SDRAM bus width is a
 * multiple of 16, and quarter bus width mode is only supported when the SDRAM
 * bus width is a multiple of 32 and the configuration parameter MEMC_QBUS_SUPPORT
 * is set. Bus width refers to DQ bus width (excluding any ECC width). Value
 * After Reset: 0x0 Exists: Always Selects proportion of DQ bus width that is used
 * by the SDRAM:
 *
 * Values:
 * - 00 - Full DQ bus width to SDRAM
 * - 01 - Half DQ bus width to SDRAM
 * - 10 - Quater DQ bus width to SDRAM
 * - 11 - Reserved
 */
/*@{*/
#define BP_DDRC_MSTR_DATA_BUS_WIDTH (12U)  /*!< Bit position for DDRC_MSTR_DATA_BUS_WIDTH. */
#define BM_DDRC_MSTR_DATA_BUS_WIDTH (0x00003000U) /*!< Bit mask for DDRC_MSTR_DATA_BUS_WIDTH. */
#define BS_DDRC_MSTR_DATA_BUS_WIDTH (2U)   /*!< Bit field size in bits for DDRC_MSTR_DATA_BUS_WIDTH. */

/*! @brief Read current value of the DDRC_MSTR_DATA_BUS_WIDTH field. */
#define BR_DDRC_MSTR_DATA_BUS_WIDTH(x) (HW_DDRC_MSTR(x).B.DATA_BUS_WIDTH)

/*! @brief Format value for bitfield DDRC_MSTR_DATA_BUS_WIDTH. */
#define BF_DDRC_MSTR_DATA_BUS_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MSTR_DATA_BUS_WIDTH) & BM_DDRC_MSTR_DATA_BUS_WIDTH)

/*! @brief Set the DATA_BUS_WIDTH field to a new value. */
#define BW_DDRC_MSTR_DATA_BUS_WIDTH(x, v) (HW_DDRC_MSTR_WR(x, (HW_DDRC_MSTR_RD(x) & ~BM_DDRC_MSTR_DATA_BUS_WIDTH) | BF_DDRC_MSTR_DATA_BUS_WIDTH(v)))
/*@}*/

/*!
 * @name Register DDRC_MSTR, field DLL_OFF_MODE[15] (RW)
 *
 * Set to 1 when the DDRC and DRAM has to be put in DLL-off mode for low
 * frequency operation. Set to 0 to put DDRC and DRAM in DLL-on mode for normal
 * frequency operation. Value After Reset: 0x0 Exists:MEMC_DDR3 == 1
 */
/*@{*/
#define BP_DDRC_MSTR_DLL_OFF_MODE (15U)    /*!< Bit position for DDRC_MSTR_DLL_OFF_MODE. */
#define BM_DDRC_MSTR_DLL_OFF_MODE (0x00008000U) /*!< Bit mask for DDRC_MSTR_DLL_OFF_MODE. */
#define BS_DDRC_MSTR_DLL_OFF_MODE (1U)     /*!< Bit field size in bits for DDRC_MSTR_DLL_OFF_MODE. */

/*! @brief Read current value of the DDRC_MSTR_DLL_OFF_MODE field. */
#define BR_DDRC_MSTR_DLL_OFF_MODE(x) (HW_DDRC_MSTR(x).B.DLL_OFF_MODE)

/*! @brief Format value for bitfield DDRC_MSTR_DLL_OFF_MODE. */
#define BF_DDRC_MSTR_DLL_OFF_MODE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MSTR_DLL_OFF_MODE) & BM_DDRC_MSTR_DLL_OFF_MODE)

/*! @brief Set the DLL_OFF_MODE field to a new value. */
#define BW_DDRC_MSTR_DLL_OFF_MODE(x, v) (HW_DDRC_MSTR_WR(x, (HW_DDRC_MSTR_RD(x) & ~BM_DDRC_MSTR_DLL_OFF_MODE) | BF_DDRC_MSTR_DLL_OFF_MODE(v)))
/*@}*/

/*!
 * @name Register DDRC_MSTR, field BURST_RDWR[19:16] (RW)
 *
 * All other values are reserved. This controls the burst size used to access
 * the SDRAM. This must match the burst length mode register setting in the SDRAM.
 * Burst length of 2 is not supported with AXI ports when MEMC_BURST_LENGTH is 8.
 * Value After Reset: 0x4 Exists: Always SDRAM burst length used:
 *
 * Values:
 * - 0001 - Burst length of 2 (only supported for mDDR)
 * - 0010 - Burst length of 4
 * - 0100 - Burst length of 8
 * - 1000 - Burst length of 16 (only supported for mDDR and LPDDR2)
 */
/*@{*/
#define BP_DDRC_MSTR_BURST_RDWR (16U)      /*!< Bit position for DDRC_MSTR_BURST_RDWR. */
#define BM_DDRC_MSTR_BURST_RDWR (0x000F0000U) /*!< Bit mask for DDRC_MSTR_BURST_RDWR. */
#define BS_DDRC_MSTR_BURST_RDWR (4U)       /*!< Bit field size in bits for DDRC_MSTR_BURST_RDWR. */

/*! @brief Read current value of the DDRC_MSTR_BURST_RDWR field. */
#define BR_DDRC_MSTR_BURST_RDWR(x) (HW_DDRC_MSTR(x).B.BURST_RDWR)

/*! @brief Format value for bitfield DDRC_MSTR_BURST_RDWR. */
#define BF_DDRC_MSTR_BURST_RDWR(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MSTR_BURST_RDWR) & BM_DDRC_MSTR_BURST_RDWR)

/*! @brief Set the BURST_RDWR field to a new value. */
#define BW_DDRC_MSTR_BURST_RDWR(x, v) (HW_DDRC_MSTR_WR(x, (HW_DDRC_MSTR_RD(x) & ~BM_DDRC_MSTR_BURST_RDWR) | BF_DDRC_MSTR_BURST_RDWR(v)))
/*@}*/

/*!
 * @name Register DDRC_MSTR, field ACTIVE_RANKS[27:24] (RW)
 *
 * Only present for multi-rank configurations. Each bit represents one rank. For
 * two-rank configurations, only bits [25:24] are present. 1 - populated 0 -
 * unpopulated LSB is the lowest rank number. For 2 ranks following combinations are
 * legal: 01 - One rank 11 - Two ranks Others - Reserved. For 4 ranks following
 * combinations are legal: 0001 - One rank 0011 - Two ranks 1111 - Four ranks
 * Value After Reset: "(MEMC_NUM_RANKS == 4) ? 0xF :((MEMC_NUM_RANKS == 2) ? 0x3 :
 * 0x1)" Exists: MEMC_NUM_RANKS > 1
 */
/*@{*/
#define BP_DDRC_MSTR_ACTIVE_RANKS (24U)    /*!< Bit position for DDRC_MSTR_ACTIVE_RANKS. */
#define BM_DDRC_MSTR_ACTIVE_RANKS (0x0F000000U) /*!< Bit mask for DDRC_MSTR_ACTIVE_RANKS. */
#define BS_DDRC_MSTR_ACTIVE_RANKS (4U)     /*!< Bit field size in bits for DDRC_MSTR_ACTIVE_RANKS. */

/*! @brief Read current value of the DDRC_MSTR_ACTIVE_RANKS field. */
#define BR_DDRC_MSTR_ACTIVE_RANKS(x) (HW_DDRC_MSTR(x).B.ACTIVE_RANKS)

/*! @brief Format value for bitfield DDRC_MSTR_ACTIVE_RANKS. */
#define BF_DDRC_MSTR_ACTIVE_RANKS(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MSTR_ACTIVE_RANKS) & BM_DDRC_MSTR_ACTIVE_RANKS)

/*! @brief Set the ACTIVE_RANKS field to a new value. */
#define BW_DDRC_MSTR_ACTIVE_RANKS(x, v) (HW_DDRC_MSTR_WR(x, (HW_DDRC_MSTR_RD(x) & ~BM_DDRC_MSTR_ACTIVE_RANKS) | BF_DDRC_MSTR_ACTIVE_RANKS(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_STAT - Operating Mode Status Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_STAT - Operating Mode Status Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_stat
{
    uint32_t U;
    struct _hw_ddrc_stat_bitfields
    {
        uint32_t OPERATING_MODE : 3;   /*!< [2:0] Operating Mode */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SELFREF_TYPE : 2;     /*!< [5:4]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t SELFREF_STATE : 2;    /*!< [9:8] Self refresh state */
        uint32_t RESERVED2 : 22;       /*!< [31:10]  */
    } B;
} hw_ddrc_stat_t;

/*!
 * @name Constants and macros for entire DDRC_STAT register
 */
/*@{*/
#define HW_DDRC_STAT_ADDR(x)     ((uintptr_t)(x) + 0x4U)

#define HW_DDRC_STAT(x)          (*(__IO hw_ddrc_stat_t *) HW_DDRC_STAT_ADDR(x))
#define HW_DDRC_STAT_RD(x)       (HW_DDRC_STAT(x).U)
#define HW_DDRC_STAT_WR(x, v)    (HW_DDRC_STAT(x).U = (v))
#define HW_DDRC_STAT_SET(x, v)   (HW_DDRC_STAT_WR(x, HW_DDRC_STAT_RD(x) |  (v)))
#define HW_DDRC_STAT_CLR(x, v)   (HW_DDRC_STAT_WR(x, HW_DDRC_STAT_RD(x) & ~(v)))
#define HW_DDRC_STAT_TOG(x, v)   (HW_DDRC_STAT_WR(x, HW_DDRC_STAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_STAT bitfields
 */

/*!
 * @name Register DDRC_STAT, field OPERATING_MODE[2:0] (RW)
 *
 * This is 3-bits wide in configurations with mDDR / LPDDR2 / LPDDR3 support and
 * 2-bits in all other configurations.Non-mDDR / LPDDR2 / LPDDR3 and non-DDR4
 * designs: 00 - Init 01 - Normal 10 - Power-down 11 - Self-refresh mDDR / LPDDR2 /
 * LPDDR3 or DDR4 designs: 000 - Init 001 - Normal 010 - Power-down 011 -
 * Self-refresh 1XX - Deep power-down / Maximum Power Saving Mode Value After Reset:
 * 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_STAT_OPERATING_MODE (0U)   /*!< Bit position for DDRC_STAT_OPERATING_MODE. */
#define BM_DDRC_STAT_OPERATING_MODE (0x00000007U) /*!< Bit mask for DDRC_STAT_OPERATING_MODE. */
#define BS_DDRC_STAT_OPERATING_MODE (3U)   /*!< Bit field size in bits for DDRC_STAT_OPERATING_MODE. */

/*! @brief Read current value of the DDRC_STAT_OPERATING_MODE field. */
#define BR_DDRC_STAT_OPERATING_MODE(x) (HW_DDRC_STAT(x).B.OPERATING_MODE)

/*! @brief Format value for bitfield DDRC_STAT_OPERATING_MODE. */
#define BF_DDRC_STAT_OPERATING_MODE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_STAT_OPERATING_MODE) & BM_DDRC_STAT_OPERATING_MODE)

/*! @brief Set the OPERATING_MODE field to a new value. */
#define BW_DDRC_STAT_OPERATING_MODE(x, v) (HW_DDRC_STAT_WR(x, (HW_DDRC_STAT_RD(x) & ~BM_DDRC_STAT_OPERATING_MODE) | BF_DDRC_STAT_OPERATING_MODE(v)))
/*@}*/

/*!
 * @name Register DDRC_STAT, field SELFREF_TYPE[5:4] (RO)
 *
 * Flags if self-refresh is entered. If it is under automatic, it is
 * self-refresh control only or not. Value After Reset: 0x0 Exists: Always
 *
 * Values:
 * - 00 - SDRAM is not in self-refresh. If retry is enabled by
 *     CRCPARCTRL1.crc_parity_retry_enable, this also indicates SRE command is still in parity
 *     error window or retry is in-progress.
 * - 11 - SDRAM is in self-refresh and self-refresh is caused by automatic
 *     self-refresh only. If retry is enabled, this guarantees SRE command is executed
 *     correctly without parity error.
 * - 10 - SDRAM is in self-refresh and self-refresh is not caused solely under
 *     automatic self-refresh control. It could have been caused by Hardware Low
 *     Power Interface and/or Software (reg_ddrc_selfref_sw). If retry is enabled,
 *     this guarantees SRE command is executed correctly without parity error.
 */
/*@{*/
#define BP_DDRC_STAT_SELFREF_TYPE (4U)     /*!< Bit position for DDRC_STAT_SELFREF_TYPE. */
#define BM_DDRC_STAT_SELFREF_TYPE (0x00000030U) /*!< Bit mask for DDRC_STAT_SELFREF_TYPE. */
#define BS_DDRC_STAT_SELFREF_TYPE (2U)     /*!< Bit field size in bits for DDRC_STAT_SELFREF_TYPE. */

/*! @brief Read current value of the DDRC_STAT_SELFREF_TYPE field. */
#define BR_DDRC_STAT_SELFREF_TYPE(x) (HW_DDRC_STAT(x).B.SELFREF_TYPE)
/*@}*/

/*!
 * @name Register DDRC_STAT, field SELFREF_STATE[9:8] (RW)
 *
 * This indicates self refresh or self refresh power down state for LPDDR4. This
 * register is used for frequency change and MRR / MRW access during
 * self-refresh. Value After Reset:0x0 Exists: MEMC_LPDDR4==1
 *
 * Values:
 * - 00 - SDRAM is not in Self Refresh.
 * - 01 - Self refresh 1
 * - 10 - Self refresh power down
 * - 11 - Self refresh 2
 */
/*@{*/
#define BP_DDRC_STAT_SELFREF_STATE (8U)    /*!< Bit position for DDRC_STAT_SELFREF_STATE. */
#define BM_DDRC_STAT_SELFREF_STATE (0x00000300U) /*!< Bit mask for DDRC_STAT_SELFREF_STATE. */
#define BS_DDRC_STAT_SELFREF_STATE (2U)    /*!< Bit field size in bits for DDRC_STAT_SELFREF_STATE. */

/*! @brief Read current value of the DDRC_STAT_SELFREF_STATE field. */
#define BR_DDRC_STAT_SELFREF_STATE(x) (HW_DDRC_STAT(x).B.SELFREF_STATE)

/*! @brief Format value for bitfield DDRC_STAT_SELFREF_STATE. */
#define BF_DDRC_STAT_SELFREF_STATE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_STAT_SELFREF_STATE) & BM_DDRC_STAT_SELFREF_STATE)

/*! @brief Set the SELFREF_STATE field to a new value. */
#define BW_DDRC_STAT_SELFREF_STATE(x, v) (HW_DDRC_STAT_WR(x, (HW_DDRC_STAT_RD(x) & ~BM_DDRC_STAT_SELFREF_STATE) | BF_DDRC_STAT_SELFREF_STATE(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_MRCTRL0 - Mode Register Read / Write Control Register 0
 ******************************************************************************/

/*!
 * @brief HW_DDRC_MRCTRL0 - Mode Register Read / Write Control Register 0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Do not enable more than one of the following fields simultaneously:
 * RCD_INIT_EN PDA_EN MPR_EN
 */
typedef union _hw_ddrc_mrctrl0
{
    uint32_t U;
    struct _hw_ddrc_mrctrl0_bitfields
    {
        uint32_t MR_TYPE : 1;          /*!< [0]  */
        uint32_t RESERVED0 : 3;        /*!< [3:1]  */
        uint32_t MR_RANK : 4;          /*!< [7:4]  */
        uint32_t RESERVED1 : 4;        /*!< [11:8]  */
        uint32_t MR_ADDR : 4;          /*!< [15:12] Address of the mode register that
                                        * is to be written to */
        uint32_t RESERVED2 : 15;       /*!< [30:16]  */
        uint32_t MR_WR : 1;            /*!< [31]  */
    } B;
} hw_ddrc_mrctrl0_t;

/*!
 * @name Constants and macros for entire DDRC_MRCTRL0 register
 */
/*@{*/
#define HW_DDRC_MRCTRL0_ADDR(x)  ((uintptr_t)(x) + 0x10U)

#define HW_DDRC_MRCTRL0(x)       (*(__IO hw_ddrc_mrctrl0_t *) HW_DDRC_MRCTRL0_ADDR(x))
#define HW_DDRC_MRCTRL0_RD(x)    (HW_DDRC_MRCTRL0(x).U)
#define HW_DDRC_MRCTRL0_WR(x, v) (HW_DDRC_MRCTRL0(x).U = (v))
#define HW_DDRC_MRCTRL0_SET(x, v) (HW_DDRC_MRCTRL0_WR(x, HW_DDRC_MRCTRL0_RD(x) |  (v)))
#define HW_DDRC_MRCTRL0_CLR(x, v) (HW_DDRC_MRCTRL0_WR(x, HW_DDRC_MRCTRL0_RD(x) & ~(v)))
#define HW_DDRC_MRCTRL0_TOG(x, v) (HW_DDRC_MRCTRL0_WR(x, HW_DDRC_MRCTRL0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_MRCTRL0 bitfields
 */

/*!
 * @name Register DDRC_MRCTRL0, field MR_TYPE[0] (RW)
 *
 * Indicates whether the mode register operation is read or write. Only used for
 * LPDDR2 / LPDDR3. Value After Reset: 0x0 Exists: MEMC_LPDDR2 == 1
 *
 * Values:
 * - 0 - Write
 * - 1 - Read
 */
/*@{*/
#define BP_DDRC_MRCTRL0_MR_TYPE (0U)       /*!< Bit position for DDRC_MRCTRL0_MR_TYPE. */
#define BM_DDRC_MRCTRL0_MR_TYPE (0x00000001U) /*!< Bit mask for DDRC_MRCTRL0_MR_TYPE. */
#define BS_DDRC_MRCTRL0_MR_TYPE (1U)       /*!< Bit field size in bits for DDRC_MRCTRL0_MR_TYPE. */

/*! @brief Read current value of the DDRC_MRCTRL0_MR_TYPE field. */
#define BR_DDRC_MRCTRL0_MR_TYPE(x) (HW_DDRC_MRCTRL0(x).B.MR_TYPE)

/*! @brief Format value for bitfield DDRC_MRCTRL0_MR_TYPE. */
#define BF_DDRC_MRCTRL0_MR_TYPE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MRCTRL0_MR_TYPE) & BM_DDRC_MRCTRL0_MR_TYPE)

/*! @brief Set the MR_TYPE field to a new value. */
#define BW_DDRC_MRCTRL0_MR_TYPE(x, v) (HW_DDRC_MRCTRL0_WR(x, (HW_DDRC_MRCTRL0_RD(x) & ~BM_DDRC_MRCTRL0_MR_TYPE) | BF_DDRC_MRCTRL0_MR_TYPE(v)))
/*@}*/

/*!
 * @name Register DDRC_MRCTRL0, field MR_RANK[7:4] (RW)
 *
 * Controls which rank is accessed by MRCTRL0.mr_wr. Normally, it is desired to
 * access all ranks, so all bits should be set to 1. However, for multi-rank
 * UDIMMs / RDIMMs which implement address mirroring, it may be necessary to access
 * ranks individually. Examples (assume DDRC is configured for 4 ranks): 0x1 -
 * select rank 0 only 0x2 - select rank 1 only 0x5 - select ranks 0 and 2 0xA -
 * select ranks 1 and 3 0xF - select ranks 0, 1, 2 and 3 Value After Reset:
 * "(MEMC_NUM_RANKS == 4) ? 0xF :((MEMC_NUM_RANKS == 2) ? 0x3 : 0x1)" Exists: Always
 */
/*@{*/
#define BP_DDRC_MRCTRL0_MR_RANK (4U)       /*!< Bit position for DDRC_MRCTRL0_MR_RANK. */
#define BM_DDRC_MRCTRL0_MR_RANK (0x000000F0U) /*!< Bit mask for DDRC_MRCTRL0_MR_RANK. */
#define BS_DDRC_MRCTRL0_MR_RANK (4U)       /*!< Bit field size in bits for DDRC_MRCTRL0_MR_RANK. */

/*! @brief Read current value of the DDRC_MRCTRL0_MR_RANK field. */
#define BR_DDRC_MRCTRL0_MR_RANK(x) (HW_DDRC_MRCTRL0(x).B.MR_RANK)

/*! @brief Format value for bitfield DDRC_MRCTRL0_MR_RANK. */
#define BF_DDRC_MRCTRL0_MR_RANK(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MRCTRL0_MR_RANK) & BM_DDRC_MRCTRL0_MR_RANK)

/*! @brief Set the MR_RANK field to a new value. */
#define BW_DDRC_MRCTRL0_MR_RANK(x, v) (HW_DDRC_MRCTRL0_WR(x, (HW_DDRC_MRCTRL0_RD(x) & ~BM_DDRC_MRCTRL0_MR_RANK) | BF_DDRC_MRCTRL0_MR_RANK(v)))
/*@}*/

/*!
 * @name Register DDRC_MRCTRL0, field MR_ADDR[15:12] (RW)
 *
 * Do not Care for LPDDR2 / LPDDR3 (see MRCTRL1.mr_data formode register
 * addressing in LPDDR2 / LPDDR3).This signal is also used for writing to control words
 * of RDIMMs. In that case, it corresponds to the bank address bits sent to the
 * RDIMM Value After Reset: 0x0 Exists: Always
 *
 * Values:
 * - 0000 - MR0
 * - 0001 - MR1
 * - 0010 - MR2
 * - 0011 - MR3
 * - 0100 - MR4
 * - 0101 - MR5
 * - 0110 - MR6
 * - 0111 - MR7
 */
/*@{*/
#define BP_DDRC_MRCTRL0_MR_ADDR (12U)      /*!< Bit position for DDRC_MRCTRL0_MR_ADDR. */
#define BM_DDRC_MRCTRL0_MR_ADDR (0x0000F000U) /*!< Bit mask for DDRC_MRCTRL0_MR_ADDR. */
#define BS_DDRC_MRCTRL0_MR_ADDR (4U)       /*!< Bit field size in bits for DDRC_MRCTRL0_MR_ADDR. */

/*! @brief Read current value of the DDRC_MRCTRL0_MR_ADDR field. */
#define BR_DDRC_MRCTRL0_MR_ADDR(x) (HW_DDRC_MRCTRL0(x).B.MR_ADDR)

/*! @brief Format value for bitfield DDRC_MRCTRL0_MR_ADDR. */
#define BF_DDRC_MRCTRL0_MR_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MRCTRL0_MR_ADDR) & BM_DDRC_MRCTRL0_MR_ADDR)

/*! @brief Set the MR_ADDR field to a new value. */
#define BW_DDRC_MRCTRL0_MR_ADDR(x, v) (HW_DDRC_MRCTRL0_WR(x, (HW_DDRC_MRCTRL0_RD(x) & ~BM_DDRC_MRCTRL0_MR_ADDR) | BF_DDRC_MRCTRL0_MR_ADDR(v)))
/*@}*/

/*!
 * @name Register DDRC_MRCTRL0, field MR_WR[31] (RW)
 *
 * Setting this register bit to 1 triggers a mode register read or write
 * operation. When the MR operation is complete, the DDRC automatically clears this bit.
 * The other register fields of this register must be written in a separate APB
 * transaction, before setting this mr_wr bit. It is recommended NOT to set this
 * signal if in Init, Deep power-down or MPSM operating modes. Value After Reset:
 * 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_MRCTRL0_MR_WR (31U)        /*!< Bit position for DDRC_MRCTRL0_MR_WR. */
#define BM_DDRC_MRCTRL0_MR_WR (0x80000000U) /*!< Bit mask for DDRC_MRCTRL0_MR_WR. */
#define BS_DDRC_MRCTRL0_MR_WR (1U)         /*!< Bit field size in bits for DDRC_MRCTRL0_MR_WR. */

/*! @brief Read current value of the DDRC_MRCTRL0_MR_WR field. */
#define BR_DDRC_MRCTRL0_MR_WR(x) (HW_DDRC_MRCTRL0(x).B.MR_WR)

/*! @brief Format value for bitfield DDRC_MRCTRL0_MR_WR. */
#define BF_DDRC_MRCTRL0_MR_WR(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MRCTRL0_MR_WR) & BM_DDRC_MRCTRL0_MR_WR)

/*! @brief Set the MR_WR field to a new value. */
#define BW_DDRC_MRCTRL0_MR_WR(x, v) (HW_DDRC_MRCTRL0_WR(x, (HW_DDRC_MRCTRL0_RD(x) & ~BM_DDRC_MRCTRL0_MR_WR) | BF_DDRC_MRCTRL0_MR_WR(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_MRCTRL1 - Mode Register Read / Write Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_DDRC_MRCTRL1 - Mode Register Read / Write Control Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_mrctrl1
{
    uint32_t U;
    struct _hw_ddrc_mrctrl1_bitfields
    {
        uint32_t MR_DATA : 18;         /*!< [17:0]  */
        uint32_t RESERVED0 : 14;       /*!< [31:18]  */
    } B;
} hw_ddrc_mrctrl1_t;

/*!
 * @name Constants and macros for entire DDRC_MRCTRL1 register
 */
/*@{*/
#define HW_DDRC_MRCTRL1_ADDR(x)  ((uintptr_t)(x) + 0x14U)

#define HW_DDRC_MRCTRL1(x)       (*(__IO hw_ddrc_mrctrl1_t *) HW_DDRC_MRCTRL1_ADDR(x))
#define HW_DDRC_MRCTRL1_RD(x)    (HW_DDRC_MRCTRL1(x).U)
#define HW_DDRC_MRCTRL1_WR(x, v) (HW_DDRC_MRCTRL1(x).U = (v))
#define HW_DDRC_MRCTRL1_SET(x, v) (HW_DDRC_MRCTRL1_WR(x, HW_DDRC_MRCTRL1_RD(x) |  (v)))
#define HW_DDRC_MRCTRL1_CLR(x, v) (HW_DDRC_MRCTRL1_WR(x, HW_DDRC_MRCTRL1_RD(x) & ~(v)))
#define HW_DDRC_MRCTRL1_TOG(x, v) (HW_DDRC_MRCTRL1_WR(x, HW_DDRC_MRCTRL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_MRCTRL1 bitfields
 */

/*!
 * @name Register DDRC_MRCTRL1, field MR_DATA[17:0] (RW)
 *
 * Mode register write data for all non- LPDDR2 / non-LPDDR3 modes. For LPDDR2 /
 * LPDDR3, MRCTRL1 [15:0] are interpreted as [15:8] MR Address. [7:0] MR data
 * for writes, do not care for reads. This is 18-bit wide in configurations with
 * support and 16-bit in all other configurations. Value After Reset: 0x0 Exists:
 * Always
 */
/*@{*/
#define BP_DDRC_MRCTRL1_MR_DATA (0U)       /*!< Bit position for DDRC_MRCTRL1_MR_DATA. */
#define BM_DDRC_MRCTRL1_MR_DATA (0x0003FFFFU) /*!< Bit mask for DDRC_MRCTRL1_MR_DATA. */
#define BS_DDRC_MRCTRL1_MR_DATA (18U)      /*!< Bit field size in bits for DDRC_MRCTRL1_MR_DATA. */

/*! @brief Read current value of the DDRC_MRCTRL1_MR_DATA field. */
#define BR_DDRC_MRCTRL1_MR_DATA(x) (HW_DDRC_MRCTRL1(x).B.MR_DATA)

/*! @brief Format value for bitfield DDRC_MRCTRL1_MR_DATA. */
#define BF_DDRC_MRCTRL1_MR_DATA(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MRCTRL1_MR_DATA) & BM_DDRC_MRCTRL1_MR_DATA)

/*! @brief Set the MR_DATA field to a new value. */
#define BW_DDRC_MRCTRL1_MR_DATA(x, v) (HW_DDRC_MRCTRL1_WR(x, (HW_DDRC_MRCTRL1_RD(x) & ~BM_DDRC_MRCTRL1_MR_DATA) | BF_DDRC_MRCTRL1_MR_DATA(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_MRSTAT - Mode Register Read / Write Status Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_MRSTAT - Mode Register Read / Write Status Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_mrstat
{
    uint32_t U;
    struct _hw_ddrc_mrstat_bitfields
    {
        uint32_t MR_WR_BUSY : 1;       /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_ddrc_mrstat_t;

/*!
 * @name Constants and macros for entire DDRC_MRSTAT register
 */
/*@{*/
#define HW_DDRC_MRSTAT_ADDR(x)   ((uintptr_t)(x) + 0x18U)

#define HW_DDRC_MRSTAT(x)        (*(__I hw_ddrc_mrstat_t *) HW_DDRC_MRSTAT_ADDR(x))
#define HW_DDRC_MRSTAT_RD(x)     (HW_DDRC_MRSTAT(x).U)
/*@}*/

/*
 * Constants & macros for individual DDRC_MRSTAT bitfields
 */

/*!
 * @name Register DDRC_MRSTAT, field MR_WR_BUSY[0] (RO)
 *
 * The SoC core may initiate a MR write operation only if this signal is
 * low.This signal goes high in the clock after the DDRC accepts the MRW / MRR request.
 * It goes low when the MRW / MRR command is issued to the SDRAM. It is
 * recommended not to perform MRW / MRR commands when 'MRSTAT.mr_wr_busy' is high. Value
 * After Reset: 0x0 Exists: Always
 *
 * Values:
 * - 0 - Indicates that the SoC core can initiate a mode register write operation
 * - 1 - Indicates that mode register write operation is in progress
 */
/*@{*/
#define BP_DDRC_MRSTAT_MR_WR_BUSY (0U)     /*!< Bit position for DDRC_MRSTAT_MR_WR_BUSY. */
#define BM_DDRC_MRSTAT_MR_WR_BUSY (0x00000001U) /*!< Bit mask for DDRC_MRSTAT_MR_WR_BUSY. */
#define BS_DDRC_MRSTAT_MR_WR_BUSY (1U)     /*!< Bit field size in bits for DDRC_MRSTAT_MR_WR_BUSY. */

/*! @brief Read current value of the DDRC_MRSTAT_MR_WR_BUSY field. */
#define BR_DDRC_MRSTAT_MR_WR_BUSY(x) (HW_DDRC_MRSTAT(x).B.MR_WR_BUSY)
/*@}*/

/*******************************************************************************
 * HW_DDRC_DERATEEN - Temperature Derate Enable Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DERATEEN - Temperature Derate Enable Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: MEMC_LPDDR2==1
 */
typedef union _hw_ddrc_derateen
{
    uint32_t U;
    struct _hw_ddrc_derateen_bitfields
    {
        uint32_t DERATE_ENABLE : 1;    /*!< [0] Enable Derating */
        uint32_t DERATE_VALUE : 1;     /*!< [1] Derate Value */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t DERATE_BYTE : 4;      /*!< [7:4]  */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_ddrc_derateen_t;

/*!
 * @name Constants and macros for entire DDRC_DERATEEN register
 */
/*@{*/
#define HW_DDRC_DERATEEN_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_DDRC_DERATEEN(x)      (*(__IO hw_ddrc_derateen_t *) HW_DDRC_DERATEEN_ADDR(x))
#define HW_DDRC_DERATEEN_RD(x)   (HW_DDRC_DERATEEN(x).U)
#define HW_DDRC_DERATEEN_WR(x, v) (HW_DDRC_DERATEEN(x).U = (v))
#define HW_DDRC_DERATEEN_SET(x, v) (HW_DDRC_DERATEEN_WR(x, HW_DDRC_DERATEEN_RD(x) |  (v)))
#define HW_DDRC_DERATEEN_CLR(x, v) (HW_DDRC_DERATEEN_WR(x, HW_DDRC_DERATEEN_RD(x) & ~(v)))
#define HW_DDRC_DERATEEN_TOG(x, v) (HW_DDRC_DERATEEN_WR(x, HW_DDRC_DERATEEN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DERATEEN bitfields
 */

/*!
 * @name Register DDRC_DERATEEN, field DERATE_ENABLE[0] (RW)
 *
 * Present only in designs configured to support LPDDR2 / LPDDR3. This field
 * must be set to '0' for non-LPDDR2 / LPDDR3 mode. Value After Reset: 0x0 Exists:
 * MEMC_LPDDR2==1
 *
 * Values:
 * - 0 - Timing parameter derating is disabled
 * - 1 - Timing parameter derating is enabled using MR4 read value
 */
/*@{*/
#define BP_DDRC_DERATEEN_DERATE_ENABLE (0U) /*!< Bit position for DDRC_DERATEEN_DERATE_ENABLE. */
#define BM_DDRC_DERATEEN_DERATE_ENABLE (0x00000001U) /*!< Bit mask for DDRC_DERATEEN_DERATE_ENABLE. */
#define BS_DDRC_DERATEEN_DERATE_ENABLE (1U) /*!< Bit field size in bits for DDRC_DERATEEN_DERATE_ENABLE. */

/*! @brief Read current value of the DDRC_DERATEEN_DERATE_ENABLE field. */
#define BR_DDRC_DERATEEN_DERATE_ENABLE(x) (HW_DDRC_DERATEEN(x).B.DERATE_ENABLE)

/*! @brief Format value for bitfield DDRC_DERATEEN_DERATE_ENABLE. */
#define BF_DDRC_DERATEEN_DERATE_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DERATEEN_DERATE_ENABLE) & BM_DDRC_DERATEEN_DERATE_ENABLE)

/*! @brief Set the DERATE_ENABLE field to a new value. */
#define BW_DDRC_DERATEEN_DERATE_ENABLE(x, v) (HW_DDRC_DERATEEN_WR(x, (HW_DDRC_DERATEEN_RD(x) & ~BM_DDRC_DERATEEN_DERATE_ENABLE) | BF_DDRC_DERATEEN_DERATE_ENABLE(v)))
/*@}*/

/*!
 * @name Register DDRC_DERATEEN, field DERATE_VALUE[1] (RW)
 *
 * Present only in designs configured to support LPDDR2 or LPDDR3 Set to 0 for
 * all LPDDR2 speed grades as derating value of +1.875 ns is less than a
 * core_ddrc_core_clk period. It can be 0 or 1 for LPDDR3, depending if +1.875 ns is less
 * than a core_ddrc_core_clk period or not. Value After Reset: 0x0
 * Exists:MEMC_LPDDR2==1
 *
 * Values:
 * - 0 - Derating uses + 1
 * - 1 - Derating uses + 2
 */
/*@{*/
#define BP_DDRC_DERATEEN_DERATE_VALUE (1U) /*!< Bit position for DDRC_DERATEEN_DERATE_VALUE. */
#define BM_DDRC_DERATEEN_DERATE_VALUE (0x00000002U) /*!< Bit mask for DDRC_DERATEEN_DERATE_VALUE. */
#define BS_DDRC_DERATEEN_DERATE_VALUE (1U) /*!< Bit field size in bits for DDRC_DERATEEN_DERATE_VALUE. */

/*! @brief Read current value of the DDRC_DERATEEN_DERATE_VALUE field. */
#define BR_DDRC_DERATEEN_DERATE_VALUE(x) (HW_DDRC_DERATEEN(x).B.DERATE_VALUE)

/*! @brief Format value for bitfield DDRC_DERATEEN_DERATE_VALUE. */
#define BF_DDRC_DERATEEN_DERATE_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DERATEEN_DERATE_VALUE) & BM_DDRC_DERATEEN_DERATE_VALUE)

/*! @brief Set the DERATE_VALUE field to a new value. */
#define BW_DDRC_DERATEEN_DERATE_VALUE(x, v) (HW_DDRC_DERATEEN_WR(x, (HW_DDRC_DERATEEN_RD(x) & ~BM_DDRC_DERATEEN_DERATE_VALUE) | BF_DDRC_DERATEEN_DERATE_VALUE(v)))
/*@}*/

/*!
 * @name Register DDRC_DERATEEN, field DERATE_BYTE[7:4] (RW)
 *
 * Derate byte present only in designs configured to support LPDDR2 or LPDDR3
 * indicates which byte of the MRR data is used for derating. The maximum valid
 * value depends on MEMC_DRAM_TOTAL_DATA_WIDTH. Value After Reset: 0x0 Exists:
 * MEMC_LPDdR2==1
 */
/*@{*/
#define BP_DDRC_DERATEEN_DERATE_BYTE (4U)  /*!< Bit position for DDRC_DERATEEN_DERATE_BYTE. */
#define BM_DDRC_DERATEEN_DERATE_BYTE (0x000000F0U) /*!< Bit mask for DDRC_DERATEEN_DERATE_BYTE. */
#define BS_DDRC_DERATEEN_DERATE_BYTE (4U)  /*!< Bit field size in bits for DDRC_DERATEEN_DERATE_BYTE. */

/*! @brief Read current value of the DDRC_DERATEEN_DERATE_BYTE field. */
#define BR_DDRC_DERATEEN_DERATE_BYTE(x) (HW_DDRC_DERATEEN(x).B.DERATE_BYTE)

/*! @brief Format value for bitfield DDRC_DERATEEN_DERATE_BYTE. */
#define BF_DDRC_DERATEEN_DERATE_BYTE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DERATEEN_DERATE_BYTE) & BM_DDRC_DERATEEN_DERATE_BYTE)

/*! @brief Set the DERATE_BYTE field to a new value. */
#define BW_DDRC_DERATEEN_DERATE_BYTE(x, v) (HW_DDRC_DERATEEN_WR(x, (HW_DDRC_DERATEEN_RD(x) & ~BM_DDRC_DERATEEN_DERATE_BYTE) | BF_DDRC_DERATEEN_DERATE_BYTE(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DERATEINT - Temperature Derate Interval Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DERATEINT - Temperature Derate Interval Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: MEMC_LPDDR2==1
 */
typedef union _hw_ddrc_derateint
{
    uint32_t U;
    struct _hw_ddrc_derateint_bitfields
    {
        uint32_t MR4_READ_INTERVAL : 32; /*!< [31:0]  */
    } B;
} hw_ddrc_derateint_t;

/*!
 * @name Constants and macros for entire DDRC_DERATEINT register
 */
/*@{*/
#define HW_DDRC_DERATEINT_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_DDRC_DERATEINT(x)     (*(__IO hw_ddrc_derateint_t *) HW_DDRC_DERATEINT_ADDR(x))
#define HW_DDRC_DERATEINT_RD(x)  (HW_DDRC_DERATEINT(x).U)
#define HW_DDRC_DERATEINT_WR(x, v) (HW_DDRC_DERATEINT(x).U = (v))
#define HW_DDRC_DERATEINT_SET(x, v) (HW_DDRC_DERATEINT_WR(x, HW_DDRC_DERATEINT_RD(x) |  (v)))
#define HW_DDRC_DERATEINT_CLR(x, v) (HW_DDRC_DERATEINT_WR(x, HW_DDRC_DERATEINT_RD(x) & ~(v)))
#define HW_DDRC_DERATEINT_TOG(x, v) (HW_DDRC_DERATEINT_WR(x, HW_DDRC_DERATEINT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DERATEINT bitfields
 */

/*!
 * @name Register DDRC_DERATEINT, field MR4_READ_INTERVAL[31:0] (RW)
 *
 * Interval between two MR4 reads, used to derate the timing parameters. Present
 * only in designs configured to support LPDDR2 / LPDDR3. This register cannot
 * not be set to zero. Value After Reset: 0x800000 Exists: MEMC_LPDDR2 == 1
 */
/*@{*/
#define BP_DDRC_DERATEINT_MR4_READ_INTERVAL (0U) /*!< Bit position for DDRC_DERATEINT_MR4_READ_INTERVAL. */
#define BM_DDRC_DERATEINT_MR4_READ_INTERVAL (0xFFFFFFFFU) /*!< Bit mask for DDRC_DERATEINT_MR4_READ_INTERVAL. */
#define BS_DDRC_DERATEINT_MR4_READ_INTERVAL (32U) /*!< Bit field size in bits for DDRC_DERATEINT_MR4_READ_INTERVAL. */

/*! @brief Read current value of the DDRC_DERATEINT_MR4_READ_INTERVAL field. */
#define BR_DDRC_DERATEINT_MR4_READ_INTERVAL(x) (HW_DDRC_DERATEINT(x).U)

/*! @brief Format value for bitfield DDRC_DERATEINT_MR4_READ_INTERVAL. */
#define BF_DDRC_DERATEINT_MR4_READ_INTERVAL(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DERATEINT_MR4_READ_INTERVAL) & BM_DDRC_DERATEINT_MR4_READ_INTERVAL)

/*! @brief Set the MR4_READ_INTERVAL field to a new value. */
#define BW_DDRC_DERATEINT_MR4_READ_INTERVAL(x, v) (HW_DDRC_DERATEINT_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_DDRC_PWRCTL - Low Power Control Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_PWRCTL - Low Power Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_pwrctl
{
    uint32_t U;
    struct _hw_ddrc_pwrctl_bitfields
    {
        uint32_t SELFREF_EN : 1;       /*!< [0]  */
        uint32_t POWERDOWN_EN : 1;     /*!< [1]  */
        uint32_t DEEPPOWERDOWN_EN : 1; /*!< [2]  */
        uint32_t EN_DFI_DRAM_CLK_DISABLE : 1; /*!< [3]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t SELFREF_SW : 1;       /*!< [5]  */
        uint32_t RESERVED1 : 26;       /*!< [31:6]  */
    } B;
} hw_ddrc_pwrctl_t;

/*!
 * @name Constants and macros for entire DDRC_PWRCTL register
 */
/*@{*/
#define HW_DDRC_PWRCTL_ADDR(x)   ((uintptr_t)(x) + 0x30U)

#define HW_DDRC_PWRCTL(x)        (*(__IO hw_ddrc_pwrctl_t *) HW_DDRC_PWRCTL_ADDR(x))
#define HW_DDRC_PWRCTL_RD(x)     (HW_DDRC_PWRCTL(x).U)
#define HW_DDRC_PWRCTL_WR(x, v)  (HW_DDRC_PWRCTL(x).U = (v))
#define HW_DDRC_PWRCTL_SET(x, v) (HW_DDRC_PWRCTL_WR(x, HW_DDRC_PWRCTL_RD(x) |  (v)))
#define HW_DDRC_PWRCTL_CLR(x, v) (HW_DDRC_PWRCTL_WR(x, HW_DDRC_PWRCTL_RD(x) & ~(v)))
#define HW_DDRC_PWRCTL_TOG(x, v) (HW_DDRC_PWRCTL_WR(x, HW_DDRC_PWRCTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_PWRCTL bitfields
 */

/*!
 * @name Register DDRC_PWRCTL, field SELFREF_EN[0] (RW)
 *
 * If true then the DDRC puts the SDRAM into Self Refresh after a programmable
 * number of cycles "maximum idle clocks before Self Refresh
 * (PWRTMG.selfref_to_x32)". This register bit may be re-programmed during the course of normal
 * operation. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_PWRCTL_SELFREF_EN (0U)     /*!< Bit position for DDRC_PWRCTL_SELFREF_EN. */
#define BM_DDRC_PWRCTL_SELFREF_EN (0x00000001U) /*!< Bit mask for DDRC_PWRCTL_SELFREF_EN. */
#define BS_DDRC_PWRCTL_SELFREF_EN (1U)     /*!< Bit field size in bits for DDRC_PWRCTL_SELFREF_EN. */

/*! @brief Read current value of the DDRC_PWRCTL_SELFREF_EN field. */
#define BR_DDRC_PWRCTL_SELFREF_EN(x) (HW_DDRC_PWRCTL(x).B.SELFREF_EN)

/*! @brief Format value for bitfield DDRC_PWRCTL_SELFREF_EN. */
#define BF_DDRC_PWRCTL_SELFREF_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_PWRCTL_SELFREF_EN) & BM_DDRC_PWRCTL_SELFREF_EN)

/*! @brief Set the SELFREF_EN field to a new value. */
#define BW_DDRC_PWRCTL_SELFREF_EN(x, v) (HW_DDRC_PWRCTL_WR(x, (HW_DDRC_PWRCTL_RD(x) & ~BM_DDRC_PWRCTL_SELFREF_EN) | BF_DDRC_PWRCTL_SELFREF_EN(v)))
/*@}*/

/*!
 * @name Register DDRC_PWRCTL, field POWERDOWN_EN[1] (RW)
 *
 * If true then the DDRC goes into power-down after a programmable number of
 * cycles "maximum idle clocks before power down" (PWRTMG.powerdown_to_x32). This
 * register bit may be re-programmed during the course of normal operation. Value
 * After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_PWRCTL_POWERDOWN_EN (1U)   /*!< Bit position for DDRC_PWRCTL_POWERDOWN_EN. */
#define BM_DDRC_PWRCTL_POWERDOWN_EN (0x00000002U) /*!< Bit mask for DDRC_PWRCTL_POWERDOWN_EN. */
#define BS_DDRC_PWRCTL_POWERDOWN_EN (1U)   /*!< Bit field size in bits for DDRC_PWRCTL_POWERDOWN_EN. */

/*! @brief Read current value of the DDRC_PWRCTL_POWERDOWN_EN field. */
#define BR_DDRC_PWRCTL_POWERDOWN_EN(x) (HW_DDRC_PWRCTL(x).B.POWERDOWN_EN)

/*! @brief Format value for bitfield DDRC_PWRCTL_POWERDOWN_EN. */
#define BF_DDRC_PWRCTL_POWERDOWN_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_PWRCTL_POWERDOWN_EN) & BM_DDRC_PWRCTL_POWERDOWN_EN)

/*! @brief Set the POWERDOWN_EN field to a new value. */
#define BW_DDRC_PWRCTL_POWERDOWN_EN(x, v) (HW_DDRC_PWRCTL_WR(x, (HW_DDRC_PWRCTL_RD(x) & ~BM_DDRC_PWRCTL_POWERDOWN_EN) | BF_DDRC_PWRCTL_POWERDOWN_EN(v)))
/*@}*/

/*!
 * @name Register DDRC_PWRCTL, field DEEPPOWERDOWN_EN[2] (RW)
 *
 * When this is 1, DDRC puts the SDRAM into deep power-down mode when the
 * transaction store is empty. This register must be reset to '0' to bring DDRC out of
 * deep power-down mode. Controller performs automatic SDRAM initialization on
 * deep power-down exit. Present only in designs configured to support mDDR or
 * LPDDR2 or LPDDR3. FOR PERFORMANCE ONLY. Value After Reset: 0x0 Exists: MEMC_LPDDR2
 * == 1
 */
/*@{*/
#define BP_DDRC_PWRCTL_DEEPPOWERDOWN_EN (2U) /*!< Bit position for DDRC_PWRCTL_DEEPPOWERDOWN_EN. */
#define BM_DDRC_PWRCTL_DEEPPOWERDOWN_EN (0x00000004U) /*!< Bit mask for DDRC_PWRCTL_DEEPPOWERDOWN_EN. */
#define BS_DDRC_PWRCTL_DEEPPOWERDOWN_EN (1U) /*!< Bit field size in bits for DDRC_PWRCTL_DEEPPOWERDOWN_EN. */

/*! @brief Read current value of the DDRC_PWRCTL_DEEPPOWERDOWN_EN field. */
#define BR_DDRC_PWRCTL_DEEPPOWERDOWN_EN(x) (HW_DDRC_PWRCTL(x).B.DEEPPOWERDOWN_EN)

/*! @brief Format value for bitfield DDRC_PWRCTL_DEEPPOWERDOWN_EN. */
#define BF_DDRC_PWRCTL_DEEPPOWERDOWN_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_PWRCTL_DEEPPOWERDOWN_EN) & BM_DDRC_PWRCTL_DEEPPOWERDOWN_EN)

/*! @brief Set the DEEPPOWERDOWN_EN field to a new value. */
#define BW_DDRC_PWRCTL_DEEPPOWERDOWN_EN(x, v) (HW_DDRC_PWRCTL_WR(x, (HW_DDRC_PWRCTL_RD(x) & ~BM_DDRC_PWRCTL_DEEPPOWERDOWN_EN) | BF_DDRC_PWRCTL_DEEPPOWERDOWN_EN(v)))
/*@}*/

/*!
 * @name Register DDRC_PWRCTL, field EN_DFI_DRAM_CLK_DISABLE[3] (RW)
 *
 * Enable the assertion of dfi_dram_clk_disable whenever a clock is not required
 * by the SDRAM. If set to 0, dfi_dram_clk_disable is never asserted. Assertion
 * of dfi_dram_clk_disable is as follows: In DDR2 / DDR3, can only be asserted in
 * self-refresh. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_PWRCTL_EN_DFI_DRAM_CLK_DISABLE (3U) /*!< Bit position for DDRC_PWRCTL_EN_DFI_DRAM_CLK_DISABLE. */
#define BM_DDRC_PWRCTL_EN_DFI_DRAM_CLK_DISABLE (0x00000008U) /*!< Bit mask for DDRC_PWRCTL_EN_DFI_DRAM_CLK_DISABLE. */
#define BS_DDRC_PWRCTL_EN_DFI_DRAM_CLK_DISABLE (1U) /*!< Bit field size in bits for DDRC_PWRCTL_EN_DFI_DRAM_CLK_DISABLE. */

/*! @brief Read current value of the DDRC_PWRCTL_EN_DFI_DRAM_CLK_DISABLE field. */
#define BR_DDRC_PWRCTL_EN_DFI_DRAM_CLK_DISABLE(x) (HW_DDRC_PWRCTL(x).B.EN_DFI_DRAM_CLK_DISABLE)

/*! @brief Format value for bitfield DDRC_PWRCTL_EN_DFI_DRAM_CLK_DISABLE. */
#define BF_DDRC_PWRCTL_EN_DFI_DRAM_CLK_DISABLE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_PWRCTL_EN_DFI_DRAM_CLK_DISABLE) & BM_DDRC_PWRCTL_EN_DFI_DRAM_CLK_DISABLE)

/*! @brief Set the EN_DFI_DRAM_CLK_DISABLE field to a new value. */
#define BW_DDRC_PWRCTL_EN_DFI_DRAM_CLK_DISABLE(x, v) (HW_DDRC_PWRCTL_WR(x, (HW_DDRC_PWRCTL_RD(x) & ~BM_DDRC_PWRCTL_EN_DFI_DRAM_CLK_DISABLE) | BF_DDRC_PWRCTL_EN_DFI_DRAM_CLK_DISABLE(v)))
/*@}*/

/*!
 * @name Register DDRC_PWRCTL, field SELFREF_SW[5] (RW)
 *
 * A value 0 of 1 to this register causes system to move to self-refresh state
 * immediately, as long as it is not in INIT or DPD / MPSM operating_mode. This is
 * referred to as Software Entry / Exit to Self-refresh. Value After Reset: 0x0
 * Exists: Always
 *
 * Values:
 * - 1 - Software Entry to Self-refresh
 * - 0 - Software Exit from Self-refresh
 */
/*@{*/
#define BP_DDRC_PWRCTL_SELFREF_SW (5U)     /*!< Bit position for DDRC_PWRCTL_SELFREF_SW. */
#define BM_DDRC_PWRCTL_SELFREF_SW (0x00000020U) /*!< Bit mask for DDRC_PWRCTL_SELFREF_SW. */
#define BS_DDRC_PWRCTL_SELFREF_SW (1U)     /*!< Bit field size in bits for DDRC_PWRCTL_SELFREF_SW. */

/*! @brief Read current value of the DDRC_PWRCTL_SELFREF_SW field. */
#define BR_DDRC_PWRCTL_SELFREF_SW(x) (HW_DDRC_PWRCTL(x).B.SELFREF_SW)

/*! @brief Format value for bitfield DDRC_PWRCTL_SELFREF_SW. */
#define BF_DDRC_PWRCTL_SELFREF_SW(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_PWRCTL_SELFREF_SW) & BM_DDRC_PWRCTL_SELFREF_SW)

/*! @brief Set the SELFREF_SW field to a new value. */
#define BW_DDRC_PWRCTL_SELFREF_SW(x, v) (HW_DDRC_PWRCTL_WR(x, (HW_DDRC_PWRCTL_RD(x) & ~BM_DDRC_PWRCTL_SELFREF_SW) | BF_DDRC_PWRCTL_SELFREF_SW(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_PWRTMG - Low Power Timing Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_PWRTMG - Low Power Timing Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_pwrtmg
{
    uint32_t U;
    struct _hw_ddrc_pwrtmg_bitfields
    {
        uint32_t POWERDOWN_TO_X32 : 5; /*!< [4:0]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t T_DPD_X4096 : 8;      /*!< [15:8]  */
        uint32_t SELFREF_TO_X32 : 8;   /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_ddrc_pwrtmg_t;

/*!
 * @name Constants and macros for entire DDRC_PWRTMG register
 */
/*@{*/
#define HW_DDRC_PWRTMG_ADDR(x)   ((uintptr_t)(x) + 0x34U)

#define HW_DDRC_PWRTMG(x)        (*(__IO hw_ddrc_pwrtmg_t *) HW_DDRC_PWRTMG_ADDR(x))
#define HW_DDRC_PWRTMG_RD(x)     (HW_DDRC_PWRTMG(x).U)
#define HW_DDRC_PWRTMG_WR(x, v)  (HW_DDRC_PWRTMG(x).U = (v))
#define HW_DDRC_PWRTMG_SET(x, v) (HW_DDRC_PWRTMG_WR(x, HW_DDRC_PWRTMG_RD(x) |  (v)))
#define HW_DDRC_PWRTMG_CLR(x, v) (HW_DDRC_PWRTMG_WR(x, HW_DDRC_PWRTMG_RD(x) & ~(v)))
#define HW_DDRC_PWRTMG_TOG(x, v) (HW_DDRC_PWRTMG_WR(x, HW_DDRC_PWRTMG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_PWRTMG bitfields
 */

/*!
 * @name Register DDRC_PWRTMG, field POWERDOWN_TO_X32[4:0] (RW)
 *
 * After this many clocks of NOP or deselect the DDRC automatically puts the
 * SDRAM into power-down. This must be enabled in the PWRCTL.powerdown_en. Unit:
 * Multiples of 32 clocks FOR PERFORMANCE ONLY. Value After Reset: 0x10 Exists:
 * Always
 */
/*@{*/
#define BP_DDRC_PWRTMG_POWERDOWN_TO_X32 (0U) /*!< Bit position for DDRC_PWRTMG_POWERDOWN_TO_X32. */
#define BM_DDRC_PWRTMG_POWERDOWN_TO_X32 (0x0000001FU) /*!< Bit mask for DDRC_PWRTMG_POWERDOWN_TO_X32. */
#define BS_DDRC_PWRTMG_POWERDOWN_TO_X32 (5U) /*!< Bit field size in bits for DDRC_PWRTMG_POWERDOWN_TO_X32. */

/*! @brief Read current value of the DDRC_PWRTMG_POWERDOWN_TO_X32 field. */
#define BR_DDRC_PWRTMG_POWERDOWN_TO_X32(x) (HW_DDRC_PWRTMG(x).B.POWERDOWN_TO_X32)

/*! @brief Format value for bitfield DDRC_PWRTMG_POWERDOWN_TO_X32. */
#define BF_DDRC_PWRTMG_POWERDOWN_TO_X32(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_PWRTMG_POWERDOWN_TO_X32) & BM_DDRC_PWRTMG_POWERDOWN_TO_X32)

/*! @brief Set the POWERDOWN_TO_X32 field to a new value. */
#define BW_DDRC_PWRTMG_POWERDOWN_TO_X32(x, v) (HW_DDRC_PWRTMG_WR(x, (HW_DDRC_PWRTMG_RD(x) & ~BM_DDRC_PWRTMG_POWERDOWN_TO_X32) | BF_DDRC_PWRTMG_POWERDOWN_TO_X32(v)))
/*@}*/

/*!
 * @name Register DDRC_PWRTMG, field T_DPD_X4096[15:8] (RW)
 *
 * Minimum deep power-down timeFor mDDR, value from the JEDEC specification is 0
 * as mDDR exits from deep power-down mode immediately after
 * PWRCTL.deeppowerdown_en is de-asserted. For LPDDR2 / LPDDR3, value from the JEDEC specification
 * is 500 us. Unit: Multiples of 4096 clocks. Present only in designs configured
 * to support mDDR, LPDDR2 or LPDDR3. FOR PERFORMANCE ONLY. Value After Reset:
 * "(MEMC_MOBILE_OR_LPDDR2_EN) ? 0x20 : 0x0" Exists: MEMC_LPDDR2 == 1
 */
/*@{*/
#define BP_DDRC_PWRTMG_T_DPD_X4096 (8U)    /*!< Bit position for DDRC_PWRTMG_T_DPD_X4096. */
#define BM_DDRC_PWRTMG_T_DPD_X4096 (0x0000FF00U) /*!< Bit mask for DDRC_PWRTMG_T_DPD_X4096. */
#define BS_DDRC_PWRTMG_T_DPD_X4096 (8U)    /*!< Bit field size in bits for DDRC_PWRTMG_T_DPD_X4096. */

/*! @brief Read current value of the DDRC_PWRTMG_T_DPD_X4096 field. */
#define BR_DDRC_PWRTMG_T_DPD_X4096(x) (HW_DDRC_PWRTMG(x).B.T_DPD_X4096)

/*! @brief Format value for bitfield DDRC_PWRTMG_T_DPD_X4096. */
#define BF_DDRC_PWRTMG_T_DPD_X4096(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_PWRTMG_T_DPD_X4096) & BM_DDRC_PWRTMG_T_DPD_X4096)

/*! @brief Set the T_DPD_X4096 field to a new value. */
#define BW_DDRC_PWRTMG_T_DPD_X4096(x, v) (HW_DDRC_PWRTMG_WR(x, (HW_DDRC_PWRTMG_RD(x) & ~BM_DDRC_PWRTMG_T_DPD_X4096) | BF_DDRC_PWRTMG_T_DPD_X4096(v)))
/*@}*/

/*!
 * @name Register DDRC_PWRTMG, field SELFREF_TO_X32[23:16] (RW)
 *
 * After this many clocks of NOP or deselect the DDRC automatically puts the
 * SDRAM into Self Refresh. This must be enabled in the PWRCTL.selfref_en.Unit:
 * Multiples of 32 clocks. FOR PERFORMANCE ONLY. Value After Reset: 0x40 Exists:
 * Always
 */
/*@{*/
#define BP_DDRC_PWRTMG_SELFREF_TO_X32 (16U) /*!< Bit position for DDRC_PWRTMG_SELFREF_TO_X32. */
#define BM_DDRC_PWRTMG_SELFREF_TO_X32 (0x00FF0000U) /*!< Bit mask for DDRC_PWRTMG_SELFREF_TO_X32. */
#define BS_DDRC_PWRTMG_SELFREF_TO_X32 (8U) /*!< Bit field size in bits for DDRC_PWRTMG_SELFREF_TO_X32. */

/*! @brief Read current value of the DDRC_PWRTMG_SELFREF_TO_X32 field. */
#define BR_DDRC_PWRTMG_SELFREF_TO_X32(x) (HW_DDRC_PWRTMG(x).B.SELFREF_TO_X32)

/*! @brief Format value for bitfield DDRC_PWRTMG_SELFREF_TO_X32. */
#define BF_DDRC_PWRTMG_SELFREF_TO_X32(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_PWRTMG_SELFREF_TO_X32) & BM_DDRC_PWRTMG_SELFREF_TO_X32)

/*! @brief Set the SELFREF_TO_X32 field to a new value. */
#define BW_DDRC_PWRTMG_SELFREF_TO_X32(x, v) (HW_DDRC_PWRTMG_WR(x, (HW_DDRC_PWRTMG_RD(x) & ~BM_DDRC_PWRTMG_SELFREF_TO_X32) | BF_DDRC_PWRTMG_SELFREF_TO_X32(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_HWLPCTL - Hardware Low Power Control Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_HWLPCTL - Hardware Low Power Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_hwlpctl
{
    uint32_t U;
    struct _hw_ddrc_hwlpctl_bitfields
    {
        uint32_t HW_LP_EN : 1;         /*!< [0] Enable for Hardware Low Power
                                        * Interface */
        uint32_t HW_LP_EXIT_IDLE_EN : 1; /*!< [1]  */
        uint32_t RESERVED0 : 14;       /*!< [15:2]  */
        uint32_t HW_LP_IDLE_X32 : 12;  /*!< [27:16]  */
        uint32_t RESERVED1 : 4;        /*!< [31:28]  */
    } B;
} hw_ddrc_hwlpctl_t;

/*!
 * @name Constants and macros for entire DDRC_HWLPCTL register
 */
/*@{*/
#define HW_DDRC_HWLPCTL_ADDR(x)  ((uintptr_t)(x) + 0x38U)

#define HW_DDRC_HWLPCTL(x)       (*(__IO hw_ddrc_hwlpctl_t *) HW_DDRC_HWLPCTL_ADDR(x))
#define HW_DDRC_HWLPCTL_RD(x)    (HW_DDRC_HWLPCTL(x).U)
#define HW_DDRC_HWLPCTL_WR(x, v) (HW_DDRC_HWLPCTL(x).U = (v))
#define HW_DDRC_HWLPCTL_SET(x, v) (HW_DDRC_HWLPCTL_WR(x, HW_DDRC_HWLPCTL_RD(x) |  (v)))
#define HW_DDRC_HWLPCTL_CLR(x, v) (HW_DDRC_HWLPCTL_WR(x, HW_DDRC_HWLPCTL_RD(x) & ~(v)))
#define HW_DDRC_HWLPCTL_TOG(x, v) (HW_DDRC_HWLPCTL_WR(x, HW_DDRC_HWLPCTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_HWLPCTL bitfields
 */

/*!
 * @name Register DDRC_HWLPCTL, field HW_LP_EN[0] (RW)
 *
 * Value After Reset: 0x1 Exists: Always
 */
/*@{*/
#define BP_DDRC_HWLPCTL_HW_LP_EN (0U)      /*!< Bit position for DDRC_HWLPCTL_HW_LP_EN. */
#define BM_DDRC_HWLPCTL_HW_LP_EN (0x00000001U) /*!< Bit mask for DDRC_HWLPCTL_HW_LP_EN. */
#define BS_DDRC_HWLPCTL_HW_LP_EN (1U)      /*!< Bit field size in bits for DDRC_HWLPCTL_HW_LP_EN. */

/*! @brief Read current value of the DDRC_HWLPCTL_HW_LP_EN field. */
#define BR_DDRC_HWLPCTL_HW_LP_EN(x) (HW_DDRC_HWLPCTL(x).B.HW_LP_EN)

/*! @brief Format value for bitfield DDRC_HWLPCTL_HW_LP_EN. */
#define BF_DDRC_HWLPCTL_HW_LP_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_HWLPCTL_HW_LP_EN) & BM_DDRC_HWLPCTL_HW_LP_EN)

/*! @brief Set the HW_LP_EN field to a new value. */
#define BW_DDRC_HWLPCTL_HW_LP_EN(x, v) (HW_DDRC_HWLPCTL_WR(x, (HW_DDRC_HWLPCTL_RD(x) & ~BM_DDRC_HWLPCTL_HW_LP_EN) | BF_DDRC_HWLPCTL_HW_LP_EN(v)))
/*@}*/

/*!
 * @name Register DDRC_HWLPCTL, field HW_LP_EXIT_IDLE_EN[1] (RW)
 *
 * When this bit is programmed to 1 the cactive_in_ddrc pin of the DDRC can be
 * used to exit from the automatic clock stop, automatic power down or automatic
 * self-refreshmodes. It will not cause exit of Self-Refresh that is caused by
 * Hardware Low Power Interface and / or Software (PWRCTL.selfref_sw). Value After
 * Reset: 0x1 Exists: Always
 */
/*@{*/
#define BP_DDRC_HWLPCTL_HW_LP_EXIT_IDLE_EN (1U) /*!< Bit position for DDRC_HWLPCTL_HW_LP_EXIT_IDLE_EN. */
#define BM_DDRC_HWLPCTL_HW_LP_EXIT_IDLE_EN (0x00000002U) /*!< Bit mask for DDRC_HWLPCTL_HW_LP_EXIT_IDLE_EN. */
#define BS_DDRC_HWLPCTL_HW_LP_EXIT_IDLE_EN (1U) /*!< Bit field size in bits for DDRC_HWLPCTL_HW_LP_EXIT_IDLE_EN. */

/*! @brief Read current value of the DDRC_HWLPCTL_HW_LP_EXIT_IDLE_EN field. */
#define BR_DDRC_HWLPCTL_HW_LP_EXIT_IDLE_EN(x) (HW_DDRC_HWLPCTL(x).B.HW_LP_EXIT_IDLE_EN)

/*! @brief Format value for bitfield DDRC_HWLPCTL_HW_LP_EXIT_IDLE_EN. */
#define BF_DDRC_HWLPCTL_HW_LP_EXIT_IDLE_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_HWLPCTL_HW_LP_EXIT_IDLE_EN) & BM_DDRC_HWLPCTL_HW_LP_EXIT_IDLE_EN)

/*! @brief Set the HW_LP_EXIT_IDLE_EN field to a new value. */
#define BW_DDRC_HWLPCTL_HW_LP_EXIT_IDLE_EN(x, v) (HW_DDRC_HWLPCTL_WR(x, (HW_DDRC_HWLPCTL_RD(x) & ~BM_DDRC_HWLPCTL_HW_LP_EXIT_IDLE_EN) | BF_DDRC_HWLPCTL_HW_LP_EXIT_IDLE_EN(v)))
/*@}*/

/*!
 * @name Register DDRC_HWLPCTL, field HW_LP_IDLE_X32[27:16] (RW)
 *
 * Hardware idle period. The cactive_ddrc output is driven low if the system is
 * idle for hw_lp_idle * 32 cycles if not in INIT or DPD / MPSM operating_mode.
 * The hardware idle function is disabled when hw_lp_idle_x32 = 0. Unit: Multiples
 * of 32 clocks. FOR PERFORMANCE ONLY. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_HWLPCTL_HW_LP_IDLE_X32 (16U) /*!< Bit position for DDRC_HWLPCTL_HW_LP_IDLE_X32. */
#define BM_DDRC_HWLPCTL_HW_LP_IDLE_X32 (0x0FFF0000U) /*!< Bit mask for DDRC_HWLPCTL_HW_LP_IDLE_X32. */
#define BS_DDRC_HWLPCTL_HW_LP_IDLE_X32 (12U) /*!< Bit field size in bits for DDRC_HWLPCTL_HW_LP_IDLE_X32. */

/*! @brief Read current value of the DDRC_HWLPCTL_HW_LP_IDLE_X32 field. */
#define BR_DDRC_HWLPCTL_HW_LP_IDLE_X32(x) (HW_DDRC_HWLPCTL(x).B.HW_LP_IDLE_X32)

/*! @brief Format value for bitfield DDRC_HWLPCTL_HW_LP_IDLE_X32. */
#define BF_DDRC_HWLPCTL_HW_LP_IDLE_X32(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_HWLPCTL_HW_LP_IDLE_X32) & BM_DDRC_HWLPCTL_HW_LP_IDLE_X32)

/*! @brief Set the HW_LP_IDLE_X32 field to a new value. */
#define BW_DDRC_HWLPCTL_HW_LP_IDLE_X32(x, v) (HW_DDRC_HWLPCTL_WR(x, (HW_DDRC_HWLPCTL_RD(x) & ~BM_DDRC_HWLPCTL_HW_LP_IDLE_X32) | BF_DDRC_HWLPCTL_HW_LP_IDLE_X32(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_RFSHCTL0 - Refresh Control Register 0
 ******************************************************************************/

/*!
 * @brief HW_DDRC_RFSHCTL0 - Refresh Control Register 0 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_rfshctl0
{
    uint32_t U;
    struct _hw_ddrc_rfshctl0_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t PER_BANK_REFRESH : 1; /*!< [2]  */
        uint32_t RESERVED1 : 1;        /*!< [3]  */
        uint32_t REFRESH_BURST : 5;    /*!< [8:4]  */
        uint32_t RESERVED2 : 3;        /*!< [11:9]  */
        uint32_t REFRESH_TO_X32 : 5;   /*!< [16:12]  */
        uint32_t RESERVED3 : 3;        /*!< [19:17]  */
        uint32_t REFRESH_MARGIN : 4;   /*!< [23:20]  */
        uint32_t RESERVED4 : 8;        /*!< [31:24]  */
    } B;
} hw_ddrc_rfshctl0_t;

/*!
 * @name Constants and macros for entire DDRC_RFSHCTL0 register
 */
/*@{*/
#define HW_DDRC_RFSHCTL0_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_DDRC_RFSHCTL0(x)      (*(__IO hw_ddrc_rfshctl0_t *) HW_DDRC_RFSHCTL0_ADDR(x))
#define HW_DDRC_RFSHCTL0_RD(x)   (HW_DDRC_RFSHCTL0(x).U)
#define HW_DDRC_RFSHCTL0_WR(x, v) (HW_DDRC_RFSHCTL0(x).U = (v))
#define HW_DDRC_RFSHCTL0_SET(x, v) (HW_DDRC_RFSHCTL0_WR(x, HW_DDRC_RFSHCTL0_RD(x) |  (v)))
#define HW_DDRC_RFSHCTL0_CLR(x, v) (HW_DDRC_RFSHCTL0_WR(x, HW_DDRC_RFSHCTL0_RD(x) & ~(v)))
#define HW_DDRC_RFSHCTL0_TOG(x, v) (HW_DDRC_RFSHCTL0_WR(x, HW_DDRC_RFSHCTL0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_RFSHCTL0 bitfields
 */

/*!
 * @name Register DDRC_RFSHCTL0, field PER_BANK_REFRESH[2] (RW)
 *
 * Per bank refresh allows traffic to flow to other banks. Per bank refresh is
 * not supported by all LPDDR2 devices but should be supported by all LPDDR3
 * devices. Present only in designs configured to support LPDDR2 / LPDDR3. Value After
 * Reset: 0x0 Exists: MEMC_LPDDR2 == 1
 *
 * Values:
 * - 1 - Per bank refresh
 * - 0 - All bank refresh
 */
/*@{*/
#define BP_DDRC_RFSHCTL0_PER_BANK_REFRESH (2U) /*!< Bit position for DDRC_RFSHCTL0_PER_BANK_REFRESH. */
#define BM_DDRC_RFSHCTL0_PER_BANK_REFRESH (0x00000004U) /*!< Bit mask for DDRC_RFSHCTL0_PER_BANK_REFRESH. */
#define BS_DDRC_RFSHCTL0_PER_BANK_REFRESH (1U) /*!< Bit field size in bits for DDRC_RFSHCTL0_PER_BANK_REFRESH. */

/*! @brief Read current value of the DDRC_RFSHCTL0_PER_BANK_REFRESH field. */
#define BR_DDRC_RFSHCTL0_PER_BANK_REFRESH(x) (HW_DDRC_RFSHCTL0(x).B.PER_BANK_REFRESH)

/*! @brief Format value for bitfield DDRC_RFSHCTL0_PER_BANK_REFRESH. */
#define BF_DDRC_RFSHCTL0_PER_BANK_REFRESH(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_RFSHCTL0_PER_BANK_REFRESH) & BM_DDRC_RFSHCTL0_PER_BANK_REFRESH)

/*! @brief Set the PER_BANK_REFRESH field to a new value. */
#define BW_DDRC_RFSHCTL0_PER_BANK_REFRESH(x, v) (HW_DDRC_RFSHCTL0_WR(x, (HW_DDRC_RFSHCTL0_RD(x) & ~BM_DDRC_RFSHCTL0_PER_BANK_REFRESH) | BF_DDRC_RFSHCTL0_PER_BANK_REFRESH(v)))
/*@}*/

/*!
 * @name Register DDRC_RFSHCTL0, field REFRESH_BURST[8:4] (RW)
 *
 * The programmed value + 1 is the number of refresh timeouts that is allowed to
 * accumulate before traffic is blocked and the refreshes are forced to execute.
 * Closing pages to perform a refresh is a one-time penalty that must be paid
 * for each group of refreshes. Therefore, performing refreshes in a burst reduces
 * the per-refresh penalty of these page closings. Higher numbers for
 * RFSHCTL.refresh_burst slightly increases utilization; lower numbers decreases the
 * worst-case latency associated with refreshes. For information on burst refresh
 * feature refer to section 3.9 of DDR2 JEDEC specification - JESD79-2F.pdf. For DDR2 /
 * DDR3, the refresh is always per-rank and not per-bank. The rank refresh can
 * be accumulated over 8 * tREFI cycles using the burst refresh feature. Value
 * After Reset: 0x0 Exists: Always
 *
 * Values:
 * - 0 - Single refresh
 * - 1 - Burst-of-2 refresh
 */
/*@{*/
#define BP_DDRC_RFSHCTL0_REFRESH_BURST (4U) /*!< Bit position for DDRC_RFSHCTL0_REFRESH_BURST. */
#define BM_DDRC_RFSHCTL0_REFRESH_BURST (0x000001F0U) /*!< Bit mask for DDRC_RFSHCTL0_REFRESH_BURST. */
#define BS_DDRC_RFSHCTL0_REFRESH_BURST (5U) /*!< Bit field size in bits for DDRC_RFSHCTL0_REFRESH_BURST. */

/*! @brief Read current value of the DDRC_RFSHCTL0_REFRESH_BURST field. */
#define BR_DDRC_RFSHCTL0_REFRESH_BURST(x) (HW_DDRC_RFSHCTL0(x).B.REFRESH_BURST)

/*! @brief Format value for bitfield DDRC_RFSHCTL0_REFRESH_BURST. */
#define BF_DDRC_RFSHCTL0_REFRESH_BURST(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_RFSHCTL0_REFRESH_BURST) & BM_DDRC_RFSHCTL0_REFRESH_BURST)

/*! @brief Set the REFRESH_BURST field to a new value. */
#define BW_DDRC_RFSHCTL0_REFRESH_BURST(x, v) (HW_DDRC_RFSHCTL0_WR(x, (HW_DDRC_RFSHCTL0_RD(x) & ~BM_DDRC_RFSHCTL0_REFRESH_BURST) | BF_DDRC_RFSHCTL0_REFRESH_BURST(v)))
/*@}*/

/*!
 * @name Register DDRC_RFSHCTL0, field REFRESH_TO_X32[16:12] (RW)
 *
 * If the refresh timer (tRFCnom, also known as tREFI) has expired at least
 * once, but it has not expired (RFSHCTL0.refresh_burst + 1) times yet, then a
 * speculative refresh may be performed. A speculative refresh is a refresh performed
 * at a time when refresh would be useful, but before it is absolutely required.
 * When the SDRAM bus is idle for a period of time determined by
 * thisRFSHCTL0.refresh_to_x32 and the refresh timer has expired at least once since the last
 * refresh, then a speculative refresh is performed. Speculative refreshes continues
 * successively until there are no refreshes pending or until new reads or writes
 * are issued to the DDRC. FOR PERFORMANCE ONLY. Value After Reset: 0x10 Exists:
 * Always
 */
/*@{*/
#define BP_DDRC_RFSHCTL0_REFRESH_TO_X32 (12U) /*!< Bit position for DDRC_RFSHCTL0_REFRESH_TO_X32. */
#define BM_DDRC_RFSHCTL0_REFRESH_TO_X32 (0x0001F000U) /*!< Bit mask for DDRC_RFSHCTL0_REFRESH_TO_X32. */
#define BS_DDRC_RFSHCTL0_REFRESH_TO_X32 (5U) /*!< Bit field size in bits for DDRC_RFSHCTL0_REFRESH_TO_X32. */

/*! @brief Read current value of the DDRC_RFSHCTL0_REFRESH_TO_X32 field. */
#define BR_DDRC_RFSHCTL0_REFRESH_TO_X32(x) (HW_DDRC_RFSHCTL0(x).B.REFRESH_TO_X32)

/*! @brief Format value for bitfield DDRC_RFSHCTL0_REFRESH_TO_X32. */
#define BF_DDRC_RFSHCTL0_REFRESH_TO_X32(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_RFSHCTL0_REFRESH_TO_X32) & BM_DDRC_RFSHCTL0_REFRESH_TO_X32)

/*! @brief Set the REFRESH_TO_X32 field to a new value. */
#define BW_DDRC_RFSHCTL0_REFRESH_TO_X32(x, v) (HW_DDRC_RFSHCTL0_WR(x, (HW_DDRC_RFSHCTL0_RD(x) & ~BM_DDRC_RFSHCTL0_REFRESH_TO_X32) | BF_DDRC_RFSHCTL0_REFRESH_TO_X32(v)))
/*@}*/

/*!
 * @name Register DDRC_RFSHCTL0, field REFRESH_MARGIN[23:20] (RW)
 *
 * Threshold value in number of clock cycles before the critical refresh or page
 * timer expires. A critical refresh is to be issued before this threshold is
 * reached. It is recommended that this not be changed from the default value,
 * currently shown as 0x2. It must always be less than internally used t_rfc_nom_x32.
 * Note that, in LPDDR2 / LPDDR3, internally used t_rfc_nom_x32 may be equal to
 * RFSHTMG.t_rfc_nom_x32 >> 2 if derating is enabled (DERATEEN.derate_enable =
 * 1). Otherwise, internally used t_rfc_nom_x32 will be equal to
 * RFSHTMG.t_rfc_nom_x32. Unit: Multiples of 32 clocks. Value After Reset: 0x2 Exists: Always
 */
/*@{*/
#define BP_DDRC_RFSHCTL0_REFRESH_MARGIN (20U) /*!< Bit position for DDRC_RFSHCTL0_REFRESH_MARGIN. */
#define BM_DDRC_RFSHCTL0_REFRESH_MARGIN (0x00F00000U) /*!< Bit mask for DDRC_RFSHCTL0_REFRESH_MARGIN. */
#define BS_DDRC_RFSHCTL0_REFRESH_MARGIN (4U) /*!< Bit field size in bits for DDRC_RFSHCTL0_REFRESH_MARGIN. */

/*! @brief Read current value of the DDRC_RFSHCTL0_REFRESH_MARGIN field. */
#define BR_DDRC_RFSHCTL0_REFRESH_MARGIN(x) (HW_DDRC_RFSHCTL0(x).B.REFRESH_MARGIN)

/*! @brief Format value for bitfield DDRC_RFSHCTL0_REFRESH_MARGIN. */
#define BF_DDRC_RFSHCTL0_REFRESH_MARGIN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_RFSHCTL0_REFRESH_MARGIN) & BM_DDRC_RFSHCTL0_REFRESH_MARGIN)

/*! @brief Set the REFRESH_MARGIN field to a new value. */
#define BW_DDRC_RFSHCTL0_REFRESH_MARGIN(x, v) (HW_DDRC_RFSHCTL0_WR(x, (HW_DDRC_RFSHCTL0_RD(x) & ~BM_DDRC_RFSHCTL0_REFRESH_MARGIN) | BF_DDRC_RFSHCTL0_REFRESH_MARGIN(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_RFSHCTL1 - Refresh Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_DDRC_RFSHCTL1 - Refresh Control Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: MEMC_NUM_RANKS > 1
 */
typedef union _hw_ddrc_rfshctl1
{
    uint32_t U;
    struct _hw_ddrc_rfshctl1_bitfields
    {
        uint32_t REFRESH_TIMER0_START_VALUE_X32 : 12; /*!< [11:0]  */
        uint32_t RESERVED0 : 4;        /*!< [15:12]  */
        uint32_t REFRESH_TIMER1_START_VALUE_X32 : 12; /*!< [27:16]  */
        uint32_t RESERVED1 : 4;        /*!< [31:28]  */
    } B;
} hw_ddrc_rfshctl1_t;

/*!
 * @name Constants and macros for entire DDRC_RFSHCTL1 register
 */
/*@{*/
#define HW_DDRC_RFSHCTL1_ADDR(x) ((uintptr_t)(x) + 0x54U)

#define HW_DDRC_RFSHCTL1(x)      (*(__IO hw_ddrc_rfshctl1_t *) HW_DDRC_RFSHCTL1_ADDR(x))
#define HW_DDRC_RFSHCTL1_RD(x)   (HW_DDRC_RFSHCTL1(x).U)
#define HW_DDRC_RFSHCTL1_WR(x, v) (HW_DDRC_RFSHCTL1(x).U = (v))
#define HW_DDRC_RFSHCTL1_SET(x, v) (HW_DDRC_RFSHCTL1_WR(x, HW_DDRC_RFSHCTL1_RD(x) |  (v)))
#define HW_DDRC_RFSHCTL1_CLR(x, v) (HW_DDRC_RFSHCTL1_WR(x, HW_DDRC_RFSHCTL1_RD(x) & ~(v)))
#define HW_DDRC_RFSHCTL1_TOG(x, v) (HW_DDRC_RFSHCTL1_WR(x, HW_DDRC_RFSHCTL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_RFSHCTL1 bitfields
 */

/*!
 * @name Register DDRC_RFSHCTL1, field REFRESH_TIMER0_START_VALUE_X32[11:0] (RW)
 *
 * Refresh timer start for rank 0 (only present in multi-rank configurations).
 * This is useful in staggering the refreshes to multiple ranks to help traffic to
 * proceed. This is explained in Refresh Controls section of architecture
 * chapter. Unit: Multiples of 32 clocks. FOR PERFORMANCE ONLY. Value After Reset: 0x0
 * Exists: MEMC_NUM_RANKS > 1
 */
/*@{*/
#define BP_DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32 (0U) /*!< Bit position for DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32. */
#define BM_DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32 (0x00000FFFU) /*!< Bit mask for DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32. */
#define BS_DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32 (12U) /*!< Bit field size in bits for DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32. */

/*! @brief Read current value of the DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32 field. */
#define BR_DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32(x) (HW_DDRC_RFSHCTL1(x).B.REFRESH_TIMER0_START_VALUE_X32)

/*! @brief Format value for bitfield DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32. */
#define BF_DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32) & BM_DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32)

/*! @brief Set the REFRESH_TIMER0_START_VALUE_X32 field to a new value. */
#define BW_DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32(x, v) (HW_DDRC_RFSHCTL1_WR(x, (HW_DDRC_RFSHCTL1_RD(x) & ~BM_DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32) | BF_DDRC_RFSHCTL1_REFRESH_TIMER0_START_VALUE_X32(v)))
/*@}*/

/*!
 * @name Register DDRC_RFSHCTL1, field REFRESH_TIMER1_START_VALUE_X32[27:16] (RW)
 *
 * Refresh timer start for rank 1 (only present in multi-rank configurations).
 * This is useful in staggering the refreshes to multiple ranks to help traffic to
 * proceed. This is explained in Refresh Controls section of architecture
 * chapter. Unit: Multiples of 32 clocks. FOR PERFORMANCE ONLY. Value After Reset: 0x0
 * Exists: MEMC_NUM_RANKS > 1
 */
/*@{*/
#define BP_DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32 (16U) /*!< Bit position for DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32. */
#define BM_DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32 (0x0FFF0000U) /*!< Bit mask for DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32. */
#define BS_DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32 (12U) /*!< Bit field size in bits for DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32. */

/*! @brief Read current value of the DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32 field. */
#define BR_DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32(x) (HW_DDRC_RFSHCTL1(x).B.REFRESH_TIMER1_START_VALUE_X32)

/*! @brief Format value for bitfield DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32. */
#define BF_DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32) & BM_DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32)

/*! @brief Set the REFRESH_TIMER1_START_VALUE_X32 field to a new value. */
#define BW_DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32(x, v) (HW_DDRC_RFSHCTL1_WR(x, (HW_DDRC_RFSHCTL1_RD(x) & ~BM_DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32) | BF_DDRC_RFSHCTL1_REFRESH_TIMER1_START_VALUE_X32(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_RFSHCTL3 - Refresh Control Register 0
 ******************************************************************************/

/*!
 * @brief HW_DDRC_RFSHCTL3 - Refresh Control Register 0 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_rfshctl3
{
    uint32_t U;
    struct _hw_ddrc_rfshctl3_bitfields
    {
        uint32_t DIS_AUTO_REFRESH : 1; /*!< [0]  */
        uint32_t REFRESH_UPDATE_LEVEL : 1; /*!< [1]  */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_ddrc_rfshctl3_t;

/*!
 * @name Constants and macros for entire DDRC_RFSHCTL3 register
 */
/*@{*/
#define HW_DDRC_RFSHCTL3_ADDR(x) ((uintptr_t)(x) + 0x60U)

#define HW_DDRC_RFSHCTL3(x)      (*(__IO hw_ddrc_rfshctl3_t *) HW_DDRC_RFSHCTL3_ADDR(x))
#define HW_DDRC_RFSHCTL3_RD(x)   (HW_DDRC_RFSHCTL3(x).U)
#define HW_DDRC_RFSHCTL3_WR(x, v) (HW_DDRC_RFSHCTL3(x).U = (v))
#define HW_DDRC_RFSHCTL3_SET(x, v) (HW_DDRC_RFSHCTL3_WR(x, HW_DDRC_RFSHCTL3_RD(x) |  (v)))
#define HW_DDRC_RFSHCTL3_CLR(x, v) (HW_DDRC_RFSHCTL3_WR(x, HW_DDRC_RFSHCTL3_RD(x) & ~(v)))
#define HW_DDRC_RFSHCTL3_TOG(x, v) (HW_DDRC_RFSHCTL3_WR(x, HW_DDRC_RFSHCTL3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_RFSHCTL3 bitfields
 */

/*!
 * @name Register DDRC_RFSHCTL3, field DIS_AUTO_REFRESH[0] (RW)
 *
 * When '1', disable auto-refresh generated by the DDRC.When auto-refresh is
 * disabled, the SoC core must generate refreshes using the registers
 * reg_ddrc_rank0_refresh, reg_ddrc_rank1_refresh, reg_ddrc_rank2_refresh and
 * reg_ddrc_rank3_refresh. When dis_auto_refresh transitions from 0 to 1, any pending refreshes
 * are immediately scheduled by the DDRC. If DDR4 CRC / parity retry is enabled
 * (CRCPARCTL1.crc_parity_retry_enable = 1), disable auto- refresh is not supported,
 * and this bit must be set to '0'. This register field is changeable on the
 * fly. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_RFSHCTL3_DIS_AUTO_REFRESH (0U) /*!< Bit position for DDRC_RFSHCTL3_DIS_AUTO_REFRESH. */
#define BM_DDRC_RFSHCTL3_DIS_AUTO_REFRESH (0x00000001U) /*!< Bit mask for DDRC_RFSHCTL3_DIS_AUTO_REFRESH. */
#define BS_DDRC_RFSHCTL3_DIS_AUTO_REFRESH (1U) /*!< Bit field size in bits for DDRC_RFSHCTL3_DIS_AUTO_REFRESH. */

/*! @brief Read current value of the DDRC_RFSHCTL3_DIS_AUTO_REFRESH field. */
#define BR_DDRC_RFSHCTL3_DIS_AUTO_REFRESH(x) (HW_DDRC_RFSHCTL3(x).B.DIS_AUTO_REFRESH)

/*! @brief Format value for bitfield DDRC_RFSHCTL3_DIS_AUTO_REFRESH. */
#define BF_DDRC_RFSHCTL3_DIS_AUTO_REFRESH(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_RFSHCTL3_DIS_AUTO_REFRESH) & BM_DDRC_RFSHCTL3_DIS_AUTO_REFRESH)

/*! @brief Set the DIS_AUTO_REFRESH field to a new value. */
#define BW_DDRC_RFSHCTL3_DIS_AUTO_REFRESH(x, v) (HW_DDRC_RFSHCTL3_WR(x, (HW_DDRC_RFSHCTL3_RD(x) & ~BM_DDRC_RFSHCTL3_DIS_AUTO_REFRESH) | BF_DDRC_RFSHCTL3_DIS_AUTO_REFRESH(v)))
/*@}*/

/*!
 * @name Register DDRC_RFSHCTL3, field REFRESH_UPDATE_LEVEL[1] (RW)
 *
 * Toggle this signal (either from 0 to 1 or from 1 to 0) to indicate that the
 * refresh register(s) have been updated. The value is automatically updated when
 * exiting reset, so it does not need to be toggled initially. Value After Reset:
 * 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_RFSHCTL3_REFRESH_UPDATE_LEVEL (1U) /*!< Bit position for DDRC_RFSHCTL3_REFRESH_UPDATE_LEVEL. */
#define BM_DDRC_RFSHCTL3_REFRESH_UPDATE_LEVEL (0x00000002U) /*!< Bit mask for DDRC_RFSHCTL3_REFRESH_UPDATE_LEVEL. */
#define BS_DDRC_RFSHCTL3_REFRESH_UPDATE_LEVEL (1U) /*!< Bit field size in bits for DDRC_RFSHCTL3_REFRESH_UPDATE_LEVEL. */

/*! @brief Read current value of the DDRC_RFSHCTL3_REFRESH_UPDATE_LEVEL field. */
#define BR_DDRC_RFSHCTL3_REFRESH_UPDATE_LEVEL(x) (HW_DDRC_RFSHCTL3(x).B.REFRESH_UPDATE_LEVEL)

/*! @brief Format value for bitfield DDRC_RFSHCTL3_REFRESH_UPDATE_LEVEL. */
#define BF_DDRC_RFSHCTL3_REFRESH_UPDATE_LEVEL(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_RFSHCTL3_REFRESH_UPDATE_LEVEL) & BM_DDRC_RFSHCTL3_REFRESH_UPDATE_LEVEL)

/*! @brief Set the REFRESH_UPDATE_LEVEL field to a new value. */
#define BW_DDRC_RFSHCTL3_REFRESH_UPDATE_LEVEL(x, v) (HW_DDRC_RFSHCTL3_WR(x, (HW_DDRC_RFSHCTL3_RD(x) & ~BM_DDRC_RFSHCTL3_REFRESH_UPDATE_LEVEL) | BF_DDRC_RFSHCTL3_REFRESH_UPDATE_LEVEL(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_RFSHTMG - Refresh Timing Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_RFSHTMG - Refresh Timing Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_rfshtmg
{
    uint32_t U;
    struct _hw_ddrc_rfshtmg_bitfields
    {
        uint32_t T_RFC_MIN : 10;       /*!< [9:0]  */
        uint32_t RESERVED0 : 6;        /*!< [15:10]  */
        uint32_t T_RFC_NOM_X32 : 12;   /*!< [27:16]  */
        uint32_t RESERVED1 : 4;        /*!< [31:28]  */
    } B;
} hw_ddrc_rfshtmg_t;

/*!
 * @name Constants and macros for entire DDRC_RFSHTMG register
 */
/*@{*/
#define HW_DDRC_RFSHTMG_ADDR(x)  ((uintptr_t)(x) + 0x64U)

#define HW_DDRC_RFSHTMG(x)       (*(__IO hw_ddrc_rfshtmg_t *) HW_DDRC_RFSHTMG_ADDR(x))
#define HW_DDRC_RFSHTMG_RD(x)    (HW_DDRC_RFSHTMG(x).U)
#define HW_DDRC_RFSHTMG_WR(x, v) (HW_DDRC_RFSHTMG(x).U = (v))
#define HW_DDRC_RFSHTMG_SET(x, v) (HW_DDRC_RFSHTMG_WR(x, HW_DDRC_RFSHTMG_RD(x) |  (v)))
#define HW_DDRC_RFSHTMG_CLR(x, v) (HW_DDRC_RFSHTMG_WR(x, HW_DDRC_RFSHTMG_RD(x) & ~(v)))
#define HW_DDRC_RFSHTMG_TOG(x, v) (HW_DDRC_RFSHTMG_WR(x, HW_DDRC_RFSHTMG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_RFSHTMG bitfields
 */

/*!
 * @name Register DDRC_RFSHTMG, field T_RFC_MIN[9:0] (RW)
 *
 * tRFC (min): Minimum time from refresh to refresh or activate. For
 * MEMC_FREQ_RATIO = 1 configurations, t_rfc_min should be set to RoundUp (tRFCmin / tCK).
 * For MEMC_FREQ_RATIO = 2 configurations, t_rfc_min should be set to RoundUp
 * (RoundUp (tRFCmin / tCK) / 2). In LPDDR2 / LPDDR3 mode: If using all-bank
 * refreshes, the tRFCmin value in the above equations is equal to tRFCab If using
 * per-bank refreshes, the tRFCmin value in the above equations is equal to tRFCpb
 * Unit: Clocks. Value After Reset: 0x8c Exists: Always
 */
/*@{*/
#define BP_DDRC_RFSHTMG_T_RFC_MIN (0U)     /*!< Bit position for DDRC_RFSHTMG_T_RFC_MIN. */
#define BM_DDRC_RFSHTMG_T_RFC_MIN (0x000003FFU) /*!< Bit mask for DDRC_RFSHTMG_T_RFC_MIN. */
#define BS_DDRC_RFSHTMG_T_RFC_MIN (10U)    /*!< Bit field size in bits for DDRC_RFSHTMG_T_RFC_MIN. */

/*! @brief Read current value of the DDRC_RFSHTMG_T_RFC_MIN field. */
#define BR_DDRC_RFSHTMG_T_RFC_MIN(x) (HW_DDRC_RFSHTMG(x).B.T_RFC_MIN)

/*! @brief Format value for bitfield DDRC_RFSHTMG_T_RFC_MIN. */
#define BF_DDRC_RFSHTMG_T_RFC_MIN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_RFSHTMG_T_RFC_MIN) & BM_DDRC_RFSHTMG_T_RFC_MIN)

/*! @brief Set the T_RFC_MIN field to a new value. */
#define BW_DDRC_RFSHTMG_T_RFC_MIN(x, v) (HW_DDRC_RFSHTMG_WR(x, (HW_DDRC_RFSHTMG_RD(x) & ~BM_DDRC_RFSHTMG_T_RFC_MIN) | BF_DDRC_RFSHTMG_T_RFC_MIN(v)))
/*@}*/

/*!
 * @name Register DDRC_RFSHTMG, field T_RFC_NOM_X32[27:16] (RW)
 *
 * tREFI: Average time interval between refreshes per rank (Specification: 7.8us
 * for DDR3. See JEDEC specification for mDDR, LPDDR2 and LPDDR3). For LPDDR2 /
 * LPDDR3: If using all-bank refreshes (RFSHCTL0.per_bank_refresh = 0), this
 * register should be set to tREFIab If using per-bank refreshes
 * (RFSHCTL0.per_bank_refresh = 1), this register should be set to tREFIpb For configurations with
 * MEMC_FREQ_RATIO = 2, program this to (tREFI / 2), no rounding up. Note that
 * RFSHTMG.t_rfc_nom_x32 * 32 must be greater than RFSHTMG.t_rfc_min. Unit: Multiples
 * of 32 clocks. Value After Reset: 0x62 Exists: Always
 */
/*@{*/
#define BP_DDRC_RFSHTMG_T_RFC_NOM_X32 (16U) /*!< Bit position for DDRC_RFSHTMG_T_RFC_NOM_X32. */
#define BM_DDRC_RFSHTMG_T_RFC_NOM_X32 (0x0FFF0000U) /*!< Bit mask for DDRC_RFSHTMG_T_RFC_NOM_X32. */
#define BS_DDRC_RFSHTMG_T_RFC_NOM_X32 (12U) /*!< Bit field size in bits for DDRC_RFSHTMG_T_RFC_NOM_X32. */

/*! @brief Read current value of the DDRC_RFSHTMG_T_RFC_NOM_X32 field. */
#define BR_DDRC_RFSHTMG_T_RFC_NOM_X32(x) (HW_DDRC_RFSHTMG(x).B.T_RFC_NOM_X32)

/*! @brief Format value for bitfield DDRC_RFSHTMG_T_RFC_NOM_X32. */
#define BF_DDRC_RFSHTMG_T_RFC_NOM_X32(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_RFSHTMG_T_RFC_NOM_X32) & BM_DDRC_RFSHTMG_T_RFC_NOM_X32)

/*! @brief Set the T_RFC_NOM_X32 field to a new value. */
#define BW_DDRC_RFSHTMG_T_RFC_NOM_X32(x, v) (HW_DDRC_RFSHTMG_WR(x, (HW_DDRC_RFSHTMG_RD(x) & ~BM_DDRC_RFSHTMG_T_RFC_NOM_X32) | BF_DDRC_RFSHTMG_T_RFC_NOM_X32(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_INIT0 - SDRAM Initialization Register 0
 ******************************************************************************/

/*!
 * @brief HW_DDRC_INIT0 - SDRAM Initialization Register 0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: Always
 */
typedef union _hw_ddrc_init0
{
    uint32_t U;
    struct _hw_ddrc_init0_bitfields
    {
        uint32_t PRE_CKE_X1024 : 11;   /*!< [10:0]  */
        uint32_t RESERVED0 : 5;        /*!< [15:11]  */
        uint32_t POST_CKE_X1024 : 10;  /*!< [25:16]  */
        uint32_t RESERVED1 : 4;        /*!< [29:26]  */
        uint32_t SKIP_DRAM_INIT : 2;   /*!< [31:30]  */
    } B;
} hw_ddrc_init0_t;

/*!
 * @name Constants and macros for entire DDRC_INIT0 register
 */
/*@{*/
#define HW_DDRC_INIT0_ADDR(x)    ((uintptr_t)(x) + 0xD0U)

#define HW_DDRC_INIT0(x)         (*(__IO hw_ddrc_init0_t *) HW_DDRC_INIT0_ADDR(x))
#define HW_DDRC_INIT0_RD(x)      (HW_DDRC_INIT0(x).U)
#define HW_DDRC_INIT0_WR(x, v)   (HW_DDRC_INIT0(x).U = (v))
#define HW_DDRC_INIT0_SET(x, v)  (HW_DDRC_INIT0_WR(x, HW_DDRC_INIT0_RD(x) |  (v)))
#define HW_DDRC_INIT0_CLR(x, v)  (HW_DDRC_INIT0_WR(x, HW_DDRC_INIT0_RD(x) & ~(v)))
#define HW_DDRC_INIT0_TOG(x, v)  (HW_DDRC_INIT0_WR(x, HW_DDRC_INIT0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_INIT0 bitfields
 */

/*!
 * @name Register DDRC_INIT0, field PRE_CKE_X1024[10:0] (RW)
 *
 * Cycles to wait after reset before driving CKE high to start the SDRAM
 * initialization sequence. Unit: 1024 clock cycles. DDR2 specifications typically
 * require this to be programmed for a delay of >= 200 us. LPDDR2 / LPDDR3: tINIT1 of
 * 100 ns (min) For configurations with MEMC_FREQ_RATIO = 2, program this to
 * JEDEC spec value divided by 2, and round it up to next integer value. Value After
 * Reset: 0x4e Exists: Always
 */
/*@{*/
#define BP_DDRC_INIT0_PRE_CKE_X1024 (0U)   /*!< Bit position for DDRC_INIT0_PRE_CKE_X1024. */
#define BM_DDRC_INIT0_PRE_CKE_X1024 (0x000007FFU) /*!< Bit mask for DDRC_INIT0_PRE_CKE_X1024. */
#define BS_DDRC_INIT0_PRE_CKE_X1024 (11U)  /*!< Bit field size in bits for DDRC_INIT0_PRE_CKE_X1024. */

/*! @brief Read current value of the DDRC_INIT0_PRE_CKE_X1024 field. */
#define BR_DDRC_INIT0_PRE_CKE_X1024(x) (HW_DDRC_INIT0(x).B.PRE_CKE_X1024)

/*! @brief Format value for bitfield DDRC_INIT0_PRE_CKE_X1024. */
#define BF_DDRC_INIT0_PRE_CKE_X1024(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_INIT0_PRE_CKE_X1024) & BM_DDRC_INIT0_PRE_CKE_X1024)

/*! @brief Set the PRE_CKE_X1024 field to a new value. */
#define BW_DDRC_INIT0_PRE_CKE_X1024(x, v) (HW_DDRC_INIT0_WR(x, (HW_DDRC_INIT0_RD(x) & ~BM_DDRC_INIT0_PRE_CKE_X1024) | BF_DDRC_INIT0_PRE_CKE_X1024(v)))
/*@}*/

/*!
 * @name Register DDRC_INIT0, field POST_CKE_X1024[25:16] (RW)
 *
 * Cycles to wait after driving CKE high to start the SDRAM initialization
 * sequence. Unit: 1024 clocks. DDR2 typically requires a 400 ns delay, requiring this
 * value to be programmed to 2 at all clock speeds. LPDDR2 / LPDDR3 typically
 * requires this to be programmed for a delay of 200 us. For configurations with
 * MEMC_FREQ_RATIO = 2, program this to JEDEC spec value divided by 2, and round it
 * up to next integer value. Value After Reset: 0x2 Exists: Always
 */
/*@{*/
#define BP_DDRC_INIT0_POST_CKE_X1024 (16U) /*!< Bit position for DDRC_INIT0_POST_CKE_X1024. */
#define BM_DDRC_INIT0_POST_CKE_X1024 (0x03FF0000U) /*!< Bit mask for DDRC_INIT0_POST_CKE_X1024. */
#define BS_DDRC_INIT0_POST_CKE_X1024 (10U) /*!< Bit field size in bits for DDRC_INIT0_POST_CKE_X1024. */

/*! @brief Read current value of the DDRC_INIT0_POST_CKE_X1024 field. */
#define BR_DDRC_INIT0_POST_CKE_X1024(x) (HW_DDRC_INIT0(x).B.POST_CKE_X1024)

/*! @brief Format value for bitfield DDRC_INIT0_POST_CKE_X1024. */
#define BF_DDRC_INIT0_POST_CKE_X1024(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_INIT0_POST_CKE_X1024) & BM_DDRC_INIT0_POST_CKE_X1024)

/*! @brief Set the POST_CKE_X1024 field to a new value. */
#define BW_DDRC_INIT0_POST_CKE_X1024(x, v) (HW_DDRC_INIT0_WR(x, (HW_DDRC_INIT0_RD(x) & ~BM_DDRC_INIT0_POST_CKE_X1024) | BF_DDRC_INIT0_POST_CKE_X1024(v)))
/*@}*/

/*!
 * @name Register DDRC_INIT0, field SKIP_DRAM_INIT[31:30] (RW)
 *
 * If lower bit is enabled the SDRAM initialization routine is skipped. The
 * upper bit decides what state the controller starts up in when reset is removed.
 * Value After Reset: 0x0 Exists: Always
 *
 * Values:
 * - 00 - SDRAM Intialization routine is run after power-up.
 * - 01 - SDRAM Intialization routine is skipped after power- up. Controller
 *     starts up in Normal Mode.
 * - 11 - SDRAM Intialization routine is skipped after power- up. Controller
 *     starts up in Self-refresh Mode.
 * - 10 - SDRAM Intialization routine is run after power-up.
 */
/*@{*/
#define BP_DDRC_INIT0_SKIP_DRAM_INIT (30U) /*!< Bit position for DDRC_INIT0_SKIP_DRAM_INIT. */
#define BM_DDRC_INIT0_SKIP_DRAM_INIT (0xC0000000U) /*!< Bit mask for DDRC_INIT0_SKIP_DRAM_INIT. */
#define BS_DDRC_INIT0_SKIP_DRAM_INIT (2U)  /*!< Bit field size in bits for DDRC_INIT0_SKIP_DRAM_INIT. */

/*! @brief Read current value of the DDRC_INIT0_SKIP_DRAM_INIT field. */
#define BR_DDRC_INIT0_SKIP_DRAM_INIT(x) (HW_DDRC_INIT0(x).B.SKIP_DRAM_INIT)

/*! @brief Format value for bitfield DDRC_INIT0_SKIP_DRAM_INIT. */
#define BF_DDRC_INIT0_SKIP_DRAM_INIT(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_INIT0_SKIP_DRAM_INIT) & BM_DDRC_INIT0_SKIP_DRAM_INIT)

/*! @brief Set the SKIP_DRAM_INIT field to a new value. */
#define BW_DDRC_INIT0_SKIP_DRAM_INIT(x, v) (HW_DDRC_INIT0_WR(x, (HW_DDRC_INIT0_RD(x) & ~BM_DDRC_INIT0_SKIP_DRAM_INIT) | BF_DDRC_INIT0_SKIP_DRAM_INIT(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_INIT1 - SDRAM Initialization Register 1
 ******************************************************************************/

/*!
 * @brief HW_DDRC_INIT1 - SDRAM Initialization Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_init1
{
    uint32_t U;
    struct _hw_ddrc_init1_bitfields
    {
        uint32_t PRE_OCD_X32 : 4;      /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t FINAL_WAIT_X32 : 7;   /*!< [14:8]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t DRAM_RSTN_X1024 : 8;  /*!< [23:16]  */
        uint32_t RESERVED2 : 8;        /*!< [31:24]  */
    } B;
} hw_ddrc_init1_t;

/*!
 * @name Constants and macros for entire DDRC_INIT1 register
 */
/*@{*/
#define HW_DDRC_INIT1_ADDR(x)    ((uintptr_t)(x) + 0xD4U)

#define HW_DDRC_INIT1(x)         (*(__IO hw_ddrc_init1_t *) HW_DDRC_INIT1_ADDR(x))
#define HW_DDRC_INIT1_RD(x)      (HW_DDRC_INIT1(x).U)
#define HW_DDRC_INIT1_WR(x, v)   (HW_DDRC_INIT1(x).U = (v))
#define HW_DDRC_INIT1_SET(x, v)  (HW_DDRC_INIT1_WR(x, HW_DDRC_INIT1_RD(x) |  (v)))
#define HW_DDRC_INIT1_CLR(x, v)  (HW_DDRC_INIT1_WR(x, HW_DDRC_INIT1_RD(x) & ~(v)))
#define HW_DDRC_INIT1_TOG(x, v)  (HW_DDRC_INIT1_WR(x, HW_DDRC_INIT1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_INIT1 bitfields
 */

/*!
 * @name Register DDRC_INIT1, field PRE_OCD_X32[3:0] (RW)
 *
 * Wait period before driving the OCD complete command to SDRAM. Unit: Counts of
 * a global timer that pulses every 32 clock cycles. There is no known specific
 * requirement for this; it may be set to zero. Value After Reset: 0x0 Exists:
 * Always
 */
/*@{*/
#define BP_DDRC_INIT1_PRE_OCD_X32 (0U)     /*!< Bit position for DDRC_INIT1_PRE_OCD_X32. */
#define BM_DDRC_INIT1_PRE_OCD_X32 (0x0000000FU) /*!< Bit mask for DDRC_INIT1_PRE_OCD_X32. */
#define BS_DDRC_INIT1_PRE_OCD_X32 (4U)     /*!< Bit field size in bits for DDRC_INIT1_PRE_OCD_X32. */

/*! @brief Read current value of the DDRC_INIT1_PRE_OCD_X32 field. */
#define BR_DDRC_INIT1_PRE_OCD_X32(x) (HW_DDRC_INIT1(x).B.PRE_OCD_X32)

/*! @brief Format value for bitfield DDRC_INIT1_PRE_OCD_X32. */
#define BF_DDRC_INIT1_PRE_OCD_X32(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_INIT1_PRE_OCD_X32) & BM_DDRC_INIT1_PRE_OCD_X32)

/*! @brief Set the PRE_OCD_X32 field to a new value. */
#define BW_DDRC_INIT1_PRE_OCD_X32(x, v) (HW_DDRC_INIT1_WR(x, (HW_DDRC_INIT1_RD(x) & ~BM_DDRC_INIT1_PRE_OCD_X32) | BF_DDRC_INIT1_PRE_OCD_X32(v)))
/*@}*/

/*!
 * @name Register DDRC_INIT1, field FINAL_WAIT_X32[14:8] (RW)
 *
 * Cycles to wait after completing the SDRAM initialization sequence before
 * starting the dynamic scheduler. Unit: Counts of a global timer that pulses every
 * 32 clock cycles. There is no known specific requirement for this; it may be set
 * to zero. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_INIT1_FINAL_WAIT_X32 (8U)  /*!< Bit position for DDRC_INIT1_FINAL_WAIT_X32. */
#define BM_DDRC_INIT1_FINAL_WAIT_X32 (0x00007F00U) /*!< Bit mask for DDRC_INIT1_FINAL_WAIT_X32. */
#define BS_DDRC_INIT1_FINAL_WAIT_X32 (7U)  /*!< Bit field size in bits for DDRC_INIT1_FINAL_WAIT_X32. */

/*! @brief Read current value of the DDRC_INIT1_FINAL_WAIT_X32 field. */
#define BR_DDRC_INIT1_FINAL_WAIT_X32(x) (HW_DDRC_INIT1(x).B.FINAL_WAIT_X32)

/*! @brief Format value for bitfield DDRC_INIT1_FINAL_WAIT_X32. */
#define BF_DDRC_INIT1_FINAL_WAIT_X32(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_INIT1_FINAL_WAIT_X32) & BM_DDRC_INIT1_FINAL_WAIT_X32)

/*! @brief Set the FINAL_WAIT_X32 field to a new value. */
#define BW_DDRC_INIT1_FINAL_WAIT_X32(x, v) (HW_DDRC_INIT1_WR(x, (HW_DDRC_INIT1_RD(x) & ~BM_DDRC_INIT1_FINAL_WAIT_X32) | BF_DDRC_INIT1_FINAL_WAIT_X32(v)))
/*@}*/

/*!
 * @name Register DDRC_INIT1, field DRAM_RSTN_X1024[23:16] (RW)
 *
 * Number of cycles to assert SDRAM reset signal during init sequence. This is
 * only present for designs supporting DDR3 devices. Value After Reset: 0x0
 * Exists: MEMC_DDR3 == 1
 */
/*@{*/
#define BP_DDRC_INIT1_DRAM_RSTN_X1024 (16U) /*!< Bit position for DDRC_INIT1_DRAM_RSTN_X1024. */
#define BM_DDRC_INIT1_DRAM_RSTN_X1024 (0x00FF0000U) /*!< Bit mask for DDRC_INIT1_DRAM_RSTN_X1024. */
#define BS_DDRC_INIT1_DRAM_RSTN_X1024 (8U) /*!< Bit field size in bits for DDRC_INIT1_DRAM_RSTN_X1024. */

/*! @brief Read current value of the DDRC_INIT1_DRAM_RSTN_X1024 field. */
#define BR_DDRC_INIT1_DRAM_RSTN_X1024(x) (HW_DDRC_INIT1(x).B.DRAM_RSTN_X1024)

/*! @brief Format value for bitfield DDRC_INIT1_DRAM_RSTN_X1024. */
#define BF_DDRC_INIT1_DRAM_RSTN_X1024(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_INIT1_DRAM_RSTN_X1024) & BM_DDRC_INIT1_DRAM_RSTN_X1024)

/*! @brief Set the DRAM_RSTN_X1024 field to a new value. */
#define BW_DDRC_INIT1_DRAM_RSTN_X1024(x, v) (HW_DDRC_INIT1_WR(x, (HW_DDRC_INIT1_RD(x) & ~BM_DDRC_INIT1_DRAM_RSTN_X1024) | BF_DDRC_INIT1_DRAM_RSTN_X1024(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_INIT2 - SDRAM Initialization Register 2
 ******************************************************************************/

/*!
 * @brief HW_DDRC_INIT2 - SDRAM Initialization Register 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: MEMC_LPDDR2==1
 */
typedef union _hw_ddrc_init2
{
    uint32_t U;
    struct _hw_ddrc_init2_bitfields
    {
        uint32_t MIN_STABLE_CLOCK_X1 : 4; /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t IDLE_AFTER_RESET_X32 : 8; /*!< [15:8]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_ddrc_init2_t;

/*!
 * @name Constants and macros for entire DDRC_INIT2 register
 */
/*@{*/
#define HW_DDRC_INIT2_ADDR(x)    ((uintptr_t)(x) + 0xD8U)

#define HW_DDRC_INIT2(x)         (*(__IO hw_ddrc_init2_t *) HW_DDRC_INIT2_ADDR(x))
#define HW_DDRC_INIT2_RD(x)      (HW_DDRC_INIT2(x).U)
#define HW_DDRC_INIT2_WR(x, v)   (HW_DDRC_INIT2(x).U = (v))
#define HW_DDRC_INIT2_SET(x, v)  (HW_DDRC_INIT2_WR(x, HW_DDRC_INIT2_RD(x) |  (v)))
#define HW_DDRC_INIT2_CLR(x, v)  (HW_DDRC_INIT2_WR(x, HW_DDRC_INIT2_RD(x) & ~(v)))
#define HW_DDRC_INIT2_TOG(x, v)  (HW_DDRC_INIT2_WR(x, HW_DDRC_INIT2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_INIT2 bitfields
 */

/*!
 * @name Register DDRC_INIT2, field MIN_STABLE_CLOCK_X1[3:0] (RW)
 *
 * Time to wait after the first CKE high, tINIT2. Present only in designs
 * configured to support LPDDR2 / LPDDR3. Unit: 1 clock cycle. LPDDR2 / LPDDR3
 * typically requires 5 x tCK delay. Value After Reset: (MEMC_LPDDR2) ? 0x5 : 0x0 Exists:
 * MEMC_LPDDR2 == 1
 */
/*@{*/
#define BP_DDRC_INIT2_MIN_STABLE_CLOCK_X1 (0U) /*!< Bit position for DDRC_INIT2_MIN_STABLE_CLOCK_X1. */
#define BM_DDRC_INIT2_MIN_STABLE_CLOCK_X1 (0x0000000FU) /*!< Bit mask for DDRC_INIT2_MIN_STABLE_CLOCK_X1. */
#define BS_DDRC_INIT2_MIN_STABLE_CLOCK_X1 (4U) /*!< Bit field size in bits for DDRC_INIT2_MIN_STABLE_CLOCK_X1. */

/*! @brief Read current value of the DDRC_INIT2_MIN_STABLE_CLOCK_X1 field. */
#define BR_DDRC_INIT2_MIN_STABLE_CLOCK_X1(x) (HW_DDRC_INIT2(x).B.MIN_STABLE_CLOCK_X1)

/*! @brief Format value for bitfield DDRC_INIT2_MIN_STABLE_CLOCK_X1. */
#define BF_DDRC_INIT2_MIN_STABLE_CLOCK_X1(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_INIT2_MIN_STABLE_CLOCK_X1) & BM_DDRC_INIT2_MIN_STABLE_CLOCK_X1)

/*! @brief Set the MIN_STABLE_CLOCK_X1 field to a new value. */
#define BW_DDRC_INIT2_MIN_STABLE_CLOCK_X1(x, v) (HW_DDRC_INIT2_WR(x, (HW_DDRC_INIT2_RD(x) & ~BM_DDRC_INIT2_MIN_STABLE_CLOCK_X1) | BF_DDRC_INIT2_MIN_STABLE_CLOCK_X1(v)))
/*@}*/

/*!
 * @name Register DDRC_INIT2, field IDLE_AFTER_RESET_X32[15:8] (RW)
 *
 * Idle time after the reset command, tINIT4. Present only in designs configured
 * to support LPDDR2. Unit: 32 clock cycles. Value After Reset: (MEMC_LPDDR2) ?
 * 0xd : 0x0 Exists: MEMC_LPDDR2 == 1
 */
/*@{*/
#define BP_DDRC_INIT2_IDLE_AFTER_RESET_X32 (8U) /*!< Bit position for DDRC_INIT2_IDLE_AFTER_RESET_X32. */
#define BM_DDRC_INIT2_IDLE_AFTER_RESET_X32 (0x0000FF00U) /*!< Bit mask for DDRC_INIT2_IDLE_AFTER_RESET_X32. */
#define BS_DDRC_INIT2_IDLE_AFTER_RESET_X32 (8U) /*!< Bit field size in bits for DDRC_INIT2_IDLE_AFTER_RESET_X32. */

/*! @brief Read current value of the DDRC_INIT2_IDLE_AFTER_RESET_X32 field. */
#define BR_DDRC_INIT2_IDLE_AFTER_RESET_X32(x) (HW_DDRC_INIT2(x).B.IDLE_AFTER_RESET_X32)

/*! @brief Format value for bitfield DDRC_INIT2_IDLE_AFTER_RESET_X32. */
#define BF_DDRC_INIT2_IDLE_AFTER_RESET_X32(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_INIT2_IDLE_AFTER_RESET_X32) & BM_DDRC_INIT2_IDLE_AFTER_RESET_X32)

/*! @brief Set the IDLE_AFTER_RESET_X32 field to a new value. */
#define BW_DDRC_INIT2_IDLE_AFTER_RESET_X32(x, v) (HW_DDRC_INIT2_WR(x, (HW_DDRC_INIT2_RD(x) & ~BM_DDRC_INIT2_IDLE_AFTER_RESET_X32) | BF_DDRC_INIT2_IDLE_AFTER_RESET_X32(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_INIT3 - SDRAM Initialization Register 3
 ******************************************************************************/

/*!
 * @brief HW_DDRC_INIT3 - SDRAM Initialization Register 3 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_init3
{
    uint32_t U;
    struct _hw_ddrc_init3_bitfields
    {
        uint32_t EMR : 16;             /*!< [15:0]  */
        uint32_t MR : 16;              /*!< [31:16]  */
    } B;
} hw_ddrc_init3_t;

/*!
 * @name Constants and macros for entire DDRC_INIT3 register
 */
/*@{*/
#define HW_DDRC_INIT3_ADDR(x)    ((uintptr_t)(x) + 0xDCU)

#define HW_DDRC_INIT3(x)         (*(__IO hw_ddrc_init3_t *) HW_DDRC_INIT3_ADDR(x))
#define HW_DDRC_INIT3_RD(x)      (HW_DDRC_INIT3(x).U)
#define HW_DDRC_INIT3_WR(x, v)   (HW_DDRC_INIT3(x).U = (v))
#define HW_DDRC_INIT3_SET(x, v)  (HW_DDRC_INIT3_WR(x, HW_DDRC_INIT3_RD(x) |  (v)))
#define HW_DDRC_INIT3_CLR(x, v)  (HW_DDRC_INIT3_WR(x, HW_DDRC_INIT3_RD(x) & ~(v)))
#define HW_DDRC_INIT3_TOG(x, v)  (HW_DDRC_INIT3_WR(x, HW_DDRC_INIT3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_INIT3 bitfields
 */

/*!
 * @name Register DDRC_INIT3, field EMR[15:0] (RW)
 *
 * DDR2: Value to write to EMR register. Bits 9:7 are for OCD and the setting in
 * this register is ignored. The DDRC sets those bits appropriately. DDR3: Value
 * to write to MR1 register. Set bit 7 to 0. If PHY-evaluation mode training is
 * enabled, this bit is set appropriately by the DDRC during write leveling.
 * mDDR: Value to write to EMR register LPDDR2 / LPDDR3: Value to write to MR2
 * register Value After Reset: 0x510 Exists: Always
 */
/*@{*/
#define BP_DDRC_INIT3_EMR    (0U)          /*!< Bit position for DDRC_INIT3_EMR. */
#define BM_DDRC_INIT3_EMR    (0x0000FFFFU) /*!< Bit mask for DDRC_INIT3_EMR. */
#define BS_DDRC_INIT3_EMR    (16U)         /*!< Bit field size in bits for DDRC_INIT3_EMR. */

/*! @brief Read current value of the DDRC_INIT3_EMR field. */
#define BR_DDRC_INIT3_EMR(x) (HW_DDRC_INIT3(x).B.EMR)

/*! @brief Format value for bitfield DDRC_INIT3_EMR. */
#define BF_DDRC_INIT3_EMR(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_INIT3_EMR) & BM_DDRC_INIT3_EMR)

/*! @brief Set the EMR field to a new value. */
#define BW_DDRC_INIT3_EMR(x, v) (HW_DDRC_INIT3_WR(x, (HW_DDRC_INIT3_RD(x) & ~BM_DDRC_INIT3_EMR) | BF_DDRC_INIT3_EMR(v)))
/*@}*/

/*!
 * @name Register DDRC_INIT3, field MR[31:16] (RW)
 *
 * DDR2: Value to write to MR register. Bit 8 is for DLL and the setting here is
 * ignored. The DDRC sets this bit appropriately. DDR3: Value loaded into MR0
 * register. mDDR: Value to write to MR register. LPDDR2 / LPDDR3 - Value to write
 * to MR1 register Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_INIT3_MR     (16U)         /*!< Bit position for DDRC_INIT3_MR. */
#define BM_DDRC_INIT3_MR     (0xFFFF0000U) /*!< Bit mask for DDRC_INIT3_MR. */
#define BS_DDRC_INIT3_MR     (16U)         /*!< Bit field size in bits for DDRC_INIT3_MR. */

/*! @brief Read current value of the DDRC_INIT3_MR field. */
#define BR_DDRC_INIT3_MR(x)  (HW_DDRC_INIT3(x).B.MR)

/*! @brief Format value for bitfield DDRC_INIT3_MR. */
#define BF_DDRC_INIT3_MR(v)  ((uint32_t)((uint32_t)(v) << BP_DDRC_INIT3_MR) & BM_DDRC_INIT3_MR)

/*! @brief Set the MR field to a new value. */
#define BW_DDRC_INIT3_MR(x, v) (HW_DDRC_INIT3_WR(x, (HW_DDRC_INIT3_RD(x) & ~BM_DDRC_INIT3_MR) | BF_DDRC_INIT3_MR(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_INIT4 - SDRAM Initialization Register 4
 ******************************************************************************/

/*!
 * @brief HW_DDRC_INIT4 - SDRAM Initialization Register 4 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_init4
{
    uint32_t U;
    struct _hw_ddrc_init4_bitfields
    {
        uint32_t EMR3 : 16;            /*!< [15:0]  */
        uint32_t EMR2 : 16;            /*!< [31:16]  */
    } B;
} hw_ddrc_init4_t;

/*!
 * @name Constants and macros for entire DDRC_INIT4 register
 */
/*@{*/
#define HW_DDRC_INIT4_ADDR(x)    ((uintptr_t)(x) + 0xE0U)

#define HW_DDRC_INIT4(x)         (*(__IO hw_ddrc_init4_t *) HW_DDRC_INIT4_ADDR(x))
#define HW_DDRC_INIT4_RD(x)      (HW_DDRC_INIT4(x).U)
#define HW_DDRC_INIT4_WR(x, v)   (HW_DDRC_INIT4(x).U = (v))
#define HW_DDRC_INIT4_SET(x, v)  (HW_DDRC_INIT4_WR(x, HW_DDRC_INIT4_RD(x) |  (v)))
#define HW_DDRC_INIT4_CLR(x, v)  (HW_DDRC_INIT4_WR(x, HW_DDRC_INIT4_RD(x) & ~(v)))
#define HW_DDRC_INIT4_TOG(x, v)  (HW_DDRC_INIT4_WR(x, HW_DDRC_INIT4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_INIT4 bitfields
 */

/*!
 * @name Register DDRC_INIT4, field EMR3[15:0] (RW)
 *
 * DDR2: Value to write to EMR3 register. DDR3: Value to write to MR3 register
 * mDDR / LPDDR2 / LPDDR3: Unused Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_INIT4_EMR3   (0U)          /*!< Bit position for DDRC_INIT4_EMR3. */
#define BM_DDRC_INIT4_EMR3   (0x0000FFFFU) /*!< Bit mask for DDRC_INIT4_EMR3. */
#define BS_DDRC_INIT4_EMR3   (16U)         /*!< Bit field size in bits for DDRC_INIT4_EMR3. */

/*! @brief Read current value of the DDRC_INIT4_EMR3 field. */
#define BR_DDRC_INIT4_EMR3(x) (HW_DDRC_INIT4(x).B.EMR3)

/*! @brief Format value for bitfield DDRC_INIT4_EMR3. */
#define BF_DDRC_INIT4_EMR3(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_INIT4_EMR3) & BM_DDRC_INIT4_EMR3)

/*! @brief Set the EMR3 field to a new value. */
#define BW_DDRC_INIT4_EMR3(x, v) (HW_DDRC_INIT4_WR(x, (HW_DDRC_INIT4_RD(x) & ~BM_DDRC_INIT4_EMR3) | BF_DDRC_INIT4_EMR3(v)))
/*@}*/

/*!
 * @name Register DDRC_INIT4, field EMR2[31:16] (RW)
 *
 * DDR2: Value to write to EMR2 register. DDR3: Value to write to MR2 register
 * LPDDR2 / LPDDR3: Value to write to MR3 register mDDR: Unused Value After Reset:
 * 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_INIT4_EMR2   (16U)         /*!< Bit position for DDRC_INIT4_EMR2. */
#define BM_DDRC_INIT4_EMR2   (0xFFFF0000U) /*!< Bit mask for DDRC_INIT4_EMR2. */
#define BS_DDRC_INIT4_EMR2   (16U)         /*!< Bit field size in bits for DDRC_INIT4_EMR2. */

/*! @brief Read current value of the DDRC_INIT4_EMR2 field. */
#define BR_DDRC_INIT4_EMR2(x) (HW_DDRC_INIT4(x).B.EMR2)

/*! @brief Format value for bitfield DDRC_INIT4_EMR2. */
#define BF_DDRC_INIT4_EMR2(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_INIT4_EMR2) & BM_DDRC_INIT4_EMR2)

/*! @brief Set the EMR2 field to a new value. */
#define BW_DDRC_INIT4_EMR2(x, v) (HW_DDRC_INIT4_WR(x, (HW_DDRC_INIT4_RD(x) & ~BM_DDRC_INIT4_EMR2) | BF_DDRC_INIT4_EMR2(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_INIT5 - SDRAM Initialization Register 5
 ******************************************************************************/

/*!
 * @brief HW_DDRC_INIT5 - SDRAM Initialization Register 5 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: MEMC_DDR3==1 || MEMC_LPDDR2==1
 */
typedef union _hw_ddrc_init5
{
    uint32_t U;
    struct _hw_ddrc_init5_bitfields
    {
        uint32_t MAX_AUTO_INIT_X1024 : 10; /*!< [9:0]  */
        uint32_t RESERVED0 : 6;        /*!< [15:10]  */
        uint32_t DEV_ZQINIT_X32 : 8;   /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_ddrc_init5_t;

/*!
 * @name Constants and macros for entire DDRC_INIT5 register
 */
/*@{*/
#define HW_DDRC_INIT5_ADDR(x)    ((uintptr_t)(x) + 0xE4U)

#define HW_DDRC_INIT5(x)         (*(__IO hw_ddrc_init5_t *) HW_DDRC_INIT5_ADDR(x))
#define HW_DDRC_INIT5_RD(x)      (HW_DDRC_INIT5(x).U)
#define HW_DDRC_INIT5_WR(x, v)   (HW_DDRC_INIT5(x).U = (v))
#define HW_DDRC_INIT5_SET(x, v)  (HW_DDRC_INIT5_WR(x, HW_DDRC_INIT5_RD(x) |  (v)))
#define HW_DDRC_INIT5_CLR(x, v)  (HW_DDRC_INIT5_WR(x, HW_DDRC_INIT5_RD(x) & ~(v)))
#define HW_DDRC_INIT5_TOG(x, v)  (HW_DDRC_INIT5_WR(x, HW_DDRC_INIT5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_INIT5 bitfields
 */

/*!
 * @name Register DDRC_INIT5, field MAX_AUTO_INIT_X1024[9:0] (RW)
 *
 * Maximum duration of the auto initialization, tINIT5. Present only in designs
 * configured to support LPDDR2 / LPDDR3. LPDDR2 / LPDDR3 typically requires 10
 * us. Value After Reset: (MEMC_LPDDR2) ? 0x4 : 0x0 Exists: MEMC_LPDDR2 == 1
 */
/*@{*/
#define BP_DDRC_INIT5_MAX_AUTO_INIT_X1024 (0U) /*!< Bit position for DDRC_INIT5_MAX_AUTO_INIT_X1024. */
#define BM_DDRC_INIT5_MAX_AUTO_INIT_X1024 (0x000003FFU) /*!< Bit mask for DDRC_INIT5_MAX_AUTO_INIT_X1024. */
#define BS_DDRC_INIT5_MAX_AUTO_INIT_X1024 (10U) /*!< Bit field size in bits for DDRC_INIT5_MAX_AUTO_INIT_X1024. */

/*! @brief Read current value of the DDRC_INIT5_MAX_AUTO_INIT_X1024 field. */
#define BR_DDRC_INIT5_MAX_AUTO_INIT_X1024(x) (HW_DDRC_INIT5(x).B.MAX_AUTO_INIT_X1024)

/*! @brief Format value for bitfield DDRC_INIT5_MAX_AUTO_INIT_X1024. */
#define BF_DDRC_INIT5_MAX_AUTO_INIT_X1024(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_INIT5_MAX_AUTO_INIT_X1024) & BM_DDRC_INIT5_MAX_AUTO_INIT_X1024)

/*! @brief Set the MAX_AUTO_INIT_X1024 field to a new value. */
#define BW_DDRC_INIT5_MAX_AUTO_INIT_X1024(x, v) (HW_DDRC_INIT5_WR(x, (HW_DDRC_INIT5_RD(x) & ~BM_DDRC_INIT5_MAX_AUTO_INIT_X1024) | BF_DDRC_INIT5_MAX_AUTO_INIT_X1024(v)))
/*@}*/

/*!
 * @name Register DDRC_INIT5, field DEV_ZQINIT_X32[23:16] (RW)
 *
 * ZQ initial calibration, tZQINIT. Present only in designs configured to
 * support DDR3 or LPDDR2 / LPDDR3. Unit: 32 clock cycles. DDR3 typically requires 512
 * clocks. LPDDR2 / LPDDR3 requires 1 us. Value After Reset: 0x10 Exists:
 * MEMC_DDR3 == 1 || MEMC_LPDDR2 == 1
 */
/*@{*/
#define BP_DDRC_INIT5_DEV_ZQINIT_X32 (16U) /*!< Bit position for DDRC_INIT5_DEV_ZQINIT_X32. */
#define BM_DDRC_INIT5_DEV_ZQINIT_X32 (0x00FF0000U) /*!< Bit mask for DDRC_INIT5_DEV_ZQINIT_X32. */
#define BS_DDRC_INIT5_DEV_ZQINIT_X32 (8U)  /*!< Bit field size in bits for DDRC_INIT5_DEV_ZQINIT_X32. */

/*! @brief Read current value of the DDRC_INIT5_DEV_ZQINIT_X32 field. */
#define BR_DDRC_INIT5_DEV_ZQINIT_X32(x) (HW_DDRC_INIT5(x).B.DEV_ZQINIT_X32)

/*! @brief Format value for bitfield DDRC_INIT5_DEV_ZQINIT_X32. */
#define BF_DDRC_INIT5_DEV_ZQINIT_X32(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_INIT5_DEV_ZQINIT_X32) & BM_DDRC_INIT5_DEV_ZQINIT_X32)

/*! @brief Set the DEV_ZQINIT_X32 field to a new value. */
#define BW_DDRC_INIT5_DEV_ZQINIT_X32(x, v) (HW_DDRC_INIT5_WR(x, (HW_DDRC_INIT5_RD(x) & ~BM_DDRC_INIT5_DEV_ZQINIT_X32) | BF_DDRC_INIT5_DEV_ZQINIT_X32(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_RANKCTL - Rank Control Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_RANKCTL - Rank Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: MEMC_NUM_RANKs > 1
 */
typedef union _hw_ddrc_rankctl
{
    uint32_t U;
    struct _hw_ddrc_rankctl_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t DIFF_RANK_RD_GAP : 4; /*!< [7:4]  */
        uint32_t DIFF_RANK_WR_GAP : 4; /*!< [11:8]  */
        uint32_t RESERVED1 : 20;       /*!< [31:12]  */
    } B;
} hw_ddrc_rankctl_t;

/*!
 * @name Constants and macros for entire DDRC_RANKCTL register
 */
/*@{*/
#define HW_DDRC_RANKCTL_ADDR(x)  ((uintptr_t)(x) + 0xF4U)

#define HW_DDRC_RANKCTL(x)       (*(__IO hw_ddrc_rankctl_t *) HW_DDRC_RANKCTL_ADDR(x))
#define HW_DDRC_RANKCTL_RD(x)    (HW_DDRC_RANKCTL(x).U)
#define HW_DDRC_RANKCTL_WR(x, v) (HW_DDRC_RANKCTL(x).U = (v))
#define HW_DDRC_RANKCTL_SET(x, v) (HW_DDRC_RANKCTL_WR(x, HW_DDRC_RANKCTL_RD(x) |  (v)))
#define HW_DDRC_RANKCTL_CLR(x, v) (HW_DDRC_RANKCTL_WR(x, HW_DDRC_RANKCTL_RD(x) & ~(v)))
#define HW_DDRC_RANKCTL_TOG(x, v) (HW_DDRC_RANKCTL_WR(x, HW_DDRC_RANKCTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_RANKCTL bitfields
 */

/*!
 * @name Register DDRC_RANKCTL, field DIFF_RANK_RD_GAP[7:4] (RW)
 *
 * Description: Only present for multi-rank configurations. Indicates the number
 * of clocks of gap in data responses when performing consecutive reads to
 * different ranks. This is used to switch the delays in the PHY to match the rank
 * requirements. The value programmed in this register takes care of the ODT switch
 * off timing requirement when switching ranks during reads. For configurations
 * with MEMC_FREQ_RATIO = 2, program this to (N / 2) and round it up to the next
 * integer value. N is value required by PHY, in terms of PHY clocks. If read
 * preamble is set to 2tCK (DDR4 only), it increases by 1. For configuration with
 * MEMC_FREQ_RATIO = 1, program this to N + 1. For configuration with
 * MEMC_FREQ_RATIO = 2, program this to ((N + 10 / 2) and round it up to the next integer
 * value. Value After Reset: 0x6 Exists: MEMC_NUM_RANKS > 1
 */
/*@{*/
#define BP_DDRC_RANKCTL_DIFF_RANK_RD_GAP (4U) /*!< Bit position for DDRC_RANKCTL_DIFF_RANK_RD_GAP. */
#define BM_DDRC_RANKCTL_DIFF_RANK_RD_GAP (0x000000F0U) /*!< Bit mask for DDRC_RANKCTL_DIFF_RANK_RD_GAP. */
#define BS_DDRC_RANKCTL_DIFF_RANK_RD_GAP (4U) /*!< Bit field size in bits for DDRC_RANKCTL_DIFF_RANK_RD_GAP. */

/*! @brief Read current value of the DDRC_RANKCTL_DIFF_RANK_RD_GAP field. */
#define BR_DDRC_RANKCTL_DIFF_RANK_RD_GAP(x) (HW_DDRC_RANKCTL(x).B.DIFF_RANK_RD_GAP)

/*! @brief Format value for bitfield DDRC_RANKCTL_DIFF_RANK_RD_GAP. */
#define BF_DDRC_RANKCTL_DIFF_RANK_RD_GAP(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_RANKCTL_DIFF_RANK_RD_GAP) & BM_DDRC_RANKCTL_DIFF_RANK_RD_GAP)

/*! @brief Set the DIFF_RANK_RD_GAP field to a new value. */
#define BW_DDRC_RANKCTL_DIFF_RANK_RD_GAP(x, v) (HW_DDRC_RANKCTL_WR(x, (HW_DDRC_RANKCTL_RD(x) & ~BM_DDRC_RANKCTL_DIFF_RANK_RD_GAP) | BF_DDRC_RANKCTL_DIFF_RANK_RD_GAP(v)))
/*@}*/

/*!
 * @name Register DDRC_RANKCTL, field DIFF_RANK_WR_GAP[11:8] (RW)
 *
 * Description: Only present for multi-rank configurations. Indicates the number
 * of clocks of gap in data responses when performing consecutive writes to
 * different ranks. This is used to switch the delays in the PHY to match the rank
 * requirements. The value programmed in this register takes care of the ODT switch
 * off timing requirement when switching ranks during writes. For configurations
 * with MEMC_FREQ_RATIO = 2, program this to (N / 2) and round it up to the next
 * integer value. N is value required by PHY, in terms of PHY clocks. If write
 * preamble is set to 2tCK (DDR4 only), it increases by 1. For configurations with
 * MEMC_FREQ_RATIO = 1, program this to N + 1. For configurations with
 * MEMC_FREQ_RATIO = 2, program this to ((N + 1) / 2) and round it up to the next integer
 * value. Value After Reset: 0x6 Exists: MEMC_NUM_RANKS > 1
 */
/*@{*/
#define BP_DDRC_RANKCTL_DIFF_RANK_WR_GAP (8U) /*!< Bit position for DDRC_RANKCTL_DIFF_RANK_WR_GAP. */
#define BM_DDRC_RANKCTL_DIFF_RANK_WR_GAP (0x00000F00U) /*!< Bit mask for DDRC_RANKCTL_DIFF_RANK_WR_GAP. */
#define BS_DDRC_RANKCTL_DIFF_RANK_WR_GAP (4U) /*!< Bit field size in bits for DDRC_RANKCTL_DIFF_RANK_WR_GAP. */

/*! @brief Read current value of the DDRC_RANKCTL_DIFF_RANK_WR_GAP field. */
#define BR_DDRC_RANKCTL_DIFF_RANK_WR_GAP(x) (HW_DDRC_RANKCTL(x).B.DIFF_RANK_WR_GAP)

/*! @brief Format value for bitfield DDRC_RANKCTL_DIFF_RANK_WR_GAP. */
#define BF_DDRC_RANKCTL_DIFF_RANK_WR_GAP(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_RANKCTL_DIFF_RANK_WR_GAP) & BM_DDRC_RANKCTL_DIFF_RANK_WR_GAP)

/*! @brief Set the DIFF_RANK_WR_GAP field to a new value. */
#define BW_DDRC_RANKCTL_DIFF_RANK_WR_GAP(x, v) (HW_DDRC_RANKCTL_WR(x, (HW_DDRC_RANKCTL_RD(x) & ~BM_DDRC_RANKCTL_DIFF_RANK_WR_GAP) | BF_DDRC_RANKCTL_DIFF_RANK_WR_GAP(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DRAMTMG0 - SDRAM Timing Register 0
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DRAMTMG0 - SDRAM Timing Register 0 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_dramtmg0
{
    uint32_t U;
    struct _hw_ddrc_dramtmg0_bitfields
    {
        uint32_t T_RAS_MIN : 6;        /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t T_RAS_MAX : 7;        /*!< [14:8]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t T_FAW : 6;            /*!< [21:16]  */
        uint32_t RESERVED2 : 2;        /*!< [23:22]  */
        uint32_t WR2PRE : 7;           /*!< [30:24] Minimum time between write and
                                        * precharge to same bank */
        uint32_t RESERVED3 : 1;        /*!< [31]  */
    } B;
} hw_ddrc_dramtmg0_t;

/*!
 * @name Constants and macros for entire DDRC_DRAMTMG0 register
 */
/*@{*/
#define HW_DDRC_DRAMTMG0_ADDR(x) ((uintptr_t)(x) + 0x100U)

#define HW_DDRC_DRAMTMG0(x)      (*(__IO hw_ddrc_dramtmg0_t *) HW_DDRC_DRAMTMG0_ADDR(x))
#define HW_DDRC_DRAMTMG0_RD(x)   (HW_DDRC_DRAMTMG0(x).U)
#define HW_DDRC_DRAMTMG0_WR(x, v) (HW_DDRC_DRAMTMG0(x).U = (v))
#define HW_DDRC_DRAMTMG0_SET(x, v) (HW_DDRC_DRAMTMG0_WR(x, HW_DDRC_DRAMTMG0_RD(x) |  (v)))
#define HW_DDRC_DRAMTMG0_CLR(x, v) (HW_DDRC_DRAMTMG0_WR(x, HW_DDRC_DRAMTMG0_RD(x) & ~(v)))
#define HW_DDRC_DRAMTMG0_TOG(x, v) (HW_DDRC_DRAMTMG0_WR(x, HW_DDRC_DRAMTMG0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DRAMTMG0 bitfields
 */

/*!
 * @name Register DDRC_DRAMTMG0, field T_RAS_MIN[5:0] (RW)
 *
 * tRAS (min): Minimum time between activate and precharge to the same bank. For
 * configurations with MEMC_FREQ_RATIO = 2, 1T mode, program this to tRAS(min) /
 * 2. No rounding up. For configurations with MEMC_FREQ_RATIO = 2, 2T mode,
 * program this to (tRAS (min) / 2 + 1). No rounding up of the division operation.
 * Unit: Clocks Value After Reset: 0xf Exists: Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG0_T_RAS_MIN (0U)    /*!< Bit position for DDRC_DRAMTMG0_T_RAS_MIN. */
#define BM_DDRC_DRAMTMG0_T_RAS_MIN (0x0000003FU) /*!< Bit mask for DDRC_DRAMTMG0_T_RAS_MIN. */
#define BS_DDRC_DRAMTMG0_T_RAS_MIN (6U)    /*!< Bit field size in bits for DDRC_DRAMTMG0_T_RAS_MIN. */

/*! @brief Read current value of the DDRC_DRAMTMG0_T_RAS_MIN field. */
#define BR_DDRC_DRAMTMG0_T_RAS_MIN(x) (HW_DDRC_DRAMTMG0(x).B.T_RAS_MIN)

/*! @brief Format value for bitfield DDRC_DRAMTMG0_T_RAS_MIN. */
#define BF_DDRC_DRAMTMG0_T_RAS_MIN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG0_T_RAS_MIN) & BM_DDRC_DRAMTMG0_T_RAS_MIN)

/*! @brief Set the T_RAS_MIN field to a new value. */
#define BW_DDRC_DRAMTMG0_T_RAS_MIN(x, v) (HW_DDRC_DRAMTMG0_WR(x, (HW_DDRC_DRAMTMG0_RD(x) & ~BM_DDRC_DRAMTMG0_T_RAS_MIN) | BF_DDRC_DRAMTMG0_T_RAS_MIN(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG0, field T_RAS_MAX[14:8] (RW)
 *
 * tRAS(max): Maximum time between activate and precharge to same bank. This is
 * the maximum time that a page can be kept open. Minimum value of this register
 * is 1. Zero is invalid. For configurations with MEMC_FREQ_RATIO = 2, program
 * this to (tRAS (max) - 1) / 2. No rounding up. Unit: Multiples of 1024 clocks.
 * Value After Reset: 0x1b Exists: Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG0_T_RAS_MAX (8U)    /*!< Bit position for DDRC_DRAMTMG0_T_RAS_MAX. */
#define BM_DDRC_DRAMTMG0_T_RAS_MAX (0x00007F00U) /*!< Bit mask for DDRC_DRAMTMG0_T_RAS_MAX. */
#define BS_DDRC_DRAMTMG0_T_RAS_MAX (7U)    /*!< Bit field size in bits for DDRC_DRAMTMG0_T_RAS_MAX. */

/*! @brief Read current value of the DDRC_DRAMTMG0_T_RAS_MAX field. */
#define BR_DDRC_DRAMTMG0_T_RAS_MAX(x) (HW_DDRC_DRAMTMG0(x).B.T_RAS_MAX)

/*! @brief Format value for bitfield DDRC_DRAMTMG0_T_RAS_MAX. */
#define BF_DDRC_DRAMTMG0_T_RAS_MAX(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG0_T_RAS_MAX) & BM_DDRC_DRAMTMG0_T_RAS_MAX)

/*! @brief Set the T_RAS_MAX field to a new value. */
#define BW_DDRC_DRAMTMG0_T_RAS_MAX(x, v) (HW_DDRC_DRAMTMG0_WR(x, (HW_DDRC_DRAMTMG0_RD(x) & ~BM_DDRC_DRAMTMG0_T_RAS_MAX) | BF_DDRC_DRAMTMG0_T_RAS_MAX(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG0, field T_FAW[21:16] (RW)
 *
 * tFAW Valid only when 8 or more banks (or banks x bank groups) are present. In
 * 8-bank design, at most 4 banks must be activated in a rolling window of tFAW
 * cycles. For configurations with MEMC_FREQ_RATIO = 2, program this to (tFAW /
 * 2) and round up to next integer value. In a 4-bank design, set this register to
 * 0x1 independent of the MEMC_FREQ_RATIO configuration. Unit: Clocks Value
 * After Reset: 0x10 Exists: Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG0_T_FAW (16U)       /*!< Bit position for DDRC_DRAMTMG0_T_FAW. */
#define BM_DDRC_DRAMTMG0_T_FAW (0x003F0000U) /*!< Bit mask for DDRC_DRAMTMG0_T_FAW. */
#define BS_DDRC_DRAMTMG0_T_FAW (6U)        /*!< Bit field size in bits for DDRC_DRAMTMG0_T_FAW. */

/*! @brief Read current value of the DDRC_DRAMTMG0_T_FAW field. */
#define BR_DDRC_DRAMTMG0_T_FAW(x) (HW_DDRC_DRAMTMG0(x).B.T_FAW)

/*! @brief Format value for bitfield DDRC_DRAMTMG0_T_FAW. */
#define BF_DDRC_DRAMTMG0_T_FAW(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG0_T_FAW) & BM_DDRC_DRAMTMG0_T_FAW)

/*! @brief Set the T_FAW field to a new value. */
#define BW_DDRC_DRAMTMG0_T_FAW(x, v) (HW_DDRC_DRAMTMG0_WR(x, (HW_DDRC_DRAMTMG0_RD(x) & ~BM_DDRC_DRAMTMG0_T_FAW) | BF_DDRC_DRAMTMG0_T_FAW(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG0, field WR2PRE[30:24] (RW)
 *
 * Unit: Clocks Specifications: WL + BL/2 + tWR = approximately 8 cycles + 15 ns
 * = 14 clocks @ 400 MHz and less for lower frequencies where: WL = write
 * latency BL = burst length. This must match the value programmed in the BL bit of the
 * mode register to the SDRAM. BST (burst terminate) is not supported at
 * present. tWR = Write recovery time. This comes directly from the SDRAMspecification.
 * Add one extra cycle for LPDDR2/LPDDR3 for this parameter. For configurations
 * with MEMC_FREQ_RATIO = 2, 1T mode, divide the above value by 2. No rounding up.
 * For configurations with MEMC_FREQ_RATIO = 2, 2T mode, divide the above value
 * by 2 and add 1. No rounding up. Value After Reset: 0xf Exists:Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG0_WR2PRE (24U)      /*!< Bit position for DDRC_DRAMTMG0_WR2PRE. */
#define BM_DDRC_DRAMTMG0_WR2PRE (0x7F000000U) /*!< Bit mask for DDRC_DRAMTMG0_WR2PRE. */
#define BS_DDRC_DRAMTMG0_WR2PRE (7U)       /*!< Bit field size in bits for DDRC_DRAMTMG0_WR2PRE. */

/*! @brief Read current value of the DDRC_DRAMTMG0_WR2PRE field. */
#define BR_DDRC_DRAMTMG0_WR2PRE(x) (HW_DDRC_DRAMTMG0(x).B.WR2PRE)

/*! @brief Format value for bitfield DDRC_DRAMTMG0_WR2PRE. */
#define BF_DDRC_DRAMTMG0_WR2PRE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG0_WR2PRE) & BM_DDRC_DRAMTMG0_WR2PRE)

/*! @brief Set the WR2PRE field to a new value. */
#define BW_DDRC_DRAMTMG0_WR2PRE(x, v) (HW_DDRC_DRAMTMG0_WR(x, (HW_DDRC_DRAMTMG0_RD(x) & ~BM_DDRC_DRAMTMG0_WR2PRE) | BF_DDRC_DRAMTMG0_WR2PRE(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DRAMTMG1 - SDRAM Timing Register 1
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DRAMTMG1 - SDRAM Timing Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_dramtmg1
{
    uint32_t U;
    struct _hw_ddrc_dramtmg1_bitfields
    {
        uint32_t T_RC : 7;             /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t RD2PRE : 5;           /*!< [12:8]  */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t T_XP : 5;             /*!< [20:16]  */
        uint32_t RESERVED2 : 11;       /*!< [31:21]  */
    } B;
} hw_ddrc_dramtmg1_t;

/*!
 * @name Constants and macros for entire DDRC_DRAMTMG1 register
 */
/*@{*/
#define HW_DDRC_DRAMTMG1_ADDR(x) ((uintptr_t)(x) + 0x104U)

#define HW_DDRC_DRAMTMG1(x)      (*(__IO hw_ddrc_dramtmg1_t *) HW_DDRC_DRAMTMG1_ADDR(x))
#define HW_DDRC_DRAMTMG1_RD(x)   (HW_DDRC_DRAMTMG1(x).U)
#define HW_DDRC_DRAMTMG1_WR(x, v) (HW_DDRC_DRAMTMG1(x).U = (v))
#define HW_DDRC_DRAMTMG1_SET(x, v) (HW_DDRC_DRAMTMG1_WR(x, HW_DDRC_DRAMTMG1_RD(x) |  (v)))
#define HW_DDRC_DRAMTMG1_CLR(x, v) (HW_DDRC_DRAMTMG1_WR(x, HW_DDRC_DRAMTMG1_RD(x) & ~(v)))
#define HW_DDRC_DRAMTMG1_TOG(x, v) (HW_DDRC_DRAMTMG1_WR(x, HW_DDRC_DRAMTMG1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DRAMTMG1 bitfields
 */

/*!
 * @name Register DDRC_DRAMTMG1, field T_RC[6:0] (RW)
 *
 * tRC: Minimumtime between activates to same bank. For configurations with
 * MEMC_FREQ_RATIO = 2, program this to (tRC / 2) and round up to next integer value.
 * Unit: Clocks. Value After Reset: 0x14 Exists: Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG1_T_RC (0U)         /*!< Bit position for DDRC_DRAMTMG1_T_RC. */
#define BM_DDRC_DRAMTMG1_T_RC (0x0000007FU) /*!< Bit mask for DDRC_DRAMTMG1_T_RC. */
#define BS_DDRC_DRAMTMG1_T_RC (7U)         /*!< Bit field size in bits for DDRC_DRAMTMG1_T_RC. */

/*! @brief Read current value of the DDRC_DRAMTMG1_T_RC field. */
#define BR_DDRC_DRAMTMG1_T_RC(x) (HW_DDRC_DRAMTMG1(x).B.T_RC)

/*! @brief Format value for bitfield DDRC_DRAMTMG1_T_RC. */
#define BF_DDRC_DRAMTMG1_T_RC(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG1_T_RC) & BM_DDRC_DRAMTMG1_T_RC)

/*! @brief Set the T_RC field to a new value. */
#define BW_DDRC_DRAMTMG1_T_RC(x, v) (HW_DDRC_DRAMTMG1_WR(x, (HW_DDRC_DRAMTMG1_RD(x) & ~BM_DDRC_DRAMTMG1_T_RC) | BF_DDRC_DRAMTMG1_T_RC(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG1, field RD2PRE[12:8] (RW)
 *
 * tRTP: Minimum time from read to precharge of same bank. DDR3: tAL + max
 * (tRTP, 4) DDR4: Max of following two equations: tAL + max (tRTP, 4) or, RL + BL / 2
 * - tRP. LPDDR2: Depends on if it's LPDDR2-S2 or LPDDR2-S4: LPDDR3: BL / 2 +
 * max (tRTP, 4) - 4 For configurations with MEMC_FREQ_RATIO = 2, divide the above
 * value by 2. No rounding up. Unit: Clocks. Value After Reset: 0x4 Exists: Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG1_RD2PRE (8U)       /*!< Bit position for DDRC_DRAMTMG1_RD2PRE. */
#define BM_DDRC_DRAMTMG1_RD2PRE (0x00001F00U) /*!< Bit mask for DDRC_DRAMTMG1_RD2PRE. */
#define BS_DDRC_DRAMTMG1_RD2PRE (5U)       /*!< Bit field size in bits for DDRC_DRAMTMG1_RD2PRE. */

/*! @brief Read current value of the DDRC_DRAMTMG1_RD2PRE field. */
#define BR_DDRC_DRAMTMG1_RD2PRE(x) (HW_DDRC_DRAMTMG1(x).B.RD2PRE)

/*! @brief Format value for bitfield DDRC_DRAMTMG1_RD2PRE. */
#define BF_DDRC_DRAMTMG1_RD2PRE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG1_RD2PRE) & BM_DDRC_DRAMTMG1_RD2PRE)

/*! @brief Set the RD2PRE field to a new value. */
#define BW_DDRC_DRAMTMG1_RD2PRE(x, v) (HW_DDRC_DRAMTMG1_WR(x, (HW_DDRC_DRAMTMG1_RD(x) & ~BM_DDRC_DRAMTMG1_RD2PRE) | BF_DDRC_DRAMTMG1_RD2PRE(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG1, field T_XP[20:16] (RW)
 *
 * tXP: Minimum time after power-down exit to any operation. For DDR3, this
 * should be programmed to tXPDLL if slow powerdown exit is selected in MR0[12].
 * Units: Clocks Value After Reset: 0x8 Exists: Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG1_T_XP (16U)        /*!< Bit position for DDRC_DRAMTMG1_T_XP. */
#define BM_DDRC_DRAMTMG1_T_XP (0x001F0000U) /*!< Bit mask for DDRC_DRAMTMG1_T_XP. */
#define BS_DDRC_DRAMTMG1_T_XP (5U)         /*!< Bit field size in bits for DDRC_DRAMTMG1_T_XP. */

/*! @brief Read current value of the DDRC_DRAMTMG1_T_XP field. */
#define BR_DDRC_DRAMTMG1_T_XP(x) (HW_DDRC_DRAMTMG1(x).B.T_XP)

/*! @brief Format value for bitfield DDRC_DRAMTMG1_T_XP. */
#define BF_DDRC_DRAMTMG1_T_XP(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG1_T_XP) & BM_DDRC_DRAMTMG1_T_XP)

/*! @brief Set the T_XP field to a new value. */
#define BW_DDRC_DRAMTMG1_T_XP(x, v) (HW_DDRC_DRAMTMG1_WR(x, (HW_DDRC_DRAMTMG1_RD(x) & ~BM_DDRC_DRAMTMG1_T_XP) | BF_DDRC_DRAMTMG1_T_XP(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DRAMTMG2 - SDRAM Timing Register 2
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DRAMTMG2 - SDRAM Timing Register 2 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_dramtmg2
{
    uint32_t U;
    struct _hw_ddrc_dramtmg2_bitfields
    {
        uint32_t WR2RD : 6;            /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t RD2WR : 6;            /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t READ_LATENCY : 6;     /*!< [21:16] Set to RL */
        uint32_t RESERVED2 : 2;        /*!< [23:22]  */
        uint32_t WRITE_LATENCY : 6;    /*!< [29:24] Set to WL */
        uint32_t RESERVED3 : 2;        /*!< [31:30]  */
    } B;
} hw_ddrc_dramtmg2_t;

/*!
 * @name Constants and macros for entire DDRC_DRAMTMG2 register
 */
/*@{*/
#define HW_DDRC_DRAMTMG2_ADDR(x) ((uintptr_t)(x) + 0x108U)

#define HW_DDRC_DRAMTMG2(x)      (*(__IO hw_ddrc_dramtmg2_t *) HW_DDRC_DRAMTMG2_ADDR(x))
#define HW_DDRC_DRAMTMG2_RD(x)   (HW_DDRC_DRAMTMG2(x).U)
#define HW_DDRC_DRAMTMG2_WR(x, v) (HW_DDRC_DRAMTMG2(x).U = (v))
#define HW_DDRC_DRAMTMG2_SET(x, v) (HW_DDRC_DRAMTMG2_WR(x, HW_DDRC_DRAMTMG2_RD(x) |  (v)))
#define HW_DDRC_DRAMTMG2_CLR(x, v) (HW_DDRC_DRAMTMG2_WR(x, HW_DDRC_DRAMTMG2_RD(x) & ~(v)))
#define HW_DDRC_DRAMTMG2_TOG(x, v) (HW_DDRC_DRAMTMG2_WR(x, HW_DDRC_DRAMTMG2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DRAMTMG2 bitfields
 */

/*!
 * @name Register DDRC_DRAMTMG2, field WR2RD[5:0] (RW)
 *
 * DDR4: CWL + PL + BL / 2 + tWTR_L Others: CWL + BL / 2 + tWTR In DDR4, minimum
 * time from write command to read command for same bank group. In others,
 * minimum time from write command to read command. Includes time for bus turnaround,
 * recovery times, and all per-bank, per-rank, and global constraints. Unit:
 * Clocks. Where: CWL = CAS write latency PL = Parity latency BL = Burst length. This
 * must match the value programmed in the BL bit of the mode register to the
 * SDRAM. tWTR_L = Internal write to read command delay for same bank group. This
 * comes directly from the SDRAM specification. tWTR = Internal write to read
 * command delay. This comes directly from the SDRAM specification. Add one extra
 * cycle for LPDDR2 / LPDDR3 operation. For configurations with MEMC_FREQ_RATIO = 2,
 * divide the value calculated using the above equation by 2, and round it up to
 * next integer. Value After Reset: 0xd Exists: Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG2_WR2RD (0U)        /*!< Bit position for DDRC_DRAMTMG2_WR2RD. */
#define BM_DDRC_DRAMTMG2_WR2RD (0x0000003FU) /*!< Bit mask for DDRC_DRAMTMG2_WR2RD. */
#define BS_DDRC_DRAMTMG2_WR2RD (6U)        /*!< Bit field size in bits for DDRC_DRAMTMG2_WR2RD. */

/*! @brief Read current value of the DDRC_DRAMTMG2_WR2RD field. */
#define BR_DDRC_DRAMTMG2_WR2RD(x) (HW_DDRC_DRAMTMG2(x).B.WR2RD)

/*! @brief Format value for bitfield DDRC_DRAMTMG2_WR2RD. */
#define BF_DDRC_DRAMTMG2_WR2RD(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG2_WR2RD) & BM_DDRC_DRAMTMG2_WR2RD)

/*! @brief Set the WR2RD field to a new value. */
#define BW_DDRC_DRAMTMG2_WR2RD(x, v) (HW_DDRC_DRAMTMG2_WR(x, (HW_DDRC_DRAMTMG2_RD(x) & ~BM_DDRC_DRAMTMG2_WR2RD) | BF_DDRC_DRAMTMG2_WR2RD(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG2, field RD2WR[13:8] (RW)
 *
 * DDR2/3/mDDR: RL + BL / 2 - WL DDR4: RL + BL / 2 + 1 +WR_PREAMBLE - WL
 * LPDDR2/LPDDR3: RL + BL / 2 + RU (tDQSCKmax / tCK) + 1 - WL. Minimum time from read
 * command to write command. Include time for bus turnaround and all per-bank,
 * per-rank, and global constraints. Unit: Clocks. Where WL = write latency BL =
 * burst length. This must match the value programmed in the BL bit of the mode
 * register to the SDRAM. RL = read latency = CAS latency WR_PREAMBLE = write
 * preamble. This is unique to DDR4. For configurations with MEMC_FREQ_RATIO = 2, divide
 * the value calculated using the above equation by 2, and round it up to next
 * integer. Value After Reset: 0x6 Exists: Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG2_RD2WR (8U)        /*!< Bit position for DDRC_DRAMTMG2_RD2WR. */
#define BM_DDRC_DRAMTMG2_RD2WR (0x00003F00U) /*!< Bit mask for DDRC_DRAMTMG2_RD2WR. */
#define BS_DDRC_DRAMTMG2_RD2WR (6U)        /*!< Bit field size in bits for DDRC_DRAMTMG2_RD2WR. */

/*! @brief Read current value of the DDRC_DRAMTMG2_RD2WR field. */
#define BR_DDRC_DRAMTMG2_RD2WR(x) (HW_DDRC_DRAMTMG2(x).B.RD2WR)

/*! @brief Format value for bitfield DDRC_DRAMTMG2_RD2WR. */
#define BF_DDRC_DRAMTMG2_RD2WR(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG2_RD2WR) & BM_DDRC_DRAMTMG2_RD2WR)

/*! @brief Set the RD2WR field to a new value. */
#define BW_DDRC_DRAMTMG2_RD2WR(x, v) (HW_DDRC_DRAMTMG2_WR(x, (HW_DDRC_DRAMTMG2_RD(x) & ~BM_DDRC_DRAMTMG2_RD2WR) | BF_DDRC_DRAMTMG2_RD2WR(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG2, field READ_LATENCY[21:16] (RW)
 *
 * Time from read command to read data on SDRAM interface.This must be set to
 * RL. Depending on the PHY, if using RDIMM, it may be necessary to use a value of
 * RL + 1 to compensate for the extra cycle of latency through the RDIMM. For
 * configurations with MEMC_FREQ_RATIO = 2, divide the value calculated using the
 * above equation by 2, and round it up to next integer. This register field is not
 * required for DDR2 and DDR3 as the DFI read and write latencies defined in
 * DFITMG0 and DFITMG1 are sufficient for those protocols Unit: clocks Value After
 * Reset: 0x5 Exists: MEMC_MOBILE==1 || MEMC_LPDDR2==1 || MEMC_DDR4==1 ||
 * MEMC_TRAINING==1
 */
/*@{*/
#define BP_DDRC_DRAMTMG2_READ_LATENCY (16U) /*!< Bit position for DDRC_DRAMTMG2_READ_LATENCY. */
#define BM_DDRC_DRAMTMG2_READ_LATENCY (0x003F0000U) /*!< Bit mask for DDRC_DRAMTMG2_READ_LATENCY. */
#define BS_DDRC_DRAMTMG2_READ_LATENCY (6U) /*!< Bit field size in bits for DDRC_DRAMTMG2_READ_LATENCY. */

/*! @brief Read current value of the DDRC_DRAMTMG2_READ_LATENCY field. */
#define BR_DDRC_DRAMTMG2_READ_LATENCY(x) (HW_DDRC_DRAMTMG2(x).B.READ_LATENCY)

/*! @brief Format value for bitfield DDRC_DRAMTMG2_READ_LATENCY. */
#define BF_DDRC_DRAMTMG2_READ_LATENCY(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG2_READ_LATENCY) & BM_DDRC_DRAMTMG2_READ_LATENCY)

/*! @brief Set the READ_LATENCY field to a new value. */
#define BW_DDRC_DRAMTMG2_READ_LATENCY(x, v) (HW_DDRC_DRAMTMG2_WR(x, (HW_DDRC_DRAMTMG2_RD(x) & ~BM_DDRC_DRAMTMG2_READ_LATENCY) | BF_DDRC_DRAMTMG2_READ_LATENCY(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG2, field WRITE_LATENCY[29:24] (RW)
 *
 * Time from write command to write data on SDRAMinterface. This must be set to
 * WL. Note that, depending on the PHY, if using RDIMM, it may be necessary to
 * use a value of WL + 1 to compensate for the extra cycle of latency through the
 * RDIMM For configurations with MEMC_FREQ_RATIO = 2, divide the value calculated
 * using the above equation by 2, and round it up to next integer. This register
 * field is not required for DDR3 as the DFI read and write latencies defined in
 * DFITMG0 and DFITMG1 are sufficient for those protocols. Unit: clocks Value
 * After Reset: 0x3 Exists: MEMC_MOBILE==1 || MEMC_LPDDR2==1 || MEMC_DDR4==1 ||
 * MEMC_TRAINING==1
 */
/*@{*/
#define BP_DDRC_DRAMTMG2_WRITE_LATENCY (24U) /*!< Bit position for DDRC_DRAMTMG2_WRITE_LATENCY. */
#define BM_DDRC_DRAMTMG2_WRITE_LATENCY (0x3F000000U) /*!< Bit mask for DDRC_DRAMTMG2_WRITE_LATENCY. */
#define BS_DDRC_DRAMTMG2_WRITE_LATENCY (6U) /*!< Bit field size in bits for DDRC_DRAMTMG2_WRITE_LATENCY. */

/*! @brief Read current value of the DDRC_DRAMTMG2_WRITE_LATENCY field. */
#define BR_DDRC_DRAMTMG2_WRITE_LATENCY(x) (HW_DDRC_DRAMTMG2(x).B.WRITE_LATENCY)

/*! @brief Format value for bitfield DDRC_DRAMTMG2_WRITE_LATENCY. */
#define BF_DDRC_DRAMTMG2_WRITE_LATENCY(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG2_WRITE_LATENCY) & BM_DDRC_DRAMTMG2_WRITE_LATENCY)

/*! @brief Set the WRITE_LATENCY field to a new value. */
#define BW_DDRC_DRAMTMG2_WRITE_LATENCY(x, v) (HW_DDRC_DRAMTMG2_WR(x, (HW_DDRC_DRAMTMG2_RD(x) & ~BM_DDRC_DRAMTMG2_WRITE_LATENCY) | BF_DDRC_DRAMTMG2_WRITE_LATENCY(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DRAMTMG3 - SDRAM Timing Register 3
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DRAMTMG3 - SDRAM Timing Register 3 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_dramtmg3
{
    uint32_t U;
    struct _hw_ddrc_dramtmg3_bitfields
    {
        uint32_t T_MOD : 10;           /*!< [9:0]  */
        uint32_t RESERVED0 : 2;        /*!< [11:10]  */
        uint32_t T_MRD : 6;            /*!< [17:12]  */
        uint32_t RESERVED1 : 2;        /*!< [19:18]  */
        uint32_t T_MRW : 10;           /*!< [29:20]  */
        uint32_t RESERVED2 : 2;        /*!< [31:30]  */
    } B;
} hw_ddrc_dramtmg3_t;

/*!
 * @name Constants and macros for entire DDRC_DRAMTMG3 register
 */
/*@{*/
#define HW_DDRC_DRAMTMG3_ADDR(x) ((uintptr_t)(x) + 0x10CU)

#define HW_DDRC_DRAMTMG3(x)      (*(__IO hw_ddrc_dramtmg3_t *) HW_DDRC_DRAMTMG3_ADDR(x))
#define HW_DDRC_DRAMTMG3_RD(x)   (HW_DDRC_DRAMTMG3(x).U)
#define HW_DDRC_DRAMTMG3_WR(x, v) (HW_DDRC_DRAMTMG3(x).U = (v))
#define HW_DDRC_DRAMTMG3_SET(x, v) (HW_DDRC_DRAMTMG3_WR(x, HW_DDRC_DRAMTMG3_RD(x) |  (v)))
#define HW_DDRC_DRAMTMG3_CLR(x, v) (HW_DDRC_DRAMTMG3_WR(x, HW_DDRC_DRAMTMG3_RD(x) & ~(v)))
#define HW_DDRC_DRAMTMG3_TOG(x, v) (HW_DDRC_DRAMTMG3_WR(x, HW_DDRC_DRAMTMG3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DRAMTMG3 bitfields
 */

/*!
 * @name Register DDRC_DRAMTMG3, field T_MOD[9:0] (RW)
 *
 * tMOD: Present if MEMC_DDR3_OR_4 = 1. Cycles between loadmode command and
 * following non-load mode command. This is required to be programmed even when a
 * design that supports DDR3 / DDR4 is running in DDR2 mode. Set to tMOD if
 * MEMC_FREQ_RATIO = 1, or tMOD / 2 (rounded up to next integer) if MEMC_FREQ_RATIO = 2.
 * Note that if using RDIMM, depending on the PHY, it may be necessary to use a
 * value of tMOD + 1 or (tMOD + 1) / 2 to compensate for the extra cycle of
 * latency applied to mode register writes by the RDIMM chip. Value After Reset:
 * (MEMC_DDR3 == 1 ) ? 0xc : 0x0 Exists: MEMC_DDR3 == 1
 */
/*@{*/
#define BP_DDRC_DRAMTMG3_T_MOD (0U)        /*!< Bit position for DDRC_DRAMTMG3_T_MOD. */
#define BM_DDRC_DRAMTMG3_T_MOD (0x000003FFU) /*!< Bit mask for DDRC_DRAMTMG3_T_MOD. */
#define BS_DDRC_DRAMTMG3_T_MOD (10U)       /*!< Bit field size in bits for DDRC_DRAMTMG3_T_MOD. */

/*! @brief Read current value of the DDRC_DRAMTMG3_T_MOD field. */
#define BR_DDRC_DRAMTMG3_T_MOD(x) (HW_DDRC_DRAMTMG3(x).B.T_MOD)

/*! @brief Format value for bitfield DDRC_DRAMTMG3_T_MOD. */
#define BF_DDRC_DRAMTMG3_T_MOD(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG3_T_MOD) & BM_DDRC_DRAMTMG3_T_MOD)

/*! @brief Set the T_MOD field to a new value. */
#define BW_DDRC_DRAMTMG3_T_MOD(x, v) (HW_DDRC_DRAMTMG3_WR(x, (HW_DDRC_DRAMTMG3_RD(x) & ~BM_DDRC_DRAMTMG3_T_MOD) | BF_DDRC_DRAMTMG3_T_MOD(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG3, field T_MRD[17:12] (RW)
 *
 * tMRD: Cycles between loadmode commands. If MEMC_DDR3 = 0, this parameter is
 * also used to define the cycles between load mode command and following non-load
 * mode command. For configurations with MEMC_FREQ_RATIO = 2, program this to
 * (tMRD / 2) and round it up to the next integer value. If C/A parity for DDR4 is
 * used, set to tMRD_PAR (tMOD + PL) instead. Value After Reset: 0x4 Exists:
 * Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG3_T_MRD (12U)       /*!< Bit position for DDRC_DRAMTMG3_T_MRD. */
#define BM_DDRC_DRAMTMG3_T_MRD (0x0003F000U) /*!< Bit mask for DDRC_DRAMTMG3_T_MRD. */
#define BS_DDRC_DRAMTMG3_T_MRD (6U)        /*!< Bit field size in bits for DDRC_DRAMTMG3_T_MRD. */

/*! @brief Read current value of the DDRC_DRAMTMG3_T_MRD field. */
#define BR_DDRC_DRAMTMG3_T_MRD(x) (HW_DDRC_DRAMTMG3(x).B.T_MRD)

/*! @brief Format value for bitfield DDRC_DRAMTMG3_T_MRD. */
#define BF_DDRC_DRAMTMG3_T_MRD(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG3_T_MRD) & BM_DDRC_DRAMTMG3_T_MRD)

/*! @brief Set the T_MRD field to a new value. */
#define BW_DDRC_DRAMTMG3_T_MRD(x, v) (HW_DDRC_DRAMTMG3_WR(x, (HW_DDRC_DRAMTMG3_RD(x) & ~BM_DDRC_DRAMTMG3_T_MRD) | BF_DDRC_DRAMTMG3_T_MRD(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG3, field T_MRW[29:20] (RW)
 *
 * Time to wait after a mode register write or read (MRW or MRR). Present only
 * in designs configured to support LPDDR2 / LPDDR3. LPDDR2 typically requires
 * value of 5. LPDDR3 typically requires value of 10. Value After Reset:
 * (MEMC_LPDDR2 == 1) ? 0x5 : 0x0 Exists: MEMC_LPDDR2 == 1
 */
/*@{*/
#define BP_DDRC_DRAMTMG3_T_MRW (20U)       /*!< Bit position for DDRC_DRAMTMG3_T_MRW. */
#define BM_DDRC_DRAMTMG3_T_MRW (0x3FF00000U) /*!< Bit mask for DDRC_DRAMTMG3_T_MRW. */
#define BS_DDRC_DRAMTMG3_T_MRW (10U)       /*!< Bit field size in bits for DDRC_DRAMTMG3_T_MRW. */

/*! @brief Read current value of the DDRC_DRAMTMG3_T_MRW field. */
#define BR_DDRC_DRAMTMG3_T_MRW(x) (HW_DDRC_DRAMTMG3(x).B.T_MRW)

/*! @brief Format value for bitfield DDRC_DRAMTMG3_T_MRW. */
#define BF_DDRC_DRAMTMG3_T_MRW(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG3_T_MRW) & BM_DDRC_DRAMTMG3_T_MRW)

/*! @brief Set the T_MRW field to a new value. */
#define BW_DDRC_DRAMTMG3_T_MRW(x, v) (HW_DDRC_DRAMTMG3_WR(x, (HW_DDRC_DRAMTMG3_RD(x) & ~BM_DDRC_DRAMTMG3_T_MRW) | BF_DDRC_DRAMTMG3_T_MRW(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DRAMTMG4 - SDRAM Timing Register 4
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DRAMTMG4 - SDRAM Timing Register 4 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: Always
 */
typedef union _hw_ddrc_dramtmg4
{
    uint32_t U;
    struct _hw_ddrc_dramtmg4_bitfields
    {
        uint32_t T_RP : 5;             /*!< [4:0]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t T_RRD : 4;            /*!< [11:8]  */
        uint32_t RESERVED1 : 4;        /*!< [15:12]  */
        uint32_t T_CCD : 4;            /*!< [19:16]  */
        uint32_t RESERVED2 : 4;        /*!< [23:20]  */
        uint32_t T_RCD : 5;            /*!< [28:24]  */
        uint32_t RESERVED3 : 3;        /*!< [31:29]  */
    } B;
} hw_ddrc_dramtmg4_t;

/*!
 * @name Constants and macros for entire DDRC_DRAMTMG4 register
 */
/*@{*/
#define HW_DDRC_DRAMTMG4_ADDR(x) ((uintptr_t)(x) + 0x110U)

#define HW_DDRC_DRAMTMG4(x)      (*(__IO hw_ddrc_dramtmg4_t *) HW_DDRC_DRAMTMG4_ADDR(x))
#define HW_DDRC_DRAMTMG4_RD(x)   (HW_DDRC_DRAMTMG4(x).U)
#define HW_DDRC_DRAMTMG4_WR(x, v) (HW_DDRC_DRAMTMG4(x).U = (v))
#define HW_DDRC_DRAMTMG4_SET(x, v) (HW_DDRC_DRAMTMG4_WR(x, HW_DDRC_DRAMTMG4_RD(x) |  (v)))
#define HW_DDRC_DRAMTMG4_CLR(x, v) (HW_DDRC_DRAMTMG4_WR(x, HW_DDRC_DRAMTMG4_RD(x) & ~(v)))
#define HW_DDRC_DRAMTMG4_TOG(x, v) (HW_DDRC_DRAMTMG4_WR(x, HW_DDRC_DRAMTMG4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DRAMTMG4 bitfields
 */

/*!
 * @name Register DDRC_DRAMTMG4, field T_RP[4:0] (RW)
 *
 * tRP: Minimum time from precharge to activate of same bank For MEMC_FREQ_RATIO
 * = 1 configurations, t_rp should be set to RoundUp (tRP / tCK). For
 * MEMC_FREQ_RATIO = 2 configurations, t_rp should be set to RoundDown (RoundUp (tRP / tCK)
 * / 2) + 1. Unit: Clocks Value After Reset:0x5 Exists:Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG4_T_RP (0U)         /*!< Bit position for DDRC_DRAMTMG4_T_RP. */
#define BM_DDRC_DRAMTMG4_T_RP (0x0000001FU) /*!< Bit mask for DDRC_DRAMTMG4_T_RP. */
#define BS_DDRC_DRAMTMG4_T_RP (5U)         /*!< Bit field size in bits for DDRC_DRAMTMG4_T_RP. */

/*! @brief Read current value of the DDRC_DRAMTMG4_T_RP field. */
#define BR_DDRC_DRAMTMG4_T_RP(x) (HW_DDRC_DRAMTMG4(x).B.T_RP)

/*! @brief Format value for bitfield DDRC_DRAMTMG4_T_RP. */
#define BF_DDRC_DRAMTMG4_T_RP(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG4_T_RP) & BM_DDRC_DRAMTMG4_T_RP)

/*! @brief Set the T_RP field to a new value. */
#define BW_DDRC_DRAMTMG4_T_RP(x, v) (HW_DDRC_DRAMTMG4_WR(x, (HW_DDRC_DRAMTMG4_RD(x) & ~BM_DDRC_DRAMTMG4_T_RP) | BF_DDRC_DRAMTMG4_T_RP(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG4, field T_RRD[11:8] (RW)
 *
 * DDR4: tRRD_L: Minimum time between activates from bank a to bank b for same
 * bank group. Others: tRRD: Minimum time between activates from bank a to bank b.
 * For configurations with MEMC_FREQ_RATIO = 2, program this to (tRRD_L / 2 or
 * tRRD / 2) and round it up to the next integer value. Unit: Clocks. Value After
 * Reset: 0x4 Exists: Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG4_T_RRD (8U)        /*!< Bit position for DDRC_DRAMTMG4_T_RRD. */
#define BM_DDRC_DRAMTMG4_T_RRD (0x00000F00U) /*!< Bit mask for DDRC_DRAMTMG4_T_RRD. */
#define BS_DDRC_DRAMTMG4_T_RRD (4U)        /*!< Bit field size in bits for DDRC_DRAMTMG4_T_RRD. */

/*! @brief Read current value of the DDRC_DRAMTMG4_T_RRD field. */
#define BR_DDRC_DRAMTMG4_T_RRD(x) (HW_DDRC_DRAMTMG4(x).B.T_RRD)

/*! @brief Format value for bitfield DDRC_DRAMTMG4_T_RRD. */
#define BF_DDRC_DRAMTMG4_T_RRD(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG4_T_RRD) & BM_DDRC_DRAMTMG4_T_RRD)

/*! @brief Set the T_RRD field to a new value. */
#define BW_DDRC_DRAMTMG4_T_RRD(x, v) (HW_DDRC_DRAMTMG4_WR(x, (HW_DDRC_DRAMTMG4_RD(x) & ~BM_DDRC_DRAMTMG4_T_RRD) | BF_DDRC_DRAMTMG4_T_RRD(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG4, field T_CCD[19:16] (RW)
 *
 * DDR4: tCCD_L: This is the minimum time between two reads or two writes for
 * same bank group. Other: tCCD: This is the minimum time between two reads or two
 * writes. For configurations with MEMC_FREQ_RATIO = 2, program this to (tCCD_L /
 * 2 or tCCD / 2) and round it up to the next integer value. Unit: clocks. Value
 * After Reset: 0x4 Exists: Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG4_T_CCD (16U)       /*!< Bit position for DDRC_DRAMTMG4_T_CCD. */
#define BM_DDRC_DRAMTMG4_T_CCD (0x000F0000U) /*!< Bit mask for DDRC_DRAMTMG4_T_CCD. */
#define BS_DDRC_DRAMTMG4_T_CCD (4U)        /*!< Bit field size in bits for DDRC_DRAMTMG4_T_CCD. */

/*! @brief Read current value of the DDRC_DRAMTMG4_T_CCD field. */
#define BR_DDRC_DRAMTMG4_T_CCD(x) (HW_DDRC_DRAMTMG4(x).B.T_CCD)

/*! @brief Format value for bitfield DDRC_DRAMTMG4_T_CCD. */
#define BF_DDRC_DRAMTMG4_T_CCD(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG4_T_CCD) & BM_DDRC_DRAMTMG4_T_CCD)

/*! @brief Set the T_CCD field to a new value. */
#define BW_DDRC_DRAMTMG4_T_CCD(x, v) (HW_DDRC_DRAMTMG4_WR(x, (HW_DDRC_DRAMTMG4_RD(x) & ~BM_DDRC_DRAMTMG4_T_CCD) | BF_DDRC_DRAMTMG4_T_CCD(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG4, field T_RCD[28:24] (RW)
 *
 * tRCD - tAL: Minimum time from activate to read or write command to same bank.
 * For configurations with MEMC_FREQ_RATIO = 2, program this to ((tRCD - tAL) /
 * 2) and round it up to the next integer value. Minimum value allowed for this
 * register is 1, which implies minimum (tRCD - tAL) value to be 2 in
 * configurations with MEMC_FREQ_RATIO = 2. Unit: Clocks. Value After Reset: 0x5 Exists:
 * Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG4_T_RCD (24U)       /*!< Bit position for DDRC_DRAMTMG4_T_RCD. */
#define BM_DDRC_DRAMTMG4_T_RCD (0x1F000000U) /*!< Bit mask for DDRC_DRAMTMG4_T_RCD. */
#define BS_DDRC_DRAMTMG4_T_RCD (5U)        /*!< Bit field size in bits for DDRC_DRAMTMG4_T_RCD. */

/*! @brief Read current value of the DDRC_DRAMTMG4_T_RCD field. */
#define BR_DDRC_DRAMTMG4_T_RCD(x) (HW_DDRC_DRAMTMG4(x).B.T_RCD)

/*! @brief Format value for bitfield DDRC_DRAMTMG4_T_RCD. */
#define BF_DDRC_DRAMTMG4_T_RCD(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG4_T_RCD) & BM_DDRC_DRAMTMG4_T_RCD)

/*! @brief Set the T_RCD field to a new value. */
#define BW_DDRC_DRAMTMG4_T_RCD(x, v) (HW_DDRC_DRAMTMG4_WR(x, (HW_DDRC_DRAMTMG4_RD(x) & ~BM_DDRC_DRAMTMG4_T_RCD) | BF_DDRC_DRAMTMG4_T_RCD(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DRAMTMG5 - SDRAM Timing Register5
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DRAMTMG5 - SDRAM Timing Register5 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_dramtmg5
{
    uint32_t U;
    struct _hw_ddrc_dramtmg5_bitfields
    {
        uint32_t T_CKE : 5;            /*!< [4:0]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t T_CKESR : 6;          /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t T_CKSRE : 4;          /*!< [19:16]  */
        uint32_t RESERVED2 : 4;        /*!< [23:20]  */
        uint32_t T_CKSRX : 4;          /*!< [27:24]  */
        uint32_t RESERVED3 : 4;        /*!< [31:28]  */
    } B;
} hw_ddrc_dramtmg5_t;

/*!
 * @name Constants and macros for entire DDRC_DRAMTMG5 register
 */
/*@{*/
#define HW_DDRC_DRAMTMG5_ADDR(x) ((uintptr_t)(x) + 0x114U)

#define HW_DDRC_DRAMTMG5(x)      (*(__IO hw_ddrc_dramtmg5_t *) HW_DDRC_DRAMTMG5_ADDR(x))
#define HW_DDRC_DRAMTMG5_RD(x)   (HW_DDRC_DRAMTMG5(x).U)
#define HW_DDRC_DRAMTMG5_WR(x, v) (HW_DDRC_DRAMTMG5(x).U = (v))
#define HW_DDRC_DRAMTMG5_SET(x, v) (HW_DDRC_DRAMTMG5_WR(x, HW_DDRC_DRAMTMG5_RD(x) |  (v)))
#define HW_DDRC_DRAMTMG5_CLR(x, v) (HW_DDRC_DRAMTMG5_WR(x, HW_DDRC_DRAMTMG5_RD(x) & ~(v)))
#define HW_DDRC_DRAMTMG5_TOG(x, v) (HW_DDRC_DRAMTMG5_WR(x, HW_DDRC_DRAMTMG5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DRAMTMG5 bitfields
 */

/*!
 * @name Register DDRC_DRAMTMG5, field T_CKE[4:0] (RW)
 *
 * Minimum number of cycles of CKE HIGH / LOW during power-down and self
 * refresh. LPDDR2 / LPDDR3 mode: Set this to the larger of tCKE or tCKESR Non-LPDDR2 /
 * non-LPDDR3 designs: Set this to tCKE value. For configurations with
 * MEMC_FREQ_RATIO = 2, program this to (value described above) / 2 and round it up to the
 * next integer value. Unit: Clocks. Value After Reset: 0x3 Exists: Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG5_T_CKE (0U)        /*!< Bit position for DDRC_DRAMTMG5_T_CKE. */
#define BM_DDRC_DRAMTMG5_T_CKE (0x0000001FU) /*!< Bit mask for DDRC_DRAMTMG5_T_CKE. */
#define BS_DDRC_DRAMTMG5_T_CKE (5U)        /*!< Bit field size in bits for DDRC_DRAMTMG5_T_CKE. */

/*! @brief Read current value of the DDRC_DRAMTMG5_T_CKE field. */
#define BR_DDRC_DRAMTMG5_T_CKE(x) (HW_DDRC_DRAMTMG5(x).B.T_CKE)

/*! @brief Format value for bitfield DDRC_DRAMTMG5_T_CKE. */
#define BF_DDRC_DRAMTMG5_T_CKE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG5_T_CKE) & BM_DDRC_DRAMTMG5_T_CKE)

/*! @brief Set the T_CKE field to a new value. */
#define BW_DDRC_DRAMTMG5_T_CKE(x, v) (HW_DDRC_DRAMTMG5_WR(x, (HW_DDRC_DRAMTMG5_RD(x) & ~BM_DDRC_DRAMTMG5_T_CKE) | BF_DDRC_DRAMTMG5_T_CKE(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG5, field T_CKESR[13:8] (RW)
 *
 * Minimum CKE low width for Self refresh entry to exit timing in memory clock
 * cycles. Recommended settings: LPDDR2: tCKESR LPDDR3: tCKESR DDR3: tCKE + 1 For
 * configurations with MEMC_FREQ_RATIO = 2, program this to recommended value
 * divided by two and round it up to next integer. Value After Reset: 0x4 Exists:
 * Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG5_T_CKESR (8U)      /*!< Bit position for DDRC_DRAMTMG5_T_CKESR. */
#define BM_DDRC_DRAMTMG5_T_CKESR (0x00003F00U) /*!< Bit mask for DDRC_DRAMTMG5_T_CKESR. */
#define BS_DDRC_DRAMTMG5_T_CKESR (6U)      /*!< Bit field size in bits for DDRC_DRAMTMG5_T_CKESR. */

/*! @brief Read current value of the DDRC_DRAMTMG5_T_CKESR field. */
#define BR_DDRC_DRAMTMG5_T_CKESR(x) (HW_DDRC_DRAMTMG5(x).B.T_CKESR)

/*! @brief Format value for bitfield DDRC_DRAMTMG5_T_CKESR. */
#define BF_DDRC_DRAMTMG5_T_CKESR(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG5_T_CKESR) & BM_DDRC_DRAMTMG5_T_CKESR)

/*! @brief Set the T_CKESR field to a new value. */
#define BW_DDRC_DRAMTMG5_T_CKESR(x, v) (HW_DDRC_DRAMTMG5_WR(x, (HW_DDRC_DRAMTMG5_RD(x) & ~BM_DDRC_DRAMTMG5_T_CKESR) | BF_DDRC_DRAMTMG5_T_CKESR(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG5, field T_CKSRE[19:16] (RW)
 *
 * This is the time after Self Refresh Down Entry that CK is maintained as a
 * valid clock. Specifies the clock disable delay after SRE. Recommended settings:
 * LPDDR2: 2 LPDDR3: 2 DDR3: max (10 ns, 5 tCK) For configurations with
 * MEMC_FREQ_RATIO = 2, program this to recommended value divided by two and round it up to
 * next integer. Value After Reset: 0x5 Exists: Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG5_T_CKSRE (16U)     /*!< Bit position for DDRC_DRAMTMG5_T_CKSRE. */
#define BM_DDRC_DRAMTMG5_T_CKSRE (0x000F0000U) /*!< Bit mask for DDRC_DRAMTMG5_T_CKSRE. */
#define BS_DDRC_DRAMTMG5_T_CKSRE (4U)      /*!< Bit field size in bits for DDRC_DRAMTMG5_T_CKSRE. */

/*! @brief Read current value of the DDRC_DRAMTMG5_T_CKSRE field. */
#define BR_DDRC_DRAMTMG5_T_CKSRE(x) (HW_DDRC_DRAMTMG5(x).B.T_CKSRE)

/*! @brief Format value for bitfield DDRC_DRAMTMG5_T_CKSRE. */
#define BF_DDRC_DRAMTMG5_T_CKSRE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG5_T_CKSRE) & BM_DDRC_DRAMTMG5_T_CKSRE)

/*! @brief Set the T_CKSRE field to a new value. */
#define BW_DDRC_DRAMTMG5_T_CKSRE(x, v) (HW_DDRC_DRAMTMG5_WR(x, (HW_DDRC_DRAMTMG5_RD(x) & ~BM_DDRC_DRAMTMG5_T_CKSRE) | BF_DDRC_DRAMTMG5_T_CKSRE(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG5, field T_CKSRX[27:24] (RW)
 *
 * This is the time before Self Refresh Exit that CK is maintained as a valid
 * clock before issuing SRX. Specifies the clock stable time before SRX.
 * Recommended settings: LPDDR2: 2 LPDDR3: 2 DDR3: tCKSRX For configurations with
 * MEMC_FREQ_RATIO = 2, program this to recommended value divided by two and round it up
 * to next integer. Value After Reset: 0x5 Exists: Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG5_T_CKSRX (24U)     /*!< Bit position for DDRC_DRAMTMG5_T_CKSRX. */
#define BM_DDRC_DRAMTMG5_T_CKSRX (0x0F000000U) /*!< Bit mask for DDRC_DRAMTMG5_T_CKSRX. */
#define BS_DDRC_DRAMTMG5_T_CKSRX (4U)      /*!< Bit field size in bits for DDRC_DRAMTMG5_T_CKSRX. */

/*! @brief Read current value of the DDRC_DRAMTMG5_T_CKSRX field. */
#define BR_DDRC_DRAMTMG5_T_CKSRX(x) (HW_DDRC_DRAMTMG5(x).B.T_CKSRX)

/*! @brief Format value for bitfield DDRC_DRAMTMG5_T_CKSRX. */
#define BF_DDRC_DRAMTMG5_T_CKSRX(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG5_T_CKSRX) & BM_DDRC_DRAMTMG5_T_CKSRX)

/*! @brief Set the T_CKSRX field to a new value. */
#define BW_DDRC_DRAMTMG5_T_CKSRX(x, v) (HW_DDRC_DRAMTMG5_WR(x, (HW_DDRC_DRAMTMG5_RD(x) & ~BM_DDRC_DRAMTMG5_T_CKSRX) | BF_DDRC_DRAMTMG5_T_CKSRX(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DRAMTMG6 - SDRAM Timing Register 6
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DRAMTMG6 - SDRAM Timing Register 6 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: MEMC_MOBILE==1 || MEMC_LPDDR2==1
 */
typedef union _hw_ddrc_dramtmg6
{
    uint32_t U;
    struct _hw_ddrc_dramtmg6_bitfields
    {
        uint32_t T_CKCSX : 4;          /*!< [3:0]  */
        uint32_t RESERVED0 : 12;       /*!< [15:4]  */
        uint32_t T_CKDPDX : 4;         /*!< [19:16]  */
        uint32_t RESERVED1 : 4;        /*!< [23:20]  */
        uint32_t T_CKDPDE : 4;         /*!< [27:24]  */
        uint32_t RESERVED2 : 4;        /*!< [31:28]  */
    } B;
} hw_ddrc_dramtmg6_t;

/*!
 * @name Constants and macros for entire DDRC_DRAMTMG6 register
 */
/*@{*/
#define HW_DDRC_DRAMTMG6_ADDR(x) ((uintptr_t)(x) + 0x118U)

#define HW_DDRC_DRAMTMG6(x)      (*(__IO hw_ddrc_dramtmg6_t *) HW_DDRC_DRAMTMG6_ADDR(x))
#define HW_DDRC_DRAMTMG6_RD(x)   (HW_DDRC_DRAMTMG6(x).U)
#define HW_DDRC_DRAMTMG6_WR(x, v) (HW_DDRC_DRAMTMG6(x).U = (v))
#define HW_DDRC_DRAMTMG6_SET(x, v) (HW_DDRC_DRAMTMG6_WR(x, HW_DDRC_DRAMTMG6_RD(x) |  (v)))
#define HW_DDRC_DRAMTMG6_CLR(x, v) (HW_DDRC_DRAMTMG6_WR(x, HW_DDRC_DRAMTMG6_RD(x) & ~(v)))
#define HW_DDRC_DRAMTMG6_TOG(x, v) (HW_DDRC_DRAMTMG6_WR(x, HW_DDRC_DRAMTMG6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DRAMTMG6 bitfields
 */

/*!
 * @name Register DDRC_DRAMTMG6, field T_CKCSX[3:0] (RW)
 *
 * This is the time before Clock Stop Exit that CK is maintained as a valid
 * clock before issuing Clock Stop Exit. Specifies the clock stable time before next
 * command after Clock Stop Exit. Recommended settings: LPDDR2: tXP + 2 LPDDR3:
 * tXP + 2 For configurations with MEMC_FREQ_RATIO = 2, program this to
 * recommended value divided by two and round it up to next integer. This is only present
 * for designs supporting mDDR or LPDDR2 / LPDDR3 devices. Value After Reset: 0x5
 * Exists:MEMC_LPDDR2 == 1
 */
/*@{*/
#define BP_DDRC_DRAMTMG6_T_CKCSX (0U)      /*!< Bit position for DDRC_DRAMTMG6_T_CKCSX. */
#define BM_DDRC_DRAMTMG6_T_CKCSX (0x0000000FU) /*!< Bit mask for DDRC_DRAMTMG6_T_CKCSX. */
#define BS_DDRC_DRAMTMG6_T_CKCSX (4U)      /*!< Bit field size in bits for DDRC_DRAMTMG6_T_CKCSX. */

/*! @brief Read current value of the DDRC_DRAMTMG6_T_CKCSX field. */
#define BR_DDRC_DRAMTMG6_T_CKCSX(x) (HW_DDRC_DRAMTMG6(x).B.T_CKCSX)

/*! @brief Format value for bitfield DDRC_DRAMTMG6_T_CKCSX. */
#define BF_DDRC_DRAMTMG6_T_CKCSX(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG6_T_CKCSX) & BM_DDRC_DRAMTMG6_T_CKCSX)

/*! @brief Set the T_CKCSX field to a new value. */
#define BW_DDRC_DRAMTMG6_T_CKCSX(x, v) (HW_DDRC_DRAMTMG6_WR(x, (HW_DDRC_DRAMTMG6_RD(x) & ~BM_DDRC_DRAMTMG6_T_CKCSX) | BF_DDRC_DRAMTMG6_T_CKCSX(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG6, field T_CKDPDX[19:16] (RW)
 *
 * This is the time before Deep Power Down Exit that CK is maintained as a valid
 * clock before issuing DPDX. Specifies the clock stable time before DPDX.
 * Recommended settings: LPDDR2: 2 LPDDR3: 2 For configurations with MEMC_FREQ_RATIO =
 * 2, program this to recommended value divided by two and round it up to next
 * integer. This is only present for designs supporting mDDR or LPDDR2 devices.
 * Value After Reset: 0x2 Exists: MEMC_LPDDR2==1
 */
/*@{*/
#define BP_DDRC_DRAMTMG6_T_CKDPDX (16U)    /*!< Bit position for DDRC_DRAMTMG6_T_CKDPDX. */
#define BM_DDRC_DRAMTMG6_T_CKDPDX (0x000F0000U) /*!< Bit mask for DDRC_DRAMTMG6_T_CKDPDX. */
#define BS_DDRC_DRAMTMG6_T_CKDPDX (4U)     /*!< Bit field size in bits for DDRC_DRAMTMG6_T_CKDPDX. */

/*! @brief Read current value of the DDRC_DRAMTMG6_T_CKDPDX field. */
#define BR_DDRC_DRAMTMG6_T_CKDPDX(x) (HW_DDRC_DRAMTMG6(x).B.T_CKDPDX)

/*! @brief Format value for bitfield DDRC_DRAMTMG6_T_CKDPDX. */
#define BF_DDRC_DRAMTMG6_T_CKDPDX(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG6_T_CKDPDX) & BM_DDRC_DRAMTMG6_T_CKDPDX)

/*! @brief Set the T_CKDPDX field to a new value. */
#define BW_DDRC_DRAMTMG6_T_CKDPDX(x, v) (HW_DDRC_DRAMTMG6_WR(x, (HW_DDRC_DRAMTMG6_RD(x) & ~BM_DDRC_DRAMTMG6_T_CKDPDX) | BF_DDRC_DRAMTMG6_T_CKDPDX(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG6, field T_CKDPDE[27:24] (RW)
 *
 * This is the time after Deep Power Down Entry that CK is maintained as a valid
 * clock. Specifies the clock disable delay after DPDE. Recommended settings:
 * LPDDR2: 2 LPDDR3: 2 For configurations with MEMC_FREQ_RATIO = 2, program this to
 * recommended value divided by two and round it up to next integer. This is
 * only present for designs supporting mDDR or LPDDR2 / LPDDR3 devices. Value After
 * Reset: 0x2 Exists: MEMC_LPDDR2==1
 */
/*@{*/
#define BP_DDRC_DRAMTMG6_T_CKDPDE (24U)    /*!< Bit position for DDRC_DRAMTMG6_T_CKDPDE. */
#define BM_DDRC_DRAMTMG6_T_CKDPDE (0x0F000000U) /*!< Bit mask for DDRC_DRAMTMG6_T_CKDPDE. */
#define BS_DDRC_DRAMTMG6_T_CKDPDE (4U)     /*!< Bit field size in bits for DDRC_DRAMTMG6_T_CKDPDE. */

/*! @brief Read current value of the DDRC_DRAMTMG6_T_CKDPDE field. */
#define BR_DDRC_DRAMTMG6_T_CKDPDE(x) (HW_DDRC_DRAMTMG6(x).B.T_CKDPDE)

/*! @brief Format value for bitfield DDRC_DRAMTMG6_T_CKDPDE. */
#define BF_DDRC_DRAMTMG6_T_CKDPDE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG6_T_CKDPDE) & BM_DDRC_DRAMTMG6_T_CKDPDE)

/*! @brief Set the T_CKDPDE field to a new value. */
#define BW_DDRC_DRAMTMG6_T_CKDPDE(x, v) (HW_DDRC_DRAMTMG6_WR(x, (HW_DDRC_DRAMTMG6_RD(x) & ~BM_DDRC_DRAMTMG6_T_CKDPDE) | BF_DDRC_DRAMTMG6_T_CKDPDE(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DRAMTMG7 - SDRAM Timing Register 7
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DRAMTMG7 - SDRAM Timing Register 7 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: MEMC_MOBILE==1 || MEMC_LPDDR2==1
 */
typedef union _hw_ddrc_dramtmg7
{
    uint32_t U;
    struct _hw_ddrc_dramtmg7_bitfields
    {
        uint32_t T_CKPDX : 4;          /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t T_CKPDE : 4;          /*!< [11:8]  */
        uint32_t RESERVED1 : 20;       /*!< [31:12]  */
    } B;
} hw_ddrc_dramtmg7_t;

/*!
 * @name Constants and macros for entire DDRC_DRAMTMG7 register
 */
/*@{*/
#define HW_DDRC_DRAMTMG7_ADDR(x) ((uintptr_t)(x) + 0x11CU)

#define HW_DDRC_DRAMTMG7(x)      (*(__IO hw_ddrc_dramtmg7_t *) HW_DDRC_DRAMTMG7_ADDR(x))
#define HW_DDRC_DRAMTMG7_RD(x)   (HW_DDRC_DRAMTMG7(x).U)
#define HW_DDRC_DRAMTMG7_WR(x, v) (HW_DDRC_DRAMTMG7(x).U = (v))
#define HW_DDRC_DRAMTMG7_SET(x, v) (HW_DDRC_DRAMTMG7_WR(x, HW_DDRC_DRAMTMG7_RD(x) |  (v)))
#define HW_DDRC_DRAMTMG7_CLR(x, v) (HW_DDRC_DRAMTMG7_WR(x, HW_DDRC_DRAMTMG7_RD(x) & ~(v)))
#define HW_DDRC_DRAMTMG7_TOG(x, v) (HW_DDRC_DRAMTMG7_WR(x, HW_DDRC_DRAMTMG7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DRAMTMG7 bitfields
 */

/*!
 * @name Register DDRC_DRAMTMG7, field T_CKPDX[3:0] (RW)
 *
 * This is the time before Power Down Exit that CK is maintained as a valid
 * clock before issuing PDX. Specifies the clock stable time before PDX. Recommended
 * settings: LPDDR2: 2 LPDDR3: 2 For configurations with MEMC_FREQ_RATIO = 2,
 * program this to recommended value divided by two and round it up to next integer.
 * This is only present for designs supporting mDDR or LPDDR2 / LPDDR3 devices.
 * Value After Reset: 0x2 Exists: MEMC_LPDDR2 == 1
 */
/*@{*/
#define BP_DDRC_DRAMTMG7_T_CKPDX (0U)      /*!< Bit position for DDRC_DRAMTMG7_T_CKPDX. */
#define BM_DDRC_DRAMTMG7_T_CKPDX (0x0000000FU) /*!< Bit mask for DDRC_DRAMTMG7_T_CKPDX. */
#define BS_DDRC_DRAMTMG7_T_CKPDX (4U)      /*!< Bit field size in bits for DDRC_DRAMTMG7_T_CKPDX. */

/*! @brief Read current value of the DDRC_DRAMTMG7_T_CKPDX field. */
#define BR_DDRC_DRAMTMG7_T_CKPDX(x) (HW_DDRC_DRAMTMG7(x).B.T_CKPDX)

/*! @brief Format value for bitfield DDRC_DRAMTMG7_T_CKPDX. */
#define BF_DDRC_DRAMTMG7_T_CKPDX(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG7_T_CKPDX) & BM_DDRC_DRAMTMG7_T_CKPDX)

/*! @brief Set the T_CKPDX field to a new value. */
#define BW_DDRC_DRAMTMG7_T_CKPDX(x, v) (HW_DDRC_DRAMTMG7_WR(x, (HW_DDRC_DRAMTMG7_RD(x) & ~BM_DDRC_DRAMTMG7_T_CKPDX) | BF_DDRC_DRAMTMG7_T_CKPDX(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG7, field T_CKPDE[11:8] (RW)
 *
 * This is the time after Power Down Entry that CK is maintained as a valid
 * clock. Specifies the clock disable delay after PDE. Recommended settings: LPDDR2:
 * 2 LPDDR3: 2 For configurations with MEMC_FREQ_RATIO = 2, program this to
 * recommended value divided by two and round it up to next integer. This is only
 * present for designs supporting mDDR or LPDDR2 / LPDDR3 devices. Value After Reset:
 * 0x2 Exists: MEMC_LPDDR2 == 1
 */
/*@{*/
#define BP_DDRC_DRAMTMG7_T_CKPDE (8U)      /*!< Bit position for DDRC_DRAMTMG7_T_CKPDE. */
#define BM_DDRC_DRAMTMG7_T_CKPDE (0x00000F00U) /*!< Bit mask for DDRC_DRAMTMG7_T_CKPDE. */
#define BS_DDRC_DRAMTMG7_T_CKPDE (4U)      /*!< Bit field size in bits for DDRC_DRAMTMG7_T_CKPDE. */

/*! @brief Read current value of the DDRC_DRAMTMG7_T_CKPDE field. */
#define BR_DDRC_DRAMTMG7_T_CKPDE(x) (HW_DDRC_DRAMTMG7(x).B.T_CKPDE)

/*! @brief Format value for bitfield DDRC_DRAMTMG7_T_CKPDE. */
#define BF_DDRC_DRAMTMG7_T_CKPDE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG7_T_CKPDE) & BM_DDRC_DRAMTMG7_T_CKPDE)

/*! @brief Set the T_CKPDE field to a new value. */
#define BW_DDRC_DRAMTMG7_T_CKPDE(x, v) (HW_DDRC_DRAMTMG7_WR(x, (HW_DDRC_DRAMTMG7_RD(x) & ~BM_DDRC_DRAMTMG7_T_CKPDE) | BF_DDRC_DRAMTMG7_T_CKPDE(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DRAMTMG8 - SDRAM Timing Register 8
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DRAMTMG8 - SDRAM Timing Register 8 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_dramtmg8
{
    uint32_t U;
    struct _hw_ddrc_dramtmg8_bitfields
    {
        uint32_t T_XS_X32 : 7;         /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t T_XS_DLL_X32 : 7;     /*!< [14:8]  */
        uint32_t RESERVED1 : 17;       /*!< [31:15]  */
    } B;
} hw_ddrc_dramtmg8_t;

/*!
 * @name Constants and macros for entire DDRC_DRAMTMG8 register
 */
/*@{*/
#define HW_DDRC_DRAMTMG8_ADDR(x) ((uintptr_t)(x) + 0x120U)

#define HW_DDRC_DRAMTMG8(x)      (*(__IO hw_ddrc_dramtmg8_t *) HW_DDRC_DRAMTMG8_ADDR(x))
#define HW_DDRC_DRAMTMG8_RD(x)   (HW_DDRC_DRAMTMG8(x).U)
#define HW_DDRC_DRAMTMG8_WR(x, v) (HW_DDRC_DRAMTMG8(x).U = (v))
#define HW_DDRC_DRAMTMG8_SET(x, v) (HW_DDRC_DRAMTMG8_WR(x, HW_DDRC_DRAMTMG8_RD(x) |  (v)))
#define HW_DDRC_DRAMTMG8_CLR(x, v) (HW_DDRC_DRAMTMG8_WR(x, HW_DDRC_DRAMTMG8_RD(x) & ~(v)))
#define HW_DDRC_DRAMTMG8_TOG(x, v) (HW_DDRC_DRAMTMG8_WR(x, HW_DDRC_DRAMTMG8_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DRAMTMG8 bitfields
 */

/*!
 * @name Register DDRC_DRAMTMG8, field T_XS_X32[6:0] (RW)
 *
 * tXS: Exit Self Refresh to commands not requiring a locked DLL. For
 * configurations with MEMC_FREQ_RATIO = 2, program this to the above value divided by 2
 * and round up to next integer value. Unit: Multiples of 32 clocks. In LPDDR2 /
 * LPDDR3 / Mobile DDR mode, t_xs_x32 and t_xs_dll_x32 must be set the same values
 * derived from tXSR. Value After Reset: 0x5 Exists: Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG8_T_XS_X32 (0U)     /*!< Bit position for DDRC_DRAMTMG8_T_XS_X32. */
#define BM_DDRC_DRAMTMG8_T_XS_X32 (0x0000007FU) /*!< Bit mask for DDRC_DRAMTMG8_T_XS_X32. */
#define BS_DDRC_DRAMTMG8_T_XS_X32 (7U)     /*!< Bit field size in bits for DDRC_DRAMTMG8_T_XS_X32. */

/*! @brief Read current value of the DDRC_DRAMTMG8_T_XS_X32 field. */
#define BR_DDRC_DRAMTMG8_T_XS_X32(x) (HW_DDRC_DRAMTMG8(x).B.T_XS_X32)

/*! @brief Format value for bitfield DDRC_DRAMTMG8_T_XS_X32. */
#define BF_DDRC_DRAMTMG8_T_XS_X32(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG8_T_XS_X32) & BM_DDRC_DRAMTMG8_T_XS_X32)

/*! @brief Set the T_XS_X32 field to a new value. */
#define BW_DDRC_DRAMTMG8_T_XS_X32(x, v) (HW_DDRC_DRAMTMG8_WR(x, (HW_DDRC_DRAMTMG8_RD(x) & ~BM_DDRC_DRAMTMG8_T_XS_X32) | BF_DDRC_DRAMTMG8_T_XS_X32(v)))
/*@}*/

/*!
 * @name Register DDRC_DRAMTMG8, field T_XS_DLL_X32[14:8] (RW)
 *
 * tXSDLL: Exit Self Refresh to commands requiring a locked DLL. For
 * configurations with MEMC_FREQ_RATIO = 2, program this to the above value divided by 2 and
 * round up to next integer value. Unit: Multiples of 32 clocks. In LPDDR2 /
 * LPDDR3 / Mobile DDR mode, t_xs_x32 and t_xs_dll_x32 must be set the same values
 * derived from tXSR. Value After Reset: 0x44 Exists: Always
 */
/*@{*/
#define BP_DDRC_DRAMTMG8_T_XS_DLL_X32 (8U) /*!< Bit position for DDRC_DRAMTMG8_T_XS_DLL_X32. */
#define BM_DDRC_DRAMTMG8_T_XS_DLL_X32 (0x00007F00U) /*!< Bit mask for DDRC_DRAMTMG8_T_XS_DLL_X32. */
#define BS_DDRC_DRAMTMG8_T_XS_DLL_X32 (7U) /*!< Bit field size in bits for DDRC_DRAMTMG8_T_XS_DLL_X32. */

/*! @brief Read current value of the DDRC_DRAMTMG8_T_XS_DLL_X32 field. */
#define BR_DDRC_DRAMTMG8_T_XS_DLL_X32(x) (HW_DDRC_DRAMTMG8(x).B.T_XS_DLL_X32)

/*! @brief Format value for bitfield DDRC_DRAMTMG8_T_XS_DLL_X32. */
#define BF_DDRC_DRAMTMG8_T_XS_DLL_X32(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DRAMTMG8_T_XS_DLL_X32) & BM_DDRC_DRAMTMG8_T_XS_DLL_X32)

/*! @brief Set the T_XS_DLL_X32 field to a new value. */
#define BW_DDRC_DRAMTMG8_T_XS_DLL_X32(x, v) (HW_DDRC_DRAMTMG8_WR(x, (HW_DDRC_DRAMTMG8_RD(x) & ~BM_DDRC_DRAMTMG8_T_XS_DLL_X32) | BF_DDRC_DRAMTMG8_T_XS_DLL_X32(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_ZQCTL0 - ZQ Control Register 0
 ******************************************************************************/

/*!
 * @brief HW_DDRC_ZQCTL0 - ZQ Control Register 0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: MEMC_DDR3==1 || MEMC_LPDDR2==1
 */
typedef union _hw_ddrc_zqctl0
{
    uint32_t U;
    struct _hw_ddrc_zqctl0_bitfields
    {
        uint32_t T_ZQ_SHORT_NOP : 10;  /*!< [9:0]  */
        uint32_t RESERVED0 : 6;        /*!< [15:10]  */
        uint32_t T_ZQ_LONG_NOP : 10;   /*!< [25:16]  */
        uint32_t RESERVED1 : 3;        /*!< [28:26]  */
        uint32_t ZQ_RESISTOR_SHARED : 1; /*!< [29]  */
        uint32_t DIS_SRX_ZQCL : 1;     /*!< [30]  */
        uint32_t DIS_AUTO_ZQ : 1;      /*!< [31]  */
    } B;
} hw_ddrc_zqctl0_t;

/*!
 * @name Constants and macros for entire DDRC_ZQCTL0 register
 */
/*@{*/
#define HW_DDRC_ZQCTL0_ADDR(x)   ((uintptr_t)(x) + 0x180U)

#define HW_DDRC_ZQCTL0(x)        (*(__IO hw_ddrc_zqctl0_t *) HW_DDRC_ZQCTL0_ADDR(x))
#define HW_DDRC_ZQCTL0_RD(x)     (HW_DDRC_ZQCTL0(x).U)
#define HW_DDRC_ZQCTL0_WR(x, v)  (HW_DDRC_ZQCTL0(x).U = (v))
#define HW_DDRC_ZQCTL0_SET(x, v) (HW_DDRC_ZQCTL0_WR(x, HW_DDRC_ZQCTL0_RD(x) |  (v)))
#define HW_DDRC_ZQCTL0_CLR(x, v) (HW_DDRC_ZQCTL0_WR(x, HW_DDRC_ZQCTL0_RD(x) & ~(v)))
#define HW_DDRC_ZQCTL0_TOG(x, v) (HW_DDRC_ZQCTL0_WR(x, HW_DDRC_ZQCTL0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_ZQCTL0 bitfields
 */

/*!
 * @name Register DDRC_ZQCTL0, field T_ZQ_SHORT_NOP[9:0] (RW)
 *
 * tZQCS: Number of cycles of NOP required after a ZQCS (ZQ calibration short)
 * command is issued to SDRAM. For configurations with MEMC_FREQ_RATIO = 2,
 * program this to tZQCS / 2 and round it up to the next integer value. Unit: Clock
 * cycles. This is only present for designs supporting DDR3 or LPDDR2 / LPDDR3
 * devices. Value After Reset: 0x40 Exists: MEMC_DDR3 == 1 || MEMC_LPDDR2 == 1
 */
/*@{*/
#define BP_DDRC_ZQCTL0_T_ZQ_SHORT_NOP (0U) /*!< Bit position for DDRC_ZQCTL0_T_ZQ_SHORT_NOP. */
#define BM_DDRC_ZQCTL0_T_ZQ_SHORT_NOP (0x000003FFU) /*!< Bit mask for DDRC_ZQCTL0_T_ZQ_SHORT_NOP. */
#define BS_DDRC_ZQCTL0_T_ZQ_SHORT_NOP (10U) /*!< Bit field size in bits for DDRC_ZQCTL0_T_ZQ_SHORT_NOP. */

/*! @brief Read current value of the DDRC_ZQCTL0_T_ZQ_SHORT_NOP field. */
#define BR_DDRC_ZQCTL0_T_ZQ_SHORT_NOP(x) (HW_DDRC_ZQCTL0(x).B.T_ZQ_SHORT_NOP)

/*! @brief Format value for bitfield DDRC_ZQCTL0_T_ZQ_SHORT_NOP. */
#define BF_DDRC_ZQCTL0_T_ZQ_SHORT_NOP(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ZQCTL0_T_ZQ_SHORT_NOP) & BM_DDRC_ZQCTL0_T_ZQ_SHORT_NOP)

/*! @brief Set the T_ZQ_SHORT_NOP field to a new value. */
#define BW_DDRC_ZQCTL0_T_ZQ_SHORT_NOP(x, v) (HW_DDRC_ZQCTL0_WR(x, (HW_DDRC_ZQCTL0_RD(x) & ~BM_DDRC_ZQCTL0_T_ZQ_SHORT_NOP) | BF_DDRC_ZQCTL0_T_ZQ_SHORT_NOP(v)))
/*@}*/

/*!
 * @name Register DDRC_ZQCTL0, field T_ZQ_LONG_NOP[25:16] (RW)
 *
 * tZQoper for DDR3, tZQCL for LPDDR2 / LPDDR3: Number of cycles of NOP required
 * after a ZQCL (ZQ calibration long) command is issued to SDRAM. For
 * configurations with MEMC_FREQ_RATIO = 2: DDR3: program this to tZQoper / 2 and round it
 * up to the next integer value. LPDDR2 / LPDDR3: program this to tZQCL / 2 and
 * round it up to the next integer value. Unit: Clock cycles. This is only present
 * for designs supporting DDR3 or LPDDR2 / LPDDR3 devices. Value After Reset:
 * 0x200 Exists: MEMC_DDR3 == 1 || MEMC_LPDDR2 == 1
 */
/*@{*/
#define BP_DDRC_ZQCTL0_T_ZQ_LONG_NOP (16U) /*!< Bit position for DDRC_ZQCTL0_T_ZQ_LONG_NOP. */
#define BM_DDRC_ZQCTL0_T_ZQ_LONG_NOP (0x03FF0000U) /*!< Bit mask for DDRC_ZQCTL0_T_ZQ_LONG_NOP. */
#define BS_DDRC_ZQCTL0_T_ZQ_LONG_NOP (10U) /*!< Bit field size in bits for DDRC_ZQCTL0_T_ZQ_LONG_NOP. */

/*! @brief Read current value of the DDRC_ZQCTL0_T_ZQ_LONG_NOP field. */
#define BR_DDRC_ZQCTL0_T_ZQ_LONG_NOP(x) (HW_DDRC_ZQCTL0(x).B.T_ZQ_LONG_NOP)

/*! @brief Format value for bitfield DDRC_ZQCTL0_T_ZQ_LONG_NOP. */
#define BF_DDRC_ZQCTL0_T_ZQ_LONG_NOP(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ZQCTL0_T_ZQ_LONG_NOP) & BM_DDRC_ZQCTL0_T_ZQ_LONG_NOP)

/*! @brief Set the T_ZQ_LONG_NOP field to a new value. */
#define BW_DDRC_ZQCTL0_T_ZQ_LONG_NOP(x, v) (HW_DDRC_ZQCTL0_WR(x, (HW_DDRC_ZQCTL0_RD(x) & ~BM_DDRC_ZQCTL0_T_ZQ_LONG_NOP) | BF_DDRC_ZQCTL0_T_ZQ_LONG_NOP(v)))
/*@}*/

/*!
 * @name Register DDRC_ZQCTL0, field ZQ_RESISTOR_SHARED[29] (RW)
 *
 * This is only present for designs supporting DDR3 or LPDDR2 / LPDDR3 devices.
 * Value After Reset: 0x0 Exists: MEMC_DDR3 == 1 || MEMC_LPDDR2 == 1
 *
 * Values:
 * - 1 - Denotes that ZQ resistor is shared between ranks. Means ZQinit / ZQCL /
 *     ZQCS commands are sent to one rank at a time with tZQinit / tZQCL / tZQCS
 *     timing met between commands so that commands to different ranks do not
 *     overlap.
 * - 0 - ZQ resistor is not shared.
 */
/*@{*/
#define BP_DDRC_ZQCTL0_ZQ_RESISTOR_SHARED (29U) /*!< Bit position for DDRC_ZQCTL0_ZQ_RESISTOR_SHARED. */
#define BM_DDRC_ZQCTL0_ZQ_RESISTOR_SHARED (0x20000000U) /*!< Bit mask for DDRC_ZQCTL0_ZQ_RESISTOR_SHARED. */
#define BS_DDRC_ZQCTL0_ZQ_RESISTOR_SHARED (1U) /*!< Bit field size in bits for DDRC_ZQCTL0_ZQ_RESISTOR_SHARED. */

/*! @brief Read current value of the DDRC_ZQCTL0_ZQ_RESISTOR_SHARED field. */
#define BR_DDRC_ZQCTL0_ZQ_RESISTOR_SHARED(x) (HW_DDRC_ZQCTL0(x).B.ZQ_RESISTOR_SHARED)

/*! @brief Format value for bitfield DDRC_ZQCTL0_ZQ_RESISTOR_SHARED. */
#define BF_DDRC_ZQCTL0_ZQ_RESISTOR_SHARED(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ZQCTL0_ZQ_RESISTOR_SHARED) & BM_DDRC_ZQCTL0_ZQ_RESISTOR_SHARED)

/*! @brief Set the ZQ_RESISTOR_SHARED field to a new value. */
#define BW_DDRC_ZQCTL0_ZQ_RESISTOR_SHARED(x, v) (HW_DDRC_ZQCTL0_WR(x, (HW_DDRC_ZQCTL0_RD(x) & ~BM_DDRC_ZQCTL0_ZQ_RESISTOR_SHARED) | BF_DDRC_ZQCTL0_ZQ_RESISTOR_SHARED(v)))
/*@}*/

/*!
 * @name Register DDRC_ZQCTL0, field DIS_SRX_ZQCL[30] (RW)
 *
 * This is only present for designs supporting DDR3 or LPDDR2 / LPDDR3 devices.
 * Value After Reset: 0x0 Exists: MEMC_DDR3 == 1 || MEMC_LPDDR2 == 1
 *
 * Values:
 * - 1 - Disable issuing of ZQCL command at Self-Refresh exit. Only applicable
 *     when run in DDR3 or LPDDR2 or LPDDR3 mode.
 * - 0 - Enable issuing of ZQCL command at Self-Refresh exit. Only applicable
 *     when run in DDR3 or LPDDR2 or LPDDR3 mode.
 */
/*@{*/
#define BP_DDRC_ZQCTL0_DIS_SRX_ZQCL (30U)  /*!< Bit position for DDRC_ZQCTL0_DIS_SRX_ZQCL. */
#define BM_DDRC_ZQCTL0_DIS_SRX_ZQCL (0x40000000U) /*!< Bit mask for DDRC_ZQCTL0_DIS_SRX_ZQCL. */
#define BS_DDRC_ZQCTL0_DIS_SRX_ZQCL (1U)   /*!< Bit field size in bits for DDRC_ZQCTL0_DIS_SRX_ZQCL. */

/*! @brief Read current value of the DDRC_ZQCTL0_DIS_SRX_ZQCL field. */
#define BR_DDRC_ZQCTL0_DIS_SRX_ZQCL(x) (HW_DDRC_ZQCTL0(x).B.DIS_SRX_ZQCL)

/*! @brief Format value for bitfield DDRC_ZQCTL0_DIS_SRX_ZQCL. */
#define BF_DDRC_ZQCTL0_DIS_SRX_ZQCL(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ZQCTL0_DIS_SRX_ZQCL) & BM_DDRC_ZQCTL0_DIS_SRX_ZQCL)

/*! @brief Set the DIS_SRX_ZQCL field to a new value. */
#define BW_DDRC_ZQCTL0_DIS_SRX_ZQCL(x, v) (HW_DDRC_ZQCTL0_WR(x, (HW_DDRC_ZQCTL0_RD(x) & ~BM_DDRC_ZQCTL0_DIS_SRX_ZQCL) | BF_DDRC_ZQCTL0_DIS_SRX_ZQCL(v)))
/*@}*/

/*!
 * @name Register DDRC_ZQCTL0, field DIS_AUTO_ZQ[31] (RW)
 *
 * This is only present for designs supporting DDR3 or LPDDR2 / LPDDR3 devices.
 * Value After Reset: 0x0 Exists: MEMC_DDR3 == 1 || MEMC_LPDDR2 == 1
 *
 * Values:
 * - 1 - Disable DDRC generation of ZQCS command. Register DBGCMD.zq_calib_short
 *     can be used instead to issue ZQ calibration request from APB module.
 * - 0 - Internally generate ZQCS commands based on
 *     ZQCTL1.t_zq_short_interval_x1024.
 */
/*@{*/
#define BP_DDRC_ZQCTL0_DIS_AUTO_ZQ (31U)   /*!< Bit position for DDRC_ZQCTL0_DIS_AUTO_ZQ. */
#define BM_DDRC_ZQCTL0_DIS_AUTO_ZQ (0x80000000U) /*!< Bit mask for DDRC_ZQCTL0_DIS_AUTO_ZQ. */
#define BS_DDRC_ZQCTL0_DIS_AUTO_ZQ (1U)    /*!< Bit field size in bits for DDRC_ZQCTL0_DIS_AUTO_ZQ. */

/*! @brief Read current value of the DDRC_ZQCTL0_DIS_AUTO_ZQ field. */
#define BR_DDRC_ZQCTL0_DIS_AUTO_ZQ(x) (HW_DDRC_ZQCTL0(x).B.DIS_AUTO_ZQ)

/*! @brief Format value for bitfield DDRC_ZQCTL0_DIS_AUTO_ZQ. */
#define BF_DDRC_ZQCTL0_DIS_AUTO_ZQ(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ZQCTL0_DIS_AUTO_ZQ) & BM_DDRC_ZQCTL0_DIS_AUTO_ZQ)

/*! @brief Set the DIS_AUTO_ZQ field to a new value. */
#define BW_DDRC_ZQCTL0_DIS_AUTO_ZQ(x, v) (HW_DDRC_ZQCTL0_WR(x, (HW_DDRC_ZQCTL0_RD(x) & ~BM_DDRC_ZQCTL0_DIS_AUTO_ZQ) | BF_DDRC_ZQCTL0_DIS_AUTO_ZQ(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_ZQCTL1 - ZQ Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_DDRC_ZQCTL1 - ZQ Control Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: MEMC_DDR3==1 || MEMC_LPDDR2==1
 */
typedef union _hw_ddrc_zqctl1
{
    uint32_t U;
    struct _hw_ddrc_zqctl1_bitfields
    {
        uint32_t T_ZQ_SHORT_INTERVAL_X1024 : 20; /*!< [19:0]  */
        uint32_t T_ZQ_RESET_NOP : 10;  /*!< [29:20]  */
        uint32_t RESERVED0 : 2;        /*!< [31:30]  */
    } B;
} hw_ddrc_zqctl1_t;

/*!
 * @name Constants and macros for entire DDRC_ZQCTL1 register
 */
/*@{*/
#define HW_DDRC_ZQCTL1_ADDR(x)   ((uintptr_t)(x) + 0x184U)

#define HW_DDRC_ZQCTL1(x)        (*(__IO hw_ddrc_zqctl1_t *) HW_DDRC_ZQCTL1_ADDR(x))
#define HW_DDRC_ZQCTL1_RD(x)     (HW_DDRC_ZQCTL1(x).U)
#define HW_DDRC_ZQCTL1_WR(x, v)  (HW_DDRC_ZQCTL1(x).U = (v))
#define HW_DDRC_ZQCTL1_SET(x, v) (HW_DDRC_ZQCTL1_WR(x, HW_DDRC_ZQCTL1_RD(x) |  (v)))
#define HW_DDRC_ZQCTL1_CLR(x, v) (HW_DDRC_ZQCTL1_WR(x, HW_DDRC_ZQCTL1_RD(x) & ~(v)))
#define HW_DDRC_ZQCTL1_TOG(x, v) (HW_DDRC_ZQCTL1_WR(x, HW_DDRC_ZQCTL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_ZQCTL1 bitfields
 */

/*!
 * @name Register DDRC_ZQCTL1, field T_ZQ_SHORT_INTERVAL_X1024[19:0] (RW)
 *
 * Average interval to wait between automatically issuing ZQCS (ZQ calibration
 * short) commands to DDR3 / LPDDR2 / LPDDR3 devices. Meaningless, if
 * ZQCTL0.dis_auto_zq = 1. Unit: 1024 clock cycles. This is only present for designs
 * supporting DDR3 or LPDDR2/LPDDR3 devices. Value After Reset: 0x100 Exists: MEMC_DDR3
 * == 1 || MEMC_LPDDR2 == 1
 */
/*@{*/
#define BP_DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024 (0U) /*!< Bit position for DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024. */
#define BM_DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024 (0x000FFFFFU) /*!< Bit mask for DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024. */
#define BS_DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024 (20U) /*!< Bit field size in bits for DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024. */

/*! @brief Read current value of the DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024 field. */
#define BR_DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024(x) (HW_DDRC_ZQCTL1(x).B.T_ZQ_SHORT_INTERVAL_X1024)

/*! @brief Format value for bitfield DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024. */
#define BF_DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024) & BM_DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024)

/*! @brief Set the T_ZQ_SHORT_INTERVAL_X1024 field to a new value. */
#define BW_DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024(x, v) (HW_DDRC_ZQCTL1_WR(x, (HW_DDRC_ZQCTL1_RD(x) & ~BM_DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024) | BF_DDRC_ZQCTL1_T_ZQ_SHORT_INTERVAL_X1024(v)))
/*@}*/

/*!
 * @name Register DDRC_ZQCTL1, field T_ZQ_RESET_NOP[29:20] (RW)
 *
 * tZQReset: Number of cycles of NOP required after a ZQReset (ZQ calibration
 * Reset) command is issued to SDRAM. For configurations with MEMC_FREQ_RATIO = 2,
 * program this to tZQReset / 2 and round it up to the next integer value. Unit:
 * Clock cycles. This is only present for designs supporting LPDDR2 / LPDDR3
 * devices. Value After Reset: 0x20 Exists: MEMC_LPDDR2 == 1
 */
/*@{*/
#define BP_DDRC_ZQCTL1_T_ZQ_RESET_NOP (20U) /*!< Bit position for DDRC_ZQCTL1_T_ZQ_RESET_NOP. */
#define BM_DDRC_ZQCTL1_T_ZQ_RESET_NOP (0x3FF00000U) /*!< Bit mask for DDRC_ZQCTL1_T_ZQ_RESET_NOP. */
#define BS_DDRC_ZQCTL1_T_ZQ_RESET_NOP (10U) /*!< Bit field size in bits for DDRC_ZQCTL1_T_ZQ_RESET_NOP. */

/*! @brief Read current value of the DDRC_ZQCTL1_T_ZQ_RESET_NOP field. */
#define BR_DDRC_ZQCTL1_T_ZQ_RESET_NOP(x) (HW_DDRC_ZQCTL1(x).B.T_ZQ_RESET_NOP)

/*! @brief Format value for bitfield DDRC_ZQCTL1_T_ZQ_RESET_NOP. */
#define BF_DDRC_ZQCTL1_T_ZQ_RESET_NOP(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ZQCTL1_T_ZQ_RESET_NOP) & BM_DDRC_ZQCTL1_T_ZQ_RESET_NOP)

/*! @brief Set the T_ZQ_RESET_NOP field to a new value. */
#define BW_DDRC_ZQCTL1_T_ZQ_RESET_NOP(x, v) (HW_DDRC_ZQCTL1_WR(x, (HW_DDRC_ZQCTL1_RD(x) & ~BM_DDRC_ZQCTL1_T_ZQ_RESET_NOP) | BF_DDRC_ZQCTL1_T_ZQ_RESET_NOP(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_ZQCTL2 - ZQ Control Register 2
 ******************************************************************************/

/*!
 * @brief HW_DDRC_ZQCTL2 - ZQ Control Register 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: MEMC_LPDDR2==1
 */
typedef union _hw_ddrc_zqctl2
{
    uint32_t U;
    struct _hw_ddrc_zqctl2_bitfields
    {
        uint32_t ZQ_RESET : 1;         /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_ddrc_zqctl2_t;

/*!
 * @name Constants and macros for entire DDRC_ZQCTL2 register
 */
/*@{*/
#define HW_DDRC_ZQCTL2_ADDR(x)   ((uintptr_t)(x) + 0x188U)

#define HW_DDRC_ZQCTL2(x)        (*(__IO hw_ddrc_zqctl2_t *) HW_DDRC_ZQCTL2_ADDR(x))
#define HW_DDRC_ZQCTL2_RD(x)     (HW_DDRC_ZQCTL2(x).U)
#define HW_DDRC_ZQCTL2_WR(x, v)  (HW_DDRC_ZQCTL2(x).U = (v))
#define HW_DDRC_ZQCTL2_SET(x, v) (HW_DDRC_ZQCTL2_WR(x, HW_DDRC_ZQCTL2_RD(x) |  (v)))
#define HW_DDRC_ZQCTL2_CLR(x, v) (HW_DDRC_ZQCTL2_WR(x, HW_DDRC_ZQCTL2_RD(x) & ~(v)))
#define HW_DDRC_ZQCTL2_TOG(x, v) (HW_DDRC_ZQCTL2_WR(x, HW_DDRC_ZQCTL2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_ZQCTL2 bitfields
 */

/*!
 * @name Register DDRC_ZQCTL2, field ZQ_RESET[0] (RW)
 *
 * Setting this register bit to 1 triggers a ZQ Reset operation.When the ZQ
 * Reset operation is complete, the DDRC automatically clears this bit. It is
 * recommended NOT to set this signal if in Init, Self-Refresh or Deep power- down
 * operating modes. This is only present for designs supporting LPDDR2 / LPDDR3
 * devices. Value After Reset: 0x0 Exists: MEMC_LPDDR2 == 1
 */
/*@{*/
#define BP_DDRC_ZQCTL2_ZQ_RESET (0U)       /*!< Bit position for DDRC_ZQCTL2_ZQ_RESET. */
#define BM_DDRC_ZQCTL2_ZQ_RESET (0x00000001U) /*!< Bit mask for DDRC_ZQCTL2_ZQ_RESET. */
#define BS_DDRC_ZQCTL2_ZQ_RESET (1U)       /*!< Bit field size in bits for DDRC_ZQCTL2_ZQ_RESET. */

/*! @brief Read current value of the DDRC_ZQCTL2_ZQ_RESET field. */
#define BR_DDRC_ZQCTL2_ZQ_RESET(x) (HW_DDRC_ZQCTL2(x).B.ZQ_RESET)

/*! @brief Format value for bitfield DDRC_ZQCTL2_ZQ_RESET. */
#define BF_DDRC_ZQCTL2_ZQ_RESET(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ZQCTL2_ZQ_RESET) & BM_DDRC_ZQCTL2_ZQ_RESET)

/*! @brief Set the ZQ_RESET field to a new value. */
#define BW_DDRC_ZQCTL2_ZQ_RESET(x, v) (HW_DDRC_ZQCTL2_WR(x, (HW_DDRC_ZQCTL2_RD(x) & ~BM_DDRC_ZQCTL2_ZQ_RESET) | BF_DDRC_ZQCTL2_ZQ_RESET(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_ZQSTAT - ZQ Status Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_ZQSTAT - ZQ Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * Exists: MEMC_LPDDR2==1
 */
typedef union _hw_ddrc_zqstat
{
    uint32_t U;
    struct _hw_ddrc_zqstat_bitfields
    {
        uint32_t ZQ_RESET_BUSY : 1;    /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_ddrc_zqstat_t;

/*!
 * @name Constants and macros for entire DDRC_ZQSTAT register
 */
/*@{*/
#define HW_DDRC_ZQSTAT_ADDR(x)   ((uintptr_t)(x) + 0x18CU)

#define HW_DDRC_ZQSTAT(x)        (*(__I hw_ddrc_zqstat_t *) HW_DDRC_ZQSTAT_ADDR(x))
#define HW_DDRC_ZQSTAT_RD(x)     (HW_DDRC_ZQSTAT(x).U)
/*@}*/

/*
 * Constants & macros for individual DDRC_ZQSTAT bitfields
 */

/*!
 * @name Register DDRC_ZQSTAT, field ZQ_RESET_BUSY[0] (RO)
 *
 * SoC core may initiate a ZQ Reset operation only if this signal is low. This
 * signal goes high in the clock after the DDRC accepts the ZQ Reset request. It
 * goes low when the ZQ Reset command is issued to the SDRAM and the associated
 * NOP period is over. It is recommended not to perform ZQ Reset commands when this
 * signal is high. Value After Reset: 0x0 Exists: Always
 *
 * Values:
 * - 0 - Indicates that the SoC core can initiate a ZQ Reset operation.
 * - 1 - Indicates that ZQ Reset operation is in progress.
 */
/*@{*/
#define BP_DDRC_ZQSTAT_ZQ_RESET_BUSY (0U)  /*!< Bit position for DDRC_ZQSTAT_ZQ_RESET_BUSY. */
#define BM_DDRC_ZQSTAT_ZQ_RESET_BUSY (0x00000001U) /*!< Bit mask for DDRC_ZQSTAT_ZQ_RESET_BUSY. */
#define BS_DDRC_ZQSTAT_ZQ_RESET_BUSY (1U)  /*!< Bit field size in bits for DDRC_ZQSTAT_ZQ_RESET_BUSY. */

/*! @brief Read current value of the DDRC_ZQSTAT_ZQ_RESET_BUSY field. */
#define BR_DDRC_ZQSTAT_ZQ_RESET_BUSY(x) (HW_DDRC_ZQSTAT(x).B.ZQ_RESET_BUSY)
/*@}*/

/*******************************************************************************
 * HW_DDRC_DFITMG0 - DFI Timing Register 0
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DFITMG0 - DFI Timing Register 0 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_dfitmg0
{
    uint32_t U;
    struct _hw_ddrc_dfitmg0_bitfields
    {
        uint32_t DFI_TPHY_WRLAT : 6;   /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t DFI_TPHY_WRDATA : 6;  /*!< [13:8]  */
        uint32_t RESERVED1 : 1;        /*!< [14]  */
        uint32_t DFI_WRDATA_USE_SDR : 1; /*!< [15]  */
        uint32_t DFI_T_RDDATA_EN : 6;  /*!< [21:16]  */
        uint32_t RESERVED2 : 1;        /*!< [22]  */
        uint32_t DFI_RDDATA_USE_SDR : 1; /*!< [23]  */
        uint32_t DFI_T_CTRL_DELAY : 5; /*!< [28:24]  */
        uint32_t RESERVED3 : 3;        /*!< [31:29]  */
    } B;
} hw_ddrc_dfitmg0_t;

/*!
 * @name Constants and macros for entire DDRC_DFITMG0 register
 */
/*@{*/
#define HW_DDRC_DFITMG0_ADDR(x)  ((uintptr_t)(x) + 0x190U)

#define HW_DDRC_DFITMG0(x)       (*(__IO hw_ddrc_dfitmg0_t *) HW_DDRC_DFITMG0_ADDR(x))
#define HW_DDRC_DFITMG0_RD(x)    (HW_DDRC_DFITMG0(x).U)
#define HW_DDRC_DFITMG0_WR(x, v) (HW_DDRC_DFITMG0(x).U = (v))
#define HW_DDRC_DFITMG0_SET(x, v) (HW_DDRC_DFITMG0_WR(x, HW_DDRC_DFITMG0_RD(x) |  (v)))
#define HW_DDRC_DFITMG0_CLR(x, v) (HW_DDRC_DFITMG0_WR(x, HW_DDRC_DFITMG0_RD(x) & ~(v)))
#define HW_DDRC_DFITMG0_TOG(x, v) (HW_DDRC_DFITMG0_WR(x, HW_DDRC_DFITMG0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DFITMG0 bitfields
 */

/*!
 * @name Register DDRC_DFITMG0, field DFI_TPHY_WRLAT[5:0] (RW)
 *
 * Write latency Number of clocks from the write command to write data enable
 * (dfi_wrdata_en). This corresponds to the DFI timing parameter tphy_wrlat. Refer
 * to PHY specification for correct value.Note that, depending on the PHY, if
 * using RDIMM, it may be necessary to use the value (CL + 1) in the calculation of
 * tphy_wrlat. This is to compensate for the extra cycle of latency through the
 * RDIMM. Value After Reset: 0x2 Exists: Always
 */
/*@{*/
#define BP_DDRC_DFITMG0_DFI_TPHY_WRLAT (0U) /*!< Bit position for DDRC_DFITMG0_DFI_TPHY_WRLAT. */
#define BM_DDRC_DFITMG0_DFI_TPHY_WRLAT (0x0000003FU) /*!< Bit mask for DDRC_DFITMG0_DFI_TPHY_WRLAT. */
#define BS_DDRC_DFITMG0_DFI_TPHY_WRLAT (6U) /*!< Bit field size in bits for DDRC_DFITMG0_DFI_TPHY_WRLAT. */

/*! @brief Read current value of the DDRC_DFITMG0_DFI_TPHY_WRLAT field. */
#define BR_DDRC_DFITMG0_DFI_TPHY_WRLAT(x) (HW_DDRC_DFITMG0(x).B.DFI_TPHY_WRLAT)

/*! @brief Format value for bitfield DDRC_DFITMG0_DFI_TPHY_WRLAT. */
#define BF_DDRC_DFITMG0_DFI_TPHY_WRLAT(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFITMG0_DFI_TPHY_WRLAT) & BM_DDRC_DFITMG0_DFI_TPHY_WRLAT)

/*! @brief Set the DFI_TPHY_WRLAT field to a new value. */
#define BW_DDRC_DFITMG0_DFI_TPHY_WRLAT(x, v) (HW_DDRC_DFITMG0_WR(x, (HW_DDRC_DFITMG0_RD(x) & ~BM_DDRC_DFITMG0_DFI_TPHY_WRLAT) | BF_DDRC_DFITMG0_DFI_TPHY_WRLAT(v)))
/*@}*/

/*!
 * @name Register DDRC_DFITMG0, field DFI_TPHY_WRDATA[13:8] (RW)
 *
 * Specifies the number of clock cycles between when dfi_wrdata_en is asserted
 * to when the associated write data is driven on the dfi_wrdata signal. This
 * corresponds to the DFI timing parameter tphy_wrdata. Refer to PHY specification
 * for correct value. The max supported value is 8. Unit: Clocks Value After Reset:
 * 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_DFITMG0_DFI_TPHY_WRDATA (8U) /*!< Bit position for DDRC_DFITMG0_DFI_TPHY_WRDATA. */
#define BM_DDRC_DFITMG0_DFI_TPHY_WRDATA (0x00003F00U) /*!< Bit mask for DDRC_DFITMG0_DFI_TPHY_WRDATA. */
#define BS_DDRC_DFITMG0_DFI_TPHY_WRDATA (6U) /*!< Bit field size in bits for DDRC_DFITMG0_DFI_TPHY_WRDATA. */

/*! @brief Read current value of the DDRC_DFITMG0_DFI_TPHY_WRDATA field. */
#define BR_DDRC_DFITMG0_DFI_TPHY_WRDATA(x) (HW_DDRC_DFITMG0(x).B.DFI_TPHY_WRDATA)

/*! @brief Format value for bitfield DDRC_DFITMG0_DFI_TPHY_WRDATA. */
#define BF_DDRC_DFITMG0_DFI_TPHY_WRDATA(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFITMG0_DFI_TPHY_WRDATA) & BM_DDRC_DFITMG0_DFI_TPHY_WRDATA)

/*! @brief Set the DFI_TPHY_WRDATA field to a new value. */
#define BW_DDRC_DFITMG0_DFI_TPHY_WRDATA(x, v) (HW_DDRC_DFITMG0_WR(x, (HW_DDRC_DFITMG0_RD(x) & ~BM_DDRC_DFITMG0_DFI_TPHY_WRDATA) | BF_DDRC_DFITMG0_DFI_TPHY_WRDATA(v)))
/*@}*/

/*!
 * @name Register DDRC_DFITMG0, field DFI_WRDATA_USE_SDR[15] (RW)
 *
 * Defines whether dfi_wrdata_en / dfi_wrdata / dfi_wrdata_mask is generated
 * using HDR or SDR values Selects whether value in DFITMG0.dfi_tphy_wrlat is in
 * terms of SDR or HDR clock cycles Selects whether value in DFITMG0.dfi_tphy_wrdata
 * is in terms of SDR or HDR clock cycles. Refer to PHY specification for
 * correct value. Value After Reset: 0x0 Exists: MEMC_FREQ_RATIO==2
 *
 * Values:
 * - 0 - In terms of HDR clock cycles
 * - 1 - In terms of SDR clock cycles
 */
/*@{*/
#define BP_DDRC_DFITMG0_DFI_WRDATA_USE_SDR (15U) /*!< Bit position for DDRC_DFITMG0_DFI_WRDATA_USE_SDR. */
#define BM_DDRC_DFITMG0_DFI_WRDATA_USE_SDR (0x00008000U) /*!< Bit mask for DDRC_DFITMG0_DFI_WRDATA_USE_SDR. */
#define BS_DDRC_DFITMG0_DFI_WRDATA_USE_SDR (1U) /*!< Bit field size in bits for DDRC_DFITMG0_DFI_WRDATA_USE_SDR. */

/*! @brief Read current value of the DDRC_DFITMG0_DFI_WRDATA_USE_SDR field. */
#define BR_DDRC_DFITMG0_DFI_WRDATA_USE_SDR(x) (HW_DDRC_DFITMG0(x).B.DFI_WRDATA_USE_SDR)

/*! @brief Format value for bitfield DDRC_DFITMG0_DFI_WRDATA_USE_SDR. */
#define BF_DDRC_DFITMG0_DFI_WRDATA_USE_SDR(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFITMG0_DFI_WRDATA_USE_SDR) & BM_DDRC_DFITMG0_DFI_WRDATA_USE_SDR)

/*! @brief Set the DFI_WRDATA_USE_SDR field to a new value. */
#define BW_DDRC_DFITMG0_DFI_WRDATA_USE_SDR(x, v) (HW_DDRC_DFITMG0_WR(x, (HW_DDRC_DFITMG0_RD(x) & ~BM_DDRC_DFITMG0_DFI_WRDATA_USE_SDR) | BF_DDRC_DFITMG0_DFI_WRDATA_USE_SDR(v)))
/*@}*/

/*!
 * @name Register DDRC_DFITMG0, field DFI_T_RDDATA_EN[21:16] (RW)
 *
 * Time from the assertion of a read command on the DFI interface to the
 * assertion of the dfi_rddata_en signal. Refer to PHY specification for correct value.
 * This corresponds to the DFI parameter trddata_en. Note that, depending on the
 * PHY, if using RDIMM, it may be necessary to use the value (CL + 1) in the
 * calculation of trddata_en. This is to compensate for the extra cycle of latency
 * through the RDIMM. Unit: Clocks Value After Reset: 0x2 Exists: Always
 */
/*@{*/
#define BP_DDRC_DFITMG0_DFI_T_RDDATA_EN (16U) /*!< Bit position for DDRC_DFITMG0_DFI_T_RDDATA_EN. */
#define BM_DDRC_DFITMG0_DFI_T_RDDATA_EN (0x003F0000U) /*!< Bit mask for DDRC_DFITMG0_DFI_T_RDDATA_EN. */
#define BS_DDRC_DFITMG0_DFI_T_RDDATA_EN (6U) /*!< Bit field size in bits for DDRC_DFITMG0_DFI_T_RDDATA_EN. */

/*! @brief Read current value of the DDRC_DFITMG0_DFI_T_RDDATA_EN field. */
#define BR_DDRC_DFITMG0_DFI_T_RDDATA_EN(x) (HW_DDRC_DFITMG0(x).B.DFI_T_RDDATA_EN)

/*! @brief Format value for bitfield DDRC_DFITMG0_DFI_T_RDDATA_EN. */
#define BF_DDRC_DFITMG0_DFI_T_RDDATA_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFITMG0_DFI_T_RDDATA_EN) & BM_DDRC_DFITMG0_DFI_T_RDDATA_EN)

/*! @brief Set the DFI_T_RDDATA_EN field to a new value. */
#define BW_DDRC_DFITMG0_DFI_T_RDDATA_EN(x, v) (HW_DDRC_DFITMG0_WR(x, (HW_DDRC_DFITMG0_RD(x) & ~BM_DDRC_DFITMG0_DFI_T_RDDATA_EN) | BF_DDRC_DFITMG0_DFI_T_RDDATA_EN(v)))
/*@}*/

/*!
 * @name Register DDRC_DFITMG0, field DFI_RDDATA_USE_SDR[23] (RW)
 *
 * Defines whether dfi_rddata_en / dfi_rddata / dfi_rddata_valid is generated
 * using HDR or SDR values Selects whether value in DFITMG0.dfi_t_rddata_en is in
 * terms of SDR or HDR clock cycles. Value After Reset: 0x0 Exists:
 * MEMC_FREQ_RATIO == 2
 *
 * Values:
 * - 0 - In terms of HDR clock cycles
 * - 1 - In terms of SDR clock cycles Refer to PHY specification for correct
 *     value.
 */
/*@{*/
#define BP_DDRC_DFITMG0_DFI_RDDATA_USE_SDR (23U) /*!< Bit position for DDRC_DFITMG0_DFI_RDDATA_USE_SDR. */
#define BM_DDRC_DFITMG0_DFI_RDDATA_USE_SDR (0x00800000U) /*!< Bit mask for DDRC_DFITMG0_DFI_RDDATA_USE_SDR. */
#define BS_DDRC_DFITMG0_DFI_RDDATA_USE_SDR (1U) /*!< Bit field size in bits for DDRC_DFITMG0_DFI_RDDATA_USE_SDR. */

/*! @brief Read current value of the DDRC_DFITMG0_DFI_RDDATA_USE_SDR field. */
#define BR_DDRC_DFITMG0_DFI_RDDATA_USE_SDR(x) (HW_DDRC_DFITMG0(x).B.DFI_RDDATA_USE_SDR)

/*! @brief Format value for bitfield DDRC_DFITMG0_DFI_RDDATA_USE_SDR. */
#define BF_DDRC_DFITMG0_DFI_RDDATA_USE_SDR(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFITMG0_DFI_RDDATA_USE_SDR) & BM_DDRC_DFITMG0_DFI_RDDATA_USE_SDR)

/*! @brief Set the DFI_RDDATA_USE_SDR field to a new value. */
#define BW_DDRC_DFITMG0_DFI_RDDATA_USE_SDR(x, v) (HW_DDRC_DFITMG0_WR(x, (HW_DDRC_DFITMG0_RD(x) & ~BM_DDRC_DFITMG0_DFI_RDDATA_USE_SDR) | BF_DDRC_DFITMG0_DFI_RDDATA_USE_SDR(v)))
/*@}*/

/*!
 * @name Register DDRC_DFITMG0, field DFI_T_CTRL_DELAY[28:24] (RW)
 *
 * Specifies the number of DFI clock cycles after an assertion or de-assertion
 * of the DFI control signals that the control signals at the PHY-DRAM interface
 * reflect the assertion or deassertion. If the DFI clock and the memory clock are
 * not phase-aligned, this timing parameter should be rounded up to the next
 * integer value Value After Reset: 0x7. Exists: Always
 */
/*@{*/
#define BP_DDRC_DFITMG0_DFI_T_CTRL_DELAY (24U) /*!< Bit position for DDRC_DFITMG0_DFI_T_CTRL_DELAY. */
#define BM_DDRC_DFITMG0_DFI_T_CTRL_DELAY (0x1F000000U) /*!< Bit mask for DDRC_DFITMG0_DFI_T_CTRL_DELAY. */
#define BS_DDRC_DFITMG0_DFI_T_CTRL_DELAY (5U) /*!< Bit field size in bits for DDRC_DFITMG0_DFI_T_CTRL_DELAY. */

/*! @brief Read current value of the DDRC_DFITMG0_DFI_T_CTRL_DELAY field. */
#define BR_DDRC_DFITMG0_DFI_T_CTRL_DELAY(x) (HW_DDRC_DFITMG0(x).B.DFI_T_CTRL_DELAY)

/*! @brief Format value for bitfield DDRC_DFITMG0_DFI_T_CTRL_DELAY. */
#define BF_DDRC_DFITMG0_DFI_T_CTRL_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFITMG0_DFI_T_CTRL_DELAY) & BM_DDRC_DFITMG0_DFI_T_CTRL_DELAY)

/*! @brief Set the DFI_T_CTRL_DELAY field to a new value. */
#define BW_DDRC_DFITMG0_DFI_T_CTRL_DELAY(x, v) (HW_DDRC_DFITMG0_WR(x, (HW_DDRC_DFITMG0_RD(x) & ~BM_DDRC_DFITMG0_DFI_T_CTRL_DELAY) | BF_DDRC_DFITMG0_DFI_T_CTRL_DELAY(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DFITMG1 - DFI Timing Register 1
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DFITMG1 - DFI Timing Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_dfitmg1
{
    uint32_t U;
    struct _hw_ddrc_dfitmg1_bitfields
    {
        uint32_t DFI_T_DRAM_CLK_ENABLE : 4; /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t DFI_T_DRAM_CLK_DISABLE : 4; /*!< [11:8]  */
        uint32_t RESERVED1 : 4;        /*!< [15:12]  */
        uint32_t DFI_T_WRDATA_DELAY : 5; /*!< [20:16]  */
        uint32_t RESERVED2 : 11;       /*!< [31:21]  */
    } B;
} hw_ddrc_dfitmg1_t;

/*!
 * @name Constants and macros for entire DDRC_DFITMG1 register
 */
/*@{*/
#define HW_DDRC_DFITMG1_ADDR(x)  ((uintptr_t)(x) + 0x194U)

#define HW_DDRC_DFITMG1(x)       (*(__IO hw_ddrc_dfitmg1_t *) HW_DDRC_DFITMG1_ADDR(x))
#define HW_DDRC_DFITMG1_RD(x)    (HW_DDRC_DFITMG1(x).U)
#define HW_DDRC_DFITMG1_WR(x, v) (HW_DDRC_DFITMG1(x).U = (v))
#define HW_DDRC_DFITMG1_SET(x, v) (HW_DDRC_DFITMG1_WR(x, HW_DDRC_DFITMG1_RD(x) |  (v)))
#define HW_DDRC_DFITMG1_CLR(x, v) (HW_DDRC_DFITMG1_WR(x, HW_DDRC_DFITMG1_RD(x) & ~(v)))
#define HW_DDRC_DFITMG1_TOG(x, v) (HW_DDRC_DFITMG1_WR(x, HW_DDRC_DFITMG1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DFITMG1 bitfields
 */

/*!
 * @name Register DDRC_DFITMG1, field DFI_T_DRAM_CLK_ENABLE[3:0] (RW)
 *
 * Specifies the number of DFI clock cycles from the de-assertion of the
 * dfi_dram_clk_disable signal on the DFI until the first valid rising edge of the clock
 * to the DRAM memory devices, at the PHY-DRAM boundary. If the DFI clock and
 * the memory clock are not phase aligned, this timing parameter should be rounded
 * up to the next integer value. Value After Reset: 0x4 Exists: Always
 */
/*@{*/
#define BP_DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE (0U) /*!< Bit position for DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE. */
#define BM_DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE (0x0000000FU) /*!< Bit mask for DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE. */
#define BS_DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE (4U) /*!< Bit field size in bits for DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE. */

/*! @brief Read current value of the DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE field. */
#define BR_DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE(x) (HW_DDRC_DFITMG1(x).B.DFI_T_DRAM_CLK_ENABLE)

/*! @brief Format value for bitfield DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE. */
#define BF_DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE) & BM_DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE)

/*! @brief Set the DFI_T_DRAM_CLK_ENABLE field to a new value. */
#define BW_DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE(x, v) (HW_DDRC_DFITMG1_WR(x, (HW_DDRC_DFITMG1_RD(x) & ~BM_DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE) | BF_DDRC_DFITMG1_DFI_T_DRAM_CLK_ENABLE(v)))
/*@}*/

/*!
 * @name Register DDRC_DFITMG1, field DFI_T_DRAM_CLK_DISABLE[11:8] (RW)
 *
 * Specifies the number of DFI clock cycles from the assertion of the
 * dfi_dram_clk_disable signal on the DFI until the clock to the DRAM memory devices, at
 * the PHY-DRAM boundary, maintains a low value. If the DFI clock and the memory
 * clock are not phase aligned, this timing parameter should be rounded up to the
 * next integer value. Value After Reset: 0x4 Exists: Always
 */
/*@{*/
#define BP_DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE (8U) /*!< Bit position for DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE. */
#define BM_DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE (0x00000F00U) /*!< Bit mask for DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE. */
#define BS_DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE (4U) /*!< Bit field size in bits for DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE. */

/*! @brief Read current value of the DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE field. */
#define BR_DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE(x) (HW_DDRC_DFITMG1(x).B.DFI_T_DRAM_CLK_DISABLE)

/*! @brief Format value for bitfield DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE. */
#define BF_DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE) & BM_DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE)

/*! @brief Set the DFI_T_DRAM_CLK_DISABLE field to a new value. */
#define BW_DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE(x, v) (HW_DDRC_DFITMG1_WR(x, (HW_DDRC_DFITMG1_RD(x) & ~BM_DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE) | BF_DDRC_DFITMG1_DFI_T_DRAM_CLK_DISABLE(v)))
/*@}*/

/*!
 * @name Register DDRC_DFITMG1, field DFI_T_WRDATA_DELAY[20:16] (RW)
 *
 * Specifies the number of DFI clocks between when the dfi_wrdata_en signal is
 * asserted and when the corresponding write data transfer is completed on the
 * DRAM bus. This corresponds to the DFI timing parameter twrdata_delay. Refer to
 * PHY specification for correct value. For DFI 3.0 PHY, set to twrdata_delay, a
 * new timing parameter introduced in DFI 3.0. For DFI 2.1 PHY, set to tphy_wrdata
 * + (delay of DFI write data to the DRAM). Value to be programmed is in terms of
 * DFI clocks, not PHY clocks. In FREQ_RATIO = 2, divide PHY's value by 2 and
 * round up to next integer. If usingDFITMG0.dfi_wrdata_use_sdr = 1, add 1 to the
 * value. Unit: Clocks Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_DFITMG1_DFI_T_WRDATA_DELAY (16U) /*!< Bit position for DDRC_DFITMG1_DFI_T_WRDATA_DELAY. */
#define BM_DDRC_DFITMG1_DFI_T_WRDATA_DELAY (0x001F0000U) /*!< Bit mask for DDRC_DFITMG1_DFI_T_WRDATA_DELAY. */
#define BS_DDRC_DFITMG1_DFI_T_WRDATA_DELAY (5U) /*!< Bit field size in bits for DDRC_DFITMG1_DFI_T_WRDATA_DELAY. */

/*! @brief Read current value of the DDRC_DFITMG1_DFI_T_WRDATA_DELAY field. */
#define BR_DDRC_DFITMG1_DFI_T_WRDATA_DELAY(x) (HW_DDRC_DFITMG1(x).B.DFI_T_WRDATA_DELAY)

/*! @brief Format value for bitfield DDRC_DFITMG1_DFI_T_WRDATA_DELAY. */
#define BF_DDRC_DFITMG1_DFI_T_WRDATA_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFITMG1_DFI_T_WRDATA_DELAY) & BM_DDRC_DFITMG1_DFI_T_WRDATA_DELAY)

/*! @brief Set the DFI_T_WRDATA_DELAY field to a new value. */
#define BW_DDRC_DFITMG1_DFI_T_WRDATA_DELAY(x, v) (HW_DDRC_DFITMG1_WR(x, (HW_DDRC_DFITMG1_RD(x) & ~BM_DDRC_DFITMG1_DFI_T_WRDATA_DELAY) | BF_DDRC_DFITMG1_DFI_T_WRDATA_DELAY(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DFILPCFG0 - DFI Low Power Configuration Register 0
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DFILPCFG0 - DFI Low Power Configuration Register 0 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_dfilpcfg0
{
    uint32_t U;
    struct _hw_ddrc_dfilpcfg0_bitfields
    {
        uint32_t DFI_LP_EN_PD : 1;     /*!< [0]  */
        uint32_t RESERVED0 : 3;        /*!< [3:1]  */
        uint32_t DFI_LP_WAKEUP_PD : 4; /*!< [7:4]  */
        uint32_t DFI_LP_EN_SR : 1;     /*!< [8]  */
        uint32_t RESERVED1 : 3;        /*!< [11:9]  */
        uint32_t DFI_LP_WAKEUP_SR : 4; /*!< [15:12]  */
        uint32_t DFI_LP_EN_DPD : 1;    /*!< [16]  */
        uint32_t RESERVED2 : 3;        /*!< [19:17]  */
        uint32_t DFI_LP_WAKEUP_DPD : 4; /*!< [23:20]  */
        uint32_t DFI_TLP_RESP : 4;     /*!< [27:24]  */
        uint32_t RESERVED3 : 4;        /*!< [31:28]  */
    } B;
} hw_ddrc_dfilpcfg0_t;

/*!
 * @name Constants and macros for entire DDRC_DFILPCFG0 register
 */
/*@{*/
#define HW_DDRC_DFILPCFG0_ADDR(x) ((uintptr_t)(x) + 0x198U)

#define HW_DDRC_DFILPCFG0(x)     (*(__IO hw_ddrc_dfilpcfg0_t *) HW_DDRC_DFILPCFG0_ADDR(x))
#define HW_DDRC_DFILPCFG0_RD(x)  (HW_DDRC_DFILPCFG0(x).U)
#define HW_DDRC_DFILPCFG0_WR(x, v) (HW_DDRC_DFILPCFG0(x).U = (v))
#define HW_DDRC_DFILPCFG0_SET(x, v) (HW_DDRC_DFILPCFG0_WR(x, HW_DDRC_DFILPCFG0_RD(x) |  (v)))
#define HW_DDRC_DFILPCFG0_CLR(x, v) (HW_DDRC_DFILPCFG0_WR(x, HW_DDRC_DFILPCFG0_RD(x) & ~(v)))
#define HW_DDRC_DFILPCFG0_TOG(x, v) (HW_DDRC_DFILPCFG0_WR(x, HW_DDRC_DFILPCFG0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DFILPCFG0 bitfields
 */

/*!
 * @name Register DDRC_DFILPCFG0, field DFI_LP_EN_PD[0] (RW)
 *
 * Enables DFI Low Power interface handshaking during Power Down Entry / Exit.
 * Value After Reset: 0x0 Exists: Always
 *
 * Values:
 * - 0 - Disabled
 * - 1 - Enabled
 */
/*@{*/
#define BP_DDRC_DFILPCFG0_DFI_LP_EN_PD (0U) /*!< Bit position for DDRC_DFILPCFG0_DFI_LP_EN_PD. */
#define BM_DDRC_DFILPCFG0_DFI_LP_EN_PD (0x00000001U) /*!< Bit mask for DDRC_DFILPCFG0_DFI_LP_EN_PD. */
#define BS_DDRC_DFILPCFG0_DFI_LP_EN_PD (1U) /*!< Bit field size in bits for DDRC_DFILPCFG0_DFI_LP_EN_PD. */

/*! @brief Read current value of the DDRC_DFILPCFG0_DFI_LP_EN_PD field. */
#define BR_DDRC_DFILPCFG0_DFI_LP_EN_PD(x) (HW_DDRC_DFILPCFG0(x).B.DFI_LP_EN_PD)

/*! @brief Format value for bitfield DDRC_DFILPCFG0_DFI_LP_EN_PD. */
#define BF_DDRC_DFILPCFG0_DFI_LP_EN_PD(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFILPCFG0_DFI_LP_EN_PD) & BM_DDRC_DFILPCFG0_DFI_LP_EN_PD)

/*! @brief Set the DFI_LP_EN_PD field to a new value. */
#define BW_DDRC_DFILPCFG0_DFI_LP_EN_PD(x, v) (HW_DDRC_DFILPCFG0_WR(x, (HW_DDRC_DFILPCFG0_RD(x) & ~BM_DDRC_DFILPCFG0_DFI_LP_EN_PD) | BF_DDRC_DFILPCFG0_DFI_LP_EN_PD(v)))
/*@}*/

/*!
 * @name Register DDRC_DFILPCFG0, field DFI_LP_WAKEUP_PD[7:4] (RW)
 *
 * Value to drive on dfi_lp_wakeup signal when Power Down mode is entered.
 * Determines the DFI's tlp_wakeup time. Value After Reset: 0x0 Exists: Always
 *
 * Values:
 * - 0 - 16 cycles
 * - 1 - 32 cycles
 * - 10 - 64 cycles
 * - 11 - 128 cycles
 * - 100 - 256 cycles
 * - 101 - 512 cycles
 * - 110 - 1024 cycles
 * - 111 - 2948 cycles
 * - 1000 - 4096 cycles
 * - 1001 - 8192 cycles
 * - 1010 - 16384 cycles
 * - 1011 - 32768 cycles
 * - 1100 - 65536 cycles
 * - 1101 - 131072 cycles
 * - 1110 - 262144 cycles
 * - 1111 - Unlimited
 */
/*@{*/
#define BP_DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD (4U) /*!< Bit position for DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD. */
#define BM_DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD (0x000000F0U) /*!< Bit mask for DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD. */
#define BS_DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD (4U) /*!< Bit field size in bits for DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD. */

/*! @brief Read current value of the DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD field. */
#define BR_DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD(x) (HW_DDRC_DFILPCFG0(x).B.DFI_LP_WAKEUP_PD)

/*! @brief Format value for bitfield DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD. */
#define BF_DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD) & BM_DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD)

/*! @brief Set the DFI_LP_WAKEUP_PD field to a new value. */
#define BW_DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD(x, v) (HW_DDRC_DFILPCFG0_WR(x, (HW_DDRC_DFILPCFG0_RD(x) & ~BM_DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD) | BF_DDRC_DFILPCFG0_DFI_LP_WAKEUP_PD(v)))
/*@}*/

/*!
 * @name Register DDRC_DFILPCFG0, field DFI_LP_EN_SR[8] (RW)
 *
 * Enables DFI Low Power interface handshaking during Self Refresh Entry / Exit.
 * Value After Reset: 0x0 Exists: Always
 *
 * Values:
 * - 0 - Disabled
 * - 1 - Enabled
 */
/*@{*/
#define BP_DDRC_DFILPCFG0_DFI_LP_EN_SR (8U) /*!< Bit position for DDRC_DFILPCFG0_DFI_LP_EN_SR. */
#define BM_DDRC_DFILPCFG0_DFI_LP_EN_SR (0x00000100U) /*!< Bit mask for DDRC_DFILPCFG0_DFI_LP_EN_SR. */
#define BS_DDRC_DFILPCFG0_DFI_LP_EN_SR (1U) /*!< Bit field size in bits for DDRC_DFILPCFG0_DFI_LP_EN_SR. */

/*! @brief Read current value of the DDRC_DFILPCFG0_DFI_LP_EN_SR field. */
#define BR_DDRC_DFILPCFG0_DFI_LP_EN_SR(x) (HW_DDRC_DFILPCFG0(x).B.DFI_LP_EN_SR)

/*! @brief Format value for bitfield DDRC_DFILPCFG0_DFI_LP_EN_SR. */
#define BF_DDRC_DFILPCFG0_DFI_LP_EN_SR(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFILPCFG0_DFI_LP_EN_SR) & BM_DDRC_DFILPCFG0_DFI_LP_EN_SR)

/*! @brief Set the DFI_LP_EN_SR field to a new value. */
#define BW_DDRC_DFILPCFG0_DFI_LP_EN_SR(x, v) (HW_DDRC_DFILPCFG0_WR(x, (HW_DDRC_DFILPCFG0_RD(x) & ~BM_DDRC_DFILPCFG0_DFI_LP_EN_SR) | BF_DDRC_DFILPCFG0_DFI_LP_EN_SR(v)))
/*@}*/

/*!
 * @name Register DDRC_DFILPCFG0, field DFI_LP_WAKEUP_SR[15:12] (RW)
 *
 * Value to drive on dfi_lp_wakeup signal when Self Refresh mode is entered.
 * Determines the DFI's tlp_wakeup time. Value After Reset: 0x0 Exists: Always
 *
 * Values:
 * - 0 - 16 cycles
 * - 1 - 32 cycles
 * - 10 - 64 cycles
 * - 11 - 128 cycles
 * - 100 - 256 cycles
 * - 101 - 512 cycles
 * - 110 - 1024 cycles
 * - 111 - 2948 cycles
 * - 1000 - 4096 cycles
 * - 1001 - 8192 cycles
 * - 1010 - 16384 cycles
 * - 1011 - 32768 cycles
 * - 1100 - 65536 cycles
 * - 1101 - 131072 cycles
 * - 1110 - 262144 cycles
 * - 1111 - Unlimited
 */
/*@{*/
#define BP_DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR (12U) /*!< Bit position for DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR. */
#define BM_DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR (0x0000F000U) /*!< Bit mask for DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR. */
#define BS_DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR (4U) /*!< Bit field size in bits for DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR. */

/*! @brief Read current value of the DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR field. */
#define BR_DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR(x) (HW_DDRC_DFILPCFG0(x).B.DFI_LP_WAKEUP_SR)

/*! @brief Format value for bitfield DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR. */
#define BF_DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR) & BM_DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR)

/*! @brief Set the DFI_LP_WAKEUP_SR field to a new value. */
#define BW_DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR(x, v) (HW_DDRC_DFILPCFG0_WR(x, (HW_DDRC_DFILPCFG0_RD(x) & ~BM_DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR) | BF_DDRC_DFILPCFG0_DFI_LP_WAKEUP_SR(v)))
/*@}*/

/*!
 * @name Register DDRC_DFILPCFG0, field DFI_LP_EN_DPD[16] (RW)
 *
 * Enables DFI Low Power interface handshaking during Deep Power Down Entry /
 * Exit. This is only present for designs supporting mDDR or LPDDR2 / LPDDR3
 * devices. Value After Reset: 0x0 Exists: MEMC_LPDDR2 == 1
 *
 * Values:
 * - 0 - Disabled
 * - 1 - Enabled
 */
/*@{*/
#define BP_DDRC_DFILPCFG0_DFI_LP_EN_DPD (16U) /*!< Bit position for DDRC_DFILPCFG0_DFI_LP_EN_DPD. */
#define BM_DDRC_DFILPCFG0_DFI_LP_EN_DPD (0x00010000U) /*!< Bit mask for DDRC_DFILPCFG0_DFI_LP_EN_DPD. */
#define BS_DDRC_DFILPCFG0_DFI_LP_EN_DPD (1U) /*!< Bit field size in bits for DDRC_DFILPCFG0_DFI_LP_EN_DPD. */

/*! @brief Read current value of the DDRC_DFILPCFG0_DFI_LP_EN_DPD field. */
#define BR_DDRC_DFILPCFG0_DFI_LP_EN_DPD(x) (HW_DDRC_DFILPCFG0(x).B.DFI_LP_EN_DPD)

/*! @brief Format value for bitfield DDRC_DFILPCFG0_DFI_LP_EN_DPD. */
#define BF_DDRC_DFILPCFG0_DFI_LP_EN_DPD(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFILPCFG0_DFI_LP_EN_DPD) & BM_DDRC_DFILPCFG0_DFI_LP_EN_DPD)

/*! @brief Set the DFI_LP_EN_DPD field to a new value. */
#define BW_DDRC_DFILPCFG0_DFI_LP_EN_DPD(x, v) (HW_DDRC_DFILPCFG0_WR(x, (HW_DDRC_DFILPCFG0_RD(x) & ~BM_DDRC_DFILPCFG0_DFI_LP_EN_DPD) | BF_DDRC_DFILPCFG0_DFI_LP_EN_DPD(v)))
/*@}*/

/*!
 * @name Register DDRC_DFILPCFG0, field DFI_LP_WAKEUP_DPD[23:20] (RW)
 *
 * Value to drive on dfi_lp_wakeup signal when Deep Power Down mode is entered.
 * Determines the DFI's tlp_wakeup time. This is only present for designs
 * supporting mDDR or LPDDR2 / LPDDR3 devices. Value After Reset: 0x0 Exists:
 * MEMC_MOBILE == 1 ||MEMC_LPDDR2 == 1
 *
 * Values:
 * - 0 - 16 cycles
 * - 1 - 32 cycles
 * - 10 - 64 cycles
 * - 11 - 128 cycles
 * - 100 - 256 cycles
 * - 101 - 512 cycles
 * - 110 - 1024 cycles
 * - 111 - 2948 cycles
 * - 1000 - 4096 cycles
 * - 1001 - 8192 cycles
 * - 1010 - 16384 cycles
 * - 1011 - 32768 cycles
 * - 1100 - 65536 cycles
 * - 1101 - 131072 cycles
 * - 1110 - 262144 cycles
 * - 1111 - Unlimited
 */
/*@{*/
#define BP_DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD (20U) /*!< Bit position for DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD. */
#define BM_DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD (0x00F00000U) /*!< Bit mask for DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD. */
#define BS_DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD (4U) /*!< Bit field size in bits for DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD. */

/*! @brief Read current value of the DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD field. */
#define BR_DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD(x) (HW_DDRC_DFILPCFG0(x).B.DFI_LP_WAKEUP_DPD)

/*! @brief Format value for bitfield DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD. */
#define BF_DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD) & BM_DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD)

/*! @brief Set the DFI_LP_WAKEUP_DPD field to a new value. */
#define BW_DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD(x, v) (HW_DDRC_DFILPCFG0_WR(x, (HW_DDRC_DFILPCFG0_RD(x) & ~BM_DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD) | BF_DDRC_DFILPCFG0_DFI_LP_WAKEUP_DPD(v)))
/*@}*/

/*!
 * @name Register DDRC_DFILPCFG0, field DFI_TLP_RESP[27:24] (RW)
 *
 * Setting for DFI's tlp_resp time. Same value is used for both Power Down, Self
 * Refresh, Deep Power Down and Maximum Power Saving modes. DFI 2.1
 * specification onwards, recommends using a fixed value of 7 always. Value After Reset: 0x7
 * Exists: Always
 */
/*@{*/
#define BP_DDRC_DFILPCFG0_DFI_TLP_RESP (24U) /*!< Bit position for DDRC_DFILPCFG0_DFI_TLP_RESP. */
#define BM_DDRC_DFILPCFG0_DFI_TLP_RESP (0x0F000000U) /*!< Bit mask for DDRC_DFILPCFG0_DFI_TLP_RESP. */
#define BS_DDRC_DFILPCFG0_DFI_TLP_RESP (4U) /*!< Bit field size in bits for DDRC_DFILPCFG0_DFI_TLP_RESP. */

/*! @brief Read current value of the DDRC_DFILPCFG0_DFI_TLP_RESP field. */
#define BR_DDRC_DFILPCFG0_DFI_TLP_RESP(x) (HW_DDRC_DFILPCFG0(x).B.DFI_TLP_RESP)

/*! @brief Format value for bitfield DDRC_DFILPCFG0_DFI_TLP_RESP. */
#define BF_DDRC_DFILPCFG0_DFI_TLP_RESP(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFILPCFG0_DFI_TLP_RESP) & BM_DDRC_DFILPCFG0_DFI_TLP_RESP)

/*! @brief Set the DFI_TLP_RESP field to a new value. */
#define BW_DDRC_DFILPCFG0_DFI_TLP_RESP(x, v) (HW_DDRC_DFILPCFG0_WR(x, (HW_DDRC_DFILPCFG0_RD(x) & ~BM_DDRC_DFILPCFG0_DFI_TLP_RESP) | BF_DDRC_DFILPCFG0_DFI_TLP_RESP(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DFIUPD0 - DFI Update Register 0
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DFIUPD0 - DFI Update Register 0 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_dfiupd0
{
    uint32_t U;
    struct _hw_ddrc_dfiupd0_bitfields
    {
        uint32_t DFI_T_CTRLUP_MIN : 10; /*!< [9:0]  */
        uint32_t RESERVED0 : 6;        /*!< [15:10]  */
        uint32_t DFI_T_CTRLUP_MAX : 10; /*!< [25:16]  */
        uint32_t RESERVED1 : 4;        /*!< [29:26]  */
        uint32_t DIS_AUTO_CTRLUPD_SRX : 1; /*!< [30]  */
        uint32_t DIS_AUTO_CTRLUPD : 1; /*!< [31]  */
    } B;
} hw_ddrc_dfiupd0_t;

/*!
 * @name Constants and macros for entire DDRC_DFIUPD0 register
 */
/*@{*/
#define HW_DDRC_DFIUPD0_ADDR(x)  ((uintptr_t)(x) + 0x1A0U)

#define HW_DDRC_DFIUPD0(x)       (*(__IO hw_ddrc_dfiupd0_t *) HW_DDRC_DFIUPD0_ADDR(x))
#define HW_DDRC_DFIUPD0_RD(x)    (HW_DDRC_DFIUPD0(x).U)
#define HW_DDRC_DFIUPD0_WR(x, v) (HW_DDRC_DFIUPD0(x).U = (v))
#define HW_DDRC_DFIUPD0_SET(x, v) (HW_DDRC_DFIUPD0_WR(x, HW_DDRC_DFIUPD0_RD(x) |  (v)))
#define HW_DDRC_DFIUPD0_CLR(x, v) (HW_DDRC_DFIUPD0_WR(x, HW_DDRC_DFIUPD0_RD(x) & ~(v)))
#define HW_DDRC_DFIUPD0_TOG(x, v) (HW_DDRC_DFIUPD0_WR(x, HW_DDRC_DFIUPD0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DFIUPD0 bitfields
 */

/*!
 * @name Register DDRC_DFIUPD0, field DFI_T_CTRLUP_MIN[9:0] (RW)
 *
 * Specifies the minimum number of clock cycles that the dfi_ctrlupd_req signal
 * must be asserted. The DDRC expects the PHY to respond within this time. If the
 * PHY does not respond, the DDRC will de-assert dfi_ctrlupd_req after
 * dfi_t_ctrlup_min + 2 cycles. Lowest value to assign to this variable is 0x3. Unit:
 * Clocks Value After Reset: 0x3 Exists: Always
 */
/*@{*/
#define BP_DDRC_DFIUPD0_DFI_T_CTRLUP_MIN (0U) /*!< Bit position for DDRC_DFIUPD0_DFI_T_CTRLUP_MIN. */
#define BM_DDRC_DFIUPD0_DFI_T_CTRLUP_MIN (0x000003FFU) /*!< Bit mask for DDRC_DFIUPD0_DFI_T_CTRLUP_MIN. */
#define BS_DDRC_DFIUPD0_DFI_T_CTRLUP_MIN (10U) /*!< Bit field size in bits for DDRC_DFIUPD0_DFI_T_CTRLUP_MIN. */

/*! @brief Read current value of the DDRC_DFIUPD0_DFI_T_CTRLUP_MIN field. */
#define BR_DDRC_DFIUPD0_DFI_T_CTRLUP_MIN(x) (HW_DDRC_DFIUPD0(x).B.DFI_T_CTRLUP_MIN)

/*! @brief Format value for bitfield DDRC_DFIUPD0_DFI_T_CTRLUP_MIN. */
#define BF_DDRC_DFIUPD0_DFI_T_CTRLUP_MIN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFIUPD0_DFI_T_CTRLUP_MIN) & BM_DDRC_DFIUPD0_DFI_T_CTRLUP_MIN)

/*! @brief Set the DFI_T_CTRLUP_MIN field to a new value. */
#define BW_DDRC_DFIUPD0_DFI_T_CTRLUP_MIN(x, v) (HW_DDRC_DFIUPD0_WR(x, (HW_DDRC_DFIUPD0_RD(x) & ~BM_DDRC_DFIUPD0_DFI_T_CTRLUP_MIN) | BF_DDRC_DFIUPD0_DFI_T_CTRLUP_MIN(v)))
/*@}*/

/*!
 * @name Register DDRC_DFIUPD0, field DFI_T_CTRLUP_MAX[25:16] (RW)
 *
 * Specifies themaximum number of clock cycles that the dfi_ctrlupd_req signal
 * can assert. The lowest value to assign to this variable is 0x40. Unit: Clocks
 * Value After Reset: 0x40 Exists: Always
 */
/*@{*/
#define BP_DDRC_DFIUPD0_DFI_T_CTRLUP_MAX (16U) /*!< Bit position for DDRC_DFIUPD0_DFI_T_CTRLUP_MAX. */
#define BM_DDRC_DFIUPD0_DFI_T_CTRLUP_MAX (0x03FF0000U) /*!< Bit mask for DDRC_DFIUPD0_DFI_T_CTRLUP_MAX. */
#define BS_DDRC_DFIUPD0_DFI_T_CTRLUP_MAX (10U) /*!< Bit field size in bits for DDRC_DFIUPD0_DFI_T_CTRLUP_MAX. */

/*! @brief Read current value of the DDRC_DFIUPD0_DFI_T_CTRLUP_MAX field. */
#define BR_DDRC_DFIUPD0_DFI_T_CTRLUP_MAX(x) (HW_DDRC_DFIUPD0(x).B.DFI_T_CTRLUP_MAX)

/*! @brief Format value for bitfield DDRC_DFIUPD0_DFI_T_CTRLUP_MAX. */
#define BF_DDRC_DFIUPD0_DFI_T_CTRLUP_MAX(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFIUPD0_DFI_T_CTRLUP_MAX) & BM_DDRC_DFIUPD0_DFI_T_CTRLUP_MAX)

/*! @brief Set the DFI_T_CTRLUP_MAX field to a new value. */
#define BW_DDRC_DFIUPD0_DFI_T_CTRLUP_MAX(x, v) (HW_DDRC_DFIUPD0_WR(x, (HW_DDRC_DFIUPD0_RD(x) & ~BM_DDRC_DFIUPD0_DFI_T_CTRLUP_MAX) | BF_DDRC_DFIUPD0_DFI_T_CTRLUP_MAX(v)))
/*@}*/

/*!
 * @name Register DDRC_DFIUPD0, field DIS_AUTO_CTRLUPD_SRX[30] (RW)
 *
 * When '1', disable the automatic dfi_ctrlupd_req generation by the DDRC
 * following a self-refresh exit. The core must issue the dfi_ctrlupd_req signal using
 * register reg_ddrc_ctrlupd. This register field is changeable on the fly. When
 * '0', DDRC issues a dfi_ctrlupd_req after exiting self- refresh. Value After
 * Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD_SRX (30U) /*!< Bit position for DDRC_DFIUPD0_DIS_AUTO_CTRLUPD_SRX. */
#define BM_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD_SRX (0x40000000U) /*!< Bit mask for DDRC_DFIUPD0_DIS_AUTO_CTRLUPD_SRX. */
#define BS_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD_SRX (1U) /*!< Bit field size in bits for DDRC_DFIUPD0_DIS_AUTO_CTRLUPD_SRX. */

/*! @brief Read current value of the DDRC_DFIUPD0_DIS_AUTO_CTRLUPD_SRX field. */
#define BR_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD_SRX(x) (HW_DDRC_DFIUPD0(x).B.DIS_AUTO_CTRLUPD_SRX)

/*! @brief Format value for bitfield DDRC_DFIUPD0_DIS_AUTO_CTRLUPD_SRX. */
#define BF_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD_SRX(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD_SRX) & BM_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD_SRX)

/*! @brief Set the DIS_AUTO_CTRLUPD_SRX field to a new value. */
#define BW_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD_SRX(x, v) (HW_DDRC_DFIUPD0_WR(x, (HW_DDRC_DFIUPD0_RD(x) & ~BM_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD_SRX) | BF_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD_SRX(v)))
/*@}*/

/*!
 * @name Register DDRC_DFIUPD0, field DIS_AUTO_CTRLUPD[31] (RW)
 *
 * When '1', disable the automatic dfi_ctrlupd_req generation by the DDRC. The
 * core must issue the dfi_ctrlupd_req signal using register reg_ddrc_ctrlupd.
 * This register field is changeable on the fly. When '0', DDRC issues
 * dfi_ctrlupd_req periodically. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD (31U) /*!< Bit position for DDRC_DFIUPD0_DIS_AUTO_CTRLUPD. */
#define BM_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD (0x80000000U) /*!< Bit mask for DDRC_DFIUPD0_DIS_AUTO_CTRLUPD. */
#define BS_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD (1U) /*!< Bit field size in bits for DDRC_DFIUPD0_DIS_AUTO_CTRLUPD. */

/*! @brief Read current value of the DDRC_DFIUPD0_DIS_AUTO_CTRLUPD field. */
#define BR_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD(x) (HW_DDRC_DFIUPD0(x).B.DIS_AUTO_CTRLUPD)

/*! @brief Format value for bitfield DDRC_DFIUPD0_DIS_AUTO_CTRLUPD. */
#define BF_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD) & BM_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD)

/*! @brief Set the DIS_AUTO_CTRLUPD field to a new value. */
#define BW_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD(x, v) (HW_DDRC_DFIUPD0_WR(x, (HW_DDRC_DFIUPD0_RD(x) & ~BM_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD) | BF_DDRC_DFIUPD0_DIS_AUTO_CTRLUPD(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DFIUPD1 - DFI Update Register 1
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DFIUPD1 - DFI Update Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_dfiupd1
{
    uint32_t U;
    struct _hw_ddrc_dfiupd1_bitfields
    {
        uint32_t DFI_T_CTRLUPD_INTERVAL_MAX_X1024 : 8; /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t DFI_T_CTRLUPD_INTERVAL_MIN_X1024 : 8; /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_ddrc_dfiupd1_t;

/*!
 * @name Constants and macros for entire DDRC_DFIUPD1 register
 */
/*@{*/
#define HW_DDRC_DFIUPD1_ADDR(x)  ((uintptr_t)(x) + 0x1A4U)

#define HW_DDRC_DFIUPD1(x)       (*(__IO hw_ddrc_dfiupd1_t *) HW_DDRC_DFIUPD1_ADDR(x))
#define HW_DDRC_DFIUPD1_RD(x)    (HW_DDRC_DFIUPD1(x).U)
#define HW_DDRC_DFIUPD1_WR(x, v) (HW_DDRC_DFIUPD1(x).U = (v))
#define HW_DDRC_DFIUPD1_SET(x, v) (HW_DDRC_DFIUPD1_WR(x, HW_DDRC_DFIUPD1_RD(x) |  (v)))
#define HW_DDRC_DFIUPD1_CLR(x, v) (HW_DDRC_DFIUPD1_WR(x, HW_DDRC_DFIUPD1_RD(x) & ~(v)))
#define HW_DDRC_DFIUPD1_TOG(x, v) (HW_DDRC_DFIUPD1_WR(x, HW_DDRC_DFIUPD1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DFIUPD1 bitfields
 */

/*!
 * @name Register DDRC_DFIUPD1, field DFI_T_CTRLUPD_INTERVAL_MAX_X1024[7:0] (RW)
 *
 * This is the maximum amount of time between DDRC initiated DFI update
 * requests. This timer resets with each update request; when the timer expires
 * dfi_ctrlupd_req is sent and traffic is blocked until the dfi_ctrlupd_ackx is received.
 * PHY can use this idle time to recalibrate the delay lines to the DLLs. The DFI
 * controller update is also used to reset PHY FIFO pointers in case of data
 * capture errors. Updates are required to maintain calibration over PVT, but
 * frequent updates may impact performance. Value programmed for
 * DFIUPD1.dfi_t_ctrlupd_interval_max_x1024 must be greater than
 * DFIUPD1.dfi_t_ctrlupd_interval_min_x1024. Unit: 1024 clocks Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024 (0U) /*!< Bit position for DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024. */
#define BM_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024 (0x000000FFU) /*!< Bit mask for DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024. */
#define BS_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024 (8U) /*!< Bit field size in bits for DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024. */

/*! @brief Read current value of the DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024 field. */
#define BR_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024(x) (HW_DDRC_DFIUPD1(x).B.DFI_T_CTRLUPD_INTERVAL_MAX_X1024)

/*! @brief Format value for bitfield DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024. */
#define BF_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024) & BM_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024)

/*! @brief Set the DFI_T_CTRLUPD_INTERVAL_MAX_X1024 field to a new value. */
#define BW_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024(x, v) (HW_DDRC_DFIUPD1_WR(x, (HW_DDRC_DFIUPD1_RD(x) & ~BM_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024) | BF_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MAX_X1024(v)))
/*@}*/

/*!
 * @name Register DDRC_DFIUPD1, field DFI_T_CTRLUPD_INTERVAL_MIN_X1024[23:16] (RW)
 *
 * This is the minimum amount of time between DDRC initiated DFI update requests
 * (which is executed whenever the DDRC is idle). Set this number higher to
 * reduce the frequency of update requests, which can have a small impact on the
 * latency of the first read request when the DDRC is idle. Unit: 1024 clocks Value
 * After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024 (16U) /*!< Bit position for DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024. */
#define BM_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024 (0x00FF0000U) /*!< Bit mask for DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024. */
#define BS_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024 (8U) /*!< Bit field size in bits for DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024. */

/*! @brief Read current value of the DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024 field. */
#define BR_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024(x) (HW_DDRC_DFIUPD1(x).B.DFI_T_CTRLUPD_INTERVAL_MIN_X1024)

/*! @brief Format value for bitfield DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024. */
#define BF_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024) & BM_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024)

/*! @brief Set the DFI_T_CTRLUPD_INTERVAL_MIN_X1024 field to a new value. */
#define BW_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024(x, v) (HW_DDRC_DFIUPD1_WR(x, (HW_DDRC_DFIUPD1_RD(x) & ~BM_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024) | BF_DDRC_DFIUPD1_DFI_T_CTRLUPD_INTERVAL_MIN_X1024(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DFIUPD2 - DFI Update Register 2
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DFIUPD2 - DFI Update Register 2 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_dfiupd2
{
    uint32_t U;
    struct _hw_ddrc_dfiupd2_bitfields
    {
        uint32_t DFI_PHYUPD_TYPE0 : 12; /*!< [11:0]  */
        uint32_t RESERVED0 : 4;        /*!< [15:12]  */
        uint32_t DFI_PHYUPD_TYPE1 : 12; /*!< [27:16]  */
        uint32_t RESERVED1 : 3;        /*!< [30:28]  */
        uint32_t DFI_PHYUPD_EN : 1;    /*!< [31]  */
    } B;
} hw_ddrc_dfiupd2_t;

/*!
 * @name Constants and macros for entire DDRC_DFIUPD2 register
 */
/*@{*/
#define HW_DDRC_DFIUPD2_ADDR(x)  ((uintptr_t)(x) + 0x1A8U)

#define HW_DDRC_DFIUPD2(x)       (*(__IO hw_ddrc_dfiupd2_t *) HW_DDRC_DFIUPD2_ADDR(x))
#define HW_DDRC_DFIUPD2_RD(x)    (HW_DDRC_DFIUPD2(x).U)
#define HW_DDRC_DFIUPD2_WR(x, v) (HW_DDRC_DFIUPD2(x).U = (v))
#define HW_DDRC_DFIUPD2_SET(x, v) (HW_DDRC_DFIUPD2_WR(x, HW_DDRC_DFIUPD2_RD(x) |  (v)))
#define HW_DDRC_DFIUPD2_CLR(x, v) (HW_DDRC_DFIUPD2_WR(x, HW_DDRC_DFIUPD2_RD(x) & ~(v)))
#define HW_DDRC_DFIUPD2_TOG(x, v) (HW_DDRC_DFIUPD2_WR(x, HW_DDRC_DFIUPD2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DFIUPD2 bitfields
 */

/*!
 * @name Register DDRC_DFIUPD2, field DFI_PHYUPD_TYPE0[11:0] (RW)
 *
 * Specifies the maximum number of DFI clock cycles that the dfi_phyupd_req
 * signal may remain asserted after the assertion of the dfi_phyupd_ack signal for
 * dfi_phyupd_type = 2'b00. Is used in conjunction with value defined via
 * DFIUPD4.dfi_phyupd_type0_mult. The dfi_phyupd_req signal may de-assert at any cycle
 * after the assertion of the dfi_phyupd_ack signal. Value After Reset: 0x10 Exists:
 * Always
 */
/*@{*/
#define BP_DDRC_DFIUPD2_DFI_PHYUPD_TYPE0 (0U) /*!< Bit position for DDRC_DFIUPD2_DFI_PHYUPD_TYPE0. */
#define BM_DDRC_DFIUPD2_DFI_PHYUPD_TYPE0 (0x00000FFFU) /*!< Bit mask for DDRC_DFIUPD2_DFI_PHYUPD_TYPE0. */
#define BS_DDRC_DFIUPD2_DFI_PHYUPD_TYPE0 (12U) /*!< Bit field size in bits for DDRC_DFIUPD2_DFI_PHYUPD_TYPE0. */

/*! @brief Read current value of the DDRC_DFIUPD2_DFI_PHYUPD_TYPE0 field. */
#define BR_DDRC_DFIUPD2_DFI_PHYUPD_TYPE0(x) (HW_DDRC_DFIUPD2(x).B.DFI_PHYUPD_TYPE0)

/*! @brief Format value for bitfield DDRC_DFIUPD2_DFI_PHYUPD_TYPE0. */
#define BF_DDRC_DFIUPD2_DFI_PHYUPD_TYPE0(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFIUPD2_DFI_PHYUPD_TYPE0) & BM_DDRC_DFIUPD2_DFI_PHYUPD_TYPE0)

/*! @brief Set the DFI_PHYUPD_TYPE0 field to a new value. */
#define BW_DDRC_DFIUPD2_DFI_PHYUPD_TYPE0(x, v) (HW_DDRC_DFIUPD2_WR(x, (HW_DDRC_DFIUPD2_RD(x) & ~BM_DDRC_DFIUPD2_DFI_PHYUPD_TYPE0) | BF_DDRC_DFIUPD2_DFI_PHYUPD_TYPE0(v)))
/*@}*/

/*!
 * @name Register DDRC_DFIUPD2, field DFI_PHYUPD_TYPE1[27:16] (RW)
 *
 * Specifies the maximum number of DFI clock cycles that the dfi_phyupd_req
 * signal may remain asserted after the assertion of the dfi_phyupd_ack signal for
 * dfi_phyupd_type = 2'b01. Is used in conjunction with value defined via
 * DFIUPD4.dfi_phyupd_type1_mult. The dfi_phyupd_req signal may de-assert at any cycle
 * after the assertion of the dfi_phyupd_ack signal. Value After Reset: 0x10 Exists:
 * Always
 */
/*@{*/
#define BP_DDRC_DFIUPD2_DFI_PHYUPD_TYPE1 (16U) /*!< Bit position for DDRC_DFIUPD2_DFI_PHYUPD_TYPE1. */
#define BM_DDRC_DFIUPD2_DFI_PHYUPD_TYPE1 (0x0FFF0000U) /*!< Bit mask for DDRC_DFIUPD2_DFI_PHYUPD_TYPE1. */
#define BS_DDRC_DFIUPD2_DFI_PHYUPD_TYPE1 (12U) /*!< Bit field size in bits for DDRC_DFIUPD2_DFI_PHYUPD_TYPE1. */

/*! @brief Read current value of the DDRC_DFIUPD2_DFI_PHYUPD_TYPE1 field. */
#define BR_DDRC_DFIUPD2_DFI_PHYUPD_TYPE1(x) (HW_DDRC_DFIUPD2(x).B.DFI_PHYUPD_TYPE1)

/*! @brief Format value for bitfield DDRC_DFIUPD2_DFI_PHYUPD_TYPE1. */
#define BF_DDRC_DFIUPD2_DFI_PHYUPD_TYPE1(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFIUPD2_DFI_PHYUPD_TYPE1) & BM_DDRC_DFIUPD2_DFI_PHYUPD_TYPE1)

/*! @brief Set the DFI_PHYUPD_TYPE1 field to a new value. */
#define BW_DDRC_DFIUPD2_DFI_PHYUPD_TYPE1(x, v) (HW_DDRC_DFIUPD2_WR(x, (HW_DDRC_DFIUPD2_RD(x) & ~BM_DDRC_DFIUPD2_DFI_PHYUPD_TYPE1) | BF_DDRC_DFIUPD2_DFI_PHYUPD_TYPE1(v)))
/*@}*/

/*!
 * @name Register DDRC_DFIUPD2, field DFI_PHYUPD_EN[31] (RW)
 *
 * Enables the support for acknowledging PHY- initiated updates. Value After
 * Reset: 0x1 Exists: Always
 *
 * Values:
 * - 0 - Disabled
 * - 1 - Enabled
 */
/*@{*/
#define BP_DDRC_DFIUPD2_DFI_PHYUPD_EN (31U) /*!< Bit position for DDRC_DFIUPD2_DFI_PHYUPD_EN. */
#define BM_DDRC_DFIUPD2_DFI_PHYUPD_EN (0x80000000U) /*!< Bit mask for DDRC_DFIUPD2_DFI_PHYUPD_EN. */
#define BS_DDRC_DFIUPD2_DFI_PHYUPD_EN (1U) /*!< Bit field size in bits for DDRC_DFIUPD2_DFI_PHYUPD_EN. */

/*! @brief Read current value of the DDRC_DFIUPD2_DFI_PHYUPD_EN field. */
#define BR_DDRC_DFIUPD2_DFI_PHYUPD_EN(x) (HW_DDRC_DFIUPD2(x).B.DFI_PHYUPD_EN)

/*! @brief Format value for bitfield DDRC_DFIUPD2_DFI_PHYUPD_EN. */
#define BF_DDRC_DFIUPD2_DFI_PHYUPD_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFIUPD2_DFI_PHYUPD_EN) & BM_DDRC_DFIUPD2_DFI_PHYUPD_EN)

/*! @brief Set the DFI_PHYUPD_EN field to a new value. */
#define BW_DDRC_DFIUPD2_DFI_PHYUPD_EN(x, v) (HW_DDRC_DFIUPD2_WR(x, (HW_DDRC_DFIUPD2_RD(x) & ~BM_DDRC_DFIUPD2_DFI_PHYUPD_EN) | BF_DDRC_DFIUPD2_DFI_PHYUPD_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DFIUPD3 - DFI Update Register 3
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DFIUPD3 - DFI Update Register 3 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_dfiupd3
{
    uint32_t U;
    struct _hw_ddrc_dfiupd3_bitfields
    {
        uint32_t DFI_PHYUPD_TYPE2 : 12; /*!< [11:0]  */
        uint32_t RESERVED0 : 4;        /*!< [15:12]  */
        uint32_t DFI_PHYUPD_TYPE3 : 12; /*!< [27:16]  */
        uint32_t RESERVED1 : 4;        /*!< [31:28]  */
    } B;
} hw_ddrc_dfiupd3_t;

/*!
 * @name Constants and macros for entire DDRC_DFIUPD3 register
 */
/*@{*/
#define HW_DDRC_DFIUPD3_ADDR(x)  ((uintptr_t)(x) + 0x1ACU)

#define HW_DDRC_DFIUPD3(x)       (*(__IO hw_ddrc_dfiupd3_t *) HW_DDRC_DFIUPD3_ADDR(x))
#define HW_DDRC_DFIUPD3_RD(x)    (HW_DDRC_DFIUPD3(x).U)
#define HW_DDRC_DFIUPD3_WR(x, v) (HW_DDRC_DFIUPD3(x).U = (v))
#define HW_DDRC_DFIUPD3_SET(x, v) (HW_DDRC_DFIUPD3_WR(x, HW_DDRC_DFIUPD3_RD(x) |  (v)))
#define HW_DDRC_DFIUPD3_CLR(x, v) (HW_DDRC_DFIUPD3_WR(x, HW_DDRC_DFIUPD3_RD(x) & ~(v)))
#define HW_DDRC_DFIUPD3_TOG(x, v) (HW_DDRC_DFIUPD3_WR(x, HW_DDRC_DFIUPD3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DFIUPD3 bitfields
 */

/*!
 * @name Register DDRC_DFIUPD3, field DFI_PHYUPD_TYPE2[11:0] (RW)
 *
 * Specifies the maximum number of DFI clock cycles that the dfi_phyupd_req
 * signal may remain asserted after the assertion of the dfi_phyupd_ack signal for
 * dfi_phyupd_type = 2'b10. Is used in conjunction with value defined via
 * DFIUPD4.dfi_phyupd_type2_mult. The dfi_phyupd_req signal may de-assert at any cycle
 * after the assertion of the dfi_phyupd_ack signal. Value After Reset: 0x10 Exists:
 * Always
 */
/*@{*/
#define BP_DDRC_DFIUPD3_DFI_PHYUPD_TYPE2 (0U) /*!< Bit position for DDRC_DFIUPD3_DFI_PHYUPD_TYPE2. */
#define BM_DDRC_DFIUPD3_DFI_PHYUPD_TYPE2 (0x00000FFFU) /*!< Bit mask for DDRC_DFIUPD3_DFI_PHYUPD_TYPE2. */
#define BS_DDRC_DFIUPD3_DFI_PHYUPD_TYPE2 (12U) /*!< Bit field size in bits for DDRC_DFIUPD3_DFI_PHYUPD_TYPE2. */

/*! @brief Read current value of the DDRC_DFIUPD3_DFI_PHYUPD_TYPE2 field. */
#define BR_DDRC_DFIUPD3_DFI_PHYUPD_TYPE2(x) (HW_DDRC_DFIUPD3(x).B.DFI_PHYUPD_TYPE2)

/*! @brief Format value for bitfield DDRC_DFIUPD3_DFI_PHYUPD_TYPE2. */
#define BF_DDRC_DFIUPD3_DFI_PHYUPD_TYPE2(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFIUPD3_DFI_PHYUPD_TYPE2) & BM_DDRC_DFIUPD3_DFI_PHYUPD_TYPE2)

/*! @brief Set the DFI_PHYUPD_TYPE2 field to a new value. */
#define BW_DDRC_DFIUPD3_DFI_PHYUPD_TYPE2(x, v) (HW_DDRC_DFIUPD3_WR(x, (HW_DDRC_DFIUPD3_RD(x) & ~BM_DDRC_DFIUPD3_DFI_PHYUPD_TYPE2) | BF_DDRC_DFIUPD3_DFI_PHYUPD_TYPE2(v)))
/*@}*/

/*!
 * @name Register DDRC_DFIUPD3, field DFI_PHYUPD_TYPE3[27:16] (RW)
 *
 * Specifies the maximum number of DFI clock cycles that the dfi_phyupd_req
 * signal may remain asserted after the assertion of the dfi_phyupd_ack signal for
 * dfi_phyupd_type = 2'b11. Is used in conjunction with value defined via
 * DFIUPD4.dfi_phyupd_type3_mult. The dfi_phyupd_req signal may de-assert at any cycle
 * after the assertion of the dfi_phyupd_ack signal. Value After Reset: 0x10 Exists:
 * Always
 */
/*@{*/
#define BP_DDRC_DFIUPD3_DFI_PHYUPD_TYPE3 (16U) /*!< Bit position for DDRC_DFIUPD3_DFI_PHYUPD_TYPE3. */
#define BM_DDRC_DFIUPD3_DFI_PHYUPD_TYPE3 (0x0FFF0000U) /*!< Bit mask for DDRC_DFIUPD3_DFI_PHYUPD_TYPE3. */
#define BS_DDRC_DFIUPD3_DFI_PHYUPD_TYPE3 (12U) /*!< Bit field size in bits for DDRC_DFIUPD3_DFI_PHYUPD_TYPE3. */

/*! @brief Read current value of the DDRC_DFIUPD3_DFI_PHYUPD_TYPE3 field. */
#define BR_DDRC_DFIUPD3_DFI_PHYUPD_TYPE3(x) (HW_DDRC_DFIUPD3(x).B.DFI_PHYUPD_TYPE3)

/*! @brief Format value for bitfield DDRC_DFIUPD3_DFI_PHYUPD_TYPE3. */
#define BF_DDRC_DFIUPD3_DFI_PHYUPD_TYPE3(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFIUPD3_DFI_PHYUPD_TYPE3) & BM_DDRC_DFIUPD3_DFI_PHYUPD_TYPE3)

/*! @brief Set the DFI_PHYUPD_TYPE3 field to a new value. */
#define BW_DDRC_DFIUPD3_DFI_PHYUPD_TYPE3(x, v) (HW_DDRC_DFIUPD3_WR(x, (HW_DDRC_DFIUPD3_RD(x) & ~BM_DDRC_DFIUPD3_DFI_PHYUPD_TYPE3) | BF_DDRC_DFIUPD3_DFI_PHYUPD_TYPE3(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DFIMISC - DFI Miscellaneous Control Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DFIMISC - DFI Miscellaneous Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_dfimisc
{
    uint32_t U;
    struct _hw_ddrc_dfimisc_bitfields
    {
        uint32_t DFI_INIT_COMPLETE_EN : 1; /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_ddrc_dfimisc_t;

/*!
 * @name Constants and macros for entire DDRC_DFIMISC register
 */
/*@{*/
#define HW_DDRC_DFIMISC_ADDR(x)  ((uintptr_t)(x) + 0x1B0U)

#define HW_DDRC_DFIMISC(x)       (*(__IO hw_ddrc_dfimisc_t *) HW_DDRC_DFIMISC_ADDR(x))
#define HW_DDRC_DFIMISC_RD(x)    (HW_DDRC_DFIMISC(x).U)
#define HW_DDRC_DFIMISC_WR(x, v) (HW_DDRC_DFIMISC(x).U = (v))
#define HW_DDRC_DFIMISC_SET(x, v) (HW_DDRC_DFIMISC_WR(x, HW_DDRC_DFIMISC_RD(x) |  (v)))
#define HW_DDRC_DFIMISC_CLR(x, v) (HW_DDRC_DFIMISC_WR(x, HW_DDRC_DFIMISC_RD(x) & ~(v)))
#define HW_DDRC_DFIMISC_TOG(x, v) (HW_DDRC_DFIMISC_WR(x, HW_DDRC_DFIMISC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DFIMISC bitfields
 */

/*!
 * @name Register DDRC_DFIMISC, field DFI_INIT_COMPLETE_EN[0] (RW)
 *
 * PHY initialization complete enable signal. When asserted the
 * dfi_init_complete signal can be used to trigger SDRAM initialisation Value After Reset: 0x1
 * Exists: Always
 */
/*@{*/
#define BP_DDRC_DFIMISC_DFI_INIT_COMPLETE_EN (0U) /*!< Bit position for DDRC_DFIMISC_DFI_INIT_COMPLETE_EN. */
#define BM_DDRC_DFIMISC_DFI_INIT_COMPLETE_EN (0x00000001U) /*!< Bit mask for DDRC_DFIMISC_DFI_INIT_COMPLETE_EN. */
#define BS_DDRC_DFIMISC_DFI_INIT_COMPLETE_EN (1U) /*!< Bit field size in bits for DDRC_DFIMISC_DFI_INIT_COMPLETE_EN. */

/*! @brief Read current value of the DDRC_DFIMISC_DFI_INIT_COMPLETE_EN field. */
#define BR_DDRC_DFIMISC_DFI_INIT_COMPLETE_EN(x) (HW_DDRC_DFIMISC(x).B.DFI_INIT_COMPLETE_EN)

/*! @brief Format value for bitfield DDRC_DFIMISC_DFI_INIT_COMPLETE_EN. */
#define BF_DDRC_DFIMISC_DFI_INIT_COMPLETE_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DFIMISC_DFI_INIT_COMPLETE_EN) & BM_DDRC_DFIMISC_DFI_INIT_COMPLETE_EN)

/*! @brief Set the DFI_INIT_COMPLETE_EN field to a new value. */
#define BW_DDRC_DFIMISC_DFI_INIT_COMPLETE_EN(x, v) (HW_DDRC_DFIMISC_WR(x, (HW_DDRC_DFIMISC_RD(x) & ~BM_DDRC_DFIMISC_DFI_INIT_COMPLETE_EN) | BF_DDRC_DFIMISC_DFI_INIT_COMPLETE_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_ADDRMAP0 - Address Map Register 0
 ******************************************************************************/

/*!
 * @brief HW_DDRC_ADDRMAP0 - Address Map Register 0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: (MEMC_NUM_RANKS>1)
 */
typedef union _hw_ddrc_addrmap0
{
    uint32_t U;
    struct _hw_ddrc_addrmap0_bitfields
    {
        uint32_t ADDRMAP_CS_BIT0 : 5;  /*!< [4:0]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t ADDRMAP_CS_BIT1 : 5;  /*!< [12:8]  */
        uint32_t RESERVED1 : 19;       /*!< [31:13]  */
    } B;
} hw_ddrc_addrmap0_t;

/*!
 * @name Constants and macros for entire DDRC_ADDRMAP0 register
 */
/*@{*/
#define HW_DDRC_ADDRMAP0_ADDR(x) ((uintptr_t)(x) + 0x200U)

#define HW_DDRC_ADDRMAP0(x)      (*(__IO hw_ddrc_addrmap0_t *) HW_DDRC_ADDRMAP0_ADDR(x))
#define HW_DDRC_ADDRMAP0_RD(x)   (HW_DDRC_ADDRMAP0(x).U)
#define HW_DDRC_ADDRMAP0_WR(x, v) (HW_DDRC_ADDRMAP0(x).U = (v))
#define HW_DDRC_ADDRMAP0_SET(x, v) (HW_DDRC_ADDRMAP0_WR(x, HW_DDRC_ADDRMAP0_RD(x) |  (v)))
#define HW_DDRC_ADDRMAP0_CLR(x, v) (HW_DDRC_ADDRMAP0_WR(x, HW_DDRC_ADDRMAP0_RD(x) & ~(v)))
#define HW_DDRC_ADDRMAP0_TOG(x, v) (HW_DDRC_ADDRMAP0_WR(x, HW_DDRC_ADDRMAP0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_ADDRMAP0 bitfields
 */

/*!
 * @name Register DDRC_ADDRMAP0, field ADDRMAP_CS_BIT0[4:0] (RW)
 *
 * Selects the HIF address bit used as rank address bit 0. Valid Range: 0 to 27,
 * and 31 Internal Base: 6 The selected HIF address bit is determined by adding
 * the internal base to the value of this field. If set to 31, rank address bit 0
 * is set to 0. Value After Reset: 0x0 Exists: MEMC_NUM_RANKS > 1
 */
/*@{*/
#define BP_DDRC_ADDRMAP0_ADDRMAP_CS_BIT0 (0U) /*!< Bit position for DDRC_ADDRMAP0_ADDRMAP_CS_BIT0. */
#define BM_DDRC_ADDRMAP0_ADDRMAP_CS_BIT0 (0x0000001FU) /*!< Bit mask for DDRC_ADDRMAP0_ADDRMAP_CS_BIT0. */
#define BS_DDRC_ADDRMAP0_ADDRMAP_CS_BIT0 (5U) /*!< Bit field size in bits for DDRC_ADDRMAP0_ADDRMAP_CS_BIT0. */

/*! @brief Read current value of the DDRC_ADDRMAP0_ADDRMAP_CS_BIT0 field. */
#define BR_DDRC_ADDRMAP0_ADDRMAP_CS_BIT0(x) (HW_DDRC_ADDRMAP0(x).B.ADDRMAP_CS_BIT0)

/*! @brief Format value for bitfield DDRC_ADDRMAP0_ADDRMAP_CS_BIT0. */
#define BF_DDRC_ADDRMAP0_ADDRMAP_CS_BIT0(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP0_ADDRMAP_CS_BIT0) & BM_DDRC_ADDRMAP0_ADDRMAP_CS_BIT0)

/*! @brief Set the ADDRMAP_CS_BIT0 field to a new value. */
#define BW_DDRC_ADDRMAP0_ADDRMAP_CS_BIT0(x, v) (HW_DDRC_ADDRMAP0_WR(x, (HW_DDRC_ADDRMAP0_RD(x) & ~BM_DDRC_ADDRMAP0_ADDRMAP_CS_BIT0) | BF_DDRC_ADDRMAP0_ADDRMAP_CS_BIT0(v)))
/*@}*/

/*!
 * @name Register DDRC_ADDRMAP0, field ADDRMAP_CS_BIT1[12:8] (RW)
 *
 * Selects the HIF address bit used as rank address bit 1. Valid Range: 0 to 26,
 * and 31 Internal Base: 7 The selected HIF address bit is determined by adding
 * the internal base to the value of this field. If set to 31, rank address bit 1
 * is set to 0. Value After Reset: 0x0 Exists: MEMC_NUM_RANKS == 4
 */
/*@{*/
#define BP_DDRC_ADDRMAP0_ADDRMAP_CS_BIT1 (8U) /*!< Bit position for DDRC_ADDRMAP0_ADDRMAP_CS_BIT1. */
#define BM_DDRC_ADDRMAP0_ADDRMAP_CS_BIT1 (0x00001F00U) /*!< Bit mask for DDRC_ADDRMAP0_ADDRMAP_CS_BIT1. */
#define BS_DDRC_ADDRMAP0_ADDRMAP_CS_BIT1 (5U) /*!< Bit field size in bits for DDRC_ADDRMAP0_ADDRMAP_CS_BIT1. */

/*! @brief Read current value of the DDRC_ADDRMAP0_ADDRMAP_CS_BIT1 field. */
#define BR_DDRC_ADDRMAP0_ADDRMAP_CS_BIT1(x) (HW_DDRC_ADDRMAP0(x).B.ADDRMAP_CS_BIT1)

/*! @brief Format value for bitfield DDRC_ADDRMAP0_ADDRMAP_CS_BIT1. */
#define BF_DDRC_ADDRMAP0_ADDRMAP_CS_BIT1(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP0_ADDRMAP_CS_BIT1) & BM_DDRC_ADDRMAP0_ADDRMAP_CS_BIT1)

/*! @brief Set the ADDRMAP_CS_BIT1 field to a new value. */
#define BW_DDRC_ADDRMAP0_ADDRMAP_CS_BIT1(x, v) (HW_DDRC_ADDRMAP0_WR(x, (HW_DDRC_ADDRMAP0_RD(x) & ~BM_DDRC_ADDRMAP0_ADDRMAP_CS_BIT1) | BF_DDRC_ADDRMAP0_ADDRMAP_CS_BIT1(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_ADDRMAP1 - Address Map Register 1
 ******************************************************************************/

/*!
 * @brief HW_DDRC_ADDRMAP1 - Address Map Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_addrmap1
{
    uint32_t U;
    struct _hw_ddrc_addrmap1_bitfields
    {
        uint32_t ADDRMAP_BANK_B0 : 5;  /*!< [4:0]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t ADDRMAP_BANK_B1 : 5;  /*!< [12:8]  */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t ADDRMAP_BANK_B2 : 5;  /*!< [20:16]  */
        uint32_t RESERVED2 : 11;       /*!< [31:21]  */
    } B;
} hw_ddrc_addrmap1_t;

/*!
 * @name Constants and macros for entire DDRC_ADDRMAP1 register
 */
/*@{*/
#define HW_DDRC_ADDRMAP1_ADDR(x) ((uintptr_t)(x) + 0x204U)

#define HW_DDRC_ADDRMAP1(x)      (*(__IO hw_ddrc_addrmap1_t *) HW_DDRC_ADDRMAP1_ADDR(x))
#define HW_DDRC_ADDRMAP1_RD(x)   (HW_DDRC_ADDRMAP1(x).U)
#define HW_DDRC_ADDRMAP1_WR(x, v) (HW_DDRC_ADDRMAP1(x).U = (v))
#define HW_DDRC_ADDRMAP1_SET(x, v) (HW_DDRC_ADDRMAP1_WR(x, HW_DDRC_ADDRMAP1_RD(x) |  (v)))
#define HW_DDRC_ADDRMAP1_CLR(x, v) (HW_DDRC_ADDRMAP1_WR(x, HW_DDRC_ADDRMAP1_RD(x) & ~(v)))
#define HW_DDRC_ADDRMAP1_TOG(x, v) (HW_DDRC_ADDRMAP1_WR(x, HW_DDRC_ADDRMAP1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_ADDRMAP1 bitfields
 */

/*!
 * @name Register DDRC_ADDRMAP1, field ADDRMAP_BANK_B0[4:0] (RW)
 *
 * Selects the HIF address bits used as bank address bit 0. Valid Range: 0 to 30
 * Internal Base: 2 The selected HIF address bit for each of the bank address
 * bits is determined by adding the internal base to the value of this field. Value
 * After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP1_ADDRMAP_BANK_B0 (0U) /*!< Bit position for DDRC_ADDRMAP1_ADDRMAP_BANK_B0. */
#define BM_DDRC_ADDRMAP1_ADDRMAP_BANK_B0 (0x0000001FU) /*!< Bit mask for DDRC_ADDRMAP1_ADDRMAP_BANK_B0. */
#define BS_DDRC_ADDRMAP1_ADDRMAP_BANK_B0 (5U) /*!< Bit field size in bits for DDRC_ADDRMAP1_ADDRMAP_BANK_B0. */

/*! @brief Read current value of the DDRC_ADDRMAP1_ADDRMAP_BANK_B0 field. */
#define BR_DDRC_ADDRMAP1_ADDRMAP_BANK_B0(x) (HW_DDRC_ADDRMAP1(x).B.ADDRMAP_BANK_B0)

/*! @brief Format value for bitfield DDRC_ADDRMAP1_ADDRMAP_BANK_B0. */
#define BF_DDRC_ADDRMAP1_ADDRMAP_BANK_B0(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP1_ADDRMAP_BANK_B0) & BM_DDRC_ADDRMAP1_ADDRMAP_BANK_B0)

/*! @brief Set the ADDRMAP_BANK_B0 field to a new value. */
#define BW_DDRC_ADDRMAP1_ADDRMAP_BANK_B0(x, v) (HW_DDRC_ADDRMAP1_WR(x, (HW_DDRC_ADDRMAP1_RD(x) & ~BM_DDRC_ADDRMAP1_ADDRMAP_BANK_B0) | BF_DDRC_ADDRMAP1_ADDRMAP_BANK_B0(v)))
/*@}*/

/*!
 * @name Register DDRC_ADDRMAP1, field ADDRMAP_BANK_B1[12:8] (RW)
 *
 * Selects the HIF address bits used as bank address bit 1. Valid Range: 0 to 30
 * Internal Base: 3 The selected HIF address bit for each of the bank address
 * bits is determined by adding the internal base to the value of this field. Value
 * After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP1_ADDRMAP_BANK_B1 (8U) /*!< Bit position for DDRC_ADDRMAP1_ADDRMAP_BANK_B1. */
#define BM_DDRC_ADDRMAP1_ADDRMAP_BANK_B1 (0x00001F00U) /*!< Bit mask for DDRC_ADDRMAP1_ADDRMAP_BANK_B1. */
#define BS_DDRC_ADDRMAP1_ADDRMAP_BANK_B1 (5U) /*!< Bit field size in bits for DDRC_ADDRMAP1_ADDRMAP_BANK_B1. */

/*! @brief Read current value of the DDRC_ADDRMAP1_ADDRMAP_BANK_B1 field. */
#define BR_DDRC_ADDRMAP1_ADDRMAP_BANK_B1(x) (HW_DDRC_ADDRMAP1(x).B.ADDRMAP_BANK_B1)

/*! @brief Format value for bitfield DDRC_ADDRMAP1_ADDRMAP_BANK_B1. */
#define BF_DDRC_ADDRMAP1_ADDRMAP_BANK_B1(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP1_ADDRMAP_BANK_B1) & BM_DDRC_ADDRMAP1_ADDRMAP_BANK_B1)

/*! @brief Set the ADDRMAP_BANK_B1 field to a new value. */
#define BW_DDRC_ADDRMAP1_ADDRMAP_BANK_B1(x, v) (HW_DDRC_ADDRMAP1_WR(x, (HW_DDRC_ADDRMAP1_RD(x) & ~BM_DDRC_ADDRMAP1_ADDRMAP_BANK_B1) | BF_DDRC_ADDRMAP1_ADDRMAP_BANK_B1(v)))
/*@}*/

/*!
 * @name Register DDRC_ADDRMAP1, field ADDRMAP_BANK_B2[20:16] (RW)
 *
 * Selects the HIF address bit used as bank address bit 2. Valid Range: 0 to 29
 * and 31 Internal Base: 4 The selected HIF address bit is determined by adding
 * the internal base to the value of this field. If set to 31, bank address bit 2
 * is set to 0. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP1_ADDRMAP_BANK_B2 (16U) /*!< Bit position for DDRC_ADDRMAP1_ADDRMAP_BANK_B2. */
#define BM_DDRC_ADDRMAP1_ADDRMAP_BANK_B2 (0x001F0000U) /*!< Bit mask for DDRC_ADDRMAP1_ADDRMAP_BANK_B2. */
#define BS_DDRC_ADDRMAP1_ADDRMAP_BANK_B2 (5U) /*!< Bit field size in bits for DDRC_ADDRMAP1_ADDRMAP_BANK_B2. */

/*! @brief Read current value of the DDRC_ADDRMAP1_ADDRMAP_BANK_B2 field. */
#define BR_DDRC_ADDRMAP1_ADDRMAP_BANK_B2(x) (HW_DDRC_ADDRMAP1(x).B.ADDRMAP_BANK_B2)

/*! @brief Format value for bitfield DDRC_ADDRMAP1_ADDRMAP_BANK_B2. */
#define BF_DDRC_ADDRMAP1_ADDRMAP_BANK_B2(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP1_ADDRMAP_BANK_B2) & BM_DDRC_ADDRMAP1_ADDRMAP_BANK_B2)

/*! @brief Set the ADDRMAP_BANK_B2 field to a new value. */
#define BW_DDRC_ADDRMAP1_ADDRMAP_BANK_B2(x, v) (HW_DDRC_ADDRMAP1_WR(x, (HW_DDRC_ADDRMAP1_RD(x) & ~BM_DDRC_ADDRMAP1_ADDRMAP_BANK_B2) | BF_DDRC_ADDRMAP1_ADDRMAP_BANK_B2(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_ADDRMAP2 - Address Map Register 2
 ******************************************************************************/

/*!
 * @brief HW_DDRC_ADDRMAP2 - Address Map Register 2 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_addrmap2
{
    uint32_t U;
    struct _hw_ddrc_addrmap2_bitfields
    {
        uint32_t ADDRMAP_COL_B2 : 4;   /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t ADDRMAP_COL_B3 : 4;   /*!< [11:8]  */
        uint32_t RESERVED1 : 4;        /*!< [15:12]  */
        uint32_t ADDRMAP_COL_B4 : 4;   /*!< [19:16]  */
        uint32_t RESERVED2 : 4;        /*!< [23:20]  */
        uint32_t ADDRMAP_COL_B5 : 4;   /*!< [27:24]  */
        uint32_t RESERVED3 : 4;        /*!< [31:28]  */
    } B;
} hw_ddrc_addrmap2_t;

/*!
 * @name Constants and macros for entire DDRC_ADDRMAP2 register
 */
/*@{*/
#define HW_DDRC_ADDRMAP2_ADDR(x) ((uintptr_t)(x) + 0x208U)

#define HW_DDRC_ADDRMAP2(x)      (*(__IO hw_ddrc_addrmap2_t *) HW_DDRC_ADDRMAP2_ADDR(x))
#define HW_DDRC_ADDRMAP2_RD(x)   (HW_DDRC_ADDRMAP2(x).U)
#define HW_DDRC_ADDRMAP2_WR(x, v) (HW_DDRC_ADDRMAP2(x).U = (v))
#define HW_DDRC_ADDRMAP2_SET(x, v) (HW_DDRC_ADDRMAP2_WR(x, HW_DDRC_ADDRMAP2_RD(x) |  (v)))
#define HW_DDRC_ADDRMAP2_CLR(x, v) (HW_DDRC_ADDRMAP2_WR(x, HW_DDRC_ADDRMAP2_RD(x) & ~(v)))
#define HW_DDRC_ADDRMAP2_TOG(x, v) (HW_DDRC_ADDRMAP2_WR(x, HW_DDRC_ADDRMAP2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_ADDRMAP2 bitfields
 */

/*!
 * @name Register DDRC_ADDRMAP2, field ADDRMAP_COL_B2[3:0] (RW)
 *
 * Full bus width mode: Selects the HIF address bit used as column address bit
 * 2. Half bus width mode: Selects the HIF address bit used as column address bit
 * 3. Quarter bus width mode: Selects the HIF address bit used as column address
 * bit 4. Valid Range: 0 to 7 Internal Base: 2 The selected HIF address bit is
 * determined by adding the internal base to the value of this field.If
 * DDRC_INCL_ARB = 1 and MEMC_BURST_LENGTH = 8, it is required to program this to 0. Value
 * After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP2_ADDRMAP_COL_B2 (0U) /*!< Bit position for DDRC_ADDRMAP2_ADDRMAP_COL_B2. */
#define BM_DDRC_ADDRMAP2_ADDRMAP_COL_B2 (0x0000000FU) /*!< Bit mask for DDRC_ADDRMAP2_ADDRMAP_COL_B2. */
#define BS_DDRC_ADDRMAP2_ADDRMAP_COL_B2 (4U) /*!< Bit field size in bits for DDRC_ADDRMAP2_ADDRMAP_COL_B2. */

/*! @brief Read current value of the DDRC_ADDRMAP2_ADDRMAP_COL_B2 field. */
#define BR_DDRC_ADDRMAP2_ADDRMAP_COL_B2(x) (HW_DDRC_ADDRMAP2(x).B.ADDRMAP_COL_B2)

/*! @brief Format value for bitfield DDRC_ADDRMAP2_ADDRMAP_COL_B2. */
#define BF_DDRC_ADDRMAP2_ADDRMAP_COL_B2(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP2_ADDRMAP_COL_B2) & BM_DDRC_ADDRMAP2_ADDRMAP_COL_B2)

/*! @brief Set the ADDRMAP_COL_B2 field to a new value. */
#define BW_DDRC_ADDRMAP2_ADDRMAP_COL_B2(x, v) (HW_DDRC_ADDRMAP2_WR(x, (HW_DDRC_ADDRMAP2_RD(x) & ~BM_DDRC_ADDRMAP2_ADDRMAP_COL_B2) | BF_DDRC_ADDRMAP2_ADDRMAP_COL_B2(v)))
/*@}*/

/*!
 * @name Register DDRC_ADDRMAP2, field ADDRMAP_COL_B3[11:8] (RW)
 *
 * Full bus width mode: Selects the HIF address bit used as column address bit
 * 3. Half bus width mode: Selects the HIF address bit used as column address bit
 * 4. Quarter bus width mode: Selects the HIF address bit used as column address
 * bit 5. Valid Range: 0 to 7 Internal Base: 3 The selected HIF address bit is
 * determined by adding the internal base to the value of this field. Value After
 * Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP2_ADDRMAP_COL_B3 (8U) /*!< Bit position for DDRC_ADDRMAP2_ADDRMAP_COL_B3. */
#define BM_DDRC_ADDRMAP2_ADDRMAP_COL_B3 (0x00000F00U) /*!< Bit mask for DDRC_ADDRMAP2_ADDRMAP_COL_B3. */
#define BS_DDRC_ADDRMAP2_ADDRMAP_COL_B3 (4U) /*!< Bit field size in bits for DDRC_ADDRMAP2_ADDRMAP_COL_B3. */

/*! @brief Read current value of the DDRC_ADDRMAP2_ADDRMAP_COL_B3 field. */
#define BR_DDRC_ADDRMAP2_ADDRMAP_COL_B3(x) (HW_DDRC_ADDRMAP2(x).B.ADDRMAP_COL_B3)

/*! @brief Format value for bitfield DDRC_ADDRMAP2_ADDRMAP_COL_B3. */
#define BF_DDRC_ADDRMAP2_ADDRMAP_COL_B3(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP2_ADDRMAP_COL_B3) & BM_DDRC_ADDRMAP2_ADDRMAP_COL_B3)

/*! @brief Set the ADDRMAP_COL_B3 field to a new value. */
#define BW_DDRC_ADDRMAP2_ADDRMAP_COL_B3(x, v) (HW_DDRC_ADDRMAP2_WR(x, (HW_DDRC_ADDRMAP2_RD(x) & ~BM_DDRC_ADDRMAP2_ADDRMAP_COL_B3) | BF_DDRC_ADDRMAP2_ADDRMAP_COL_B3(v)))
/*@}*/

/*!
 * @name Register DDRC_ADDRMAP2, field ADDRMAP_COL_B4[19:16] (RW)
 *
 * Description: Full bus width mode: Selects the HIF address bit used as column
 * address bit 4. Half bus width mode: Selects the HIF address bit used as column
 * address bit 5. Quarter bus width mode: Selects the HIF address bit used as
 * column address bit 6. Valid Range: 0 to 7, and 15 Internal Base: 4 The selected
 * HIF address bit is determined by adding the internal base to the value of this
 * field. If set to 15, this column address bit is set to 0. Value After Reset:
 * 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP2_ADDRMAP_COL_B4 (16U) /*!< Bit position for DDRC_ADDRMAP2_ADDRMAP_COL_B4. */
#define BM_DDRC_ADDRMAP2_ADDRMAP_COL_B4 (0x000F0000U) /*!< Bit mask for DDRC_ADDRMAP2_ADDRMAP_COL_B4. */
#define BS_DDRC_ADDRMAP2_ADDRMAP_COL_B4 (4U) /*!< Bit field size in bits for DDRC_ADDRMAP2_ADDRMAP_COL_B4. */

/*! @brief Read current value of the DDRC_ADDRMAP2_ADDRMAP_COL_B4 field. */
#define BR_DDRC_ADDRMAP2_ADDRMAP_COL_B4(x) (HW_DDRC_ADDRMAP2(x).B.ADDRMAP_COL_B4)

/*! @brief Format value for bitfield DDRC_ADDRMAP2_ADDRMAP_COL_B4. */
#define BF_DDRC_ADDRMAP2_ADDRMAP_COL_B4(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP2_ADDRMAP_COL_B4) & BM_DDRC_ADDRMAP2_ADDRMAP_COL_B4)

/*! @brief Set the ADDRMAP_COL_B4 field to a new value. */
#define BW_DDRC_ADDRMAP2_ADDRMAP_COL_B4(x, v) (HW_DDRC_ADDRMAP2_WR(x, (HW_DDRC_ADDRMAP2_RD(x) & ~BM_DDRC_ADDRMAP2_ADDRMAP_COL_B4) | BF_DDRC_ADDRMAP2_ADDRMAP_COL_B4(v)))
/*@}*/

/*!
 * @name Register DDRC_ADDRMAP2, field ADDRMAP_COL_B5[27:24] (RW)
 *
 * Description: Full bus width mode: Selects the HIF address bit used as column
 * address bit 5. Half bus width mode: Selects the HIF address bit used as column
 * address bit 6. Quarter bus width mode: Selects the HIF address bit used as
 * column address bit 7. Valid Range: 0 to 7, and 15 Internal Base: 5 The selected
 * HIF address bit is determined by adding the internal base to the value of this
 * field. If set to 15, this column address bit is set to 0. Value After Reset:
 * 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP2_ADDRMAP_COL_B5 (24U) /*!< Bit position for DDRC_ADDRMAP2_ADDRMAP_COL_B5. */
#define BM_DDRC_ADDRMAP2_ADDRMAP_COL_B5 (0x0F000000U) /*!< Bit mask for DDRC_ADDRMAP2_ADDRMAP_COL_B5. */
#define BS_DDRC_ADDRMAP2_ADDRMAP_COL_B5 (4U) /*!< Bit field size in bits for DDRC_ADDRMAP2_ADDRMAP_COL_B5. */

/*! @brief Read current value of the DDRC_ADDRMAP2_ADDRMAP_COL_B5 field. */
#define BR_DDRC_ADDRMAP2_ADDRMAP_COL_B5(x) (HW_DDRC_ADDRMAP2(x).B.ADDRMAP_COL_B5)

/*! @brief Format value for bitfield DDRC_ADDRMAP2_ADDRMAP_COL_B5. */
#define BF_DDRC_ADDRMAP2_ADDRMAP_COL_B5(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP2_ADDRMAP_COL_B5) & BM_DDRC_ADDRMAP2_ADDRMAP_COL_B5)

/*! @brief Set the ADDRMAP_COL_B5 field to a new value. */
#define BW_DDRC_ADDRMAP2_ADDRMAP_COL_B5(x, v) (HW_DDRC_ADDRMAP2_WR(x, (HW_DDRC_ADDRMAP2_RD(x) & ~BM_DDRC_ADDRMAP2_ADDRMAP_COL_B5) | BF_DDRC_ADDRMAP2_ADDRMAP_COL_B5(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_ADDRMAP3 - Address Map Register 3
 ******************************************************************************/

/*!
 * @brief HW_DDRC_ADDRMAP3 - Address Map Register 3 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_addrmap3
{
    uint32_t U;
    struct _hw_ddrc_addrmap3_bitfields
    {
        uint32_t ADDRMAP_COL_B6 : 4;   /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t ADDRMAP_COL_B7 : 4;   /*!< [11:8]  */
        uint32_t RESERVED1 : 4;        /*!< [15:12]  */
        uint32_t ADDRMAP_COL_B8 : 4;   /*!< [19:16]  */
        uint32_t RESERVED2 : 4;        /*!< [23:20]  */
        uint32_t ADDRMAP_COL_B9 : 4;   /*!< [27:24]  */
        uint32_t RESERVED3 : 4;        /*!< [31:28]  */
    } B;
} hw_ddrc_addrmap3_t;

/*!
 * @name Constants and macros for entire DDRC_ADDRMAP3 register
 */
/*@{*/
#define HW_DDRC_ADDRMAP3_ADDR(x) ((uintptr_t)(x) + 0x20CU)

#define HW_DDRC_ADDRMAP3(x)      (*(__IO hw_ddrc_addrmap3_t *) HW_DDRC_ADDRMAP3_ADDR(x))
#define HW_DDRC_ADDRMAP3_RD(x)   (HW_DDRC_ADDRMAP3(x).U)
#define HW_DDRC_ADDRMAP3_WR(x, v) (HW_DDRC_ADDRMAP3(x).U = (v))
#define HW_DDRC_ADDRMAP3_SET(x, v) (HW_DDRC_ADDRMAP3_WR(x, HW_DDRC_ADDRMAP3_RD(x) |  (v)))
#define HW_DDRC_ADDRMAP3_CLR(x, v) (HW_DDRC_ADDRMAP3_WR(x, HW_DDRC_ADDRMAP3_RD(x) & ~(v)))
#define HW_DDRC_ADDRMAP3_TOG(x, v) (HW_DDRC_ADDRMAP3_WR(x, HW_DDRC_ADDRMAP3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_ADDRMAP3 bitfields
 */

/*!
 * @name Register DDRC_ADDRMAP3, field ADDRMAP_COL_B6[3:0] (RW)
 *
 * Description: Full bus width mode: Selects the HIF address bit used as column
 * address bit 6. Half bus width mode: Selects the HIF address bit used as column
 * address bit 7. Quarter bus width mode: Selects the HIF address bit used as
 * column address bit 8. Valid Range: 0 to 7, and 15 Internal Base: 6 The selected
 * HIF address bit is determined by adding the internal base to the value of this
 * field. If set to 15, this column address bit is set to 0. Value After Reset:
 * 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP3_ADDRMAP_COL_B6 (0U) /*!< Bit position for DDRC_ADDRMAP3_ADDRMAP_COL_B6. */
#define BM_DDRC_ADDRMAP3_ADDRMAP_COL_B6 (0x0000000FU) /*!< Bit mask for DDRC_ADDRMAP3_ADDRMAP_COL_B6. */
#define BS_DDRC_ADDRMAP3_ADDRMAP_COL_B6 (4U) /*!< Bit field size in bits for DDRC_ADDRMAP3_ADDRMAP_COL_B6. */

/*! @brief Read current value of the DDRC_ADDRMAP3_ADDRMAP_COL_B6 field. */
#define BR_DDRC_ADDRMAP3_ADDRMAP_COL_B6(x) (HW_DDRC_ADDRMAP3(x).B.ADDRMAP_COL_B6)

/*! @brief Format value for bitfield DDRC_ADDRMAP3_ADDRMAP_COL_B6. */
#define BF_DDRC_ADDRMAP3_ADDRMAP_COL_B6(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP3_ADDRMAP_COL_B6) & BM_DDRC_ADDRMAP3_ADDRMAP_COL_B6)

/*! @brief Set the ADDRMAP_COL_B6 field to a new value. */
#define BW_DDRC_ADDRMAP3_ADDRMAP_COL_B6(x, v) (HW_DDRC_ADDRMAP3_WR(x, (HW_DDRC_ADDRMAP3_RD(x) & ~BM_DDRC_ADDRMAP3_ADDRMAP_COL_B6) | BF_DDRC_ADDRMAP3_ADDRMAP_COL_B6(v)))
/*@}*/

/*!
 * @name Register DDRC_ADDRMAP3, field ADDRMAP_COL_B7[11:8] (RW)
 *
 * Description: Full bus width mode: Selects the HIF address bit used as column
 * address bit 7. Half bus width mode: Selects the HIF address bit used as column
 * address bit 8. Quarter bus width mode: Selects the HIF address bit used as
 * column address bit 9. Valid Range: 0 to 7, and 15 Internal Base: 7 The selected
 * HIF address bit is determined by adding the internal base to the value of this
 * field. If set to 15, this column address bit is set to 0. Value After Reset:
 * 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP3_ADDRMAP_COL_B7 (8U) /*!< Bit position for DDRC_ADDRMAP3_ADDRMAP_COL_B7. */
#define BM_DDRC_ADDRMAP3_ADDRMAP_COL_B7 (0x00000F00U) /*!< Bit mask for DDRC_ADDRMAP3_ADDRMAP_COL_B7. */
#define BS_DDRC_ADDRMAP3_ADDRMAP_COL_B7 (4U) /*!< Bit field size in bits for DDRC_ADDRMAP3_ADDRMAP_COL_B7. */

/*! @brief Read current value of the DDRC_ADDRMAP3_ADDRMAP_COL_B7 field. */
#define BR_DDRC_ADDRMAP3_ADDRMAP_COL_B7(x) (HW_DDRC_ADDRMAP3(x).B.ADDRMAP_COL_B7)

/*! @brief Format value for bitfield DDRC_ADDRMAP3_ADDRMAP_COL_B7. */
#define BF_DDRC_ADDRMAP3_ADDRMAP_COL_B7(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP3_ADDRMAP_COL_B7) & BM_DDRC_ADDRMAP3_ADDRMAP_COL_B7)

/*! @brief Set the ADDRMAP_COL_B7 field to a new value. */
#define BW_DDRC_ADDRMAP3_ADDRMAP_COL_B7(x, v) (HW_DDRC_ADDRMAP3_WR(x, (HW_DDRC_ADDRMAP3_RD(x) & ~BM_DDRC_ADDRMAP3_ADDRMAP_COL_B7) | BF_DDRC_ADDRMAP3_ADDRMAP_COL_B7(v)))
/*@}*/

/*!
 * @name Register DDRC_ADDRMAP3, field ADDRMAP_COL_B8[19:16] (RW)
 *
 * Description: Full bus width mode: Selects the HIF address bit used as column
 * address bit 8. Half bus width mode: Selects the HIF address bit used as column
 * address bit 9. Quarter bus width mode: Selects the HIF address bit used as
 * column address bit 11 (10 in LPDDR2 / LPDDR3 mode). Valid Range: 0 to 7, and 15
 * Internal Base: 8 The selected HIF address bit is determined by adding the
 * internal base to the value of this field. If set to 15, this column address bit is
 * set to 0. Per JEDEC DDR2 / DDR3 / mDDR specification, column address bit 10
 * is reserved for indicating auto-precharge, and hence no source address bit can
 * be mapped to column address bit 10. In LPDDR2 / LPDDR3, there is a dedicated
 * bit for auto-precharge in the CA bus and hence column bit 10 is used. Value
 * After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP3_ADDRMAP_COL_B8 (16U) /*!< Bit position for DDRC_ADDRMAP3_ADDRMAP_COL_B8. */
#define BM_DDRC_ADDRMAP3_ADDRMAP_COL_B8 (0x000F0000U) /*!< Bit mask for DDRC_ADDRMAP3_ADDRMAP_COL_B8. */
#define BS_DDRC_ADDRMAP3_ADDRMAP_COL_B8 (4U) /*!< Bit field size in bits for DDRC_ADDRMAP3_ADDRMAP_COL_B8. */

/*! @brief Read current value of the DDRC_ADDRMAP3_ADDRMAP_COL_B8 field. */
#define BR_DDRC_ADDRMAP3_ADDRMAP_COL_B8(x) (HW_DDRC_ADDRMAP3(x).B.ADDRMAP_COL_B8)

/*! @brief Format value for bitfield DDRC_ADDRMAP3_ADDRMAP_COL_B8. */
#define BF_DDRC_ADDRMAP3_ADDRMAP_COL_B8(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP3_ADDRMAP_COL_B8) & BM_DDRC_ADDRMAP3_ADDRMAP_COL_B8)

/*! @brief Set the ADDRMAP_COL_B8 field to a new value. */
#define BW_DDRC_ADDRMAP3_ADDRMAP_COL_B8(x, v) (HW_DDRC_ADDRMAP3_WR(x, (HW_DDRC_ADDRMAP3_RD(x) & ~BM_DDRC_ADDRMAP3_ADDRMAP_COL_B8) | BF_DDRC_ADDRMAP3_ADDRMAP_COL_B8(v)))
/*@}*/

/*!
 * @name Register DDRC_ADDRMAP3, field ADDRMAP_COL_B9[27:24] (RW)
 *
 * Description: Full bus width mode: Selects the HIF address bit used as column
 * address bit 9. Half bus width mode: Selects the HIF address bit used as column
 * address bit 11 (10 in LPDDR2 / LPDDR3 mode) Quarter bus width mode: Selects
 * the HIF address bit used as column address bit 13 (11 in LPDDR2 / LPDDR3 mode).
 * Valid Range: 0 to 7, and 15 Internal Base: 9 The selected HIF address bit is
 * determined by adding the internal base to the value of this field. If set to
 * 15, this column address bit is set to 0. Per JEDEC DDR2 / DDR3 / mDDR
 * specification, column address bit 10 is reserved for indicating auto-precharge, and
 * hence no source address bit can be mapped to column address bit 10.In LPDDR2 /
 * LPDDR3, there is a dedicated bit for auto- precharge in the CA bus and hence
 * column bit 10 is used. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP3_ADDRMAP_COL_B9 (24U) /*!< Bit position for DDRC_ADDRMAP3_ADDRMAP_COL_B9. */
#define BM_DDRC_ADDRMAP3_ADDRMAP_COL_B9 (0x0F000000U) /*!< Bit mask for DDRC_ADDRMAP3_ADDRMAP_COL_B9. */
#define BS_DDRC_ADDRMAP3_ADDRMAP_COL_B9 (4U) /*!< Bit field size in bits for DDRC_ADDRMAP3_ADDRMAP_COL_B9. */

/*! @brief Read current value of the DDRC_ADDRMAP3_ADDRMAP_COL_B9 field. */
#define BR_DDRC_ADDRMAP3_ADDRMAP_COL_B9(x) (HW_DDRC_ADDRMAP3(x).B.ADDRMAP_COL_B9)

/*! @brief Format value for bitfield DDRC_ADDRMAP3_ADDRMAP_COL_B9. */
#define BF_DDRC_ADDRMAP3_ADDRMAP_COL_B9(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP3_ADDRMAP_COL_B9) & BM_DDRC_ADDRMAP3_ADDRMAP_COL_B9)

/*! @brief Set the ADDRMAP_COL_B9 field to a new value. */
#define BW_DDRC_ADDRMAP3_ADDRMAP_COL_B9(x, v) (HW_DDRC_ADDRMAP3_WR(x, (HW_DDRC_ADDRMAP3_RD(x) & ~BM_DDRC_ADDRMAP3_ADDRMAP_COL_B9) | BF_DDRC_ADDRMAP3_ADDRMAP_COL_B9(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_ADDRMAP4 - Address Map Register 4
 ******************************************************************************/

/*!
 * @brief HW_DDRC_ADDRMAP4 - Address Map Register 4 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: Always
 */
typedef union _hw_ddrc_addrmap4
{
    uint32_t U;
    struct _hw_ddrc_addrmap4_bitfields
    {
        uint32_t ADDRMAP_COL_B10 : 4;  /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t ADDRMAP_COL_B11 : 4;  /*!< [11:8]  */
        uint32_t RESERVED1 : 20;       /*!< [31:12]  */
    } B;
} hw_ddrc_addrmap4_t;

/*!
 * @name Constants and macros for entire DDRC_ADDRMAP4 register
 */
/*@{*/
#define HW_DDRC_ADDRMAP4_ADDR(x) ((uintptr_t)(x) + 0x210U)

#define HW_DDRC_ADDRMAP4(x)      (*(__IO hw_ddrc_addrmap4_t *) HW_DDRC_ADDRMAP4_ADDR(x))
#define HW_DDRC_ADDRMAP4_RD(x)   (HW_DDRC_ADDRMAP4(x).U)
#define HW_DDRC_ADDRMAP4_WR(x, v) (HW_DDRC_ADDRMAP4(x).U = (v))
#define HW_DDRC_ADDRMAP4_SET(x, v) (HW_DDRC_ADDRMAP4_WR(x, HW_DDRC_ADDRMAP4_RD(x) |  (v)))
#define HW_DDRC_ADDRMAP4_CLR(x, v) (HW_DDRC_ADDRMAP4_WR(x, HW_DDRC_ADDRMAP4_RD(x) & ~(v)))
#define HW_DDRC_ADDRMAP4_TOG(x, v) (HW_DDRC_ADDRMAP4_WR(x, HW_DDRC_ADDRMAP4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_ADDRMAP4 bitfields
 */

/*!
 * @name Register DDRC_ADDRMAP4, field ADDRMAP_COL_B10[3:0] (RW)
 *
 * Description: Full bus width mode: Selects the HIF address bit used as column
 * address bit 11 (10 in LPDDR2 / LPDDR3 mode). Half bus width mode: Selects the
 * HIF address bit used as column address bit 13 (11 in LPDDR2 / LPDDR3 mode).
 * Quarter bus width mode: UNUSED. To make it unused, this must be tied to 4'hF.
 * Valid Range: 0 to 7, and 15 Internal Base: 10 The selected HIF address bit is
 * determined by adding the internal base to the value of this field. If set to 15,
 * this column address bit is set to 0. Per JEDEC DDR2 / DDR3 / mDDR
 * specification, column address bit 10 is reserved for indicating auto-precharge, and hence
 * no source address bit can be mapped to column address bit 10. In LPDDR2 /
 * LPDDR3, there is a dedicated bit for auto-precharge in the CA bus and hence
 * column bit 10 is used. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP4_ADDRMAP_COL_B10 (0U) /*!< Bit position for DDRC_ADDRMAP4_ADDRMAP_COL_B10. */
#define BM_DDRC_ADDRMAP4_ADDRMAP_COL_B10 (0x0000000FU) /*!< Bit mask for DDRC_ADDRMAP4_ADDRMAP_COL_B10. */
#define BS_DDRC_ADDRMAP4_ADDRMAP_COL_B10 (4U) /*!< Bit field size in bits for DDRC_ADDRMAP4_ADDRMAP_COL_B10. */

/*! @brief Read current value of the DDRC_ADDRMAP4_ADDRMAP_COL_B10 field. */
#define BR_DDRC_ADDRMAP4_ADDRMAP_COL_B10(x) (HW_DDRC_ADDRMAP4(x).B.ADDRMAP_COL_B10)

/*! @brief Format value for bitfield DDRC_ADDRMAP4_ADDRMAP_COL_B10. */
#define BF_DDRC_ADDRMAP4_ADDRMAP_COL_B10(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP4_ADDRMAP_COL_B10) & BM_DDRC_ADDRMAP4_ADDRMAP_COL_B10)

/*! @brief Set the ADDRMAP_COL_B10 field to a new value. */
#define BW_DDRC_ADDRMAP4_ADDRMAP_COL_B10(x, v) (HW_DDRC_ADDRMAP4_WR(x, (HW_DDRC_ADDRMAP4_RD(x) & ~BM_DDRC_ADDRMAP4_ADDRMAP_COL_B10) | BF_DDRC_ADDRMAP4_ADDRMAP_COL_B10(v)))
/*@}*/

/*!
 * @name Register DDRC_ADDRMAP4, field ADDRMAP_COL_B11[11:8] (RW)
 *
 * Description: Full bus width mode: Selects the HIF address bit used as column
 * address bit 13 (11 in LPDDR2 / LPDDR3 mode). Half bus width mode: Unused.
 * Tomake it unused, this should be tied to 4'hF. Quarter bus width mode: Unused.
 * Tomake it unused, this must be tied to 4'hF. Valid Range: 0 to 7, and 15 Internal
 * Base: 11 The selected HIF address bit is determined by adding the internal
 * base to the value of this field. If set to 15, this column address bit is set to
 * 0. Per JEDEC DDR2 / DDR3 / mDDR specification, column address bit 10 is
 * reserved for indicating auto-precharge, and hence no source address bit can be
 * mapped to column address bit 10. In LPDDR2 / LPDDR3, there is a dedicated bit for
 * auto-precharge in the CA bus and hence column bit 10 is used. Value After
 * Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP4_ADDRMAP_COL_B11 (8U) /*!< Bit position for DDRC_ADDRMAP4_ADDRMAP_COL_B11. */
#define BM_DDRC_ADDRMAP4_ADDRMAP_COL_B11 (0x00000F00U) /*!< Bit mask for DDRC_ADDRMAP4_ADDRMAP_COL_B11. */
#define BS_DDRC_ADDRMAP4_ADDRMAP_COL_B11 (4U) /*!< Bit field size in bits for DDRC_ADDRMAP4_ADDRMAP_COL_B11. */

/*! @brief Read current value of the DDRC_ADDRMAP4_ADDRMAP_COL_B11 field. */
#define BR_DDRC_ADDRMAP4_ADDRMAP_COL_B11(x) (HW_DDRC_ADDRMAP4(x).B.ADDRMAP_COL_B11)

/*! @brief Format value for bitfield DDRC_ADDRMAP4_ADDRMAP_COL_B11. */
#define BF_DDRC_ADDRMAP4_ADDRMAP_COL_B11(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP4_ADDRMAP_COL_B11) & BM_DDRC_ADDRMAP4_ADDRMAP_COL_B11)

/*! @brief Set the ADDRMAP_COL_B11 field to a new value. */
#define BW_DDRC_ADDRMAP4_ADDRMAP_COL_B11(x, v) (HW_DDRC_ADDRMAP4_WR(x, (HW_DDRC_ADDRMAP4_RD(x) & ~BM_DDRC_ADDRMAP4_ADDRMAP_COL_B11) | BF_DDRC_ADDRMAP4_ADDRMAP_COL_B11(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_ADDRMAP5 - Address Map Register 5
 ******************************************************************************/

/*!
 * @brief HW_DDRC_ADDRMAP5 - Address Map Register 5 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_addrmap5
{
    uint32_t U;
    struct _hw_ddrc_addrmap5_bitfields
    {
        uint32_t ADDRMAP_ROW_B0 : 4;   /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t ADDRMAP_ROW_B1 : 4;   /*!< [11:8]  */
        uint32_t RESERVED1 : 4;        /*!< [15:12]  */
        uint32_t ADDRMAP_ROW_B2_10 : 4; /*!< [19:16]  */
        uint32_t RESERVED2 : 4;        /*!< [23:20]  */
        uint32_t ADDRMAP_ROW_B11 : 4;  /*!< [27:24]  */
        uint32_t RESERVED3 : 4;        /*!< [31:28]  */
    } B;
} hw_ddrc_addrmap5_t;

/*!
 * @name Constants and macros for entire DDRC_ADDRMAP5 register
 */
/*@{*/
#define HW_DDRC_ADDRMAP5_ADDR(x) ((uintptr_t)(x) + 0x214U)

#define HW_DDRC_ADDRMAP5(x)      (*(__IO hw_ddrc_addrmap5_t *) HW_DDRC_ADDRMAP5_ADDR(x))
#define HW_DDRC_ADDRMAP5_RD(x)   (HW_DDRC_ADDRMAP5(x).U)
#define HW_DDRC_ADDRMAP5_WR(x, v) (HW_DDRC_ADDRMAP5(x).U = (v))
#define HW_DDRC_ADDRMAP5_SET(x, v) (HW_DDRC_ADDRMAP5_WR(x, HW_DDRC_ADDRMAP5_RD(x) |  (v)))
#define HW_DDRC_ADDRMAP5_CLR(x, v) (HW_DDRC_ADDRMAP5_WR(x, HW_DDRC_ADDRMAP5_RD(x) & ~(v)))
#define HW_DDRC_ADDRMAP5_TOG(x, v) (HW_DDRC_ADDRMAP5_WR(x, HW_DDRC_ADDRMAP5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_ADDRMAP5 bitfields
 */

/*!
 * @name Register DDRC_ADDRMAP5, field ADDRMAP_ROW_B0[3:0] (RW)
 *
 * Selects the HIF address bits used as row address bit 0. Valid Range: 0 to 11
 * Internal Base: 6 The selected HIF address bit for each of the row address bits
 * is determined by adding the internal base to the value of this field. Value
 * After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP5_ADDRMAP_ROW_B0 (0U) /*!< Bit position for DDRC_ADDRMAP5_ADDRMAP_ROW_B0. */
#define BM_DDRC_ADDRMAP5_ADDRMAP_ROW_B0 (0x0000000FU) /*!< Bit mask for DDRC_ADDRMAP5_ADDRMAP_ROW_B0. */
#define BS_DDRC_ADDRMAP5_ADDRMAP_ROW_B0 (4U) /*!< Bit field size in bits for DDRC_ADDRMAP5_ADDRMAP_ROW_B0. */

/*! @brief Read current value of the DDRC_ADDRMAP5_ADDRMAP_ROW_B0 field. */
#define BR_DDRC_ADDRMAP5_ADDRMAP_ROW_B0(x) (HW_DDRC_ADDRMAP5(x).B.ADDRMAP_ROW_B0)

/*! @brief Format value for bitfield DDRC_ADDRMAP5_ADDRMAP_ROW_B0. */
#define BF_DDRC_ADDRMAP5_ADDRMAP_ROW_B0(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP5_ADDRMAP_ROW_B0) & BM_DDRC_ADDRMAP5_ADDRMAP_ROW_B0)

/*! @brief Set the ADDRMAP_ROW_B0 field to a new value. */
#define BW_DDRC_ADDRMAP5_ADDRMAP_ROW_B0(x, v) (HW_DDRC_ADDRMAP5_WR(x, (HW_DDRC_ADDRMAP5_RD(x) & ~BM_DDRC_ADDRMAP5_ADDRMAP_ROW_B0) | BF_DDRC_ADDRMAP5_ADDRMAP_ROW_B0(v)))
/*@}*/

/*!
 * @name Register DDRC_ADDRMAP5, field ADDRMAP_ROW_B1[11:8] (RW)
 *
 * Selects the HIF address bits used as row address bit 1. Valid Range: 0 to 11
 * Internal Base: 7 The selected HIF address bit for each of the row address bits
 * is determined by adding the internal base to the value of this field. Value
 * After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP5_ADDRMAP_ROW_B1 (8U) /*!< Bit position for DDRC_ADDRMAP5_ADDRMAP_ROW_B1. */
#define BM_DDRC_ADDRMAP5_ADDRMAP_ROW_B1 (0x00000F00U) /*!< Bit mask for DDRC_ADDRMAP5_ADDRMAP_ROW_B1. */
#define BS_DDRC_ADDRMAP5_ADDRMAP_ROW_B1 (4U) /*!< Bit field size in bits for DDRC_ADDRMAP5_ADDRMAP_ROW_B1. */

/*! @brief Read current value of the DDRC_ADDRMAP5_ADDRMAP_ROW_B1 field. */
#define BR_DDRC_ADDRMAP5_ADDRMAP_ROW_B1(x) (HW_DDRC_ADDRMAP5(x).B.ADDRMAP_ROW_B1)

/*! @brief Format value for bitfield DDRC_ADDRMAP5_ADDRMAP_ROW_B1. */
#define BF_DDRC_ADDRMAP5_ADDRMAP_ROW_B1(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP5_ADDRMAP_ROW_B1) & BM_DDRC_ADDRMAP5_ADDRMAP_ROW_B1)

/*! @brief Set the ADDRMAP_ROW_B1 field to a new value. */
#define BW_DDRC_ADDRMAP5_ADDRMAP_ROW_B1(x, v) (HW_DDRC_ADDRMAP5_WR(x, (HW_DDRC_ADDRMAP5_RD(x) & ~BM_DDRC_ADDRMAP5_ADDRMAP_ROW_B1) | BF_DDRC_ADDRMAP5_ADDRMAP_ROW_B1(v)))
/*@}*/

/*!
 * @name Register DDRC_ADDRMAP5, field ADDRMAP_ROW_B2_10[19:16] (RW)
 *
 * Selects the HIF address bits used as row address bits 2 to 10. Valid Range: 0
 * to 11 Internal Base: 8 (for row address bit 2), 9 (for row address bit 3), 10
 * (for row address bit 4) etc increasing to 16 (for row address bit 10) The
 * selected HIF address bit for each of the row address bits is determined by adding
 * the internal base to the value of this field. Value After Reset: 0x0 Exists:
 * Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10 (16U) /*!< Bit position for DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10. */
#define BM_DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10 (0x000F0000U) /*!< Bit mask for DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10. */
#define BS_DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10 (4U) /*!< Bit field size in bits for DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10. */

/*! @brief Read current value of the DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10 field. */
#define BR_DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10(x) (HW_DDRC_ADDRMAP5(x).B.ADDRMAP_ROW_B2_10)

/*! @brief Format value for bitfield DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10. */
#define BF_DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10) & BM_DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10)

/*! @brief Set the ADDRMAP_ROW_B2_10 field to a new value. */
#define BW_DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10(x, v) (HW_DDRC_ADDRMAP5_WR(x, (HW_DDRC_ADDRMAP5_RD(x) & ~BM_DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10) | BF_DDRC_ADDRMAP5_ADDRMAP_ROW_B2_10(v)))
/*@}*/

/*!
 * @name Register DDRC_ADDRMAP5, field ADDRMAP_ROW_B11[27:24] (RW)
 *
 * Selects the HIF address bit used as row address bit 11. Valid Range: 0 to 11,
 * and 15 Internal Base: 17 The selected HIF address bit is determined by adding
 * the internal base to the value of this field. If set to 15, row address bit
 * 11 is set to 0. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP5_ADDRMAP_ROW_B11 (24U) /*!< Bit position for DDRC_ADDRMAP5_ADDRMAP_ROW_B11. */
#define BM_DDRC_ADDRMAP5_ADDRMAP_ROW_B11 (0x0F000000U) /*!< Bit mask for DDRC_ADDRMAP5_ADDRMAP_ROW_B11. */
#define BS_DDRC_ADDRMAP5_ADDRMAP_ROW_B11 (4U) /*!< Bit field size in bits for DDRC_ADDRMAP5_ADDRMAP_ROW_B11. */

/*! @brief Read current value of the DDRC_ADDRMAP5_ADDRMAP_ROW_B11 field. */
#define BR_DDRC_ADDRMAP5_ADDRMAP_ROW_B11(x) (HW_DDRC_ADDRMAP5(x).B.ADDRMAP_ROW_B11)

/*! @brief Format value for bitfield DDRC_ADDRMAP5_ADDRMAP_ROW_B11. */
#define BF_DDRC_ADDRMAP5_ADDRMAP_ROW_B11(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP5_ADDRMAP_ROW_B11) & BM_DDRC_ADDRMAP5_ADDRMAP_ROW_B11)

/*! @brief Set the ADDRMAP_ROW_B11 field to a new value. */
#define BW_DDRC_ADDRMAP5_ADDRMAP_ROW_B11(x, v) (HW_DDRC_ADDRMAP5_WR(x, (HW_DDRC_ADDRMAP5_RD(x) & ~BM_DDRC_ADDRMAP5_ADDRMAP_ROW_B11) | BF_DDRC_ADDRMAP5_ADDRMAP_ROW_B11(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_ADDRMAP6 - Address Map Register 6
 ******************************************************************************/

/*!
 * @brief HW_DDRC_ADDRMAP6 - Address Map Register 6 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_addrmap6
{
    uint32_t U;
    struct _hw_ddrc_addrmap6_bitfields
    {
        uint32_t ADDRMAP_ROW_B12 : 4;  /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t ADDRMAP_ROW_B13 : 4;  /*!< [11:8]  */
        uint32_t RESERVED1 : 4;        /*!< [15:12]  */
        uint32_t ADDRMAP_ROW_B14 : 4;  /*!< [19:16]  */
        uint32_t RESERVED2 : 4;        /*!< [23:20]  */
        uint32_t ADDRMAP_ROW_B15 : 4;  /*!< [27:24]  */
        uint32_t RESERVED3 : 3;        /*!< [30:28]  */
        uint32_t LPDDR3_6GB_12GB : 1;  /*!< [31]  */
    } B;
} hw_ddrc_addrmap6_t;

/*!
 * @name Constants and macros for entire DDRC_ADDRMAP6 register
 */
/*@{*/
#define HW_DDRC_ADDRMAP6_ADDR(x) ((uintptr_t)(x) + 0x218U)

#define HW_DDRC_ADDRMAP6(x)      (*(__IO hw_ddrc_addrmap6_t *) HW_DDRC_ADDRMAP6_ADDR(x))
#define HW_DDRC_ADDRMAP6_RD(x)   (HW_DDRC_ADDRMAP6(x).U)
#define HW_DDRC_ADDRMAP6_WR(x, v) (HW_DDRC_ADDRMAP6(x).U = (v))
#define HW_DDRC_ADDRMAP6_SET(x, v) (HW_DDRC_ADDRMAP6_WR(x, HW_DDRC_ADDRMAP6_RD(x) |  (v)))
#define HW_DDRC_ADDRMAP6_CLR(x, v) (HW_DDRC_ADDRMAP6_WR(x, HW_DDRC_ADDRMAP6_RD(x) & ~(v)))
#define HW_DDRC_ADDRMAP6_TOG(x, v) (HW_DDRC_ADDRMAP6_WR(x, HW_DDRC_ADDRMAP6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_ADDRMAP6 bitfields
 */

/*!
 * @name Register DDRC_ADDRMAP6, field ADDRMAP_ROW_B12[3:0] (RW)
 *
 * Selects the HIF address bit used as row address bit 12. Valid Range: 0 to 11,
 * and 15 Internal Base: 18 The selected HIF address bit is determined by adding
 * the internal base to the value of this field. If set to 15, row address bit
 * 12 is set to 0. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP6_ADDRMAP_ROW_B12 (0U) /*!< Bit position for DDRC_ADDRMAP6_ADDRMAP_ROW_B12. */
#define BM_DDRC_ADDRMAP6_ADDRMAP_ROW_B12 (0x0000000FU) /*!< Bit mask for DDRC_ADDRMAP6_ADDRMAP_ROW_B12. */
#define BS_DDRC_ADDRMAP6_ADDRMAP_ROW_B12 (4U) /*!< Bit field size in bits for DDRC_ADDRMAP6_ADDRMAP_ROW_B12. */

/*! @brief Read current value of the DDRC_ADDRMAP6_ADDRMAP_ROW_B12 field. */
#define BR_DDRC_ADDRMAP6_ADDRMAP_ROW_B12(x) (HW_DDRC_ADDRMAP6(x).B.ADDRMAP_ROW_B12)

/*! @brief Format value for bitfield DDRC_ADDRMAP6_ADDRMAP_ROW_B12. */
#define BF_DDRC_ADDRMAP6_ADDRMAP_ROW_B12(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP6_ADDRMAP_ROW_B12) & BM_DDRC_ADDRMAP6_ADDRMAP_ROW_B12)

/*! @brief Set the ADDRMAP_ROW_B12 field to a new value. */
#define BW_DDRC_ADDRMAP6_ADDRMAP_ROW_B12(x, v) (HW_DDRC_ADDRMAP6_WR(x, (HW_DDRC_ADDRMAP6_RD(x) & ~BM_DDRC_ADDRMAP6_ADDRMAP_ROW_B12) | BF_DDRC_ADDRMAP6_ADDRMAP_ROW_B12(v)))
/*@}*/

/*!
 * @name Register DDRC_ADDRMAP6, field ADDRMAP_ROW_B13[11:8] (RW)
 *
 * Selects the HIF address bit used as row address bit 13. Valid Range: 0 to 11,
 * and 15 Internal Base: 19 The selected HIF address bit is determined by adding
 * the internal base to the value of this field. If set to 15, row address bit
 * 13 is set to 0. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP6_ADDRMAP_ROW_B13 (8U) /*!< Bit position for DDRC_ADDRMAP6_ADDRMAP_ROW_B13. */
#define BM_DDRC_ADDRMAP6_ADDRMAP_ROW_B13 (0x00000F00U) /*!< Bit mask for DDRC_ADDRMAP6_ADDRMAP_ROW_B13. */
#define BS_DDRC_ADDRMAP6_ADDRMAP_ROW_B13 (4U) /*!< Bit field size in bits for DDRC_ADDRMAP6_ADDRMAP_ROW_B13. */

/*! @brief Read current value of the DDRC_ADDRMAP6_ADDRMAP_ROW_B13 field. */
#define BR_DDRC_ADDRMAP6_ADDRMAP_ROW_B13(x) (HW_DDRC_ADDRMAP6(x).B.ADDRMAP_ROW_B13)

/*! @brief Format value for bitfield DDRC_ADDRMAP6_ADDRMAP_ROW_B13. */
#define BF_DDRC_ADDRMAP6_ADDRMAP_ROW_B13(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP6_ADDRMAP_ROW_B13) & BM_DDRC_ADDRMAP6_ADDRMAP_ROW_B13)

/*! @brief Set the ADDRMAP_ROW_B13 field to a new value. */
#define BW_DDRC_ADDRMAP6_ADDRMAP_ROW_B13(x, v) (HW_DDRC_ADDRMAP6_WR(x, (HW_DDRC_ADDRMAP6_RD(x) & ~BM_DDRC_ADDRMAP6_ADDRMAP_ROW_B13) | BF_DDRC_ADDRMAP6_ADDRMAP_ROW_B13(v)))
/*@}*/

/*!
 * @name Register DDRC_ADDRMAP6, field ADDRMAP_ROW_B14[19:16] (RW)
 *
 * Selects the HIF address bit used as row address bit 14. Valid Range: 0 to 11,
 * and 15 Internal Base: 20 The selected HIF address bit is determined by adding
 * the internal base to the value of this field. If set to 15, row address bit
 * 14 is set to 0. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP6_ADDRMAP_ROW_B14 (16U) /*!< Bit position for DDRC_ADDRMAP6_ADDRMAP_ROW_B14. */
#define BM_DDRC_ADDRMAP6_ADDRMAP_ROW_B14 (0x000F0000U) /*!< Bit mask for DDRC_ADDRMAP6_ADDRMAP_ROW_B14. */
#define BS_DDRC_ADDRMAP6_ADDRMAP_ROW_B14 (4U) /*!< Bit field size in bits for DDRC_ADDRMAP6_ADDRMAP_ROW_B14. */

/*! @brief Read current value of the DDRC_ADDRMAP6_ADDRMAP_ROW_B14 field. */
#define BR_DDRC_ADDRMAP6_ADDRMAP_ROW_B14(x) (HW_DDRC_ADDRMAP6(x).B.ADDRMAP_ROW_B14)

/*! @brief Format value for bitfield DDRC_ADDRMAP6_ADDRMAP_ROW_B14. */
#define BF_DDRC_ADDRMAP6_ADDRMAP_ROW_B14(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP6_ADDRMAP_ROW_B14) & BM_DDRC_ADDRMAP6_ADDRMAP_ROW_B14)

/*! @brief Set the ADDRMAP_ROW_B14 field to a new value. */
#define BW_DDRC_ADDRMAP6_ADDRMAP_ROW_B14(x, v) (HW_DDRC_ADDRMAP6_WR(x, (HW_DDRC_ADDRMAP6_RD(x) & ~BM_DDRC_ADDRMAP6_ADDRMAP_ROW_B14) | BF_DDRC_ADDRMAP6_ADDRMAP_ROW_B14(v)))
/*@}*/

/*!
 * @name Register DDRC_ADDRMAP6, field ADDRMAP_ROW_B15[27:24] (RW)
 *
 * Selects the HIF address bit used as row address bit 15. Valid Range: 0 to 11,
 * and 15 Internal Base: 21 The selected HIF address bit is determined by adding
 * the internal base to the value of this field. If set to 15, row address bit
 * 15 is set to 0. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ADDRMAP6_ADDRMAP_ROW_B15 (24U) /*!< Bit position for DDRC_ADDRMAP6_ADDRMAP_ROW_B15. */
#define BM_DDRC_ADDRMAP6_ADDRMAP_ROW_B15 (0x0F000000U) /*!< Bit mask for DDRC_ADDRMAP6_ADDRMAP_ROW_B15. */
#define BS_DDRC_ADDRMAP6_ADDRMAP_ROW_B15 (4U) /*!< Bit field size in bits for DDRC_ADDRMAP6_ADDRMAP_ROW_B15. */

/*! @brief Read current value of the DDRC_ADDRMAP6_ADDRMAP_ROW_B15 field. */
#define BR_DDRC_ADDRMAP6_ADDRMAP_ROW_B15(x) (HW_DDRC_ADDRMAP6(x).B.ADDRMAP_ROW_B15)

/*! @brief Format value for bitfield DDRC_ADDRMAP6_ADDRMAP_ROW_B15. */
#define BF_DDRC_ADDRMAP6_ADDRMAP_ROW_B15(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP6_ADDRMAP_ROW_B15) & BM_DDRC_ADDRMAP6_ADDRMAP_ROW_B15)

/*! @brief Set the ADDRMAP_ROW_B15 field to a new value. */
#define BW_DDRC_ADDRMAP6_ADDRMAP_ROW_B15(x, v) (HW_DDRC_ADDRMAP6_WR(x, (HW_DDRC_ADDRMAP6_RD(x) & ~BM_DDRC_ADDRMAP6_ADDRMAP_ROW_B15) | BF_DDRC_ADDRMAP6_ADDRMAP_ROW_B15(v)))
/*@}*/

/*!
 * @name Register DDRC_ADDRMAP6, field LPDDR3_6GB_12GB[31] (RW)
 *
 * Set this to 1 if there is an LPDDR3 SDRAM 6 Gb or 12 Gb device in use.
 * Present only in designs configured to support LPDDR3. Value After Reset: 0x0 Exists:
 * MEMC_LPDDR3 == 1
 *
 * Values:
 * - 1 - LPDDR3 SDRAM 6 Gb / 12 Gb device in use. Every address having
 *     row[14:13] == 2'b11 is considered as invalid
 * - 0 - Non-LPDDR3 6 Gb / 12 Gb device in use. All addresses are valid
 */
/*@{*/
#define BP_DDRC_ADDRMAP6_LPDDR3_6GB_12GB (31U) /*!< Bit position for DDRC_ADDRMAP6_LPDDR3_6GB_12GB. */
#define BM_DDRC_ADDRMAP6_LPDDR3_6GB_12GB (0x80000000U) /*!< Bit mask for DDRC_ADDRMAP6_LPDDR3_6GB_12GB. */
#define BS_DDRC_ADDRMAP6_LPDDR3_6GB_12GB (1U) /*!< Bit field size in bits for DDRC_ADDRMAP6_LPDDR3_6GB_12GB. */

/*! @brief Read current value of the DDRC_ADDRMAP6_LPDDR3_6GB_12GB field. */
#define BR_DDRC_ADDRMAP6_LPDDR3_6GB_12GB(x) (HW_DDRC_ADDRMAP6(x).B.LPDDR3_6GB_12GB)

/*! @brief Format value for bitfield DDRC_ADDRMAP6_LPDDR3_6GB_12GB. */
#define BF_DDRC_ADDRMAP6_LPDDR3_6GB_12GB(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ADDRMAP6_LPDDR3_6GB_12GB) & BM_DDRC_ADDRMAP6_LPDDR3_6GB_12GB)

/*! @brief Set the LPDDR3_6GB_12GB field to a new value. */
#define BW_DDRC_ADDRMAP6_LPDDR3_6GB_12GB(x, v) (HW_DDRC_ADDRMAP6_WR(x, (HW_DDRC_ADDRMAP6_RD(x) & ~BM_DDRC_ADDRMAP6_LPDDR3_6GB_12GB) | BF_DDRC_ADDRMAP6_LPDDR3_6GB_12GB(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_ODTCFG - ODT Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_ODTCFG - ODT Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_odtcfg
{
    uint32_t U;
    struct _hw_ddrc_odtcfg_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t RD_ODT_DELAY : 5;     /*!< [6:2]  */
        uint32_t RESERVED1 : 1;        /*!< [7]  */
        uint32_t RD_ODT_HOLD : 4;      /*!< [11:8]  */
        uint32_t RESERVED2 : 4;        /*!< [15:12]  */
        uint32_t WR_ODT_DELAY : 5;     /*!< [20:16]  */
        uint32_t RESERVED3 : 3;        /*!< [23:21]  */
        uint32_t WR_ODT_HOLD : 4;      /*!< [27:24]  */
        uint32_t RESERVED4 : 4;        /*!< [31:28]  */
    } B;
} hw_ddrc_odtcfg_t;

/*!
 * @name Constants and macros for entire DDRC_ODTCFG register
 */
/*@{*/
#define HW_DDRC_ODTCFG_ADDR(x)   ((uintptr_t)(x) + 0x240U)

#define HW_DDRC_ODTCFG(x)        (*(__IO hw_ddrc_odtcfg_t *) HW_DDRC_ODTCFG_ADDR(x))
#define HW_DDRC_ODTCFG_RD(x)     (HW_DDRC_ODTCFG(x).U)
#define HW_DDRC_ODTCFG_WR(x, v)  (HW_DDRC_ODTCFG(x).U = (v))
#define HW_DDRC_ODTCFG_SET(x, v) (HW_DDRC_ODTCFG_WR(x, HW_DDRC_ODTCFG_RD(x) |  (v)))
#define HW_DDRC_ODTCFG_CLR(x, v) (HW_DDRC_ODTCFG_WR(x, HW_DDRC_ODTCFG_RD(x) & ~(v)))
#define HW_DDRC_ODTCFG_TOG(x, v) (HW_DDRC_ODTCFG_WR(x, HW_DDRC_ODTCFG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_ODTCFG bitfields
 */

/*!
 * @name Register DDRC_ODTCFG, field RD_ODT_DELAY[6:2] (RW)
 *
 * The delay, in clock cycles, from issuing a read command to setting ODT values
 * associated with that command. ODT setting must remain constant for the entire
 * time that DQS is driven by the DDRC. Recommended values: DDR3: (CL - CWL)
 * Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ODTCFG_RD_ODT_DELAY (2U)   /*!< Bit position for DDRC_ODTCFG_RD_ODT_DELAY. */
#define BM_DDRC_ODTCFG_RD_ODT_DELAY (0x0000007CU) /*!< Bit mask for DDRC_ODTCFG_RD_ODT_DELAY. */
#define BS_DDRC_ODTCFG_RD_ODT_DELAY (5U)   /*!< Bit field size in bits for DDRC_ODTCFG_RD_ODT_DELAY. */

/*! @brief Read current value of the DDRC_ODTCFG_RD_ODT_DELAY field. */
#define BR_DDRC_ODTCFG_RD_ODT_DELAY(x) (HW_DDRC_ODTCFG(x).B.RD_ODT_DELAY)

/*! @brief Format value for bitfield DDRC_ODTCFG_RD_ODT_DELAY. */
#define BF_DDRC_ODTCFG_RD_ODT_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ODTCFG_RD_ODT_DELAY) & BM_DDRC_ODTCFG_RD_ODT_DELAY)

/*! @brief Set the RD_ODT_DELAY field to a new value. */
#define BW_DDRC_ODTCFG_RD_ODT_DELAY(x, v) (HW_DDRC_ODTCFG_WR(x, (HW_DDRC_ODTCFG_RD(x) & ~BM_DDRC_ODTCFG_RD_ODT_DELAY) | BF_DDRC_ODTCFG_RD_ODT_DELAY(v)))
/*@}*/

/*!
 * @name Register DDRC_ODTCFG, field RD_ODT_HOLD[11:8] (RW)
 *
 * Cycles to hold ODT for a read command. The minimum supported value is 2.
 * Recommended values: DDR3: BL8 - 0x6 BL4 - 0x4 Value After Reset: 0x4 Exists: Always
 */
/*@{*/
#define BP_DDRC_ODTCFG_RD_ODT_HOLD (8U)    /*!< Bit position for DDRC_ODTCFG_RD_ODT_HOLD. */
#define BM_DDRC_ODTCFG_RD_ODT_HOLD (0x00000F00U) /*!< Bit mask for DDRC_ODTCFG_RD_ODT_HOLD. */
#define BS_DDRC_ODTCFG_RD_ODT_HOLD (4U)    /*!< Bit field size in bits for DDRC_ODTCFG_RD_ODT_HOLD. */

/*! @brief Read current value of the DDRC_ODTCFG_RD_ODT_HOLD field. */
#define BR_DDRC_ODTCFG_RD_ODT_HOLD(x) (HW_DDRC_ODTCFG(x).B.RD_ODT_HOLD)

/*! @brief Format value for bitfield DDRC_ODTCFG_RD_ODT_HOLD. */
#define BF_DDRC_ODTCFG_RD_ODT_HOLD(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ODTCFG_RD_ODT_HOLD) & BM_DDRC_ODTCFG_RD_ODT_HOLD)

/*! @brief Set the RD_ODT_HOLD field to a new value. */
#define BW_DDRC_ODTCFG_RD_ODT_HOLD(x, v) (HW_DDRC_ODTCFG_WR(x, (HW_DDRC_ODTCFG_RD(x) & ~BM_DDRC_ODTCFG_RD_ODT_HOLD) | BF_DDRC_ODTCFG_RD_ODT_HOLD(v)))
/*@}*/

/*!
 * @name Register DDRC_ODTCFG, field WR_ODT_DELAY[20:16] (RW)
 *
 * The delay, in clock cycles, from issuing a write command to setting ODT
 * values associated with that command. ODT setting must remain constant for the
 * entire time that DQS is driven by the DDRC. ODT is used only in DDR3 designs.
 * Recommended values: DDR3 - 0 Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_ODTCFG_WR_ODT_DELAY (16U)  /*!< Bit position for DDRC_ODTCFG_WR_ODT_DELAY. */
#define BM_DDRC_ODTCFG_WR_ODT_DELAY (0x001F0000U) /*!< Bit mask for DDRC_ODTCFG_WR_ODT_DELAY. */
#define BS_DDRC_ODTCFG_WR_ODT_DELAY (5U)   /*!< Bit field size in bits for DDRC_ODTCFG_WR_ODT_DELAY. */

/*! @brief Read current value of the DDRC_ODTCFG_WR_ODT_DELAY field. */
#define BR_DDRC_ODTCFG_WR_ODT_DELAY(x) (HW_DDRC_ODTCFG(x).B.WR_ODT_DELAY)

/*! @brief Format value for bitfield DDRC_ODTCFG_WR_ODT_DELAY. */
#define BF_DDRC_ODTCFG_WR_ODT_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ODTCFG_WR_ODT_DELAY) & BM_DDRC_ODTCFG_WR_ODT_DELAY)

/*! @brief Set the WR_ODT_DELAY field to a new value. */
#define BW_DDRC_ODTCFG_WR_ODT_DELAY(x, v) (HW_DDRC_ODTCFG_WR(x, (HW_DDRC_ODTCFG_RD(x) & ~BM_DDRC_ODTCFG_WR_ODT_DELAY) | BF_DDRC_ODTCFG_WR_ODT_DELAY(v)))
/*@}*/

/*!
 * @name Register DDRC_ODTCFG, field WR_ODT_HOLD[27:24] (RW)
 *
 * Cycles to hold ODT for a write command. The minimum supported value is 2.
 * DDR3: BL8 - 0x6 BL4 - 0x4 Value After Reset: 0x4 Exists: Always
 */
/*@{*/
#define BP_DDRC_ODTCFG_WR_ODT_HOLD (24U)   /*!< Bit position for DDRC_ODTCFG_WR_ODT_HOLD. */
#define BM_DDRC_ODTCFG_WR_ODT_HOLD (0x0F000000U) /*!< Bit mask for DDRC_ODTCFG_WR_ODT_HOLD. */
#define BS_DDRC_ODTCFG_WR_ODT_HOLD (4U)    /*!< Bit field size in bits for DDRC_ODTCFG_WR_ODT_HOLD. */

/*! @brief Read current value of the DDRC_ODTCFG_WR_ODT_HOLD field. */
#define BR_DDRC_ODTCFG_WR_ODT_HOLD(x) (HW_DDRC_ODTCFG(x).B.WR_ODT_HOLD)

/*! @brief Format value for bitfield DDRC_ODTCFG_WR_ODT_HOLD. */
#define BF_DDRC_ODTCFG_WR_ODT_HOLD(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ODTCFG_WR_ODT_HOLD) & BM_DDRC_ODTCFG_WR_ODT_HOLD)

/*! @brief Set the WR_ODT_HOLD field to a new value. */
#define BW_DDRC_ODTCFG_WR_ODT_HOLD(x, v) (HW_DDRC_ODTCFG_WR(x, (HW_DDRC_ODTCFG_RD(x) & ~BM_DDRC_ODTCFG_WR_ODT_HOLD) | BF_DDRC_ODTCFG_WR_ODT_HOLD(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_ODTMAP - ODT / Rank Map Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_ODTMAP - ODT / Rank Map Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_odtmap
{
    uint32_t U;
    struct _hw_ddrc_odtmap_bitfields
    {
        uint32_t RANK0_WR_ODT : 4;     /*!< [3:0]  */
        uint32_t RANK0_RD_ODT : 4;     /*!< [7:4]  */
        uint32_t RANK1_WR_ODT : 4;     /*!< [11:8]  */
        uint32_t RANK1_RD_ODT : 4;     /*!< [15:12]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_ddrc_odtmap_t;

/*!
 * @name Constants and macros for entire DDRC_ODTMAP register
 */
/*@{*/
#define HW_DDRC_ODTMAP_ADDR(x)   ((uintptr_t)(x) + 0x244U)

#define HW_DDRC_ODTMAP(x)        (*(__IO hw_ddrc_odtmap_t *) HW_DDRC_ODTMAP_ADDR(x))
#define HW_DDRC_ODTMAP_RD(x)     (HW_DDRC_ODTMAP(x).U)
#define HW_DDRC_ODTMAP_WR(x, v)  (HW_DDRC_ODTMAP(x).U = (v))
#define HW_DDRC_ODTMAP_SET(x, v) (HW_DDRC_ODTMAP_WR(x, HW_DDRC_ODTMAP_RD(x) |  (v)))
#define HW_DDRC_ODTMAP_CLR(x, v) (HW_DDRC_ODTMAP_WR(x, HW_DDRC_ODTMAP_RD(x) & ~(v)))
#define HW_DDRC_ODTMAP_TOG(x, v) (HW_DDRC_ODTMAP_WR(x, HW_DDRC_ODTMAP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_ODTMAP bitfields
 */

/*!
 * @name Register DDRC_ODTMAP, field RANK0_WR_ODT[3:0] (RW)
 *
 * Indicates which remote ODTs must be turned on during a write to rank 0. Each
 * rank has a remote ODT (in the SDRAM) which can be turned on by setting the
 * appropriate bit here. Rank 0 is controlled by the LSB; rank 1 is controlled by
 * bit next to the LSB, etc. For each rank, set its bit to 1 to enable its ODT.
 * Value After Reset: 0x1 Exists: Always
 */
/*@{*/
#define BP_DDRC_ODTMAP_RANK0_WR_ODT (0U)   /*!< Bit position for DDRC_ODTMAP_RANK0_WR_ODT. */
#define BM_DDRC_ODTMAP_RANK0_WR_ODT (0x0000000FU) /*!< Bit mask for DDRC_ODTMAP_RANK0_WR_ODT. */
#define BS_DDRC_ODTMAP_RANK0_WR_ODT (4U)   /*!< Bit field size in bits for DDRC_ODTMAP_RANK0_WR_ODT. */

/*! @brief Read current value of the DDRC_ODTMAP_RANK0_WR_ODT field. */
#define BR_DDRC_ODTMAP_RANK0_WR_ODT(x) (HW_DDRC_ODTMAP(x).B.RANK0_WR_ODT)

/*! @brief Format value for bitfield DDRC_ODTMAP_RANK0_WR_ODT. */
#define BF_DDRC_ODTMAP_RANK0_WR_ODT(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ODTMAP_RANK0_WR_ODT) & BM_DDRC_ODTMAP_RANK0_WR_ODT)

/*! @brief Set the RANK0_WR_ODT field to a new value. */
#define BW_DDRC_ODTMAP_RANK0_WR_ODT(x, v) (HW_DDRC_ODTMAP_WR(x, (HW_DDRC_ODTMAP_RD(x) & ~BM_DDRC_ODTMAP_RANK0_WR_ODT) | BF_DDRC_ODTMAP_RANK0_WR_ODT(v)))
/*@}*/

/*!
 * @name Register DDRC_ODTMAP, field RANK0_RD_ODT[7:4] (RW)
 *
 * Indicates which remote ODTs must be turned on during a read from rank 0. Each
 * rank has a remote ODT (in the SDRAM) which can be turned on by setting the
 * appropriate bit here. Rank 0 is controlled by the LSB; rank 1 is controlled by
 * bit next to the LSB, etc. For each rank, set its bit to 1 to enable its ODT.
 * Value After Reset: 0x1 Exists: Always
 */
/*@{*/
#define BP_DDRC_ODTMAP_RANK0_RD_ODT (4U)   /*!< Bit position for DDRC_ODTMAP_RANK0_RD_ODT. */
#define BM_DDRC_ODTMAP_RANK0_RD_ODT (0x000000F0U) /*!< Bit mask for DDRC_ODTMAP_RANK0_RD_ODT. */
#define BS_DDRC_ODTMAP_RANK0_RD_ODT (4U)   /*!< Bit field size in bits for DDRC_ODTMAP_RANK0_RD_ODT. */

/*! @brief Read current value of the DDRC_ODTMAP_RANK0_RD_ODT field. */
#define BR_DDRC_ODTMAP_RANK0_RD_ODT(x) (HW_DDRC_ODTMAP(x).B.RANK0_RD_ODT)

/*! @brief Format value for bitfield DDRC_ODTMAP_RANK0_RD_ODT. */
#define BF_DDRC_ODTMAP_RANK0_RD_ODT(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ODTMAP_RANK0_RD_ODT) & BM_DDRC_ODTMAP_RANK0_RD_ODT)

/*! @brief Set the RANK0_RD_ODT field to a new value. */
#define BW_DDRC_ODTMAP_RANK0_RD_ODT(x, v) (HW_DDRC_ODTMAP_WR(x, (HW_DDRC_ODTMAP_RD(x) & ~BM_DDRC_ODTMAP_RANK0_RD_ODT) | BF_DDRC_ODTMAP_RANK0_RD_ODT(v)))
/*@}*/

/*!
 * @name Register DDRC_ODTMAP, field RANK1_WR_ODT[11:8] (RW)
 *
 * Indicates which remote ODTs must be turned on during a write to rank 1. Each
 * rank has a remote ODT (in the SDRAM) which can be turned on by setting the
 * appropriate bit here. Rank 0 is controlled by the LSB; rank 1 is controlled by
 * bit next to the LSB, etc. For each rank, set its bit to 1 to enable its ODT.
 * Present only in configurations that have 2 or more ranks Value After Reset:
 * "(MEMC_NUM_RANKS > 1) ? 0x2 : 0x0" Exists: MEMC_NUM_RANKS > 1
 */
/*@{*/
#define BP_DDRC_ODTMAP_RANK1_WR_ODT (8U)   /*!< Bit position for DDRC_ODTMAP_RANK1_WR_ODT. */
#define BM_DDRC_ODTMAP_RANK1_WR_ODT (0x00000F00U) /*!< Bit mask for DDRC_ODTMAP_RANK1_WR_ODT. */
#define BS_DDRC_ODTMAP_RANK1_WR_ODT (4U)   /*!< Bit field size in bits for DDRC_ODTMAP_RANK1_WR_ODT. */

/*! @brief Read current value of the DDRC_ODTMAP_RANK1_WR_ODT field. */
#define BR_DDRC_ODTMAP_RANK1_WR_ODT(x) (HW_DDRC_ODTMAP(x).B.RANK1_WR_ODT)

/*! @brief Format value for bitfield DDRC_ODTMAP_RANK1_WR_ODT. */
#define BF_DDRC_ODTMAP_RANK1_WR_ODT(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ODTMAP_RANK1_WR_ODT) & BM_DDRC_ODTMAP_RANK1_WR_ODT)

/*! @brief Set the RANK1_WR_ODT field to a new value. */
#define BW_DDRC_ODTMAP_RANK1_WR_ODT(x, v) (HW_DDRC_ODTMAP_WR(x, (HW_DDRC_ODTMAP_RD(x) & ~BM_DDRC_ODTMAP_RANK1_WR_ODT) | BF_DDRC_ODTMAP_RANK1_WR_ODT(v)))
/*@}*/

/*!
 * @name Register DDRC_ODTMAP, field RANK1_RD_ODT[15:12] (RW)
 *
 * Indicates which remote ODTs must be turned on during a read from rank 1. Each
 * rank has a remote ODT (in the SDRAM) which can be turned on by setting the
 * appropriate bit here. Rank 0 is controlled by the LSB; rank 1 is controlled by
 * bit next to the LSB, etc. For each rank, set its bit to 1 to enable its ODT.
 * Present only in configurations that have 2 or more ranks Value After Reset:
 * "(MEMC_NUM_RANKS > 1) ? 0x2 : 0x0" Exists: MEMC_NUM_RANKS > 1
 */
/*@{*/
#define BP_DDRC_ODTMAP_RANK1_RD_ODT (12U)  /*!< Bit position for DDRC_ODTMAP_RANK1_RD_ODT. */
#define BM_DDRC_ODTMAP_RANK1_RD_ODT (0x0000F000U) /*!< Bit mask for DDRC_ODTMAP_RANK1_RD_ODT. */
#define BS_DDRC_ODTMAP_RANK1_RD_ODT (4U)   /*!< Bit field size in bits for DDRC_ODTMAP_RANK1_RD_ODT. */

/*! @brief Read current value of the DDRC_ODTMAP_RANK1_RD_ODT field. */
#define BR_DDRC_ODTMAP_RANK1_RD_ODT(x) (HW_DDRC_ODTMAP(x).B.RANK1_RD_ODT)

/*! @brief Format value for bitfield DDRC_ODTMAP_RANK1_RD_ODT. */
#define BF_DDRC_ODTMAP_RANK1_RD_ODT(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_ODTMAP_RANK1_RD_ODT) & BM_DDRC_ODTMAP_RANK1_RD_ODT)

/*! @brief Set the RANK1_RD_ODT field to a new value. */
#define BW_DDRC_ODTMAP_RANK1_RD_ODT(x, v) (HW_DDRC_ODTMAP_WR(x, (HW_DDRC_ODTMAP_RD(x) & ~BM_DDRC_ODTMAP_RANK1_RD_ODT) | BF_DDRC_ODTMAP_RANK1_RD_ODT(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_SCHED - Scheduler Control Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_SCHED - Scheduler Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_sched
{
    uint32_t U;
    struct _hw_ddrc_sched_bitfields
    {
        uint32_t FORCE_LOW_PRI_N : 1;  /*!< [0]  */
        uint32_t PREFER_WRITE : 1;     /*!< [1]  */
        uint32_t PAGECLOSE : 1;        /*!< [2]  */
        uint32_t RESERVED0 : 5;        /*!< [7:3]  */
        uint32_t LPR_NUM_ENTRIES : 6;  /*!< [13:8]  */
        uint32_t RESERVED1 : 10;       /*!< [23:14]  */
        uint32_t RDWR_IDLE_GAP : 7;    /*!< [30:24]  */
        uint32_t RESERVED2 : 1;        /*!< [31]  */
    } B;
} hw_ddrc_sched_t;

/*!
 * @name Constants and macros for entire DDRC_SCHED register
 */
/*@{*/
#define HW_DDRC_SCHED_ADDR(x)    ((uintptr_t)(x) + 0x250U)

#define HW_DDRC_SCHED(x)         (*(__IO hw_ddrc_sched_t *) HW_DDRC_SCHED_ADDR(x))
#define HW_DDRC_SCHED_RD(x)      (HW_DDRC_SCHED(x).U)
#define HW_DDRC_SCHED_WR(x, v)   (HW_DDRC_SCHED(x).U = (v))
#define HW_DDRC_SCHED_SET(x, v)  (HW_DDRC_SCHED_WR(x, HW_DDRC_SCHED_RD(x) |  (v)))
#define HW_DDRC_SCHED_CLR(x, v)  (HW_DDRC_SCHED_WR(x, HW_DDRC_SCHED_RD(x) & ~(v)))
#define HW_DDRC_SCHED_TOG(x, v)  (HW_DDRC_SCHED_WR(x, HW_DDRC_SCHED_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_SCHED bitfields
 */

/*!
 * @name Register DDRC_SCHED, field FORCE_LOW_PRI_N[0] (RW)
 *
 * Active low signal.When asserted ('0'), all incoming transactions are forced
 * to low priority. This implies that all High Priority Read (HPR) and Variable
 * Priority Read commands (VPR) will be treated as Low Priority Read (LPR)
 * commands. On the write side, all Variable PriorityWrite (VPW) commands will be treated
 * as Normal PriorityWrite (NPW) commands. Forcing the incoming transactions to
 * low priority implicitly turns off Bypass path for read commands. FOR
 * PERFORMANCE ONLY. Value After Reset: 0x1 Exists: Always
 */
/*@{*/
#define BP_DDRC_SCHED_FORCE_LOW_PRI_N (0U) /*!< Bit position for DDRC_SCHED_FORCE_LOW_PRI_N. */
#define BM_DDRC_SCHED_FORCE_LOW_PRI_N (0x00000001U) /*!< Bit mask for DDRC_SCHED_FORCE_LOW_PRI_N. */
#define BS_DDRC_SCHED_FORCE_LOW_PRI_N (1U) /*!< Bit field size in bits for DDRC_SCHED_FORCE_LOW_PRI_N. */

/*! @brief Read current value of the DDRC_SCHED_FORCE_LOW_PRI_N field. */
#define BR_DDRC_SCHED_FORCE_LOW_PRI_N(x) (HW_DDRC_SCHED(x).B.FORCE_LOW_PRI_N)

/*! @brief Format value for bitfield DDRC_SCHED_FORCE_LOW_PRI_N. */
#define BF_DDRC_SCHED_FORCE_LOW_PRI_N(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_SCHED_FORCE_LOW_PRI_N) & BM_DDRC_SCHED_FORCE_LOW_PRI_N)

/*! @brief Set the FORCE_LOW_PRI_N field to a new value. */
#define BW_DDRC_SCHED_FORCE_LOW_PRI_N(x, v) (HW_DDRC_SCHED_WR(x, (HW_DDRC_SCHED_RD(x) & ~BM_DDRC_SCHED_FORCE_LOW_PRI_N) | BF_DDRC_SCHED_FORCE_LOW_PRI_N(v)))
/*@}*/

/*!
 * @name Register DDRC_SCHED, field PREFER_WRITE[1] (RW)
 *
 * If set then the bank selector prefers writes over reads. FOR DEBUG ONLY.
 * Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_SCHED_PREFER_WRITE (1U)    /*!< Bit position for DDRC_SCHED_PREFER_WRITE. */
#define BM_DDRC_SCHED_PREFER_WRITE (0x00000002U) /*!< Bit mask for DDRC_SCHED_PREFER_WRITE. */
#define BS_DDRC_SCHED_PREFER_WRITE (1U)    /*!< Bit field size in bits for DDRC_SCHED_PREFER_WRITE. */

/*! @brief Read current value of the DDRC_SCHED_PREFER_WRITE field. */
#define BR_DDRC_SCHED_PREFER_WRITE(x) (HW_DDRC_SCHED(x).B.PREFER_WRITE)

/*! @brief Format value for bitfield DDRC_SCHED_PREFER_WRITE. */
#define BF_DDRC_SCHED_PREFER_WRITE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_SCHED_PREFER_WRITE) & BM_DDRC_SCHED_PREFER_WRITE)

/*! @brief Set the PREFER_WRITE field to a new value. */
#define BW_DDRC_SCHED_PREFER_WRITE(x, v) (HW_DDRC_SCHED_WR(x, (HW_DDRC_SCHED_RD(x) & ~BM_DDRC_SCHED_PREFER_WRITE) | BF_DDRC_SCHED_PREFER_WRITE(v)))
/*@}*/

/*!
 * @name Register DDRC_SCHED, field PAGECLOSE[2] (RW)
 *
 * If true, bank is kept open only until there are page hit transactions
 * available in the CAM to that bank. The last read or write command in the CAM with a
 * bank and page hit will be executed with auto-precharge if
 * SCHED1.pageclose_timer = 0. Even if this register set to 1 and SCHED1.pageclose_timer is set to 0,
 * explicit precharge (and not auto-precharge) may be issued in some cases where
 * there is a mode switch betweenWrite and Read or between LPR and HPR. The Read
 * andWrite commands that are executed as part of the ECC scrub requests are also
 * executed without auto-precharge. If false, the bank remains open until there
 * is a need to close it (to open a different page, or for page timeout or
 * refresh timeout) - also known as open page policy. The open page policy can be
 * overridden by setting the per-command- autopre bit on the HIF interface
 * (hif_cmd_autopre). The pageclose feature provids a midway between Open and Close page
 * policies. FOR PERFORMANCE ONLY. Value After Reset: 0x1 Exists: Always
 */
/*@{*/
#define BP_DDRC_SCHED_PAGECLOSE (2U)       /*!< Bit position for DDRC_SCHED_PAGECLOSE. */
#define BM_DDRC_SCHED_PAGECLOSE (0x00000004U) /*!< Bit mask for DDRC_SCHED_PAGECLOSE. */
#define BS_DDRC_SCHED_PAGECLOSE (1U)       /*!< Bit field size in bits for DDRC_SCHED_PAGECLOSE. */

/*! @brief Read current value of the DDRC_SCHED_PAGECLOSE field. */
#define BR_DDRC_SCHED_PAGECLOSE(x) (HW_DDRC_SCHED(x).B.PAGECLOSE)

/*! @brief Format value for bitfield DDRC_SCHED_PAGECLOSE. */
#define BF_DDRC_SCHED_PAGECLOSE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_SCHED_PAGECLOSE) & BM_DDRC_SCHED_PAGECLOSE)

/*! @brief Set the PAGECLOSE field to a new value. */
#define BW_DDRC_SCHED_PAGECLOSE(x, v) (HW_DDRC_SCHED_WR(x, (HW_DDRC_SCHED_RD(x) & ~BM_DDRC_SCHED_PAGECLOSE) | BF_DDRC_SCHED_PAGECLOSE(v)))
/*@}*/

/*!
 * @name Register DDRC_SCHED, field LPR_NUM_ENTRIES[13:8] (RW)
 *
 * Number of entries in the low priority transaction store is this value + 1.
 * (MEMC_NO_OF_ENTRY - (SCHED.lpr_num_entries + 1)) is the number of entries
 * available for the high priority transaction store. Setting this to maximum value
 * allocates all entries to low priority transaction store. Setting this to 0
 * allocates 1 entry to low priority transaction store and the rest to high priority
 * transaction store. Value After Reset: "MEMC_NO_OF_ENTRY / 2" Exists: Always
 */
/*@{*/
#define BP_DDRC_SCHED_LPR_NUM_ENTRIES (8U) /*!< Bit position for DDRC_SCHED_LPR_NUM_ENTRIES. */
#define BM_DDRC_SCHED_LPR_NUM_ENTRIES (0x00003F00U) /*!< Bit mask for DDRC_SCHED_LPR_NUM_ENTRIES. */
#define BS_DDRC_SCHED_LPR_NUM_ENTRIES (6U) /*!< Bit field size in bits for DDRC_SCHED_LPR_NUM_ENTRIES. */

/*! @brief Read current value of the DDRC_SCHED_LPR_NUM_ENTRIES field. */
#define BR_DDRC_SCHED_LPR_NUM_ENTRIES(x) (HW_DDRC_SCHED(x).B.LPR_NUM_ENTRIES)

/*! @brief Format value for bitfield DDRC_SCHED_LPR_NUM_ENTRIES. */
#define BF_DDRC_SCHED_LPR_NUM_ENTRIES(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_SCHED_LPR_NUM_ENTRIES) & BM_DDRC_SCHED_LPR_NUM_ENTRIES)

/*! @brief Set the LPR_NUM_ENTRIES field to a new value. */
#define BW_DDRC_SCHED_LPR_NUM_ENTRIES(x, v) (HW_DDRC_SCHED_WR(x, (HW_DDRC_SCHED_RD(x) & ~BM_DDRC_SCHED_LPR_NUM_ENTRIES) | BF_DDRC_SCHED_LPR_NUM_ENTRIES(v)))
/*@}*/

/*!
 * @name Register DDRC_SCHED, field RDWR_IDLE_GAP[30:24] (RW)
 *
 * When the preferred transaction store is empty for these many clock cycles,
 * switch to the alternate transaction store if it is non-empty. The read
 * transaction store (both high and low priority) is the default preferred transaction
 * store and the write transaction store is the alternative store. When prefer write
 * over read is set this is reversed. 0x0 is a legal value for this register.
 * When set to 0x0, the transaction store switching will happen immediately when
 * the switching conditions become true. FOR PERFORMANCE ONLY Value After Reset:
 * 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_SCHED_RDWR_IDLE_GAP (24U)  /*!< Bit position for DDRC_SCHED_RDWR_IDLE_GAP. */
#define BM_DDRC_SCHED_RDWR_IDLE_GAP (0x7F000000U) /*!< Bit mask for DDRC_SCHED_RDWR_IDLE_GAP. */
#define BS_DDRC_SCHED_RDWR_IDLE_GAP (7U)   /*!< Bit field size in bits for DDRC_SCHED_RDWR_IDLE_GAP. */

/*! @brief Read current value of the DDRC_SCHED_RDWR_IDLE_GAP field. */
#define BR_DDRC_SCHED_RDWR_IDLE_GAP(x) (HW_DDRC_SCHED(x).B.RDWR_IDLE_GAP)

/*! @brief Format value for bitfield DDRC_SCHED_RDWR_IDLE_GAP. */
#define BF_DDRC_SCHED_RDWR_IDLE_GAP(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_SCHED_RDWR_IDLE_GAP) & BM_DDRC_SCHED_RDWR_IDLE_GAP)

/*! @brief Set the RDWR_IDLE_GAP field to a new value. */
#define BW_DDRC_SCHED_RDWR_IDLE_GAP(x, v) (HW_DDRC_SCHED_WR(x, (HW_DDRC_SCHED_RD(x) & ~BM_DDRC_SCHED_RDWR_IDLE_GAP) | BF_DDRC_SCHED_RDWR_IDLE_GAP(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_SCHED1 - Scheduler Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_DDRC_SCHED1 - Scheduler Control Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_sched1
{
    uint32_t U;
    struct _hw_ddrc_sched1_bitfields
    {
        uint32_t PAGECLOSE_TIMER : 8;  /*!< [7:0]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_ddrc_sched1_t;

/*!
 * @name Constants and macros for entire DDRC_SCHED1 register
 */
/*@{*/
#define HW_DDRC_SCHED1_ADDR(x)   ((uintptr_t)(x) + 0x254U)

#define HW_DDRC_SCHED1(x)        (*(__IO hw_ddrc_sched1_t *) HW_DDRC_SCHED1_ADDR(x))
#define HW_DDRC_SCHED1_RD(x)     (HW_DDRC_SCHED1(x).U)
#define HW_DDRC_SCHED1_WR(x, v)  (HW_DDRC_SCHED1(x).U = (v))
#define HW_DDRC_SCHED1_SET(x, v) (HW_DDRC_SCHED1_WR(x, HW_DDRC_SCHED1_RD(x) |  (v)))
#define HW_DDRC_SCHED1_CLR(x, v) (HW_DDRC_SCHED1_WR(x, HW_DDRC_SCHED1_RD(x) & ~(v)))
#define HW_DDRC_SCHED1_TOG(x, v) (HW_DDRC_SCHED1_WR(x, HW_DDRC_SCHED1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_SCHED1 bitfields
 */

/*!
 * @name Register DDRC_SCHED1, field PAGECLOSE_TIMER[7:0] (RW)
 *
 * This field works in conjunction with SCHED.pageclose. It only has meaning if
 * SCHED.pageclose == 1. If SCHED.pageclose == 1 and pageclose_timer == 0, then
 * an auto-precharge may be scheduled for last read or write command in the CAM
 * with a bank and page hit. Note, sometimes an explicit precharge is scheduled
 * instead of the auto-precharge. See SCHED.pageclose for details of when this may
 * happen. If SCHED.pageclose == 1 and pageclose_timer > 0, then an auto-precharge
 * is not scheduled for last read or write command in the CAM with a bank and
 * page hit. Instead, a timer is started, with pageclose_timer as the initial
 * value. There is a timer on a per bank basis. The timer decrements unless the next
 * read or write in the CAM to a bank is a page hit. It gets reset to
 * pageclose_timer value if the next read or write in the CAM to a bank is a page hit. Once
 * the timer has reached zero, an explcit precharge will be attempted to be
 * scheduled. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_SCHED1_PAGECLOSE_TIMER (0U) /*!< Bit position for DDRC_SCHED1_PAGECLOSE_TIMER. */
#define BM_DDRC_SCHED1_PAGECLOSE_TIMER (0x000000FFU) /*!< Bit mask for DDRC_SCHED1_PAGECLOSE_TIMER. */
#define BS_DDRC_SCHED1_PAGECLOSE_TIMER (8U) /*!< Bit field size in bits for DDRC_SCHED1_PAGECLOSE_TIMER. */

/*! @brief Read current value of the DDRC_SCHED1_PAGECLOSE_TIMER field. */
#define BR_DDRC_SCHED1_PAGECLOSE_TIMER(x) (HW_DDRC_SCHED1(x).B.PAGECLOSE_TIMER)

/*! @brief Format value for bitfield DDRC_SCHED1_PAGECLOSE_TIMER. */
#define BF_DDRC_SCHED1_PAGECLOSE_TIMER(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_SCHED1_PAGECLOSE_TIMER) & BM_DDRC_SCHED1_PAGECLOSE_TIMER)

/*! @brief Set the PAGECLOSE_TIMER field to a new value. */
#define BW_DDRC_SCHED1_PAGECLOSE_TIMER(x, v) (HW_DDRC_SCHED1_WR(x, (HW_DDRC_SCHED1_RD(x) & ~BM_DDRC_SCHED1_PAGECLOSE_TIMER) | BF_DDRC_SCHED1_PAGECLOSE_TIMER(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_PERFHPR1 - High Priority Read CAM Register 1
 ******************************************************************************/

/*!
 * @brief HW_DDRC_PERFHPR1 - High Priority Read CAM Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_perfhpr1
{
    uint32_t U;
    struct _hw_ddrc_perfhpr1_bitfields
    {
        uint32_t HPR_MAX_STARVE : 16;  /*!< [15:0]  */
        uint32_t RESERVED0 : 8;        /*!< [23:16]  */
        uint32_t HPR_XACT_RUN_LENGTH : 8; /*!< [31:24]  */
    } B;
} hw_ddrc_perfhpr1_t;

/*!
 * @name Constants and macros for entire DDRC_PERFHPR1 register
 */
/*@{*/
#define HW_DDRC_PERFHPR1_ADDR(x) ((uintptr_t)(x) + 0x25CU)

#define HW_DDRC_PERFHPR1(x)      (*(__IO hw_ddrc_perfhpr1_t *) HW_DDRC_PERFHPR1_ADDR(x))
#define HW_DDRC_PERFHPR1_RD(x)   (HW_DDRC_PERFHPR1(x).U)
#define HW_DDRC_PERFHPR1_WR(x, v) (HW_DDRC_PERFHPR1(x).U = (v))
#define HW_DDRC_PERFHPR1_SET(x, v) (HW_DDRC_PERFHPR1_WR(x, HW_DDRC_PERFHPR1_RD(x) |  (v)))
#define HW_DDRC_PERFHPR1_CLR(x, v) (HW_DDRC_PERFHPR1_WR(x, HW_DDRC_PERFHPR1_RD(x) & ~(v)))
#define HW_DDRC_PERFHPR1_TOG(x, v) (HW_DDRC_PERFHPR1_WR(x, HW_DDRC_PERFHPR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_PERFHPR1 bitfields
 */

/*!
 * @name Register DDRC_PERFHPR1, field HPR_MAX_STARVE[15:0] (RW)
 *
 * Number of clocks that the HPR queue can be starved before it goes critical.
 * The minimum valid functional value for this register is 0x1. Programming it to
 * 0x0 will disable the starvation functionality; during normal operation, this
 * function should not be disabled as it will cause excessive latencies. Unit:
 * Clock cycles. FOR PERFORMANCE ONLY. Value After Reset: 0x1 Exists: Always
 */
/*@{*/
#define BP_DDRC_PERFHPR1_HPR_MAX_STARVE (0U) /*!< Bit position for DDRC_PERFHPR1_HPR_MAX_STARVE. */
#define BM_DDRC_PERFHPR1_HPR_MAX_STARVE (0x0000FFFFU) /*!< Bit mask for DDRC_PERFHPR1_HPR_MAX_STARVE. */
#define BS_DDRC_PERFHPR1_HPR_MAX_STARVE (16U) /*!< Bit field size in bits for DDRC_PERFHPR1_HPR_MAX_STARVE. */

/*! @brief Read current value of the DDRC_PERFHPR1_HPR_MAX_STARVE field. */
#define BR_DDRC_PERFHPR1_HPR_MAX_STARVE(x) (HW_DDRC_PERFHPR1(x).B.HPR_MAX_STARVE)

/*! @brief Format value for bitfield DDRC_PERFHPR1_HPR_MAX_STARVE. */
#define BF_DDRC_PERFHPR1_HPR_MAX_STARVE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_PERFHPR1_HPR_MAX_STARVE) & BM_DDRC_PERFHPR1_HPR_MAX_STARVE)

/*! @brief Set the HPR_MAX_STARVE field to a new value. */
#define BW_DDRC_PERFHPR1_HPR_MAX_STARVE(x, v) (HW_DDRC_PERFHPR1_WR(x, (HW_DDRC_PERFHPR1_RD(x) & ~BM_DDRC_PERFHPR1_HPR_MAX_STARVE) | BF_DDRC_PERFHPR1_HPR_MAX_STARVE(v)))
/*@}*/

/*!
 * @name Register DDRC_PERFHPR1, field HPR_XACT_RUN_LENGTH[31:24] (RW)
 *
 * Number of transactions that are serviced once the HPR queue goes critical is
 * the smaller of: This number Number of transactions available. Unit:
 * Transaction FOR PERFORMANCE ONLY. Value After Reset: 0xf Exists: Always
 */
/*@{*/
#define BP_DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH (24U) /*!< Bit position for DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH. */
#define BM_DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH (0xFF000000U) /*!< Bit mask for DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH. */
#define BS_DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH (8U) /*!< Bit field size in bits for DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH. */

/*! @brief Read current value of the DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH field. */
#define BR_DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH(x) (HW_DDRC_PERFHPR1(x).B.HPR_XACT_RUN_LENGTH)

/*! @brief Format value for bitfield DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH. */
#define BF_DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH) & BM_DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH)

/*! @brief Set the HPR_XACT_RUN_LENGTH field to a new value. */
#define BW_DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH(x, v) (HW_DDRC_PERFHPR1_WR(x, (HW_DDRC_PERFHPR1_RD(x) & ~BM_DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH) | BF_DDRC_PERFHPR1_HPR_XACT_RUN_LENGTH(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_PERFLPR1 - Low Priority Read CAM Register 1
 ******************************************************************************/

/*!
 * @brief HW_DDRC_PERFLPR1 - Low Priority Read CAM Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_perflpr1
{
    uint32_t U;
    struct _hw_ddrc_perflpr1_bitfields
    {
        uint32_t LPR_MAX_STARVE : 16;  /*!< [15:0]  */
        uint32_t RESERVED0 : 8;        /*!< [23:16]  */
        uint32_t LPR_XACT_RUN_LENGTH : 8; /*!< [31:24]  */
    } B;
} hw_ddrc_perflpr1_t;

/*!
 * @name Constants and macros for entire DDRC_PERFLPR1 register
 */
/*@{*/
#define HW_DDRC_PERFLPR1_ADDR(x) ((uintptr_t)(x) + 0x264U)

#define HW_DDRC_PERFLPR1(x)      (*(__IO hw_ddrc_perflpr1_t *) HW_DDRC_PERFLPR1_ADDR(x))
#define HW_DDRC_PERFLPR1_RD(x)   (HW_DDRC_PERFLPR1(x).U)
#define HW_DDRC_PERFLPR1_WR(x, v) (HW_DDRC_PERFLPR1(x).U = (v))
#define HW_DDRC_PERFLPR1_SET(x, v) (HW_DDRC_PERFLPR1_WR(x, HW_DDRC_PERFLPR1_RD(x) |  (v)))
#define HW_DDRC_PERFLPR1_CLR(x, v) (HW_DDRC_PERFLPR1_WR(x, HW_DDRC_PERFLPR1_RD(x) & ~(v)))
#define HW_DDRC_PERFLPR1_TOG(x, v) (HW_DDRC_PERFLPR1_WR(x, HW_DDRC_PERFLPR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_PERFLPR1 bitfields
 */

/*!
 * @name Register DDRC_PERFLPR1, field LPR_MAX_STARVE[15:0] (RW)
 *
 * Number of clocks that the LPR queue can be starved before it goes critical.
 * The minimum valid functional value for this register is 0x1. Programming it to
 * 0x0 will disable the starvation functionality; during normal operation, this
 * function should not be disabled as it will cause excessive latencies. Unit:
 * Clock cycles. FOR PERFORMANCE ONLY. Value After Reset: 0x7f Exists: Always
 */
/*@{*/
#define BP_DDRC_PERFLPR1_LPR_MAX_STARVE (0U) /*!< Bit position for DDRC_PERFLPR1_LPR_MAX_STARVE. */
#define BM_DDRC_PERFLPR1_LPR_MAX_STARVE (0x0000FFFFU) /*!< Bit mask for DDRC_PERFLPR1_LPR_MAX_STARVE. */
#define BS_DDRC_PERFLPR1_LPR_MAX_STARVE (16U) /*!< Bit field size in bits for DDRC_PERFLPR1_LPR_MAX_STARVE. */

/*! @brief Read current value of the DDRC_PERFLPR1_LPR_MAX_STARVE field. */
#define BR_DDRC_PERFLPR1_LPR_MAX_STARVE(x) (HW_DDRC_PERFLPR1(x).B.LPR_MAX_STARVE)

/*! @brief Format value for bitfield DDRC_PERFLPR1_LPR_MAX_STARVE. */
#define BF_DDRC_PERFLPR1_LPR_MAX_STARVE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_PERFLPR1_LPR_MAX_STARVE) & BM_DDRC_PERFLPR1_LPR_MAX_STARVE)

/*! @brief Set the LPR_MAX_STARVE field to a new value. */
#define BW_DDRC_PERFLPR1_LPR_MAX_STARVE(x, v) (HW_DDRC_PERFLPR1_WR(x, (HW_DDRC_PERFLPR1_RD(x) & ~BM_DDRC_PERFLPR1_LPR_MAX_STARVE) | BF_DDRC_PERFLPR1_LPR_MAX_STARVE(v)))
/*@}*/

/*!
 * @name Register DDRC_PERFLPR1, field LPR_XACT_RUN_LENGTH[31:24] (RW)
 *
 * Number of transactions that are serviced once the LPR queue goes critical is
 * the smaller of: This number Number of transactions available Unit:
 * Transaction. FOR PERFORMANCE ONLY. Value After Reset: 0xf Exists: Always
 */
/*@{*/
#define BP_DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH (24U) /*!< Bit position for DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH. */
#define BM_DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH (0xFF000000U) /*!< Bit mask for DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH. */
#define BS_DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH (8U) /*!< Bit field size in bits for DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH. */

/*! @brief Read current value of the DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH field. */
#define BR_DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH(x) (HW_DDRC_PERFLPR1(x).B.LPR_XACT_RUN_LENGTH)

/*! @brief Format value for bitfield DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH. */
#define BF_DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH) & BM_DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH)

/*! @brief Set the LPR_XACT_RUN_LENGTH field to a new value. */
#define BW_DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH(x, v) (HW_DDRC_PERFLPR1_WR(x, (HW_DDRC_PERFLPR1_RD(x) & ~BM_DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH) | BF_DDRC_PERFLPR1_LPR_XACT_RUN_LENGTH(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_PERFWR1 - Write CAM Register 1
 ******************************************************************************/

/*!
 * @brief HW_DDRC_PERFWR1 - Write CAM Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_perfwr1
{
    uint32_t U;
    struct _hw_ddrc_perfwr1_bitfields
    {
        uint32_t W_MAX_STARVE : 16;    /*!< [15:0]  */
        uint32_t RESERVED0 : 8;        /*!< [23:16]  */
        uint32_t W_XACT_RUN_LENGTH : 8; /*!< [31:24]  */
    } B;
} hw_ddrc_perfwr1_t;

/*!
 * @name Constants and macros for entire DDRC_PERFWR1 register
 */
/*@{*/
#define HW_DDRC_PERFWR1_ADDR(x)  ((uintptr_t)(x) + 0x26CU)

#define HW_DDRC_PERFWR1(x)       (*(__IO hw_ddrc_perfwr1_t *) HW_DDRC_PERFWR1_ADDR(x))
#define HW_DDRC_PERFWR1_RD(x)    (HW_DDRC_PERFWR1(x).U)
#define HW_DDRC_PERFWR1_WR(x, v) (HW_DDRC_PERFWR1(x).U = (v))
#define HW_DDRC_PERFWR1_SET(x, v) (HW_DDRC_PERFWR1_WR(x, HW_DDRC_PERFWR1_RD(x) |  (v)))
#define HW_DDRC_PERFWR1_CLR(x, v) (HW_DDRC_PERFWR1_WR(x, HW_DDRC_PERFWR1_RD(x) & ~(v)))
#define HW_DDRC_PERFWR1_TOG(x, v) (HW_DDRC_PERFWR1_WR(x, HW_DDRC_PERFWR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_PERFWR1 bitfields
 */

/*!
 * @name Register DDRC_PERFWR1, field W_MAX_STARVE[15:0] (RW)
 *
 * Number of clocks that the WR queue can be starved before it goes critical.
 * The minimum valid functional value for this register is 0x1. Programming it to
 * 0x0 will disable the starvation functionality; during normal operation, this
 * function should not be disabled as it will cause excessive latencies. Unit:
 * Clock cycles. FOR PERFORMANCE ONLY. Value After Reset: 0x7f Exists: Always
 */
/*@{*/
#define BP_DDRC_PERFWR1_W_MAX_STARVE (0U)  /*!< Bit position for DDRC_PERFWR1_W_MAX_STARVE. */
#define BM_DDRC_PERFWR1_W_MAX_STARVE (0x0000FFFFU) /*!< Bit mask for DDRC_PERFWR1_W_MAX_STARVE. */
#define BS_DDRC_PERFWR1_W_MAX_STARVE (16U) /*!< Bit field size in bits for DDRC_PERFWR1_W_MAX_STARVE. */

/*! @brief Read current value of the DDRC_PERFWR1_W_MAX_STARVE field. */
#define BR_DDRC_PERFWR1_W_MAX_STARVE(x) (HW_DDRC_PERFWR1(x).B.W_MAX_STARVE)

/*! @brief Format value for bitfield DDRC_PERFWR1_W_MAX_STARVE. */
#define BF_DDRC_PERFWR1_W_MAX_STARVE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_PERFWR1_W_MAX_STARVE) & BM_DDRC_PERFWR1_W_MAX_STARVE)

/*! @brief Set the W_MAX_STARVE field to a new value. */
#define BW_DDRC_PERFWR1_W_MAX_STARVE(x, v) (HW_DDRC_PERFWR1_WR(x, (HW_DDRC_PERFWR1_RD(x) & ~BM_DDRC_PERFWR1_W_MAX_STARVE) | BF_DDRC_PERFWR1_W_MAX_STARVE(v)))
/*@}*/

/*!
 * @name Register DDRC_PERFWR1, field W_XACT_RUN_LENGTH[31:24] (RW)
 *
 * Number of transactions that are serviced once the WR queue goes critical is
 * the smaller of: This number Number of transactions available Unit: Transaction.
 * FOR PERFORMANCE ONLY. Value After Reset: 0xf Exists: Always
 */
/*@{*/
#define BP_DDRC_PERFWR1_W_XACT_RUN_LENGTH (24U) /*!< Bit position for DDRC_PERFWR1_W_XACT_RUN_LENGTH. */
#define BM_DDRC_PERFWR1_W_XACT_RUN_LENGTH (0xFF000000U) /*!< Bit mask for DDRC_PERFWR1_W_XACT_RUN_LENGTH. */
#define BS_DDRC_PERFWR1_W_XACT_RUN_LENGTH (8U) /*!< Bit field size in bits for DDRC_PERFWR1_W_XACT_RUN_LENGTH. */

/*! @brief Read current value of the DDRC_PERFWR1_W_XACT_RUN_LENGTH field. */
#define BR_DDRC_PERFWR1_W_XACT_RUN_LENGTH(x) (HW_DDRC_PERFWR1(x).B.W_XACT_RUN_LENGTH)

/*! @brief Format value for bitfield DDRC_PERFWR1_W_XACT_RUN_LENGTH. */
#define BF_DDRC_PERFWR1_W_XACT_RUN_LENGTH(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_PERFWR1_W_XACT_RUN_LENGTH) & BM_DDRC_PERFWR1_W_XACT_RUN_LENGTH)

/*! @brief Set the W_XACT_RUN_LENGTH field to a new value. */
#define BW_DDRC_PERFWR1_W_XACT_RUN_LENGTH(x, v) (HW_DDRC_PERFWR1_WR(x, (HW_DDRC_PERFWR1_RD(x) & ~BM_DDRC_PERFWR1_W_XACT_RUN_LENGTH) | BF_DDRC_PERFWR1_W_XACT_RUN_LENGTH(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_PERFVPR1 - Variable Priority Read CAM Register 1
 ******************************************************************************/

/*!
 * @brief HW_DDRC_PERFVPR1 - Variable Priority Read CAM Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: DDRC_VPR_EN==1
 */
typedef union _hw_ddrc_perfvpr1
{
    uint32_t U;
    struct _hw_ddrc_perfvpr1_bitfields
    {
        uint32_t VPR_TIMEOUT_RANGE : 11; /*!< [10:0]  */
        uint32_t RESERVED0 : 21;       /*!< [31:11]  */
    } B;
} hw_ddrc_perfvpr1_t;

/*!
 * @name Constants and macros for entire DDRC_PERFVPR1 register
 */
/*@{*/
#define HW_DDRC_PERFVPR1_ADDR(x) ((uintptr_t)(x) + 0x274U)

#define HW_DDRC_PERFVPR1(x)      (*(__IO hw_ddrc_perfvpr1_t *) HW_DDRC_PERFVPR1_ADDR(x))
#define HW_DDRC_PERFVPR1_RD(x)   (HW_DDRC_PERFVPR1(x).U)
#define HW_DDRC_PERFVPR1_WR(x, v) (HW_DDRC_PERFVPR1(x).U = (v))
#define HW_DDRC_PERFVPR1_SET(x, v) (HW_DDRC_PERFVPR1_WR(x, HW_DDRC_PERFVPR1_RD(x) |  (v)))
#define HW_DDRC_PERFVPR1_CLR(x, v) (HW_DDRC_PERFVPR1_WR(x, HW_DDRC_PERFVPR1_RD(x) & ~(v)))
#define HW_DDRC_PERFVPR1_TOG(x, v) (HW_DDRC_PERFVPR1_WR(x, HW_DDRC_PERFVPR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_PERFVPR1 bitfields
 */

/*!
 * @name Register DDRC_PERFVPR1, field VPR_TIMEOUT_RANGE[10:0] (RW)
 *
 * Indicates the range of the timeout value that is used for grouping the
 * expired VPR commands in the CAM in DDRC. For example, if the register value is set
 * to 0xF, then the priorities of all the VPR commands whose timeout counters are
 * 15 or below will be considered as expired-VPR commands when the timeout value
 * of any of the VPR commands reach 0. The expired-VPR commands, when present,
 * are given higher priority than HPR commands. The VPR commands are expected to
 * consist of largely page hit traffic and by grouping them together the bus
 * utilization is expected to increase. This register applies to transactions inside
 * the DDRC only. The Max value for this register is 0x7FF and the Min value is
 * 0x0. When programmed to the Max value of 0x7FF, all the VPR commands that come in
 * to DDRC will time-out right-away and will be considered as expired-VPR. When
 * programmed to the Min value of 0x0, the timer of each command would have to
 * reach a value of 0 before it will be considered as expired-VPR. Unit: Clock
 * cycles. FOR PERFORMANCE ONLY. Value After Reset: 0x0 Exists: DDRC_VPR_EN == 1
 */
/*@{*/
#define BP_DDRC_PERFVPR1_VPR_TIMEOUT_RANGE (0U) /*!< Bit position for DDRC_PERFVPR1_VPR_TIMEOUT_RANGE. */
#define BM_DDRC_PERFVPR1_VPR_TIMEOUT_RANGE (0x000007FFU) /*!< Bit mask for DDRC_PERFVPR1_VPR_TIMEOUT_RANGE. */
#define BS_DDRC_PERFVPR1_VPR_TIMEOUT_RANGE (11U) /*!< Bit field size in bits for DDRC_PERFVPR1_VPR_TIMEOUT_RANGE. */

/*! @brief Read current value of the DDRC_PERFVPR1_VPR_TIMEOUT_RANGE field. */
#define BR_DDRC_PERFVPR1_VPR_TIMEOUT_RANGE(x) (HW_DDRC_PERFVPR1(x).B.VPR_TIMEOUT_RANGE)

/*! @brief Format value for bitfield DDRC_PERFVPR1_VPR_TIMEOUT_RANGE. */
#define BF_DDRC_PERFVPR1_VPR_TIMEOUT_RANGE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_PERFVPR1_VPR_TIMEOUT_RANGE) & BM_DDRC_PERFVPR1_VPR_TIMEOUT_RANGE)

/*! @brief Set the VPR_TIMEOUT_RANGE field to a new value. */
#define BW_DDRC_PERFVPR1_VPR_TIMEOUT_RANGE(x, v) (HW_DDRC_PERFVPR1_WR(x, (HW_DDRC_PERFVPR1_RD(x) & ~BM_DDRC_PERFVPR1_VPR_TIMEOUT_RANGE) | BF_DDRC_PERFVPR1_VPR_TIMEOUT_RANGE(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_PERFVPW1 - Variable Priority Write CAM Register 1
 ******************************************************************************/

/*!
 * @brief HW_DDRC_PERFVPW1 - Variable Priority Write CAM Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: DDRC_VPW_EN==1
 */
typedef union _hw_ddrc_perfvpw1
{
    uint32_t U;
    struct _hw_ddrc_perfvpw1_bitfields
    {
        uint32_t VPW_TIMEOUT_RANGE : 11; /*!< [10:0]  */
        uint32_t RESERVED0 : 21;       /*!< [31:11]  */
    } B;
} hw_ddrc_perfvpw1_t;

/*!
 * @name Constants and macros for entire DDRC_PERFVPW1 register
 */
/*@{*/
#define HW_DDRC_PERFVPW1_ADDR(x) ((uintptr_t)(x) + 0x278U)

#define HW_DDRC_PERFVPW1(x)      (*(__IO hw_ddrc_perfvpw1_t *) HW_DDRC_PERFVPW1_ADDR(x))
#define HW_DDRC_PERFVPW1_RD(x)   (HW_DDRC_PERFVPW1(x).U)
#define HW_DDRC_PERFVPW1_WR(x, v) (HW_DDRC_PERFVPW1(x).U = (v))
#define HW_DDRC_PERFVPW1_SET(x, v) (HW_DDRC_PERFVPW1_WR(x, HW_DDRC_PERFVPW1_RD(x) |  (v)))
#define HW_DDRC_PERFVPW1_CLR(x, v) (HW_DDRC_PERFVPW1_WR(x, HW_DDRC_PERFVPW1_RD(x) & ~(v)))
#define HW_DDRC_PERFVPW1_TOG(x, v) (HW_DDRC_PERFVPW1_WR(x, HW_DDRC_PERFVPW1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_PERFVPW1 bitfields
 */

/*!
 * @name Register DDRC_PERFVPW1, field VPW_TIMEOUT_RANGE[10:0] (RW)
 *
 * Indicates the range of the timeout value that is used for grouping the
 * expired VPW commands in the CAM in DDRC. For example, if the register value is set
 * to 0xF, then the priorities of all the VPW commands whose timeout counters are
 * 15 or below will be considered as expired-VPW commands when the timeout value
 * of any of the VPW commands reach 0. The expired-VPW commands, when present,
 * are given higher priority than normalWrite commands. The VPW commands are
 * expected to consist of largely page hit traffic and by grouping them together the
 * bus utilization is expected to increase. This register applies to transactions
 * inside the DDRC only. The Max value for this register is 0x7FF and the Min
 * value is 0x0. When programmed to the Max value of 0x7FF, all the VPW commands that
 * come in to DDRC will time-out right-away and will be considered as
 * expired-VPW. When programmed to the Min value of 0x0, the timer of each command would
 * have to reach a value of 0 before it will be considered as expired-VPW. Unit:
 * Clock cycles. FOR PERFORMANCE ONLY. Value After Reset: 0x0 Exists: DDRC_VPW_EN
 * == 1
 */
/*@{*/
#define BP_DDRC_PERFVPW1_VPW_TIMEOUT_RANGE (0U) /*!< Bit position for DDRC_PERFVPW1_VPW_TIMEOUT_RANGE. */
#define BM_DDRC_PERFVPW1_VPW_TIMEOUT_RANGE (0x000007FFU) /*!< Bit mask for DDRC_PERFVPW1_VPW_TIMEOUT_RANGE. */
#define BS_DDRC_PERFVPW1_VPW_TIMEOUT_RANGE (11U) /*!< Bit field size in bits for DDRC_PERFVPW1_VPW_TIMEOUT_RANGE. */

/*! @brief Read current value of the DDRC_PERFVPW1_VPW_TIMEOUT_RANGE field. */
#define BR_DDRC_PERFVPW1_VPW_TIMEOUT_RANGE(x) (HW_DDRC_PERFVPW1(x).B.VPW_TIMEOUT_RANGE)

/*! @brief Format value for bitfield DDRC_PERFVPW1_VPW_TIMEOUT_RANGE. */
#define BF_DDRC_PERFVPW1_VPW_TIMEOUT_RANGE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_PERFVPW1_VPW_TIMEOUT_RANGE) & BM_DDRC_PERFVPW1_VPW_TIMEOUT_RANGE)

/*! @brief Set the VPW_TIMEOUT_RANGE field to a new value. */
#define BW_DDRC_PERFVPW1_VPW_TIMEOUT_RANGE(x, v) (HW_DDRC_PERFVPW1_WR(x, (HW_DDRC_PERFVPW1_RD(x) & ~BM_DDRC_PERFVPW1_VPW_TIMEOUT_RANGE) | BF_DDRC_PERFVPW1_VPW_TIMEOUT_RANGE(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DBG0 - Debug Register 0
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DBG0 - Debug Register 0 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_dbg0
{
    uint32_t U;
    struct _hw_ddrc_dbg0_bitfields
    {
        uint32_t DIS_WC : 1;           /*!< [0]  */
        uint32_t RESERVED0 : 3;        /*!< [3:1]  */
        uint32_t DIS_COLLISION_PAGE_OPT : 1; /*!< [4]  */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_ddrc_dbg0_t;

/*!
 * @name Constants and macros for entire DDRC_DBG0 register
 */
/*@{*/
#define HW_DDRC_DBG0_ADDR(x)     ((uintptr_t)(x) + 0x300U)

#define HW_DDRC_DBG0(x)          (*(__IO hw_ddrc_dbg0_t *) HW_DDRC_DBG0_ADDR(x))
#define HW_DDRC_DBG0_RD(x)       (HW_DDRC_DBG0(x).U)
#define HW_DDRC_DBG0_WR(x, v)    (HW_DDRC_DBG0(x).U = (v))
#define HW_DDRC_DBG0_SET(x, v)   (HW_DDRC_DBG0_WR(x, HW_DDRC_DBG0_RD(x) |  (v)))
#define HW_DDRC_DBG0_CLR(x, v)   (HW_DDRC_DBG0_WR(x, HW_DDRC_DBG0_RD(x) & ~(v)))
#define HW_DDRC_DBG0_TOG(x, v)   (HW_DDRC_DBG0_WR(x, HW_DDRC_DBG0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DBG0 bitfields
 */

/*!
 * @name Register DDRC_DBG0, field DIS_WC[0] (RW)
 *
 * When the value is 1, disable write combine. FOR DEBUG ONLY Value After Reset:
 * 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_DBG0_DIS_WC  (0U)          /*!< Bit position for DDRC_DBG0_DIS_WC. */
#define BM_DDRC_DBG0_DIS_WC  (0x00000001U) /*!< Bit mask for DDRC_DBG0_DIS_WC. */
#define BS_DDRC_DBG0_DIS_WC  (1U)          /*!< Bit field size in bits for DDRC_DBG0_DIS_WC. */

/*! @brief Read current value of the DDRC_DBG0_DIS_WC field. */
#define BR_DDRC_DBG0_DIS_WC(x) (HW_DDRC_DBG0(x).B.DIS_WC)

/*! @brief Format value for bitfield DDRC_DBG0_DIS_WC. */
#define BF_DDRC_DBG0_DIS_WC(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DBG0_DIS_WC) & BM_DDRC_DBG0_DIS_WC)

/*! @brief Set the DIS_WC field to a new value. */
#define BW_DDRC_DBG0_DIS_WC(x, v) (HW_DDRC_DBG0_WR(x, (HW_DDRC_DBG0_RD(x) & ~BM_DDRC_DBG0_DIS_WC) | BF_DDRC_DBG0_DIS_WC(v)))
/*@}*/

/*!
 * @name Register DDRC_DBG0, field DIS_COLLISION_PAGE_OPT[4] (RW)
 *
 * When this is set to '0', auto-precharge is disabled for the flushed command
 * in a collision case. Collision cases are write followed by read to same
 * address, read followed by write to same address, or write followed by write to same
 * address with DBG0.dis_wc bit = 1 (where same address comparisons exclude the
 * two address bits representing critical word). FOR DEBUG ONLY. Value After Reset:
 * 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_DBG0_DIS_COLLISION_PAGE_OPT (4U) /*!< Bit position for DDRC_DBG0_DIS_COLLISION_PAGE_OPT. */
#define BM_DDRC_DBG0_DIS_COLLISION_PAGE_OPT (0x00000010U) /*!< Bit mask for DDRC_DBG0_DIS_COLLISION_PAGE_OPT. */
#define BS_DDRC_DBG0_DIS_COLLISION_PAGE_OPT (1U) /*!< Bit field size in bits for DDRC_DBG0_DIS_COLLISION_PAGE_OPT. */

/*! @brief Read current value of the DDRC_DBG0_DIS_COLLISION_PAGE_OPT field. */
#define BR_DDRC_DBG0_DIS_COLLISION_PAGE_OPT(x) (HW_DDRC_DBG0(x).B.DIS_COLLISION_PAGE_OPT)

/*! @brief Format value for bitfield DDRC_DBG0_DIS_COLLISION_PAGE_OPT. */
#define BF_DDRC_DBG0_DIS_COLLISION_PAGE_OPT(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DBG0_DIS_COLLISION_PAGE_OPT) & BM_DDRC_DBG0_DIS_COLLISION_PAGE_OPT)

/*! @brief Set the DIS_COLLISION_PAGE_OPT field to a new value. */
#define BW_DDRC_DBG0_DIS_COLLISION_PAGE_OPT(x, v) (HW_DDRC_DBG0_WR(x, (HW_DDRC_DBG0_RD(x) & ~BM_DDRC_DBG0_DIS_COLLISION_PAGE_OPT) | BF_DDRC_DBG0_DIS_COLLISION_PAGE_OPT(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DBG1 - Debug Register 1
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DBG1 - Debug Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_dbg1
{
    uint32_t U;
    struct _hw_ddrc_dbg1_bitfields
    {
        uint32_t DIS_DQ : 1;           /*!< [0]  */
        uint32_t DIS_HIF : 1;          /*!< [1]  */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_ddrc_dbg1_t;

/*!
 * @name Constants and macros for entire DDRC_DBG1 register
 */
/*@{*/
#define HW_DDRC_DBG1_ADDR(x)     ((uintptr_t)(x) + 0x304U)

#define HW_DDRC_DBG1(x)          (*(__IO hw_ddrc_dbg1_t *) HW_DDRC_DBG1_ADDR(x))
#define HW_DDRC_DBG1_RD(x)       (HW_DDRC_DBG1(x).U)
#define HW_DDRC_DBG1_WR(x, v)    (HW_DDRC_DBG1(x).U = (v))
#define HW_DDRC_DBG1_SET(x, v)   (HW_DDRC_DBG1_WR(x, HW_DDRC_DBG1_RD(x) |  (v)))
#define HW_DDRC_DBG1_CLR(x, v)   (HW_DDRC_DBG1_WR(x, HW_DDRC_DBG1_RD(x) & ~(v)))
#define HW_DDRC_DBG1_TOG(x, v)   (HW_DDRC_DBG1_WR(x, HW_DDRC_DBG1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DBG1 bitfields
 */

/*!
 * @name Register DDRC_DBG1, field DIS_DQ[0] (RW)
 *
 * When 1, DDRC will not de-queue any transactions from the CAM. Bypass is also
 * disabled. All transactions are queued in the CAM. No reads or writes are
 * issued to SDRAM as long as this is asserted. This bit may be used to prevent reads
 * or writes being issued by the DDRC, which makes it safe to modify certain
 * register fields associated with reads and writes (see User Guide for details).
 * After setting this bit, it is strongly recommended to poll
 * DBGCAM.wr_data_pipeline_empty and DBGCAM.rd_data_pipeline_empty, beforemaking changes to any
 * registers which affect reads and writes. This will ensure that the relevant logic in
 * the DDRC is idle. This bit is intended to be switched on-the-fly. Value After
 * Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_DBG1_DIS_DQ  (0U)          /*!< Bit position for DDRC_DBG1_DIS_DQ. */
#define BM_DDRC_DBG1_DIS_DQ  (0x00000001U) /*!< Bit mask for DDRC_DBG1_DIS_DQ. */
#define BS_DDRC_DBG1_DIS_DQ  (1U)          /*!< Bit field size in bits for DDRC_DBG1_DIS_DQ. */

/*! @brief Read current value of the DDRC_DBG1_DIS_DQ field. */
#define BR_DDRC_DBG1_DIS_DQ(x) (HW_DDRC_DBG1(x).B.DIS_DQ)

/*! @brief Format value for bitfield DDRC_DBG1_DIS_DQ. */
#define BF_DDRC_DBG1_DIS_DQ(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DBG1_DIS_DQ) & BM_DDRC_DBG1_DIS_DQ)

/*! @brief Set the DIS_DQ field to a new value. */
#define BW_DDRC_DBG1_DIS_DQ(x, v) (HW_DDRC_DBG1_WR(x, (HW_DDRC_DBG1_RD(x) & ~BM_DDRC_DBG1_DIS_DQ) | BF_DDRC_DBG1_DIS_DQ(v)))
/*@}*/

/*!
 * @name Register DDRC_DBG1, field DIS_HIF[1] (RW)
 *
 * When 1, the DDRC asserts the HIF command signal hif_cmd_stall. The DDRC will
 * ignore the hif_cmd_valid and all other associated request signals. This bit is
 * intended to be switched on-the-fly. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_DBG1_DIS_HIF (1U)          /*!< Bit position for DDRC_DBG1_DIS_HIF. */
#define BM_DDRC_DBG1_DIS_HIF (0x00000002U) /*!< Bit mask for DDRC_DBG1_DIS_HIF. */
#define BS_DDRC_DBG1_DIS_HIF (1U)          /*!< Bit field size in bits for DDRC_DBG1_DIS_HIF. */

/*! @brief Read current value of the DDRC_DBG1_DIS_HIF field. */
#define BR_DDRC_DBG1_DIS_HIF(x) (HW_DDRC_DBG1(x).B.DIS_HIF)

/*! @brief Format value for bitfield DDRC_DBG1_DIS_HIF. */
#define BF_DDRC_DBG1_DIS_HIF(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DBG1_DIS_HIF) & BM_DDRC_DBG1_DIS_HIF)

/*! @brief Set the DIS_HIF field to a new value. */
#define BW_DDRC_DBG1_DIS_HIF(x, v) (HW_DDRC_DBG1_WR(x, (HW_DDRC_DBG1_RD(x) & ~BM_DDRC_DBG1_DIS_HIF) | BF_DDRC_DBG1_DIS_HIF(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DBGCAM - CAM Debug Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DBGCAM - CAM Debug Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_dbgcam
{
    uint32_t U;
    struct _hw_ddrc_dbgcam_bitfields
    {
        uint32_t DBG_HPR_Q_DEPTH : 7;  /*!< [6:0] High Priority Read Queue
                                        * Depth */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t DBG_LPR_Q_DEPTH : 7;  /*!< [14:8] Low Priority Read Queue
                                        * Depth */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t DBG_W_Q_DEPTH : 7;    /*!< [22:16] Write Queue Depth */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t DBG_STALL : 1;        /*!< [24] Stall */
        uint32_t DBG_RD_Q_EMPTY : 1;   /*!< [25]  */
        uint32_t DBG_WR_Q_EMPTY : 1;   /*!< [26]  */
        uint32_t RESERVED3 : 1;        /*!< [27]  */
        uint32_t RD_DATA_PIPELINE_EMPTY : 1; /*!< [28]  */
        uint32_t WR_DATA_PIPELINE_EMPTY : 1; /*!< [29]  */
        uint32_t DBG_STALL_WR : 1;     /*!< [30]  */
        uint32_t DBG_STALL_RD : 1;     /*!< [31]  */
    } B;
} hw_ddrc_dbgcam_t;

/*!
 * @name Constants and macros for entire DDRC_DBGCAM register
 */
/*@{*/
#define HW_DDRC_DBGCAM_ADDR(x)   ((uintptr_t)(x) + 0x308U)

#define HW_DDRC_DBGCAM(x)        (*(__I hw_ddrc_dbgcam_t *) HW_DDRC_DBGCAM_ADDR(x))
#define HW_DDRC_DBGCAM_RD(x)     (HW_DDRC_DBGCAM(x).U)
/*@}*/

/*
 * Constants & macros for individual DDRC_DBGCAM bitfields
 */

/*!
 * @name Register DDRC_DBGCAM, field DBG_HPR_Q_DEPTH[6:0] (RO)
 *
 * FOR DEBUG ONLY Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_DBGCAM_DBG_HPR_Q_DEPTH (0U) /*!< Bit position for DDRC_DBGCAM_DBG_HPR_Q_DEPTH. */
#define BM_DDRC_DBGCAM_DBG_HPR_Q_DEPTH (0x0000007FU) /*!< Bit mask for DDRC_DBGCAM_DBG_HPR_Q_DEPTH. */
#define BS_DDRC_DBGCAM_DBG_HPR_Q_DEPTH (7U) /*!< Bit field size in bits for DDRC_DBGCAM_DBG_HPR_Q_DEPTH. */

/*! @brief Read current value of the DDRC_DBGCAM_DBG_HPR_Q_DEPTH field. */
#define BR_DDRC_DBGCAM_DBG_HPR_Q_DEPTH(x) (HW_DDRC_DBGCAM(x).B.DBG_HPR_Q_DEPTH)
/*@}*/

/*!
 * @name Register DDRC_DBGCAM, field DBG_LPR_Q_DEPTH[14:8] (RO)
 *
 * FOR DEBUG ONLY Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_DBGCAM_DBG_LPR_Q_DEPTH (8U) /*!< Bit position for DDRC_DBGCAM_DBG_LPR_Q_DEPTH. */
#define BM_DDRC_DBGCAM_DBG_LPR_Q_DEPTH (0x00007F00U) /*!< Bit mask for DDRC_DBGCAM_DBG_LPR_Q_DEPTH. */
#define BS_DDRC_DBGCAM_DBG_LPR_Q_DEPTH (7U) /*!< Bit field size in bits for DDRC_DBGCAM_DBG_LPR_Q_DEPTH. */

/*! @brief Read current value of the DDRC_DBGCAM_DBG_LPR_Q_DEPTH field. */
#define BR_DDRC_DBGCAM_DBG_LPR_Q_DEPTH(x) (HW_DDRC_DBGCAM(x).B.DBG_LPR_Q_DEPTH)
/*@}*/

/*!
 * @name Register DDRC_DBGCAM, field DBG_W_Q_DEPTH[22:16] (RO)
 *
 * FOR DEBUG ONLY Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_DBGCAM_DBG_W_Q_DEPTH (16U) /*!< Bit position for DDRC_DBGCAM_DBG_W_Q_DEPTH. */
#define BM_DDRC_DBGCAM_DBG_W_Q_DEPTH (0x007F0000U) /*!< Bit mask for DDRC_DBGCAM_DBG_W_Q_DEPTH. */
#define BS_DDRC_DBGCAM_DBG_W_Q_DEPTH (7U)  /*!< Bit field size in bits for DDRC_DBGCAM_DBG_W_Q_DEPTH. */

/*! @brief Read current value of the DDRC_DBGCAM_DBG_W_Q_DEPTH field. */
#define BR_DDRC_DBGCAM_DBG_W_Q_DEPTH(x) (HW_DDRC_DBGCAM(x).B.DBG_W_Q_DEPTH)
/*@}*/

/*!
 * @name Register DDRC_DBGCAM, field DBG_STALL[24] (RO)
 *
 * FOR DEBUG ONLY Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_DBGCAM_DBG_STALL (24U)     /*!< Bit position for DDRC_DBGCAM_DBG_STALL. */
#define BM_DDRC_DBGCAM_DBG_STALL (0x01000000U) /*!< Bit mask for DDRC_DBGCAM_DBG_STALL. */
#define BS_DDRC_DBGCAM_DBG_STALL (1U)      /*!< Bit field size in bits for DDRC_DBGCAM_DBG_STALL. */

/*! @brief Read current value of the DDRC_DBGCAM_DBG_STALL field. */
#define BR_DDRC_DBGCAM_DBG_STALL(x) (HW_DDRC_DBGCAM(x).B.DBG_STALL)
/*@}*/

/*!
 * @name Register DDRC_DBGCAM, field DBG_RD_Q_EMPTY[25] (RO)
 *
 * When 1, all the Read command queues and Read data buffers inside DDRC are
 * empty. This register is to be used for debug purpose. An example use-case
 * scenario:When Controller enters Self-Refresh using the Low-Power entry sequence,
 * Controller is expected to have executed all the commands in its queues and the
 * write and read data drained. Hence this register should be 1 at that time. FOR
 * DEBUG ONLY Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_DBGCAM_DBG_RD_Q_EMPTY (25U) /*!< Bit position for DDRC_DBGCAM_DBG_RD_Q_EMPTY. */
#define BM_DDRC_DBGCAM_DBG_RD_Q_EMPTY (0x02000000U) /*!< Bit mask for DDRC_DBGCAM_DBG_RD_Q_EMPTY. */
#define BS_DDRC_DBGCAM_DBG_RD_Q_EMPTY (1U) /*!< Bit field size in bits for DDRC_DBGCAM_DBG_RD_Q_EMPTY. */

/*! @brief Read current value of the DDRC_DBGCAM_DBG_RD_Q_EMPTY field. */
#define BR_DDRC_DBGCAM_DBG_RD_Q_EMPTY(x) (HW_DDRC_DBGCAM(x).B.DBG_RD_Q_EMPTY)
/*@}*/

/*!
 * @name Register DDRC_DBGCAM, field DBG_WR_Q_EMPTY[26] (RO)
 *
 * When 1, all theWrite command queues and Write data buffers inside DDRC are
 * empty. This register is to be used for debug purpose. An example use-case
 * scenario:When Controller enters Self- Refresh using the Low-Power entry sequence,
 * Controller is expected to have executed all the commands in its queues and the
 * write and read data drained. Hence this register should be 1 at that time. FOR
 * DEBUG ONLY Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_DBGCAM_DBG_WR_Q_EMPTY (26U) /*!< Bit position for DDRC_DBGCAM_DBG_WR_Q_EMPTY. */
#define BM_DDRC_DBGCAM_DBG_WR_Q_EMPTY (0x04000000U) /*!< Bit mask for DDRC_DBGCAM_DBG_WR_Q_EMPTY. */
#define BS_DDRC_DBGCAM_DBG_WR_Q_EMPTY (1U) /*!< Bit field size in bits for DDRC_DBGCAM_DBG_WR_Q_EMPTY. */

/*! @brief Read current value of the DDRC_DBGCAM_DBG_WR_Q_EMPTY field. */
#define BR_DDRC_DBGCAM_DBG_WR_Q_EMPTY(x) (HW_DDRC_DBGCAM(x).B.DBG_WR_Q_EMPTY)
/*@}*/

/*!
 * @name Register DDRC_DBGCAM, field RD_DATA_PIPELINE_EMPTY[28] (RO)
 *
 * This bit indicates that the read data pipeline on the DFI interface is empty.
 * This register is intended to be polled after setting DBG1.dis_dq, to ensure
 * that all remaining commands / data have completed. Value After Reset: 0x0
 * Exists: Always
 */
/*@{*/
#define BP_DDRC_DBGCAM_RD_DATA_PIPELINE_EMPTY (28U) /*!< Bit position for DDRC_DBGCAM_RD_DATA_PIPELINE_EMPTY. */
#define BM_DDRC_DBGCAM_RD_DATA_PIPELINE_EMPTY (0x10000000U) /*!< Bit mask for DDRC_DBGCAM_RD_DATA_PIPELINE_EMPTY. */
#define BS_DDRC_DBGCAM_RD_DATA_PIPELINE_EMPTY (1U) /*!< Bit field size in bits for DDRC_DBGCAM_RD_DATA_PIPELINE_EMPTY. */

/*! @brief Read current value of the DDRC_DBGCAM_RD_DATA_PIPELINE_EMPTY field. */
#define BR_DDRC_DBGCAM_RD_DATA_PIPELINE_EMPTY(x) (HW_DDRC_DBGCAM(x).B.RD_DATA_PIPELINE_EMPTY)
/*@}*/

/*!
 * @name Register DDRC_DBGCAM, field WR_DATA_PIPELINE_EMPTY[29] (RO)
 *
 * This bit indicates that the write data pipeline on the DFI interface is
 * empty. This register is intended to be polled after setting DBG1.dis_dq, to ensure
 * that all remaining commands / data have completed. Value After Reset: 0x0
 * Exists: Always
 */
/*@{*/
#define BP_DDRC_DBGCAM_WR_DATA_PIPELINE_EMPTY (29U) /*!< Bit position for DDRC_DBGCAM_WR_DATA_PIPELINE_EMPTY. */
#define BM_DDRC_DBGCAM_WR_DATA_PIPELINE_EMPTY (0x20000000U) /*!< Bit mask for DDRC_DBGCAM_WR_DATA_PIPELINE_EMPTY. */
#define BS_DDRC_DBGCAM_WR_DATA_PIPELINE_EMPTY (1U) /*!< Bit field size in bits for DDRC_DBGCAM_WR_DATA_PIPELINE_EMPTY. */

/*! @brief Read current value of the DDRC_DBGCAM_WR_DATA_PIPELINE_EMPTY field. */
#define BR_DDRC_DBGCAM_WR_DATA_PIPELINE_EMPTY(x) (HW_DDRC_DBGCAM(x).B.WR_DATA_PIPELINE_EMPTY)
/*@}*/

/*!
 * @name Register DDRC_DBGCAM, field DBG_STALL_WR[30] (RO)
 *
 * Stall for Write channel FOR DEBUG ONLY Value After Reset: 0x0 Exists:
 * DDRC_DUAL_PA_1 == 1
 */
/*@{*/
#define BP_DDRC_DBGCAM_DBG_STALL_WR (30U)  /*!< Bit position for DDRC_DBGCAM_DBG_STALL_WR. */
#define BM_DDRC_DBGCAM_DBG_STALL_WR (0x40000000U) /*!< Bit mask for DDRC_DBGCAM_DBG_STALL_WR. */
#define BS_DDRC_DBGCAM_DBG_STALL_WR (1U)   /*!< Bit field size in bits for DDRC_DBGCAM_DBG_STALL_WR. */

/*! @brief Read current value of the DDRC_DBGCAM_DBG_STALL_WR field. */
#define BR_DDRC_DBGCAM_DBG_STALL_WR(x) (HW_DDRC_DBGCAM(x).B.DBG_STALL_WR)
/*@}*/

/*!
 * @name Register DDRC_DBGCAM, field DBG_STALL_RD[31] (RO)
 *
 * Stall for Read channel FOR DEBUG ONLY Value After Reset: 0x0 Exists:
 * DDRC_DUAL_PA_1 == 1
 */
/*@{*/
#define BP_DDRC_DBGCAM_DBG_STALL_RD (31U)  /*!< Bit position for DDRC_DBGCAM_DBG_STALL_RD. */
#define BM_DDRC_DBGCAM_DBG_STALL_RD (0x80000000U) /*!< Bit mask for DDRC_DBGCAM_DBG_STALL_RD. */
#define BS_DDRC_DBGCAM_DBG_STALL_RD (1U)   /*!< Bit field size in bits for DDRC_DBGCAM_DBG_STALL_RD. */

/*! @brief Read current value of the DDRC_DBGCAM_DBG_STALL_RD field. */
#define BR_DDRC_DBGCAM_DBG_STALL_RD(x) (HW_DDRC_DBGCAM(x).B.DBG_STALL_RD)
/*@}*/

/*******************************************************************************
 * HW_DDRC_DBGCMD - Command Debug Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DBGCMD - Command Debug Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_dbgcmd
{
    uint32_t U;
    struct _hw_ddrc_dbgcmd_bitfields
    {
        uint32_t RANK0_REFRESH : 1;    /*!< [0]  */
        uint32_t RANK1_REFRESH : 1;    /*!< [1]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t ZQ_CALIB_SHORT : 1;   /*!< [4]  */
        uint32_t CTRLUPD : 1;          /*!< [5]  */
        uint32_t RESERVED1 : 26;       /*!< [31:6]  */
    } B;
} hw_ddrc_dbgcmd_t;

/*!
 * @name Constants and macros for entire DDRC_DBGCMD register
 */
/*@{*/
#define HW_DDRC_DBGCMD_ADDR(x)   ((uintptr_t)(x) + 0x30CU)

#define HW_DDRC_DBGCMD(x)        (*(__IO hw_ddrc_dbgcmd_t *) HW_DDRC_DBGCMD_ADDR(x))
#define HW_DDRC_DBGCMD_RD(x)     (HW_DDRC_DBGCMD(x).U)
#define HW_DDRC_DBGCMD_WR(x, v)  (HW_DDRC_DBGCMD(x).U = (v))
#define HW_DDRC_DBGCMD_SET(x, v) (HW_DDRC_DBGCMD_WR(x, HW_DDRC_DBGCMD_RD(x) |  (v)))
#define HW_DDRC_DBGCMD_CLR(x, v) (HW_DDRC_DBGCMD_WR(x, HW_DDRC_DBGCMD_RD(x) & ~(v)))
#define HW_DDRC_DBGCMD_TOG(x, v) (HW_DDRC_DBGCMD_WR(x, HW_DDRC_DBGCMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_DBGCMD bitfields
 */

/*!
 * @name Register DDRC_DBGCMD, field RANK0_REFRESH[0] (RW)
 *
 * Setting this register bit to 1 indicates to the DDRC to issue a refresh to
 * rank 0.Writing to this bit causes DBGSTAT.rank0_refresh_busy to be set. When
 * DBGSTAT.rank0_refresh_busy is cleared, the command has been stored in the DDRC.
 * This operation can be performed only when RFSHCTL3.dis_auto_refresh = 1. It is
 * recommended NOT to set this register bit if in Init or Deep power-down
 * operating modes or Maximum Power Saving Mode. Value After Reset: 0x0 Exists: Always
 * Testable: Read only
 */
/*@{*/
#define BP_DDRC_DBGCMD_RANK0_REFRESH (0U)  /*!< Bit position for DDRC_DBGCMD_RANK0_REFRESH. */
#define BM_DDRC_DBGCMD_RANK0_REFRESH (0x00000001U) /*!< Bit mask for DDRC_DBGCMD_RANK0_REFRESH. */
#define BS_DDRC_DBGCMD_RANK0_REFRESH (1U)  /*!< Bit field size in bits for DDRC_DBGCMD_RANK0_REFRESH. */

/*! @brief Read current value of the DDRC_DBGCMD_RANK0_REFRESH field. */
#define BR_DDRC_DBGCMD_RANK0_REFRESH(x) (HW_DDRC_DBGCMD(x).B.RANK0_REFRESH)

/*! @brief Format value for bitfield DDRC_DBGCMD_RANK0_REFRESH. */
#define BF_DDRC_DBGCMD_RANK0_REFRESH(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DBGCMD_RANK0_REFRESH) & BM_DDRC_DBGCMD_RANK0_REFRESH)

/*! @brief Set the RANK0_REFRESH field to a new value. */
#define BW_DDRC_DBGCMD_RANK0_REFRESH(x, v) (HW_DDRC_DBGCMD_WR(x, (HW_DDRC_DBGCMD_RD(x) & ~BM_DDRC_DBGCMD_RANK0_REFRESH) | BF_DDRC_DBGCMD_RANK0_REFRESH(v)))
/*@}*/

/*!
 * @name Register DDRC_DBGCMD, field RANK1_REFRESH[1] (RW)
 *
 * Setting this register bit to 1 indicates to the DDRC to issue a refresh to
 * rank 1.Writing to this bit causes DBGSTAT.rank1_refresh_busy to be set. When
 * DBGSTAT.rank1_refresh_busy is cleared, the command has been stored in the DDRC.
 * This operation can be performed only when RFSHCTL3.dis_auto_refresh = 1. It is
 * recommended NOT to set this register bit if in Init or Deep power-down
 * operating modes or Maximum Power Saving Mode. Value After Reset: 0x0
 * Exists:MEMC_NUM_RANKS > 1 Testable: Read only
 */
/*@{*/
#define BP_DDRC_DBGCMD_RANK1_REFRESH (1U)  /*!< Bit position for DDRC_DBGCMD_RANK1_REFRESH. */
#define BM_DDRC_DBGCMD_RANK1_REFRESH (0x00000002U) /*!< Bit mask for DDRC_DBGCMD_RANK1_REFRESH. */
#define BS_DDRC_DBGCMD_RANK1_REFRESH (1U)  /*!< Bit field size in bits for DDRC_DBGCMD_RANK1_REFRESH. */

/*! @brief Read current value of the DDRC_DBGCMD_RANK1_REFRESH field. */
#define BR_DDRC_DBGCMD_RANK1_REFRESH(x) (HW_DDRC_DBGCMD(x).B.RANK1_REFRESH)

/*! @brief Format value for bitfield DDRC_DBGCMD_RANK1_REFRESH. */
#define BF_DDRC_DBGCMD_RANK1_REFRESH(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DBGCMD_RANK1_REFRESH) & BM_DDRC_DBGCMD_RANK1_REFRESH)

/*! @brief Set the RANK1_REFRESH field to a new value. */
#define BW_DDRC_DBGCMD_RANK1_REFRESH(x, v) (HW_DDRC_DBGCMD_WR(x, (HW_DDRC_DBGCMD_RD(x) & ~BM_DDRC_DBGCMD_RANK1_REFRESH) | BF_DDRC_DBGCMD_RANK1_REFRESH(v)))
/*@}*/

/*!
 * @name Register DDRC_DBGCMD, field ZQ_CALIB_SHORT[4] (RW)
 *
 * Setting this register bit to 1 indicates to the DDRC to issue a ZQCS (ZQ
 * calibration short) command to the SDRAM. When this request is stored in the DDRC,
 * the bit is automatically cleared. This operation can be performed only when
 * ZQCTL0.dis_auto_zq = 1. It is recommended NOT to set this register bit if in
 * Init operating mode. This register bit is ignored when in Self-Refresh and Deep
 * power-down operating modes and Maximum Power Saving Mode. Value After Reset:
 * 0x0 Exists: MEMC_DDR3_OR_4_OR_LPDDR2 == 1 Testable: Read only
 */
/*@{*/
#define BP_DDRC_DBGCMD_ZQ_CALIB_SHORT (4U) /*!< Bit position for DDRC_DBGCMD_ZQ_CALIB_SHORT. */
#define BM_DDRC_DBGCMD_ZQ_CALIB_SHORT (0x00000010U) /*!< Bit mask for DDRC_DBGCMD_ZQ_CALIB_SHORT. */
#define BS_DDRC_DBGCMD_ZQ_CALIB_SHORT (1U) /*!< Bit field size in bits for DDRC_DBGCMD_ZQ_CALIB_SHORT. */

/*! @brief Read current value of the DDRC_DBGCMD_ZQ_CALIB_SHORT field. */
#define BR_DDRC_DBGCMD_ZQ_CALIB_SHORT(x) (HW_DDRC_DBGCMD(x).B.ZQ_CALIB_SHORT)

/*! @brief Format value for bitfield DDRC_DBGCMD_ZQ_CALIB_SHORT. */
#define BF_DDRC_DBGCMD_ZQ_CALIB_SHORT(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DBGCMD_ZQ_CALIB_SHORT) & BM_DDRC_DBGCMD_ZQ_CALIB_SHORT)

/*! @brief Set the ZQ_CALIB_SHORT field to a new value. */
#define BW_DDRC_DBGCMD_ZQ_CALIB_SHORT(x, v) (HW_DDRC_DBGCMD_WR(x, (HW_DDRC_DBGCMD_RD(x) & ~BM_DDRC_DBGCMD_ZQ_CALIB_SHORT) | BF_DDRC_DBGCMD_ZQ_CALIB_SHORT(v)))
/*@}*/

/*!
 * @name Register DDRC_DBGCMD, field CTRLUPD[5] (RW)
 *
 * Setting this register bit to 1 indicates to the DDRC to issue a
 * dfi_ctrlupd_req to the PHY. When this request is stored in the DDRC, the bit is
 * automatically cleared. This operation must only be performed when
 * DFIUPD0.dis_auto_ctrlupd = 1. Value After Reset: 0x0 Exists: Always Testable: Read only
 */
/*@{*/
#define BP_DDRC_DBGCMD_CTRLUPD (5U)        /*!< Bit position for DDRC_DBGCMD_CTRLUPD. */
#define BM_DDRC_DBGCMD_CTRLUPD (0x00000020U) /*!< Bit mask for DDRC_DBGCMD_CTRLUPD. */
#define BS_DDRC_DBGCMD_CTRLUPD (1U)        /*!< Bit field size in bits for DDRC_DBGCMD_CTRLUPD. */

/*! @brief Read current value of the DDRC_DBGCMD_CTRLUPD field. */
#define BR_DDRC_DBGCMD_CTRLUPD(x) (HW_DDRC_DBGCMD(x).B.CTRLUPD)

/*! @brief Format value for bitfield DDRC_DBGCMD_CTRLUPD. */
#define BF_DDRC_DBGCMD_CTRLUPD(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_DBGCMD_CTRLUPD) & BM_DDRC_DBGCMD_CTRLUPD)

/*! @brief Set the CTRLUPD field to a new value. */
#define BW_DDRC_DBGCMD_CTRLUPD(x, v) (HW_DDRC_DBGCMD_WR(x, (HW_DDRC_DBGCMD_RD(x) & ~BM_DDRC_DBGCMD_CTRLUPD) | BF_DDRC_DBGCMD_CTRLUPD(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_DBGSTAT - Status Debug Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_DBGSTAT - Status Debug Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_dbgstat
{
    uint32_t U;
    struct _hw_ddrc_dbgstat_bitfields
    {
        uint32_t RANK0_REFRESH_BUSY : 1; /*!< [0]  */
        uint32_t RANK1_REFRESH_BUSY : 1; /*!< [1]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t ZQ_CALIB_SHORT_BUSY : 1; /*!< [4]  */
        uint32_t CTRLUPD_BUSY : 1;     /*!< [5]  */
        uint32_t RESERVED1 : 26;       /*!< [31:6]  */
    } B;
} hw_ddrc_dbgstat_t;

/*!
 * @name Constants and macros for entire DDRC_DBGSTAT register
 */
/*@{*/
#define HW_DDRC_DBGSTAT_ADDR(x)  ((uintptr_t)(x) + 0x310U)

#define HW_DDRC_DBGSTAT(x)       (*(__I hw_ddrc_dbgstat_t *) HW_DDRC_DBGSTAT_ADDR(x))
#define HW_DDRC_DBGSTAT_RD(x)    (HW_DDRC_DBGSTAT(x).U)
/*@}*/

/*
 * Constants & macros for individual DDRC_DBGSTAT bitfields
 */

/*!
 * @name Register DDRC_DBGSTAT, field RANK0_REFRESH_BUSY[0] (RO)
 *
 * SoC core may initiate a rank0_refresh operation (refresh operation to rank 0)
 * only if this signal is low. This signal goes high in the clock after
 * DBGCMD.rank0_refresh is set to one. It goes low when the rank0_refresh operation is
 * stored in the DDRC. It is recommended not to performrank0_refresh operationswhen
 * this signal is high. Value After Reset: 0x0 Exists: Always
 *
 * Values:
 * - 0 - Indicates that the SoC core can initiate a rank0_refresh operation
 * - 1 - Indicates that rank0_refresh operation has not been stored yet in the
 *     DDRC
 */
/*@{*/
#define BP_DDRC_DBGSTAT_RANK0_REFRESH_BUSY (0U) /*!< Bit position for DDRC_DBGSTAT_RANK0_REFRESH_BUSY. */
#define BM_DDRC_DBGSTAT_RANK0_REFRESH_BUSY (0x00000001U) /*!< Bit mask for DDRC_DBGSTAT_RANK0_REFRESH_BUSY. */
#define BS_DDRC_DBGSTAT_RANK0_REFRESH_BUSY (1U) /*!< Bit field size in bits for DDRC_DBGSTAT_RANK0_REFRESH_BUSY. */

/*! @brief Read current value of the DDRC_DBGSTAT_RANK0_REFRESH_BUSY field. */
#define BR_DDRC_DBGSTAT_RANK0_REFRESH_BUSY(x) (HW_DDRC_DBGSTAT(x).B.RANK0_REFRESH_BUSY)
/*@}*/

/*!
 * @name Register DDRC_DBGSTAT, field RANK1_REFRESH_BUSY[1] (RO)
 *
 * SoC core may initiate a rank1_refresh operation (refresh operation to rank 1)
 * only if this signal is low. This signal goes high in the clock after
 * DBGCMD.rank1_refresh is set to one. It goes low when the rank1_refresh operation is
 * stored in the DDRC. It is recommended not to performrank1_refresh operationswhen
 * this signal is high. Value After Reset: 0x0 Exists: MEMC_NUM_RANKS > 1
 *
 * Values:
 * - 0 - Indicates that the SoC core can initiate a rank1_refresh operation
 * - 1 - Indicates that rank1_refresh operation has not been stored yet in the
 *     DDRC
 */
/*@{*/
#define BP_DDRC_DBGSTAT_RANK1_REFRESH_BUSY (1U) /*!< Bit position for DDRC_DBGSTAT_RANK1_REFRESH_BUSY. */
#define BM_DDRC_DBGSTAT_RANK1_REFRESH_BUSY (0x00000002U) /*!< Bit mask for DDRC_DBGSTAT_RANK1_REFRESH_BUSY. */
#define BS_DDRC_DBGSTAT_RANK1_REFRESH_BUSY (1U) /*!< Bit field size in bits for DDRC_DBGSTAT_RANK1_REFRESH_BUSY. */

/*! @brief Read current value of the DDRC_DBGSTAT_RANK1_REFRESH_BUSY field. */
#define BR_DDRC_DBGSTAT_RANK1_REFRESH_BUSY(x) (HW_DDRC_DBGSTAT(x).B.RANK1_REFRESH_BUSY)
/*@}*/

/*!
 * @name Register DDRC_DBGSTAT, field ZQ_CALIB_SHORT_BUSY[4] (RO)
 *
 * SoC core may initiate a ZQCS (ZQ calibration short) operation only if this
 * signal is low. This signal goes high in the clock after the DDRC accepts the
 * ZQCS request. It goes low when the ZQCS operation is initiated in the DDRC. It is
 * recommended not to perform ZQCS operations when this signal is high. Value
 * After Reset: 0x0 Exists: MEMC_DDR3_OR_LPDDR2 == 1
 */
/*@{*/
#define BP_DDRC_DBGSTAT_ZQ_CALIB_SHORT_BUSY (4U) /*!< Bit position for DDRC_DBGSTAT_ZQ_CALIB_SHORT_BUSY. */
#define BM_DDRC_DBGSTAT_ZQ_CALIB_SHORT_BUSY (0x00000010U) /*!< Bit mask for DDRC_DBGSTAT_ZQ_CALIB_SHORT_BUSY. */
#define BS_DDRC_DBGSTAT_ZQ_CALIB_SHORT_BUSY (1U) /*!< Bit field size in bits for DDRC_DBGSTAT_ZQ_CALIB_SHORT_BUSY. */

/*! @brief Read current value of the DDRC_DBGSTAT_ZQ_CALIB_SHORT_BUSY field. */
#define BR_DDRC_DBGSTAT_ZQ_CALIB_SHORT_BUSY(x) (HW_DDRC_DBGSTAT(x).B.ZQ_CALIB_SHORT_BUSY)
/*@}*/

/*!
 * @name Register DDRC_DBGSTAT, field CTRLUPD_BUSY[5] (RO)
 *
 * SoC coremay initiate a ctrlupd operation only if this signal is low. This
 * signal goes high in the clock after the DDRC accepts the ctrlupd request. It goes
 * low when the ctrlupd operation is initiated in the DDRC. It is recommended
 * not to perform ctrlupd operations when this signal is high. Value After Reset:
 * 0x0 Exists: Always
 *
 * Values:
 * - 0 - Indicates that the SoC core can initiate a ctrlupd operation
 * - 1 - Indicates that ctrlupd operation has not been initiated yet in the DDRC
 */
/*@{*/
#define BP_DDRC_DBGSTAT_CTRLUPD_BUSY (5U)  /*!< Bit position for DDRC_DBGSTAT_CTRLUPD_BUSY. */
#define BM_DDRC_DBGSTAT_CTRLUPD_BUSY (0x00000020U) /*!< Bit mask for DDRC_DBGSTAT_CTRLUPD_BUSY. */
#define BS_DDRC_DBGSTAT_CTRLUPD_BUSY (1U)  /*!< Bit field size in bits for DDRC_DBGSTAT_CTRLUPD_BUSY. */

/*! @brief Read current value of the DDRC_DBGSTAT_CTRLUPD_BUSY field. */
#define BR_DDRC_DBGSTAT_CTRLUPD_BUSY(x) (HW_DDRC_DBGSTAT(x).B.CTRLUPD_BUSY)
/*@}*/

/*******************************************************************************
 * HW_DDRC_SWCTL - Software Register Programming Control Enable
 ******************************************************************************/

/*!
 * @brief HW_DDRC_SWCTL - Software Register Programming Control Enable (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_swctl
{
    uint32_t U;
    struct _hw_ddrc_swctl_bitfields
    {
        uint32_t SW_DONE : 1;          /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_ddrc_swctl_t;

/*!
 * @name Constants and macros for entire DDRC_SWCTL register
 */
/*@{*/
#define HW_DDRC_SWCTL_ADDR(x)    ((uintptr_t)(x) + 0x320U)

#define HW_DDRC_SWCTL(x)         (*(__IO hw_ddrc_swctl_t *) HW_DDRC_SWCTL_ADDR(x))
#define HW_DDRC_SWCTL_RD(x)      (HW_DDRC_SWCTL(x).U)
#define HW_DDRC_SWCTL_WR(x, v)   (HW_DDRC_SWCTL(x).U = (v))
#define HW_DDRC_SWCTL_SET(x, v)  (HW_DDRC_SWCTL_WR(x, HW_DDRC_SWCTL_RD(x) |  (v)))
#define HW_DDRC_SWCTL_CLR(x, v)  (HW_DDRC_SWCTL_WR(x, HW_DDRC_SWCTL_RD(x) & ~(v)))
#define HW_DDRC_SWCTL_TOG(x, v)  (HW_DDRC_SWCTL_WR(x, HW_DDRC_SWCTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_SWCTL bitfields
 */

/*!
 * @name Register DDRC_SWCTL, field SW_DONE[0] (RW)
 *
 * Enable quasi dynamic register programming outside reset. Program register to
 * 0 to enable quasi dynamic programming. Set back register to 1 once programming
 * is done. Value After Reset: 0x1 Exists: Always
 */
/*@{*/
#define BP_DDRC_SWCTL_SW_DONE (0U)         /*!< Bit position for DDRC_SWCTL_SW_DONE. */
#define BM_DDRC_SWCTL_SW_DONE (0x00000001U) /*!< Bit mask for DDRC_SWCTL_SW_DONE. */
#define BS_DDRC_SWCTL_SW_DONE (1U)         /*!< Bit field size in bits for DDRC_SWCTL_SW_DONE. */

/*! @brief Read current value of the DDRC_SWCTL_SW_DONE field. */
#define BR_DDRC_SWCTL_SW_DONE(x) (HW_DDRC_SWCTL(x).B.SW_DONE)

/*! @brief Format value for bitfield DDRC_SWCTL_SW_DONE. */
#define BF_DDRC_SWCTL_SW_DONE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_SWCTL_SW_DONE) & BM_DDRC_SWCTL_SW_DONE)

/*! @brief Set the SW_DONE field to a new value. */
#define BW_DDRC_SWCTL_SW_DONE(x, v) (HW_DDRC_SWCTL_WR(x, (HW_DDRC_SWCTL_RD(x) & ~BM_DDRC_SWCTL_SW_DONE) | BF_DDRC_SWCTL_SW_DONE(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_SWSTAT - Software Register Programming Control Status
 ******************************************************************************/

/*!
 * @brief HW_DDRC_SWSTAT - Software Register Programming Control Status (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddrc_swstat
{
    uint32_t U;
    struct _hw_ddrc_swstat_bitfields
    {
        uint32_t SW_DONE_ACK : 1;      /*!< [0] Register programming done */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_ddrc_swstat_t;

/*!
 * @name Constants and macros for entire DDRC_SWSTAT register
 */
/*@{*/
#define HW_DDRC_SWSTAT_ADDR(x)   ((uintptr_t)(x) + 0x324U)

#define HW_DDRC_SWSTAT(x)        (*(__I hw_ddrc_swstat_t *) HW_DDRC_SWSTAT_ADDR(x))
#define HW_DDRC_SWSTAT_RD(x)     (HW_DDRC_SWSTAT(x).U)
/*@}*/

/*
 * Constants & macros for individual DDRC_SWSTAT bitfields
 */

/*!
 * @name Register DDRC_SWSTAT, field SW_DONE_ACK[0] (RO)
 *
 * This register is the echo of SWCTL.sw_done.Wait for sw_done value 1 to
 * propagate to sw_done_ack at the end of the programming sequence to ensure that the
 * correct registers values are propagated to the destination clock domains. Value
 * After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_SWSTAT_SW_DONE_ACK (0U)    /*!< Bit position for DDRC_SWSTAT_SW_DONE_ACK. */
#define BM_DDRC_SWSTAT_SW_DONE_ACK (0x00000001U) /*!< Bit mask for DDRC_SWSTAT_SW_DONE_ACK. */
#define BS_DDRC_SWSTAT_SW_DONE_ACK (1U)    /*!< Bit field size in bits for DDRC_SWSTAT_SW_DONE_ACK. */

/*! @brief Read current value of the DDRC_SWSTAT_SW_DONE_ACK field. */
#define BR_DDRC_SWSTAT_SW_DONE_ACK(x) (HW_DDRC_SWSTAT(x).B.SW_DONE_ACK)
/*@}*/

/*******************************************************************************
 * hw_ddrc_t - module struct
 ******************************************************************************/
/*!
 * @brief All DDRC module registers.
 */
#pragma pack(1)
typedef struct _hw_ddrc
{
    __IO hw_ddrc_mstr_t MSTR;              /*!< [0x0] Master Register */
    __IO hw_ddrc_stat_t STAT;              /*!< [0x4] Operating Mode Status Register */
    uint8_t _reserved0[8];
    __IO hw_ddrc_mrctrl0_t MRCTRL0;        /*!< [0x10] Mode Register Read / Write Control Register 0 */
    __IO hw_ddrc_mrctrl1_t MRCTRL1;        /*!< [0x14] Mode Register Read / Write Control Register 1 */
    __I hw_ddrc_mrstat_t MRSTAT;           /*!< [0x18] Mode Register Read / Write Status Register */
    uint8_t _reserved1[4];
    __IO hw_ddrc_derateen_t DERATEEN;      /*!< [0x20] Temperature Derate Enable Register */
    __IO hw_ddrc_derateint_t DERATEINT;    /*!< [0x24] Temperature Derate Interval Register */
    uint8_t _reserved2[8];
    __IO hw_ddrc_pwrctl_t PWRCTL;          /*!< [0x30] Low Power Control Register */
    __IO hw_ddrc_pwrtmg_t PWRTMG;          /*!< [0x34] Low Power Timing Register */
    __IO hw_ddrc_hwlpctl_t HWLPCTL;        /*!< [0x38] Hardware Low Power Control Register */
    uint8_t _reserved3[20];
    __IO hw_ddrc_rfshctl0_t RFSHCTL0;      /*!< [0x50] Refresh Control Register 0 */
    __IO hw_ddrc_rfshctl1_t RFSHCTL1;      /*!< [0x54] Refresh Control Register 1 */
    uint8_t _reserved4[8];
    __IO hw_ddrc_rfshctl3_t RFSHCTL3;      /*!< [0x60] Refresh Control Register 0 */
    __IO hw_ddrc_rfshtmg_t RFSHTMG;        /*!< [0x64] Refresh Timing Register */
    uint8_t _reserved5[104];
    __IO hw_ddrc_init0_t INIT0;            /*!< [0xD0] SDRAM Initialization Register 0 */
    __IO hw_ddrc_init1_t INIT1;            /*!< [0xD4] SDRAM Initialization Register 1 */
    __IO hw_ddrc_init2_t INIT2;            /*!< [0xD8] SDRAM Initialization Register 2 */
    __IO hw_ddrc_init3_t INIT3;            /*!< [0xDC] SDRAM Initialization Register 3 */
    __IO hw_ddrc_init4_t INIT4;            /*!< [0xE0] SDRAM Initialization Register 4 */
    __IO hw_ddrc_init5_t INIT5;            /*!< [0xE4] SDRAM Initialization Register 5 */
    uint8_t _reserved6[12];
    __IO hw_ddrc_rankctl_t RANKCTL;        /*!< [0xF4] Rank Control Register */
    uint8_t _reserved7[8];
    __IO hw_ddrc_dramtmg0_t DRAMTMG0;      /*!< [0x100] SDRAM Timing Register 0 */
    __IO hw_ddrc_dramtmg1_t DRAMTMG1;      /*!< [0x104] SDRAM Timing Register 1 */
    __IO hw_ddrc_dramtmg2_t DRAMTMG2;      /*!< [0x108] SDRAM Timing Register 2 */
    __IO hw_ddrc_dramtmg3_t DRAMTMG3;      /*!< [0x10C] SDRAM Timing Register 3 */
    __IO hw_ddrc_dramtmg4_t DRAMTMG4;      /*!< [0x110] SDRAM Timing Register 4 */
    __IO hw_ddrc_dramtmg5_t DRAMTMG5;      /*!< [0x114] SDRAM Timing Register5 */
    __IO hw_ddrc_dramtmg6_t DRAMTMG6;      /*!< [0x118] SDRAM Timing Register 6 */
    __IO hw_ddrc_dramtmg7_t DRAMTMG7;      /*!< [0x11C] SDRAM Timing Register 7 */
    __IO hw_ddrc_dramtmg8_t DRAMTMG8;      /*!< [0x120] SDRAM Timing Register 8 */
    uint8_t _reserved8[92];
    __IO hw_ddrc_zqctl0_t ZQCTL0;          /*!< [0x180] ZQ Control Register 0 */
    __IO hw_ddrc_zqctl1_t ZQCTL1;          /*!< [0x184] ZQ Control Register 1 */
    __IO hw_ddrc_zqctl2_t ZQCTL2;          /*!< [0x188] ZQ Control Register 2 */
    __I hw_ddrc_zqstat_t ZQSTAT;           /*!< [0x18C] ZQ Status Register */
    __IO hw_ddrc_dfitmg0_t DFITMG0;        /*!< [0x190] DFI Timing Register 0 */
    __IO hw_ddrc_dfitmg1_t DFITMG1;        /*!< [0x194] DFI Timing Register 1 */
    __IO hw_ddrc_dfilpcfg0_t DFILPCFG0;    /*!< [0x198] DFI Low Power Configuration Register 0 */
    uint8_t _reserved9[4];
    __IO hw_ddrc_dfiupd0_t DFIUPD0;        /*!< [0x1A0] DFI Update Register 0 */
    __IO hw_ddrc_dfiupd1_t DFIUPD1;        /*!< [0x1A4] DFI Update Register 1 */
    __IO hw_ddrc_dfiupd2_t DFIUPD2;        /*!< [0x1A8] DFI Update Register 2 */
    __IO hw_ddrc_dfiupd3_t DFIUPD3;        /*!< [0x1AC] DFI Update Register 3 */
    __IO hw_ddrc_dfimisc_t DFIMISC;        /*!< [0x1B0] DFI Miscellaneous Control Register */
    uint8_t _reserved10[76];
    __IO hw_ddrc_addrmap0_t ADDRMAP0;      /*!< [0x200] Address Map Register 0 */
    __IO hw_ddrc_addrmap1_t ADDRMAP1;      /*!< [0x204] Address Map Register 1 */
    __IO hw_ddrc_addrmap2_t ADDRMAP2;      /*!< [0x208] Address Map Register 2 */
    __IO hw_ddrc_addrmap3_t ADDRMAP3;      /*!< [0x20C] Address Map Register 3 */
    __IO hw_ddrc_addrmap4_t ADDRMAP4;      /*!< [0x210] Address Map Register 4 */
    __IO hw_ddrc_addrmap5_t ADDRMAP5;      /*!< [0x214] Address Map Register 5 */
    __IO hw_ddrc_addrmap6_t ADDRMAP6;      /*!< [0x218] Address Map Register 6 */
    uint8_t _reserved11[36];
    __IO hw_ddrc_odtcfg_t ODTCFG;          /*!< [0x240] ODT Configuration Register */
    __IO hw_ddrc_odtmap_t ODTMAP;          /*!< [0x244] ODT / Rank Map Register */
    uint8_t _reserved12[8];
    __IO hw_ddrc_sched_t SCHED;            /*!< [0x250] Scheduler Control Register */
    __IO hw_ddrc_sched1_t SCHED1;          /*!< [0x254] Scheduler Control Register 1 */
    uint8_t _reserved13[4];
    __IO hw_ddrc_perfhpr1_t PERFHPR1;      /*!< [0x25C] High Priority Read CAM Register 1 */
    uint8_t _reserved14[4];
    __IO hw_ddrc_perflpr1_t PERFLPR1;      /*!< [0x264] Low Priority Read CAM Register 1 */
    uint8_t _reserved15[4];
    __IO hw_ddrc_perfwr1_t PERFWR1;        /*!< [0x26C] Write CAM Register 1 */
    uint8_t _reserved16[4];
    __IO hw_ddrc_perfvpr1_t PERFVPR1;      /*!< [0x274] Variable Priority Read CAM Register 1 */
    __IO hw_ddrc_perfvpw1_t PERFVPW1;      /*!< [0x278] Variable Priority Write CAM Register 1 */
    uint8_t _reserved17[132];
    __IO hw_ddrc_dbg0_t DBG0;              /*!< [0x300] Debug Register 0 */
    __IO hw_ddrc_dbg1_t DBG1;              /*!< [0x304] Debug Register 1 */
    __I hw_ddrc_dbgcam_t DBGCAM;           /*!< [0x308] CAM Debug Register */
    __IO hw_ddrc_dbgcmd_t DBGCMD;          /*!< [0x30C] Command Debug Register */
    __I hw_ddrc_dbgstat_t DBGSTAT;         /*!< [0x310] Status Debug Register */
    uint8_t _reserved18[12];
    __IO hw_ddrc_swctl_t SWCTL;            /*!< [0x320] Software Register Programming Control Enable */
    __I hw_ddrc_swstat_t SWSTAT;           /*!< [0x324] Software Register Programming Control Status */
} hw_ddrc_t;
#pragma pack()

/*! @brief Macro to access all DDRC registers. */
/*! @param x DDRC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_DDRC_REGS(DDRC_BASE)</code>. */
#define HW_DDRC_REGS(x) (*(hw_ddrc_t *)(x))

/*
 * iMX7D DDRC_MP
 *
 * DDRC Multi Port Registers
 *
 * Registers defined in this header file:
 * - HW_DDRC_MP_PSTAT - Port Status Register
 * - HW_DDRC_MP_PCCFG - Port Common Configuration Register
 * - HW_DDRC_MP_PCFGR_0 - Port n Configuration Read Register
 * - HW_DDRC_MP_PCFGW_0 - Port n Configuration Write Register
 * - HW_DDRC_MP_PCFGIDMASKCH_n0 - Port n Channel m Configuration ID Mask Register
 * - HW_DDRC_MP_PCFGIDVALUECH_n0 - Port n Channel m Configuration ID Value Register
 * - HW_DDRC_MP_PCTRL_0 - Port n Control Register
 * - HW_DDRC_MP_PCFGQOS0_0 - Port n Read QoS Configuration Register 0
 * - HW_DDRC_MP_PCFGQOS1_0 - Port n Read QoS Configuration Register 1
 * - HW_DDRC_MP_PCFGWQOS0_0 - Port n Write QoS Configuration Register 0
 * - HW_DDRC_MP_PCFGWQOS1_0 - Port n Write QoS Configuration Register 1
 * - HW_DDRC_MP_SARBASEn - SAR Base Address Register n
 * - HW_DDRC_MP_SARSIZEn - SAR Size Register n
 *
 * - hw_ddrc_mp_t - Struct containing all module registers.
 */

#define HW_DDRC_MP_INSTANCE_COUNT (1U) /*!< Number of instances of the DDRC_MP module. */
#define HW_DDRC_MP (0U) /*!< Instance number for DDRC_MP. */
#define DDRC_MP_BASE          (0x307A0000U) /*!< Base address for DDRC_MP. */
/*! Array initializer of DDRC_MP base addresses. */
#define DDRC_MP_BASE_ADDRS    { DDRC_MP_BASE }

/*******************************************************************************
 * HW_DDRC_MP_PSTAT - Port Status Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_MP_PSTAT - Port Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * Exists: DDRC_INCL_ARB==1
 */
typedef union _hw_ddrc_mp_pstat
{
    uint32_t U;
    struct _hw_ddrc_mp_pstat_bitfields
    {
        uint32_t RD_PORT_BUSY_0 : 1;   /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_ddrc_mp_pstat_t;

/*!
 * @name Constants and macros for entire DDRC_MP_PSTAT register
 */
/*@{*/
#define HW_DDRC_MP_PSTAT_ADDR(x) ((uintptr_t)(x) + 0x3FCU)

#define HW_DDRC_MP_PSTAT(x)      (*(__I hw_ddrc_mp_pstat_t *) HW_DDRC_MP_PSTAT_ADDR(x))
#define HW_DDRC_MP_PSTAT_RD(x)   (HW_DDRC_MP_PSTAT(x).U)
/*@}*/

/*
 * Constants & macros for individual DDRC_MP_PSTAT bitfields
 */

/*!
 * @name Register DDRC_MP_PSTAT, field RD_PORT_BUSY_0[0] (RO)
 *
 * Indicates if there are outstanding reads for port 0. Value After Reset: 0x0
 * Exists: DDRC_PORT_0 == 1
 */
/*@{*/
#define BP_DDRC_MP_PSTAT_RD_PORT_BUSY_0 (0U) /*!< Bit position for DDRC_MP_PSTAT_RD_PORT_BUSY_0. */
#define BM_DDRC_MP_PSTAT_RD_PORT_BUSY_0 (0x00000001U) /*!< Bit mask for DDRC_MP_PSTAT_RD_PORT_BUSY_0. */
#define BS_DDRC_MP_PSTAT_RD_PORT_BUSY_0 (1U) /*!< Bit field size in bits for DDRC_MP_PSTAT_RD_PORT_BUSY_0. */

/*! @brief Read current value of the DDRC_MP_PSTAT_RD_PORT_BUSY_0 field. */
#define BR_DDRC_MP_PSTAT_RD_PORT_BUSY_0(x) (HW_DDRC_MP_PSTAT(x).B.RD_PORT_BUSY_0)
/*@}*/

/*******************************************************************************
 * HW_DDRC_MP_PCCFG - Port Common Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_MP_PCCFG - Port Common Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: DDRC_INCL_ARB==1
 */
typedef union _hw_ddrc_mp_pccfg
{
    uint32_t U;
    struct _hw_ddrc_mp_pccfg_bitfields
    {
        uint32_t GO2CRITICAL_EN : 1;   /*!< [0]  */
        uint32_t RESERVED0 : 3;        /*!< [3:1]  */
        uint32_t PAGEMATCH_LIMIT : 1;  /*!< [4] Page Match Four Limit */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_ddrc_mp_pccfg_t;

/*!
 * @name Constants and macros for entire DDRC_MP_PCCFG register
 */
/*@{*/
#define HW_DDRC_MP_PCCFG_ADDR(x) ((uintptr_t)(x) + 0x400U)

#define HW_DDRC_MP_PCCFG(x)      (*(__IO hw_ddrc_mp_pccfg_t *) HW_DDRC_MP_PCCFG_ADDR(x))
#define HW_DDRC_MP_PCCFG_RD(x)   (HW_DDRC_MP_PCCFG(x).U)
#define HW_DDRC_MP_PCCFG_WR(x, v) (HW_DDRC_MP_PCCFG(x).U = (v))
#define HW_DDRC_MP_PCCFG_SET(x, v) (HW_DDRC_MP_PCCFG_WR(x, HW_DDRC_MP_PCCFG_RD(x) |  (v)))
#define HW_DDRC_MP_PCCFG_CLR(x, v) (HW_DDRC_MP_PCCFG_WR(x, HW_DDRC_MP_PCCFG_RD(x) & ~(v)))
#define HW_DDRC_MP_PCCFG_TOG(x, v) (HW_DDRC_MP_PCCFG_WR(x, HW_DDRC_MP_PCCFG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_MP_PCCFG bitfields
 */

/*!
 * @name Register DDRC_MP_PCCFG, field GO2CRITICAL_EN[0] (RW)
 *
 * If set to 1 (enabled), sets hif_go2critical_wr and hif_go2critical_lpr /
 * hif_go2critical_hpr signals going to DDRC based on urgent input (awurgent,
 * arurgent) coming from AXI master. If set to 0 (disabled), hif_go2critical_wr and
 * hif_go2critical_lpr / hif_go2critical_hpr signals at DDRC are driven to 1b'0.
 * Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCCFG_GO2CRITICAL_EN (0U) /*!< Bit position for DDRC_MP_PCCFG_GO2CRITICAL_EN. */
#define BM_DDRC_MP_PCCFG_GO2CRITICAL_EN (0x00000001U) /*!< Bit mask for DDRC_MP_PCCFG_GO2CRITICAL_EN. */
#define BS_DDRC_MP_PCCFG_GO2CRITICAL_EN (1U) /*!< Bit field size in bits for DDRC_MP_PCCFG_GO2CRITICAL_EN. */

/*! @brief Read current value of the DDRC_MP_PCCFG_GO2CRITICAL_EN field. */
#define BR_DDRC_MP_PCCFG_GO2CRITICAL_EN(x) (HW_DDRC_MP_PCCFG(x).B.GO2CRITICAL_EN)

/*! @brief Format value for bitfield DDRC_MP_PCCFG_GO2CRITICAL_EN. */
#define BF_DDRC_MP_PCCFG_GO2CRITICAL_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCCFG_GO2CRITICAL_EN) & BM_DDRC_MP_PCCFG_GO2CRITICAL_EN)

/*! @brief Set the GO2CRITICAL_EN field to a new value. */
#define BW_DDRC_MP_PCCFG_GO2CRITICAL_EN(x, v) (HW_DDRC_MP_PCCFG_WR(x, (HW_DDRC_MP_PCCFG_RD(x) & ~BM_DDRC_MP_PCCFG_GO2CRITICAL_EN) | BF_DDRC_MP_PCCFG_GO2CRITICAL_EN(v)))
/*@}*/

/*!
 * @name Register DDRC_MP_PCCFG, field PAGEMATCH_LIMIT[4] (RW)
 *
 * If set to 1, limits the number of consecutive same page DDRC transactions
 * that can be granted by the Port Arbiter to four when Page Match feature is
 * enabled. If set to 0, there is no limit imposed on number of consecutive same page
 * DDRC transactions. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCCFG_PAGEMATCH_LIMIT (4U) /*!< Bit position for DDRC_MP_PCCFG_PAGEMATCH_LIMIT. */
#define BM_DDRC_MP_PCCFG_PAGEMATCH_LIMIT (0x00000010U) /*!< Bit mask for DDRC_MP_PCCFG_PAGEMATCH_LIMIT. */
#define BS_DDRC_MP_PCCFG_PAGEMATCH_LIMIT (1U) /*!< Bit field size in bits for DDRC_MP_PCCFG_PAGEMATCH_LIMIT. */

/*! @brief Read current value of the DDRC_MP_PCCFG_PAGEMATCH_LIMIT field. */
#define BR_DDRC_MP_PCCFG_PAGEMATCH_LIMIT(x) (HW_DDRC_MP_PCCFG(x).B.PAGEMATCH_LIMIT)

/*! @brief Format value for bitfield DDRC_MP_PCCFG_PAGEMATCH_LIMIT. */
#define BF_DDRC_MP_PCCFG_PAGEMATCH_LIMIT(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCCFG_PAGEMATCH_LIMIT) & BM_DDRC_MP_PCCFG_PAGEMATCH_LIMIT)

/*! @brief Set the PAGEMATCH_LIMIT field to a new value. */
#define BW_DDRC_MP_PCCFG_PAGEMATCH_LIMIT(x, v) (HW_DDRC_MP_PCCFG_WR(x, (HW_DDRC_MP_PCCFG_RD(x) & ~BM_DDRC_MP_PCCFG_PAGEMATCH_LIMIT) | BF_DDRC_MP_PCCFG_PAGEMATCH_LIMIT(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_MP_PCFGR_0 - Port n Configuration Read Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_MP_PCFGR_0 - Port n Configuration Read Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: DDRC_INCL_ARB==1 && DDRC_PORT_n==1
 */
typedef union _hw_ddrc_mp_pcfgr_0
{
    uint32_t U;
    struct _hw_ddrc_mp_pcfgr_0_bitfields
    {
        uint32_t RD_PORT_PRIORITY : 10; /*!< [9:0]  */
        uint32_t RESERVED0 : 1;        /*!< [10]  */
        uint32_t READ_REORDER_BYPASS_EN : 1; /*!< [11]  */
        uint32_t RD_PORT_AGING_EN : 1; /*!< [12]  */
        uint32_t RD_PORT_URGENT_EN : 1; /*!< [13]  */
        uint32_t RD_PORT_PAGEMATCH_EN : 1; /*!< [14]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t RDWR_ORDERED_EN : 1;  /*!< [16]  */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_ddrc_mp_pcfgr_0_t;

/*!
 * @name Constants and macros for entire DDRC_MP_PCFGR_0 register
 */
/*@{*/
#define HW_DDRC_MP_PCFGR_0_ADDR(x) ((uintptr_t)(x) + 0x404U)

#define HW_DDRC_MP_PCFGR_0(x)    (*(__IO hw_ddrc_mp_pcfgr_0_t *) HW_DDRC_MP_PCFGR_0_ADDR(x))
#define HW_DDRC_MP_PCFGR_0_RD(x) (HW_DDRC_MP_PCFGR_0(x).U)
#define HW_DDRC_MP_PCFGR_0_WR(x, v) (HW_DDRC_MP_PCFGR_0(x).U = (v))
#define HW_DDRC_MP_PCFGR_0_SET(x, v) (HW_DDRC_MP_PCFGR_0_WR(x, HW_DDRC_MP_PCFGR_0_RD(x) |  (v)))
#define HW_DDRC_MP_PCFGR_0_CLR(x, v) (HW_DDRC_MP_PCFGR_0_WR(x, HW_DDRC_MP_PCFGR_0_RD(x) & ~(v)))
#define HW_DDRC_MP_PCFGR_0_TOG(x, v) (HW_DDRC_MP_PCFGR_0_WR(x, HW_DDRC_MP_PCFGR_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_MP_PCFGR_0 bitfields
 */

/*!
 * @name Register DDRC_MP_PCFGR_0, field RD_PORT_PRIORITY[9:0] (RW)
 *
 * Determines the initial load value of read aging counters. These counters will
 * be parallel loaded after reset, or after each grant to the corresponding
 * port. The aging counters down-count every clock cycle where the port is requesting
 * but not granted. The higher significant 5-bit of the read aging counter sets
 * the priority of the read channel of a given port. Port's priority will
 * increase as the higher significant 5-bit of the counter starts to decrease. When the
 * aging counter becomes 0, the corresponding port channel will have the highest
 * priority level (timeout condition - Priority0). For multi port configurations,
 * the aging counters cannot be used to set port priorities when external
 * dynamic priority inputs (arqos) are enabled (timeout is still applicable). For
 * single port configurations, the aging counters are only used when they timeout
 * (become 0) to force read-write direction switching. In this case, external dynamic
 * priority input, arqos (for reads only) can still be used to set the DDRC read
 * priority (two priority levels: low priority read - LPR, high priority read -
 * HPR) on a command by command basis. Note: The two LSBs of this register field
 * are tied internally to 2'b00. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCFGR_0_RD_PORT_PRIORITY (0U) /*!< Bit position for DDRC_MP_PCFGR_0_RD_PORT_PRIORITY. */
#define BM_DDRC_MP_PCFGR_0_RD_PORT_PRIORITY (0x000003FFU) /*!< Bit mask for DDRC_MP_PCFGR_0_RD_PORT_PRIORITY. */
#define BS_DDRC_MP_PCFGR_0_RD_PORT_PRIORITY (10U) /*!< Bit field size in bits for DDRC_MP_PCFGR_0_RD_PORT_PRIORITY. */

/*! @brief Read current value of the DDRC_MP_PCFGR_0_RD_PORT_PRIORITY field. */
#define BR_DDRC_MP_PCFGR_0_RD_PORT_PRIORITY(x) (HW_DDRC_MP_PCFGR_0(x).B.RD_PORT_PRIORITY)

/*! @brief Format value for bitfield DDRC_MP_PCFGR_0_RD_PORT_PRIORITY. */
#define BF_DDRC_MP_PCFGR_0_RD_PORT_PRIORITY(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGR_0_RD_PORT_PRIORITY) & BM_DDRC_MP_PCFGR_0_RD_PORT_PRIORITY)

/*! @brief Set the RD_PORT_PRIORITY field to a new value. */
#define BW_DDRC_MP_PCFGR_0_RD_PORT_PRIORITY(x, v) (HW_DDRC_MP_PCFGR_0_WR(x, (HW_DDRC_MP_PCFGR_0_RD(x) & ~BM_DDRC_MP_PCFGR_0_RD_PORT_PRIORITY) | BF_DDRC_MP_PCFGR_0_RD_PORT_PRIORITY(v)))
/*@}*/

/*!
 * @name Register DDRC_MP_PCFGR_0, field READ_REORDER_BYPASS_EN[11] (RW)
 *
 * If set to 1, read transactions with ID not covered by any of the virtual
 * channel ID mapping registers are not reordered. Value After Reset: 0x0 Exists:
 * DDRC_PORT_CHm_0 == 1
 */
/*@{*/
#define BP_DDRC_MP_PCFGR_0_READ_REORDER_BYPASS_EN (11U) /*!< Bit position for DDRC_MP_PCFGR_0_READ_REORDER_BYPASS_EN. */
#define BM_DDRC_MP_PCFGR_0_READ_REORDER_BYPASS_EN (0x00000800U) /*!< Bit mask for DDRC_MP_PCFGR_0_READ_REORDER_BYPASS_EN. */
#define BS_DDRC_MP_PCFGR_0_READ_REORDER_BYPASS_EN (1U) /*!< Bit field size in bits for DDRC_MP_PCFGR_0_READ_REORDER_BYPASS_EN. */

/*! @brief Read current value of the DDRC_MP_PCFGR_0_READ_REORDER_BYPASS_EN field. */
#define BR_DDRC_MP_PCFGR_0_READ_REORDER_BYPASS_EN(x) (HW_DDRC_MP_PCFGR_0(x).B.READ_REORDER_BYPASS_EN)

/*! @brief Format value for bitfield DDRC_MP_PCFGR_0_READ_REORDER_BYPASS_EN. */
#define BF_DDRC_MP_PCFGR_0_READ_REORDER_BYPASS_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGR_0_READ_REORDER_BYPASS_EN) & BM_DDRC_MP_PCFGR_0_READ_REORDER_BYPASS_EN)

/*! @brief Set the READ_REORDER_BYPASS_EN field to a new value. */
#define BW_DDRC_MP_PCFGR_0_READ_REORDER_BYPASS_EN(x, v) (HW_DDRC_MP_PCFGR_0_WR(x, (HW_DDRC_MP_PCFGR_0_RD(x) & ~BM_DDRC_MP_PCFGR_0_READ_REORDER_BYPASS_EN) | BF_DDRC_MP_PCFGR_0_READ_REORDER_BYPASS_EN(v)))
/*@}*/

/*!
 * @name Register DDRC_MP_PCFGR_0, field RD_PORT_AGING_EN[12] (RW)
 *
 * If set to 1, enables aging function for the read channel of the port. Value
 * After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCFGR_0_RD_PORT_AGING_EN (12U) /*!< Bit position for DDRC_MP_PCFGR_0_RD_PORT_AGING_EN. */
#define BM_DDRC_MP_PCFGR_0_RD_PORT_AGING_EN (0x00001000U) /*!< Bit mask for DDRC_MP_PCFGR_0_RD_PORT_AGING_EN. */
#define BS_DDRC_MP_PCFGR_0_RD_PORT_AGING_EN (1U) /*!< Bit field size in bits for DDRC_MP_PCFGR_0_RD_PORT_AGING_EN. */

/*! @brief Read current value of the DDRC_MP_PCFGR_0_RD_PORT_AGING_EN field. */
#define BR_DDRC_MP_PCFGR_0_RD_PORT_AGING_EN(x) (HW_DDRC_MP_PCFGR_0(x).B.RD_PORT_AGING_EN)

/*! @brief Format value for bitfield DDRC_MP_PCFGR_0_RD_PORT_AGING_EN. */
#define BF_DDRC_MP_PCFGR_0_RD_PORT_AGING_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGR_0_RD_PORT_AGING_EN) & BM_DDRC_MP_PCFGR_0_RD_PORT_AGING_EN)

/*! @brief Set the RD_PORT_AGING_EN field to a new value. */
#define BW_DDRC_MP_PCFGR_0_RD_PORT_AGING_EN(x, v) (HW_DDRC_MP_PCFGR_0_WR(x, (HW_DDRC_MP_PCFGR_0_RD(x) & ~BM_DDRC_MP_PCFGR_0_RD_PORT_AGING_EN) | BF_DDRC_MP_PCFGR_0_RD_PORT_AGING_EN(v)))
/*@}*/

/*!
 * @name Register DDRC_MP_PCFGR_0, field RD_PORT_URGENT_EN[13] (RW)
 *
 * If set to 1, enables the AXI urgent sideband signal (arurgent). When enabled
 * and arurgent is asserted by the master, that port becomes the highest priority
 * and hif_go2critical_lpr / hif_go2critical_hpr signal to DDRC is asserted if
 * enabled in PCCFG.go2critical_en register. Arurgent signal can be asserted
 * anytime and as long as required which is independent of address handshaking (it is
 * not associated with any particular command). Value After Reset: 0x0 Exists:
 * Always
 */
/*@{*/
#define BP_DDRC_MP_PCFGR_0_RD_PORT_URGENT_EN (13U) /*!< Bit position for DDRC_MP_PCFGR_0_RD_PORT_URGENT_EN. */
#define BM_DDRC_MP_PCFGR_0_RD_PORT_URGENT_EN (0x00002000U) /*!< Bit mask for DDRC_MP_PCFGR_0_RD_PORT_URGENT_EN. */
#define BS_DDRC_MP_PCFGR_0_RD_PORT_URGENT_EN (1U) /*!< Bit field size in bits for DDRC_MP_PCFGR_0_RD_PORT_URGENT_EN. */

/*! @brief Read current value of the DDRC_MP_PCFGR_0_RD_PORT_URGENT_EN field. */
#define BR_DDRC_MP_PCFGR_0_RD_PORT_URGENT_EN(x) (HW_DDRC_MP_PCFGR_0(x).B.RD_PORT_URGENT_EN)

/*! @brief Format value for bitfield DDRC_MP_PCFGR_0_RD_PORT_URGENT_EN. */
#define BF_DDRC_MP_PCFGR_0_RD_PORT_URGENT_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGR_0_RD_PORT_URGENT_EN) & BM_DDRC_MP_PCFGR_0_RD_PORT_URGENT_EN)

/*! @brief Set the RD_PORT_URGENT_EN field to a new value. */
#define BW_DDRC_MP_PCFGR_0_RD_PORT_URGENT_EN(x, v) (HW_DDRC_MP_PCFGR_0_WR(x, (HW_DDRC_MP_PCFGR_0_RD(x) & ~BM_DDRC_MP_PCFGR_0_RD_PORT_URGENT_EN) | BF_DDRC_MP_PCFGR_0_RD_PORT_URGENT_EN(v)))
/*@}*/

/*!
 * @name Register DDRC_MP_PCFGR_0, field RD_PORT_PAGEMATCH_EN[14] (RW)
 *
 * If set to 1, enables the Page Match feature. If enabled, once a requesting
 * port is granted, the port is continued to be granted if the following immediate
 * commands are to the same memory page (same bank and same row). See also
 * related PCCFG.pagematch_limit register. Value After Reset:0x1 Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCFGR_0_RD_PORT_PAGEMATCH_EN (14U) /*!< Bit position for DDRC_MP_PCFGR_0_RD_PORT_PAGEMATCH_EN. */
#define BM_DDRC_MP_PCFGR_0_RD_PORT_PAGEMATCH_EN (0x00004000U) /*!< Bit mask for DDRC_MP_PCFGR_0_RD_PORT_PAGEMATCH_EN. */
#define BS_DDRC_MP_PCFGR_0_RD_PORT_PAGEMATCH_EN (1U) /*!< Bit field size in bits for DDRC_MP_PCFGR_0_RD_PORT_PAGEMATCH_EN. */

/*! @brief Read current value of the DDRC_MP_PCFGR_0_RD_PORT_PAGEMATCH_EN field. */
#define BR_DDRC_MP_PCFGR_0_RD_PORT_PAGEMATCH_EN(x) (HW_DDRC_MP_PCFGR_0(x).B.RD_PORT_PAGEMATCH_EN)

/*! @brief Format value for bitfield DDRC_MP_PCFGR_0_RD_PORT_PAGEMATCH_EN. */
#define BF_DDRC_MP_PCFGR_0_RD_PORT_PAGEMATCH_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGR_0_RD_PORT_PAGEMATCH_EN) & BM_DDRC_MP_PCFGR_0_RD_PORT_PAGEMATCH_EN)

/*! @brief Set the RD_PORT_PAGEMATCH_EN field to a new value. */
#define BW_DDRC_MP_PCFGR_0_RD_PORT_PAGEMATCH_EN(x, v) (HW_DDRC_MP_PCFGR_0_WR(x, (HW_DDRC_MP_PCFGR_0_RD(x) & ~BM_DDRC_MP_PCFGR_0_RD_PORT_PAGEMATCH_EN) | BF_DDRC_MP_PCFGR_0_RD_PORT_PAGEMATCH_EN(v)))
/*@}*/

/*!
 * @name Register DDRC_MP_PCFGR_0, field RDWR_ORDERED_EN[16] (RW)
 *
 * Enable ordered read / writes. If set to 1, preserves the ordering between
 * read transaction and write transaction issued to the same address, on a given
 * port. In other words, the controller ensures that all same address read and write
 * commands from the application port interface are transported to the DFI
 * interface in the order of acceptance. This feature is useful in cases where
 * software coherency is desired for masters issuing back-to-back read / write
 * transactions without waiting for write/read responses. This register has an effect only
 * if necessary logic is instantiated via the DDRC_RDWR_ORDERED_0 parameter.
 * Value After Reset: 0x0 Exists: DDRC_A_RDWR_ORDERED_0 == 1 && DDRC_A_AXI_0 == 1
 */
/*@{*/
#define BP_DDRC_MP_PCFGR_0_RDWR_ORDERED_EN (16U) /*!< Bit position for DDRC_MP_PCFGR_0_RDWR_ORDERED_EN. */
#define BM_DDRC_MP_PCFGR_0_RDWR_ORDERED_EN (0x00010000U) /*!< Bit mask for DDRC_MP_PCFGR_0_RDWR_ORDERED_EN. */
#define BS_DDRC_MP_PCFGR_0_RDWR_ORDERED_EN (1U) /*!< Bit field size in bits for DDRC_MP_PCFGR_0_RDWR_ORDERED_EN. */

/*! @brief Read current value of the DDRC_MP_PCFGR_0_RDWR_ORDERED_EN field. */
#define BR_DDRC_MP_PCFGR_0_RDWR_ORDERED_EN(x) (HW_DDRC_MP_PCFGR_0(x).B.RDWR_ORDERED_EN)

/*! @brief Format value for bitfield DDRC_MP_PCFGR_0_RDWR_ORDERED_EN. */
#define BF_DDRC_MP_PCFGR_0_RDWR_ORDERED_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGR_0_RDWR_ORDERED_EN) & BM_DDRC_MP_PCFGR_0_RDWR_ORDERED_EN)

/*! @brief Set the RDWR_ORDERED_EN field to a new value. */
#define BW_DDRC_MP_PCFGR_0_RDWR_ORDERED_EN(x, v) (HW_DDRC_MP_PCFGR_0_WR(x, (HW_DDRC_MP_PCFGR_0_RD(x) & ~BM_DDRC_MP_PCFGR_0_RDWR_ORDERED_EN) | BF_DDRC_MP_PCFGR_0_RDWR_ORDERED_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_MP_PCFGW_0 - Port n Configuration Write Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_MP_PCFGW_0 - Port n Configuration Write Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: DDRC_INCL_ARB==1 && DDRC_PORT_0==1
 */
typedef union _hw_ddrc_mp_pcfgw_0
{
    uint32_t U;
    struct _hw_ddrc_mp_pcfgw_0_bitfields
    {
        uint32_t WR_PORT_PRIORITY : 10; /*!< [9:0]  */
        uint32_t RESERVED0 : 2;        /*!< [11:10]  */
        uint32_t WR_PORT_AGING_EN : 1; /*!< [12]  */
        uint32_t WR_PORT_URGENT_EN : 1; /*!< [13]  */
        uint32_t WR_PORT_PAGEMATCH_EN : 1; /*!< [14]  */
        uint32_t RESERVED1 : 17;       /*!< [31:15]  */
    } B;
} hw_ddrc_mp_pcfgw_0_t;

/*!
 * @name Constants and macros for entire DDRC_MP_PCFGW_0 register
 */
/*@{*/
#define HW_DDRC_MP_PCFGW_0_ADDR(x) ((uintptr_t)(x) + 0x408U)

#define HW_DDRC_MP_PCFGW_0(x)    (*(__IO hw_ddrc_mp_pcfgw_0_t *) HW_DDRC_MP_PCFGW_0_ADDR(x))
#define HW_DDRC_MP_PCFGW_0_RD(x) (HW_DDRC_MP_PCFGW_0(x).U)
#define HW_DDRC_MP_PCFGW_0_WR(x, v) (HW_DDRC_MP_PCFGW_0(x).U = (v))
#define HW_DDRC_MP_PCFGW_0_SET(x, v) (HW_DDRC_MP_PCFGW_0_WR(x, HW_DDRC_MP_PCFGW_0_RD(x) |  (v)))
#define HW_DDRC_MP_PCFGW_0_CLR(x, v) (HW_DDRC_MP_PCFGW_0_WR(x, HW_DDRC_MP_PCFGW_0_RD(x) & ~(v)))
#define HW_DDRC_MP_PCFGW_0_TOG(x, v) (HW_DDRC_MP_PCFGW_0_WR(x, HW_DDRC_MP_PCFGW_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_MP_PCFGW_0 bitfields
 */

/*!
 * @name Register DDRC_MP_PCFGW_0, field WR_PORT_PRIORITY[9:0] (RW)
 *
 * Determines the initial load value of write aging counters. These counters
 * will be parallel loaded after reset, or after each grant to the corresponding
 * port. The aging counters down-count every clock cycle where the port is
 * requesting but not granted. The higher significant 5-bit of the write aging counter
 * sets the initial priority of the write channel of a given port. Port's priority
 * will increase as the higher significant 5-bit of the counter starts to
 * decrease. When the aging counter becomes 0, the corresponding port channel will have
 * the highest priority level. For multi port configurations, the aging counters
 * cannot be used to set port priorities when external dynamic priority inputs
 * (awqos) are enabled (timeout is still applicable). For single port
 * configurations, the aging counters are only used when they timeout (become 0) to force
 * read-write direction switching. Two LSBs of this register field are tied internally
 * to 2'b00. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCFGW_0_WR_PORT_PRIORITY (0U) /*!< Bit position for DDRC_MP_PCFGW_0_WR_PORT_PRIORITY. */
#define BM_DDRC_MP_PCFGW_0_WR_PORT_PRIORITY (0x000003FFU) /*!< Bit mask for DDRC_MP_PCFGW_0_WR_PORT_PRIORITY. */
#define BS_DDRC_MP_PCFGW_0_WR_PORT_PRIORITY (10U) /*!< Bit field size in bits for DDRC_MP_PCFGW_0_WR_PORT_PRIORITY. */

/*! @brief Read current value of the DDRC_MP_PCFGW_0_WR_PORT_PRIORITY field. */
#define BR_DDRC_MP_PCFGW_0_WR_PORT_PRIORITY(x) (HW_DDRC_MP_PCFGW_0(x).B.WR_PORT_PRIORITY)

/*! @brief Format value for bitfield DDRC_MP_PCFGW_0_WR_PORT_PRIORITY. */
#define BF_DDRC_MP_PCFGW_0_WR_PORT_PRIORITY(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGW_0_WR_PORT_PRIORITY) & BM_DDRC_MP_PCFGW_0_WR_PORT_PRIORITY)

/*! @brief Set the WR_PORT_PRIORITY field to a new value. */
#define BW_DDRC_MP_PCFGW_0_WR_PORT_PRIORITY(x, v) (HW_DDRC_MP_PCFGW_0_WR(x, (HW_DDRC_MP_PCFGW_0_RD(x) & ~BM_DDRC_MP_PCFGW_0_WR_PORT_PRIORITY) | BF_DDRC_MP_PCFGW_0_WR_PORT_PRIORITY(v)))
/*@}*/

/*!
 * @name Register DDRC_MP_PCFGW_0, field WR_PORT_AGING_EN[12] (RW)
 *
 * If set to 1, enables aging function for the write channel of the port. Value
 * After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCFGW_0_WR_PORT_AGING_EN (12U) /*!< Bit position for DDRC_MP_PCFGW_0_WR_PORT_AGING_EN. */
#define BM_DDRC_MP_PCFGW_0_WR_PORT_AGING_EN (0x00001000U) /*!< Bit mask for DDRC_MP_PCFGW_0_WR_PORT_AGING_EN. */
#define BS_DDRC_MP_PCFGW_0_WR_PORT_AGING_EN (1U) /*!< Bit field size in bits for DDRC_MP_PCFGW_0_WR_PORT_AGING_EN. */

/*! @brief Read current value of the DDRC_MP_PCFGW_0_WR_PORT_AGING_EN field. */
#define BR_DDRC_MP_PCFGW_0_WR_PORT_AGING_EN(x) (HW_DDRC_MP_PCFGW_0(x).B.WR_PORT_AGING_EN)

/*! @brief Format value for bitfield DDRC_MP_PCFGW_0_WR_PORT_AGING_EN. */
#define BF_DDRC_MP_PCFGW_0_WR_PORT_AGING_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGW_0_WR_PORT_AGING_EN) & BM_DDRC_MP_PCFGW_0_WR_PORT_AGING_EN)

/*! @brief Set the WR_PORT_AGING_EN field to a new value. */
#define BW_DDRC_MP_PCFGW_0_WR_PORT_AGING_EN(x, v) (HW_DDRC_MP_PCFGW_0_WR(x, (HW_DDRC_MP_PCFGW_0_RD(x) & ~BM_DDRC_MP_PCFGW_0_WR_PORT_AGING_EN) | BF_DDRC_MP_PCFGW_0_WR_PORT_AGING_EN(v)))
/*@}*/

/*!
 * @name Register DDRC_MP_PCFGW_0, field WR_PORT_URGENT_EN[13] (RW)
 *
 * If set to 1, enables the AXI urgent sideband signal (awurgent). When enabled
 * and awurgent is asserted by the master, that port becomes the highest priority
 * and hif_go2critical_wr signal to DDRC is asserted if enabled in
 * PCCFG.go2critical_enregister. Awurgent signal can be asserted anytime and as long as
 * required which is independent of address handshaking (it is not associated with any
 * particular command). Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCFGW_0_WR_PORT_URGENT_EN (13U) /*!< Bit position for DDRC_MP_PCFGW_0_WR_PORT_URGENT_EN. */
#define BM_DDRC_MP_PCFGW_0_WR_PORT_URGENT_EN (0x00002000U) /*!< Bit mask for DDRC_MP_PCFGW_0_WR_PORT_URGENT_EN. */
#define BS_DDRC_MP_PCFGW_0_WR_PORT_URGENT_EN (1U) /*!< Bit field size in bits for DDRC_MP_PCFGW_0_WR_PORT_URGENT_EN. */

/*! @brief Read current value of the DDRC_MP_PCFGW_0_WR_PORT_URGENT_EN field. */
#define BR_DDRC_MP_PCFGW_0_WR_PORT_URGENT_EN(x) (HW_DDRC_MP_PCFGW_0(x).B.WR_PORT_URGENT_EN)

/*! @brief Format value for bitfield DDRC_MP_PCFGW_0_WR_PORT_URGENT_EN. */
#define BF_DDRC_MP_PCFGW_0_WR_PORT_URGENT_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGW_0_WR_PORT_URGENT_EN) & BM_DDRC_MP_PCFGW_0_WR_PORT_URGENT_EN)

/*! @brief Set the WR_PORT_URGENT_EN field to a new value. */
#define BW_DDRC_MP_PCFGW_0_WR_PORT_URGENT_EN(x, v) (HW_DDRC_MP_PCFGW_0_WR(x, (HW_DDRC_MP_PCFGW_0_RD(x) & ~BM_DDRC_MP_PCFGW_0_WR_PORT_URGENT_EN) | BF_DDRC_MP_PCFGW_0_WR_PORT_URGENT_EN(v)))
/*@}*/

/*!
 * @name Register DDRC_MP_PCFGW_0, field WR_PORT_PAGEMATCH_EN[14] (RW)
 *
 * If set to 1, enables the Page Match feature. If enabled, once a requesting
 * port is granted, the port is continued to be granted if the following immediate
 * commands are to the same memory page (same bank and same row). See also
 * related PCCFG.pagematch_limit register. Value After Reset: 0x1 Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCFGW_0_WR_PORT_PAGEMATCH_EN (14U) /*!< Bit position for DDRC_MP_PCFGW_0_WR_PORT_PAGEMATCH_EN. */
#define BM_DDRC_MP_PCFGW_0_WR_PORT_PAGEMATCH_EN (0x00004000U) /*!< Bit mask for DDRC_MP_PCFGW_0_WR_PORT_PAGEMATCH_EN. */
#define BS_DDRC_MP_PCFGW_0_WR_PORT_PAGEMATCH_EN (1U) /*!< Bit field size in bits for DDRC_MP_PCFGW_0_WR_PORT_PAGEMATCH_EN. */

/*! @brief Read current value of the DDRC_MP_PCFGW_0_WR_PORT_PAGEMATCH_EN field. */
#define BR_DDRC_MP_PCFGW_0_WR_PORT_PAGEMATCH_EN(x) (HW_DDRC_MP_PCFGW_0(x).B.WR_PORT_PAGEMATCH_EN)

/*! @brief Format value for bitfield DDRC_MP_PCFGW_0_WR_PORT_PAGEMATCH_EN. */
#define BF_DDRC_MP_PCFGW_0_WR_PORT_PAGEMATCH_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGW_0_WR_PORT_PAGEMATCH_EN) & BM_DDRC_MP_PCFGW_0_WR_PORT_PAGEMATCH_EN)

/*! @brief Set the WR_PORT_PAGEMATCH_EN field to a new value. */
#define BW_DDRC_MP_PCFGW_0_WR_PORT_PAGEMATCH_EN(x, v) (HW_DDRC_MP_PCFGW_0_WR(x, (HW_DDRC_MP_PCFGW_0_RD(x) & ~BM_DDRC_MP_PCFGW_0_WR_PORT_PAGEMATCH_EN) | BF_DDRC_MP_PCFGW_0_WR_PORT_PAGEMATCH_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_MP_PCFGIDMASKCH_n0 - Port n Channel m Configuration ID Mask Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_MP_PCFGIDMASKCH_n0 - Port n Channel m Configuration ID Mask Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * M signifies the number of the virtual channel for the Port n where m = 0 to
 * 15. Exists: DDRC_PORT_CH m_0==1
 */
typedef union _hw_ddrc_mp_pcfgidmaskch_n0
{
    uint32_t U;
    struct _hw_ddrc_mp_pcfgidmaskch_n0_bitfields
    {
        uint32_t ID_MASK : 32;         /*!< [31:0]  */
    } B;
} hw_ddrc_mp_pcfgidmaskch_n0_t;

/*!
 * @name Constants and macros for entire DDRC_MP_PCFGIDMASKCH_n0 register
 */
/*@{*/
#define HW_DDRC_MP_PCFGIDMASKCH_n0_COUNT (16U)

#define HW_DDRC_MP_PCFGIDMASKCH_n0_ADDR(x, n) ((uintptr_t)(x) + 0x410U + (0x8U * (n)))

#define HW_DDRC_MP_PCFGIDMASKCH_n0(x, n) (*(__IO hw_ddrc_mp_pcfgidmaskch_n0_t *) HW_DDRC_MP_PCFGIDMASKCH_n0_ADDR(x, n))
#define HW_DDRC_MP_PCFGIDMASKCH_n0_RD(x, n) (HW_DDRC_MP_PCFGIDMASKCH_n0(x, n).U)
#define HW_DDRC_MP_PCFGIDMASKCH_n0_WR(x, n, v) (HW_DDRC_MP_PCFGIDMASKCH_n0(x, n).U = (v))
#define HW_DDRC_MP_PCFGIDMASKCH_n0_SET(x, n, v) (HW_DDRC_MP_PCFGIDMASKCH_n0_WR(x, n, HW_DDRC_MP_PCFGIDMASKCH_n0_RD(x, n) |  (v)))
#define HW_DDRC_MP_PCFGIDMASKCH_n0_CLR(x, n, v) (HW_DDRC_MP_PCFGIDMASKCH_n0_WR(x, n, HW_DDRC_MP_PCFGIDMASKCH_n0_RD(x, n) & ~(v)))
#define HW_DDRC_MP_PCFGIDMASKCH_n0_TOG(x, n, v) (HW_DDRC_MP_PCFGIDMASKCH_n0_WR(x, n, HW_DDRC_MP_PCFGIDMASKCH_n0_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_MP_PCFGIDMASKCH_n0 bitfields
 */

/*!
 * @name Register DDRC_MP_PCFGIDMASKCH_n0, field ID_MASK[31:0] (RW)
 *
 * Determines the mask used in the ID mapping function for virtual channel m.
 * Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCFGIDMASKCH_n0_ID_MASK (0U) /*!< Bit position for DDRC_MP_PCFGIDMASKCH_n0_ID_MASK. */
#define BM_DDRC_MP_PCFGIDMASKCH_n0_ID_MASK (0xFFFFFFFFU) /*!< Bit mask for DDRC_MP_PCFGIDMASKCH_n0_ID_MASK. */
#define BS_DDRC_MP_PCFGIDMASKCH_n0_ID_MASK (32U) /*!< Bit field size in bits for DDRC_MP_PCFGIDMASKCH_n0_ID_MASK. */

/*! @brief Read current value of the DDRC_MP_PCFGIDMASKCH_n0_ID_MASK field. */
#define BR_DDRC_MP_PCFGIDMASKCH_n0_ID_MASK(x, n) (HW_DDRC_MP_PCFGIDMASKCH_n0(x, n).U)

/*! @brief Format value for bitfield DDRC_MP_PCFGIDMASKCH_n0_ID_MASK. */
#define BF_DDRC_MP_PCFGIDMASKCH_n0_ID_MASK(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGIDMASKCH_n0_ID_MASK) & BM_DDRC_MP_PCFGIDMASKCH_n0_ID_MASK)

/*! @brief Set the ID_MASK field to a new value. */
#define BW_DDRC_MP_PCFGIDMASKCH_n0_ID_MASK(x, n, v) (HW_DDRC_MP_PCFGIDMASKCH_n0_WR(x, n, v))
/*@}*/
/*******************************************************************************
 * HW_DDRC_MP_PCFGIDVALUECH_n0 - Port n Channel m Configuration ID Value Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_MP_PCFGIDVALUECH_n0 - Port n Channel m Configuration ID Value Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: DDRC_PORT_CH m_0==1
 */
typedef union _hw_ddrc_mp_pcfgidvaluech_n0
{
    uint32_t U;
    struct _hw_ddrc_mp_pcfgidvaluech_n0_bitfields
    {
        uint32_t ID_VALUE : 32;        /*!< [31:0]  */
    } B;
} hw_ddrc_mp_pcfgidvaluech_n0_t;

/*!
 * @name Constants and macros for entire DDRC_MP_PCFGIDVALUECH_n0 register
 */
/*@{*/
#define HW_DDRC_MP_PCFGIDVALUECH_n0_COUNT (16U)

#define HW_DDRC_MP_PCFGIDVALUECH_n0_ADDR(x, n) ((uintptr_t)(x) + 0x414U + (0x8U * (n)))

#define HW_DDRC_MP_PCFGIDVALUECH_n0(x, n) (*(__IO hw_ddrc_mp_pcfgidvaluech_n0_t *) HW_DDRC_MP_PCFGIDVALUECH_n0_ADDR(x, n))
#define HW_DDRC_MP_PCFGIDVALUECH_n0_RD(x, n) (HW_DDRC_MP_PCFGIDVALUECH_n0(x, n).U)
#define HW_DDRC_MP_PCFGIDVALUECH_n0_WR(x, n, v) (HW_DDRC_MP_PCFGIDVALUECH_n0(x, n).U = (v))
#define HW_DDRC_MP_PCFGIDVALUECH_n0_SET(x, n, v) (HW_DDRC_MP_PCFGIDVALUECH_n0_WR(x, n, HW_DDRC_MP_PCFGIDVALUECH_n0_RD(x, n) |  (v)))
#define HW_DDRC_MP_PCFGIDVALUECH_n0_CLR(x, n, v) (HW_DDRC_MP_PCFGIDVALUECH_n0_WR(x, n, HW_DDRC_MP_PCFGIDVALUECH_n0_RD(x, n) & ~(v)))
#define HW_DDRC_MP_PCFGIDVALUECH_n0_TOG(x, n, v) (HW_DDRC_MP_PCFGIDVALUECH_n0_WR(x, n, HW_DDRC_MP_PCFGIDVALUECH_n0_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_MP_PCFGIDVALUECH_n0 bitfields
 */

/*!
 * @name Register DDRC_MP_PCFGIDVALUECH_n0, field ID_VALUE[31:0] (RW)
 *
 * Determines the value used in the ID mapping function for virtual channel m.
 * Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCFGIDVALUECH_n0_ID_VALUE (0U) /*!< Bit position for DDRC_MP_PCFGIDVALUECH_n0_ID_VALUE. */
#define BM_DDRC_MP_PCFGIDVALUECH_n0_ID_VALUE (0xFFFFFFFFU) /*!< Bit mask for DDRC_MP_PCFGIDVALUECH_n0_ID_VALUE. */
#define BS_DDRC_MP_PCFGIDVALUECH_n0_ID_VALUE (32U) /*!< Bit field size in bits for DDRC_MP_PCFGIDVALUECH_n0_ID_VALUE. */

/*! @brief Read current value of the DDRC_MP_PCFGIDVALUECH_n0_ID_VALUE field. */
#define BR_DDRC_MP_PCFGIDVALUECH_n0_ID_VALUE(x, n) (HW_DDRC_MP_PCFGIDVALUECH_n0(x, n).U)

/*! @brief Format value for bitfield DDRC_MP_PCFGIDVALUECH_n0_ID_VALUE. */
#define BF_DDRC_MP_PCFGIDVALUECH_n0_ID_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGIDVALUECH_n0_ID_VALUE) & BM_DDRC_MP_PCFGIDVALUECH_n0_ID_VALUE)

/*! @brief Set the ID_VALUE field to a new value. */
#define BW_DDRC_MP_PCFGIDVALUECH_n0_ID_VALUE(x, n, v) (HW_DDRC_MP_PCFGIDVALUECH_n0_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_DDRC_MP_PCTRL_0 - Port n Control Register
 ******************************************************************************/

/*!
 * @brief HW_DDRC_MP_PCTRL_0 - Port n Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * n signifies the Port where n= 0 to 15. Exists: DDRC_INCL_ARB==1 &&
 * DDRC_PORT_0==1
 */
typedef union _hw_ddrc_mp_pctrl_0
{
    uint32_t U;
    struct _hw_ddrc_mp_pctrl_0_bitfields
    {
        uint32_t PORT_EN : 1;          /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_ddrc_mp_pctrl_0_t;

/*!
 * @name Constants and macros for entire DDRC_MP_PCTRL_0 register
 */
/*@{*/
#define HW_DDRC_MP_PCTRL_0_ADDR(x) ((uintptr_t)(x) + 0x490U)

#define HW_DDRC_MP_PCTRL_0(x)    (*(__IO hw_ddrc_mp_pctrl_0_t *) HW_DDRC_MP_PCTRL_0_ADDR(x))
#define HW_DDRC_MP_PCTRL_0_RD(x) (HW_DDRC_MP_PCTRL_0(x).U)
#define HW_DDRC_MP_PCTRL_0_WR(x, v) (HW_DDRC_MP_PCTRL_0(x).U = (v))
#define HW_DDRC_MP_PCTRL_0_SET(x, v) (HW_DDRC_MP_PCTRL_0_WR(x, HW_DDRC_MP_PCTRL_0_RD(x) |  (v)))
#define HW_DDRC_MP_PCTRL_0_CLR(x, v) (HW_DDRC_MP_PCTRL_0_WR(x, HW_DDRC_MP_PCTRL_0_RD(x) & ~(v)))
#define HW_DDRC_MP_PCTRL_0_TOG(x, v) (HW_DDRC_MP_PCTRL_0_WR(x, HW_DDRC_MP_PCTRL_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_MP_PCTRL_0 bitfields
 */

/*!
 * @name Register DDRC_MP_PCTRL_0, field PORT_EN[0] (RW)
 *
 * Enables port n Value After Reset: DDRC_PORT_EN_RESET_VALUE Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCTRL_0_PORT_EN (0U)    /*!< Bit position for DDRC_MP_PCTRL_0_PORT_EN. */
#define BM_DDRC_MP_PCTRL_0_PORT_EN (0x00000001U) /*!< Bit mask for DDRC_MP_PCTRL_0_PORT_EN. */
#define BS_DDRC_MP_PCTRL_0_PORT_EN (1U)    /*!< Bit field size in bits for DDRC_MP_PCTRL_0_PORT_EN. */

/*! @brief Read current value of the DDRC_MP_PCTRL_0_PORT_EN field. */
#define BR_DDRC_MP_PCTRL_0_PORT_EN(x) (HW_DDRC_MP_PCTRL_0(x).B.PORT_EN)

/*! @brief Format value for bitfield DDRC_MP_PCTRL_0_PORT_EN. */
#define BF_DDRC_MP_PCTRL_0_PORT_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCTRL_0_PORT_EN) & BM_DDRC_MP_PCTRL_0_PORT_EN)

/*! @brief Set the PORT_EN field to a new value. */
#define BW_DDRC_MP_PCTRL_0_PORT_EN(x, v) (HW_DDRC_MP_PCTRL_0_WR(x, (HW_DDRC_MP_PCTRL_0_RD(x) & ~BM_DDRC_MP_PCTRL_0_PORT_EN) | BF_DDRC_MP_PCTRL_0_PORT_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_MP_PCFGQOS0_0 - Port n Read QoS Configuration Register 0
 ******************************************************************************/

/*!
 * @brief HW_DDRC_MP_PCFGQOS0_0 - Port n Read QoS Configuration Register 0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: DDRC_A_AXI_0==1
 */
typedef union _hw_ddrc_mp_pcfgqos0_0
{
    uint32_t U;
    struct _hw_ddrc_mp_pcfgqos0_0_bitfields
    {
        uint32_t RQOS_MAP_LEVEL1 : 4;  /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t RQOS_MAP_LEVEL2 : 4;  /*!< [11:8]  */
        uint32_t RESERVED1 : 4;        /*!< [15:12]  */
        uint32_t RQOS_MAP_REGION0 : 2; /*!< [17:16]  */
        uint32_t RESERVED2 : 2;        /*!< [19:18]  */
        uint32_t RQOS_MAP_REGION1 : 2; /*!< [21:20]  */
        uint32_t RESERVED3 : 2;        /*!< [23:22]  */
        uint32_t RQOS_MAP_REGION2 : 2; /*!< [25:24]  */
        uint32_t RESERVED4 : 6;        /*!< [31:26]  */
    } B;
} hw_ddrc_mp_pcfgqos0_0_t;

/*!
 * @name Constants and macros for entire DDRC_MP_PCFGQOS0_0 register
 */
/*@{*/
#define HW_DDRC_MP_PCFGQOS0_0_ADDR(x) ((uintptr_t)(x) + 0x494U)

#define HW_DDRC_MP_PCFGQOS0_0(x) (*(__IO hw_ddrc_mp_pcfgqos0_0_t *) HW_DDRC_MP_PCFGQOS0_0_ADDR(x))
#define HW_DDRC_MP_PCFGQOS0_0_RD(x) (HW_DDRC_MP_PCFGQOS0_0(x).U)
#define HW_DDRC_MP_PCFGQOS0_0_WR(x, v) (HW_DDRC_MP_PCFGQOS0_0(x).U = (v))
#define HW_DDRC_MP_PCFGQOS0_0_SET(x, v) (HW_DDRC_MP_PCFGQOS0_0_WR(x, HW_DDRC_MP_PCFGQOS0_0_RD(x) |  (v)))
#define HW_DDRC_MP_PCFGQOS0_0_CLR(x, v) (HW_DDRC_MP_PCFGQOS0_0_WR(x, HW_DDRC_MP_PCFGQOS0_0_RD(x) & ~(v)))
#define HW_DDRC_MP_PCFGQOS0_0_TOG(x, v) (HW_DDRC_MP_PCFGQOS0_0_WR(x, HW_DDRC_MP_PCFGQOS0_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_MP_PCFGQOS0_0 bitfields
 */

/*!
 * @name Register DDRC_MP_PCFGQOS0_0, field RQOS_MAP_LEVEL1[3:0] (RW)
 *
 * Separation level1 indicating the end of region0 mapping; start of region0 is
 * 0. Possible values for level1 are 0 to 13 (for dual RAQ) or 0 to 14 (for
 * single RAQ) which corresponds to arqos. For PA, arqos values are used directly as
 * port priorities, where the higher the value corresponds to higher port
 * priority. All of the map_level* registers must be set to distinct values. Value After
 * Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1 (0U) /*!< Bit position for DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1. */
#define BM_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1 (0x0000000FU) /*!< Bit mask for DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1. */
#define BS_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1 (4U) /*!< Bit field size in bits for DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1. */

/*! @brief Read current value of the DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1 field. */
#define BR_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1(x) (HW_DDRC_MP_PCFGQOS0_0(x).B.RQOS_MAP_LEVEL1)

/*! @brief Format value for bitfield DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1. */
#define BF_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1) & BM_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1)

/*! @brief Set the RQOS_MAP_LEVEL1 field to a new value. */
#define BW_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1(x, v) (HW_DDRC_MP_PCFGQOS0_0_WR(x, (HW_DDRC_MP_PCFGQOS0_0_RD(x) & ~BM_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1) | BF_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL1(v)))
/*@}*/

/*!
 * @name Register DDRC_MP_PCFGQOS0_0, field RQOS_MAP_LEVEL2[11:8] (RW)
 *
 * Separation level2 indicating the end of region1 mapping; start of region1 is
 * (level1 + 1). Possible values for level2 are (level1 + 1) to 14 which
 * corresponds to arqos. Region2 starts from (level2 + 1) up to 15. For PA, arqos values
 * are used directly as port priorities, where the higher the value corresponds
 * to higher port priority. All of the map_level* registers must be set to
 * distinct values. Value After Reset: 0xe Exists: DDRC_A_USE2RAQ_0 == 1
 */
/*@{*/
#define BP_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2 (8U) /*!< Bit position for DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2. */
#define BM_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2 (0x00000F00U) /*!< Bit mask for DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2. */
#define BS_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2 (4U) /*!< Bit field size in bits for DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2. */

/*! @brief Read current value of the DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2 field. */
#define BR_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2(x) (HW_DDRC_MP_PCFGQOS0_0(x).B.RQOS_MAP_LEVEL2)

/*! @brief Format value for bitfield DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2. */
#define BF_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2) & BM_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2)

/*! @brief Set the RQOS_MAP_LEVEL2 field to a new value. */
#define BW_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2(x, v) (HW_DDRC_MP_PCFGQOS0_0_WR(x, (HW_DDRC_MP_PCFGQOS0_0_RD(x) & ~BM_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2) | BF_DDRC_MP_PCFGQOS0_0_RQOS_MAP_LEVEL2(v)))
/*@}*/

/*!
 * @name Register DDRC_MP_PCFGQOS0_0, field RQOS_MAP_REGION0[17:16] (RW)
 *
 * This bitfield indicates the traffic class of region 0. Valid values are: 0:
 * LPR 1: VPR 2: HPR For dual address queue configurations, region 0 maps to the
 * blue address queue. In this case, valid values are: 0: LPR 1: VPR only When VPR
 * support is disabled (DDRC_VPR_EN = 0) and traffic class of region0 is set to
 * 1 (VPR), VPR traffic is aliased to LPR traffic. Value After Reset: 0x0 Exists:
 * Always
 */
/*@{*/
#define BP_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0 (16U) /*!< Bit position for DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0. */
#define BM_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0 (0x00030000U) /*!< Bit mask for DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0. */
#define BS_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0 (2U) /*!< Bit field size in bits for DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0. */

/*! @brief Read current value of the DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0 field. */
#define BR_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0(x) (HW_DDRC_MP_PCFGQOS0_0(x).B.RQOS_MAP_REGION0)

/*! @brief Format value for bitfield DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0. */
#define BF_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0) & BM_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0)

/*! @brief Set the RQOS_MAP_REGION0 field to a new value. */
#define BW_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0(x, v) (HW_DDRC_MP_PCFGQOS0_0_WR(x, (HW_DDRC_MP_PCFGQOS0_0_RD(x) & ~BM_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0) | BF_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION0(v)))
/*@}*/

/*!
 * @name Register DDRC_MP_PCFGQOS0_0, field RQOS_MAP_REGION1[21:20] (RW)
 *
 * This bitfield indicates the traffic class of region 1. Valid values are: 0 -
 * LPR 1 - VPR 2 - HPR For dual address queue configurations, region1 maps to the
 * blue address queue. In this case, valid values are: 0: LPR 1: VPR only When
 * VPR support is disabled (DDRC_VPR_EN = 0) and traffic class of region 1 is set
 * to 1 (VPR), VPR traffic is aliased to LPR traffic. Value After Reset: 0x0
 * Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1 (20U) /*!< Bit position for DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1. */
#define BM_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1 (0x00300000U) /*!< Bit mask for DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1. */
#define BS_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1 (2U) /*!< Bit field size in bits for DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1. */

/*! @brief Read current value of the DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1 field. */
#define BR_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1(x) (HW_DDRC_MP_PCFGQOS0_0(x).B.RQOS_MAP_REGION1)

/*! @brief Format value for bitfield DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1. */
#define BF_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1) & BM_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1)

/*! @brief Set the RQOS_MAP_REGION1 field to a new value. */
#define BW_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1(x, v) (HW_DDRC_MP_PCFGQOS0_0_WR(x, (HW_DDRC_MP_PCFGQOS0_0_RD(x) & ~BM_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1) | BF_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION1(v)))
/*@}*/

/*!
 * @name Register DDRC_MP_PCFGQOS0_0, field RQOS_MAP_REGION2[25:24] (RW)
 *
 * This bitfield indicates the traffic class of region2. For dual address queue
 * configurations, region2 maps to the red address queue. Valid values are: 1:
 * VPR 2: HPR only. When VPR support is disabled (DDRC_VPR_EN = 0) and traffic
 * class of region2 is set to 1 (VPR), VPR traffic is aliased to LPR traffic. Value
 * After Reset: 0x2 Exists: DDRC_A_USE2RAQ_0 == 1
 */
/*@{*/
#define BP_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2 (24U) /*!< Bit position for DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2. */
#define BM_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2 (0x03000000U) /*!< Bit mask for DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2. */
#define BS_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2 (2U) /*!< Bit field size in bits for DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2. */

/*! @brief Read current value of the DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2 field. */
#define BR_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2(x) (HW_DDRC_MP_PCFGQOS0_0(x).B.RQOS_MAP_REGION2)

/*! @brief Format value for bitfield DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2. */
#define BF_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2) & BM_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2)

/*! @brief Set the RQOS_MAP_REGION2 field to a new value. */
#define BW_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2(x, v) (HW_DDRC_MP_PCFGQOS0_0_WR(x, (HW_DDRC_MP_PCFGQOS0_0_RD(x) & ~BM_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2) | BF_DDRC_MP_PCFGQOS0_0_RQOS_MAP_REGION2(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_MP_PCFGQOS1_0 - Port n Read QoS Configuration Register 1
 ******************************************************************************/

/*!
 * @brief HW_DDRC_MP_PCFGQOS1_0 - Port n Read QoS Configuration Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: DDRC_A_AXI_n==1 && DDRC_XPI_VPR_n==1
 */
typedef union _hw_ddrc_mp_pcfgqos1_0
{
    uint32_t U;
    struct _hw_ddrc_mp_pcfgqos1_0_bitfields
    {
        uint32_t RQOS_MAP_TIMEOUTB : 11; /*!< [10:0]  */
        uint32_t RESERVED0 : 5;        /*!< [15:11]  */
        uint32_t RQOS_MAP_TIMEOUTR : 11; /*!< [26:16]  */
        uint32_t RESERVED1 : 5;        /*!< [31:27]  */
    } B;
} hw_ddrc_mp_pcfgqos1_0_t;

/*!
 * @name Constants and macros for entire DDRC_MP_PCFGQOS1_0 register
 */
/*@{*/
#define HW_DDRC_MP_PCFGQOS1_0_ADDR(x) ((uintptr_t)(x) + 0x498U)

#define HW_DDRC_MP_PCFGQOS1_0(x) (*(__IO hw_ddrc_mp_pcfgqos1_0_t *) HW_DDRC_MP_PCFGQOS1_0_ADDR(x))
#define HW_DDRC_MP_PCFGQOS1_0_RD(x) (HW_DDRC_MP_PCFGQOS1_0(x).U)
#define HW_DDRC_MP_PCFGQOS1_0_WR(x, v) (HW_DDRC_MP_PCFGQOS1_0(x).U = (v))
#define HW_DDRC_MP_PCFGQOS1_0_SET(x, v) (HW_DDRC_MP_PCFGQOS1_0_WR(x, HW_DDRC_MP_PCFGQOS1_0_RD(x) |  (v)))
#define HW_DDRC_MP_PCFGQOS1_0_CLR(x, v) (HW_DDRC_MP_PCFGQOS1_0_WR(x, HW_DDRC_MP_PCFGQOS1_0_RD(x) & ~(v)))
#define HW_DDRC_MP_PCFGQOS1_0_TOG(x, v) (HW_DDRC_MP_PCFGQOS1_0_WR(x, HW_DDRC_MP_PCFGQOS1_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_MP_PCFGQOS1_0 bitfields
 */

/*!
 * @name Register DDRC_MP_PCFGQOS1_0, field RQOS_MAP_TIMEOUTB[10:0] (RW)
 *
 * Specifies the timeout value for transactions mapped to the blue address
 * queue. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB (0U) /*!< Bit position for DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB. */
#define BM_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB (0x000007FFU) /*!< Bit mask for DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB. */
#define BS_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB (11U) /*!< Bit field size in bits for DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB. */

/*! @brief Read current value of the DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB field. */
#define BR_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB(x) (HW_DDRC_MP_PCFGQOS1_0(x).B.RQOS_MAP_TIMEOUTB)

/*! @brief Format value for bitfield DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB. */
#define BF_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB) & BM_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB)

/*! @brief Set the RQOS_MAP_TIMEOUTB field to a new value. */
#define BW_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB(x, v) (HW_DDRC_MP_PCFGQOS1_0_WR(x, (HW_DDRC_MP_PCFGQOS1_0_RD(x) & ~BM_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB) | BF_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTB(v)))
/*@}*/

/*!
 * @name Register DDRC_MP_PCFGQOS1_0, field RQOS_MAP_TIMEOUTR[26:16] (RW)
 *
 * Specifies the timeout value for transactions mapped to the red address queue.
 * Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR (16U) /*!< Bit position for DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR. */
#define BM_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR (0x07FF0000U) /*!< Bit mask for DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR. */
#define BS_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR (11U) /*!< Bit field size in bits for DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR. */

/*! @brief Read current value of the DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR field. */
#define BR_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR(x) (HW_DDRC_MP_PCFGQOS1_0(x).B.RQOS_MAP_TIMEOUTR)

/*! @brief Format value for bitfield DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR. */
#define BF_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR) & BM_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR)

/*! @brief Set the RQOS_MAP_TIMEOUTR field to a new value. */
#define BW_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR(x, v) (HW_DDRC_MP_PCFGQOS1_0_WR(x, (HW_DDRC_MP_PCFGQOS1_0_RD(x) & ~BM_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR) | BF_DDRC_MP_PCFGQOS1_0_RQOS_MAP_TIMEOUTR(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_MP_PCFGWQOS0_0 - Port n Write QoS Configuration Register 0
 ******************************************************************************/

/*!
 * @brief HW_DDRC_MP_PCFGWQOS0_0 - Port n Write QoS Configuration Register 0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * n signifies the Port where n = 0 to 15. Exists: DDRC_A_AXI_n==1 &&
 * DDRC_XPI_VPW_n==1
 */
typedef union _hw_ddrc_mp_pcfgwqos0_0
{
    uint32_t U;
    struct _hw_ddrc_mp_pcfgwqos0_0_bitfields
    {
        uint32_t WQOS_MAP_LEVEL : 4;   /*!< [3:0]  */
        uint32_t RESERVED0 : 12;       /*!< [15:4]  */
        uint32_t WQOS_MAP_REGION0 : 2; /*!< [17:16]  */
        uint32_t RESERVED1 : 2;        /*!< [19:18]  */
        uint32_t WQOS_MAP_REGION1 : 2; /*!< [21:20]  */
        uint32_t RESERVED2 : 10;       /*!< [31:22]  */
    } B;
} hw_ddrc_mp_pcfgwqos0_0_t;

/*!
 * @name Constants and macros for entire DDRC_MP_PCFGWQOS0_0 register
 */
/*@{*/
#define HW_DDRC_MP_PCFGWQOS0_0_ADDR(x) ((uintptr_t)(x) + 0x49CU)

#define HW_DDRC_MP_PCFGWQOS0_0(x) (*(__IO hw_ddrc_mp_pcfgwqos0_0_t *) HW_DDRC_MP_PCFGWQOS0_0_ADDR(x))
#define HW_DDRC_MP_PCFGWQOS0_0_RD(x) (HW_DDRC_MP_PCFGWQOS0_0(x).U)
#define HW_DDRC_MP_PCFGWQOS0_0_WR(x, v) (HW_DDRC_MP_PCFGWQOS0_0(x).U = (v))
#define HW_DDRC_MP_PCFGWQOS0_0_SET(x, v) (HW_DDRC_MP_PCFGWQOS0_0_WR(x, HW_DDRC_MP_PCFGWQOS0_0_RD(x) |  (v)))
#define HW_DDRC_MP_PCFGWQOS0_0_CLR(x, v) (HW_DDRC_MP_PCFGWQOS0_0_WR(x, HW_DDRC_MP_PCFGWQOS0_0_RD(x) & ~(v)))
#define HW_DDRC_MP_PCFGWQOS0_0_TOG(x, v) (HW_DDRC_MP_PCFGWQOS0_0_WR(x, HW_DDRC_MP_PCFGWQOS0_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_MP_PCFGWQOS0_0 bitfields
 */

/*!
 * @name Register DDRC_MP_PCFGWQOS0_0, field WQOS_MAP_LEVEL[3:0] (RW)
 *
 * Separation level indicating the end of region0 mapping; start of region0 is
 * 0. Possible values for level1 are 0 to 14 which corresponds to awqos. For PA,
 * awqos values are used directly as port priorities, where the higher the value
 * corresponds to higher port priority. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL (0U) /*!< Bit position for DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL. */
#define BM_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL (0x0000000FU) /*!< Bit mask for DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL. */
#define BS_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL (4U) /*!< Bit field size in bits for DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL. */

/*! @brief Read current value of the DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL field. */
#define BR_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL(x) (HW_DDRC_MP_PCFGWQOS0_0(x).B.WQOS_MAP_LEVEL)

/*! @brief Format value for bitfield DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL. */
#define BF_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL) & BM_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL)

/*! @brief Set the WQOS_MAP_LEVEL field to a new value. */
#define BW_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL(x, v) (HW_DDRC_MP_PCFGWQOS0_0_WR(x, (HW_DDRC_MP_PCFGWQOS0_0_RD(x) & ~BM_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL) | BF_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_LEVEL(v)))
/*@}*/

/*!
 * @name Register DDRC_MP_PCFGWQOS0_0, field WQOS_MAP_REGION0[17:16] (RW)
 *
 * This bitfield indicates the traffic class of region 0. Valid values are: 0:
 * NPW 1: VPW When VPW support is disabled (DDRC_VPW_EN = 0) and traffic class of
 * region0 is set to 1 (VPW), VPW traffic is aliased to NPW traffic. Value After
 * Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0 (16U) /*!< Bit position for DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0. */
#define BM_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0 (0x00030000U) /*!< Bit mask for DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0. */
#define BS_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0 (2U) /*!< Bit field size in bits for DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0. */

/*! @brief Read current value of the DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0 field. */
#define BR_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0(x) (HW_DDRC_MP_PCFGWQOS0_0(x).B.WQOS_MAP_REGION0)

/*! @brief Format value for bitfield DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0. */
#define BF_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0) & BM_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0)

/*! @brief Set the WQOS_MAP_REGION0 field to a new value. */
#define BW_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0(x, v) (HW_DDRC_MP_PCFGWQOS0_0_WR(x, (HW_DDRC_MP_PCFGWQOS0_0_RD(x) & ~BM_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0) | BF_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION0(v)))
/*@}*/

/*!
 * @name Register DDRC_MP_PCFGWQOS0_0, field WQOS_MAP_REGION1[21:20] (RW)
 *
 * This bitfield indicates the traffic class of region 1. Valid values are: 0:
 * NPW 1: VPW When VPW support is disabled (DDRC_VPW_EN = 0) and traffic class of
 * region 1 is set to 1 (VPW), VPW traffic is aliased to LPW traffic. Value After
 * Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1 (20U) /*!< Bit position for DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1. */
#define BM_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1 (0x00300000U) /*!< Bit mask for DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1. */
#define BS_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1 (2U) /*!< Bit field size in bits for DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1. */

/*! @brief Read current value of the DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1 field. */
#define BR_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1(x) (HW_DDRC_MP_PCFGWQOS0_0(x).B.WQOS_MAP_REGION1)

/*! @brief Format value for bitfield DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1. */
#define BF_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1) & BM_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1)

/*! @brief Set the WQOS_MAP_REGION1 field to a new value. */
#define BW_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1(x, v) (HW_DDRC_MP_PCFGWQOS0_0_WR(x, (HW_DDRC_MP_PCFGWQOS0_0_RD(x) & ~BM_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1) | BF_DDRC_MP_PCFGWQOS0_0_WQOS_MAP_REGION1(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_MP_PCFGWQOS1_0 - Port n Write QoS Configuration Register 1
 ******************************************************************************/

/*!
 * @brief HW_DDRC_MP_PCFGWQOS1_0 - Port n Write QoS Configuration Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Exists: DDRC_A_AXI_n==1 && DDRC_XPI_VPW_n==1
 */
typedef union _hw_ddrc_mp_pcfgwqos1_0
{
    uint32_t U;
    struct _hw_ddrc_mp_pcfgwqos1_0_bitfields
    {
        uint32_t WQOS_MAP_TIMEOUT : 11; /*!< [10:0]  */
        uint32_t RESERVED0 : 21;       /*!< [31:11]  */
    } B;
} hw_ddrc_mp_pcfgwqos1_0_t;

/*!
 * @name Constants and macros for entire DDRC_MP_PCFGWQOS1_0 register
 */
/*@{*/
#define HW_DDRC_MP_PCFGWQOS1_0_ADDR(x) ((uintptr_t)(x) + 0x4A0U)

#define HW_DDRC_MP_PCFGWQOS1_0(x) (*(__IO hw_ddrc_mp_pcfgwqos1_0_t *) HW_DDRC_MP_PCFGWQOS1_0_ADDR(x))
#define HW_DDRC_MP_PCFGWQOS1_0_RD(x) (HW_DDRC_MP_PCFGWQOS1_0(x).U)
#define HW_DDRC_MP_PCFGWQOS1_0_WR(x, v) (HW_DDRC_MP_PCFGWQOS1_0(x).U = (v))
#define HW_DDRC_MP_PCFGWQOS1_0_SET(x, v) (HW_DDRC_MP_PCFGWQOS1_0_WR(x, HW_DDRC_MP_PCFGWQOS1_0_RD(x) |  (v)))
#define HW_DDRC_MP_PCFGWQOS1_0_CLR(x, v) (HW_DDRC_MP_PCFGWQOS1_0_WR(x, HW_DDRC_MP_PCFGWQOS1_0_RD(x) & ~(v)))
#define HW_DDRC_MP_PCFGWQOS1_0_TOG(x, v) (HW_DDRC_MP_PCFGWQOS1_0_WR(x, HW_DDRC_MP_PCFGWQOS1_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_MP_PCFGWQOS1_0 bitfields
 */

/*!
 * @name Register DDRC_MP_PCFGWQOS1_0, field WQOS_MAP_TIMEOUT[10:0] (RW)
 *
 * Specifies the timeout value for write transactions. Value After Reset: 0x0
 * Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT (0U) /*!< Bit position for DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT. */
#define BM_DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT (0x000007FFU) /*!< Bit mask for DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT. */
#define BS_DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT (11U) /*!< Bit field size in bits for DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT. */

/*! @brief Read current value of the DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT field. */
#define BR_DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT(x) (HW_DDRC_MP_PCFGWQOS1_0(x).B.WQOS_MAP_TIMEOUT)

/*! @brief Format value for bitfield DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT. */
#define BF_DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT) & BM_DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT)

/*! @brief Set the WQOS_MAP_TIMEOUT field to a new value. */
#define BW_DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT(x, v) (HW_DDRC_MP_PCFGWQOS1_0_WR(x, (HW_DDRC_MP_PCFGWQOS1_0_RD(x) & ~BM_DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT) | BF_DDRC_MP_PCFGWQOS1_0_WQOS_MAP_TIMEOUT(v)))
/*@}*/

/*******************************************************************************
 * HW_DDRC_MP_SARBASEn - SAR Base Address Register n
 ******************************************************************************/

/*!
 * @brief HW_DDRC_MP_SARBASEn - SAR Base Address Register n (RW)
 *
 * Reset value: 0x00000000U
 *
 * Where n= 0 to 3 Exits: DDRC_INCL_ARB==1 && DDRC_A_SAR_n==1
 */
typedef union _hw_ddrc_mp_sarbasen
{
    uint32_t U;
    struct _hw_ddrc_mp_sarbasen_bitfields
    {
        uint32_t BASE_ADDR : 32;       /*!< [31:0]  */
    } B;
} hw_ddrc_mp_sarbasen_t;

/*!
 * @name Constants and macros for entire DDRC_MP_SARBASEn register
 */
/*@{*/
#define HW_DDRC_MP_SARBASEn_COUNT (4U)

#define HW_DDRC_MP_SARBASEn_ADDR(x, n) ((uintptr_t)(x) + 0xF04U + (0x8U * (n)))

#define HW_DDRC_MP_SARBASEn(x, n) (*(__IO hw_ddrc_mp_sarbasen_t *) HW_DDRC_MP_SARBASEn_ADDR(x, n))
#define HW_DDRC_MP_SARBASEn_RD(x, n) (HW_DDRC_MP_SARBASEn(x, n).U)
#define HW_DDRC_MP_SARBASEn_WR(x, n, v) (HW_DDRC_MP_SARBASEn(x, n).U = (v))
#define HW_DDRC_MP_SARBASEn_SET(x, n, v) (HW_DDRC_MP_SARBASEn_WR(x, n, HW_DDRC_MP_SARBASEn_RD(x, n) |  (v)))
#define HW_DDRC_MP_SARBASEn_CLR(x, n, v) (HW_DDRC_MP_SARBASEn_WR(x, n, HW_DDRC_MP_SARBASEn_RD(x, n) & ~(v)))
#define HW_DDRC_MP_SARBASEn_TOG(x, n, v) (HW_DDRC_MP_SARBASEn_WR(x, n, HW_DDRC_MP_SARBASEn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_MP_SARBASEn bitfields
 */

/*!
 * @name Register DDRC_MP_SARBASEn, field BASE_ADDR[31:0] (RW)
 *
 * Base address for address region n specified as awaddr[DDRC_A_ADDRW-1:x]and
 * araddr[DDRC_A_ADDRW-1:x] where x is determined by the minimum block size
 * parameter DDRC_SARMINSIZE: (x = log2 (block size)). Value After Reset: 0x0 Exists:
 * Always
 */
/*@{*/
#define BP_DDRC_MP_SARBASEn_BASE_ADDR (0U) /*!< Bit position for DDRC_MP_SARBASEn_BASE_ADDR. */
#define BM_DDRC_MP_SARBASEn_BASE_ADDR (0xFFFFFFFFU) /*!< Bit mask for DDRC_MP_SARBASEn_BASE_ADDR. */
#define BS_DDRC_MP_SARBASEn_BASE_ADDR (32U) /*!< Bit field size in bits for DDRC_MP_SARBASEn_BASE_ADDR. */

/*! @brief Read current value of the DDRC_MP_SARBASEn_BASE_ADDR field. */
#define BR_DDRC_MP_SARBASEn_BASE_ADDR(x, n) (HW_DDRC_MP_SARBASEn(x, n).U)

/*! @brief Format value for bitfield DDRC_MP_SARBASEn_BASE_ADDR. */
#define BF_DDRC_MP_SARBASEn_BASE_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_SARBASEn_BASE_ADDR) & BM_DDRC_MP_SARBASEn_BASE_ADDR)

/*! @brief Set the BASE_ADDR field to a new value. */
#define BW_DDRC_MP_SARBASEn_BASE_ADDR(x, n, v) (HW_DDRC_MP_SARBASEn_WR(x, n, v))
/*@}*/
/*******************************************************************************
 * HW_DDRC_MP_SARSIZEn - SAR Size Register n
 ******************************************************************************/

/*!
 * @brief HW_DDRC_MP_SARSIZEn - SAR Size Register n (RW)
 *
 * Reset value: 0x00000000U
 *
 * Where n= 0 to 3 Exists: DDRC_INCL_ARB==1 && DDRC_A_SAR_n==1
 */
typedef union _hw_ddrc_mp_sarsizen
{
    uint32_t U;
    struct _hw_ddrc_mp_sarsizen_bitfields
    {
        uint32_t NBLOCKS : 8;          /*!< [7:0]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_ddrc_mp_sarsizen_t;

/*!
 * @name Constants and macros for entire DDRC_MP_SARSIZEn register
 */
/*@{*/
#define HW_DDRC_MP_SARSIZEn_COUNT (4U)

#define HW_DDRC_MP_SARSIZEn_ADDR(x, n) ((uintptr_t)(x) + 0xF08U + (0x8U * (n)))

#define HW_DDRC_MP_SARSIZEn(x, n) (*(__IO hw_ddrc_mp_sarsizen_t *) HW_DDRC_MP_SARSIZEn_ADDR(x, n))
#define HW_DDRC_MP_SARSIZEn_RD(x, n) (HW_DDRC_MP_SARSIZEn(x, n).U)
#define HW_DDRC_MP_SARSIZEn_WR(x, n, v) (HW_DDRC_MP_SARSIZEn(x, n).U = (v))
#define HW_DDRC_MP_SARSIZEn_SET(x, n, v) (HW_DDRC_MP_SARSIZEn_WR(x, n, HW_DDRC_MP_SARSIZEn_RD(x, n) |  (v)))
#define HW_DDRC_MP_SARSIZEn_CLR(x, n, v) (HW_DDRC_MP_SARSIZEn_WR(x, n, HW_DDRC_MP_SARSIZEn_RD(x, n) & ~(v)))
#define HW_DDRC_MP_SARSIZEn_TOG(x, n, v) (HW_DDRC_MP_SARSIZEn_WR(x, n, HW_DDRC_MP_SARSIZEn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDRC_MP_SARSIZEn bitfields
 */

/*!
 * @name Register DDRC_MP_SARSIZEn, field NBLOCKS[7:0] (RW)
 *
 * Number of blocks for address region n. This register determines the total
 * size of the region in multiples of minimum block size as specified by the
 * hardware parameter DDRC_SARMINSIZE. The register value is encoded as number of blocks
 * = nblocks + 1. For example, if register is programmed to 0, region will have
 * 1 block. Value After Reset: 0x0 Exists: Always
 */
/*@{*/
#define BP_DDRC_MP_SARSIZEn_NBLOCKS (0U)   /*!< Bit position for DDRC_MP_SARSIZEn_NBLOCKS. */
#define BM_DDRC_MP_SARSIZEn_NBLOCKS (0x000000FFU) /*!< Bit mask for DDRC_MP_SARSIZEn_NBLOCKS. */
#define BS_DDRC_MP_SARSIZEn_NBLOCKS (8U)   /*!< Bit field size in bits for DDRC_MP_SARSIZEn_NBLOCKS. */

/*! @brief Read current value of the DDRC_MP_SARSIZEn_NBLOCKS field. */
#define BR_DDRC_MP_SARSIZEn_NBLOCKS(x, n) (HW_DDRC_MP_SARSIZEn(x, n).B.NBLOCKS)

/*! @brief Format value for bitfield DDRC_MP_SARSIZEn_NBLOCKS. */
#define BF_DDRC_MP_SARSIZEn_NBLOCKS(v) ((uint32_t)((uint32_t)(v) << BP_DDRC_MP_SARSIZEn_NBLOCKS) & BM_DDRC_MP_SARSIZEn_NBLOCKS)

/*! @brief Set the NBLOCKS field to a new value. */
#define BW_DDRC_MP_SARSIZEn_NBLOCKS(x, n, v) (HW_DDRC_MP_SARSIZEn_WR(x, n, (HW_DDRC_MP_SARSIZEn_RD(x, n) & ~BM_DDRC_MP_SARSIZEn_NBLOCKS) | BF_DDRC_MP_SARSIZEn_NBLOCKS(v)))
/*@}*/

/*******************************************************************************
 * hw_ddrc_mp_t - module struct
 ******************************************************************************/
/*!
 * @brief All DDRC_MP module registers.
 */
#pragma pack(1)
typedef struct _hw_ddrc_mp
{
    uint8_t _reserved0[1020];
    __I hw_ddrc_mp_pstat_t PSTAT;          /*!< [0x3FC] Port Status Register */
    __IO hw_ddrc_mp_pccfg_t PCCFG;         /*!< [0x400] Port Common Configuration Register */
    __IO hw_ddrc_mp_pcfgr_0_t PCFGR_0;     /*!< [0x404] Port n Configuration Read Register */
    __IO hw_ddrc_mp_pcfgw_0_t PCFGW_0;     /*!< [0x408] Port n Configuration Write Register */
    uint8_t _reserved1[4];
    struct {
        __IO hw_ddrc_mp_pcfgidmaskch_n0_t PCFGIDMASKCH_n0; /*!< [0x410] Port n Channel m Configuration ID Mask Register */
        __IO hw_ddrc_mp_pcfgidvaluech_n0_t PCFGIDVALUECH_n0; /*!< [0x414] Port n Channel m Configuration ID Value Register */
    } PCFGID[16];
    __IO hw_ddrc_mp_pctrl_0_t PCTRL_0;     /*!< [0x490] Port n Control Register */
    __IO hw_ddrc_mp_pcfgqos0_0_t PCFGQOS0_0; /*!< [0x494] Port n Read QoS Configuration Register 0 */
    __IO hw_ddrc_mp_pcfgqos1_0_t PCFGQOS1_0; /*!< [0x498] Port n Read QoS Configuration Register 1 */
    __IO hw_ddrc_mp_pcfgwqos0_0_t PCFGWQOS0_0; /*!< [0x49C] Port n Write QoS Configuration Register 0 */
    __IO hw_ddrc_mp_pcfgwqos1_0_t PCFGWQOS1_0; /*!< [0x4A0] Port n Write QoS Configuration Register 1 */
    uint8_t _reserved2[2656];
    struct {
        __IO hw_ddrc_mp_sarbasen_t SARBASEn; /*!< [0xF04] SAR Base Address Register n */
        __IO hw_ddrc_mp_sarsizen_t SARSIZEn; /*!< [0xF08] SAR Size Register n */
    } SAR[4];
} hw_ddrc_mp_t;
#pragma pack()

/*! @brief Macro to access all DDRC_MP registers. */
/*! @param x DDRC_MP module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_DDRC_MP_REGS(DDRC_MP_BASE)</code>. */
#define HW_DDRC_MP_REGS(x) (*(hw_ddrc_mp_t *)(x))

/*
 * iMX7D DDR_PHY
 *
 * DDR PHY Control Register
 *
 * Registers defined in this header file:
 * - HW_DDR_PHY_PHY_CON0 -
 * - HW_DDR_PHY_PHY_CON1 -
 * - HW_DDR_PHY_PHY_CON2 -
 * - HW_DDR_PHY_PHY_CON3 -
 * - HW_DDR_PHY_PHY_CON4 -
 * - HW_DDR_PHY_PHY_CON5 -
 * - HW_DDR_PHY_LP_CON0 -
 * - HW_DDR_PHY_RODT_CON0 -
 * - HW_DDR_PHY_OFFSET_RD_CON0 -
 * - HW_DDR_PHY_OFFSET_WR_CON0 -
 * - HW_DDR_PHY_GATE_CODE_CON0 -
 * - HW_DDR_PHY_SHIFTC_CON0 -
 * - HW_DDR_PHY_CMD_SDLL_CON0 -
 * - HW_DDR_PHY_LVL_CON0 -
 * - HW_DDR_PHY_LVL_CON3 -
 * - HW_DDR_PHY_CMD_DESKEW_CON0 -
 * - HW_DDR_PHY_CMD_DESKEW_CON1 -
 * - HW_DDR_PHY_CMD_DESKEW_CON2 -
 * - HW_DDR_PHY_CMD_DESKEW_CON3 -
 * - HW_DDR_PHY_CMD_DESKEW_CON4 -
 * - HW_DDR_PHY_DRVDS_CON0 -
 * - HW_DDR_PHY_MDLL_CON0 -
 * - HW_DDR_PHY_MDLL_CON1 -
 * - HW_DDR_PHY_ZQ_CON0 -
 * - HW_DDR_PHY_ZQ_CON1 -
 * - HW_DDR_PHY_ZQ_CON2 -
 * - HW_DDR_PHY_RD_DESKEW_CON0 -
 * - HW_DDR_PHY_RD_DESKEW_CON3 -
 * - HW_DDR_PHY_RD_DESKEW_CON6 -
 * - HW_DDR_PHY_RD_DESKEW_CON9 -
 * - HW_DDR_PHY_RD_DESKEW_CON12 -
 * - HW_DDR_PHY_RD_DESKEW_CON15 -
 * - HW_DDR_PHY_RD_DESKEW_CON18 -
 * - HW_DDR_PHY_RD_DESKEW_CON21 -
 * - HW_DDR_PHY_WR_DESKEW_CON0 -
 * - HW_DDR_PHY_WR_DESKEW_CON3 -
 * - HW_DDR_PHY_WR_DESKEW_CON6 -
 * - HW_DDR_PHY_WR_DESKEW_CON9 -
 * - HW_DDR_PHY_WR_DESKEW_CON12 -
 * - HW_DDR_PHY_WR_DESKEW_CON15 -
 * - HW_DDR_PHY_WR_DESKEW_CON18 -
 * - HW_DDR_PHY_WR_DESKEW_CON21 -
 * - HW_DDR_PHY_DM_DESKEW_CON -
 * - HW_DDR_PHY_RDATA0 -
 * - HW_DDR_PHY_STAT0 -
 *
 * - hw_ddr_phy_t - Struct containing all module registers.
 */

#define HW_DDR_PHY_INSTANCE_COUNT (1U) /*!< Number of instances of the DDR_PHY module. */
#define HW_DDR_PHY (0U) /*!< Instance number for DDR_PHY. */
#define DDR_PHY_BASE          (0x30790000U) /*!< Base address for DDR_PHY. */
/*! Array initializer of DDR_PHY base addresses. */
#define DDR_PHY_BASE_ADDRS    { DDR_PHY_BASE }

/*******************************************************************************
 * HW_DDR_PHY_PHY_CON0 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_PHY_CON0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * PHY Control Register
 */
typedef union _hw_ddr_phy_phy_con0
{
    uint32_t U;
    struct _hw_ddr_phy_phy_con0_bitfields
    {
        uint32_t CTRL_FNC_FB : 3;      /*!< [2:0]  */
        uint32_t CTRL_TWPRE : 1;       /*!< [3]  */
        uint32_t CTRL_CMOSRCV : 1;     /*!< [4]  */
        uint32_t RESERVED0 : 1;        /*!< [5]  */
        uint32_t CTRL_ATGATE : 1;      /*!< [6]  */
        uint32_t RESERVED1 : 1;        /*!< [7]  */
        uint32_t CTRL_SHGATE : 1;      /*!< [8]  */
        uint32_t CTRL_DFDQS : 1;       /*!< [9]  */
        uint32_t RESERVED2 : 1;        /*!< [10]  */
        uint32_t CTRL_DDR_MODE : 2;    /*!< [12:11]  */
        uint32_t RESERVED3 : 3;        /*!< [15:13]  */
        uint32_t WRLVL_MODE : 1;       /*!< [16]  */
        uint32_t RESERVED4 : 3;        /*!< [19:17]  */
        uint32_t CTRL_UPD_RANGE : 2;   /*!< [21:20]  */
        uint32_t CTRL_UPD_MODE : 2;    /*!< [23:22]  */
        uint32_t RESERVED5 : 8;        /*!< [31:24]  */
    } B;
} hw_ddr_phy_phy_con0_t;

/*!
 * @name Constants and macros for entire DDR_PHY_PHY_CON0 register
 */
/*@{*/
#define HW_DDR_PHY_PHY_CON0_ADDR(x) ((uintptr_t)(x) + 0x0U)

#define HW_DDR_PHY_PHY_CON0(x)   (*(__IO hw_ddr_phy_phy_con0_t *) HW_DDR_PHY_PHY_CON0_ADDR(x))
#define HW_DDR_PHY_PHY_CON0_RD(x) (HW_DDR_PHY_PHY_CON0(x).U)
#define HW_DDR_PHY_PHY_CON0_WR(x, v) (HW_DDR_PHY_PHY_CON0(x).U = (v))
#define HW_DDR_PHY_PHY_CON0_SET(x, v) (HW_DDR_PHY_PHY_CON0_WR(x, HW_DDR_PHY_PHY_CON0_RD(x) |  (v)))
#define HW_DDR_PHY_PHY_CON0_CLR(x, v) (HW_DDR_PHY_PHY_CON0_WR(x, HW_DDR_PHY_PHY_CON0_RD(x) & ~(v)))
#define HW_DDR_PHY_PHY_CON0_TOG(x, v) (HW_DDR_PHY_PHY_CON0_WR(x, HW_DDR_PHY_PHY_CON0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_PHY_CON0 bitfields
 */

/*!
 * @name Register DDR_PHY_PHY_CON0, field CTRL_FNC_FB[2:0] (RW)
 *
 * Valid only when {mode_phy, mode_nand, mode_scan, mode_mux} is 4'b00000.
 * Initial Value = 3'b000For normal operation 3'b000: Normal operation mode. For ATE
 * test purpose 3'b010: External FNC read feedback test mode. 3'b011: Internal FNC
 * read feedback test mode. For Board test purpose 3'b100: External PHY read
 * feedback test mode. When memory is not attached on the board 3'b101: Internal PHY
 * read feedback test mode. mode_highz should be set. 3'b110: Internal PHY write
 * feedback test mode. mode_highz should be set.
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON0_CTRL_FNC_FB (0U) /*!< Bit position for DDR_PHY_PHY_CON0_CTRL_FNC_FB. */
#define BM_DDR_PHY_PHY_CON0_CTRL_FNC_FB (0x00000007U) /*!< Bit mask for DDR_PHY_PHY_CON0_CTRL_FNC_FB. */
#define BS_DDR_PHY_PHY_CON0_CTRL_FNC_FB (3U) /*!< Bit field size in bits for DDR_PHY_PHY_CON0_CTRL_FNC_FB. */

/*! @brief Read current value of the DDR_PHY_PHY_CON0_CTRL_FNC_FB field. */
#define BR_DDR_PHY_PHY_CON0_CTRL_FNC_FB(x) (HW_DDR_PHY_PHY_CON0(x).B.CTRL_FNC_FB)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON0_CTRL_FNC_FB. */
#define BF_DDR_PHY_PHY_CON0_CTRL_FNC_FB(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON0_CTRL_FNC_FB) & BM_DDR_PHY_PHY_CON0_CTRL_FNC_FB)

/*! @brief Set the CTRL_FNC_FB field to a new value. */
#define BW_DDR_PHY_PHY_CON0_CTRL_FNC_FB(x, v) (HW_DDR_PHY_PHY_CON0_WR(x, (HW_DDR_PHY_PHY_CON0_RD(x) & ~BM_DDR_PHY_PHY_CON0_CTRL_FNC_FB) | BF_DDR_PHY_PHY_CON0_CTRL_FNC_FB(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON0, field CTRL_TWPRE[3] (RW)
 *
 * Write preamble setting Initial Value = 1'b0
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON0_CTRL_TWPRE (3U) /*!< Bit position for DDR_PHY_PHY_CON0_CTRL_TWPRE. */
#define BM_DDR_PHY_PHY_CON0_CTRL_TWPRE (0x00000008U) /*!< Bit mask for DDR_PHY_PHY_CON0_CTRL_TWPRE. */
#define BS_DDR_PHY_PHY_CON0_CTRL_TWPRE (1U) /*!< Bit field size in bits for DDR_PHY_PHY_CON0_CTRL_TWPRE. */

/*! @brief Read current value of the DDR_PHY_PHY_CON0_CTRL_TWPRE field. */
#define BR_DDR_PHY_PHY_CON0_CTRL_TWPRE(x) (HW_DDR_PHY_PHY_CON0(x).B.CTRL_TWPRE)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON0_CTRL_TWPRE. */
#define BF_DDR_PHY_PHY_CON0_CTRL_TWPRE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON0_CTRL_TWPRE) & BM_DDR_PHY_PHY_CON0_CTRL_TWPRE)

/*! @brief Set the CTRL_TWPRE field to a new value. */
#define BW_DDR_PHY_PHY_CON0_CTRL_TWPRE(x, v) (HW_DDR_PHY_PHY_CON0_WR(x, (HW_DDR_PHY_PHY_CON0_RD(x) & ~BM_DDR_PHY_PHY_CON0_CTRL_TWPRE) | BF_DDR_PHY_PHY_CON0_CTRL_TWPRE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON0, field CTRL_CMOSRCV[4] (RW)
 *
 * This field controls the input mode of I/O. Initial Value = 1'b0
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON0_CTRL_CMOSRCV (4U) /*!< Bit position for DDR_PHY_PHY_CON0_CTRL_CMOSRCV. */
#define BM_DDR_PHY_PHY_CON0_CTRL_CMOSRCV (0x00000010U) /*!< Bit mask for DDR_PHY_PHY_CON0_CTRL_CMOSRCV. */
#define BS_DDR_PHY_PHY_CON0_CTRL_CMOSRCV (1U) /*!< Bit field size in bits for DDR_PHY_PHY_CON0_CTRL_CMOSRCV. */

/*! @brief Read current value of the DDR_PHY_PHY_CON0_CTRL_CMOSRCV field. */
#define BR_DDR_PHY_PHY_CON0_CTRL_CMOSRCV(x) (HW_DDR_PHY_PHY_CON0(x).B.CTRL_CMOSRCV)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON0_CTRL_CMOSRCV. */
#define BF_DDR_PHY_PHY_CON0_CTRL_CMOSRCV(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON0_CTRL_CMOSRCV) & BM_DDR_PHY_PHY_CON0_CTRL_CMOSRCV)

/*! @brief Set the CTRL_CMOSRCV field to a new value. */
#define BW_DDR_PHY_PHY_CON0_CTRL_CMOSRCV(x, v) (HW_DDR_PHY_PHY_CON0_WR(x, (HW_DDR_PHY_PHY_CON0_RD(x) & ~BM_DDR_PHY_PHY_CON0_CTRL_CMOSRCV) | BF_DDR_PHY_PHY_CON0_CTRL_CMOSRCV(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON0, field CTRL_ATGATE[6] (RW)
 *
 * This bit should be set to 1'b1. Initial Value = 1'b1
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON0_CTRL_ATGATE (6U) /*!< Bit position for DDR_PHY_PHY_CON0_CTRL_ATGATE. */
#define BM_DDR_PHY_PHY_CON0_CTRL_ATGATE (0x00000040U) /*!< Bit mask for DDR_PHY_PHY_CON0_CTRL_ATGATE. */
#define BS_DDR_PHY_PHY_CON0_CTRL_ATGATE (1U) /*!< Bit field size in bits for DDR_PHY_PHY_CON0_CTRL_ATGATE. */

/*! @brief Read current value of the DDR_PHY_PHY_CON0_CTRL_ATGATE field. */
#define BR_DDR_PHY_PHY_CON0_CTRL_ATGATE(x) (HW_DDR_PHY_PHY_CON0(x).B.CTRL_ATGATE)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON0_CTRL_ATGATE. */
#define BF_DDR_PHY_PHY_CON0_CTRL_ATGATE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON0_CTRL_ATGATE) & BM_DDR_PHY_PHY_CON0_CTRL_ATGATE)

/*! @brief Set the CTRL_ATGATE field to a new value. */
#define BW_DDR_PHY_PHY_CON0_CTRL_ATGATE(x, v) (HW_DDR_PHY_PHY_CON0_WR(x, (HW_DDR_PHY_PHY_CON0_RD(x) & ~BM_DDR_PHY_PHY_CON0_CTRL_ATGATE) | BF_DDR_PHY_PHY_CON0_CTRL_ATGATE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON0, field CTRL_SHGATE[8] (RW)
 *
 * This field controls the gate control signal Initial Value = 1'b0
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON0_CTRL_SHGATE (8U) /*!< Bit position for DDR_PHY_PHY_CON0_CTRL_SHGATE. */
#define BM_DDR_PHY_PHY_CON0_CTRL_SHGATE (0x00000100U) /*!< Bit mask for DDR_PHY_PHY_CON0_CTRL_SHGATE. */
#define BS_DDR_PHY_PHY_CON0_CTRL_SHGATE (1U) /*!< Bit field size in bits for DDR_PHY_PHY_CON0_CTRL_SHGATE. */

/*! @brief Read current value of the DDR_PHY_PHY_CON0_CTRL_SHGATE field. */
#define BR_DDR_PHY_PHY_CON0_CTRL_SHGATE(x) (HW_DDR_PHY_PHY_CON0(x).B.CTRL_SHGATE)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON0_CTRL_SHGATE. */
#define BF_DDR_PHY_PHY_CON0_CTRL_SHGATE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON0_CTRL_SHGATE) & BM_DDR_PHY_PHY_CON0_CTRL_SHGATE)

/*! @brief Set the CTRL_SHGATE field to a new value. */
#define BW_DDR_PHY_PHY_CON0_CTRL_SHGATE(x, v) (HW_DDR_PHY_PHY_CON0_WR(x, (HW_DDR_PHY_PHY_CON0_RD(x) & ~BM_DDR_PHY_PHY_CON0_CTRL_SHGATE) | BF_DDR_PHY_PHY_CON0_CTRL_SHGATE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON0, field CTRL_DFDQS[9] (RW)
 *
 * Initial Value = 1'b1
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON0_CTRL_DFDQS (9U) /*!< Bit position for DDR_PHY_PHY_CON0_CTRL_DFDQS. */
#define BM_DDR_PHY_PHY_CON0_CTRL_DFDQS (0x00000200U) /*!< Bit mask for DDR_PHY_PHY_CON0_CTRL_DFDQS. */
#define BS_DDR_PHY_PHY_CON0_CTRL_DFDQS (1U) /*!< Bit field size in bits for DDR_PHY_PHY_CON0_CTRL_DFDQS. */

/*! @brief Read current value of the DDR_PHY_PHY_CON0_CTRL_DFDQS field. */
#define BR_DDR_PHY_PHY_CON0_CTRL_DFDQS(x) (HW_DDR_PHY_PHY_CON0(x).B.CTRL_DFDQS)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON0_CTRL_DFDQS. */
#define BF_DDR_PHY_PHY_CON0_CTRL_DFDQS(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON0_CTRL_DFDQS) & BM_DDR_PHY_PHY_CON0_CTRL_DFDQS)

/*! @brief Set the CTRL_DFDQS field to a new value. */
#define BW_DDR_PHY_PHY_CON0_CTRL_DFDQS(x, v) (HW_DDR_PHY_PHY_CON0_WR(x, (HW_DDR_PHY_PHY_CON0_RD(x) & ~BM_DDR_PHY_PHY_CON0_CTRL_DFDQS) | BF_DDR_PHY_PHY_CON0_CTRL_DFDQS(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON0, field CTRL_DDR_MODE[12:11] (RW)
 *
 * Initial Value = 2'b11
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON0_CTRL_DDR_MODE (11U) /*!< Bit position for DDR_PHY_PHY_CON0_CTRL_DDR_MODE. */
#define BM_DDR_PHY_PHY_CON0_CTRL_DDR_MODE (0x00001800U) /*!< Bit mask for DDR_PHY_PHY_CON0_CTRL_DDR_MODE. */
#define BS_DDR_PHY_PHY_CON0_CTRL_DDR_MODE (2U) /*!< Bit field size in bits for DDR_PHY_PHY_CON0_CTRL_DDR_MODE. */

/*! @brief Read current value of the DDR_PHY_PHY_CON0_CTRL_DDR_MODE field. */
#define BR_DDR_PHY_PHY_CON0_CTRL_DDR_MODE(x) (HW_DDR_PHY_PHY_CON0(x).B.CTRL_DDR_MODE)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON0_CTRL_DDR_MODE. */
#define BF_DDR_PHY_PHY_CON0_CTRL_DDR_MODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON0_CTRL_DDR_MODE) & BM_DDR_PHY_PHY_CON0_CTRL_DDR_MODE)

/*! @brief Set the CTRL_DDR_MODE field to a new value. */
#define BW_DDR_PHY_PHY_CON0_CTRL_DDR_MODE(x, v) (HW_DDR_PHY_PHY_CON0_WR(x, (HW_DDR_PHY_PHY_CON0_RD(x) & ~BM_DDR_PHY_PHY_CON0_CTRL_DDR_MODE) | BF_DDR_PHY_PHY_CON0_CTRL_DDR_MODE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON0, field WRLVL_MODE[16] (RW)
 *
 * Write Leveling Mode Enable Initial Value = 1'b0
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON0_WRLVL_MODE (16U) /*!< Bit position for DDR_PHY_PHY_CON0_WRLVL_MODE. */
#define BM_DDR_PHY_PHY_CON0_WRLVL_MODE (0x00010000U) /*!< Bit mask for DDR_PHY_PHY_CON0_WRLVL_MODE. */
#define BS_DDR_PHY_PHY_CON0_WRLVL_MODE (1U) /*!< Bit field size in bits for DDR_PHY_PHY_CON0_WRLVL_MODE. */

/*! @brief Read current value of the DDR_PHY_PHY_CON0_WRLVL_MODE field. */
#define BR_DDR_PHY_PHY_CON0_WRLVL_MODE(x) (HW_DDR_PHY_PHY_CON0(x).B.WRLVL_MODE)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON0_WRLVL_MODE. */
#define BF_DDR_PHY_PHY_CON0_WRLVL_MODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON0_WRLVL_MODE) & BM_DDR_PHY_PHY_CON0_WRLVL_MODE)

/*! @brief Set the WRLVL_MODE field to a new value. */
#define BW_DDR_PHY_PHY_CON0_WRLVL_MODE(x, v) (HW_DDR_PHY_PHY_CON0_WR(x, (HW_DDR_PHY_PHY_CON0_RD(x) & ~BM_DDR_PHY_PHY_CON0_WRLVL_MODE) | BF_DDR_PHY_PHY_CON0_WRLVL_MODE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON0, field CTRL_UPD_RANGE[21:20] (RW)
 *
 * It decides how many differences between the new lock value and the current
 * lock value which is used in Slave-DLL is needed for updating lock value. Initial
 * Value = 2'b00
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON0_CTRL_UPD_RANGE (20U) /*!< Bit position for DDR_PHY_PHY_CON0_CTRL_UPD_RANGE. */
#define BM_DDR_PHY_PHY_CON0_CTRL_UPD_RANGE (0x00300000U) /*!< Bit mask for DDR_PHY_PHY_CON0_CTRL_UPD_RANGE. */
#define BS_DDR_PHY_PHY_CON0_CTRL_UPD_RANGE (2U) /*!< Bit field size in bits for DDR_PHY_PHY_CON0_CTRL_UPD_RANGE. */

/*! @brief Read current value of the DDR_PHY_PHY_CON0_CTRL_UPD_RANGE field. */
#define BR_DDR_PHY_PHY_CON0_CTRL_UPD_RANGE(x) (HW_DDR_PHY_PHY_CON0(x).B.CTRL_UPD_RANGE)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON0_CTRL_UPD_RANGE. */
#define BF_DDR_PHY_PHY_CON0_CTRL_UPD_RANGE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON0_CTRL_UPD_RANGE) & BM_DDR_PHY_PHY_CON0_CTRL_UPD_RANGE)

/*! @brief Set the CTRL_UPD_RANGE field to a new value. */
#define BW_DDR_PHY_PHY_CON0_CTRL_UPD_RANGE(x, v) (HW_DDR_PHY_PHY_CON0_WR(x, (HW_DDR_PHY_PHY_CON0_RD(x) & ~BM_DDR_PHY_PHY_CON0_CTRL_UPD_RANGE) | BF_DDR_PHY_PHY_CON0_CTRL_UPD_RANGE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON0, field CTRL_UPD_MODE[23:22] (RW)
 *
 * It controls when DLL is updated. Initial Value = 2'b01
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON0_CTRL_UPD_MODE (22U) /*!< Bit position for DDR_PHY_PHY_CON0_CTRL_UPD_MODE. */
#define BM_DDR_PHY_PHY_CON0_CTRL_UPD_MODE (0x00C00000U) /*!< Bit mask for DDR_PHY_PHY_CON0_CTRL_UPD_MODE. */
#define BS_DDR_PHY_PHY_CON0_CTRL_UPD_MODE (2U) /*!< Bit field size in bits for DDR_PHY_PHY_CON0_CTRL_UPD_MODE. */

/*! @brief Read current value of the DDR_PHY_PHY_CON0_CTRL_UPD_MODE field. */
#define BR_DDR_PHY_PHY_CON0_CTRL_UPD_MODE(x) (HW_DDR_PHY_PHY_CON0(x).B.CTRL_UPD_MODE)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON0_CTRL_UPD_MODE. */
#define BF_DDR_PHY_PHY_CON0_CTRL_UPD_MODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON0_CTRL_UPD_MODE) & BM_DDR_PHY_PHY_CON0_CTRL_UPD_MODE)

/*! @brief Set the CTRL_UPD_MODE field to a new value. */
#define BW_DDR_PHY_PHY_CON0_CTRL_UPD_MODE(x, v) (HW_DDR_PHY_PHY_CON0_WR(x, (HW_DDR_PHY_PHY_CON0_RD(x) & ~BM_DDR_PHY_PHY_CON0_CTRL_UPD_MODE) | BF_DDR_PHY_PHY_CON0_CTRL_UPD_MODE(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_PHY_CON1 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_PHY_CON1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * PHY Control Register
 */
typedef union _hw_ddr_phy_phy_con1
{
    uint32_t U;
    struct _hw_ddr_phy_phy_con1_bitfields
    {
        uint32_t RESERVED0 : 20;       /*!< [19:0]  */
        uint32_t ctrl_gateduradj : 4;  /*!< [23:20]  */
        uint32_t RESERVED1 : 4;        /*!< [27:24]  */
        uint32_t CTRL_GATEADJ : 4;     /*!< [31:28]  */
    } B;
} hw_ddr_phy_phy_con1_t;

/*!
 * @name Constants and macros for entire DDR_PHY_PHY_CON1 register
 */
/*@{*/
#define HW_DDR_PHY_PHY_CON1_ADDR(x) ((uintptr_t)(x) + 0x4U)

#define HW_DDR_PHY_PHY_CON1(x)   (*(__IO hw_ddr_phy_phy_con1_t *) HW_DDR_PHY_PHY_CON1_ADDR(x))
#define HW_DDR_PHY_PHY_CON1_RD(x) (HW_DDR_PHY_PHY_CON1(x).U)
#define HW_DDR_PHY_PHY_CON1_WR(x, v) (HW_DDR_PHY_PHY_CON1(x).U = (v))
#define HW_DDR_PHY_PHY_CON1_SET(x, v) (HW_DDR_PHY_PHY_CON1_WR(x, HW_DDR_PHY_PHY_CON1_RD(x) |  (v)))
#define HW_DDR_PHY_PHY_CON1_CLR(x, v) (HW_DDR_PHY_PHY_CON1_WR(x, HW_DDR_PHY_PHY_CON1_RD(x) & ~(v)))
#define HW_DDR_PHY_PHY_CON1_TOG(x, v) (HW_DDR_PHY_PHY_CON1_WR(x, HW_DDR_PHY_PHY_CON1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_PHY_CON1 bitfields
 */

/*!
 * @name Register DDR_PHY_PHY_CON1, field ctrl_gateduradj[23:20] (RW)
 *
 * It adjusts the duration cycle of "ctrl_gate" on a clock cycle base. MSB
 * (bit3) controls direction: 1'b1 (subtract delay), 1'b0 (add delay), Bit[2:0] set
 * delay value. Initial Value = 4'h2
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON1_ctrl_gateduradj (20U) /*!< Bit position for DDR_PHY_PHY_CON1_ctrl_gateduradj. */
#define BM_DDR_PHY_PHY_CON1_ctrl_gateduradj (0x00F00000U) /*!< Bit mask for DDR_PHY_PHY_CON1_ctrl_gateduradj. */
#define BS_DDR_PHY_PHY_CON1_ctrl_gateduradj (4U) /*!< Bit field size in bits for DDR_PHY_PHY_CON1_ctrl_gateduradj. */

/*! @brief Read current value of the DDR_PHY_PHY_CON1_ctrl_gateduradj field. */
#define BR_DDR_PHY_PHY_CON1_ctrl_gateduradj(x) (HW_DDR_PHY_PHY_CON1(x).B.ctrl_gateduradj)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON1_ctrl_gateduradj. */
#define BF_DDR_PHY_PHY_CON1_ctrl_gateduradj(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON1_ctrl_gateduradj) & BM_DDR_PHY_PHY_CON1_ctrl_gateduradj)

/*! @brief Set the ctrl_gateduradj field to a new value. */
#define BW_DDR_PHY_PHY_CON1_ctrl_gateduradj(x, v) (HW_DDR_PHY_PHY_CON1_WR(x, (HW_DDR_PHY_PHY_CON1_RD(x) & ~BM_DDR_PHY_PHY_CON1_ctrl_gateduradj) | BF_DDR_PHY_PHY_CON1_ctrl_gateduradj(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON1, field CTRL_GATEADJ[31:28] (RW)
 *
 * It adjusts the enable time of "ctrl_gate" on a clock cycle base. MSB (bit3)
 * controls direction: 1'b1 (subtract delay), 1'b0 (add delay), Bit[2:0] set delay
 * value. Initial Value = 4'h2
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON1_CTRL_GATEADJ (28U) /*!< Bit position for DDR_PHY_PHY_CON1_CTRL_GATEADJ. */
#define BM_DDR_PHY_PHY_CON1_CTRL_GATEADJ (0xF0000000U) /*!< Bit mask for DDR_PHY_PHY_CON1_CTRL_GATEADJ. */
#define BS_DDR_PHY_PHY_CON1_CTRL_GATEADJ (4U) /*!< Bit field size in bits for DDR_PHY_PHY_CON1_CTRL_GATEADJ. */

/*! @brief Read current value of the DDR_PHY_PHY_CON1_CTRL_GATEADJ field. */
#define BR_DDR_PHY_PHY_CON1_CTRL_GATEADJ(x) (HW_DDR_PHY_PHY_CON1(x).B.CTRL_GATEADJ)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON1_CTRL_GATEADJ. */
#define BF_DDR_PHY_PHY_CON1_CTRL_GATEADJ(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON1_CTRL_GATEADJ) & BM_DDR_PHY_PHY_CON1_CTRL_GATEADJ)

/*! @brief Set the CTRL_GATEADJ field to a new value. */
#define BW_DDR_PHY_PHY_CON1_CTRL_GATEADJ(x, v) (HW_DDR_PHY_PHY_CON1_WR(x, (HW_DDR_PHY_PHY_CON1_RD(x) & ~BM_DDR_PHY_PHY_CON1_CTRL_GATEADJ) | BF_DDR_PHY_PHY_CON1_CTRL_GATEADJ(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_PHY_CON2 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_PHY_CON2 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * PHY Control Register
 */
typedef union _hw_ddr_phy_phy_con2
{
    uint32_t U;
    struct _hw_ddr_phy_phy_con2_bitfields
    {
        uint32_t RESERVED0 : 13;       /*!< [12:0]  */
        uint32_t RDDESKEW_CLEAR : 1;   /*!< [13]  */
        uint32_t WRDESKEW_CLEAR : 1;   /*!< [14]  */
        uint32_t RESERVED1 : 8;        /*!< [22:15]  */
        uint32_t CA_CAL_MODE : 1;      /*!< [23]  */
        uint32_t GATE_CAL_MODE : 1;    /*!< [24]  */
        uint32_t RESERVED2 : 7;        /*!< [31:25]  */
    } B;
} hw_ddr_phy_phy_con2_t;

/*!
 * @name Constants and macros for entire DDR_PHY_PHY_CON2 register
 */
/*@{*/
#define HW_DDR_PHY_PHY_CON2_ADDR(x) ((uintptr_t)(x) + 0x8U)

#define HW_DDR_PHY_PHY_CON2(x)   (*(__IO hw_ddr_phy_phy_con2_t *) HW_DDR_PHY_PHY_CON2_ADDR(x))
#define HW_DDR_PHY_PHY_CON2_RD(x) (HW_DDR_PHY_PHY_CON2(x).U)
#define HW_DDR_PHY_PHY_CON2_WR(x, v) (HW_DDR_PHY_PHY_CON2(x).U = (v))
#define HW_DDR_PHY_PHY_CON2_SET(x, v) (HW_DDR_PHY_PHY_CON2_WR(x, HW_DDR_PHY_PHY_CON2_RD(x) |  (v)))
#define HW_DDR_PHY_PHY_CON2_CLR(x, v) (HW_DDR_PHY_PHY_CON2_WR(x, HW_DDR_PHY_PHY_CON2_RD(x) & ~(v)))
#define HW_DDR_PHY_PHY_CON2_TOG(x, v) (HW_DDR_PHY_PHY_CON2_WR(x, HW_DDR_PHY_PHY_CON2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_PHY_CON2 bitfields
 */

/*!
 * @name Register DDR_PHY_PHY_CON2, field RDDESKEW_CLEAR[13] (RW)
 *
 * Clear "ctrl_offsetr*" to RdDeSkewCode Initial Value = 1'b0
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON2_RDDESKEW_CLEAR (13U) /*!< Bit position for DDR_PHY_PHY_CON2_RDDESKEW_CLEAR. */
#define BM_DDR_PHY_PHY_CON2_RDDESKEW_CLEAR (0x00002000U) /*!< Bit mask for DDR_PHY_PHY_CON2_RDDESKEW_CLEAR. */
#define BS_DDR_PHY_PHY_CON2_RDDESKEW_CLEAR (1U) /*!< Bit field size in bits for DDR_PHY_PHY_CON2_RDDESKEW_CLEAR. */

/*! @brief Read current value of the DDR_PHY_PHY_CON2_RDDESKEW_CLEAR field. */
#define BR_DDR_PHY_PHY_CON2_RDDESKEW_CLEAR(x) (HW_DDR_PHY_PHY_CON2(x).B.RDDESKEW_CLEAR)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON2_RDDESKEW_CLEAR. */
#define BF_DDR_PHY_PHY_CON2_RDDESKEW_CLEAR(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON2_RDDESKEW_CLEAR) & BM_DDR_PHY_PHY_CON2_RDDESKEW_CLEAR)

/*! @brief Set the RDDESKEW_CLEAR field to a new value. */
#define BW_DDR_PHY_PHY_CON2_RDDESKEW_CLEAR(x, v) (HW_DDR_PHY_PHY_CON2_WR(x, (HW_DDR_PHY_PHY_CON2_RD(x) & ~BM_DDR_PHY_PHY_CON2_RDDESKEW_CLEAR) | BF_DDR_PHY_PHY_CON2_RDDESKEW_CLEAR(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON2, field WRDESKEW_CLEAR[14] (RW)
 *
 * Write "ctrl_offsetw*" toWrDeSkewCode Initial Value = 1'b0
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON2_WRDESKEW_CLEAR (14U) /*!< Bit position for DDR_PHY_PHY_CON2_WRDESKEW_CLEAR. */
#define BM_DDR_PHY_PHY_CON2_WRDESKEW_CLEAR (0x00004000U) /*!< Bit mask for DDR_PHY_PHY_CON2_WRDESKEW_CLEAR. */
#define BS_DDR_PHY_PHY_CON2_WRDESKEW_CLEAR (1U) /*!< Bit field size in bits for DDR_PHY_PHY_CON2_WRDESKEW_CLEAR. */

/*! @brief Read current value of the DDR_PHY_PHY_CON2_WRDESKEW_CLEAR field. */
#define BR_DDR_PHY_PHY_CON2_WRDESKEW_CLEAR(x) (HW_DDR_PHY_PHY_CON2(x).B.WRDESKEW_CLEAR)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON2_WRDESKEW_CLEAR. */
#define BF_DDR_PHY_PHY_CON2_WRDESKEW_CLEAR(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON2_WRDESKEW_CLEAR) & BM_DDR_PHY_PHY_CON2_WRDESKEW_CLEAR)

/*! @brief Set the WRDESKEW_CLEAR field to a new value. */
#define BW_DDR_PHY_PHY_CON2_WRDESKEW_CLEAR(x, v) (HW_DDR_PHY_PHY_CON2_WR(x, (HW_DDR_PHY_PHY_CON2_RD(x) & ~BM_DDR_PHY_PHY_CON2_WRDESKEW_CLEAR) | BF_DDR_PHY_PHY_CON2_WRDESKEW_CLEAR(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON2, field CA_CAL_MODE[23] (RW)
 *
 * Not used Initial Value = 1'b0
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON2_CA_CAL_MODE (23U) /*!< Bit position for DDR_PHY_PHY_CON2_CA_CAL_MODE. */
#define BM_DDR_PHY_PHY_CON2_CA_CAL_MODE (0x00800000U) /*!< Bit mask for DDR_PHY_PHY_CON2_CA_CAL_MODE. */
#define BS_DDR_PHY_PHY_CON2_CA_CAL_MODE (1U) /*!< Bit field size in bits for DDR_PHY_PHY_CON2_CA_CAL_MODE. */

/*! @brief Read current value of the DDR_PHY_PHY_CON2_CA_CAL_MODE field. */
#define BR_DDR_PHY_PHY_CON2_CA_CAL_MODE(x) (HW_DDR_PHY_PHY_CON2(x).B.CA_CAL_MODE)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON2_CA_CAL_MODE. */
#define BF_DDR_PHY_PHY_CON2_CA_CAL_MODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON2_CA_CAL_MODE) & BM_DDR_PHY_PHY_CON2_CA_CAL_MODE)

/*! @brief Set the CA_CAL_MODE field to a new value. */
#define BW_DDR_PHY_PHY_CON2_CA_CAL_MODE(x, v) (HW_DDR_PHY_PHY_CON2_WR(x, (HW_DDR_PHY_PHY_CON2_RD(x) & ~BM_DDR_PHY_PHY_CON2_CA_CAL_MODE) | BF_DDR_PHY_PHY_CON2_CA_CAL_MODE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON2, field GATE_CAL_MODE[24] (RW)
 *
 * When gate_cal_mode = 1, Gate leveling offset value will be used instead of
 * ctrl_shiftc*. If gate leveling is used, this value should be high during
 * operation. Initial Value = 1'b0
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON2_GATE_CAL_MODE (24U) /*!< Bit position for DDR_PHY_PHY_CON2_GATE_CAL_MODE. */
#define BM_DDR_PHY_PHY_CON2_GATE_CAL_MODE (0x01000000U) /*!< Bit mask for DDR_PHY_PHY_CON2_GATE_CAL_MODE. */
#define BS_DDR_PHY_PHY_CON2_GATE_CAL_MODE (1U) /*!< Bit field size in bits for DDR_PHY_PHY_CON2_GATE_CAL_MODE. */

/*! @brief Read current value of the DDR_PHY_PHY_CON2_GATE_CAL_MODE field. */
#define BR_DDR_PHY_PHY_CON2_GATE_CAL_MODE(x) (HW_DDR_PHY_PHY_CON2(x).B.GATE_CAL_MODE)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON2_GATE_CAL_MODE. */
#define BF_DDR_PHY_PHY_CON2_GATE_CAL_MODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON2_GATE_CAL_MODE) & BM_DDR_PHY_PHY_CON2_GATE_CAL_MODE)

/*! @brief Set the GATE_CAL_MODE field to a new value. */
#define BW_DDR_PHY_PHY_CON2_GATE_CAL_MODE(x, v) (HW_DDR_PHY_PHY_CON2_WR(x, (HW_DDR_PHY_PHY_CON2_RD(x) & ~BM_DDR_PHY_PHY_CON2_GATE_CAL_MODE) | BF_DDR_PHY_PHY_CON2_GATE_CAL_MODE(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_PHY_CON3 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_PHY_CON3 -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_phy_con3
{
    uint32_t U;
    struct _hw_ddr_phy_phy_con3_bitfields
    {
        uint32_t REG_MODE : 8;         /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t WRLVL_START : 1;      /*!< [16]  */
        uint32_t RESERVED1 : 3;        /*!< [19:17]  */
        uint32_t WL_CAL_MODE : 1;      /*!< [20]  */
        uint32_t WL_CAL_START : 1;     /*!< [21]  */
        uint32_t RESERVED2 : 2;        /*!< [23:22]  */
        uint32_t WRLVL_RESP : 1;       /*!< [24]  */
        uint32_t RESERVED3 : 2;        /*!< [26:25]  */
        uint32_t WL_CAL_RESP : 1;      /*!< [27]  */
        uint32_t RESERVED4 : 4;        /*!< [31:28]  */
    } B;
} hw_ddr_phy_phy_con3_t;

/*!
 * @name Constants and macros for entire DDR_PHY_PHY_CON3 register
 */
/*@{*/
#define HW_DDR_PHY_PHY_CON3_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_DDR_PHY_PHY_CON3(x)   (*(__IO hw_ddr_phy_phy_con3_t *) HW_DDR_PHY_PHY_CON3_ADDR(x))
#define HW_DDR_PHY_PHY_CON3_RD(x) (HW_DDR_PHY_PHY_CON3(x).U)
#define HW_DDR_PHY_PHY_CON3_WR(x, v) (HW_DDR_PHY_PHY_CON3(x).U = (v))
#define HW_DDR_PHY_PHY_CON3_SET(x, v) (HW_DDR_PHY_PHY_CON3_WR(x, HW_DDR_PHY_PHY_CON3_RD(x) |  (v)))
#define HW_DDR_PHY_PHY_CON3_CLR(x, v) (HW_DDR_PHY_PHY_CON3_WR(x, HW_DDR_PHY_PHY_CON3_RD(x) & ~(v)))
#define HW_DDR_PHY_PHY_CON3_TOG(x, v) (HW_DDR_PHY_PHY_CON3_WR(x, HW_DDR_PHY_PHY_CON3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_PHY_CON3 bitfields
 */

/*!
 * @name Register DDR_PHY_PHY_CON3, field REG_MODE[7:0] (RW)
 *
 * Register mode control to write the information at each data Initial Value =
 * 0x0
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON3_REG_MODE (0U)  /*!< Bit position for DDR_PHY_PHY_CON3_REG_MODE. */
#define BM_DDR_PHY_PHY_CON3_REG_MODE (0x000000FFU) /*!< Bit mask for DDR_PHY_PHY_CON3_REG_MODE. */
#define BS_DDR_PHY_PHY_CON3_REG_MODE (8U)  /*!< Bit field size in bits for DDR_PHY_PHY_CON3_REG_MODE. */

/*! @brief Read current value of the DDR_PHY_PHY_CON3_REG_MODE field. */
#define BR_DDR_PHY_PHY_CON3_REG_MODE(x) (HW_DDR_PHY_PHY_CON3(x).B.REG_MODE)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON3_REG_MODE. */
#define BF_DDR_PHY_PHY_CON3_REG_MODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON3_REG_MODE) & BM_DDR_PHY_PHY_CON3_REG_MODE)

/*! @brief Set the REG_MODE field to a new value. */
#define BW_DDR_PHY_PHY_CON3_REG_MODE(x, v) (HW_DDR_PHY_PHY_CON3_WR(x, (HW_DDR_PHY_PHY_CON3_RD(x) & ~BM_DDR_PHY_PHY_CON3_REG_MODE) | BF_DDR_PHY_PHY_CON3_REG_MODE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON3, field WRLVL_START[16] (RW)
 *
 * Start Write Leveling signal. It can be enabled when wrlvl_mode = 1. It should
 * be disabled after Write Leveling Response is asserted. Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON3_WRLVL_START (16U) /*!< Bit position for DDR_PHY_PHY_CON3_WRLVL_START. */
#define BM_DDR_PHY_PHY_CON3_WRLVL_START (0x00010000U) /*!< Bit mask for DDR_PHY_PHY_CON3_WRLVL_START. */
#define BS_DDR_PHY_PHY_CON3_WRLVL_START (1U) /*!< Bit field size in bits for DDR_PHY_PHY_CON3_WRLVL_START. */

/*! @brief Read current value of the DDR_PHY_PHY_CON3_WRLVL_START field. */
#define BR_DDR_PHY_PHY_CON3_WRLVL_START(x) (HW_DDR_PHY_PHY_CON3(x).B.WRLVL_START)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON3_WRLVL_START. */
#define BF_DDR_PHY_PHY_CON3_WRLVL_START(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON3_WRLVL_START) & BM_DDR_PHY_PHY_CON3_WRLVL_START)

/*! @brief Set the WRLVL_START field to a new value. */
#define BW_DDR_PHY_PHY_CON3_WRLVL_START(x, v) (HW_DDR_PHY_PHY_CON3_WR(x, (HW_DDR_PHY_PHY_CON3_RD(x) & ~BM_DDR_PHY_PHY_CON3_WRLVL_START) | BF_DDR_PHY_PHY_CON3_WRLVL_START(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON3, field WL_CAL_MODE[20] (RW)
 *
 * Write Leveling Calibration mode Enable Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON3_WL_CAL_MODE (20U) /*!< Bit position for DDR_PHY_PHY_CON3_WL_CAL_MODE. */
#define BM_DDR_PHY_PHY_CON3_WL_CAL_MODE (0x00100000U) /*!< Bit mask for DDR_PHY_PHY_CON3_WL_CAL_MODE. */
#define BS_DDR_PHY_PHY_CON3_WL_CAL_MODE (1U) /*!< Bit field size in bits for DDR_PHY_PHY_CON3_WL_CAL_MODE. */

/*! @brief Read current value of the DDR_PHY_PHY_CON3_WL_CAL_MODE field. */
#define BR_DDR_PHY_PHY_CON3_WL_CAL_MODE(x) (HW_DDR_PHY_PHY_CON3(x).B.WL_CAL_MODE)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON3_WL_CAL_MODE. */
#define BF_DDR_PHY_PHY_CON3_WL_CAL_MODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON3_WL_CAL_MODE) & BM_DDR_PHY_PHY_CON3_WL_CAL_MODE)

/*! @brief Set the WL_CAL_MODE field to a new value. */
#define BW_DDR_PHY_PHY_CON3_WL_CAL_MODE(x, v) (HW_DDR_PHY_PHY_CON3_WR(x, (HW_DDR_PHY_PHY_CON3_RD(x) & ~BM_DDR_PHY_PHY_CON3_WL_CAL_MODE) | BF_DDR_PHY_PHY_CON3_WL_CAL_MODE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON3, field WL_CAL_START[21] (RW)
 *
 * Start Write Leveling Calibration Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON3_WL_CAL_START (21U) /*!< Bit position for DDR_PHY_PHY_CON3_WL_CAL_START. */
#define BM_DDR_PHY_PHY_CON3_WL_CAL_START (0x00200000U) /*!< Bit mask for DDR_PHY_PHY_CON3_WL_CAL_START. */
#define BS_DDR_PHY_PHY_CON3_WL_CAL_START (1U) /*!< Bit field size in bits for DDR_PHY_PHY_CON3_WL_CAL_START. */

/*! @brief Read current value of the DDR_PHY_PHY_CON3_WL_CAL_START field. */
#define BR_DDR_PHY_PHY_CON3_WL_CAL_START(x) (HW_DDR_PHY_PHY_CON3(x).B.WL_CAL_START)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON3_WL_CAL_START. */
#define BF_DDR_PHY_PHY_CON3_WL_CAL_START(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON3_WL_CAL_START) & BM_DDR_PHY_PHY_CON3_WL_CAL_START)

/*! @brief Set the WL_CAL_START field to a new value. */
#define BW_DDR_PHY_PHY_CON3_WL_CAL_START(x, v) (HW_DDR_PHY_PHY_CON3_WR(x, (HW_DDR_PHY_PHY_CON3_RD(x) & ~BM_DDR_PHY_PHY_CON3_WL_CAL_START) | BF_DDR_PHY_PHY_CON3_WL_CAL_START(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON3, field WRLVL_RESP[24] (RW)
 *
 * Response after Write Leveling Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON3_WRLVL_RESP (24U) /*!< Bit position for DDR_PHY_PHY_CON3_WRLVL_RESP. */
#define BM_DDR_PHY_PHY_CON3_WRLVL_RESP (0x01000000U) /*!< Bit mask for DDR_PHY_PHY_CON3_WRLVL_RESP. */
#define BS_DDR_PHY_PHY_CON3_WRLVL_RESP (1U) /*!< Bit field size in bits for DDR_PHY_PHY_CON3_WRLVL_RESP. */

/*! @brief Read current value of the DDR_PHY_PHY_CON3_WRLVL_RESP field. */
#define BR_DDR_PHY_PHY_CON3_WRLVL_RESP(x) (HW_DDR_PHY_PHY_CON3(x).B.WRLVL_RESP)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON3_WRLVL_RESP. */
#define BF_DDR_PHY_PHY_CON3_WRLVL_RESP(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON3_WRLVL_RESP) & BM_DDR_PHY_PHY_CON3_WRLVL_RESP)

/*! @brief Set the WRLVL_RESP field to a new value. */
#define BW_DDR_PHY_PHY_CON3_WRLVL_RESP(x, v) (HW_DDR_PHY_PHY_CON3_WR(x, (HW_DDR_PHY_PHY_CON3_RD(x) & ~BM_DDR_PHY_PHY_CON3_WRLVL_RESP) | BF_DDR_PHY_PHY_CON3_WRLVL_RESP(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON3, field WL_CAL_RESP[27] (RW)
 *
 * Response after Write Leveling Calibration Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON3_WL_CAL_RESP (27U) /*!< Bit position for DDR_PHY_PHY_CON3_WL_CAL_RESP. */
#define BM_DDR_PHY_PHY_CON3_WL_CAL_RESP (0x08000000U) /*!< Bit mask for DDR_PHY_PHY_CON3_WL_CAL_RESP. */
#define BS_DDR_PHY_PHY_CON3_WL_CAL_RESP (1U) /*!< Bit field size in bits for DDR_PHY_PHY_CON3_WL_CAL_RESP. */

/*! @brief Read current value of the DDR_PHY_PHY_CON3_WL_CAL_RESP field. */
#define BR_DDR_PHY_PHY_CON3_WL_CAL_RESP(x) (HW_DDR_PHY_PHY_CON3(x).B.WL_CAL_RESP)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON3_WL_CAL_RESP. */
#define BF_DDR_PHY_PHY_CON3_WL_CAL_RESP(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON3_WL_CAL_RESP) & BM_DDR_PHY_PHY_CON3_WL_CAL_RESP)

/*! @brief Set the WL_CAL_RESP field to a new value. */
#define BW_DDR_PHY_PHY_CON3_WL_CAL_RESP(x, v) (HW_DDR_PHY_PHY_CON3_WR(x, (HW_DDR_PHY_PHY_CON3_RD(x) & ~BM_DDR_PHY_PHY_CON3_WL_CAL_RESP) | BF_DDR_PHY_PHY_CON3_WL_CAL_RESP(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_PHY_CON4 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_PHY_CON4 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * PHY Control Register
 */
typedef union _hw_ddr_phy_phy_con4
{
    uint32_t U;
    struct _hw_ddr_phy_phy_con4_bitfields
    {
        uint32_t CTRL_RDLAT : 5;       /*!< [4:0]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t CTRL_BSTLEN : 5;      /*!< [12:8]  */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t CTRL_WRLAT : 5;       /*!< [20:16]  */
        uint32_t RESERVED2 : 11;       /*!< [31:21]  */
    } B;
} hw_ddr_phy_phy_con4_t;

/*!
 * @name Constants and macros for entire DDR_PHY_PHY_CON4 register
 */
/*@{*/
#define HW_DDR_PHY_PHY_CON4_ADDR(x) ((uintptr_t)(x) + 0x10U)

#define HW_DDR_PHY_PHY_CON4(x)   (*(__IO hw_ddr_phy_phy_con4_t *) HW_DDR_PHY_PHY_CON4_ADDR(x))
#define HW_DDR_PHY_PHY_CON4_RD(x) (HW_DDR_PHY_PHY_CON4(x).U)
#define HW_DDR_PHY_PHY_CON4_WR(x, v) (HW_DDR_PHY_PHY_CON4(x).U = (v))
#define HW_DDR_PHY_PHY_CON4_SET(x, v) (HW_DDR_PHY_PHY_CON4_WR(x, HW_DDR_PHY_PHY_CON4_RD(x) |  (v)))
#define HW_DDR_PHY_PHY_CON4_CLR(x, v) (HW_DDR_PHY_PHY_CON4_WR(x, HW_DDR_PHY_PHY_CON4_RD(x) & ~(v)))
#define HW_DDR_PHY_PHY_CON4_TOG(x, v) (HW_DDR_PHY_PHY_CON4_WR(x, HW_DDR_PHY_PHY_CON4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_PHY_CON4 bitfields
 */

/*!
 * @name Register DDR_PHY_PHY_CON4, field CTRL_RDLAT[4:0] (RW)
 *
 * Read Latency (RL) Initial Value = 5'h0
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON4_CTRL_RDLAT (0U) /*!< Bit position for DDR_PHY_PHY_CON4_CTRL_RDLAT. */
#define BM_DDR_PHY_PHY_CON4_CTRL_RDLAT (0x0000001FU) /*!< Bit mask for DDR_PHY_PHY_CON4_CTRL_RDLAT. */
#define BS_DDR_PHY_PHY_CON4_CTRL_RDLAT (5U) /*!< Bit field size in bits for DDR_PHY_PHY_CON4_CTRL_RDLAT. */

/*! @brief Read current value of the DDR_PHY_PHY_CON4_CTRL_RDLAT field. */
#define BR_DDR_PHY_PHY_CON4_CTRL_RDLAT(x) (HW_DDR_PHY_PHY_CON4(x).B.CTRL_RDLAT)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON4_CTRL_RDLAT. */
#define BF_DDR_PHY_PHY_CON4_CTRL_RDLAT(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON4_CTRL_RDLAT) & BM_DDR_PHY_PHY_CON4_CTRL_RDLAT)

/*! @brief Set the CTRL_RDLAT field to a new value. */
#define BW_DDR_PHY_PHY_CON4_CTRL_RDLAT(x, v) (HW_DDR_PHY_PHY_CON4_WR(x, (HW_DDR_PHY_PHY_CON4_RD(x) & ~BM_DDR_PHY_PHY_CON4_CTRL_RDLAT) | BF_DDR_PHY_PHY_CON4_CTRL_RDLAT(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON4, field CTRL_BSTLEN[12:8] (RW)
 *
 * Burst Length (BL) Initial Value = 5'h0
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON4_CTRL_BSTLEN (8U) /*!< Bit position for DDR_PHY_PHY_CON4_CTRL_BSTLEN. */
#define BM_DDR_PHY_PHY_CON4_CTRL_BSTLEN (0x00001F00U) /*!< Bit mask for DDR_PHY_PHY_CON4_CTRL_BSTLEN. */
#define BS_DDR_PHY_PHY_CON4_CTRL_BSTLEN (5U) /*!< Bit field size in bits for DDR_PHY_PHY_CON4_CTRL_BSTLEN. */

/*! @brief Read current value of the DDR_PHY_PHY_CON4_CTRL_BSTLEN field. */
#define BR_DDR_PHY_PHY_CON4_CTRL_BSTLEN(x) (HW_DDR_PHY_PHY_CON4(x).B.CTRL_BSTLEN)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON4_CTRL_BSTLEN. */
#define BF_DDR_PHY_PHY_CON4_CTRL_BSTLEN(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON4_CTRL_BSTLEN) & BM_DDR_PHY_PHY_CON4_CTRL_BSTLEN)

/*! @brief Set the CTRL_BSTLEN field to a new value. */
#define BW_DDR_PHY_PHY_CON4_CTRL_BSTLEN(x, v) (HW_DDR_PHY_PHY_CON4_WR(x, (HW_DDR_PHY_PHY_CON4_RD(x) & ~BM_DDR_PHY_PHY_CON4_CTRL_BSTLEN) | BF_DDR_PHY_PHY_CON4_CTRL_BSTLEN(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON4, field CTRL_WRLAT[20:16] (RW)
 *
 * Clock cycles between write command and the first edge of DQS which can
 * capture the first valid DQ. For example, if WL is 6, It should be set as 7(= WL + 1)
 * in LPDDR3, 6(= WL) in DDR3. Initial Value = 5'h8
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON4_CTRL_WRLAT (16U) /*!< Bit position for DDR_PHY_PHY_CON4_CTRL_WRLAT. */
#define BM_DDR_PHY_PHY_CON4_CTRL_WRLAT (0x001F0000U) /*!< Bit mask for DDR_PHY_PHY_CON4_CTRL_WRLAT. */
#define BS_DDR_PHY_PHY_CON4_CTRL_WRLAT (5U) /*!< Bit field size in bits for DDR_PHY_PHY_CON4_CTRL_WRLAT. */

/*! @brief Read current value of the DDR_PHY_PHY_CON4_CTRL_WRLAT field. */
#define BR_DDR_PHY_PHY_CON4_CTRL_WRLAT(x) (HW_DDR_PHY_PHY_CON4(x).B.CTRL_WRLAT)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON4_CTRL_WRLAT. */
#define BF_DDR_PHY_PHY_CON4_CTRL_WRLAT(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON4_CTRL_WRLAT) & BM_DDR_PHY_PHY_CON4_CTRL_WRLAT)

/*! @brief Set the CTRL_WRLAT field to a new value. */
#define BW_DDR_PHY_PHY_CON4_CTRL_WRLAT(x, v) (HW_DDR_PHY_PHY_CON4_WR(x, (HW_DDR_PHY_PHY_CON4_RD(x) & ~BM_DDR_PHY_PHY_CON4_CTRL_WRLAT) | BF_DDR_PHY_PHY_CON4_CTRL_WRLAT(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_PHY_CON5 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_PHY_CON5 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * When "wl_cal_mode" = 1'b1, "PHY_CON5" will show the results of HW Write
 * Latency Calibration. Please do not change "PHY_CON5" during "wl_cal_mode" = 1'b1.
 */
typedef union _hw_ddr_phy_phy_con5
{
    uint32_t U;
    struct _hw_ddr_phy_phy_con5_bitfields
    {
        uint32_t CTRL_WRLAT_PLUS1_0 : 3; /*!< [2:0]  */
        uint32_t CTRL_WRLAT_PLUS1_1 : 3; /*!< [5:3]  */
        uint32_t CTRL_WRLAT_PLUS2 : 3; /*!< [8:6]  */
        uint32_t CTRL_WRLAT_PLUS3 : 3; /*!< [11:9]  */
        uint32_t RESERVED0 : 20;       /*!< [31:12]  */
    } B;
} hw_ddr_phy_phy_con5_t;

/*!
 * @name Constants and macros for entire DDR_PHY_PHY_CON5 register
 */
/*@{*/
#define HW_DDR_PHY_PHY_CON5_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_DDR_PHY_PHY_CON5(x)   (*(__IO hw_ddr_phy_phy_con5_t *) HW_DDR_PHY_PHY_CON5_ADDR(x))
#define HW_DDR_PHY_PHY_CON5_RD(x) (HW_DDR_PHY_PHY_CON5(x).U)
#define HW_DDR_PHY_PHY_CON5_WR(x, v) (HW_DDR_PHY_PHY_CON5(x).U = (v))
#define HW_DDR_PHY_PHY_CON5_SET(x, v) (HW_DDR_PHY_PHY_CON5_WR(x, HW_DDR_PHY_PHY_CON5_RD(x) |  (v)))
#define HW_DDR_PHY_PHY_CON5_CLR(x, v) (HW_DDR_PHY_PHY_CON5_WR(x, HW_DDR_PHY_PHY_CON5_RD(x) & ~(v)))
#define HW_DDR_PHY_PHY_CON5_TOG(x, v) (HW_DDR_PHY_PHY_CON5_WR(x, HW_DDR_PHY_PHY_CON5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_PHY_CON5 bitfields
 */

/*!
 * @name Register DDR_PHY_PHY_CON5, field CTRL_WRLAT_PLUS1_0[2:0] (RW)
 *
 * This field can control Write Latency (WL) by half cycle, one or two cycles
 * for Data_Slice0. Initial Value = 3'h0
 *
 * Values:
 * - 0 - Write Latency Increases by half clock cycle when enabled.
 * - 1 - Write Latency Increases by one clock cycle when enabled.
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0 (0U) /*!< Bit position for DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0. */
#define BM_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0 (0x00000007U) /*!< Bit mask for DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0. */
#define BS_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0 (3U) /*!< Bit field size in bits for DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0. */

/*! @brief Read current value of the DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0 field. */
#define BR_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0(x) (HW_DDR_PHY_PHY_CON5(x).B.CTRL_WRLAT_PLUS1_0)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0. */
#define BF_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0) & BM_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0)

/*! @brief Set the CTRL_WRLAT_PLUS1_0 field to a new value. */
#define BW_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0(x, v) (HW_DDR_PHY_PHY_CON5_WR(x, (HW_DDR_PHY_PHY_CON5_RD(x) & ~BM_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0) | BF_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_0(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON5, field CTRL_WRLAT_PLUS1_1[5:3] (RW)
 *
 * This field can control Write Latency (WL) by half cycle, one or two cycles
 * for Data_Slice1. Initial Value = 3'h0
 *
 * Values:
 * - 0 - Write Latency Increases by half clock cycle when enabled.
 * - 1 - Write Latency Increases by one clock cycle when enabled.
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1 (3U) /*!< Bit position for DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1. */
#define BM_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1 (0x00000038U) /*!< Bit mask for DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1. */
#define BS_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1 (3U) /*!< Bit field size in bits for DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1. */

/*! @brief Read current value of the DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1 field. */
#define BR_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1(x) (HW_DDR_PHY_PHY_CON5(x).B.CTRL_WRLAT_PLUS1_1)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1. */
#define BF_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1) & BM_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1)

/*! @brief Set the CTRL_WRLAT_PLUS1_1 field to a new value. */
#define BW_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1(x, v) (HW_DDR_PHY_PHY_CON5_WR(x, (HW_DDR_PHY_PHY_CON5_RD(x) & ~BM_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1) | BF_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS1_1(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON5, field CTRL_WRLAT_PLUS2[8:6] (RW)
 *
 * This field can control Write Latency (WL) by half cycle, one or two cycles
 * for Data_Slice2. Initial Value = 3'h0
 *
 * Values:
 * - 0 - Write Latency Increases by half clock cycle when enabled.
 * - 1 - Write Latency Increases by one clock cycle when enabled.
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2 (6U) /*!< Bit position for DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2. */
#define BM_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2 (0x000001C0U) /*!< Bit mask for DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2. */
#define BS_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2 (3U) /*!< Bit field size in bits for DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2. */

/*! @brief Read current value of the DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2 field. */
#define BR_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2(x) (HW_DDR_PHY_PHY_CON5(x).B.CTRL_WRLAT_PLUS2)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2. */
#define BF_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2) & BM_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2)

/*! @brief Set the CTRL_WRLAT_PLUS2 field to a new value. */
#define BW_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2(x, v) (HW_DDR_PHY_PHY_CON5_WR(x, (HW_DDR_PHY_PHY_CON5_RD(x) & ~BM_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2) | BF_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS2(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_PHY_CON5, field CTRL_WRLAT_PLUS3[11:9] (RW)
 *
 * This field can control Write Latency (WL) by half cycle, one or two cycles
 * for Data_Slice3. Initial Value = 3'h0
 *
 * Values:
 * - 0 - Write Latency Increases by half clock cycle when enabled.
 * - 1 - Write Latency Increases by one clock cycle when enabled.
 */
/*@{*/
#define BP_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3 (9U) /*!< Bit position for DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3. */
#define BM_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3 (0x00000E00U) /*!< Bit mask for DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3. */
#define BS_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3 (3U) /*!< Bit field size in bits for DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3. */

/*! @brief Read current value of the DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3 field. */
#define BR_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3(x) (HW_DDR_PHY_PHY_CON5(x).B.CTRL_WRLAT_PLUS3)

/*! @brief Format value for bitfield DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3. */
#define BF_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3) & BM_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3)

/*! @brief Set the CTRL_WRLAT_PLUS3 field to a new value. */
#define BW_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3(x, v) (HW_DDR_PHY_PHY_CON5_WR(x, (HW_DDR_PHY_PHY_CON5_RD(x) & ~BM_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3) | BF_DDR_PHY_PHY_CON5_CTRL_WRLAT_PLUS3(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_LP_CON0 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_LP_CON0 -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_lp_con0
{
    uint32_t U;
    struct _hw_ddr_phy_lp_con0_bitfields
    {
        uint32_t CTRL_PULLD_DQS : 9;   /*!< [8:0]  */
        uint32_t RESERVED0 : 7;        /*!< [15:9]  */
        uint32_t CTRL_PULLD_DQ : 9;    /*!< [24:16]  */
        uint32_t RESERVED1 : 7;        /*!< [31:25]  */
    } B;
} hw_ddr_phy_lp_con0_t;

/*!
 * @name Constants and macros for entire DDR_PHY_LP_CON0 register
 */
/*@{*/
#define HW_DDR_PHY_LP_CON0_ADDR(x) ((uintptr_t)(x) + 0x18U)

#define HW_DDR_PHY_LP_CON0(x)    (*(__IO hw_ddr_phy_lp_con0_t *) HW_DDR_PHY_LP_CON0_ADDR(x))
#define HW_DDR_PHY_LP_CON0_RD(x) (HW_DDR_PHY_LP_CON0(x).U)
#define HW_DDR_PHY_LP_CON0_WR(x, v) (HW_DDR_PHY_LP_CON0(x).U = (v))
#define HW_DDR_PHY_LP_CON0_SET(x, v) (HW_DDR_PHY_LP_CON0_WR(x, HW_DDR_PHY_LP_CON0_RD(x) |  (v)))
#define HW_DDR_PHY_LP_CON0_CLR(x, v) (HW_DDR_PHY_LP_CON0_WR(x, HW_DDR_PHY_LP_CON0_RD(x) & ~(v)))
#define HW_DDR_PHY_LP_CON0_TOG(x, v) (HW_DDR_PHY_LP_CON0_WR(x, HW_DDR_PHY_LP_CON0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_LP_CON0 bitfields
 */

/*!
 * @name Register DDR_PHY_LP_CON0, field CTRL_PULLD_DQS[8:0] (RW)
 *
 * Active HIGH signal to pull-up or down PDQS / NDQS signals. When using Gate
 * Leveling in DDR3, this field can be zero. When bus is idle, it can be set to
 * pull-down or up the bus not to make bus high-z state (PDQS / NDQS is pulled-down
 * / up). For LPDDR2 / LPDDR3 mode, this field should be always set for normal
 * operation to make P / NDQS signals pull-down / up. Initial Value = 4'h0
 */
/*@{*/
#define BP_DDR_PHY_LP_CON0_CTRL_PULLD_DQS (0U) /*!< Bit position for DDR_PHY_LP_CON0_CTRL_PULLD_DQS. */
#define BM_DDR_PHY_LP_CON0_CTRL_PULLD_DQS (0x000001FFU) /*!< Bit mask for DDR_PHY_LP_CON0_CTRL_PULLD_DQS. */
#define BS_DDR_PHY_LP_CON0_CTRL_PULLD_DQS (9U) /*!< Bit field size in bits for DDR_PHY_LP_CON0_CTRL_PULLD_DQS. */

/*! @brief Read current value of the DDR_PHY_LP_CON0_CTRL_PULLD_DQS field. */
#define BR_DDR_PHY_LP_CON0_CTRL_PULLD_DQS(x) (HW_DDR_PHY_LP_CON0(x).B.CTRL_PULLD_DQS)

/*! @brief Format value for bitfield DDR_PHY_LP_CON0_CTRL_PULLD_DQS. */
#define BF_DDR_PHY_LP_CON0_CTRL_PULLD_DQS(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_LP_CON0_CTRL_PULLD_DQS) & BM_DDR_PHY_LP_CON0_CTRL_PULLD_DQS)

/*! @brief Set the CTRL_PULLD_DQS field to a new value. */
#define BW_DDR_PHY_LP_CON0_CTRL_PULLD_DQS(x, v) (HW_DDR_PHY_LP_CON0_WR(x, (HW_DDR_PHY_LP_CON0_RD(x) & ~BM_DDR_PHY_LP_CON0_CTRL_PULLD_DQS) | BF_DDR_PHY_LP_CON0_CTRL_PULLD_DQS(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_LP_CON0, field CTRL_PULLD_DQ[24:16] (RW)
 *
 * Active HIGH signal to down DQ signals. For normal operation this field should
 * be zero. When bus is idle, it can be set to pull-down or up the bus not to
 * make bus high-z state. Initial Value = 4'h0
 */
/*@{*/
#define BP_DDR_PHY_LP_CON0_CTRL_PULLD_DQ (16U) /*!< Bit position for DDR_PHY_LP_CON0_CTRL_PULLD_DQ. */
#define BM_DDR_PHY_LP_CON0_CTRL_PULLD_DQ (0x01FF0000U) /*!< Bit mask for DDR_PHY_LP_CON0_CTRL_PULLD_DQ. */
#define BS_DDR_PHY_LP_CON0_CTRL_PULLD_DQ (9U) /*!< Bit field size in bits for DDR_PHY_LP_CON0_CTRL_PULLD_DQ. */

/*! @brief Read current value of the DDR_PHY_LP_CON0_CTRL_PULLD_DQ field. */
#define BR_DDR_PHY_LP_CON0_CTRL_PULLD_DQ(x) (HW_DDR_PHY_LP_CON0(x).B.CTRL_PULLD_DQ)

/*! @brief Format value for bitfield DDR_PHY_LP_CON0_CTRL_PULLD_DQ. */
#define BF_DDR_PHY_LP_CON0_CTRL_PULLD_DQ(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_LP_CON0_CTRL_PULLD_DQ) & BM_DDR_PHY_LP_CON0_CTRL_PULLD_DQ)

/*! @brief Set the CTRL_PULLD_DQ field to a new value. */
#define BW_DDR_PHY_LP_CON0_CTRL_PULLD_DQ(x, v) (HW_DDR_PHY_LP_CON0_WR(x, (HW_DDR_PHY_LP_CON0_RD(x) & ~BM_DDR_PHY_LP_CON0_CTRL_PULLD_DQ) | BF_DDR_PHY_LP_CON0_CTRL_PULLD_DQ(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_RODT_CON0 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_RODT_CON0 -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_rodt_con0
{
    uint32_t U;
    struct _hw_ddr_phy_rodt_con0_bitfields
    {
        uint32_t RESERVED0 : 16;       /*!< [15:0]  */
        uint32_t CTRL_READ_DIS : 1;    /*!< [16]  */
        uint32_t RESERVED1 : 15;       /*!< [31:17]  */
    } B;
} hw_ddr_phy_rodt_con0_t;

/*!
 * @name Constants and macros for entire DDR_PHY_RODT_CON0 register
 */
/*@{*/
#define HW_DDR_PHY_RODT_CON0_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_DDR_PHY_RODT_CON0(x)  (*(__IO hw_ddr_phy_rodt_con0_t *) HW_DDR_PHY_RODT_CON0_ADDR(x))
#define HW_DDR_PHY_RODT_CON0_RD(x) (HW_DDR_PHY_RODT_CON0(x).U)
#define HW_DDR_PHY_RODT_CON0_WR(x, v) (HW_DDR_PHY_RODT_CON0(x).U = (v))
#define HW_DDR_PHY_RODT_CON0_SET(x, v) (HW_DDR_PHY_RODT_CON0_WR(x, HW_DDR_PHY_RODT_CON0_RD(x) |  (v)))
#define HW_DDR_PHY_RODT_CON0_CLR(x, v) (HW_DDR_PHY_RODT_CON0_WR(x, HW_DDR_PHY_RODT_CON0_RD(x) & ~(v)))
#define HW_DDR_PHY_RODT_CON0_TOG(x, v) (HW_DDR_PHY_RODT_CON0_WR(x, HW_DDR_PHY_RODT_CON0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_RODT_CON0 bitfields
 */

/*!
 * @name Register DDR_PHY_RODT_CON0, field CTRL_READ_DIS[16] (RW)
 *
 * Read ODT (On-Die-Termination) Disable Signal. This signal should be one in
 * LPDDR2 or LPDDR3 mode. Initial Value = 4'h0
 */
/*@{*/
#define BP_DDR_PHY_RODT_CON0_CTRL_READ_DIS (16U) /*!< Bit position for DDR_PHY_RODT_CON0_CTRL_READ_DIS. */
#define BM_DDR_PHY_RODT_CON0_CTRL_READ_DIS (0x00010000U) /*!< Bit mask for DDR_PHY_RODT_CON0_CTRL_READ_DIS. */
#define BS_DDR_PHY_RODT_CON0_CTRL_READ_DIS (1U) /*!< Bit field size in bits for DDR_PHY_RODT_CON0_CTRL_READ_DIS. */

/*! @brief Read current value of the DDR_PHY_RODT_CON0_CTRL_READ_DIS field. */
#define BR_DDR_PHY_RODT_CON0_CTRL_READ_DIS(x) (HW_DDR_PHY_RODT_CON0(x).B.CTRL_READ_DIS)

/*! @brief Format value for bitfield DDR_PHY_RODT_CON0_CTRL_READ_DIS. */
#define BF_DDR_PHY_RODT_CON0_CTRL_READ_DIS(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_RODT_CON0_CTRL_READ_DIS) & BM_DDR_PHY_RODT_CON0_CTRL_READ_DIS)

/*! @brief Set the CTRL_READ_DIS field to a new value. */
#define BW_DDR_PHY_RODT_CON0_CTRL_READ_DIS(x, v) (HW_DDR_PHY_RODT_CON0_WR(x, (HW_DDR_PHY_RODT_CON0_RD(x) & ~BM_DDR_PHY_RODT_CON0_CTRL_READ_DIS) | BF_DDR_PHY_RODT_CON0_CTRL_READ_DIS(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_OFFSET_RD_CON0 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_OFFSET_RD_CON0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * To capture the DQs with DQS in read operation, DQS is shifted by 90degree and
 * this makes rising edge of DQS be located in the center of valid window of
 * DQs. But according to the channel condition, i.e. PCB or SSN, rising edge of DQS
 * could be biased from the center of valid window of DQs. ctrl_offset* is used
 * to compensate the biased DQS and make it be placed in the center of DQs. If
 * ctrl_offset*[7] is 0, ctrl_offset*[6:0] x tFS (tFS: fine step delay) is added to
 * the 90degree delay amount and if ctrl_offset*[7] is 1, ctrl_offset*[6:0] x tFS
 * is subtracted from the 90degree delay amount. ctrl_offset*[6:0] means the
 * number of delay cells of the "delay line". Generally, ctrl_offset*[6:0] would be
 * zero. dfi_ctrlupd_req signal is required to update delay line control signals
 * before the first normal operation after checking whether dfi_init_complete is
 * set and at every memory refresh cycle. Before set and clear this signal during
 * initialization, dfi_init_complete signal should be checked whether it's HIGH
 * to confirm that DLL is locked. Be careful that "ctrl_offsetr*" can be used for
 * the other purpose (= Read Deskew Code Register). Please refer to mode (=
 * PHY_CON3[7:0]).
 */
typedef union _hw_ddr_phy_offset_rd_con0
{
    uint32_t U;
    struct _hw_ddr_phy_offset_rd_con0_bitfields
    {
        uint32_t CTRL_OFFSETR0 : 8;    /*!< [7:0]  */
        uint32_t CTRL_OFFSETR1 : 8;    /*!< [15:8]  */
        uint32_t CTRL_OFFSETR2 : 8;    /*!< [23:16]  */
        uint32_t CTRL_OFFSETR3 : 8;    /*!< [31:24]  */
    } B;
} hw_ddr_phy_offset_rd_con0_t;

/*!
 * @name Constants and macros for entire DDR_PHY_OFFSET_RD_CON0 register
 */
/*@{*/
#define HW_DDR_PHY_OFFSET_RD_CON0_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_DDR_PHY_OFFSET_RD_CON0(x) (*(__IO hw_ddr_phy_offset_rd_con0_t *) HW_DDR_PHY_OFFSET_RD_CON0_ADDR(x))
#define HW_DDR_PHY_OFFSET_RD_CON0_RD(x) (HW_DDR_PHY_OFFSET_RD_CON0(x).U)
#define HW_DDR_PHY_OFFSET_RD_CON0_WR(x, v) (HW_DDR_PHY_OFFSET_RD_CON0(x).U = (v))
#define HW_DDR_PHY_OFFSET_RD_CON0_SET(x, v) (HW_DDR_PHY_OFFSET_RD_CON0_WR(x, HW_DDR_PHY_OFFSET_RD_CON0_RD(x) |  (v)))
#define HW_DDR_PHY_OFFSET_RD_CON0_CLR(x, v) (HW_DDR_PHY_OFFSET_RD_CON0_WR(x, HW_DDR_PHY_OFFSET_RD_CON0_RD(x) & ~(v)))
#define HW_DDR_PHY_OFFSET_RD_CON0_TOG(x, v) (HW_DDR_PHY_OFFSET_RD_CON0_WR(x, HW_DDR_PHY_OFFSET_RD_CON0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_OFFSET_RD_CON0 bitfields
 */

/*!
 * @name Register DDR_PHY_OFFSET_RD_CON0, field CTRL_OFFSETR0[7:0] (RW)
 *
 * This field can be used to give offset to read DQS. If this field is fixed,
 * this should not be changed during operation. This value is valid only after
 * dfi_ctrlupd_req becomes HIGH and LOW. The right-shifted value is limited by the
 * quarter of the maximum delay in Master Delay Line. Read DQS offset amount:
 * ctrl_offsetr0[7] = 1: (tFS: fine step delay) Read DQS 90degree delay amount −
 * ctrl_offsetr0[6:0] x tFS ctrl_offsetr0[7] = 0: Read DQS 90degree delay amount +
 * ctrl_offsetr0[6:0] x tFS Initial Value = 0x8
 */
/*@{*/
#define BP_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0 (0U) /*!< Bit position for DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0. */
#define BM_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0 (0x000000FFU) /*!< Bit mask for DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0. */
#define BS_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0 (8U) /*!< Bit field size in bits for DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0. */

/*! @brief Read current value of the DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0 field. */
#define BR_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0(x) (HW_DDR_PHY_OFFSET_RD_CON0(x).B.CTRL_OFFSETR0)

/*! @brief Format value for bitfield DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0. */
#define BF_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0) & BM_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0)

/*! @brief Set the CTRL_OFFSETR0 field to a new value. */
#define BW_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0(x, v) (HW_DDR_PHY_OFFSET_RD_CON0_WR(x, (HW_DDR_PHY_OFFSET_RD_CON0_RD(x) & ~BM_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0) | BF_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR0(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_OFFSET_RD_CON0, field CTRL_OFFSETR1[15:8] (RW)
 *
 * This field can be used to give offset to read DQS. If this field is fixed,
 * this should not be changed during operation. This value is valid only after
 * dfi_ctrlupd_req becomes HIGH and LOW. The right-shifted value is limited by the
 * quarter of the maximum delay in Master Delay Line. Read DQS offset amount:
 * ctrl_offsetr1[7] = 1: (tFS: fine step delay) Read DQS 90degree delay amount −
 * ctrl_offsetr0[6:0] x tFS ctrl_offsetr1[7] = 0: Read DQS 90degree delay amount +
 * ctrl_offsetr0[6:0] x tFS Initial Value = 0x8
 */
/*@{*/
#define BP_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1 (8U) /*!< Bit position for DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1. */
#define BM_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1. */
#define BS_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1 (8U) /*!< Bit field size in bits for DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1. */

/*! @brief Read current value of the DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1 field. */
#define BR_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1(x) (HW_DDR_PHY_OFFSET_RD_CON0(x).B.CTRL_OFFSETR1)

/*! @brief Format value for bitfield DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1. */
#define BF_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1) & BM_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1)

/*! @brief Set the CTRL_OFFSETR1 field to a new value. */
#define BW_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1(x, v) (HW_DDR_PHY_OFFSET_RD_CON0_WR(x, (HW_DDR_PHY_OFFSET_RD_CON0_RD(x) & ~BM_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1) | BF_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR1(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_OFFSET_RD_CON0, field CTRL_OFFSETR2[23:16] (RW)
 *
 * This field can be used to give offset to read DQS. If this field is fixed,
 * this should not be changed during operation. This value is valid only after
 * dfi_ctrlupd_req becomes HIGH and LOW. The right-shifted value is limited by the
 * quarter of the maximum delay in Master Delay Line. Read DQS offset amount:
 * ctrl_offsetr2[7] = 1: (tFS: fine step delay) Read DQS 90degree delay amount −
 * ctrl_offsetr0[6:0] x tFS ctrl_offsetr2[7] = 0: Read DQS 90degree delay amount +
 * ctrl_offsetr0[6:0] x tFS Initial Value = 0x8
 */
/*@{*/
#define BP_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2 (16U) /*!< Bit position for DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2. */
#define BM_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2. */
#define BS_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2 (8U) /*!< Bit field size in bits for DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2. */

/*! @brief Read current value of the DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2 field. */
#define BR_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2(x) (HW_DDR_PHY_OFFSET_RD_CON0(x).B.CTRL_OFFSETR2)

/*! @brief Format value for bitfield DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2. */
#define BF_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2) & BM_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2)

/*! @brief Set the CTRL_OFFSETR2 field to a new value. */
#define BW_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2(x, v) (HW_DDR_PHY_OFFSET_RD_CON0_WR(x, (HW_DDR_PHY_OFFSET_RD_CON0_RD(x) & ~BM_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2) | BF_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR2(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_OFFSET_RD_CON0, field CTRL_OFFSETR3[31:24] (RW)
 *
 * This field can be used to give offset to read DQS. If this field is fixed,
 * this should not be changed during operation. This value is valid only after
 * dfi_ctrlupd_req becomes HIGH and LOW. The right-shifted value is limited by the
 * quarter of the maximum delay in Master Delay Line. Read DQS offset amount:
 * ctrl_offsetr3[7] = 1: (tFS: fine step delay) Read DQS 90degree delay amount −
 * ctrl_offsetr0[6:0] x tFS ctrl_offsetr3[7] = 0: Read DQS 90degree delay amount +
 * ctrl_offsetr0[6:0] x tFS Initial Value = 0x8
 */
/*@{*/
#define BP_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3 (24U) /*!< Bit position for DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3. */
#define BM_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3 (0xFF000000U) /*!< Bit mask for DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3. */
#define BS_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3 (8U) /*!< Bit field size in bits for DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3. */

/*! @brief Read current value of the DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3 field. */
#define BR_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3(x) (HW_DDR_PHY_OFFSET_RD_CON0(x).B.CTRL_OFFSETR3)

/*! @brief Format value for bitfield DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3. */
#define BF_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3) & BM_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3)

/*! @brief Set the CTRL_OFFSETR3 field to a new value. */
#define BW_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3(x, v) (HW_DDR_PHY_OFFSET_RD_CON0_WR(x, (HW_DDR_PHY_OFFSET_RD_CON0_RD(x) & ~BM_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3) | BF_DDR_PHY_OFFSET_RD_CON0_CTRL_OFFSETR3(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_OFFSET_WR_CON0 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_OFFSET_WR_CON0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * Be careful that "ctrl_offsetw*" can be used for the other purpose (= Write
 * Deskew Code Register). Please refer to reg_mode (= PHY_CON3[7:0]).
 */
typedef union _hw_ddr_phy_offset_wr_con0
{
    uint32_t U;
    struct _hw_ddr_phy_offset_wr_con0_bitfields
    {
        uint32_t CTRL_OFFSETW0 : 8;    /*!< [7:0]  */
        uint32_t CTRL_OFFSETW1 : 8;    /*!< [15:8]  */
        uint32_t CTRL_OFFSETW2 : 8;    /*!< [23:16]  */
        uint32_t CTRL_OFFSETW3 : 8;    /*!< [31:24]  */
    } B;
} hw_ddr_phy_offset_wr_con0_t;

/*!
 * @name Constants and macros for entire DDR_PHY_OFFSET_WR_CON0 register
 */
/*@{*/
#define HW_DDR_PHY_OFFSET_WR_CON0_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_DDR_PHY_OFFSET_WR_CON0(x) (*(__IO hw_ddr_phy_offset_wr_con0_t *) HW_DDR_PHY_OFFSET_WR_CON0_ADDR(x))
#define HW_DDR_PHY_OFFSET_WR_CON0_RD(x) (HW_DDR_PHY_OFFSET_WR_CON0(x).U)
#define HW_DDR_PHY_OFFSET_WR_CON0_WR(x, v) (HW_DDR_PHY_OFFSET_WR_CON0(x).U = (v))
#define HW_DDR_PHY_OFFSET_WR_CON0_SET(x, v) (HW_DDR_PHY_OFFSET_WR_CON0_WR(x, HW_DDR_PHY_OFFSET_WR_CON0_RD(x) |  (v)))
#define HW_DDR_PHY_OFFSET_WR_CON0_CLR(x, v) (HW_DDR_PHY_OFFSET_WR_CON0_WR(x, HW_DDR_PHY_OFFSET_WR_CON0_RD(x) & ~(v)))
#define HW_DDR_PHY_OFFSET_WR_CON0_TOG(x, v) (HW_DDR_PHY_OFFSET_WR_CON0_WR(x, HW_DDR_PHY_OFFSET_WR_CON0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_OFFSET_WR_CON0 bitfields
 */

/*!
 * @name Register DDR_PHY_OFFSET_WR_CON0, field CTRL_OFFSETW0[7:0] (RW)
 *
 * This field can be used to give offset to write DQ. If this field is fixed,
 * this should not be changed during operation. This value is valid only after
 * dfi_ctrlupd_req becomes HIGH and LOW. The right-shifted value is limited by the
 * quarter of the maximum delay in Master Delay Line. Write DQ offset amount:
 * ctrl_offsetw2[7] = 1: (tFS: fine step delay) Write DQ 270degree delay amount −
 * ctrl_offsetw2[6:0] x tFS ctrl_offsetr2[7] = 0: Write DQ 270degree delay amount +
 * ctrl_offsetw2[6:0] x tFS Initial Value = 0x8
 */
/*@{*/
#define BP_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0 (0U) /*!< Bit position for DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0. */
#define BM_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0 (0x000000FFU) /*!< Bit mask for DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0. */
#define BS_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0 (8U) /*!< Bit field size in bits for DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0. */

/*! @brief Read current value of the DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0 field. */
#define BR_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0(x) (HW_DDR_PHY_OFFSET_WR_CON0(x).B.CTRL_OFFSETW0)

/*! @brief Format value for bitfield DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0. */
#define BF_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0) & BM_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0)

/*! @brief Set the CTRL_OFFSETW0 field to a new value. */
#define BW_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0(x, v) (HW_DDR_PHY_OFFSET_WR_CON0_WR(x, (HW_DDR_PHY_OFFSET_WR_CON0_RD(x) & ~BM_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0) | BF_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW0(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_OFFSET_WR_CON0, field CTRL_OFFSETW1[15:8] (RW)
 *
 * This field can be used to give offset to write DQ. If this field is fixed,
 * this should not be changed during operation. This value is valid only after
 * dfi_ctrlupd_req becomes HIGH and LOW. The right-shifted value is limited by the
 * quarter of the maximum delay in Master Delay Line. Write DQ offset amount:
 * ctrl_offsetw2[7] = 1: (tFS: fine step delay) Write DQ 270degree delay amount −
 * ctrl_offsetw2[6:0] x tFS ctrl_offsetr2[7] = 0: Write DQ 270degree delay amount +
 * ctrl_offsetw2[6:0] x tFS Initial Value = 0x8
 */
/*@{*/
#define BP_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1 (8U) /*!< Bit position for DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1. */
#define BM_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1. */
#define BS_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1 (8U) /*!< Bit field size in bits for DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1. */

/*! @brief Read current value of the DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1 field. */
#define BR_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1(x) (HW_DDR_PHY_OFFSET_WR_CON0(x).B.CTRL_OFFSETW1)

/*! @brief Format value for bitfield DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1. */
#define BF_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1) & BM_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1)

/*! @brief Set the CTRL_OFFSETW1 field to a new value. */
#define BW_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1(x, v) (HW_DDR_PHY_OFFSET_WR_CON0_WR(x, (HW_DDR_PHY_OFFSET_WR_CON0_RD(x) & ~BM_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1) | BF_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW1(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_OFFSET_WR_CON0, field CTRL_OFFSETW2[23:16] (RW)
 *
 * This field can be used to give offset to write DQ. If this field is fixed,
 * this should not be changed during operation. This value is valid only after
 * dfi_ctrlupd_req becomes HIGH and LOW. The right-shifted value is limited by the
 * quarter of the maximum delay in Master Delay Line. Write DQ offset amount:
 * ctrl_offsetw2[7] = 1: (tFS: fine step delay) Write DQ 270degree delay amount −
 * ctrl_offsetw2[6:0] x tFS ctrl_offsetr2[7] = 0: Write DQ 270degree delay amount +
 * ctrl_offsetw2[6:0] x tFS Initial Value = 0x8
 */
/*@{*/
#define BP_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2 (16U) /*!< Bit position for DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2. */
#define BM_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2. */
#define BS_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2 (8U) /*!< Bit field size in bits for DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2. */

/*! @brief Read current value of the DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2 field. */
#define BR_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2(x) (HW_DDR_PHY_OFFSET_WR_CON0(x).B.CTRL_OFFSETW2)

/*! @brief Format value for bitfield DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2. */
#define BF_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2) & BM_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2)

/*! @brief Set the CTRL_OFFSETW2 field to a new value. */
#define BW_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2(x, v) (HW_DDR_PHY_OFFSET_WR_CON0_WR(x, (HW_DDR_PHY_OFFSET_WR_CON0_RD(x) & ~BM_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2) | BF_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW2(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_OFFSET_WR_CON0, field CTRL_OFFSETW3[31:24] (RW)
 *
 * This field can be used to give offset to write DQ. If this field is fixed,
 * this should not be changed during operation. This value is valid only after
 * dfi_ctrlupd_req becomes HIGH and LOW. The right-shifted value is limited by the
 * quarter of the maximum delay in Master Delay Line. Write DQ offset amount:
 * ctrl_offsetw2[7] = 1: (tFS: fine step delay) Write DQ 270degree delay amount −
 * ctrl_offsetw2[6:0] x tFS ctrl_offsetr2[7] = 0: Write DQ 270degree delay amount +
 * ctrl_offsetw2[6:0] x tFS Initial Value = 0x8
 */
/*@{*/
#define BP_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3 (24U) /*!< Bit position for DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3. */
#define BM_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3 (0xFF000000U) /*!< Bit mask for DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3. */
#define BS_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3 (8U) /*!< Bit field size in bits for DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3. */

/*! @brief Read current value of the DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3 field. */
#define BR_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3(x) (HW_DDR_PHY_OFFSET_WR_CON0(x).B.CTRL_OFFSETW3)

/*! @brief Format value for bitfield DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3. */
#define BF_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3) & BM_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3)

/*! @brief Set the CTRL_OFFSETW3 field to a new value. */
#define BW_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3(x, v) (HW_DDR_PHY_OFFSET_WR_CON0_WR(x, (HW_DDR_PHY_OFFSET_WR_CON0_RD(x) & ~BM_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3) | BF_DDR_PHY_OFFSET_WR_CON0_CTRL_OFFSETW3(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_GATE_CODE_CON0 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_GATE_CODE_CON0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * GATE Control Register
 */
typedef union _hw_ddr_phy_gate_code_con0
{
    uint32_t U;
    struct _hw_ddr_phy_gate_code_con0_bitfields
    {
        uint32_t CTRL_OFFSETC0 : 8;    /*!< [7:0]  */
        uint32_t CTRL_OFFSETC1 : 8;    /*!< [15:8]  */
        uint32_t CTRL_OFFSETC2 : 8;    /*!< [23:16]  */
        uint32_t CTRL_OFFSETC3 : 8;    /*!< [31:24]  */
    } B;
} hw_ddr_phy_gate_code_con0_t;

/*!
 * @name Constants and macros for entire DDR_PHY_GATE_CODE_CON0 register
 */
/*@{*/
#define HW_DDR_PHY_GATE_CODE_CON0_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_DDR_PHY_GATE_CODE_CON0(x) (*(__IO hw_ddr_phy_gate_code_con0_t *) HW_DDR_PHY_GATE_CODE_CON0_ADDR(x))
#define HW_DDR_PHY_GATE_CODE_CON0_RD(x) (HW_DDR_PHY_GATE_CODE_CON0(x).U)
#define HW_DDR_PHY_GATE_CODE_CON0_WR(x, v) (HW_DDR_PHY_GATE_CODE_CON0(x).U = (v))
#define HW_DDR_PHY_GATE_CODE_CON0_SET(x, v) (HW_DDR_PHY_GATE_CODE_CON0_WR(x, HW_DDR_PHY_GATE_CODE_CON0_RD(x) |  (v)))
#define HW_DDR_PHY_GATE_CODE_CON0_CLR(x, v) (HW_DDR_PHY_GATE_CODE_CON0_WR(x, HW_DDR_PHY_GATE_CODE_CON0_RD(x) & ~(v)))
#define HW_DDR_PHY_GATE_CODE_CON0_TOG(x, v) (HW_DDR_PHY_GATE_CODE_CON0_WR(x, HW_DDR_PHY_GATE_CODE_CON0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_GATE_CODE_CON0 bitfields
 */

/*!
 * @name Register DDR_PHY_GATE_CODE_CON0, field CTRL_OFFSETC0[7:0] (RW)
 *
 * Gate offset amount for DDR3 Data Slice 0. Do not change this register value
 * after the PHY has been initialized. This value is valid only after
 * dfi_ctrlupd_req becomes HIGH and LOW. ctrl_offsetc [7] = 1 : (tFS: fine step delay)
 * GATEout delay amount − ctrl_offsetc [6:0] x tFS ctrl_offsetc [7] = 0 : GATEout
 * delay amount + ctrl_offsetc [6:0] x tFS Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0 (0U) /*!< Bit position for DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0. */
#define BM_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0 (0x000000FFU) /*!< Bit mask for DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0. */
#define BS_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0 (8U) /*!< Bit field size in bits for DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0. */

/*! @brief Read current value of the DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0 field. */
#define BR_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0(x) (HW_DDR_PHY_GATE_CODE_CON0(x).B.CTRL_OFFSETC0)

/*! @brief Format value for bitfield DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0. */
#define BF_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0) & BM_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0)

/*! @brief Set the CTRL_OFFSETC0 field to a new value. */
#define BW_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0(x, v) (HW_DDR_PHY_GATE_CODE_CON0_WR(x, (HW_DDR_PHY_GATE_CODE_CON0_RD(x) & ~BM_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0) | BF_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC0(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_GATE_CODE_CON0, field CTRL_OFFSETC1[15:8] (RW)
 *
 * Gate offset amount for DDR3 Data Slice 1. Do not change this register value
 * after the PHY has been initialized. This value is valid only after
 * dfi_ctrlupd_req becomes HIGH and LOW. ctrl_offsetc [7] = 1 : (tFS: fine step delay)
 * GATEout delay amount − ctrl_offsetc [6:0] x tFS ctrl_offsetc [7] = 0 : GATEout
 * delay amount + ctrl_offsetc [6:0] x tFS Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1 (8U) /*!< Bit position for DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1. */
#define BM_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1. */
#define BS_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1 (8U) /*!< Bit field size in bits for DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1. */

/*! @brief Read current value of the DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1 field. */
#define BR_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1(x) (HW_DDR_PHY_GATE_CODE_CON0(x).B.CTRL_OFFSETC1)

/*! @brief Format value for bitfield DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1. */
#define BF_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1) & BM_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1)

/*! @brief Set the CTRL_OFFSETC1 field to a new value. */
#define BW_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1(x, v) (HW_DDR_PHY_GATE_CODE_CON0_WR(x, (HW_DDR_PHY_GATE_CODE_CON0_RD(x) & ~BM_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1) | BF_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC1(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_GATE_CODE_CON0, field CTRL_OFFSETC2[23:16] (RW)
 *
 * Gate offset amount for DDR3 Data Slice 2. Do not change this register value
 * after the PHY has been initialized. This value is valid only after
 * dfi_ctrlupd_req becomes HIGH and LOW. ctrl_offsetc [7] = 1 : (tFS: fine step delay)
 * GATEout delay amount − ctrl_offsetc [6:0] x tFS ctrl_offsetc [7] = 0 : GATEout
 * delay amount + ctrl_offsetc [6:0] x tFS Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2 (16U) /*!< Bit position for DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2. */
#define BM_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2. */
#define BS_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2 (8U) /*!< Bit field size in bits for DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2. */

/*! @brief Read current value of the DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2 field. */
#define BR_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2(x) (HW_DDR_PHY_GATE_CODE_CON0(x).B.CTRL_OFFSETC2)

/*! @brief Format value for bitfield DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2. */
#define BF_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2) & BM_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2)

/*! @brief Set the CTRL_OFFSETC2 field to a new value. */
#define BW_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2(x, v) (HW_DDR_PHY_GATE_CODE_CON0_WR(x, (HW_DDR_PHY_GATE_CODE_CON0_RD(x) & ~BM_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2) | BF_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC2(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_GATE_CODE_CON0, field CTRL_OFFSETC3[31:24] (RW)
 *
 * Gate offset amount for DDR3 Data Slice 3. Do not change this register value
 * after the PHY has been initialized. This value is valid only after
 * dfi_ctrlupd_req becomes HIGH and LOW. ctrl_offsetc [7] = 1 : (tFS: fine step delay)
 * GATEout delay amount − ctrl_offsetc [6:0] x tFS ctrl_offsetc [7] = 0 : GATEout
 * delay amount + ctrl_offsetc [6:0] x tFS Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3 (24U) /*!< Bit position for DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3. */
#define BM_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3 (0xFF000000U) /*!< Bit mask for DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3. */
#define BS_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3 (8U) /*!< Bit field size in bits for DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3. */

/*! @brief Read current value of the DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3 field. */
#define BR_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3(x) (HW_DDR_PHY_GATE_CODE_CON0(x).B.CTRL_OFFSETC3)

/*! @brief Format value for bitfield DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3. */
#define BF_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3) & BM_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3)

/*! @brief Set the CTRL_OFFSETC3 field to a new value. */
#define BW_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3(x, v) (HW_DDR_PHY_GATE_CODE_CON0_WR(x, (HW_DDR_PHY_GATE_CODE_CON0_RD(x) & ~BM_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3) | BF_DDR_PHY_GATE_CODE_CON0_CTRL_OFFSETC3(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_SHIFTC_CON0 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_SHIFTC_CON0 -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_shiftc_con0
{
    uint32_t U;
    struct _hw_ddr_phy_shiftc_con0_bitfields
    {
        uint32_t CTRL_SHIFTC0 : 3;     /*!< [2:0]  */
        uint32_t CTRL_SHIFTC1 : 3;     /*!< [5:3]  */
        uint32_t CTRL_SHIFTC2 : 3;     /*!< [8:6]  */
        uint32_t CTRL_SHIFTC3 : 3;     /*!< [11:9]  */
        uint32_t RESERVED0 : 20;       /*!< [31:12]  */
    } B;
} hw_ddr_phy_shiftc_con0_t;

/*!
 * @name Constants and macros for entire DDR_PHY_SHIFTC_CON0 register
 */
/*@{*/
#define HW_DDR_PHY_SHIFTC_CON0_ADDR(x) ((uintptr_t)(x) + 0x4CU)

#define HW_DDR_PHY_SHIFTC_CON0(x) (*(__IO hw_ddr_phy_shiftc_con0_t *) HW_DDR_PHY_SHIFTC_CON0_ADDR(x))
#define HW_DDR_PHY_SHIFTC_CON0_RD(x) (HW_DDR_PHY_SHIFTC_CON0(x).U)
#define HW_DDR_PHY_SHIFTC_CON0_WR(x, v) (HW_DDR_PHY_SHIFTC_CON0(x).U = (v))
#define HW_DDR_PHY_SHIFTC_CON0_SET(x, v) (HW_DDR_PHY_SHIFTC_CON0_WR(x, HW_DDR_PHY_SHIFTC_CON0_RD(x) |  (v)))
#define HW_DDR_PHY_SHIFTC_CON0_CLR(x, v) (HW_DDR_PHY_SHIFTC_CON0_WR(x, HW_DDR_PHY_SHIFTC_CON0_RD(x) & ~(v)))
#define HW_DDR_PHY_SHIFTC_CON0_TOG(x, v) (HW_DDR_PHY_SHIFTC_CON0_WR(x, HW_DDR_PHY_SHIFTC_CON0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_SHIFTC_CON0 bitfields
 */

/*!
 * @name Register DDR_PHY_SHIFTC_CON0, field CTRL_SHIFTC0[2:0] (RW)
 *
 * GATEin signal delay amount for DDR. If this field is fixed, this should not
 * be changed during operation. This value is valid only after dfi_ctrlupd_req
 * becomes HIGH and LOW. This value is limited by the half of the maximum delay in
 * Master Delay Line. GATEin signal will be delayed by T/16 whenever it increases
 * one. Initial Value = 3'b010
 *
 * Values:
 * - 000 - 0 (0degree shift)
 * - 001 - T (365degree shift)
 * - 010 - T / 2 (180degree shift)
 * - 011 - T / 4 (90degree shift)
 * - 100 - T / 8 (45degree shift)
 * - 101 - T / 16 (22.5degree shift)
 */
/*@{*/
#define BP_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0 (0U) /*!< Bit position for DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0. */
#define BM_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0 (0x00000007U) /*!< Bit mask for DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0. */
#define BS_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0 (3U) /*!< Bit field size in bits for DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0. */

/*! @brief Read current value of the DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0 field. */
#define BR_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0(x) (HW_DDR_PHY_SHIFTC_CON0(x).B.CTRL_SHIFTC0)

/*! @brief Format value for bitfield DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0. */
#define BF_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0) & BM_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0)

/*! @brief Set the CTRL_SHIFTC0 field to a new value. */
#define BW_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0(x, v) (HW_DDR_PHY_SHIFTC_CON0_WR(x, (HW_DDR_PHY_SHIFTC_CON0_RD(x) & ~BM_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0) | BF_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC0(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_SHIFTC_CON0, field CTRL_SHIFTC1[5:3] (RW)
 *
 * GATEin signal delay amount for DDR. If this field is fixed, this should not
 * be changed during operation. This value is valid only after dfi_ctrlupd_req
 * becomes HIGH and LOW. This value is limited by the half of the maximum delay in
 * Master Delay Line. GATEin signal will be delayed by T/16 whenever it increases
 * one. Initial Value = 3'b010
 *
 * Values:
 * - 000 - 0 (0degree shift)
 * - 001 - T (365degree shift)
 * - 010 - T / 2 (180degree shift)
 * - 011 - T / 4 (90degree shift)
 * - 100 - T / 8 (45degree shift)
 * - 101 - T / 16 (22.5degree shift)
 */
/*@{*/
#define BP_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1 (3U) /*!< Bit position for DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1. */
#define BM_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1 (0x00000038U) /*!< Bit mask for DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1. */
#define BS_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1 (3U) /*!< Bit field size in bits for DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1. */

/*! @brief Read current value of the DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1 field. */
#define BR_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1(x) (HW_DDR_PHY_SHIFTC_CON0(x).B.CTRL_SHIFTC1)

/*! @brief Format value for bitfield DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1. */
#define BF_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1) & BM_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1)

/*! @brief Set the CTRL_SHIFTC1 field to a new value. */
#define BW_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1(x, v) (HW_DDR_PHY_SHIFTC_CON0_WR(x, (HW_DDR_PHY_SHIFTC_CON0_RD(x) & ~BM_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1) | BF_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC1(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_SHIFTC_CON0, field CTRL_SHIFTC2[8:6] (RW)
 *
 * GATEin signal delay amount for DDR. If this field is fixed, this should not
 * be changed during operation. This value is valid only after dfi_ctrlupd_req
 * becomes HIGH and LOW. This value is limited by the half of the maximum delay in
 * Master Delay Line. GATEin signal will be delayed by T/16 whenever it increases
 * one. Initial Value = 3'b010
 *
 * Values:
 * - 000 - 0 (0degree shift)
 * - 001 - T (365degree shift)
 * - 010 - T / 2 (180degree shift)
 * - 011 - T / 4 (90degree shift)
 * - 100 - T / 8 (45degree shift)
 * - 101 - T / 16 (22.5degree shift)
 */
/*@{*/
#define BP_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2 (6U) /*!< Bit position for DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2. */
#define BM_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2 (0x000001C0U) /*!< Bit mask for DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2. */
#define BS_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2 (3U) /*!< Bit field size in bits for DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2. */

/*! @brief Read current value of the DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2 field. */
#define BR_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2(x) (HW_DDR_PHY_SHIFTC_CON0(x).B.CTRL_SHIFTC2)

/*! @brief Format value for bitfield DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2. */
#define BF_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2) & BM_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2)

/*! @brief Set the CTRL_SHIFTC2 field to a new value. */
#define BW_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2(x, v) (HW_DDR_PHY_SHIFTC_CON0_WR(x, (HW_DDR_PHY_SHIFTC_CON0_RD(x) & ~BM_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2) | BF_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC2(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_SHIFTC_CON0, field CTRL_SHIFTC3[11:9] (RW)
 *
 * GATEin signal delay amount for DDR. If this field is fixed, this should not
 * be changed during operation. This value is valid only after dfi_ctrlupd_req
 * becomes HIGH and LOW. This value is limited by the half of the maximum delay in
 * Master Delay Line. GATEin signal will be delayed by T/16 whenever it increases
 * one. Initial Value = 3'b010
 *
 * Values:
 * - 000 - 0 (0degree shift)
 * - 001 - T (365degree shift)
 * - 010 - T / 2 (180degree shift)
 * - 011 - T / 4 (90degree shift)
 * - 100 - T / 8 (45degree shift)
 * - 101 - T / 16 (22.5degree shift)
 */
/*@{*/
#define BP_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3 (9U) /*!< Bit position for DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3. */
#define BM_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3 (0x00000E00U) /*!< Bit mask for DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3. */
#define BS_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3 (3U) /*!< Bit field size in bits for DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3. */

/*! @brief Read current value of the DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3 field. */
#define BR_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3(x) (HW_DDR_PHY_SHIFTC_CON0(x).B.CTRL_SHIFTC3)

/*! @brief Format value for bitfield DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3. */
#define BF_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3) & BM_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3)

/*! @brief Set the CTRL_SHIFTC3 field to a new value. */
#define BW_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3(x, v) (HW_DDR_PHY_SHIFTC_CON0_WR(x, (HW_DDR_PHY_SHIFTC_CON0_RD(x) & ~BM_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3) | BF_DDR_PHY_SHIFTC_CON0_CTRL_SHIFTC3(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_CMD_SDLL_CON0 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_CMD_SDLL_CON0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * CMD SDLL Control Register
 */
typedef union _hw_ddr_phy_cmd_sdll_con0
{
    uint32_t U;
    struct _hw_ddr_phy_cmd_sdll_con0_bitfields
    {
        uint32_t CTRL_OFFSETD : 8;     /*!< [7:0]  */
        uint32_t RESERVED0 : 16;       /*!< [23:8]  */
        uint32_t CTRL_RESYNC : 1;      /*!< [24]  */
        uint32_t RESERVED1 : 3;        /*!< [27:25]  */
        uint32_t UPD_MODE : 1;         /*!< [28]  */
        uint32_t RESERVED2 : 3;        /*!< [31:29]  */
    } B;
} hw_ddr_phy_cmd_sdll_con0_t;

/*!
 * @name Constants and macros for entire DDR_PHY_CMD_SDLL_CON0 register
 */
/*@{*/
#define HW_DDR_PHY_CMD_SDLL_CON0_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_DDR_PHY_CMD_SDLL_CON0(x) (*(__IO hw_ddr_phy_cmd_sdll_con0_t *) HW_DDR_PHY_CMD_SDLL_CON0_ADDR(x))
#define HW_DDR_PHY_CMD_SDLL_CON0_RD(x) (HW_DDR_PHY_CMD_SDLL_CON0(x).U)
#define HW_DDR_PHY_CMD_SDLL_CON0_WR(x, v) (HW_DDR_PHY_CMD_SDLL_CON0(x).U = (v))
#define HW_DDR_PHY_CMD_SDLL_CON0_SET(x, v) (HW_DDR_PHY_CMD_SDLL_CON0_WR(x, HW_DDR_PHY_CMD_SDLL_CON0_RD(x) |  (v)))
#define HW_DDR_PHY_CMD_SDLL_CON0_CLR(x, v) (HW_DDR_PHY_CMD_SDLL_CON0_WR(x, HW_DDR_PHY_CMD_SDLL_CON0_RD(x) & ~(v)))
#define HW_DDR_PHY_CMD_SDLL_CON0_TOG(x, v) (HW_DDR_PHY_CMD_SDLL_CON0_WR(x, HW_DDR_PHY_CMD_SDLL_CON0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_CMD_SDLL_CON0 bitfields
 */

/*!
 * @name Register DDR_PHY_CMD_SDLL_CON0, field CTRL_OFFSETD[7:0] (RW)
 *
 * This field is for debug purpose. (For LPDDR2) If this field is fixed, this
 * should not be changed during operation. This value is valid only after
 * dfi_ctrlupd_req becomes HIGH and LOW. The right-shifted value is limited by the quarter
 * of the maximum delay in Master Delay Line. offset amount for 270degree clock
 * generation: ctrl_offsetd[7] = 1 : (tFS: fine step delay) 270degree delay
 * amount − ctrl_offsetd[6:0] x tFS ctrl_offsetd[7] = 0 : 270degree delay amount +
 * ctrl_offsetd[6:0] x tFS Initial Value = 0x8
 */
/*@{*/
#define BP_DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD (0U) /*!< Bit position for DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD. */
#define BM_DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD (0x000000FFU) /*!< Bit mask for DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD. */
#define BS_DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD (8U) /*!< Bit field size in bits for DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD. */

/*! @brief Read current value of the DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD field. */
#define BR_DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD(x) (HW_DDR_PHY_CMD_SDLL_CON0(x).B.CTRL_OFFSETD)

/*! @brief Format value for bitfield DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD. */
#define BF_DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD) & BM_DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD)

/*! @brief Set the CTRL_OFFSETD field to a new value. */
#define BW_DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD(x, v) (HW_DDR_PHY_CMD_SDLL_CON0_WR(x, (HW_DDR_PHY_CMD_SDLL_CON0_RD(x) & ~BM_DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD) | BF_DDR_PHY_CMD_SDLL_CON0_CTRL_OFFSETD(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_CMD_SDLL_CON0, field CTRL_RESYNC[24] (RW)
 *
 * Active RISIG-EDGE signal. This signal should become LOW after set HIGH for
 * normal operation.When this bit transits from LOW to HIGH, pointers of FIFO and
 * DLL information is updated. In general, this bit should be set during
 * initialization and refresh cycles. Refer to "DLL Code Update" to use ctrl_resync.
 * Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_CMD_SDLL_CON0_CTRL_RESYNC (24U) /*!< Bit position for DDR_PHY_CMD_SDLL_CON0_CTRL_RESYNC. */
#define BM_DDR_PHY_CMD_SDLL_CON0_CTRL_RESYNC (0x01000000U) /*!< Bit mask for DDR_PHY_CMD_SDLL_CON0_CTRL_RESYNC. */
#define BS_DDR_PHY_CMD_SDLL_CON0_CTRL_RESYNC (1U) /*!< Bit field size in bits for DDR_PHY_CMD_SDLL_CON0_CTRL_RESYNC. */

/*! @brief Read current value of the DDR_PHY_CMD_SDLL_CON0_CTRL_RESYNC field. */
#define BR_DDR_PHY_CMD_SDLL_CON0_CTRL_RESYNC(x) (HW_DDR_PHY_CMD_SDLL_CON0(x).B.CTRL_RESYNC)

/*! @brief Format value for bitfield DDR_PHY_CMD_SDLL_CON0_CTRL_RESYNC. */
#define BF_DDR_PHY_CMD_SDLL_CON0_CTRL_RESYNC(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_CMD_SDLL_CON0_CTRL_RESYNC) & BM_DDR_PHY_CMD_SDLL_CON0_CTRL_RESYNC)

/*! @brief Set the CTRL_RESYNC field to a new value. */
#define BW_DDR_PHY_CMD_SDLL_CON0_CTRL_RESYNC(x, v) (HW_DDR_PHY_CMD_SDLL_CON0_WR(x, (HW_DDR_PHY_CMD_SDLL_CON0_RD(x) & ~BM_DDR_PHY_CMD_SDLL_CON0_CTRL_RESYNC) | BF_DDR_PHY_CMD_SDLL_CON0_CTRL_RESYNC(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_CMD_SDLL_CON0, field UPD_MODE[28] (RW)
 *
 * This field controls "PHY Update" Mode. Initial Value = 0x1
 */
/*@{*/
#define BP_DDR_PHY_CMD_SDLL_CON0_UPD_MODE (28U) /*!< Bit position for DDR_PHY_CMD_SDLL_CON0_UPD_MODE. */
#define BM_DDR_PHY_CMD_SDLL_CON0_UPD_MODE (0x10000000U) /*!< Bit mask for DDR_PHY_CMD_SDLL_CON0_UPD_MODE. */
#define BS_DDR_PHY_CMD_SDLL_CON0_UPD_MODE (1U) /*!< Bit field size in bits for DDR_PHY_CMD_SDLL_CON0_UPD_MODE. */

/*! @brief Read current value of the DDR_PHY_CMD_SDLL_CON0_UPD_MODE field. */
#define BR_DDR_PHY_CMD_SDLL_CON0_UPD_MODE(x) (HW_DDR_PHY_CMD_SDLL_CON0(x).B.UPD_MODE)

/*! @brief Format value for bitfield DDR_PHY_CMD_SDLL_CON0_UPD_MODE. */
#define BF_DDR_PHY_CMD_SDLL_CON0_UPD_MODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_CMD_SDLL_CON0_UPD_MODE) & BM_DDR_PHY_CMD_SDLL_CON0_UPD_MODE)

/*! @brief Set the UPD_MODE field to a new value. */
#define BW_DDR_PHY_CMD_SDLL_CON0_UPD_MODE(x, v) (HW_DDR_PHY_CMD_SDLL_CON0_WR(x, (HW_DDR_PHY_CMD_SDLL_CON0_RD(x) & ~BM_DDR_PHY_CMD_SDLL_CON0_UPD_MODE) | BF_DDR_PHY_CMD_SDLL_CON0_UPD_MODE(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_LVL_CON0 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_LVL_CON0 -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_lvl_con0
{
    uint32_t U;
    struct _hw_ddr_phy_lvl_con0_bitfields
    {
        uint32_t ctrl_wrlvl0_code : 8; /*!< [7:0]  */
        uint32_t ctrl_wrlvl1_code : 8; /*!< [15:8]  */
        uint32_t ctrl_wrlvl2_code : 8; /*!< [23:16]  */
        uint32_t ctrl_wrlvl3_code : 8; /*!< [31:24]  */
    } B;
} hw_ddr_phy_lvl_con0_t;

/*!
 * @name Constants and macros for entire DDR_PHY_LVL_CON0 register
 */
/*@{*/
#define HW_DDR_PHY_LVL_CON0_ADDR(x) ((uintptr_t)(x) + 0x6CU)

#define HW_DDR_PHY_LVL_CON0(x)   (*(__IO hw_ddr_phy_lvl_con0_t *) HW_DDR_PHY_LVL_CON0_ADDR(x))
#define HW_DDR_PHY_LVL_CON0_RD(x) (HW_DDR_PHY_LVL_CON0(x).U)
#define HW_DDR_PHY_LVL_CON0_WR(x, v) (HW_DDR_PHY_LVL_CON0(x).U = (v))
#define HW_DDR_PHY_LVL_CON0_SET(x, v) (HW_DDR_PHY_LVL_CON0_WR(x, HW_DDR_PHY_LVL_CON0_RD(x) |  (v)))
#define HW_DDR_PHY_LVL_CON0_CLR(x, v) (HW_DDR_PHY_LVL_CON0_WR(x, HW_DDR_PHY_LVL_CON0_RD(x) & ~(v)))
#define HW_DDR_PHY_LVL_CON0_TOG(x, v) (HW_DDR_PHY_LVL_CON0_WR(x, HW_DDR_PHY_LVL_CON0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_LVL_CON0 bitfields
 */

/*!
 * @name Register DDR_PHY_LVL_CON0, field ctrl_wrlvl0_code[7:0] (RW)
 *
 * Write Level Slave DLL Code Value for Data_Slice 0 Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_LVL_CON0_ctrl_wrlvl0_code (0U) /*!< Bit position for DDR_PHY_LVL_CON0_ctrl_wrlvl0_code. */
#define BM_DDR_PHY_LVL_CON0_ctrl_wrlvl0_code (0x000000FFU) /*!< Bit mask for DDR_PHY_LVL_CON0_ctrl_wrlvl0_code. */
#define BS_DDR_PHY_LVL_CON0_ctrl_wrlvl0_code (8U) /*!< Bit field size in bits for DDR_PHY_LVL_CON0_ctrl_wrlvl0_code. */

/*! @brief Read current value of the DDR_PHY_LVL_CON0_ctrl_wrlvl0_code field. */
#define BR_DDR_PHY_LVL_CON0_ctrl_wrlvl0_code(x) (HW_DDR_PHY_LVL_CON0(x).B.ctrl_wrlvl0_code)

/*! @brief Format value for bitfield DDR_PHY_LVL_CON0_ctrl_wrlvl0_code. */
#define BF_DDR_PHY_LVL_CON0_ctrl_wrlvl0_code(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_LVL_CON0_ctrl_wrlvl0_code) & BM_DDR_PHY_LVL_CON0_ctrl_wrlvl0_code)

/*! @brief Set the ctrl_wrlvl0_code field to a new value. */
#define BW_DDR_PHY_LVL_CON0_ctrl_wrlvl0_code(x, v) (HW_DDR_PHY_LVL_CON0_WR(x, (HW_DDR_PHY_LVL_CON0_RD(x) & ~BM_DDR_PHY_LVL_CON0_ctrl_wrlvl0_code) | BF_DDR_PHY_LVL_CON0_ctrl_wrlvl0_code(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_LVL_CON0, field ctrl_wrlvl1_code[15:8] (RW)
 *
 * Write Level Slave DLL Code Value for Data_Slice 1 Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_LVL_CON0_ctrl_wrlvl1_code (8U) /*!< Bit position for DDR_PHY_LVL_CON0_ctrl_wrlvl1_code. */
#define BM_DDR_PHY_LVL_CON0_ctrl_wrlvl1_code (0x0000FF00U) /*!< Bit mask for DDR_PHY_LVL_CON0_ctrl_wrlvl1_code. */
#define BS_DDR_PHY_LVL_CON0_ctrl_wrlvl1_code (8U) /*!< Bit field size in bits for DDR_PHY_LVL_CON0_ctrl_wrlvl1_code. */

/*! @brief Read current value of the DDR_PHY_LVL_CON0_ctrl_wrlvl1_code field. */
#define BR_DDR_PHY_LVL_CON0_ctrl_wrlvl1_code(x) (HW_DDR_PHY_LVL_CON0(x).B.ctrl_wrlvl1_code)

/*! @brief Format value for bitfield DDR_PHY_LVL_CON0_ctrl_wrlvl1_code. */
#define BF_DDR_PHY_LVL_CON0_ctrl_wrlvl1_code(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_LVL_CON0_ctrl_wrlvl1_code) & BM_DDR_PHY_LVL_CON0_ctrl_wrlvl1_code)

/*! @brief Set the ctrl_wrlvl1_code field to a new value. */
#define BW_DDR_PHY_LVL_CON0_ctrl_wrlvl1_code(x, v) (HW_DDR_PHY_LVL_CON0_WR(x, (HW_DDR_PHY_LVL_CON0_RD(x) & ~BM_DDR_PHY_LVL_CON0_ctrl_wrlvl1_code) | BF_DDR_PHY_LVL_CON0_ctrl_wrlvl1_code(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_LVL_CON0, field ctrl_wrlvl2_code[23:16] (RW)
 *
 * Write Level Slave DLL Code Value for Data_Slice 2 Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_LVL_CON0_ctrl_wrlvl2_code (16U) /*!< Bit position for DDR_PHY_LVL_CON0_ctrl_wrlvl2_code. */
#define BM_DDR_PHY_LVL_CON0_ctrl_wrlvl2_code (0x00FF0000U) /*!< Bit mask for DDR_PHY_LVL_CON0_ctrl_wrlvl2_code. */
#define BS_DDR_PHY_LVL_CON0_ctrl_wrlvl2_code (8U) /*!< Bit field size in bits for DDR_PHY_LVL_CON0_ctrl_wrlvl2_code. */

/*! @brief Read current value of the DDR_PHY_LVL_CON0_ctrl_wrlvl2_code field. */
#define BR_DDR_PHY_LVL_CON0_ctrl_wrlvl2_code(x) (HW_DDR_PHY_LVL_CON0(x).B.ctrl_wrlvl2_code)

/*! @brief Format value for bitfield DDR_PHY_LVL_CON0_ctrl_wrlvl2_code. */
#define BF_DDR_PHY_LVL_CON0_ctrl_wrlvl2_code(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_LVL_CON0_ctrl_wrlvl2_code) & BM_DDR_PHY_LVL_CON0_ctrl_wrlvl2_code)

/*! @brief Set the ctrl_wrlvl2_code field to a new value. */
#define BW_DDR_PHY_LVL_CON0_ctrl_wrlvl2_code(x, v) (HW_DDR_PHY_LVL_CON0_WR(x, (HW_DDR_PHY_LVL_CON0_RD(x) & ~BM_DDR_PHY_LVL_CON0_ctrl_wrlvl2_code) | BF_DDR_PHY_LVL_CON0_ctrl_wrlvl2_code(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_LVL_CON0, field ctrl_wrlvl3_code[31:24] (RW)
 *
 * Write Level Slave DLL Code Value for Data_Slice 3 Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_LVL_CON0_ctrl_wrlvl3_code (24U) /*!< Bit position for DDR_PHY_LVL_CON0_ctrl_wrlvl3_code. */
#define BM_DDR_PHY_LVL_CON0_ctrl_wrlvl3_code (0xFF000000U) /*!< Bit mask for DDR_PHY_LVL_CON0_ctrl_wrlvl3_code. */
#define BS_DDR_PHY_LVL_CON0_ctrl_wrlvl3_code (8U) /*!< Bit field size in bits for DDR_PHY_LVL_CON0_ctrl_wrlvl3_code. */

/*! @brief Read current value of the DDR_PHY_LVL_CON0_ctrl_wrlvl3_code field. */
#define BR_DDR_PHY_LVL_CON0_ctrl_wrlvl3_code(x) (HW_DDR_PHY_LVL_CON0(x).B.ctrl_wrlvl3_code)

/*! @brief Format value for bitfield DDR_PHY_LVL_CON0_ctrl_wrlvl3_code. */
#define BF_DDR_PHY_LVL_CON0_ctrl_wrlvl3_code(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_LVL_CON0_ctrl_wrlvl3_code) & BM_DDR_PHY_LVL_CON0_ctrl_wrlvl3_code)

/*! @brief Set the ctrl_wrlvl3_code field to a new value. */
#define BW_DDR_PHY_LVL_CON0_ctrl_wrlvl3_code(x, v) (HW_DDR_PHY_LVL_CON0_WR(x, (HW_DDR_PHY_LVL_CON0_RD(x) & ~BM_DDR_PHY_LVL_CON0_ctrl_wrlvl3_code) | BF_DDR_PHY_LVL_CON0_ctrl_wrlvl3_code(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_LVL_CON3 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_LVL_CON3 -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_lvl_con3
{
    uint32_t U;
    struct _hw_ddr_phy_lvl_con3_bitfields
    {
        uint32_t CTRL_WRLVL_RESYNC : 1; /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_ddr_phy_lvl_con3_t;

/*!
 * @name Constants and macros for entire DDR_PHY_LVL_CON3 register
 */
/*@{*/
#define HW_DDR_PHY_LVL_CON3_ADDR(x) ((uintptr_t)(x) + 0x78U)

#define HW_DDR_PHY_LVL_CON3(x)   (*(__IO hw_ddr_phy_lvl_con3_t *) HW_DDR_PHY_LVL_CON3_ADDR(x))
#define HW_DDR_PHY_LVL_CON3_RD(x) (HW_DDR_PHY_LVL_CON3(x).U)
#define HW_DDR_PHY_LVL_CON3_WR(x, v) (HW_DDR_PHY_LVL_CON3(x).U = (v))
#define HW_DDR_PHY_LVL_CON3_SET(x, v) (HW_DDR_PHY_LVL_CON3_WR(x, HW_DDR_PHY_LVL_CON3_RD(x) |  (v)))
#define HW_DDR_PHY_LVL_CON3_CLR(x, v) (HW_DDR_PHY_LVL_CON3_WR(x, HW_DDR_PHY_LVL_CON3_RD(x) & ~(v)))
#define HW_DDR_PHY_LVL_CON3_TOG(x, v) (HW_DDR_PHY_LVL_CON3_WR(x, HW_DDR_PHY_LVL_CON3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_LVL_CON3 bitfields
 */

/*!
 * @name Register DDR_PHY_LVL_CON3, field CTRL_WRLVL_RESYNC[0] (RW)
 *
 * Write Level DLL Code Update Enable Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_LVL_CON3_CTRL_WRLVL_RESYNC (0U) /*!< Bit position for DDR_PHY_LVL_CON3_CTRL_WRLVL_RESYNC. */
#define BM_DDR_PHY_LVL_CON3_CTRL_WRLVL_RESYNC (0x00000001U) /*!< Bit mask for DDR_PHY_LVL_CON3_CTRL_WRLVL_RESYNC. */
#define BS_DDR_PHY_LVL_CON3_CTRL_WRLVL_RESYNC (1U) /*!< Bit field size in bits for DDR_PHY_LVL_CON3_CTRL_WRLVL_RESYNC. */

/*! @brief Read current value of the DDR_PHY_LVL_CON3_CTRL_WRLVL_RESYNC field. */
#define BR_DDR_PHY_LVL_CON3_CTRL_WRLVL_RESYNC(x) (HW_DDR_PHY_LVL_CON3(x).B.CTRL_WRLVL_RESYNC)

/*! @brief Format value for bitfield DDR_PHY_LVL_CON3_CTRL_WRLVL_RESYNC. */
#define BF_DDR_PHY_LVL_CON3_CTRL_WRLVL_RESYNC(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_LVL_CON3_CTRL_WRLVL_RESYNC) & BM_DDR_PHY_LVL_CON3_CTRL_WRLVL_RESYNC)

/*! @brief Set the CTRL_WRLVL_RESYNC field to a new value. */
#define BW_DDR_PHY_LVL_CON3_CTRL_WRLVL_RESYNC(x, v) (HW_DDR_PHY_LVL_CON3_WR(x, (HW_DDR_PHY_LVL_CON3_RD(x) & ~BM_DDR_PHY_LVL_CON3_CTRL_WRLVL_RESYNC) | BF_DDR_PHY_LVL_CON3_CTRL_WRLVL_RESYNC(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_CMD_DESKEW_CON0 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_CMD_DESKEW_CON0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * CMD DESKEW Control Register
 */
typedef union _hw_ddr_phy_cmd_deskew_con0
{
    uint32_t U;
    struct _hw_ddr_phy_cmd_deskew_con0_bitfields
    {
        uint32_t CA1DESKEWCODE_0 : 8;  /*!< [7:0]  */
        uint32_t CA1DESKEWCODE_1 : 8;  /*!< [15:8]  */
        uint32_t CA2DESKEWCODE : 8;    /*!< [23:16]  */
        uint32_t CA3DESKEWCODE : 8;    /*!< [31:24]  */
    } B;
} hw_ddr_phy_cmd_deskew_con0_t;

/*!
 * @name Constants and macros for entire DDR_PHY_CMD_DESKEW_CON0 register
 */
/*@{*/
#define HW_DDR_PHY_CMD_DESKEW_CON0_ADDR(x) ((uintptr_t)(x) + 0x7CU)

#define HW_DDR_PHY_CMD_DESKEW_CON0(x) (*(__IO hw_ddr_phy_cmd_deskew_con0_t *) HW_DDR_PHY_CMD_DESKEW_CON0_ADDR(x))
#define HW_DDR_PHY_CMD_DESKEW_CON0_RD(x) (HW_DDR_PHY_CMD_DESKEW_CON0(x).U)
#define HW_DDR_PHY_CMD_DESKEW_CON0_WR(x, v) (HW_DDR_PHY_CMD_DESKEW_CON0(x).U = (v))
#define HW_DDR_PHY_CMD_DESKEW_CON0_SET(x, v) (HW_DDR_PHY_CMD_DESKEW_CON0_WR(x, HW_DDR_PHY_CMD_DESKEW_CON0_RD(x) |  (v)))
#define HW_DDR_PHY_CMD_DESKEW_CON0_CLR(x, v) (HW_DDR_PHY_CMD_DESKEW_CON0_WR(x, HW_DDR_PHY_CMD_DESKEW_CON0_RD(x) & ~(v)))
#define HW_DDR_PHY_CMD_DESKEW_CON0_TOG(x, v) (HW_DDR_PHY_CMD_DESKEW_CON0_WR(x, HW_DDR_PHY_CMD_DESKEW_CON0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_CMD_DESKEW_CON0 bitfields
 */

/*!
 * @name Register DDR_PHY_CMD_DESKEW_CON0, field CA1DESKEWCODE_0[7:0] (RW)
 *
 * DeSkew Code for CA[0] Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0 (0U) /*!< Bit position for DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0. */
#define BM_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0 (0x000000FFU) /*!< Bit mask for DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0. */
#define BS_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0 (8U) /*!< Bit field size in bits for DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0. */

/*! @brief Read current value of the DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0 field. */
#define BR_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0(x) (HW_DDR_PHY_CMD_DESKEW_CON0(x).B.CA1DESKEWCODE_0)

/*! @brief Format value for bitfield DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0. */
#define BF_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0) & BM_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0)

/*! @brief Set the CA1DESKEWCODE_0 field to a new value. */
#define BW_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0(x, v) (HW_DDR_PHY_CMD_DESKEW_CON0_WR(x, (HW_DDR_PHY_CMD_DESKEW_CON0_RD(x) & ~BM_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0) | BF_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_0(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_CMD_DESKEW_CON0, field CA1DESKEWCODE_1[15:8] (RW)
 *
 * DeSkew Code for CA[1] Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1 (8U) /*!< Bit position for DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1. */
#define BM_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1. */
#define BS_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1 (8U) /*!< Bit field size in bits for DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1. */

/*! @brief Read current value of the DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1 field. */
#define BR_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1(x) (HW_DDR_PHY_CMD_DESKEW_CON0(x).B.CA1DESKEWCODE_1)

/*! @brief Format value for bitfield DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1. */
#define BF_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1) & BM_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1)

/*! @brief Set the CA1DESKEWCODE_1 field to a new value. */
#define BW_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1(x, v) (HW_DDR_PHY_CMD_DESKEW_CON0_WR(x, (HW_DDR_PHY_CMD_DESKEW_CON0_RD(x) & ~BM_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1) | BF_DDR_PHY_CMD_DESKEW_CON0_CA1DESKEWCODE_1(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_CMD_DESKEW_CON0, field CA2DESKEWCODE[23:16] (RW)
 *
 * DeSkew Code for CA[2] Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE (16U) /*!< Bit position for DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE. */
#define BM_DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE (0x00FF0000U) /*!< Bit mask for DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE. */
#define BS_DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE (8U) /*!< Bit field size in bits for DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE. */

/*! @brief Read current value of the DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE field. */
#define BR_DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE(x) (HW_DDR_PHY_CMD_DESKEW_CON0(x).B.CA2DESKEWCODE)

/*! @brief Format value for bitfield DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE. */
#define BF_DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE) & BM_DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE)

/*! @brief Set the CA2DESKEWCODE field to a new value. */
#define BW_DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE(x, v) (HW_DDR_PHY_CMD_DESKEW_CON0_WR(x, (HW_DDR_PHY_CMD_DESKEW_CON0_RD(x) & ~BM_DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE) | BF_DDR_PHY_CMD_DESKEW_CON0_CA2DESKEWCODE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_CMD_DESKEW_CON0, field CA3DESKEWCODE[31:24] (RW)
 *
 * DeSkew Code for CA[3] Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE (24U) /*!< Bit position for DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE. */
#define BM_DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE (0xFF000000U) /*!< Bit mask for DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE. */
#define BS_DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE (8U) /*!< Bit field size in bits for DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE. */

/*! @brief Read current value of the DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE field. */
#define BR_DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE(x) (HW_DDR_PHY_CMD_DESKEW_CON0(x).B.CA3DESKEWCODE)

/*! @brief Format value for bitfield DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE. */
#define BF_DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE) & BM_DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE)

/*! @brief Set the CA3DESKEWCODE field to a new value. */
#define BW_DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE(x, v) (HW_DDR_PHY_CMD_DESKEW_CON0_WR(x, (HW_DDR_PHY_CMD_DESKEW_CON0_RD(x) & ~BM_DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE) | BF_DDR_PHY_CMD_DESKEW_CON0_CA3DESKEWCODE(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_CMD_DESKEW_CON1 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_CMD_DESKEW_CON1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * CMD DESKEW Control Register
 */
typedef union _hw_ddr_phy_cmd_deskew_con1
{
    uint32_t U;
    struct _hw_ddr_phy_cmd_deskew_con1_bitfields
    {
        uint32_t CA4DESKEWCODE : 8;    /*!< [7:0]  */
        uint32_t CA5DESKEWCODE : 8;    /*!< [15:8]  */
        uint32_t CA6DESKEWCODE : 8;    /*!< [23:16]  */
        uint32_t CA7DESKEWCODE : 8;    /*!< [31:24]  */
    } B;
} hw_ddr_phy_cmd_deskew_con1_t;

/*!
 * @name Constants and macros for entire DDR_PHY_CMD_DESKEW_CON1 register
 */
/*@{*/
#define HW_DDR_PHY_CMD_DESKEW_CON1_ADDR(x) ((uintptr_t)(x) + 0x80U)

#define HW_DDR_PHY_CMD_DESKEW_CON1(x) (*(__IO hw_ddr_phy_cmd_deskew_con1_t *) HW_DDR_PHY_CMD_DESKEW_CON1_ADDR(x))
#define HW_DDR_PHY_CMD_DESKEW_CON1_RD(x) (HW_DDR_PHY_CMD_DESKEW_CON1(x).U)
#define HW_DDR_PHY_CMD_DESKEW_CON1_WR(x, v) (HW_DDR_PHY_CMD_DESKEW_CON1(x).U = (v))
#define HW_DDR_PHY_CMD_DESKEW_CON1_SET(x, v) (HW_DDR_PHY_CMD_DESKEW_CON1_WR(x, HW_DDR_PHY_CMD_DESKEW_CON1_RD(x) |  (v)))
#define HW_DDR_PHY_CMD_DESKEW_CON1_CLR(x, v) (HW_DDR_PHY_CMD_DESKEW_CON1_WR(x, HW_DDR_PHY_CMD_DESKEW_CON1_RD(x) & ~(v)))
#define HW_DDR_PHY_CMD_DESKEW_CON1_TOG(x, v) (HW_DDR_PHY_CMD_DESKEW_CON1_WR(x, HW_DDR_PHY_CMD_DESKEW_CON1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_CMD_DESKEW_CON1 bitfields
 */

/*!
 * @name Register DDR_PHY_CMD_DESKEW_CON1, field CA4DESKEWCODE[7:0] (RW)
 *
 * DeSkew Code for CA[4] Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE (0U) /*!< Bit position for DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE. */
#define BM_DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE (0x000000FFU) /*!< Bit mask for DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE. */
#define BS_DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE (8U) /*!< Bit field size in bits for DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE. */

/*! @brief Read current value of the DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE field. */
#define BR_DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE(x) (HW_DDR_PHY_CMD_DESKEW_CON1(x).B.CA4DESKEWCODE)

/*! @brief Format value for bitfield DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE. */
#define BF_DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE) & BM_DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE)

/*! @brief Set the CA4DESKEWCODE field to a new value. */
#define BW_DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE(x, v) (HW_DDR_PHY_CMD_DESKEW_CON1_WR(x, (HW_DDR_PHY_CMD_DESKEW_CON1_RD(x) & ~BM_DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE) | BF_DDR_PHY_CMD_DESKEW_CON1_CA4DESKEWCODE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_CMD_DESKEW_CON1, field CA5DESKEWCODE[15:8] (RW)
 *
 * DeSkew Code for CA[5] Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE (8U) /*!< Bit position for DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE. */
#define BM_DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE (0x0000FF00U) /*!< Bit mask for DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE. */
#define BS_DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE (8U) /*!< Bit field size in bits for DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE. */

/*! @brief Read current value of the DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE field. */
#define BR_DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE(x) (HW_DDR_PHY_CMD_DESKEW_CON1(x).B.CA5DESKEWCODE)

/*! @brief Format value for bitfield DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE. */
#define BF_DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE) & BM_DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE)

/*! @brief Set the CA5DESKEWCODE field to a new value. */
#define BW_DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE(x, v) (HW_DDR_PHY_CMD_DESKEW_CON1_WR(x, (HW_DDR_PHY_CMD_DESKEW_CON1_RD(x) & ~BM_DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE) | BF_DDR_PHY_CMD_DESKEW_CON1_CA5DESKEWCODE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_CMD_DESKEW_CON1, field CA6DESKEWCODE[23:16] (RW)
 *
 * DeSkew Code for CA[6] Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE (16U) /*!< Bit position for DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE. */
#define BM_DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE (0x00FF0000U) /*!< Bit mask for DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE. */
#define BS_DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE (8U) /*!< Bit field size in bits for DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE. */

/*! @brief Read current value of the DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE field. */
#define BR_DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE(x) (HW_DDR_PHY_CMD_DESKEW_CON1(x).B.CA6DESKEWCODE)

/*! @brief Format value for bitfield DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE. */
#define BF_DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE) & BM_DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE)

/*! @brief Set the CA6DESKEWCODE field to a new value. */
#define BW_DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE(x, v) (HW_DDR_PHY_CMD_DESKEW_CON1_WR(x, (HW_DDR_PHY_CMD_DESKEW_CON1_RD(x) & ~BM_DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE) | BF_DDR_PHY_CMD_DESKEW_CON1_CA6DESKEWCODE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_CMD_DESKEW_CON1, field CA7DESKEWCODE[31:24] (RW)
 *
 * DeSkew Code for CA[7] Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE (24U) /*!< Bit position for DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE. */
#define BM_DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE (0xFF000000U) /*!< Bit mask for DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE. */
#define BS_DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE (8U) /*!< Bit field size in bits for DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE. */

/*! @brief Read current value of the DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE field. */
#define BR_DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE(x) (HW_DDR_PHY_CMD_DESKEW_CON1(x).B.CA7DESKEWCODE)

/*! @brief Format value for bitfield DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE. */
#define BF_DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE) & BM_DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE)

/*! @brief Set the CA7DESKEWCODE field to a new value. */
#define BW_DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE(x, v) (HW_DDR_PHY_CMD_DESKEW_CON1_WR(x, (HW_DDR_PHY_CMD_DESKEW_CON1_RD(x) & ~BM_DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE) | BF_DDR_PHY_CMD_DESKEW_CON1_CA7DESKEWCODE(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_CMD_DESKEW_CON2 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_CMD_DESKEW_CON2 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * CMD DESKEW Control Register
 */
typedef union _hw_ddr_phy_cmd_deskew_con2
{
    uint32_t U;
    struct _hw_ddr_phy_cmd_deskew_con2_bitfields
    {
        uint32_t CA8DESKEWCODE : 8;    /*!< [7:0]  */
        uint32_t CA9DESKEWCODE : 8;    /*!< [15:8]  */
        uint32_t CKDESKEWCODE : 8;     /*!< [23:16]  */
        uint32_t CS0DESKEWCODE : 8;    /*!< [31:24]  */
    } B;
} hw_ddr_phy_cmd_deskew_con2_t;

/*!
 * @name Constants and macros for entire DDR_PHY_CMD_DESKEW_CON2 register
 */
/*@{*/
#define HW_DDR_PHY_CMD_DESKEW_CON2_ADDR(x) ((uintptr_t)(x) + 0x84U)

#define HW_DDR_PHY_CMD_DESKEW_CON2(x) (*(__IO hw_ddr_phy_cmd_deskew_con2_t *) HW_DDR_PHY_CMD_DESKEW_CON2_ADDR(x))
#define HW_DDR_PHY_CMD_DESKEW_CON2_RD(x) (HW_DDR_PHY_CMD_DESKEW_CON2(x).U)
#define HW_DDR_PHY_CMD_DESKEW_CON2_WR(x, v) (HW_DDR_PHY_CMD_DESKEW_CON2(x).U = (v))
#define HW_DDR_PHY_CMD_DESKEW_CON2_SET(x, v) (HW_DDR_PHY_CMD_DESKEW_CON2_WR(x, HW_DDR_PHY_CMD_DESKEW_CON2_RD(x) |  (v)))
#define HW_DDR_PHY_CMD_DESKEW_CON2_CLR(x, v) (HW_DDR_PHY_CMD_DESKEW_CON2_WR(x, HW_DDR_PHY_CMD_DESKEW_CON2_RD(x) & ~(v)))
#define HW_DDR_PHY_CMD_DESKEW_CON2_TOG(x, v) (HW_DDR_PHY_CMD_DESKEW_CON2_WR(x, HW_DDR_PHY_CMD_DESKEW_CON2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_CMD_DESKEW_CON2 bitfields
 */

/*!
 * @name Register DDR_PHY_CMD_DESKEW_CON2, field CA8DESKEWCODE[7:0] (RW)
 *
 * DeSkew Code for CA[8] Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE (0U) /*!< Bit position for DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE. */
#define BM_DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE (0x000000FFU) /*!< Bit mask for DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE. */
#define BS_DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE (8U) /*!< Bit field size in bits for DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE. */

/*! @brief Read current value of the DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE field. */
#define BR_DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE(x) (HW_DDR_PHY_CMD_DESKEW_CON2(x).B.CA8DESKEWCODE)

/*! @brief Format value for bitfield DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE. */
#define BF_DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE) & BM_DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE)

/*! @brief Set the CA8DESKEWCODE field to a new value. */
#define BW_DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE(x, v) (HW_DDR_PHY_CMD_DESKEW_CON2_WR(x, (HW_DDR_PHY_CMD_DESKEW_CON2_RD(x) & ~BM_DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE) | BF_DDR_PHY_CMD_DESKEW_CON2_CA8DESKEWCODE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_CMD_DESKEW_CON2, field CA9DESKEWCODE[15:8] (RW)
 *
 * DeSkew Code for CA[9] Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE (8U) /*!< Bit position for DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE. */
#define BM_DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE (0x0000FF00U) /*!< Bit mask for DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE. */
#define BS_DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE (8U) /*!< Bit field size in bits for DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE. */

/*! @brief Read current value of the DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE field. */
#define BR_DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE(x) (HW_DDR_PHY_CMD_DESKEW_CON2(x).B.CA9DESKEWCODE)

/*! @brief Format value for bitfield DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE. */
#define BF_DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE) & BM_DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE)

/*! @brief Set the CA9DESKEWCODE field to a new value. */
#define BW_DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE(x, v) (HW_DDR_PHY_CMD_DESKEW_CON2_WR(x, (HW_DDR_PHY_CMD_DESKEW_CON2_RD(x) & ~BM_DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE) | BF_DDR_PHY_CMD_DESKEW_CON2_CA9DESKEWCODE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_CMD_DESKEW_CON2, field CKDESKEWCODE[23:16] (RW)
 *
 * DeSkew Code for CK Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE (16U) /*!< Bit position for DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE. */
#define BM_DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE (0x00FF0000U) /*!< Bit mask for DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE. */
#define BS_DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE (8U) /*!< Bit field size in bits for DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE. */

/*! @brief Read current value of the DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE field. */
#define BR_DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE(x) (HW_DDR_PHY_CMD_DESKEW_CON2(x).B.CKDESKEWCODE)

/*! @brief Format value for bitfield DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE. */
#define BF_DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE) & BM_DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE)

/*! @brief Set the CKDESKEWCODE field to a new value. */
#define BW_DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE(x, v) (HW_DDR_PHY_CMD_DESKEW_CON2_WR(x, (HW_DDR_PHY_CMD_DESKEW_CON2_RD(x) & ~BM_DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE) | BF_DDR_PHY_CMD_DESKEW_CON2_CKDESKEWCODE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_CMD_DESKEW_CON2, field CS0DESKEWCODE[31:24] (RW)
 *
 * DeSkew Code for CS0 Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE (24U) /*!< Bit position for DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE. */
#define BM_DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE (0xFF000000U) /*!< Bit mask for DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE. */
#define BS_DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE (8U) /*!< Bit field size in bits for DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE. */

/*! @brief Read current value of the DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE field. */
#define BR_DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE(x) (HW_DDR_PHY_CMD_DESKEW_CON2(x).B.CS0DESKEWCODE)

/*! @brief Format value for bitfield DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE. */
#define BF_DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE) & BM_DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE)

/*! @brief Set the CS0DESKEWCODE field to a new value. */
#define BW_DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE(x, v) (HW_DDR_PHY_CMD_DESKEW_CON2_WR(x, (HW_DDR_PHY_CMD_DESKEW_CON2_RD(x) & ~BM_DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE) | BF_DDR_PHY_CMD_DESKEW_CON2_CS0DESKEWCODE(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_CMD_DESKEW_CON3 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_CMD_DESKEW_CON3 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * If the DeSkew Code for CS[1:0], CK is changed, CKE should be always "LOW"
 * during updating. If the DeSkew Code for CKE[1:0] is changed, Please initialize
 * memory again.
 */
typedef union _hw_ddr_phy_cmd_deskew_con3
{
    uint32_t U;
    struct _hw_ddr_phy_cmd_deskew_con3_bitfields
    {
        uint32_t CS1DESKEWCODE : 8;    /*!< [7:0]  */
        uint32_t CKE0DESKEWCODE : 8;   /*!< [15:8]  */
        uint32_t CKE1DESKEWCODE : 8;   /*!< [23:16]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_ddr_phy_cmd_deskew_con3_t;

/*!
 * @name Constants and macros for entire DDR_PHY_CMD_DESKEW_CON3 register
 */
/*@{*/
#define HW_DDR_PHY_CMD_DESKEW_CON3_ADDR(x) ((uintptr_t)(x) + 0x88U)

#define HW_DDR_PHY_CMD_DESKEW_CON3(x) (*(__IO hw_ddr_phy_cmd_deskew_con3_t *) HW_DDR_PHY_CMD_DESKEW_CON3_ADDR(x))
#define HW_DDR_PHY_CMD_DESKEW_CON3_RD(x) (HW_DDR_PHY_CMD_DESKEW_CON3(x).U)
#define HW_DDR_PHY_CMD_DESKEW_CON3_WR(x, v) (HW_DDR_PHY_CMD_DESKEW_CON3(x).U = (v))
#define HW_DDR_PHY_CMD_DESKEW_CON3_SET(x, v) (HW_DDR_PHY_CMD_DESKEW_CON3_WR(x, HW_DDR_PHY_CMD_DESKEW_CON3_RD(x) |  (v)))
#define HW_DDR_PHY_CMD_DESKEW_CON3_CLR(x, v) (HW_DDR_PHY_CMD_DESKEW_CON3_WR(x, HW_DDR_PHY_CMD_DESKEW_CON3_RD(x) & ~(v)))
#define HW_DDR_PHY_CMD_DESKEW_CON3_TOG(x, v) (HW_DDR_PHY_CMD_DESKEW_CON3_WR(x, HW_DDR_PHY_CMD_DESKEW_CON3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_CMD_DESKEW_CON3 bitfields
 */

/*!
 * @name Register DDR_PHY_CMD_DESKEW_CON3, field CS1DESKEWCODE[7:0] (RW)
 *
 * DeSkew Code for CS1 Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE (0U) /*!< Bit position for DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE. */
#define BM_DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE (0x000000FFU) /*!< Bit mask for DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE. */
#define BS_DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE (8U) /*!< Bit field size in bits for DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE. */

/*! @brief Read current value of the DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE field. */
#define BR_DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE(x) (HW_DDR_PHY_CMD_DESKEW_CON3(x).B.CS1DESKEWCODE)

/*! @brief Format value for bitfield DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE. */
#define BF_DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE) & BM_DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE)

/*! @brief Set the CS1DESKEWCODE field to a new value. */
#define BW_DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE(x, v) (HW_DDR_PHY_CMD_DESKEW_CON3_WR(x, (HW_DDR_PHY_CMD_DESKEW_CON3_RD(x) & ~BM_DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE) | BF_DDR_PHY_CMD_DESKEW_CON3_CS1DESKEWCODE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_CMD_DESKEW_CON3, field CKE0DESKEWCODE[15:8] (RW)
 *
 * DeSkew Code for CKE0 Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE (8U) /*!< Bit position for DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE. */
#define BM_DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE (0x0000FF00U) /*!< Bit mask for DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE. */
#define BS_DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE (8U) /*!< Bit field size in bits for DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE. */

/*! @brief Read current value of the DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE field. */
#define BR_DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE(x) (HW_DDR_PHY_CMD_DESKEW_CON3(x).B.CKE0DESKEWCODE)

/*! @brief Format value for bitfield DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE. */
#define BF_DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE) & BM_DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE)

/*! @brief Set the CKE0DESKEWCODE field to a new value. */
#define BW_DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE(x, v) (HW_DDR_PHY_CMD_DESKEW_CON3_WR(x, (HW_DDR_PHY_CMD_DESKEW_CON3_RD(x) & ~BM_DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE) | BF_DDR_PHY_CMD_DESKEW_CON3_CKE0DESKEWCODE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_CMD_DESKEW_CON3, field CKE1DESKEWCODE[23:16] (RW)
 *
 * DeSkew Code for CKE1 Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE (16U) /*!< Bit position for DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE. */
#define BM_DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE (0x00FF0000U) /*!< Bit mask for DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE. */
#define BS_DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE (8U) /*!< Bit field size in bits for DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE. */

/*! @brief Read current value of the DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE field. */
#define BR_DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE(x) (HW_DDR_PHY_CMD_DESKEW_CON3(x).B.CKE1DESKEWCODE)

/*! @brief Format value for bitfield DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE. */
#define BF_DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE) & BM_DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE)

/*! @brief Set the CKE1DESKEWCODE field to a new value. */
#define BW_DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE(x, v) (HW_DDR_PHY_CMD_DESKEW_CON3_WR(x, (HW_DDR_PHY_CMD_DESKEW_CON3_RD(x) & ~BM_DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE) | BF_DDR_PHY_CMD_DESKEW_CON3_CKE1DESKEWCODE(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_CMD_DESKEW_CON4 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_CMD_DESKEW_CON4 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * CMD DESKEW Control Register
 */
typedef union _hw_ddr_phy_cmd_deskew_con4
{
    uint32_t U;
    struct _hw_ddr_phy_cmd_deskew_con4_bitfields
    {
        uint32_t RSTDESKEWCODE : 8;    /*!< [7:0]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_ddr_phy_cmd_deskew_con4_t;

/*!
 * @name Constants and macros for entire DDR_PHY_CMD_DESKEW_CON4 register
 */
/*@{*/
#define HW_DDR_PHY_CMD_DESKEW_CON4_ADDR(x) ((uintptr_t)(x) + 0x94U)

#define HW_DDR_PHY_CMD_DESKEW_CON4(x) (*(__IO hw_ddr_phy_cmd_deskew_con4_t *) HW_DDR_PHY_CMD_DESKEW_CON4_ADDR(x))
#define HW_DDR_PHY_CMD_DESKEW_CON4_RD(x) (HW_DDR_PHY_CMD_DESKEW_CON4(x).U)
#define HW_DDR_PHY_CMD_DESKEW_CON4_WR(x, v) (HW_DDR_PHY_CMD_DESKEW_CON4(x).U = (v))
#define HW_DDR_PHY_CMD_DESKEW_CON4_SET(x, v) (HW_DDR_PHY_CMD_DESKEW_CON4_WR(x, HW_DDR_PHY_CMD_DESKEW_CON4_RD(x) |  (v)))
#define HW_DDR_PHY_CMD_DESKEW_CON4_CLR(x, v) (HW_DDR_PHY_CMD_DESKEW_CON4_WR(x, HW_DDR_PHY_CMD_DESKEW_CON4_RD(x) & ~(v)))
#define HW_DDR_PHY_CMD_DESKEW_CON4_TOG(x, v) (HW_DDR_PHY_CMD_DESKEW_CON4_WR(x, HW_DDR_PHY_CMD_DESKEW_CON4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_CMD_DESKEW_CON4 bitfields
 */

/*!
 * @name Register DDR_PHY_CMD_DESKEW_CON4, field RSTDESKEWCODE[7:0] (RW)
 *
 * DeSkew Code for RST Initial Value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE (0U) /*!< Bit position for DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE. */
#define BM_DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE (0x000000FFU) /*!< Bit mask for DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE. */
#define BS_DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE (8U) /*!< Bit field size in bits for DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE. */

/*! @brief Read current value of the DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE field. */
#define BR_DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE(x) (HW_DDR_PHY_CMD_DESKEW_CON4(x).B.RSTDESKEWCODE)

/*! @brief Format value for bitfield DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE. */
#define BF_DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE) & BM_DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE)

/*! @brief Set the RSTDESKEWCODE field to a new value. */
#define BW_DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE(x, v) (HW_DDR_PHY_CMD_DESKEW_CON4_WR(x, (HW_DDR_PHY_CMD_DESKEW_CON4_RD(x) & ~BM_DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE) | BF_DDR_PHY_CMD_DESKEW_CON4_RSTDESKEWCODE(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_DRVDS_CON0 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_DRVDS_CON0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * Drive Strength Settings: 3'b000 : 240ohm Impedance output driver 3'b001 :
 * 120ohm Impedance output driver 3'b010 : 80ohm Impedance output driver 3'b011 :
 * 60ohm Impedance output driver 3'b100 : 48ohm Impedance output driver 3'b101 :
 * 40ohm Impedance output driver 3'b110 : 34ohm Impedance output driver 3'b111 :
 * 30ohm Impedance output driver It is recommended that Driver Strength will be one
 * of the following settings instead of 3'h0. 3'b100 : 48ohm Impedance output
 * driver 3'b101 : 40ohm Impedance output driver 3'b110 : 34ohm Impedance output
 * driver 3'b111 : 30ohm Impedance output driver
 */
typedef union _hw_ddr_phy_drvds_con0
{
    uint32_t U;
    struct _hw_ddr_phy_drvds_con0_bitfields
    {
        uint32_t CAADRDRVRDS : 3;      /*!< [2:0]  */
        uint32_t CACSDRVRDS : 3;       /*!< [5:3]  */
        uint32_t CACKEDRVRDS : 3;      /*!< [8:6]  */
        uint32_t CACKDRVRDS : 3;       /*!< [11:9]  */
        uint32_t RESERVED0 : 20;       /*!< [31:12]  */
    } B;
} hw_ddr_phy_drvds_con0_t;

/*!
 * @name Constants and macros for entire DDR_PHY_DRVDS_CON0 register
 */
/*@{*/
#define HW_DDR_PHY_DRVDS_CON0_ADDR(x) ((uintptr_t)(x) + 0x9CU)

#define HW_DDR_PHY_DRVDS_CON0(x) (*(__IO hw_ddr_phy_drvds_con0_t *) HW_DDR_PHY_DRVDS_CON0_ADDR(x))
#define HW_DDR_PHY_DRVDS_CON0_RD(x) (HW_DDR_PHY_DRVDS_CON0(x).U)
#define HW_DDR_PHY_DRVDS_CON0_WR(x, v) (HW_DDR_PHY_DRVDS_CON0(x).U = (v))
#define HW_DDR_PHY_DRVDS_CON0_SET(x, v) (HW_DDR_PHY_DRVDS_CON0_WR(x, HW_DDR_PHY_DRVDS_CON0_RD(x) |  (v)))
#define HW_DDR_PHY_DRVDS_CON0_CLR(x, v) (HW_DDR_PHY_DRVDS_CON0_WR(x, HW_DDR_PHY_DRVDS_CON0_RD(x) & ~(v)))
#define HW_DDR_PHY_DRVDS_CON0_TOG(x, v) (HW_DDR_PHY_DRVDS_CON0_WR(x, HW_DDR_PHY_DRVDS_CON0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_DRVDS_CON0 bitfields
 */

/*!
 * @name Register DDR_PHY_DRVDS_CON0, field CAADRDRVRDS[2:0] (RW)
 *
 * Driver strength for CA[9:0], RAS, CAS,WEN, ODT[1:0], RESET, BANK[2:0].
 * Initial value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_DRVDS_CON0_CAADRDRVRDS (0U) /*!< Bit position for DDR_PHY_DRVDS_CON0_CAADRDRVRDS. */
#define BM_DDR_PHY_DRVDS_CON0_CAADRDRVRDS (0x00000007U) /*!< Bit mask for DDR_PHY_DRVDS_CON0_CAADRDRVRDS. */
#define BS_DDR_PHY_DRVDS_CON0_CAADRDRVRDS (3U) /*!< Bit field size in bits for DDR_PHY_DRVDS_CON0_CAADRDRVRDS. */

/*! @brief Read current value of the DDR_PHY_DRVDS_CON0_CAADRDRVRDS field. */
#define BR_DDR_PHY_DRVDS_CON0_CAADRDRVRDS(x) (HW_DDR_PHY_DRVDS_CON0(x).B.CAADRDRVRDS)

/*! @brief Format value for bitfield DDR_PHY_DRVDS_CON0_CAADRDRVRDS. */
#define BF_DDR_PHY_DRVDS_CON0_CAADRDRVRDS(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_DRVDS_CON0_CAADRDRVRDS) & BM_DDR_PHY_DRVDS_CON0_CAADRDRVRDS)

/*! @brief Set the CAADRDRVRDS field to a new value. */
#define BW_DDR_PHY_DRVDS_CON0_CAADRDRVRDS(x, v) (HW_DDR_PHY_DRVDS_CON0_WR(x, (HW_DDR_PHY_DRVDS_CON0_RD(x) & ~BM_DDR_PHY_DRVDS_CON0_CAADRDRVRDS) | BF_DDR_PHY_DRVDS_CON0_CAADRDRVRDS(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_DRVDS_CON0, field CACSDRVRDS[5:3] (RW)
 *
 * Driver strength for CS[1:0] Initial value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_DRVDS_CON0_CACSDRVRDS (3U) /*!< Bit position for DDR_PHY_DRVDS_CON0_CACSDRVRDS. */
#define BM_DDR_PHY_DRVDS_CON0_CACSDRVRDS (0x00000038U) /*!< Bit mask for DDR_PHY_DRVDS_CON0_CACSDRVRDS. */
#define BS_DDR_PHY_DRVDS_CON0_CACSDRVRDS (3U) /*!< Bit field size in bits for DDR_PHY_DRVDS_CON0_CACSDRVRDS. */

/*! @brief Read current value of the DDR_PHY_DRVDS_CON0_CACSDRVRDS field. */
#define BR_DDR_PHY_DRVDS_CON0_CACSDRVRDS(x) (HW_DDR_PHY_DRVDS_CON0(x).B.CACSDRVRDS)

/*! @brief Format value for bitfield DDR_PHY_DRVDS_CON0_CACSDRVRDS. */
#define BF_DDR_PHY_DRVDS_CON0_CACSDRVRDS(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_DRVDS_CON0_CACSDRVRDS) & BM_DDR_PHY_DRVDS_CON0_CACSDRVRDS)

/*! @brief Set the CACSDRVRDS field to a new value. */
#define BW_DDR_PHY_DRVDS_CON0_CACSDRVRDS(x, v) (HW_DDR_PHY_DRVDS_CON0_WR(x, (HW_DDR_PHY_DRVDS_CON0_RD(x) & ~BM_DDR_PHY_DRVDS_CON0_CACSDRVRDS) | BF_DDR_PHY_DRVDS_CON0_CACSDRVRDS(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_DRVDS_CON0, field CACKEDRVRDS[8:6] (RW)
 *
 * Driver strength for CKE[1:0] Initial value = 0x0
 */
/*@{*/
#define BP_DDR_PHY_DRVDS_CON0_CACKEDRVRDS (6U) /*!< Bit position for DDR_PHY_DRVDS_CON0_CACKEDRVRDS. */
#define BM_DDR_PHY_DRVDS_CON0_CACKEDRVRDS (0x000001C0U) /*!< Bit mask for DDR_PHY_DRVDS_CON0_CACKEDRVRDS. */
#define BS_DDR_PHY_DRVDS_CON0_CACKEDRVRDS (3U) /*!< Bit field size in bits for DDR_PHY_DRVDS_CON0_CACKEDRVRDS. */

/*! @brief Read current value of the DDR_PHY_DRVDS_CON0_CACKEDRVRDS field. */
#define BR_DDR_PHY_DRVDS_CON0_CACKEDRVRDS(x) (HW_DDR_PHY_DRVDS_CON0(x).B.CACKEDRVRDS)

/*! @brief Format value for bitfield DDR_PHY_DRVDS_CON0_CACKEDRVRDS. */
#define BF_DDR_PHY_DRVDS_CON0_CACKEDRVRDS(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_DRVDS_CON0_CACKEDRVRDS) & BM_DDR_PHY_DRVDS_CON0_CACKEDRVRDS)

/*! @brief Set the CACKEDRVRDS field to a new value. */
#define BW_DDR_PHY_DRVDS_CON0_CACKEDRVRDS(x, v) (HW_DDR_PHY_DRVDS_CON0_WR(x, (HW_DDR_PHY_DRVDS_CON0_RD(x) & ~BM_DDR_PHY_DRVDS_CON0_CACKEDRVRDS) | BF_DDR_PHY_DRVDS_CON0_CACKEDRVRDS(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_DRVDS_CON0, field CACKDRVRDS[11:9] (RW)
 *
 * Driver strenght for CK Initial value = 0x0. See table above for register
 * setting values.
 */
/*@{*/
#define BP_DDR_PHY_DRVDS_CON0_CACKDRVRDS (9U) /*!< Bit position for DDR_PHY_DRVDS_CON0_CACKDRVRDS. */
#define BM_DDR_PHY_DRVDS_CON0_CACKDRVRDS (0x00000E00U) /*!< Bit mask for DDR_PHY_DRVDS_CON0_CACKDRVRDS. */
#define BS_DDR_PHY_DRVDS_CON0_CACKDRVRDS (3U) /*!< Bit field size in bits for DDR_PHY_DRVDS_CON0_CACKDRVRDS. */

/*! @brief Read current value of the DDR_PHY_DRVDS_CON0_CACKDRVRDS field. */
#define BR_DDR_PHY_DRVDS_CON0_CACKDRVRDS(x) (HW_DDR_PHY_DRVDS_CON0(x).B.CACKDRVRDS)

/*! @brief Format value for bitfield DDR_PHY_DRVDS_CON0_CACKDRVRDS. */
#define BF_DDR_PHY_DRVDS_CON0_CACKDRVRDS(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_DRVDS_CON0_CACKDRVRDS) & BM_DDR_PHY_DRVDS_CON0_CACKDRVRDS)

/*! @brief Set the CACKDRVRDS field to a new value. */
#define BW_DDR_PHY_DRVDS_CON0_CACKDRVRDS(x, v) (HW_DDR_PHY_DRVDS_CON0_WR(x, (HW_DDR_PHY_DRVDS_CON0_RD(x) & ~BM_DDR_PHY_DRVDS_CON0_CACKDRVRDS) | BF_DDR_PHY_DRVDS_CON0_CACKDRVRDS(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_MDLL_CON0 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_MDLL_CON0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * MDLL Control Register
 */
typedef union _hw_ddr_phy_mdll_con0
{
    uint32_t U;
    struct _hw_ddr_phy_mdll_con0_bitfields
    {
        uint32_t RESERVED0 : 1;        /*!< [0]  */
        uint32_t CTRL_REF : 4;         /*!< [4:1]  */
        uint32_t CTRL_DLL_ON : 1;      /*!< [5]  */
        uint32_t CTRL_START : 1;       /*!< [6]  */
        uint32_t CTRL_FORCE : 9;       /*!< [15:7]  */
        uint32_t CTRL_INC : 7;         /*!< [22:16]  */
        uint32_t RESERVED1 : 1;        /*!< [23]  */
        uint32_t CTRL_START_POINT : 7; /*!< [30:24]  */
        uint32_t RESERVED2 : 1;        /*!< [31]  */
    } B;
} hw_ddr_phy_mdll_con0_t;

/*!
 * @name Constants and macros for entire DDR_PHY_MDLL_CON0 register
 */
/*@{*/
#define HW_DDR_PHY_MDLL_CON0_ADDR(x) ((uintptr_t)(x) + 0xB0U)

#define HW_DDR_PHY_MDLL_CON0(x)  (*(__IO hw_ddr_phy_mdll_con0_t *) HW_DDR_PHY_MDLL_CON0_ADDR(x))
#define HW_DDR_PHY_MDLL_CON0_RD(x) (HW_DDR_PHY_MDLL_CON0(x).U)
#define HW_DDR_PHY_MDLL_CON0_WR(x, v) (HW_DDR_PHY_MDLL_CON0(x).U = (v))
#define HW_DDR_PHY_MDLL_CON0_SET(x, v) (HW_DDR_PHY_MDLL_CON0_WR(x, HW_DDR_PHY_MDLL_CON0_RD(x) |  (v)))
#define HW_DDR_PHY_MDLL_CON0_CLR(x, v) (HW_DDR_PHY_MDLL_CON0_WR(x, HW_DDR_PHY_MDLL_CON0_RD(x) & ~(v)))
#define HW_DDR_PHY_MDLL_CON0_TOG(x, v) (HW_DDR_PHY_MDLL_CON0_WR(x, HW_DDR_PHY_MDLL_CON0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_MDLL_CON0 bitfields
 */

/*!
 * @name Register DDR_PHY_MDLL_CON0, field CTRL_REF[4:1] (RW)
 *
 * This field determines the period of time when ctrl_locked is cleared. Initial
 * Value = 4'h8
 */
/*@{*/
#define BP_DDR_PHY_MDLL_CON0_CTRL_REF (1U) /*!< Bit position for DDR_PHY_MDLL_CON0_CTRL_REF. */
#define BM_DDR_PHY_MDLL_CON0_CTRL_REF (0x0000001EU) /*!< Bit mask for DDR_PHY_MDLL_CON0_CTRL_REF. */
#define BS_DDR_PHY_MDLL_CON0_CTRL_REF (4U) /*!< Bit field size in bits for DDR_PHY_MDLL_CON0_CTRL_REF. */

/*! @brief Read current value of the DDR_PHY_MDLL_CON0_CTRL_REF field. */
#define BR_DDR_PHY_MDLL_CON0_CTRL_REF(x) (HW_DDR_PHY_MDLL_CON0(x).B.CTRL_REF)

/*! @brief Format value for bitfield DDR_PHY_MDLL_CON0_CTRL_REF. */
#define BF_DDR_PHY_MDLL_CON0_CTRL_REF(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_MDLL_CON0_CTRL_REF) & BM_DDR_PHY_MDLL_CON0_CTRL_REF)

/*! @brief Set the CTRL_REF field to a new value. */
#define BW_DDR_PHY_MDLL_CON0_CTRL_REF(x, v) (HW_DDR_PHY_MDLL_CON0_WR(x, (HW_DDR_PHY_MDLL_CON0_RD(x) & ~BM_DDR_PHY_MDLL_CON0_CTRL_REF) | BF_DDR_PHY_MDLL_CON0_CTRL_REF(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_MDLL_CON0, field CTRL_DLL_ON[5] (RW)
 *
 * HIGH active start signal to turn on the DLL. This signal should be kept HIGH
 * for normal operation. If this signal becomes LOW, DLL is turned off. This bit
 * should be kept set before ctrl_start is set to turn on the DLL.HIGH active
 * start signal to turn on the DLL. This signal should be kept HIGH for normal
 * operation. If this signal becomes LOW, DLL is turned off. This bit should be kept
 * set before ctrl_start is set to turn on the DLL.Initial Value = 1'b1
 */
/*@{*/
#define BP_DDR_PHY_MDLL_CON0_CTRL_DLL_ON (5U) /*!< Bit position for DDR_PHY_MDLL_CON0_CTRL_DLL_ON. */
#define BM_DDR_PHY_MDLL_CON0_CTRL_DLL_ON (0x00000020U) /*!< Bit mask for DDR_PHY_MDLL_CON0_CTRL_DLL_ON. */
#define BS_DDR_PHY_MDLL_CON0_CTRL_DLL_ON (1U) /*!< Bit field size in bits for DDR_PHY_MDLL_CON0_CTRL_DLL_ON. */

/*! @brief Read current value of the DDR_PHY_MDLL_CON0_CTRL_DLL_ON field. */
#define BR_DDR_PHY_MDLL_CON0_CTRL_DLL_ON(x) (HW_DDR_PHY_MDLL_CON0(x).B.CTRL_DLL_ON)

/*! @brief Format value for bitfield DDR_PHY_MDLL_CON0_CTRL_DLL_ON. */
#define BF_DDR_PHY_MDLL_CON0_CTRL_DLL_ON(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_MDLL_CON0_CTRL_DLL_ON) & BM_DDR_PHY_MDLL_CON0_CTRL_DLL_ON)

/*! @brief Set the CTRL_DLL_ON field to a new value. */
#define BW_DDR_PHY_MDLL_CON0_CTRL_DLL_ON(x, v) (HW_DDR_PHY_MDLL_CON0_WR(x, (HW_DDR_PHY_MDLL_CON0_RD(x) & ~BM_DDR_PHY_MDLL_CON0_CTRL_DLL_ON) | BF_DDR_PHY_MDLL_CON0_CTRL_DLL_ON(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_MDLL_CON0, field CTRL_START[6] (RW)
 *
 * This field is used to start DLL locking. Initial Value = 1'b1
 */
/*@{*/
#define BP_DDR_PHY_MDLL_CON0_CTRL_START (6U) /*!< Bit position for DDR_PHY_MDLL_CON0_CTRL_START. */
#define BM_DDR_PHY_MDLL_CON0_CTRL_START (0x00000040U) /*!< Bit mask for DDR_PHY_MDLL_CON0_CTRL_START. */
#define BS_DDR_PHY_MDLL_CON0_CTRL_START (1U) /*!< Bit field size in bits for DDR_PHY_MDLL_CON0_CTRL_START. */

/*! @brief Read current value of the DDR_PHY_MDLL_CON0_CTRL_START field. */
#define BR_DDR_PHY_MDLL_CON0_CTRL_START(x) (HW_DDR_PHY_MDLL_CON0(x).B.CTRL_START)

/*! @brief Format value for bitfield DDR_PHY_MDLL_CON0_CTRL_START. */
#define BF_DDR_PHY_MDLL_CON0_CTRL_START(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_MDLL_CON0_CTRL_START) & BM_DDR_PHY_MDLL_CON0_CTRL_START)

/*! @brief Set the CTRL_START field to a new value. */
#define BW_DDR_PHY_MDLL_CON0_CTRL_START(x, v) (HW_DDR_PHY_MDLL_CON0_WR(x, (HW_DDR_PHY_MDLL_CON0_RD(x) & ~BM_DDR_PHY_MDLL_CON0_CTRL_START) | BF_DDR_PHY_MDLL_CON0_CTRL_START(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_MDLL_CON0, field CTRL_FORCE[15:7] (RW)
 *
 * This field is used instead of ctrl_lock_value[8:0] found by the DLL only when
 * ctrl_dll_on is LOW, i.e. If the DLL is off, this field is used to generate
 * 270degree clock and shift DQS by 90degree . Initial Value = 9'h00
 */
/*@{*/
#define BP_DDR_PHY_MDLL_CON0_CTRL_FORCE (7U) /*!< Bit position for DDR_PHY_MDLL_CON0_CTRL_FORCE. */
#define BM_DDR_PHY_MDLL_CON0_CTRL_FORCE (0x0000FF80U) /*!< Bit mask for DDR_PHY_MDLL_CON0_CTRL_FORCE. */
#define BS_DDR_PHY_MDLL_CON0_CTRL_FORCE (9U) /*!< Bit field size in bits for DDR_PHY_MDLL_CON0_CTRL_FORCE. */

/*! @brief Read current value of the DDR_PHY_MDLL_CON0_CTRL_FORCE field. */
#define BR_DDR_PHY_MDLL_CON0_CTRL_FORCE(x) (HW_DDR_PHY_MDLL_CON0(x).B.CTRL_FORCE)

/*! @brief Format value for bitfield DDR_PHY_MDLL_CON0_CTRL_FORCE. */
#define BF_DDR_PHY_MDLL_CON0_CTRL_FORCE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_MDLL_CON0_CTRL_FORCE) & BM_DDR_PHY_MDLL_CON0_CTRL_FORCE)

/*! @brief Set the CTRL_FORCE field to a new value. */
#define BW_DDR_PHY_MDLL_CON0_CTRL_FORCE(x, v) (HW_DDR_PHY_MDLL_CON0_WR(x, (HW_DDR_PHY_MDLL_CON0_RD(x) & ~BM_DDR_PHY_MDLL_CON0_CTRL_FORCE) | BF_DDR_PHY_MDLL_CON0_CTRL_FORCE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_MDLL_CON0, field CTRL_INC[22:16] (RW)
 *
 * Increase amount of start point Initial Value = 7'h10
 */
/*@{*/
#define BP_DDR_PHY_MDLL_CON0_CTRL_INC (16U) /*!< Bit position for DDR_PHY_MDLL_CON0_CTRL_INC. */
#define BM_DDR_PHY_MDLL_CON0_CTRL_INC (0x007F0000U) /*!< Bit mask for DDR_PHY_MDLL_CON0_CTRL_INC. */
#define BS_DDR_PHY_MDLL_CON0_CTRL_INC (7U) /*!< Bit field size in bits for DDR_PHY_MDLL_CON0_CTRL_INC. */

/*! @brief Read current value of the DDR_PHY_MDLL_CON0_CTRL_INC field. */
#define BR_DDR_PHY_MDLL_CON0_CTRL_INC(x) (HW_DDR_PHY_MDLL_CON0(x).B.CTRL_INC)

/*! @brief Format value for bitfield DDR_PHY_MDLL_CON0_CTRL_INC. */
#define BF_DDR_PHY_MDLL_CON0_CTRL_INC(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_MDLL_CON0_CTRL_INC) & BM_DDR_PHY_MDLL_CON0_CTRL_INC)

/*! @brief Set the CTRL_INC field to a new value. */
#define BW_DDR_PHY_MDLL_CON0_CTRL_INC(x, v) (HW_DDR_PHY_MDLL_CON0_WR(x, (HW_DDR_PHY_MDLL_CON0_RD(x) & ~BM_DDR_PHY_MDLL_CON0_CTRL_INC) | BF_DDR_PHY_MDLL_CON0_CTRL_INC(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_MDLL_CON0, field CTRL_START_POINT[30:24] (RW)
 *
 * Initial DLL lock start point. This is the number of delay cells and is the
 * start point where "DLL" start tracing to be locked. Initial delay time is
 * calculated by multiplying the unit delay of delay cell and this value. Initial Value
 * = 7'h10
 */
/*@{*/
#define BP_DDR_PHY_MDLL_CON0_CTRL_START_POINT (24U) /*!< Bit position for DDR_PHY_MDLL_CON0_CTRL_START_POINT. */
#define BM_DDR_PHY_MDLL_CON0_CTRL_START_POINT (0x7F000000U) /*!< Bit mask for DDR_PHY_MDLL_CON0_CTRL_START_POINT. */
#define BS_DDR_PHY_MDLL_CON0_CTRL_START_POINT (7U) /*!< Bit field size in bits for DDR_PHY_MDLL_CON0_CTRL_START_POINT. */

/*! @brief Read current value of the DDR_PHY_MDLL_CON0_CTRL_START_POINT field. */
#define BR_DDR_PHY_MDLL_CON0_CTRL_START_POINT(x) (HW_DDR_PHY_MDLL_CON0(x).B.CTRL_START_POINT)

/*! @brief Format value for bitfield DDR_PHY_MDLL_CON0_CTRL_START_POINT. */
#define BF_DDR_PHY_MDLL_CON0_CTRL_START_POINT(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_MDLL_CON0_CTRL_START_POINT) & BM_DDR_PHY_MDLL_CON0_CTRL_START_POINT)

/*! @brief Set the CTRL_START_POINT field to a new value. */
#define BW_DDR_PHY_MDLL_CON0_CTRL_START_POINT(x, v) (HW_DDR_PHY_MDLL_CON0_WR(x, (HW_DDR_PHY_MDLL_CON0_RD(x) & ~BM_DDR_PHY_MDLL_CON0_CTRL_START_POINT) | BF_DDR_PHY_MDLL_CON0_CTRL_START_POINT(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_MDLL_CON1 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_MDLL_CON1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * "DLL" is used to get how many delay cells should be passed through the "delay
 * line" to delay a signal to an amount of one clock period and is controlled by
 * ctrl_start, ctrl_start_point and ctrl_inc. ctrl_start should be set and kept
 * high to make "DLL" keep tracing one clock period after clock(PHY clock)
 * becomes stable. If ctrl_start becomes LOW, "DLL" stops tracing one clock period.
 * ctrl_clock and ctrl_flock are status fields indicating whether "DLL" is locked.
 * After ctrl_start becomes HIGH, DLL starts tracing one clock period and controls
 * (increases or decreases) the number of delay cells for the clock to pass
 * through. And if ctrl_clock is set("DLL" is locked), "DLL" changes step delays of
 * the "delay line" and controls the "delay line" in fine resolution to reduce the
 * "phase offset error".When ctrl_flock is set, "DLL" is locked with fine
 * resolution. ctrl_lock_value is information field to indicate the number of delay
 * cells to delay a signal to one clock period through the "delay line".
 * {ctrl_clock, ctrl_flock = 2'b00} : DLL is not locked. {ctrl_clock, ctrl_flock = 2'b01} :
 * Impossible value. {ctrl_clock, ctrl_flock = 2'b10} : Locked. {ctrl_clock,
 * ctrl_flock = 2'b11} : Locked. Recommended value for ctrl_start_point[7:0] and
 * ctrl_inc[7:0] are 8'h10.
 */
typedef union _hw_ddr_phy_mdll_con1
{
    uint32_t U;
    struct _hw_ddr_phy_mdll_con1_bitfields
    {
        uint32_t CTRL_LOCKED : 1;      /*!< [0]  */
        uint32_t CTRL_FLOCK : 1;       /*!< [1]  */
        uint32_t CTRL_CLOCK : 1;       /*!< [2]  */
        uint32_t RESERVED0 : 5;        /*!< [7:3]  */
        uint32_t CTRL_LOCK_VALUE : 9;  /*!< [16:8]  */
        uint32_t RESERVED1 : 15;       /*!< [31:17]  */
    } B;
} hw_ddr_phy_mdll_con1_t;

/*!
 * @name Constants and macros for entire DDR_PHY_MDLL_CON1 register
 */
/*@{*/
#define HW_DDR_PHY_MDLL_CON1_ADDR(x) ((uintptr_t)(x) + 0xB4U)

#define HW_DDR_PHY_MDLL_CON1(x)  (*(__IO hw_ddr_phy_mdll_con1_t *) HW_DDR_PHY_MDLL_CON1_ADDR(x))
#define HW_DDR_PHY_MDLL_CON1_RD(x) (HW_DDR_PHY_MDLL_CON1(x).U)
#define HW_DDR_PHY_MDLL_CON1_WR(x, v) (HW_DDR_PHY_MDLL_CON1(x).U = (v))
#define HW_DDR_PHY_MDLL_CON1_SET(x, v) (HW_DDR_PHY_MDLL_CON1_WR(x, HW_DDR_PHY_MDLL_CON1_RD(x) |  (v)))
#define HW_DDR_PHY_MDLL_CON1_CLR(x, v) (HW_DDR_PHY_MDLL_CON1_WR(x, HW_DDR_PHY_MDLL_CON1_RD(x) & ~(v)))
#define HW_DDR_PHY_MDLL_CON1_TOG(x, v) (HW_DDR_PHY_MDLL_CON1_WR(x, HW_DDR_PHY_MDLL_CON1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_MDLL_CON1 bitfields
 */

/*!
 * @name Register DDR_PHY_MDLL_CON1, field CTRL_LOCKED[0] (RW)
 *
 * DLL stable lock information. This field is set after ctrl_flock is set. This
 * field is cleared when ctrl_flock is de-asserted for some period of time
 * specified by ctrl_ref[3:0] value. This field is required for stable lock status
 * check.
 */
/*@{*/
#define BP_DDR_PHY_MDLL_CON1_CTRL_LOCKED (0U) /*!< Bit position for DDR_PHY_MDLL_CON1_CTRL_LOCKED. */
#define BM_DDR_PHY_MDLL_CON1_CTRL_LOCKED (0x00000001U) /*!< Bit mask for DDR_PHY_MDLL_CON1_CTRL_LOCKED. */
#define BS_DDR_PHY_MDLL_CON1_CTRL_LOCKED (1U) /*!< Bit field size in bits for DDR_PHY_MDLL_CON1_CTRL_LOCKED. */

/*! @brief Read current value of the DDR_PHY_MDLL_CON1_CTRL_LOCKED field. */
#define BR_DDR_PHY_MDLL_CON1_CTRL_LOCKED(x) (HW_DDR_PHY_MDLL_CON1(x).B.CTRL_LOCKED)

/*! @brief Format value for bitfield DDR_PHY_MDLL_CON1_CTRL_LOCKED. */
#define BF_DDR_PHY_MDLL_CON1_CTRL_LOCKED(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_MDLL_CON1_CTRL_LOCKED) & BM_DDR_PHY_MDLL_CON1_CTRL_LOCKED)

/*! @brief Set the CTRL_LOCKED field to a new value. */
#define BW_DDR_PHY_MDLL_CON1_CTRL_LOCKED(x, v) (HW_DDR_PHY_MDLL_CON1_WR(x, (HW_DDR_PHY_MDLL_CON1_RD(x) & ~BM_DDR_PHY_MDLL_CON1_CTRL_LOCKED) | BF_DDR_PHY_MDLL_CON1_CTRL_LOCKED(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_MDLL_CON1, field CTRL_FLOCK[1] (RW)
 *
 * Fine lock information. According to clock jitter, ctrl_flock can be
 * de-asserted.
 */
/*@{*/
#define BP_DDR_PHY_MDLL_CON1_CTRL_FLOCK (1U) /*!< Bit position for DDR_PHY_MDLL_CON1_CTRL_FLOCK. */
#define BM_DDR_PHY_MDLL_CON1_CTRL_FLOCK (0x00000002U) /*!< Bit mask for DDR_PHY_MDLL_CON1_CTRL_FLOCK. */
#define BS_DDR_PHY_MDLL_CON1_CTRL_FLOCK (1U) /*!< Bit field size in bits for DDR_PHY_MDLL_CON1_CTRL_FLOCK. */

/*! @brief Read current value of the DDR_PHY_MDLL_CON1_CTRL_FLOCK field. */
#define BR_DDR_PHY_MDLL_CON1_CTRL_FLOCK(x) (HW_DDR_PHY_MDLL_CON1(x).B.CTRL_FLOCK)

/*! @brief Format value for bitfield DDR_PHY_MDLL_CON1_CTRL_FLOCK. */
#define BF_DDR_PHY_MDLL_CON1_CTRL_FLOCK(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_MDLL_CON1_CTRL_FLOCK) & BM_DDR_PHY_MDLL_CON1_CTRL_FLOCK)

/*! @brief Set the CTRL_FLOCK field to a new value. */
#define BW_DDR_PHY_MDLL_CON1_CTRL_FLOCK(x, v) (HW_DDR_PHY_MDLL_CON1_WR(x, (HW_DDR_PHY_MDLL_CON1_RD(x) & ~BM_DDR_PHY_MDLL_CON1_CTRL_FLOCK) | BF_DDR_PHY_MDLL_CON1_CTRL_FLOCK(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_MDLL_CON1, field CTRL_CLOCK[2] (RW)
 *
 * Coarse lock information. According to clock jitter, ctrl_clock can be
 * de-asserted.
 */
/*@{*/
#define BP_DDR_PHY_MDLL_CON1_CTRL_CLOCK (2U) /*!< Bit position for DDR_PHY_MDLL_CON1_CTRL_CLOCK. */
#define BM_DDR_PHY_MDLL_CON1_CTRL_CLOCK (0x00000004U) /*!< Bit mask for DDR_PHY_MDLL_CON1_CTRL_CLOCK. */
#define BS_DDR_PHY_MDLL_CON1_CTRL_CLOCK (1U) /*!< Bit field size in bits for DDR_PHY_MDLL_CON1_CTRL_CLOCK. */

/*! @brief Read current value of the DDR_PHY_MDLL_CON1_CTRL_CLOCK field. */
#define BR_DDR_PHY_MDLL_CON1_CTRL_CLOCK(x) (HW_DDR_PHY_MDLL_CON1(x).B.CTRL_CLOCK)

/*! @brief Format value for bitfield DDR_PHY_MDLL_CON1_CTRL_CLOCK. */
#define BF_DDR_PHY_MDLL_CON1_CTRL_CLOCK(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_MDLL_CON1_CTRL_CLOCK) & BM_DDR_PHY_MDLL_CON1_CTRL_CLOCK)

/*! @brief Set the CTRL_CLOCK field to a new value. */
#define BW_DDR_PHY_MDLL_CON1_CTRL_CLOCK(x, v) (HW_DDR_PHY_MDLL_CON1_WR(x, (HW_DDR_PHY_MDLL_CON1_RD(x) & ~BM_DDR_PHY_MDLL_CON1_CTRL_CLOCK) | BF_DDR_PHY_MDLL_CON1_CTRL_CLOCK(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_MDLL_CON1, field CTRL_LOCK_VALUE[16:8] (RW)
 *
 * Locked delay line encoding value. Defines the number of Fine Steps to be used
 * for one clock period. From ctrl_lock_value[8:0], tFS (fine step delay) can be
 * calculated. tFS = tCK / ctrl_lock_value[8:0].
 */
/*@{*/
#define BP_DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE (8U) /*!< Bit position for DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE. */
#define BM_DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE (0x0001FF00U) /*!< Bit mask for DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE. */
#define BS_DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE (9U) /*!< Bit field size in bits for DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE. */

/*! @brief Read current value of the DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE field. */
#define BR_DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE(x) (HW_DDR_PHY_MDLL_CON1(x).B.CTRL_LOCK_VALUE)

/*! @brief Format value for bitfield DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE. */
#define BF_DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE) & BM_DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE)

/*! @brief Set the CTRL_LOCK_VALUE field to a new value. */
#define BW_DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE(x, v) (HW_DDR_PHY_MDLL_CON1_WR(x, (HW_DDR_PHY_MDLL_CON1_RD(x) & ~BM_DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE) | BF_DDR_PHY_MDLL_CON1_CTRL_LOCK_VALUE(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_ZQ_CON0 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_ZQ_CON0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * "zq_manual_str" (= ZQ_CON0[1]) should be toggled after ZQ_CON0[17:2] or
 * ZQ_CON0[26:19] is changed. For example, if zq_mode_dds is written by 3'b111,
 * "zq_manual_str" should be set and cleared to apply this new strength value (3'b111).
 */
typedef union _hw_ddr_phy_zq_con0
{
    uint32_t U;
    struct _hw_ddr_phy_zq_con0_bitfields
    {
        uint32_t ZQ_AUTO_EN : 1;       /*!< [0]  */
        uint32_t ZQ_MANUAL_STR : 1;    /*!< [1]  */
        uint32_t ZQ_MANUAL_MODE : 2;   /*!< [3:2]  */
        uint32_t ZQ_UDT_DLY : 8;       /*!< [11:4]  */
        uint32_t ZQ_FORCE_IMPP : 3;    /*!< [14:12]  */
        uint32_t ZQ_FORCE_IMPN : 3;    /*!< [17:15]  */
        uint32_t ZQ_CLK_DIV_EN : 1;    /*!< [18]  */
        uint32_t ZQ_MODE_NOTERM : 1;   /*!< [19]  */
        uint32_t ZQ_RGDDR3 : 1;        /*!< [20]  */
        uint32_t ZQ_MODE_TERM : 3;     /*!< [23:21]  */
        uint32_t ZQ_MODE_DDS : 3;      /*!< [26:24]  */
        uint32_t ZQ_CLK_EN : 1;        /*!< [27]  */
        uint32_t RESERVED0 : 4;        /*!< [31:28]  */
    } B;
} hw_ddr_phy_zq_con0_t;

/*!
 * @name Constants and macros for entire DDR_PHY_ZQ_CON0 register
 */
/*@{*/
#define HW_DDR_PHY_ZQ_CON0_ADDR(x) ((uintptr_t)(x) + 0xC0U)

#define HW_DDR_PHY_ZQ_CON0(x)    (*(__IO hw_ddr_phy_zq_con0_t *) HW_DDR_PHY_ZQ_CON0_ADDR(x))
#define HW_DDR_PHY_ZQ_CON0_RD(x) (HW_DDR_PHY_ZQ_CON0(x).U)
#define HW_DDR_PHY_ZQ_CON0_WR(x, v) (HW_DDR_PHY_ZQ_CON0(x).U = (v))
#define HW_DDR_PHY_ZQ_CON0_SET(x, v) (HW_DDR_PHY_ZQ_CON0_WR(x, HW_DDR_PHY_ZQ_CON0_RD(x) |  (v)))
#define HW_DDR_PHY_ZQ_CON0_CLR(x, v) (HW_DDR_PHY_ZQ_CON0_WR(x, HW_DDR_PHY_ZQ_CON0_RD(x) & ~(v)))
#define HW_DDR_PHY_ZQ_CON0_TOG(x, v) (HW_DDR_PHY_ZQ_CON0_WR(x, HW_DDR_PHY_ZQ_CON0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_ZQ_CON0 bitfields
 */

/*!
 * @name Register DDR_PHY_ZQ_CON0, field ZQ_AUTO_EN[0] (RW)
 *
 * Auto calibration enable Initial Value = 1'b0
 */
/*@{*/
#define BP_DDR_PHY_ZQ_CON0_ZQ_AUTO_EN (0U) /*!< Bit position for DDR_PHY_ZQ_CON0_ZQ_AUTO_EN. */
#define BM_DDR_PHY_ZQ_CON0_ZQ_AUTO_EN (0x00000001U) /*!< Bit mask for DDR_PHY_ZQ_CON0_ZQ_AUTO_EN. */
#define BS_DDR_PHY_ZQ_CON0_ZQ_AUTO_EN (1U) /*!< Bit field size in bits for DDR_PHY_ZQ_CON0_ZQ_AUTO_EN. */

/*! @brief Read current value of the DDR_PHY_ZQ_CON0_ZQ_AUTO_EN field. */
#define BR_DDR_PHY_ZQ_CON0_ZQ_AUTO_EN(x) (HW_DDR_PHY_ZQ_CON0(x).B.ZQ_AUTO_EN)

/*! @brief Format value for bitfield DDR_PHY_ZQ_CON0_ZQ_AUTO_EN. */
#define BF_DDR_PHY_ZQ_CON0_ZQ_AUTO_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_ZQ_CON0_ZQ_AUTO_EN) & BM_DDR_PHY_ZQ_CON0_ZQ_AUTO_EN)

/*! @brief Set the ZQ_AUTO_EN field to a new value. */
#define BW_DDR_PHY_ZQ_CON0_ZQ_AUTO_EN(x, v) (HW_DDR_PHY_ZQ_CON0_WR(x, (HW_DDR_PHY_ZQ_CON0_RD(x) & ~BM_DDR_PHY_ZQ_CON0_ZQ_AUTO_EN) | BF_DDR_PHY_ZQ_CON0_ZQ_AUTO_EN(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_ZQ_CON0, field ZQ_MANUAL_STR[1] (RW)
 *
 * Manual calibration start Initial Value = 1'b0
 */
/*@{*/
#define BP_DDR_PHY_ZQ_CON0_ZQ_MANUAL_STR (1U) /*!< Bit position for DDR_PHY_ZQ_CON0_ZQ_MANUAL_STR. */
#define BM_DDR_PHY_ZQ_CON0_ZQ_MANUAL_STR (0x00000002U) /*!< Bit mask for DDR_PHY_ZQ_CON0_ZQ_MANUAL_STR. */
#define BS_DDR_PHY_ZQ_CON0_ZQ_MANUAL_STR (1U) /*!< Bit field size in bits for DDR_PHY_ZQ_CON0_ZQ_MANUAL_STR. */

/*! @brief Read current value of the DDR_PHY_ZQ_CON0_ZQ_MANUAL_STR field. */
#define BR_DDR_PHY_ZQ_CON0_ZQ_MANUAL_STR(x) (HW_DDR_PHY_ZQ_CON0(x).B.ZQ_MANUAL_STR)

/*! @brief Format value for bitfield DDR_PHY_ZQ_CON0_ZQ_MANUAL_STR. */
#define BF_DDR_PHY_ZQ_CON0_ZQ_MANUAL_STR(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_ZQ_CON0_ZQ_MANUAL_STR) & BM_DDR_PHY_ZQ_CON0_ZQ_MANUAL_STR)

/*! @brief Set the ZQ_MANUAL_STR field to a new value. */
#define BW_DDR_PHY_ZQ_CON0_ZQ_MANUAL_STR(x, v) (HW_DDR_PHY_ZQ_CON0_WR(x, (HW_DDR_PHY_ZQ_CON0_RD(x) & ~BM_DDR_PHY_ZQ_CON0_ZQ_MANUAL_STR) | BF_DDR_PHY_ZQ_CON0_ZQ_MANUAL_STR(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_ZQ_CON0, field ZQ_MANUAL_MODE[3:2] (RW)
 *
 * Manual calibration mode selection Initial Value = 2'b01
 */
/*@{*/
#define BP_DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE (2U) /*!< Bit position for DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE. */
#define BM_DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE (0x0000000CU) /*!< Bit mask for DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE. */
#define BS_DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE (2U) /*!< Bit field size in bits for DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE. */

/*! @brief Read current value of the DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE field. */
#define BR_DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE(x) (HW_DDR_PHY_ZQ_CON0(x).B.ZQ_MANUAL_MODE)

/*! @brief Format value for bitfield DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE. */
#define BF_DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE) & BM_DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE)

/*! @brief Set the ZQ_MANUAL_MODE field to a new value. */
#define BW_DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE(x, v) (HW_DDR_PHY_ZQ_CON0_WR(x, (HW_DDR_PHY_ZQ_CON0_RD(x) & ~BM_DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE) | BF_DDR_PHY_ZQ_CON0_ZQ_MANUAL_MODE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_ZQ_CON0, field ZQ_UDT_DLY[11:4] (RW)
 *
 * ZQ I/O clock enable duration for auto calibration mode. Initial Value = 8'h30
 */
/*@{*/
#define BP_DDR_PHY_ZQ_CON0_ZQ_UDT_DLY (4U) /*!< Bit position for DDR_PHY_ZQ_CON0_ZQ_UDT_DLY. */
#define BM_DDR_PHY_ZQ_CON0_ZQ_UDT_DLY (0x00000FF0U) /*!< Bit mask for DDR_PHY_ZQ_CON0_ZQ_UDT_DLY. */
#define BS_DDR_PHY_ZQ_CON0_ZQ_UDT_DLY (8U) /*!< Bit field size in bits for DDR_PHY_ZQ_CON0_ZQ_UDT_DLY. */

/*! @brief Read current value of the DDR_PHY_ZQ_CON0_ZQ_UDT_DLY field. */
#define BR_DDR_PHY_ZQ_CON0_ZQ_UDT_DLY(x) (HW_DDR_PHY_ZQ_CON0(x).B.ZQ_UDT_DLY)

/*! @brief Format value for bitfield DDR_PHY_ZQ_CON0_ZQ_UDT_DLY. */
#define BF_DDR_PHY_ZQ_CON0_ZQ_UDT_DLY(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_ZQ_CON0_ZQ_UDT_DLY) & BM_DDR_PHY_ZQ_CON0_ZQ_UDT_DLY)

/*! @brief Set the ZQ_UDT_DLY field to a new value. */
#define BW_DDR_PHY_ZQ_CON0_ZQ_UDT_DLY(x, v) (HW_DDR_PHY_ZQ_CON0_WR(x, (HW_DDR_PHY_ZQ_CON0_RD(x) & ~BM_DDR_PHY_ZQ_CON0_ZQ_UDT_DLY) | BF_DDR_PHY_ZQ_CON0_ZQ_UDT_DLY(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_ZQ_CON0, field ZQ_FORCE_IMPP[14:12] (RW)
 *
 * Immediate control code for pull-up. Initial Value = 3'h7
 */
/*@{*/
#define BP_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP (12U) /*!< Bit position for DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP. */
#define BM_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP (0x00007000U) /*!< Bit mask for DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP. */
#define BS_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP (3U) /*!< Bit field size in bits for DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP. */

/*! @brief Read current value of the DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP field. */
#define BR_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP(x) (HW_DDR_PHY_ZQ_CON0(x).B.ZQ_FORCE_IMPP)

/*! @brief Format value for bitfield DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP. */
#define BF_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP) & BM_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP)

/*! @brief Set the ZQ_FORCE_IMPP field to a new value. */
#define BW_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP(x, v) (HW_DDR_PHY_ZQ_CON0_WR(x, (HW_DDR_PHY_ZQ_CON0_RD(x) & ~BM_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP) | BF_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPP(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_ZQ_CON0, field ZQ_FORCE_IMPN[17:15] (RW)
 *
 * Immediate control code for pull-down. Initial Value = 3'h0
 */
/*@{*/
#define BP_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN (15U) /*!< Bit position for DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN. */
#define BM_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN (0x00038000U) /*!< Bit mask for DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN. */
#define BS_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN (3U) /*!< Bit field size in bits for DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN. */

/*! @brief Read current value of the DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN field. */
#define BR_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN(x) (HW_DDR_PHY_ZQ_CON0(x).B.ZQ_FORCE_IMPN)

/*! @brief Format value for bitfield DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN. */
#define BF_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN) & BM_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN)

/*! @brief Set the ZQ_FORCE_IMPN field to a new value. */
#define BW_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN(x, v) (HW_DDR_PHY_ZQ_CON0_WR(x, (HW_DDR_PHY_ZQ_CON0_RD(x) & ~BM_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN) | BF_DDR_PHY_ZQ_CON0_ZQ_FORCE_IMPN(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_ZQ_CON0, field ZQ_CLK_DIV_EN[18] (RW)
 *
 * Clock dividing enable Initial Value = 1'b0
 */
/*@{*/
#define BP_DDR_PHY_ZQ_CON0_ZQ_CLK_DIV_EN (18U) /*!< Bit position for DDR_PHY_ZQ_CON0_ZQ_CLK_DIV_EN. */
#define BM_DDR_PHY_ZQ_CON0_ZQ_CLK_DIV_EN (0x00040000U) /*!< Bit mask for DDR_PHY_ZQ_CON0_ZQ_CLK_DIV_EN. */
#define BS_DDR_PHY_ZQ_CON0_ZQ_CLK_DIV_EN (1U) /*!< Bit field size in bits for DDR_PHY_ZQ_CON0_ZQ_CLK_DIV_EN. */

/*! @brief Read current value of the DDR_PHY_ZQ_CON0_ZQ_CLK_DIV_EN field. */
#define BR_DDR_PHY_ZQ_CON0_ZQ_CLK_DIV_EN(x) (HW_DDR_PHY_ZQ_CON0(x).B.ZQ_CLK_DIV_EN)

/*! @brief Format value for bitfield DDR_PHY_ZQ_CON0_ZQ_CLK_DIV_EN. */
#define BF_DDR_PHY_ZQ_CON0_ZQ_CLK_DIV_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_ZQ_CON0_ZQ_CLK_DIV_EN) & BM_DDR_PHY_ZQ_CON0_ZQ_CLK_DIV_EN)

/*! @brief Set the ZQ_CLK_DIV_EN field to a new value. */
#define BW_DDR_PHY_ZQ_CON0_ZQ_CLK_DIV_EN(x, v) (HW_DDR_PHY_ZQ_CON0_WR(x, (HW_DDR_PHY_ZQ_CON0_RD(x) & ~BM_DDR_PHY_ZQ_CON0_ZQ_CLK_DIV_EN) | BF_DDR_PHY_ZQ_CON0_ZQ_CLK_DIV_EN(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_ZQ_CON0, field ZQ_MODE_NOTERM[19] (RW)
 *
 * Termination disable selection Initial Value = 1'b0
 *
 * Values:
 * - 1 - Termination disable
 * - 0 - Termination enable
 */
/*@{*/
#define BP_DDR_PHY_ZQ_CON0_ZQ_MODE_NOTERM (19U) /*!< Bit position for DDR_PHY_ZQ_CON0_ZQ_MODE_NOTERM. */
#define BM_DDR_PHY_ZQ_CON0_ZQ_MODE_NOTERM (0x00080000U) /*!< Bit mask for DDR_PHY_ZQ_CON0_ZQ_MODE_NOTERM. */
#define BS_DDR_PHY_ZQ_CON0_ZQ_MODE_NOTERM (1U) /*!< Bit field size in bits for DDR_PHY_ZQ_CON0_ZQ_MODE_NOTERM. */

/*! @brief Read current value of the DDR_PHY_ZQ_CON0_ZQ_MODE_NOTERM field. */
#define BR_DDR_PHY_ZQ_CON0_ZQ_MODE_NOTERM(x) (HW_DDR_PHY_ZQ_CON0(x).B.ZQ_MODE_NOTERM)

/*! @brief Format value for bitfield DDR_PHY_ZQ_CON0_ZQ_MODE_NOTERM. */
#define BF_DDR_PHY_ZQ_CON0_ZQ_MODE_NOTERM(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_ZQ_CON0_ZQ_MODE_NOTERM) & BM_DDR_PHY_ZQ_CON0_ZQ_MODE_NOTERM)

/*! @brief Set the ZQ_MODE_NOTERM field to a new value. */
#define BW_DDR_PHY_ZQ_CON0_ZQ_MODE_NOTERM(x, v) (HW_DDR_PHY_ZQ_CON0_WR(x, (HW_DDR_PHY_ZQ_CON0_RD(x) & ~BM_DDR_PHY_ZQ_CON0_ZQ_MODE_NOTERM) | BF_DDR_PHY_ZQ_CON0_ZQ_MODE_NOTERM(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_ZQ_CON0, field ZQ_RGDDR3[20] (RW)
 *
 * Not used Initial Value = 1'b0
 */
/*@{*/
#define BP_DDR_PHY_ZQ_CON0_ZQ_RGDDR3 (20U) /*!< Bit position for DDR_PHY_ZQ_CON0_ZQ_RGDDR3. */
#define BM_DDR_PHY_ZQ_CON0_ZQ_RGDDR3 (0x00100000U) /*!< Bit mask for DDR_PHY_ZQ_CON0_ZQ_RGDDR3. */
#define BS_DDR_PHY_ZQ_CON0_ZQ_RGDDR3 (1U)  /*!< Bit field size in bits for DDR_PHY_ZQ_CON0_ZQ_RGDDR3. */

/*! @brief Read current value of the DDR_PHY_ZQ_CON0_ZQ_RGDDR3 field. */
#define BR_DDR_PHY_ZQ_CON0_ZQ_RGDDR3(x) (HW_DDR_PHY_ZQ_CON0(x).B.ZQ_RGDDR3)

/*! @brief Format value for bitfield DDR_PHY_ZQ_CON0_ZQ_RGDDR3. */
#define BF_DDR_PHY_ZQ_CON0_ZQ_RGDDR3(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_ZQ_CON0_ZQ_RGDDR3) & BM_DDR_PHY_ZQ_CON0_ZQ_RGDDR3)

/*! @brief Set the ZQ_RGDDR3 field to a new value. */
#define BW_DDR_PHY_ZQ_CON0_ZQ_RGDDR3(x, v) (HW_DDR_PHY_ZQ_CON0_WR(x, (HW_DDR_PHY_ZQ_CON0_RD(x) & ~BM_DDR_PHY_ZQ_CON0_ZQ_RGDDR3) | BF_DDR_PHY_ZQ_CON0_ZQ_RGDDR3(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_ZQ_CON0, field ZQ_MODE_TERM[23:21] (RW)
 *
 * On-die-termination (ODT) resistor value selection. Initial Value = 3'h0
 */
/*@{*/
#define BP_DDR_PHY_ZQ_CON0_ZQ_MODE_TERM (21U) /*!< Bit position for DDR_PHY_ZQ_CON0_ZQ_MODE_TERM. */
#define BM_DDR_PHY_ZQ_CON0_ZQ_MODE_TERM (0x00E00000U) /*!< Bit mask for DDR_PHY_ZQ_CON0_ZQ_MODE_TERM. */
#define BS_DDR_PHY_ZQ_CON0_ZQ_MODE_TERM (3U) /*!< Bit field size in bits for DDR_PHY_ZQ_CON0_ZQ_MODE_TERM. */

/*! @brief Read current value of the DDR_PHY_ZQ_CON0_ZQ_MODE_TERM field. */
#define BR_DDR_PHY_ZQ_CON0_ZQ_MODE_TERM(x) (HW_DDR_PHY_ZQ_CON0(x).B.ZQ_MODE_TERM)

/*! @brief Format value for bitfield DDR_PHY_ZQ_CON0_ZQ_MODE_TERM. */
#define BF_DDR_PHY_ZQ_CON0_ZQ_MODE_TERM(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_ZQ_CON0_ZQ_MODE_TERM) & BM_DDR_PHY_ZQ_CON0_ZQ_MODE_TERM)

/*! @brief Set the ZQ_MODE_TERM field to a new value. */
#define BW_DDR_PHY_ZQ_CON0_ZQ_MODE_TERM(x, v) (HW_DDR_PHY_ZQ_CON0_WR(x, (HW_DDR_PHY_ZQ_CON0_RD(x) & ~BM_DDR_PHY_ZQ_CON0_ZQ_MODE_TERM) | BF_DDR_PHY_ZQ_CON0_ZQ_MODE_TERM(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_ZQ_CON0, field ZQ_MODE_DDS[26:24] (RW)
 *
 * Driver strength selection. Initial Value = 3'h7
 *
 * Values:
 * - 000 - 240 ohm Impedance output driver
 * - 001 - 120 ohm Impedance output driver
 * - 010 - 80 ohm Impedance output driver
 * - 011 - 60 ohm Impedance output driver
 * - 100 - 48 ohm Impedance output driver
 * - 101 - 40 ohm Impedance output driver
 * - 110 - 34 ohm Impedance output driver
 * - 111 - 30 ohm Impedance output driver
 */
/*@{*/
#define BP_DDR_PHY_ZQ_CON0_ZQ_MODE_DDS (24U) /*!< Bit position for DDR_PHY_ZQ_CON0_ZQ_MODE_DDS. */
#define BM_DDR_PHY_ZQ_CON0_ZQ_MODE_DDS (0x07000000U) /*!< Bit mask for DDR_PHY_ZQ_CON0_ZQ_MODE_DDS. */
#define BS_DDR_PHY_ZQ_CON0_ZQ_MODE_DDS (3U) /*!< Bit field size in bits for DDR_PHY_ZQ_CON0_ZQ_MODE_DDS. */

/*! @brief Read current value of the DDR_PHY_ZQ_CON0_ZQ_MODE_DDS field. */
#define BR_DDR_PHY_ZQ_CON0_ZQ_MODE_DDS(x) (HW_DDR_PHY_ZQ_CON0(x).B.ZQ_MODE_DDS)

/*! @brief Format value for bitfield DDR_PHY_ZQ_CON0_ZQ_MODE_DDS. */
#define BF_DDR_PHY_ZQ_CON0_ZQ_MODE_DDS(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_ZQ_CON0_ZQ_MODE_DDS) & BM_DDR_PHY_ZQ_CON0_ZQ_MODE_DDS)

/*! @brief Set the ZQ_MODE_DDS field to a new value. */
#define BW_DDR_PHY_ZQ_CON0_ZQ_MODE_DDS(x, v) (HW_DDR_PHY_ZQ_CON0_WR(x, (HW_DDR_PHY_ZQ_CON0_RD(x) & ~BM_DDR_PHY_ZQ_CON0_ZQ_MODE_DDS) | BF_DDR_PHY_ZQ_CON0_ZQ_MODE_DDS(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_ZQ_CON0, field ZQ_CLK_EN[27] (RW)
 *
 * ZQ I/O Clock enable Initial Value = 1'b1
 */
/*@{*/
#define BP_DDR_PHY_ZQ_CON0_ZQ_CLK_EN (27U) /*!< Bit position for DDR_PHY_ZQ_CON0_ZQ_CLK_EN. */
#define BM_DDR_PHY_ZQ_CON0_ZQ_CLK_EN (0x08000000U) /*!< Bit mask for DDR_PHY_ZQ_CON0_ZQ_CLK_EN. */
#define BS_DDR_PHY_ZQ_CON0_ZQ_CLK_EN (1U)  /*!< Bit field size in bits for DDR_PHY_ZQ_CON0_ZQ_CLK_EN. */

/*! @brief Read current value of the DDR_PHY_ZQ_CON0_ZQ_CLK_EN field. */
#define BR_DDR_PHY_ZQ_CON0_ZQ_CLK_EN(x) (HW_DDR_PHY_ZQ_CON0(x).B.ZQ_CLK_EN)

/*! @brief Format value for bitfield DDR_PHY_ZQ_CON0_ZQ_CLK_EN. */
#define BF_DDR_PHY_ZQ_CON0_ZQ_CLK_EN(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_ZQ_CON0_ZQ_CLK_EN) & BM_DDR_PHY_ZQ_CON0_ZQ_CLK_EN)

/*! @brief Set the ZQ_CLK_EN field to a new value. */
#define BW_DDR_PHY_ZQ_CON0_ZQ_CLK_EN(x, v) (HW_DDR_PHY_ZQ_CON0_WR(x, (HW_DDR_PHY_ZQ_CON0_RD(x) & ~BM_DDR_PHY_ZQ_CON0_ZQ_CLK_EN) | BF_DDR_PHY_ZQ_CON0_ZQ_CLK_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_ZQ_CON1 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_ZQ_CON1 -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_zq_con1
{
    uint32_t U;
    struct _hw_ddr_phy_zq_con1_bitfields
    {
        uint32_t ZQ_DONE : 1;          /*!< [0]  */
        uint32_t ZQ_PENDING : 1;       /*!< [1]  */
        uint32_t ZQ_ERROR : 1;         /*!< [2]  */
        uint32_t ZQ_NMON : 3;          /*!< [5:3]  */
        uint32_t ZQ_PMON : 3;          /*!< [8:6]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_ddr_phy_zq_con1_t;

/*!
 * @name Constants and macros for entire DDR_PHY_ZQ_CON1 register
 */
/*@{*/
#define HW_DDR_PHY_ZQ_CON1_ADDR(x) ((uintptr_t)(x) + 0xC4U)

#define HW_DDR_PHY_ZQ_CON1(x)    (*(__IO hw_ddr_phy_zq_con1_t *) HW_DDR_PHY_ZQ_CON1_ADDR(x))
#define HW_DDR_PHY_ZQ_CON1_RD(x) (HW_DDR_PHY_ZQ_CON1(x).U)
#define HW_DDR_PHY_ZQ_CON1_WR(x, v) (HW_DDR_PHY_ZQ_CON1(x).U = (v))
#define HW_DDR_PHY_ZQ_CON1_SET(x, v) (HW_DDR_PHY_ZQ_CON1_WR(x, HW_DDR_PHY_ZQ_CON1_RD(x) |  (v)))
#define HW_DDR_PHY_ZQ_CON1_CLR(x, v) (HW_DDR_PHY_ZQ_CON1_WR(x, HW_DDR_PHY_ZQ_CON1_RD(x) & ~(v)))
#define HW_DDR_PHY_ZQ_CON1_TOG(x, v) (HW_DDR_PHY_ZQ_CON1_WR(x, HW_DDR_PHY_ZQ_CON1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_ZQ_CON1 bitfields
 */

/*!
 * @name Register DDR_PHY_ZQ_CON1, field ZQ_DONE[0] (RW)
 *
 * ZQ Calibration is finished. Initial Value = 1'b0
 */
/*@{*/
#define BP_DDR_PHY_ZQ_CON1_ZQ_DONE (0U)    /*!< Bit position for DDR_PHY_ZQ_CON1_ZQ_DONE. */
#define BM_DDR_PHY_ZQ_CON1_ZQ_DONE (0x00000001U) /*!< Bit mask for DDR_PHY_ZQ_CON1_ZQ_DONE. */
#define BS_DDR_PHY_ZQ_CON1_ZQ_DONE (1U)    /*!< Bit field size in bits for DDR_PHY_ZQ_CON1_ZQ_DONE. */

/*! @brief Read current value of the DDR_PHY_ZQ_CON1_ZQ_DONE field. */
#define BR_DDR_PHY_ZQ_CON1_ZQ_DONE(x) (HW_DDR_PHY_ZQ_CON1(x).B.ZQ_DONE)

/*! @brief Format value for bitfield DDR_PHY_ZQ_CON1_ZQ_DONE. */
#define BF_DDR_PHY_ZQ_CON1_ZQ_DONE(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_ZQ_CON1_ZQ_DONE) & BM_DDR_PHY_ZQ_CON1_ZQ_DONE)

/*! @brief Set the ZQ_DONE field to a new value. */
#define BW_DDR_PHY_ZQ_CON1_ZQ_DONE(x, v) (HW_DDR_PHY_ZQ_CON1_WR(x, (HW_DDR_PHY_ZQ_CON1_RD(x) & ~BM_DDR_PHY_ZQ_CON1_ZQ_DONE) | BF_DDR_PHY_ZQ_CON1_ZQ_DONE(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_ZQ_CON1, field ZQ_PENDING[1] (RW)
 *
 * Auto calibration enable status
 */
/*@{*/
#define BP_DDR_PHY_ZQ_CON1_ZQ_PENDING (1U) /*!< Bit position for DDR_PHY_ZQ_CON1_ZQ_PENDING. */
#define BM_DDR_PHY_ZQ_CON1_ZQ_PENDING (0x00000002U) /*!< Bit mask for DDR_PHY_ZQ_CON1_ZQ_PENDING. */
#define BS_DDR_PHY_ZQ_CON1_ZQ_PENDING (1U) /*!< Bit field size in bits for DDR_PHY_ZQ_CON1_ZQ_PENDING. */

/*! @brief Read current value of the DDR_PHY_ZQ_CON1_ZQ_PENDING field. */
#define BR_DDR_PHY_ZQ_CON1_ZQ_PENDING(x) (HW_DDR_PHY_ZQ_CON1(x).B.ZQ_PENDING)

/*! @brief Format value for bitfield DDR_PHY_ZQ_CON1_ZQ_PENDING. */
#define BF_DDR_PHY_ZQ_CON1_ZQ_PENDING(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_ZQ_CON1_ZQ_PENDING) & BM_DDR_PHY_ZQ_CON1_ZQ_PENDING)

/*! @brief Set the ZQ_PENDING field to a new value. */
#define BW_DDR_PHY_ZQ_CON1_ZQ_PENDING(x, v) (HW_DDR_PHY_ZQ_CON1_WR(x, (HW_DDR_PHY_ZQ_CON1_RD(x) & ~BM_DDR_PHY_ZQ_CON1_ZQ_PENDING) | BF_DDR_PHY_ZQ_CON1_ZQ_PENDING(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_ZQ_CON1, field ZQ_ERROR[2] (RW)
 *
 * Calibration fail indication (High: calibration failed)
 */
/*@{*/
#define BP_DDR_PHY_ZQ_CON1_ZQ_ERROR (2U)   /*!< Bit position for DDR_PHY_ZQ_CON1_ZQ_ERROR. */
#define BM_DDR_PHY_ZQ_CON1_ZQ_ERROR (0x00000004U) /*!< Bit mask for DDR_PHY_ZQ_CON1_ZQ_ERROR. */
#define BS_DDR_PHY_ZQ_CON1_ZQ_ERROR (1U)   /*!< Bit field size in bits for DDR_PHY_ZQ_CON1_ZQ_ERROR. */

/*! @brief Read current value of the DDR_PHY_ZQ_CON1_ZQ_ERROR field. */
#define BR_DDR_PHY_ZQ_CON1_ZQ_ERROR(x) (HW_DDR_PHY_ZQ_CON1(x).B.ZQ_ERROR)

/*! @brief Format value for bitfield DDR_PHY_ZQ_CON1_ZQ_ERROR. */
#define BF_DDR_PHY_ZQ_CON1_ZQ_ERROR(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_ZQ_CON1_ZQ_ERROR) & BM_DDR_PHY_ZQ_CON1_ZQ_ERROR)

/*! @brief Set the ZQ_ERROR field to a new value. */
#define BW_DDR_PHY_ZQ_CON1_ZQ_ERROR(x, v) (HW_DDR_PHY_ZQ_CON1_WR(x, (HW_DDR_PHY_ZQ_CON1_RD(x) & ~BM_DDR_PHY_ZQ_CON1_ZQ_ERROR) | BF_DDR_PHY_ZQ_CON1_ZQ_ERROR(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_ZQ_CON1, field ZQ_NMON[5:3] (RW)
 *
 * Control code found by auto calibration for pull-down.
 */
/*@{*/
#define BP_DDR_PHY_ZQ_CON1_ZQ_NMON (3U)    /*!< Bit position for DDR_PHY_ZQ_CON1_ZQ_NMON. */
#define BM_DDR_PHY_ZQ_CON1_ZQ_NMON (0x00000038U) /*!< Bit mask for DDR_PHY_ZQ_CON1_ZQ_NMON. */
#define BS_DDR_PHY_ZQ_CON1_ZQ_NMON (3U)    /*!< Bit field size in bits for DDR_PHY_ZQ_CON1_ZQ_NMON. */

/*! @brief Read current value of the DDR_PHY_ZQ_CON1_ZQ_NMON field. */
#define BR_DDR_PHY_ZQ_CON1_ZQ_NMON(x) (HW_DDR_PHY_ZQ_CON1(x).B.ZQ_NMON)

/*! @brief Format value for bitfield DDR_PHY_ZQ_CON1_ZQ_NMON. */
#define BF_DDR_PHY_ZQ_CON1_ZQ_NMON(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_ZQ_CON1_ZQ_NMON) & BM_DDR_PHY_ZQ_CON1_ZQ_NMON)

/*! @brief Set the ZQ_NMON field to a new value. */
#define BW_DDR_PHY_ZQ_CON1_ZQ_NMON(x, v) (HW_DDR_PHY_ZQ_CON1_WR(x, (HW_DDR_PHY_ZQ_CON1_RD(x) & ~BM_DDR_PHY_ZQ_CON1_ZQ_NMON) | BF_DDR_PHY_ZQ_CON1_ZQ_NMON(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_ZQ_CON1, field ZQ_PMON[8:6] (RW)
 *
 * Control code found by auto calibration for pull-up.
 */
/*@{*/
#define BP_DDR_PHY_ZQ_CON1_ZQ_PMON (6U)    /*!< Bit position for DDR_PHY_ZQ_CON1_ZQ_PMON. */
#define BM_DDR_PHY_ZQ_CON1_ZQ_PMON (0x000001C0U) /*!< Bit mask for DDR_PHY_ZQ_CON1_ZQ_PMON. */
#define BS_DDR_PHY_ZQ_CON1_ZQ_PMON (3U)    /*!< Bit field size in bits for DDR_PHY_ZQ_CON1_ZQ_PMON. */

/*! @brief Read current value of the DDR_PHY_ZQ_CON1_ZQ_PMON field. */
#define BR_DDR_PHY_ZQ_CON1_ZQ_PMON(x) (HW_DDR_PHY_ZQ_CON1(x).B.ZQ_PMON)

/*! @brief Format value for bitfield DDR_PHY_ZQ_CON1_ZQ_PMON. */
#define BF_DDR_PHY_ZQ_CON1_ZQ_PMON(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_ZQ_CON1_ZQ_PMON) & BM_DDR_PHY_ZQ_CON1_ZQ_PMON)

/*! @brief Set the ZQ_PMON field to a new value. */
#define BW_DDR_PHY_ZQ_CON1_ZQ_PMON(x, v) (HW_DDR_PHY_ZQ_CON1_WR(x, (HW_DDR_PHY_ZQ_CON1_RD(x) & ~BM_DDR_PHY_ZQ_CON1_ZQ_PMON) | BF_DDR_PHY_ZQ_CON1_ZQ_PMON(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_ZQ_CON2 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_ZQ_CON2 -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_zq_con2
{
    uint32_t U;
    struct _hw_ddr_phy_zq_con2_bitfields
    {
        uint32_t CTRL_ZQ_CLK_DIV : 16; /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_ddr_phy_zq_con2_t;

/*!
 * @name Constants and macros for entire DDR_PHY_ZQ_CON2 register
 */
/*@{*/
#define HW_DDR_PHY_ZQ_CON2_ADDR(x) ((uintptr_t)(x) + 0xC8U)

#define HW_DDR_PHY_ZQ_CON2(x)    (*(__IO hw_ddr_phy_zq_con2_t *) HW_DDR_PHY_ZQ_CON2_ADDR(x))
#define HW_DDR_PHY_ZQ_CON2_RD(x) (HW_DDR_PHY_ZQ_CON2(x).U)
#define HW_DDR_PHY_ZQ_CON2_WR(x, v) (HW_DDR_PHY_ZQ_CON2(x).U = (v))
#define HW_DDR_PHY_ZQ_CON2_SET(x, v) (HW_DDR_PHY_ZQ_CON2_WR(x, HW_DDR_PHY_ZQ_CON2_RD(x) |  (v)))
#define HW_DDR_PHY_ZQ_CON2_CLR(x, v) (HW_DDR_PHY_ZQ_CON2_WR(x, HW_DDR_PHY_ZQ_CON2_RD(x) & ~(v)))
#define HW_DDR_PHY_ZQ_CON2_TOG(x, v) (HW_DDR_PHY_ZQ_CON2_WR(x, HW_DDR_PHY_ZQ_CON2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_ZQ_CON2 bitfields
 */

/*!
 * @name Register DDR_PHY_ZQ_CON2, field CTRL_ZQ_CLK_DIV[15:0] (RW)
 *
 * ZQ Clock (= io_zq_clk) divider setting value. The frequency will be the
 * following formula. "io_zq_clk" (MHz) = clk2x (MHz) / ((ctrl_zq_clk_div + 1) * 4)
 */
/*@{*/
#define BP_DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV (0U) /*!< Bit position for DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV. */
#define BM_DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV (0x0000FFFFU) /*!< Bit mask for DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV. */
#define BS_DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV (16U) /*!< Bit field size in bits for DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV. */

/*! @brief Read current value of the DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV field. */
#define BR_DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV(x) (HW_DDR_PHY_ZQ_CON2(x).B.CTRL_ZQ_CLK_DIV)

/*! @brief Format value for bitfield DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV. */
#define BF_DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV) & BM_DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV)

/*! @brief Set the CTRL_ZQ_CLK_DIV field to a new value. */
#define BW_DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV(x, v) (HW_DDR_PHY_ZQ_CON2_WR(x, (HW_DDR_PHY_ZQ_CON2_RD(x) & ~BM_DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV) | BF_DDR_PHY_ZQ_CON2_CTRL_ZQ_CLK_DIV(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_RD_DESKEW_CON0 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_RD_DESKEW_CON0 -  (RO)
 *
 * Reset value: 0x00000000U
 *
 * RD DESKEW Control Register
 */
typedef union _hw_ddr_phy_rd_deskew_con0
{
    uint32_t U;
    struct _hw_ddr_phy_rd_deskew_con0_bitfields
    {
        uint32_t RD0DESKEW0 : 8;       /*!< [7:0]  */
        uint32_t RD0DESKEW1 : 8;       /*!< [15:8]  */
        uint32_t RD0DESKEW2 : 8;       /*!< [23:16]  */
        uint32_t RD0DESKEW3 : 8;       /*!< [31:24]  */
    } B;
} hw_ddr_phy_rd_deskew_con0_t;

/*!
 * @name Constants and macros for entire DDR_PHY_RD_DESKEW_CON0 register
 */
/*@{*/
#define HW_DDR_PHY_RD_DESKEW_CON0_ADDR(x) ((uintptr_t)(x) + 0x190U)

#define HW_DDR_PHY_RD_DESKEW_CON0(x) (*(__I hw_ddr_phy_rd_deskew_con0_t *) HW_DDR_PHY_RD_DESKEW_CON0_ADDR(x))
#define HW_DDR_PHY_RD_DESKEW_CON0_RD(x) (HW_DDR_PHY_RD_DESKEW_CON0(x).U)
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_RD_DESKEW_CON0 bitfields
 */

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON0, field RD0DESKEW0[7:0] (RO)
 *
 * Read DQ0 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON0_RD0DESKEW0 (0U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON0_RD0DESKEW0. */
#define BM_DDR_PHY_RD_DESKEW_CON0_RD0DESKEW0 (0x000000FFU) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON0_RD0DESKEW0. */
#define BS_DDR_PHY_RD_DESKEW_CON0_RD0DESKEW0 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON0_RD0DESKEW0. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON0_RD0DESKEW0 field. */
#define BR_DDR_PHY_RD_DESKEW_CON0_RD0DESKEW0(x) (HW_DDR_PHY_RD_DESKEW_CON0(x).B.RD0DESKEW0)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON0, field RD0DESKEW1[15:8] (RO)
 *
 * Read DQ8 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON0_RD0DESKEW1 (8U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON0_RD0DESKEW1. */
#define BM_DDR_PHY_RD_DESKEW_CON0_RD0DESKEW1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON0_RD0DESKEW1. */
#define BS_DDR_PHY_RD_DESKEW_CON0_RD0DESKEW1 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON0_RD0DESKEW1. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON0_RD0DESKEW1 field. */
#define BR_DDR_PHY_RD_DESKEW_CON0_RD0DESKEW1(x) (HW_DDR_PHY_RD_DESKEW_CON0(x).B.RD0DESKEW1)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON0, field RD0DESKEW2[23:16] (RO)
 *
 * Read DQ16 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON0_RD0DESKEW2 (16U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON0_RD0DESKEW2. */
#define BM_DDR_PHY_RD_DESKEW_CON0_RD0DESKEW2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON0_RD0DESKEW2. */
#define BS_DDR_PHY_RD_DESKEW_CON0_RD0DESKEW2 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON0_RD0DESKEW2. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON0_RD0DESKEW2 field. */
#define BR_DDR_PHY_RD_DESKEW_CON0_RD0DESKEW2(x) (HW_DDR_PHY_RD_DESKEW_CON0(x).B.RD0DESKEW2)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON0, field RD0DESKEW3[31:24] (RO)
 *
 * Read DQ24 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON0_RD0DESKEW3 (24U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON0_RD0DESKEW3. */
#define BM_DDR_PHY_RD_DESKEW_CON0_RD0DESKEW3 (0xFF000000U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON0_RD0DESKEW3. */
#define BS_DDR_PHY_RD_DESKEW_CON0_RD0DESKEW3 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON0_RD0DESKEW3. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON0_RD0DESKEW3 field. */
#define BR_DDR_PHY_RD_DESKEW_CON0_RD0DESKEW3(x) (HW_DDR_PHY_RD_DESKEW_CON0(x).B.RD0DESKEW3)
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_RD_DESKEW_CON3 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_RD_DESKEW_CON3 -  (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_rd_deskew_con3
{
    uint32_t U;
    struct _hw_ddr_phy_rd_deskew_con3_bitfields
    {
        uint32_t RD1DESKEW0 : 8;       /*!< [7:0]  */
        uint32_t RD1DESKEW1 : 8;       /*!< [15:8]  */
        uint32_t RD1DESKEW2 : 8;       /*!< [23:16]  */
        uint32_t RD1DESKEW3 : 8;       /*!< [31:24]  */
    } B;
} hw_ddr_phy_rd_deskew_con3_t;

/*!
 * @name Constants and macros for entire DDR_PHY_RD_DESKEW_CON3 register
 */
/*@{*/
#define HW_DDR_PHY_RD_DESKEW_CON3_ADDR(x) ((uintptr_t)(x) + 0x19CU)

#define HW_DDR_PHY_RD_DESKEW_CON3(x) (*(__I hw_ddr_phy_rd_deskew_con3_t *) HW_DDR_PHY_RD_DESKEW_CON3_ADDR(x))
#define HW_DDR_PHY_RD_DESKEW_CON3_RD(x) (HW_DDR_PHY_RD_DESKEW_CON3(x).U)
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_RD_DESKEW_CON3 bitfields
 */

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON3, field RD1DESKEW0[7:0] (RO)
 *
 * Read DQ1 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON3_RD1DESKEW0 (0U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON3_RD1DESKEW0. */
#define BM_DDR_PHY_RD_DESKEW_CON3_RD1DESKEW0 (0x000000FFU) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON3_RD1DESKEW0. */
#define BS_DDR_PHY_RD_DESKEW_CON3_RD1DESKEW0 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON3_RD1DESKEW0. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON3_RD1DESKEW0 field. */
#define BR_DDR_PHY_RD_DESKEW_CON3_RD1DESKEW0(x) (HW_DDR_PHY_RD_DESKEW_CON3(x).B.RD1DESKEW0)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON3, field RD1DESKEW1[15:8] (RO)
 *
 * Read DQ9 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON3_RD1DESKEW1 (8U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON3_RD1DESKEW1. */
#define BM_DDR_PHY_RD_DESKEW_CON3_RD1DESKEW1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON3_RD1DESKEW1. */
#define BS_DDR_PHY_RD_DESKEW_CON3_RD1DESKEW1 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON3_RD1DESKEW1. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON3_RD1DESKEW1 field. */
#define BR_DDR_PHY_RD_DESKEW_CON3_RD1DESKEW1(x) (HW_DDR_PHY_RD_DESKEW_CON3(x).B.RD1DESKEW1)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON3, field RD1DESKEW2[23:16] (RO)
 *
 * Read DQ17 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON3_RD1DESKEW2 (16U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON3_RD1DESKEW2. */
#define BM_DDR_PHY_RD_DESKEW_CON3_RD1DESKEW2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON3_RD1DESKEW2. */
#define BS_DDR_PHY_RD_DESKEW_CON3_RD1DESKEW2 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON3_RD1DESKEW2. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON3_RD1DESKEW2 field. */
#define BR_DDR_PHY_RD_DESKEW_CON3_RD1DESKEW2(x) (HW_DDR_PHY_RD_DESKEW_CON3(x).B.RD1DESKEW2)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON3, field RD1DESKEW3[31:24] (RO)
 *
 * Read DQ25 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON3_RD1DESKEW3 (24U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON3_RD1DESKEW3. */
#define BM_DDR_PHY_RD_DESKEW_CON3_RD1DESKEW3 (0xFF000000U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON3_RD1DESKEW3. */
#define BS_DDR_PHY_RD_DESKEW_CON3_RD1DESKEW3 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON3_RD1DESKEW3. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON3_RD1DESKEW3 field. */
#define BR_DDR_PHY_RD_DESKEW_CON3_RD1DESKEW3(x) (HW_DDR_PHY_RD_DESKEW_CON3(x).B.RD1DESKEW3)
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_RD_DESKEW_CON6 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_RD_DESKEW_CON6 -  (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_rd_deskew_con6
{
    uint32_t U;
    struct _hw_ddr_phy_rd_deskew_con6_bitfields
    {
        uint32_t RD2DESKEW0 : 8;       /*!< [7:0]  */
        uint32_t RD2DESKEW1 : 8;       /*!< [15:8]  */
        uint32_t RD2DESKEW2 : 8;       /*!< [23:16]  */
        uint32_t RD2DESKEW3 : 8;       /*!< [31:24]  */
    } B;
} hw_ddr_phy_rd_deskew_con6_t;

/*!
 * @name Constants and macros for entire DDR_PHY_RD_DESKEW_CON6 register
 */
/*@{*/
#define HW_DDR_PHY_RD_DESKEW_CON6_ADDR(x) ((uintptr_t)(x) + 0x1A8U)

#define HW_DDR_PHY_RD_DESKEW_CON6(x) (*(__I hw_ddr_phy_rd_deskew_con6_t *) HW_DDR_PHY_RD_DESKEW_CON6_ADDR(x))
#define HW_DDR_PHY_RD_DESKEW_CON6_RD(x) (HW_DDR_PHY_RD_DESKEW_CON6(x).U)
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_RD_DESKEW_CON6 bitfields
 */

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON6, field RD2DESKEW0[7:0] (RO)
 *
 * Read DQ2 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON6_RD2DESKEW0 (0U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON6_RD2DESKEW0. */
#define BM_DDR_PHY_RD_DESKEW_CON6_RD2DESKEW0 (0x000000FFU) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON6_RD2DESKEW0. */
#define BS_DDR_PHY_RD_DESKEW_CON6_RD2DESKEW0 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON6_RD2DESKEW0. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON6_RD2DESKEW0 field. */
#define BR_DDR_PHY_RD_DESKEW_CON6_RD2DESKEW0(x) (HW_DDR_PHY_RD_DESKEW_CON6(x).B.RD2DESKEW0)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON6, field RD2DESKEW1[15:8] (RO)
 *
 * Read DQ10 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON6_RD2DESKEW1 (8U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON6_RD2DESKEW1. */
#define BM_DDR_PHY_RD_DESKEW_CON6_RD2DESKEW1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON6_RD2DESKEW1. */
#define BS_DDR_PHY_RD_DESKEW_CON6_RD2DESKEW1 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON6_RD2DESKEW1. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON6_RD2DESKEW1 field. */
#define BR_DDR_PHY_RD_DESKEW_CON6_RD2DESKEW1(x) (HW_DDR_PHY_RD_DESKEW_CON6(x).B.RD2DESKEW1)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON6, field RD2DESKEW2[23:16] (RO)
 *
 * Read DQ18 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON6_RD2DESKEW2 (16U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON6_RD2DESKEW2. */
#define BM_DDR_PHY_RD_DESKEW_CON6_RD2DESKEW2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON6_RD2DESKEW2. */
#define BS_DDR_PHY_RD_DESKEW_CON6_RD2DESKEW2 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON6_RD2DESKEW2. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON6_RD2DESKEW2 field. */
#define BR_DDR_PHY_RD_DESKEW_CON6_RD2DESKEW2(x) (HW_DDR_PHY_RD_DESKEW_CON6(x).B.RD2DESKEW2)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON6, field RD2DESKEW3[31:24] (RO)
 *
 * Read DQ26 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON6_RD2DESKEW3 (24U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON6_RD2DESKEW3. */
#define BM_DDR_PHY_RD_DESKEW_CON6_RD2DESKEW3 (0xFF000000U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON6_RD2DESKEW3. */
#define BS_DDR_PHY_RD_DESKEW_CON6_RD2DESKEW3 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON6_RD2DESKEW3. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON6_RD2DESKEW3 field. */
#define BR_DDR_PHY_RD_DESKEW_CON6_RD2DESKEW3(x) (HW_DDR_PHY_RD_DESKEW_CON6(x).B.RD2DESKEW3)
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_RD_DESKEW_CON9 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_RD_DESKEW_CON9 -  (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_rd_deskew_con9
{
    uint32_t U;
    struct _hw_ddr_phy_rd_deskew_con9_bitfields
    {
        uint32_t RD3DESKEW0 : 8;       /*!< [7:0]  */
        uint32_t RD3DESKEW1 : 8;       /*!< [15:8]  */
        uint32_t RD3DESKEW2 : 8;       /*!< [23:16]  */
        uint32_t RD3DESKEW3 : 8;       /*!< [31:24]  */
    } B;
} hw_ddr_phy_rd_deskew_con9_t;

/*!
 * @name Constants and macros for entire DDR_PHY_RD_DESKEW_CON9 register
 */
/*@{*/
#define HW_DDR_PHY_RD_DESKEW_CON9_ADDR(x) ((uintptr_t)(x) + 0x1B4U)

#define HW_DDR_PHY_RD_DESKEW_CON9(x) (*(__I hw_ddr_phy_rd_deskew_con9_t *) HW_DDR_PHY_RD_DESKEW_CON9_ADDR(x))
#define HW_DDR_PHY_RD_DESKEW_CON9_RD(x) (HW_DDR_PHY_RD_DESKEW_CON9(x).U)
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_RD_DESKEW_CON9 bitfields
 */

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON9, field RD3DESKEW0[7:0] (RO)
 *
 * Read DQ3 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON9_RD3DESKEW0 (0U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON9_RD3DESKEW0. */
#define BM_DDR_PHY_RD_DESKEW_CON9_RD3DESKEW0 (0x000000FFU) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON9_RD3DESKEW0. */
#define BS_DDR_PHY_RD_DESKEW_CON9_RD3DESKEW0 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON9_RD3DESKEW0. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON9_RD3DESKEW0 field. */
#define BR_DDR_PHY_RD_DESKEW_CON9_RD3DESKEW0(x) (HW_DDR_PHY_RD_DESKEW_CON9(x).B.RD3DESKEW0)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON9, field RD3DESKEW1[15:8] (RO)
 *
 * Read DQ11 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON9_RD3DESKEW1 (8U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON9_RD3DESKEW1. */
#define BM_DDR_PHY_RD_DESKEW_CON9_RD3DESKEW1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON9_RD3DESKEW1. */
#define BS_DDR_PHY_RD_DESKEW_CON9_RD3DESKEW1 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON9_RD3DESKEW1. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON9_RD3DESKEW1 field. */
#define BR_DDR_PHY_RD_DESKEW_CON9_RD3DESKEW1(x) (HW_DDR_PHY_RD_DESKEW_CON9(x).B.RD3DESKEW1)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON9, field RD3DESKEW2[23:16] (RO)
 *
 * Read DQ19 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON9_RD3DESKEW2 (16U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON9_RD3DESKEW2. */
#define BM_DDR_PHY_RD_DESKEW_CON9_RD3DESKEW2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON9_RD3DESKEW2. */
#define BS_DDR_PHY_RD_DESKEW_CON9_RD3DESKEW2 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON9_RD3DESKEW2. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON9_RD3DESKEW2 field. */
#define BR_DDR_PHY_RD_DESKEW_CON9_RD3DESKEW2(x) (HW_DDR_PHY_RD_DESKEW_CON9(x).B.RD3DESKEW2)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON9, field RD3DESKEW3[31:24] (RO)
 *
 * Read DQ27 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON9_RD3DESKEW3 (24U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON9_RD3DESKEW3. */
#define BM_DDR_PHY_RD_DESKEW_CON9_RD3DESKEW3 (0xFF000000U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON9_RD3DESKEW3. */
#define BS_DDR_PHY_RD_DESKEW_CON9_RD3DESKEW3 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON9_RD3DESKEW3. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON9_RD3DESKEW3 field. */
#define BR_DDR_PHY_RD_DESKEW_CON9_RD3DESKEW3(x) (HW_DDR_PHY_RD_DESKEW_CON9(x).B.RD3DESKEW3)
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_RD_DESKEW_CON12 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_RD_DESKEW_CON12 -  (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_rd_deskew_con12
{
    uint32_t U;
    struct _hw_ddr_phy_rd_deskew_con12_bitfields
    {
        uint32_t RD4DESKEW0 : 8;       /*!< [7:0]  */
        uint32_t RD4DESKEW1 : 8;       /*!< [15:8]  */
        uint32_t RD4DESKEW2 : 8;       /*!< [23:16]  */
        uint32_t RD4DESKEW3 : 8;       /*!< [31:24]  */
    } B;
} hw_ddr_phy_rd_deskew_con12_t;

/*!
 * @name Constants and macros for entire DDR_PHY_RD_DESKEW_CON12 register
 */
/*@{*/
#define HW_DDR_PHY_RD_DESKEW_CON12_ADDR(x) ((uintptr_t)(x) + 0x1C0U)

#define HW_DDR_PHY_RD_DESKEW_CON12(x) (*(__I hw_ddr_phy_rd_deskew_con12_t *) HW_DDR_PHY_RD_DESKEW_CON12_ADDR(x))
#define HW_DDR_PHY_RD_DESKEW_CON12_RD(x) (HW_DDR_PHY_RD_DESKEW_CON12(x).U)
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_RD_DESKEW_CON12 bitfields
 */

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON12, field RD4DESKEW0[7:0] (RO)
 *
 * Read DQ4 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON12_RD4DESKEW0 (0U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON12_RD4DESKEW0. */
#define BM_DDR_PHY_RD_DESKEW_CON12_RD4DESKEW0 (0x000000FFU) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON12_RD4DESKEW0. */
#define BS_DDR_PHY_RD_DESKEW_CON12_RD4DESKEW0 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON12_RD4DESKEW0. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON12_RD4DESKEW0 field. */
#define BR_DDR_PHY_RD_DESKEW_CON12_RD4DESKEW0(x) (HW_DDR_PHY_RD_DESKEW_CON12(x).B.RD4DESKEW0)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON12, field RD4DESKEW1[15:8] (RO)
 *
 * Read DQ12 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON12_RD4DESKEW1 (8U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON12_RD4DESKEW1. */
#define BM_DDR_PHY_RD_DESKEW_CON12_RD4DESKEW1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON12_RD4DESKEW1. */
#define BS_DDR_PHY_RD_DESKEW_CON12_RD4DESKEW1 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON12_RD4DESKEW1. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON12_RD4DESKEW1 field. */
#define BR_DDR_PHY_RD_DESKEW_CON12_RD4DESKEW1(x) (HW_DDR_PHY_RD_DESKEW_CON12(x).B.RD4DESKEW1)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON12, field RD4DESKEW2[23:16] (RO)
 *
 * Read DQ20 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON12_RD4DESKEW2 (16U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON12_RD4DESKEW2. */
#define BM_DDR_PHY_RD_DESKEW_CON12_RD4DESKEW2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON12_RD4DESKEW2. */
#define BS_DDR_PHY_RD_DESKEW_CON12_RD4DESKEW2 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON12_RD4DESKEW2. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON12_RD4DESKEW2 field. */
#define BR_DDR_PHY_RD_DESKEW_CON12_RD4DESKEW2(x) (HW_DDR_PHY_RD_DESKEW_CON12(x).B.RD4DESKEW2)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON12, field RD4DESKEW3[31:24] (RO)
 *
 * Read DQ28 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON12_RD4DESKEW3 (24U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON12_RD4DESKEW3. */
#define BM_DDR_PHY_RD_DESKEW_CON12_RD4DESKEW3 (0xFF000000U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON12_RD4DESKEW3. */
#define BS_DDR_PHY_RD_DESKEW_CON12_RD4DESKEW3 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON12_RD4DESKEW3. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON12_RD4DESKEW3 field. */
#define BR_DDR_PHY_RD_DESKEW_CON12_RD4DESKEW3(x) (HW_DDR_PHY_RD_DESKEW_CON12(x).B.RD4DESKEW3)
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_RD_DESKEW_CON15 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_RD_DESKEW_CON15 -  (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_rd_deskew_con15
{
    uint32_t U;
    struct _hw_ddr_phy_rd_deskew_con15_bitfields
    {
        uint32_t RD5DESKEW0 : 8;       /*!< [7:0]  */
        uint32_t RD5DESKEW1 : 8;       /*!< [15:8]  */
        uint32_t RD5DESKEW2 : 8;       /*!< [23:16]  */
        uint32_t RD5DESKEW3 : 8;       /*!< [31:24]  */
    } B;
} hw_ddr_phy_rd_deskew_con15_t;

/*!
 * @name Constants and macros for entire DDR_PHY_RD_DESKEW_CON15 register
 */
/*@{*/
#define HW_DDR_PHY_RD_DESKEW_CON15_ADDR(x) ((uintptr_t)(x) + 0x1CCU)

#define HW_DDR_PHY_RD_DESKEW_CON15(x) (*(__I hw_ddr_phy_rd_deskew_con15_t *) HW_DDR_PHY_RD_DESKEW_CON15_ADDR(x))
#define HW_DDR_PHY_RD_DESKEW_CON15_RD(x) (HW_DDR_PHY_RD_DESKEW_CON15(x).U)
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_RD_DESKEW_CON15 bitfields
 */

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON15, field RD5DESKEW0[7:0] (RO)
 *
 * Read DQ5 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON15_RD5DESKEW0 (0U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON15_RD5DESKEW0. */
#define BM_DDR_PHY_RD_DESKEW_CON15_RD5DESKEW0 (0x000000FFU) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON15_RD5DESKEW0. */
#define BS_DDR_PHY_RD_DESKEW_CON15_RD5DESKEW0 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON15_RD5DESKEW0. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON15_RD5DESKEW0 field. */
#define BR_DDR_PHY_RD_DESKEW_CON15_RD5DESKEW0(x) (HW_DDR_PHY_RD_DESKEW_CON15(x).B.RD5DESKEW0)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON15, field RD5DESKEW1[15:8] (RO)
 *
 * Read DQ13 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON15_RD5DESKEW1 (8U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON15_RD5DESKEW1. */
#define BM_DDR_PHY_RD_DESKEW_CON15_RD5DESKEW1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON15_RD5DESKEW1. */
#define BS_DDR_PHY_RD_DESKEW_CON15_RD5DESKEW1 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON15_RD5DESKEW1. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON15_RD5DESKEW1 field. */
#define BR_DDR_PHY_RD_DESKEW_CON15_RD5DESKEW1(x) (HW_DDR_PHY_RD_DESKEW_CON15(x).B.RD5DESKEW1)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON15, field RD5DESKEW2[23:16] (RO)
 *
 * Read DQ21 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON15_RD5DESKEW2 (16U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON15_RD5DESKEW2. */
#define BM_DDR_PHY_RD_DESKEW_CON15_RD5DESKEW2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON15_RD5DESKEW2. */
#define BS_DDR_PHY_RD_DESKEW_CON15_RD5DESKEW2 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON15_RD5DESKEW2. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON15_RD5DESKEW2 field. */
#define BR_DDR_PHY_RD_DESKEW_CON15_RD5DESKEW2(x) (HW_DDR_PHY_RD_DESKEW_CON15(x).B.RD5DESKEW2)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON15, field RD5DESKEW3[31:24] (RO)
 *
 * Read DQ29 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON15_RD5DESKEW3 (24U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON15_RD5DESKEW3. */
#define BM_DDR_PHY_RD_DESKEW_CON15_RD5DESKEW3 (0xFF000000U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON15_RD5DESKEW3. */
#define BS_DDR_PHY_RD_DESKEW_CON15_RD5DESKEW3 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON15_RD5DESKEW3. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON15_RD5DESKEW3 field. */
#define BR_DDR_PHY_RD_DESKEW_CON15_RD5DESKEW3(x) (HW_DDR_PHY_RD_DESKEW_CON15(x).B.RD5DESKEW3)
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_RD_DESKEW_CON18 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_RD_DESKEW_CON18 -  (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_rd_deskew_con18
{
    uint32_t U;
    struct _hw_ddr_phy_rd_deskew_con18_bitfields
    {
        uint32_t RD6DESKEW0 : 8;       /*!< [7:0]  */
        uint32_t RD6DESKEW1 : 8;       /*!< [15:8]  */
        uint32_t RD6DESKEW2 : 8;       /*!< [23:16]  */
        uint32_t RD6DESKEW3 : 8;       /*!< [31:24]  */
    } B;
} hw_ddr_phy_rd_deskew_con18_t;

/*!
 * @name Constants and macros for entire DDR_PHY_RD_DESKEW_CON18 register
 */
/*@{*/
#define HW_DDR_PHY_RD_DESKEW_CON18_ADDR(x) ((uintptr_t)(x) + 0x1D8U)

#define HW_DDR_PHY_RD_DESKEW_CON18(x) (*(__I hw_ddr_phy_rd_deskew_con18_t *) HW_DDR_PHY_RD_DESKEW_CON18_ADDR(x))
#define HW_DDR_PHY_RD_DESKEW_CON18_RD(x) (HW_DDR_PHY_RD_DESKEW_CON18(x).U)
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_RD_DESKEW_CON18 bitfields
 */

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON18, field RD6DESKEW0[7:0] (RO)
 *
 * Read DQ6 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON18_RD6DESKEW0 (0U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON18_RD6DESKEW0. */
#define BM_DDR_PHY_RD_DESKEW_CON18_RD6DESKEW0 (0x000000FFU) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON18_RD6DESKEW0. */
#define BS_DDR_PHY_RD_DESKEW_CON18_RD6DESKEW0 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON18_RD6DESKEW0. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON18_RD6DESKEW0 field. */
#define BR_DDR_PHY_RD_DESKEW_CON18_RD6DESKEW0(x) (HW_DDR_PHY_RD_DESKEW_CON18(x).B.RD6DESKEW0)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON18, field RD6DESKEW1[15:8] (RO)
 *
 * Read DQ14 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON18_RD6DESKEW1 (8U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON18_RD6DESKEW1. */
#define BM_DDR_PHY_RD_DESKEW_CON18_RD6DESKEW1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON18_RD6DESKEW1. */
#define BS_DDR_PHY_RD_DESKEW_CON18_RD6DESKEW1 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON18_RD6DESKEW1. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON18_RD6DESKEW1 field. */
#define BR_DDR_PHY_RD_DESKEW_CON18_RD6DESKEW1(x) (HW_DDR_PHY_RD_DESKEW_CON18(x).B.RD6DESKEW1)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON18, field RD6DESKEW2[23:16] (RO)
 *
 * Read DQ22 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON18_RD6DESKEW2 (16U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON18_RD6DESKEW2. */
#define BM_DDR_PHY_RD_DESKEW_CON18_RD6DESKEW2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON18_RD6DESKEW2. */
#define BS_DDR_PHY_RD_DESKEW_CON18_RD6DESKEW2 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON18_RD6DESKEW2. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON18_RD6DESKEW2 field. */
#define BR_DDR_PHY_RD_DESKEW_CON18_RD6DESKEW2(x) (HW_DDR_PHY_RD_DESKEW_CON18(x).B.RD6DESKEW2)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON18, field RD6DESKEW3[31:24] (RO)
 *
 * Read DQ30 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON18_RD6DESKEW3 (24U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON18_RD6DESKEW3. */
#define BM_DDR_PHY_RD_DESKEW_CON18_RD6DESKEW3 (0xFF000000U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON18_RD6DESKEW3. */
#define BS_DDR_PHY_RD_DESKEW_CON18_RD6DESKEW3 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON18_RD6DESKEW3. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON18_RD6DESKEW3 field. */
#define BR_DDR_PHY_RD_DESKEW_CON18_RD6DESKEW3(x) (HW_DDR_PHY_RD_DESKEW_CON18(x).B.RD6DESKEW3)
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_RD_DESKEW_CON21 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_RD_DESKEW_CON21 -  (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_rd_deskew_con21
{
    uint32_t U;
    struct _hw_ddr_phy_rd_deskew_con21_bitfields
    {
        uint32_t RD7DESKEW0 : 8;       /*!< [7:0]  */
        uint32_t RD7DESKEW1 : 8;       /*!< [15:8]  */
        uint32_t RD7DESKEW2 : 8;       /*!< [23:16]  */
        uint32_t RD7DESKEW3 : 8;       /*!< [31:24]  */
    } B;
} hw_ddr_phy_rd_deskew_con21_t;

/*!
 * @name Constants and macros for entire DDR_PHY_RD_DESKEW_CON21 register
 */
/*@{*/
#define HW_DDR_PHY_RD_DESKEW_CON21_ADDR(x) ((uintptr_t)(x) + 0x1E4U)

#define HW_DDR_PHY_RD_DESKEW_CON21(x) (*(__I hw_ddr_phy_rd_deskew_con21_t *) HW_DDR_PHY_RD_DESKEW_CON21_ADDR(x))
#define HW_DDR_PHY_RD_DESKEW_CON21_RD(x) (HW_DDR_PHY_RD_DESKEW_CON21(x).U)
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_RD_DESKEW_CON21 bitfields
 */

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON21, field RD7DESKEW0[7:0] (RO)
 *
 * Read DQ7 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON21_RD7DESKEW0 (0U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON21_RD7DESKEW0. */
#define BM_DDR_PHY_RD_DESKEW_CON21_RD7DESKEW0 (0x000000FFU) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON21_RD7DESKEW0. */
#define BS_DDR_PHY_RD_DESKEW_CON21_RD7DESKEW0 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON21_RD7DESKEW0. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON21_RD7DESKEW0 field. */
#define BR_DDR_PHY_RD_DESKEW_CON21_RD7DESKEW0(x) (HW_DDR_PHY_RD_DESKEW_CON21(x).B.RD7DESKEW0)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON21, field RD7DESKEW1[15:8] (RO)
 *
 * Read DQ15 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON21_RD7DESKEW1 (8U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON21_RD7DESKEW1. */
#define BM_DDR_PHY_RD_DESKEW_CON21_RD7DESKEW1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON21_RD7DESKEW1. */
#define BS_DDR_PHY_RD_DESKEW_CON21_RD7DESKEW1 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON21_RD7DESKEW1. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON21_RD7DESKEW1 field. */
#define BR_DDR_PHY_RD_DESKEW_CON21_RD7DESKEW1(x) (HW_DDR_PHY_RD_DESKEW_CON21(x).B.RD7DESKEW1)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON21, field RD7DESKEW2[23:16] (RO)
 *
 * Read DQ23 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON21_RD7DESKEW2 (16U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON21_RD7DESKEW2. */
#define BM_DDR_PHY_RD_DESKEW_CON21_RD7DESKEW2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON21_RD7DESKEW2. */
#define BS_DDR_PHY_RD_DESKEW_CON21_RD7DESKEW2 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON21_RD7DESKEW2. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON21_RD7DESKEW2 field. */
#define BR_DDR_PHY_RD_DESKEW_CON21_RD7DESKEW2(x) (HW_DDR_PHY_RD_DESKEW_CON21(x).B.RD7DESKEW2)
/*@}*/

/*!
 * @name Register DDR_PHY_RD_DESKEW_CON21, field RD7DESKEW3[31:24] (RO)
 *
 * Read DQ31 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_RD_DESKEW_CON21_RD7DESKEW3 (24U) /*!< Bit position for DDR_PHY_RD_DESKEW_CON21_RD7DESKEW3. */
#define BM_DDR_PHY_RD_DESKEW_CON21_RD7DESKEW3 (0xFF000000U) /*!< Bit mask for DDR_PHY_RD_DESKEW_CON21_RD7DESKEW3. */
#define BS_DDR_PHY_RD_DESKEW_CON21_RD7DESKEW3 (8U) /*!< Bit field size in bits for DDR_PHY_RD_DESKEW_CON21_RD7DESKEW3. */

/*! @brief Read current value of the DDR_PHY_RD_DESKEW_CON21_RD7DESKEW3 field. */
#define BR_DDR_PHY_RD_DESKEW_CON21_RD7DESKEW3(x) (HW_DDR_PHY_RD_DESKEW_CON21(x).B.RD7DESKEW3)
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_WR_DESKEW_CON0 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_WR_DESKEW_CON0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * WR DESKEW Control Register
 */
typedef union _hw_ddr_phy_wr_deskew_con0
{
    uint32_t U;
    struct _hw_ddr_phy_wr_deskew_con0_bitfields
    {
        uint32_t WR0DESKEW0 : 8;       /*!< [7:0]  */
        uint32_t WR0DESKEW1 : 8;       /*!< [15:8]  */
        uint32_t WR0DESKEW2 : 8;       /*!< [23:16]  */
        uint32_t WR0DESKEW3 : 8;       /*!< [31:24]  */
    } B;
} hw_ddr_phy_wr_deskew_con0_t;

/*!
 * @name Constants and macros for entire DDR_PHY_WR_DESKEW_CON0 register
 */
/*@{*/
#define HW_DDR_PHY_WR_DESKEW_CON0_ADDR(x) ((uintptr_t)(x) + 0x1F0U)

#define HW_DDR_PHY_WR_DESKEW_CON0(x) (*(__IO hw_ddr_phy_wr_deskew_con0_t *) HW_DDR_PHY_WR_DESKEW_CON0_ADDR(x))
#define HW_DDR_PHY_WR_DESKEW_CON0_RD(x) (HW_DDR_PHY_WR_DESKEW_CON0(x).U)
#define HW_DDR_PHY_WR_DESKEW_CON0_WR(x, v) (HW_DDR_PHY_WR_DESKEW_CON0(x).U = (v))
#define HW_DDR_PHY_WR_DESKEW_CON0_SET(x, v) (HW_DDR_PHY_WR_DESKEW_CON0_WR(x, HW_DDR_PHY_WR_DESKEW_CON0_RD(x) |  (v)))
#define HW_DDR_PHY_WR_DESKEW_CON0_CLR(x, v) (HW_DDR_PHY_WR_DESKEW_CON0_WR(x, HW_DDR_PHY_WR_DESKEW_CON0_RD(x) & ~(v)))
#define HW_DDR_PHY_WR_DESKEW_CON0_TOG(x, v) (HW_DDR_PHY_WR_DESKEW_CON0_WR(x, HW_DDR_PHY_WR_DESKEW_CON0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_WR_DESKEW_CON0 bitfields
 */

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON0, field WR0DESKEW0[7:0] (RW)
 *
 * Write DQ0 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0 (0U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0. */
#define BM_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0 (0x000000FFU) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0. */
#define BS_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0 field. */
#define BR_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0(x) (HW_DDR_PHY_WR_DESKEW_CON0(x).B.WR0DESKEW0)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0. */
#define BF_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0) & BM_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0)

/*! @brief Set the WR0DESKEW0 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0(x, v) (HW_DDR_PHY_WR_DESKEW_CON0_WR(x, (HW_DDR_PHY_WR_DESKEW_CON0_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0) | BF_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW0(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON0, field WR0DESKEW1[15:8] (RW)
 *
 * Write DQ8 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1 (8U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1. */
#define BM_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1. */
#define BS_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1 field. */
#define BR_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1(x) (HW_DDR_PHY_WR_DESKEW_CON0(x).B.WR0DESKEW1)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1. */
#define BF_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1) & BM_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1)

/*! @brief Set the WR0DESKEW1 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1(x, v) (HW_DDR_PHY_WR_DESKEW_CON0_WR(x, (HW_DDR_PHY_WR_DESKEW_CON0_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1) | BF_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW1(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON0, field WR0DESKEW2[23:16] (RW)
 *
 * Write DQ16 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2 (16U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2. */
#define BM_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2. */
#define BS_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2 field. */
#define BR_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2(x) (HW_DDR_PHY_WR_DESKEW_CON0(x).B.WR0DESKEW2)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2. */
#define BF_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2) & BM_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2)

/*! @brief Set the WR0DESKEW2 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2(x, v) (HW_DDR_PHY_WR_DESKEW_CON0_WR(x, (HW_DDR_PHY_WR_DESKEW_CON0_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2) | BF_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW2(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON0, field WR0DESKEW3[31:24] (RW)
 *
 * Wirte DQ24 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3 (24U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3. */
#define BM_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3 (0xFF000000U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3. */
#define BS_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3 field. */
#define BR_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3(x) (HW_DDR_PHY_WR_DESKEW_CON0(x).B.WR0DESKEW3)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3. */
#define BF_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3) & BM_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3)

/*! @brief Set the WR0DESKEW3 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3(x, v) (HW_DDR_PHY_WR_DESKEW_CON0_WR(x, (HW_DDR_PHY_WR_DESKEW_CON0_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3) | BF_DDR_PHY_WR_DESKEW_CON0_WR0DESKEW3(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_WR_DESKEW_CON3 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_WR_DESKEW_CON3 -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_wr_deskew_con3
{
    uint32_t U;
    struct _hw_ddr_phy_wr_deskew_con3_bitfields
    {
        uint32_t WR1DESKEW0 : 8;       /*!< [7:0]  */
        uint32_t WR1DESKEW1 : 8;       /*!< [15:8]  */
        uint32_t WR1DESKEW2 : 8;       /*!< [23:16]  */
        uint32_t WR1DESKEW3 : 8;       /*!< [31:24]  */
    } B;
} hw_ddr_phy_wr_deskew_con3_t;

/*!
 * @name Constants and macros for entire DDR_PHY_WR_DESKEW_CON3 register
 */
/*@{*/
#define HW_DDR_PHY_WR_DESKEW_CON3_ADDR(x) ((uintptr_t)(x) + 0x1FCU)

#define HW_DDR_PHY_WR_DESKEW_CON3(x) (*(__IO hw_ddr_phy_wr_deskew_con3_t *) HW_DDR_PHY_WR_DESKEW_CON3_ADDR(x))
#define HW_DDR_PHY_WR_DESKEW_CON3_RD(x) (HW_DDR_PHY_WR_DESKEW_CON3(x).U)
#define HW_DDR_PHY_WR_DESKEW_CON3_WR(x, v) (HW_DDR_PHY_WR_DESKEW_CON3(x).U = (v))
#define HW_DDR_PHY_WR_DESKEW_CON3_SET(x, v) (HW_DDR_PHY_WR_DESKEW_CON3_WR(x, HW_DDR_PHY_WR_DESKEW_CON3_RD(x) |  (v)))
#define HW_DDR_PHY_WR_DESKEW_CON3_CLR(x, v) (HW_DDR_PHY_WR_DESKEW_CON3_WR(x, HW_DDR_PHY_WR_DESKEW_CON3_RD(x) & ~(v)))
#define HW_DDR_PHY_WR_DESKEW_CON3_TOG(x, v) (HW_DDR_PHY_WR_DESKEW_CON3_WR(x, HW_DDR_PHY_WR_DESKEW_CON3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_WR_DESKEW_CON3 bitfields
 */

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON3, field WR1DESKEW0[7:0] (RW)
 *
 * Write DQ1 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0 (0U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0. */
#define BM_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0 (0x000000FFU) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0. */
#define BS_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0 field. */
#define BR_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0(x) (HW_DDR_PHY_WR_DESKEW_CON3(x).B.WR1DESKEW0)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0. */
#define BF_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0) & BM_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0)

/*! @brief Set the WR1DESKEW0 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0(x, v) (HW_DDR_PHY_WR_DESKEW_CON3_WR(x, (HW_DDR_PHY_WR_DESKEW_CON3_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0) | BF_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW0(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON3, field WR1DESKEW1[15:8] (RW)
 *
 * Write DQ9 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1 (8U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1. */
#define BM_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1. */
#define BS_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1 field. */
#define BR_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1(x) (HW_DDR_PHY_WR_DESKEW_CON3(x).B.WR1DESKEW1)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1. */
#define BF_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1) & BM_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1)

/*! @brief Set the WR1DESKEW1 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1(x, v) (HW_DDR_PHY_WR_DESKEW_CON3_WR(x, (HW_DDR_PHY_WR_DESKEW_CON3_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1) | BF_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW1(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON3, field WR1DESKEW2[23:16] (RW)
 *
 * Write DQ17 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2 (16U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2. */
#define BM_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2. */
#define BS_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2 field. */
#define BR_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2(x) (HW_DDR_PHY_WR_DESKEW_CON3(x).B.WR1DESKEW2)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2. */
#define BF_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2) & BM_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2)

/*! @brief Set the WR1DESKEW2 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2(x, v) (HW_DDR_PHY_WR_DESKEW_CON3_WR(x, (HW_DDR_PHY_WR_DESKEW_CON3_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2) | BF_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW2(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON3, field WR1DESKEW3[31:24] (RW)
 *
 * Write DQ25 De-Skew Code
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3 (24U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3. */
#define BM_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3 (0xFF000000U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3. */
#define BS_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3 field. */
#define BR_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3(x) (HW_DDR_PHY_WR_DESKEW_CON3(x).B.WR1DESKEW3)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3. */
#define BF_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3) & BM_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3)

/*! @brief Set the WR1DESKEW3 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3(x, v) (HW_DDR_PHY_WR_DESKEW_CON3_WR(x, (HW_DDR_PHY_WR_DESKEW_CON3_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3) | BF_DDR_PHY_WR_DESKEW_CON3_WR1DESKEW3(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_WR_DESKEW_CON6 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_WR_DESKEW_CON6 -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_wr_deskew_con6
{
    uint32_t U;
    struct _hw_ddr_phy_wr_deskew_con6_bitfields
    {
        uint32_t WR2DESKEW0 : 8;       /*!< [7:0]  */
        uint32_t WR2DESKEW1 : 8;       /*!< [15:8]  */
        uint32_t WR2DESKEW2 : 8;       /*!< [23:16]  */
        uint32_t WR2DESKEW3 : 8;       /*!< [31:24]  */
    } B;
} hw_ddr_phy_wr_deskew_con6_t;

/*!
 * @name Constants and macros for entire DDR_PHY_WR_DESKEW_CON6 register
 */
/*@{*/
#define HW_DDR_PHY_WR_DESKEW_CON6_ADDR(x) ((uintptr_t)(x) + 0x208U)

#define HW_DDR_PHY_WR_DESKEW_CON6(x) (*(__IO hw_ddr_phy_wr_deskew_con6_t *) HW_DDR_PHY_WR_DESKEW_CON6_ADDR(x))
#define HW_DDR_PHY_WR_DESKEW_CON6_RD(x) (HW_DDR_PHY_WR_DESKEW_CON6(x).U)
#define HW_DDR_PHY_WR_DESKEW_CON6_WR(x, v) (HW_DDR_PHY_WR_DESKEW_CON6(x).U = (v))
#define HW_DDR_PHY_WR_DESKEW_CON6_SET(x, v) (HW_DDR_PHY_WR_DESKEW_CON6_WR(x, HW_DDR_PHY_WR_DESKEW_CON6_RD(x) |  (v)))
#define HW_DDR_PHY_WR_DESKEW_CON6_CLR(x, v) (HW_DDR_PHY_WR_DESKEW_CON6_WR(x, HW_DDR_PHY_WR_DESKEW_CON6_RD(x) & ~(v)))
#define HW_DDR_PHY_WR_DESKEW_CON6_TOG(x, v) (HW_DDR_PHY_WR_DESKEW_CON6_WR(x, HW_DDR_PHY_WR_DESKEW_CON6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_WR_DESKEW_CON6 bitfields
 */

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON6, field WR2DESKEW0[7:0] (RW)
 *
 * Write DQ2 De-Skew Code for Data Slice0.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0 (0U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0. */
#define BM_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0 (0x000000FFU) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0. */
#define BS_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0 field. */
#define BR_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0(x) (HW_DDR_PHY_WR_DESKEW_CON6(x).B.WR2DESKEW0)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0. */
#define BF_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0) & BM_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0)

/*! @brief Set the WR2DESKEW0 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0(x, v) (HW_DDR_PHY_WR_DESKEW_CON6_WR(x, (HW_DDR_PHY_WR_DESKEW_CON6_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0) | BF_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW0(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON6, field WR2DESKEW1[15:8] (RW)
 *
 * Write DQ2 De-Skew Code for Data Slice1.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1 (8U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1. */
#define BM_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1. */
#define BS_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1 field. */
#define BR_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1(x) (HW_DDR_PHY_WR_DESKEW_CON6(x).B.WR2DESKEW1)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1. */
#define BF_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1) & BM_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1)

/*! @brief Set the WR2DESKEW1 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1(x, v) (HW_DDR_PHY_WR_DESKEW_CON6_WR(x, (HW_DDR_PHY_WR_DESKEW_CON6_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1) | BF_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW1(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON6, field WR2DESKEW2[23:16] (RW)
 *
 * Write DQ2 De-Skew Code for Data Slice2.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2 (16U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2. */
#define BM_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2. */
#define BS_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2 field. */
#define BR_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2(x) (HW_DDR_PHY_WR_DESKEW_CON6(x).B.WR2DESKEW2)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2. */
#define BF_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2) & BM_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2)

/*! @brief Set the WR2DESKEW2 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2(x, v) (HW_DDR_PHY_WR_DESKEW_CON6_WR(x, (HW_DDR_PHY_WR_DESKEW_CON6_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2) | BF_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW2(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON6, field WR2DESKEW3[31:24] (RW)
 *
 * Write DQ2 De-Skew Code for Data Slice3.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3 (24U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3. */
#define BM_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3 (0xFF000000U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3. */
#define BS_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3 field. */
#define BR_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3(x) (HW_DDR_PHY_WR_DESKEW_CON6(x).B.WR2DESKEW3)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3. */
#define BF_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3) & BM_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3)

/*! @brief Set the WR2DESKEW3 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3(x, v) (HW_DDR_PHY_WR_DESKEW_CON6_WR(x, (HW_DDR_PHY_WR_DESKEW_CON6_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3) | BF_DDR_PHY_WR_DESKEW_CON6_WR2DESKEW3(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_WR_DESKEW_CON9 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_WR_DESKEW_CON9 -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_wr_deskew_con9
{
    uint32_t U;
    struct _hw_ddr_phy_wr_deskew_con9_bitfields
    {
        uint32_t WR3DESKEW0 : 8;       /*!< [7:0]  */
        uint32_t WR3DESKEW1 : 8;       /*!< [15:8]  */
        uint32_t WR3DESKEW2 : 8;       /*!< [23:16]  */
        uint32_t WR3DESKEW3 : 8;       /*!< [31:24]  */
    } B;
} hw_ddr_phy_wr_deskew_con9_t;

/*!
 * @name Constants and macros for entire DDR_PHY_WR_DESKEW_CON9 register
 */
/*@{*/
#define HW_DDR_PHY_WR_DESKEW_CON9_ADDR(x) ((uintptr_t)(x) + 0x214U)

#define HW_DDR_PHY_WR_DESKEW_CON9(x) (*(__IO hw_ddr_phy_wr_deskew_con9_t *) HW_DDR_PHY_WR_DESKEW_CON9_ADDR(x))
#define HW_DDR_PHY_WR_DESKEW_CON9_RD(x) (HW_DDR_PHY_WR_DESKEW_CON9(x).U)
#define HW_DDR_PHY_WR_DESKEW_CON9_WR(x, v) (HW_DDR_PHY_WR_DESKEW_CON9(x).U = (v))
#define HW_DDR_PHY_WR_DESKEW_CON9_SET(x, v) (HW_DDR_PHY_WR_DESKEW_CON9_WR(x, HW_DDR_PHY_WR_DESKEW_CON9_RD(x) |  (v)))
#define HW_DDR_PHY_WR_DESKEW_CON9_CLR(x, v) (HW_DDR_PHY_WR_DESKEW_CON9_WR(x, HW_DDR_PHY_WR_DESKEW_CON9_RD(x) & ~(v)))
#define HW_DDR_PHY_WR_DESKEW_CON9_TOG(x, v) (HW_DDR_PHY_WR_DESKEW_CON9_WR(x, HW_DDR_PHY_WR_DESKEW_CON9_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_WR_DESKEW_CON9 bitfields
 */

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON9, field WR3DESKEW0[7:0] (RW)
 *
 * Write DQ3 De-Skew Code for Data Slice0.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0 (0U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0. */
#define BM_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0 (0x000000FFU) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0. */
#define BS_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0 field. */
#define BR_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0(x) (HW_DDR_PHY_WR_DESKEW_CON9(x).B.WR3DESKEW0)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0. */
#define BF_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0) & BM_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0)

/*! @brief Set the WR3DESKEW0 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0(x, v) (HW_DDR_PHY_WR_DESKEW_CON9_WR(x, (HW_DDR_PHY_WR_DESKEW_CON9_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0) | BF_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW0(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON9, field WR3DESKEW1[15:8] (RW)
 *
 * Write DQ3 De-Skew Code for Data Slice1.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1 (8U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1. */
#define BM_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1. */
#define BS_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1 field. */
#define BR_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1(x) (HW_DDR_PHY_WR_DESKEW_CON9(x).B.WR3DESKEW1)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1. */
#define BF_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1) & BM_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1)

/*! @brief Set the WR3DESKEW1 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1(x, v) (HW_DDR_PHY_WR_DESKEW_CON9_WR(x, (HW_DDR_PHY_WR_DESKEW_CON9_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1) | BF_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW1(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON9, field WR3DESKEW2[23:16] (RW)
 *
 * Write DQ3 De-Skew Code for Data Slice2.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2 (16U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2. */
#define BM_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2. */
#define BS_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2 field. */
#define BR_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2(x) (HW_DDR_PHY_WR_DESKEW_CON9(x).B.WR3DESKEW2)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2. */
#define BF_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2) & BM_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2)

/*! @brief Set the WR3DESKEW2 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2(x, v) (HW_DDR_PHY_WR_DESKEW_CON9_WR(x, (HW_DDR_PHY_WR_DESKEW_CON9_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2) | BF_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW2(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON9, field WR3DESKEW3[31:24] (RW)
 *
 * Write DQ3 De-Skew Code for Data Slice3.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3 (24U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3. */
#define BM_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3 (0xFF000000U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3. */
#define BS_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3 field. */
#define BR_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3(x) (HW_DDR_PHY_WR_DESKEW_CON9(x).B.WR3DESKEW3)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3. */
#define BF_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3) & BM_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3)

/*! @brief Set the WR3DESKEW3 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3(x, v) (HW_DDR_PHY_WR_DESKEW_CON9_WR(x, (HW_DDR_PHY_WR_DESKEW_CON9_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3) | BF_DDR_PHY_WR_DESKEW_CON9_WR3DESKEW3(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_WR_DESKEW_CON12 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_WR_DESKEW_CON12 -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_wr_deskew_con12
{
    uint32_t U;
    struct _hw_ddr_phy_wr_deskew_con12_bitfields
    {
        uint32_t WR4DESKEW0 : 8;       /*!< [7:0]  */
        uint32_t WR4DESKEW1 : 8;       /*!< [15:8]  */
        uint32_t WR4DESKEW2 : 8;       /*!< [23:16]  */
        uint32_t WR4DESKEW3 : 8;       /*!< [31:24]  */
    } B;
} hw_ddr_phy_wr_deskew_con12_t;

/*!
 * @name Constants and macros for entire DDR_PHY_WR_DESKEW_CON12 register
 */
/*@{*/
#define HW_DDR_PHY_WR_DESKEW_CON12_ADDR(x) ((uintptr_t)(x) + 0x220U)

#define HW_DDR_PHY_WR_DESKEW_CON12(x) (*(__IO hw_ddr_phy_wr_deskew_con12_t *) HW_DDR_PHY_WR_DESKEW_CON12_ADDR(x))
#define HW_DDR_PHY_WR_DESKEW_CON12_RD(x) (HW_DDR_PHY_WR_DESKEW_CON12(x).U)
#define HW_DDR_PHY_WR_DESKEW_CON12_WR(x, v) (HW_DDR_PHY_WR_DESKEW_CON12(x).U = (v))
#define HW_DDR_PHY_WR_DESKEW_CON12_SET(x, v) (HW_DDR_PHY_WR_DESKEW_CON12_WR(x, HW_DDR_PHY_WR_DESKEW_CON12_RD(x) |  (v)))
#define HW_DDR_PHY_WR_DESKEW_CON12_CLR(x, v) (HW_DDR_PHY_WR_DESKEW_CON12_WR(x, HW_DDR_PHY_WR_DESKEW_CON12_RD(x) & ~(v)))
#define HW_DDR_PHY_WR_DESKEW_CON12_TOG(x, v) (HW_DDR_PHY_WR_DESKEW_CON12_WR(x, HW_DDR_PHY_WR_DESKEW_CON12_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_WR_DESKEW_CON12 bitfields
 */

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON12, field WR4DESKEW0[7:0] (RW)
 *
 * Write DQ4 De-Skew Code for Data Slice0.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0 (0U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0. */
#define BM_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0 (0x000000FFU) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0. */
#define BS_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0 field. */
#define BR_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0(x) (HW_DDR_PHY_WR_DESKEW_CON12(x).B.WR4DESKEW0)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0. */
#define BF_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0) & BM_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0)

/*! @brief Set the WR4DESKEW0 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0(x, v) (HW_DDR_PHY_WR_DESKEW_CON12_WR(x, (HW_DDR_PHY_WR_DESKEW_CON12_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0) | BF_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW0(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON12, field WR4DESKEW1[15:8] (RW)
 *
 * Write DQ4 De-Skew Code for Data Slice1.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1 (8U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1. */
#define BM_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1. */
#define BS_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1 field. */
#define BR_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1(x) (HW_DDR_PHY_WR_DESKEW_CON12(x).B.WR4DESKEW1)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1. */
#define BF_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1) & BM_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1)

/*! @brief Set the WR4DESKEW1 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1(x, v) (HW_DDR_PHY_WR_DESKEW_CON12_WR(x, (HW_DDR_PHY_WR_DESKEW_CON12_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1) | BF_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW1(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON12, field WR4DESKEW2[23:16] (RW)
 *
 * Write DQ4 De-Skew Code for Data Slice2.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2 (16U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2. */
#define BM_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2. */
#define BS_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2 field. */
#define BR_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2(x) (HW_DDR_PHY_WR_DESKEW_CON12(x).B.WR4DESKEW2)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2. */
#define BF_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2) & BM_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2)

/*! @brief Set the WR4DESKEW2 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2(x, v) (HW_DDR_PHY_WR_DESKEW_CON12_WR(x, (HW_DDR_PHY_WR_DESKEW_CON12_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2) | BF_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW2(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON12, field WR4DESKEW3[31:24] (RW)
 *
 * Write DQ4 De-Skew Code for Data Slice3.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3 (24U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3. */
#define BM_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3 (0xFF000000U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3. */
#define BS_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3 field. */
#define BR_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3(x) (HW_DDR_PHY_WR_DESKEW_CON12(x).B.WR4DESKEW3)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3. */
#define BF_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3) & BM_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3)

/*! @brief Set the WR4DESKEW3 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3(x, v) (HW_DDR_PHY_WR_DESKEW_CON12_WR(x, (HW_DDR_PHY_WR_DESKEW_CON12_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3) | BF_DDR_PHY_WR_DESKEW_CON12_WR4DESKEW3(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_WR_DESKEW_CON15 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_WR_DESKEW_CON15 -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_wr_deskew_con15
{
    uint32_t U;
    struct _hw_ddr_phy_wr_deskew_con15_bitfields
    {
        uint32_t WR5DESKEW0 : 8;       /*!< [7:0]  */
        uint32_t WR5DESKEW1 : 8;       /*!< [15:8]  */
        uint32_t WR5DESKEW2 : 8;       /*!< [23:16]  */
        uint32_t WR5DESKEW3 : 8;       /*!< [31:24]  */
    } B;
} hw_ddr_phy_wr_deskew_con15_t;

/*!
 * @name Constants and macros for entire DDR_PHY_WR_DESKEW_CON15 register
 */
/*@{*/
#define HW_DDR_PHY_WR_DESKEW_CON15_ADDR(x) ((uintptr_t)(x) + 0x22CU)

#define HW_DDR_PHY_WR_DESKEW_CON15(x) (*(__IO hw_ddr_phy_wr_deskew_con15_t *) HW_DDR_PHY_WR_DESKEW_CON15_ADDR(x))
#define HW_DDR_PHY_WR_DESKEW_CON15_RD(x) (HW_DDR_PHY_WR_DESKEW_CON15(x).U)
#define HW_DDR_PHY_WR_DESKEW_CON15_WR(x, v) (HW_DDR_PHY_WR_DESKEW_CON15(x).U = (v))
#define HW_DDR_PHY_WR_DESKEW_CON15_SET(x, v) (HW_DDR_PHY_WR_DESKEW_CON15_WR(x, HW_DDR_PHY_WR_DESKEW_CON15_RD(x) |  (v)))
#define HW_DDR_PHY_WR_DESKEW_CON15_CLR(x, v) (HW_DDR_PHY_WR_DESKEW_CON15_WR(x, HW_DDR_PHY_WR_DESKEW_CON15_RD(x) & ~(v)))
#define HW_DDR_PHY_WR_DESKEW_CON15_TOG(x, v) (HW_DDR_PHY_WR_DESKEW_CON15_WR(x, HW_DDR_PHY_WR_DESKEW_CON15_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_WR_DESKEW_CON15 bitfields
 */

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON15, field WR5DESKEW0[7:0] (RW)
 *
 * Write DQ5 De-Skew Code for Data Slice0.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0 (0U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0. */
#define BM_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0 (0x000000FFU) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0. */
#define BS_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0 field. */
#define BR_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0(x) (HW_DDR_PHY_WR_DESKEW_CON15(x).B.WR5DESKEW0)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0. */
#define BF_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0) & BM_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0)

/*! @brief Set the WR5DESKEW0 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0(x, v) (HW_DDR_PHY_WR_DESKEW_CON15_WR(x, (HW_DDR_PHY_WR_DESKEW_CON15_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0) | BF_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW0(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON15, field WR5DESKEW1[15:8] (RW)
 *
 * Write DQ5 De-Skew Code for Data Slice1.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1 (8U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1. */
#define BM_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1. */
#define BS_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1 field. */
#define BR_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1(x) (HW_DDR_PHY_WR_DESKEW_CON15(x).B.WR5DESKEW1)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1. */
#define BF_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1) & BM_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1)

/*! @brief Set the WR5DESKEW1 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1(x, v) (HW_DDR_PHY_WR_DESKEW_CON15_WR(x, (HW_DDR_PHY_WR_DESKEW_CON15_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1) | BF_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW1(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON15, field WR5DESKEW2[23:16] (RW)
 *
 * Write DQ5 De-Skew Code for Data Slice2.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2 (16U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2. */
#define BM_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2. */
#define BS_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2 field. */
#define BR_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2(x) (HW_DDR_PHY_WR_DESKEW_CON15(x).B.WR5DESKEW2)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2. */
#define BF_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2) & BM_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2)

/*! @brief Set the WR5DESKEW2 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2(x, v) (HW_DDR_PHY_WR_DESKEW_CON15_WR(x, (HW_DDR_PHY_WR_DESKEW_CON15_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2) | BF_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW2(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON15, field WR5DESKEW3[31:24] (RW)
 *
 * Write DQ5 De-Skew Code for Data Slice3.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3 (24U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3. */
#define BM_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3 (0xFF000000U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3. */
#define BS_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3 field. */
#define BR_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3(x) (HW_DDR_PHY_WR_DESKEW_CON15(x).B.WR5DESKEW3)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3. */
#define BF_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3) & BM_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3)

/*! @brief Set the WR5DESKEW3 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3(x, v) (HW_DDR_PHY_WR_DESKEW_CON15_WR(x, (HW_DDR_PHY_WR_DESKEW_CON15_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3) | BF_DDR_PHY_WR_DESKEW_CON15_WR5DESKEW3(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_WR_DESKEW_CON18 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_WR_DESKEW_CON18 -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_wr_deskew_con18
{
    uint32_t U;
    struct _hw_ddr_phy_wr_deskew_con18_bitfields
    {
        uint32_t RD6DESKEW0 : 8;       /*!< [7:0]  */
        uint32_t WR6DESKEW1 : 8;       /*!< [15:8]  */
        uint32_t WR6DESKEW2 : 8;       /*!< [23:16]  */
        uint32_t WR6DESKEW3 : 8;       /*!< [31:24]  */
    } B;
} hw_ddr_phy_wr_deskew_con18_t;

/*!
 * @name Constants and macros for entire DDR_PHY_WR_DESKEW_CON18 register
 */
/*@{*/
#define HW_DDR_PHY_WR_DESKEW_CON18_ADDR(x) ((uintptr_t)(x) + 0x238U)

#define HW_DDR_PHY_WR_DESKEW_CON18(x) (*(__IO hw_ddr_phy_wr_deskew_con18_t *) HW_DDR_PHY_WR_DESKEW_CON18_ADDR(x))
#define HW_DDR_PHY_WR_DESKEW_CON18_RD(x) (HW_DDR_PHY_WR_DESKEW_CON18(x).U)
#define HW_DDR_PHY_WR_DESKEW_CON18_WR(x, v) (HW_DDR_PHY_WR_DESKEW_CON18(x).U = (v))
#define HW_DDR_PHY_WR_DESKEW_CON18_SET(x, v) (HW_DDR_PHY_WR_DESKEW_CON18_WR(x, HW_DDR_PHY_WR_DESKEW_CON18_RD(x) |  (v)))
#define HW_DDR_PHY_WR_DESKEW_CON18_CLR(x, v) (HW_DDR_PHY_WR_DESKEW_CON18_WR(x, HW_DDR_PHY_WR_DESKEW_CON18_RD(x) & ~(v)))
#define HW_DDR_PHY_WR_DESKEW_CON18_TOG(x, v) (HW_DDR_PHY_WR_DESKEW_CON18_WR(x, HW_DDR_PHY_WR_DESKEW_CON18_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_WR_DESKEW_CON18 bitfields
 */

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON18, field RD6DESKEW0[7:0] (RO)
 *
 * Read DQ6 De-Skew Code for Data Slice0.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON18_RD6DESKEW0 (0U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON18_RD6DESKEW0. */
#define BM_DDR_PHY_WR_DESKEW_CON18_RD6DESKEW0 (0x000000FFU) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON18_RD6DESKEW0. */
#define BS_DDR_PHY_WR_DESKEW_CON18_RD6DESKEW0 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON18_RD6DESKEW0. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON18_RD6DESKEW0 field. */
#define BR_DDR_PHY_WR_DESKEW_CON18_RD6DESKEW0(x) (HW_DDR_PHY_WR_DESKEW_CON18(x).B.RD6DESKEW0)
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON18, field WR6DESKEW1[15:8] (RW)
 *
 * Write DQ6 De-Skew Code for Data Slice1.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1 (8U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1. */
#define BM_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1. */
#define BS_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1 field. */
#define BR_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1(x) (HW_DDR_PHY_WR_DESKEW_CON18(x).B.WR6DESKEW1)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1. */
#define BF_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1) & BM_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1)

/*! @brief Set the WR6DESKEW1 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1(x, v) (HW_DDR_PHY_WR_DESKEW_CON18_WR(x, (HW_DDR_PHY_WR_DESKEW_CON18_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1) | BF_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW1(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON18, field WR6DESKEW2[23:16] (RW)
 *
 * Write DQ6 De-Skew Code for Data Slice2.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2 (16U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2. */
#define BM_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2. */
#define BS_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2 field. */
#define BR_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2(x) (HW_DDR_PHY_WR_DESKEW_CON18(x).B.WR6DESKEW2)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2. */
#define BF_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2) & BM_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2)

/*! @brief Set the WR6DESKEW2 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2(x, v) (HW_DDR_PHY_WR_DESKEW_CON18_WR(x, (HW_DDR_PHY_WR_DESKEW_CON18_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2) | BF_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW2(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON18, field WR6DESKEW3[31:24] (RW)
 *
 * Write DQ6 De-Skew Code for Data Slice3.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3 (24U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3. */
#define BM_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3 (0xFF000000U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3. */
#define BS_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3 field. */
#define BR_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3(x) (HW_DDR_PHY_WR_DESKEW_CON18(x).B.WR6DESKEW3)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3. */
#define BF_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3) & BM_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3)

/*! @brief Set the WR6DESKEW3 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3(x, v) (HW_DDR_PHY_WR_DESKEW_CON18_WR(x, (HW_DDR_PHY_WR_DESKEW_CON18_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3) | BF_DDR_PHY_WR_DESKEW_CON18_WR6DESKEW3(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_WR_DESKEW_CON21 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_WR_DESKEW_CON21 -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_wr_deskew_con21
{
    uint32_t U;
    struct _hw_ddr_phy_wr_deskew_con21_bitfields
    {
        uint32_t WR7DESKEW0 : 8;       /*!< [7:0]  */
        uint32_t WR7DESKEW1 : 8;       /*!< [15:8]  */
        uint32_t WR7DESKEW2 : 8;       /*!< [23:16]  */
        uint32_t WR7DESKEW3 : 8;       /*!< [31:24]  */
    } B;
} hw_ddr_phy_wr_deskew_con21_t;

/*!
 * @name Constants and macros for entire DDR_PHY_WR_DESKEW_CON21 register
 */
/*@{*/
#define HW_DDR_PHY_WR_DESKEW_CON21_ADDR(x) ((uintptr_t)(x) + 0x244U)

#define HW_DDR_PHY_WR_DESKEW_CON21(x) (*(__IO hw_ddr_phy_wr_deskew_con21_t *) HW_DDR_PHY_WR_DESKEW_CON21_ADDR(x))
#define HW_DDR_PHY_WR_DESKEW_CON21_RD(x) (HW_DDR_PHY_WR_DESKEW_CON21(x).U)
#define HW_DDR_PHY_WR_DESKEW_CON21_WR(x, v) (HW_DDR_PHY_WR_DESKEW_CON21(x).U = (v))
#define HW_DDR_PHY_WR_DESKEW_CON21_SET(x, v) (HW_DDR_PHY_WR_DESKEW_CON21_WR(x, HW_DDR_PHY_WR_DESKEW_CON21_RD(x) |  (v)))
#define HW_DDR_PHY_WR_DESKEW_CON21_CLR(x, v) (HW_DDR_PHY_WR_DESKEW_CON21_WR(x, HW_DDR_PHY_WR_DESKEW_CON21_RD(x) & ~(v)))
#define HW_DDR_PHY_WR_DESKEW_CON21_TOG(x, v) (HW_DDR_PHY_WR_DESKEW_CON21_WR(x, HW_DDR_PHY_WR_DESKEW_CON21_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_WR_DESKEW_CON21 bitfields
 */

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON21, field WR7DESKEW0[7:0] (RW)
 *
 * Write DQ7 De-Skew Code for Data Slice0.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0 (0U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0. */
#define BM_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0 (0x000000FFU) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0. */
#define BS_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0 field. */
#define BR_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0(x) (HW_DDR_PHY_WR_DESKEW_CON21(x).B.WR7DESKEW0)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0. */
#define BF_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0) & BM_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0)

/*! @brief Set the WR7DESKEW0 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0(x, v) (HW_DDR_PHY_WR_DESKEW_CON21_WR(x, (HW_DDR_PHY_WR_DESKEW_CON21_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0) | BF_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW0(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON21, field WR7DESKEW1[15:8] (RW)
 *
 * Write DQ7 De-Skew Code for Data Slice1.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1 (8U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1. */
#define BM_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1. */
#define BS_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1 field. */
#define BR_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1(x) (HW_DDR_PHY_WR_DESKEW_CON21(x).B.WR7DESKEW1)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1. */
#define BF_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1) & BM_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1)

/*! @brief Set the WR7DESKEW1 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1(x, v) (HW_DDR_PHY_WR_DESKEW_CON21_WR(x, (HW_DDR_PHY_WR_DESKEW_CON21_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1) | BF_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW1(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON21, field WR7DESKEW2[23:16] (RW)
 *
 * Write DQ7 De-Skew Code for Data Slice2.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2 (16U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2. */
#define BM_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2. */
#define BS_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2 field. */
#define BR_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2(x) (HW_DDR_PHY_WR_DESKEW_CON21(x).B.WR7DESKEW2)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2. */
#define BF_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2) & BM_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2)

/*! @brief Set the WR7DESKEW2 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2(x, v) (HW_DDR_PHY_WR_DESKEW_CON21_WR(x, (HW_DDR_PHY_WR_DESKEW_CON21_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2) | BF_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW2(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_WR_DESKEW_CON21, field WR7DESKEW3[31:24] (RW)
 *
 * Write DQ7 De-Skew Code for Data Slice3.
 */
/*@{*/
#define BP_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3 (24U) /*!< Bit position for DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3. */
#define BM_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3 (0xFF000000U) /*!< Bit mask for DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3. */
#define BS_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3 (8U) /*!< Bit field size in bits for DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3. */

/*! @brief Read current value of the DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3 field. */
#define BR_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3(x) (HW_DDR_PHY_WR_DESKEW_CON21(x).B.WR7DESKEW3)

/*! @brief Format value for bitfield DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3. */
#define BF_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3) & BM_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3)

/*! @brief Set the WR7DESKEW3 field to a new value. */
#define BW_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3(x, v) (HW_DDR_PHY_WR_DESKEW_CON21_WR(x, (HW_DDR_PHY_WR_DESKEW_CON21_RD(x) & ~BM_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3) | BF_DDR_PHY_WR_DESKEW_CON21_WR7DESKEW3(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_DM_DESKEW_CON -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_DM_DESKEW_CON -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_dm_deskew_con
{
    uint32_t U;
    struct _hw_ddr_phy_dm_deskew_con_bitfields
    {
        uint32_t DMDESKEW0 : 8;        /*!< [7:0]  */
        uint32_t DMDESKEW1 : 8;        /*!< [15:8]  */
        uint32_t DMDESKEW2 : 8;        /*!< [23:16]  */
        uint32_t DMDESKEW3 : 8;        /*!< [31:24]  */
    } B;
} hw_ddr_phy_dm_deskew_con_t;

/*!
 * @name Constants and macros for entire DDR_PHY_DM_DESKEW_CON register
 */
/*@{*/
#define HW_DDR_PHY_DM_DESKEW_CON_ADDR(x) ((uintptr_t)(x) + 0x250U)

#define HW_DDR_PHY_DM_DESKEW_CON(x) (*(__IO hw_ddr_phy_dm_deskew_con_t *) HW_DDR_PHY_DM_DESKEW_CON_ADDR(x))
#define HW_DDR_PHY_DM_DESKEW_CON_RD(x) (HW_DDR_PHY_DM_DESKEW_CON(x).U)
#define HW_DDR_PHY_DM_DESKEW_CON_WR(x, v) (HW_DDR_PHY_DM_DESKEW_CON(x).U = (v))
#define HW_DDR_PHY_DM_DESKEW_CON_SET(x, v) (HW_DDR_PHY_DM_DESKEW_CON_WR(x, HW_DDR_PHY_DM_DESKEW_CON_RD(x) |  (v)))
#define HW_DDR_PHY_DM_DESKEW_CON_CLR(x, v) (HW_DDR_PHY_DM_DESKEW_CON_WR(x, HW_DDR_PHY_DM_DESKEW_CON_RD(x) & ~(v)))
#define HW_DDR_PHY_DM_DESKEW_CON_TOG(x, v) (HW_DDR_PHY_DM_DESKEW_CON_WR(x, HW_DDR_PHY_DM_DESKEW_CON_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_DM_DESKEW_CON bitfields
 */

/*!
 * @name Register DDR_PHY_DM_DESKEW_CON, field DMDESKEW0[7:0] (RW)
 *
 * Write DM De-Skew Code for Data Slice0.
 */
/*@{*/
#define BP_DDR_PHY_DM_DESKEW_CON_DMDESKEW0 (0U) /*!< Bit position for DDR_PHY_DM_DESKEW_CON_DMDESKEW0. */
#define BM_DDR_PHY_DM_DESKEW_CON_DMDESKEW0 (0x000000FFU) /*!< Bit mask for DDR_PHY_DM_DESKEW_CON_DMDESKEW0. */
#define BS_DDR_PHY_DM_DESKEW_CON_DMDESKEW0 (8U) /*!< Bit field size in bits for DDR_PHY_DM_DESKEW_CON_DMDESKEW0. */

/*! @brief Read current value of the DDR_PHY_DM_DESKEW_CON_DMDESKEW0 field. */
#define BR_DDR_PHY_DM_DESKEW_CON_DMDESKEW0(x) (HW_DDR_PHY_DM_DESKEW_CON(x).B.DMDESKEW0)

/*! @brief Format value for bitfield DDR_PHY_DM_DESKEW_CON_DMDESKEW0. */
#define BF_DDR_PHY_DM_DESKEW_CON_DMDESKEW0(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_DM_DESKEW_CON_DMDESKEW0) & BM_DDR_PHY_DM_DESKEW_CON_DMDESKEW0)

/*! @brief Set the DMDESKEW0 field to a new value. */
#define BW_DDR_PHY_DM_DESKEW_CON_DMDESKEW0(x, v) (HW_DDR_PHY_DM_DESKEW_CON_WR(x, (HW_DDR_PHY_DM_DESKEW_CON_RD(x) & ~BM_DDR_PHY_DM_DESKEW_CON_DMDESKEW0) | BF_DDR_PHY_DM_DESKEW_CON_DMDESKEW0(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_DM_DESKEW_CON, field DMDESKEW1[15:8] (RW)
 *
 * Write DM De-Skew Code for Data Slice1.
 */
/*@{*/
#define BP_DDR_PHY_DM_DESKEW_CON_DMDESKEW1 (8U) /*!< Bit position for DDR_PHY_DM_DESKEW_CON_DMDESKEW1. */
#define BM_DDR_PHY_DM_DESKEW_CON_DMDESKEW1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_DM_DESKEW_CON_DMDESKEW1. */
#define BS_DDR_PHY_DM_DESKEW_CON_DMDESKEW1 (8U) /*!< Bit field size in bits for DDR_PHY_DM_DESKEW_CON_DMDESKEW1. */

/*! @brief Read current value of the DDR_PHY_DM_DESKEW_CON_DMDESKEW1 field. */
#define BR_DDR_PHY_DM_DESKEW_CON_DMDESKEW1(x) (HW_DDR_PHY_DM_DESKEW_CON(x).B.DMDESKEW1)

/*! @brief Format value for bitfield DDR_PHY_DM_DESKEW_CON_DMDESKEW1. */
#define BF_DDR_PHY_DM_DESKEW_CON_DMDESKEW1(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_DM_DESKEW_CON_DMDESKEW1) & BM_DDR_PHY_DM_DESKEW_CON_DMDESKEW1)

/*! @brief Set the DMDESKEW1 field to a new value. */
#define BW_DDR_PHY_DM_DESKEW_CON_DMDESKEW1(x, v) (HW_DDR_PHY_DM_DESKEW_CON_WR(x, (HW_DDR_PHY_DM_DESKEW_CON_RD(x) & ~BM_DDR_PHY_DM_DESKEW_CON_DMDESKEW1) | BF_DDR_PHY_DM_DESKEW_CON_DMDESKEW1(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_DM_DESKEW_CON, field DMDESKEW2[23:16] (RW)
 *
 * Write DM De-Skew Code for Data Slice2.
 */
/*@{*/
#define BP_DDR_PHY_DM_DESKEW_CON_DMDESKEW2 (16U) /*!< Bit position for DDR_PHY_DM_DESKEW_CON_DMDESKEW2. */
#define BM_DDR_PHY_DM_DESKEW_CON_DMDESKEW2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_DM_DESKEW_CON_DMDESKEW2. */
#define BS_DDR_PHY_DM_DESKEW_CON_DMDESKEW2 (8U) /*!< Bit field size in bits for DDR_PHY_DM_DESKEW_CON_DMDESKEW2. */

/*! @brief Read current value of the DDR_PHY_DM_DESKEW_CON_DMDESKEW2 field. */
#define BR_DDR_PHY_DM_DESKEW_CON_DMDESKEW2(x) (HW_DDR_PHY_DM_DESKEW_CON(x).B.DMDESKEW2)

/*! @brief Format value for bitfield DDR_PHY_DM_DESKEW_CON_DMDESKEW2. */
#define BF_DDR_PHY_DM_DESKEW_CON_DMDESKEW2(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_DM_DESKEW_CON_DMDESKEW2) & BM_DDR_PHY_DM_DESKEW_CON_DMDESKEW2)

/*! @brief Set the DMDESKEW2 field to a new value. */
#define BW_DDR_PHY_DM_DESKEW_CON_DMDESKEW2(x, v) (HW_DDR_PHY_DM_DESKEW_CON_WR(x, (HW_DDR_PHY_DM_DESKEW_CON_RD(x) & ~BM_DDR_PHY_DM_DESKEW_CON_DMDESKEW2) | BF_DDR_PHY_DM_DESKEW_CON_DMDESKEW2(v)))
/*@}*/

/*!
 * @name Register DDR_PHY_DM_DESKEW_CON, field DMDESKEW3[31:24] (RW)
 *
 * Write DM De-Skew Code for Data Slice3.
 */
/*@{*/
#define BP_DDR_PHY_DM_DESKEW_CON_DMDESKEW3 (24U) /*!< Bit position for DDR_PHY_DM_DESKEW_CON_DMDESKEW3. */
#define BM_DDR_PHY_DM_DESKEW_CON_DMDESKEW3 (0xFF000000U) /*!< Bit mask for DDR_PHY_DM_DESKEW_CON_DMDESKEW3. */
#define BS_DDR_PHY_DM_DESKEW_CON_DMDESKEW3 (8U) /*!< Bit field size in bits for DDR_PHY_DM_DESKEW_CON_DMDESKEW3. */

/*! @brief Read current value of the DDR_PHY_DM_DESKEW_CON_DMDESKEW3 field. */
#define BR_DDR_PHY_DM_DESKEW_CON_DMDESKEW3(x) (HW_DDR_PHY_DM_DESKEW_CON(x).B.DMDESKEW3)

/*! @brief Format value for bitfield DDR_PHY_DM_DESKEW_CON_DMDESKEW3. */
#define BF_DDR_PHY_DM_DESKEW_CON_DMDESKEW3(v) ((uint32_t)((uint32_t)(v) << BP_DDR_PHY_DM_DESKEW_CON_DMDESKEW3) & BM_DDR_PHY_DM_DESKEW_CON_DMDESKEW3)

/*! @brief Set the DMDESKEW3 field to a new value. */
#define BW_DDR_PHY_DM_DESKEW_CON_DMDESKEW3(x, v) (HW_DDR_PHY_DM_DESKEW_CON_WR(x, (HW_DDR_PHY_DM_DESKEW_CON_RD(x) & ~BM_DDR_PHY_DM_DESKEW_CON_DMDESKEW3) | BF_DDR_PHY_DM_DESKEW_CON_DMDESKEW3(v)))
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_RDATA0 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_RDATA0 -  (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_rdata0
{
    uint32_t U;
    struct _hw_ddr_phy_rdata0_bitfields
    {
        uint32_t DQ_IO_RD0 : 8;        /*!< [7:0]  */
        uint32_t DQ_IO_RD1 : 8;        /*!< [15:8]  */
        uint32_t DQ_IO_RD2 : 8;        /*!< [23:16]  */
        uint32_t DQ_IO_RD3 : 8;        /*!< [31:24]  */
    } B;
} hw_ddr_phy_rdata0_t;

/*!
 * @name Constants and macros for entire DDR_PHY_RDATA0 register
 */
/*@{*/
#define HW_DDR_PHY_RDATA0_ADDR(x) ((uintptr_t)(x) + 0x3A0U)

#define HW_DDR_PHY_RDATA0(x)     (*(__I hw_ddr_phy_rdata0_t *) HW_DDR_PHY_RDATA0_ADDR(x))
#define HW_DDR_PHY_RDATA0_RD(x)  (HW_DDR_PHY_RDATA0(x).U)
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_RDATA0 bitfields
 */

/*!
 * @name Register DDR_PHY_RDATA0, field DQ_IO_RD0[7:0] (RO)
 *
 * DQ I/O Read Data for DS0
 */
/*@{*/
#define BP_DDR_PHY_RDATA0_DQ_IO_RD0 (0U)   /*!< Bit position for DDR_PHY_RDATA0_DQ_IO_RD0. */
#define BM_DDR_PHY_RDATA0_DQ_IO_RD0 (0x000000FFU) /*!< Bit mask for DDR_PHY_RDATA0_DQ_IO_RD0. */
#define BS_DDR_PHY_RDATA0_DQ_IO_RD0 (8U)   /*!< Bit field size in bits for DDR_PHY_RDATA0_DQ_IO_RD0. */

/*! @brief Read current value of the DDR_PHY_RDATA0_DQ_IO_RD0 field. */
#define BR_DDR_PHY_RDATA0_DQ_IO_RD0(x) (HW_DDR_PHY_RDATA0(x).B.DQ_IO_RD0)
/*@}*/

/*!
 * @name Register DDR_PHY_RDATA0, field DQ_IO_RD1[15:8] (RO)
 *
 * DQ I/O Read Data for DS1
 */
/*@{*/
#define BP_DDR_PHY_RDATA0_DQ_IO_RD1 (8U)   /*!< Bit position for DDR_PHY_RDATA0_DQ_IO_RD1. */
#define BM_DDR_PHY_RDATA0_DQ_IO_RD1 (0x0000FF00U) /*!< Bit mask for DDR_PHY_RDATA0_DQ_IO_RD1. */
#define BS_DDR_PHY_RDATA0_DQ_IO_RD1 (8U)   /*!< Bit field size in bits for DDR_PHY_RDATA0_DQ_IO_RD1. */

/*! @brief Read current value of the DDR_PHY_RDATA0_DQ_IO_RD1 field. */
#define BR_DDR_PHY_RDATA0_DQ_IO_RD1(x) (HW_DDR_PHY_RDATA0(x).B.DQ_IO_RD1)
/*@}*/

/*!
 * @name Register DDR_PHY_RDATA0, field DQ_IO_RD2[23:16] (RO)
 *
 * DQ I/O Read Data for DS2
 */
/*@{*/
#define BP_DDR_PHY_RDATA0_DQ_IO_RD2 (16U)  /*!< Bit position for DDR_PHY_RDATA0_DQ_IO_RD2. */
#define BM_DDR_PHY_RDATA0_DQ_IO_RD2 (0x00FF0000U) /*!< Bit mask for DDR_PHY_RDATA0_DQ_IO_RD2. */
#define BS_DDR_PHY_RDATA0_DQ_IO_RD2 (8U)   /*!< Bit field size in bits for DDR_PHY_RDATA0_DQ_IO_RD2. */

/*! @brief Read current value of the DDR_PHY_RDATA0_DQ_IO_RD2 field. */
#define BR_DDR_PHY_RDATA0_DQ_IO_RD2(x) (HW_DDR_PHY_RDATA0(x).B.DQ_IO_RD2)
/*@}*/

/*!
 * @name Register DDR_PHY_RDATA0, field DQ_IO_RD3[31:24] (RO)
 *
 * DQ I/O Read Data for DS3
 */
/*@{*/
#define BP_DDR_PHY_RDATA0_DQ_IO_RD3 (24U)  /*!< Bit position for DDR_PHY_RDATA0_DQ_IO_RD3. */
#define BM_DDR_PHY_RDATA0_DQ_IO_RD3 (0xFF000000U) /*!< Bit mask for DDR_PHY_RDATA0_DQ_IO_RD3. */
#define BS_DDR_PHY_RDATA0_DQ_IO_RD3 (8U)   /*!< Bit field size in bits for DDR_PHY_RDATA0_DQ_IO_RD3. */

/*! @brief Read current value of the DDR_PHY_RDATA0_DQ_IO_RD3 field. */
#define BR_DDR_PHY_RDATA0_DQ_IO_RD3(x) (HW_DDR_PHY_RDATA0(x).B.DQ_IO_RD3)
/*@}*/

/*******************************************************************************
 * HW_DDR_PHY_STAT0 -
 ******************************************************************************/

/*!
 * @brief HW_DDR_PHY_STAT0 -  (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ddr_phy_stat0
{
    uint32_t U;
    struct _hw_ddr_phy_stat0_bitfields
    {
        uint32_t VERSION_INFO : 32;    /*!< [31:0]  */
    } B;
} hw_ddr_phy_stat0_t;

/*!
 * @name Constants and macros for entire DDR_PHY_STAT0 register
 */
/*@{*/
#define HW_DDR_PHY_STAT0_ADDR(x) ((uintptr_t)(x) + 0x3ACU)

#define HW_DDR_PHY_STAT0(x)      (*(__I hw_ddr_phy_stat0_t *) HW_DDR_PHY_STAT0_ADDR(x))
#define HW_DDR_PHY_STAT0_RD(x)   (HW_DDR_PHY_STAT0(x).U)
/*@}*/

/*
 * Constants & macros for individual DDR_PHY_STAT0 bitfields
 */

/*!
 * @name Register DDR_PHY_STAT0, field VERSION_INFO[31:0] (RO)
 *
 * Version Information
 */
/*@{*/
#define BP_DDR_PHY_STAT0_VERSION_INFO (0U) /*!< Bit position for DDR_PHY_STAT0_VERSION_INFO. */
#define BM_DDR_PHY_STAT0_VERSION_INFO (0xFFFFFFFFU) /*!< Bit mask for DDR_PHY_STAT0_VERSION_INFO. */
#define BS_DDR_PHY_STAT0_VERSION_INFO (32U) /*!< Bit field size in bits for DDR_PHY_STAT0_VERSION_INFO. */

/*! @brief Read current value of the DDR_PHY_STAT0_VERSION_INFO field. */
#define BR_DDR_PHY_STAT0_VERSION_INFO(x) (HW_DDR_PHY_STAT0(x).U)
/*@}*/

/*******************************************************************************
 * hw_ddr_phy_t - module struct
 ******************************************************************************/
/*!
 * @brief All DDR_PHY module registers.
 */
#pragma pack(1)
typedef struct _hw_ddr_phy
{
    __IO hw_ddr_phy_phy_con0_t PHY_CON0;   /*!< [0x0]  */
    __IO hw_ddr_phy_phy_con1_t PHY_CON1;   /*!< [0x4]  */
    __IO hw_ddr_phy_phy_con2_t PHY_CON2;   /*!< [0x8]  */
    __IO hw_ddr_phy_phy_con3_t PHY_CON3;   /*!< [0xC]  */
    __IO hw_ddr_phy_phy_con4_t PHY_CON4;   /*!< [0x10]  */
    __IO hw_ddr_phy_phy_con5_t PHY_CON5;   /*!< [0x14]  */
    __IO hw_ddr_phy_lp_con0_t LP_CON0;     /*!< [0x18]  */
    __IO hw_ddr_phy_rodt_con0_t RODT_CON0; /*!< [0x1C]  */
    __IO hw_ddr_phy_offset_rd_con0_t OFFSET_RD_CON0; /*!< [0x20]  */
    uint8_t _reserved0[12];
    __IO hw_ddr_phy_offset_wr_con0_t OFFSET_WR_CON0; /*!< [0x30]  */
    uint8_t _reserved1[12];
    __IO hw_ddr_phy_gate_code_con0_t GATE_CODE_CON0; /*!< [0x40]  */
    uint8_t _reserved2[8];
    __IO hw_ddr_phy_shiftc_con0_t SHIFTC_CON0; /*!< [0x4C]  */
    __IO hw_ddr_phy_cmd_sdll_con0_t CMD_SDLL_CON0; /*!< [0x50]  */
    uint8_t _reserved3[24];
    __IO hw_ddr_phy_lvl_con0_t LVL_CON0;   /*!< [0x6C]  */
    uint8_t _reserved4[8];
    __IO hw_ddr_phy_lvl_con3_t LVL_CON3;   /*!< [0x78]  */
    __IO hw_ddr_phy_cmd_deskew_con0_t CMD_DESKEW_CON0; /*!< [0x7C]  */
    __IO hw_ddr_phy_cmd_deskew_con1_t CMD_DESKEW_CON1; /*!< [0x80]  */
    __IO hw_ddr_phy_cmd_deskew_con2_t CMD_DESKEW_CON2; /*!< [0x84]  */
    __IO hw_ddr_phy_cmd_deskew_con3_t CMD_DESKEW_CON3; /*!< [0x88]  */
    uint8_t _reserved5[8];
    __IO hw_ddr_phy_cmd_deskew_con4_t CMD_DESKEW_CON4; /*!< [0x94]  */
    uint8_t _reserved6[4];
    __IO hw_ddr_phy_drvds_con0_t DRVDS_CON0; /*!< [0x9C]  */
    uint8_t _reserved7[16];
    __IO hw_ddr_phy_mdll_con0_t MDLL_CON0; /*!< [0xB0]  */
    __IO hw_ddr_phy_mdll_con1_t MDLL_CON1; /*!< [0xB4]  */
    uint8_t _reserved8[8];
    __IO hw_ddr_phy_zq_con0_t ZQ_CON0;     /*!< [0xC0]  */
    __IO hw_ddr_phy_zq_con1_t ZQ_CON1;     /*!< [0xC4]  */
    __IO hw_ddr_phy_zq_con2_t ZQ_CON2;     /*!< [0xC8]  */
    uint8_t _reserved9[196];
    __I hw_ddr_phy_rd_deskew_con0_t RD_DESKEW_CON0; /*!< [0x190]  */
    uint8_t _reserved10[8];
    __I hw_ddr_phy_rd_deskew_con3_t RD_DESKEW_CON3; /*!< [0x19C]  */
    uint8_t _reserved11[8];
    __I hw_ddr_phy_rd_deskew_con6_t RD_DESKEW_CON6; /*!< [0x1A8]  */
    uint8_t _reserved12[8];
    __I hw_ddr_phy_rd_deskew_con9_t RD_DESKEW_CON9; /*!< [0x1B4]  */
    uint8_t _reserved13[8];
    __I hw_ddr_phy_rd_deskew_con12_t RD_DESKEW_CON12; /*!< [0x1C0]  */
    uint8_t _reserved14[8];
    __I hw_ddr_phy_rd_deskew_con15_t RD_DESKEW_CON15; /*!< [0x1CC]  */
    uint8_t _reserved15[8];
    __I hw_ddr_phy_rd_deskew_con18_t RD_DESKEW_CON18; /*!< [0x1D8]  */
    uint8_t _reserved16[8];
    __I hw_ddr_phy_rd_deskew_con21_t RD_DESKEW_CON21; /*!< [0x1E4]  */
    uint8_t _reserved17[8];
    __IO hw_ddr_phy_wr_deskew_con0_t WR_DESKEW_CON0; /*!< [0x1F0]  */
    uint8_t _reserved18[8];
    __IO hw_ddr_phy_wr_deskew_con3_t WR_DESKEW_CON3; /*!< [0x1FC]  */
    uint8_t _reserved19[8];
    __IO hw_ddr_phy_wr_deskew_con6_t WR_DESKEW_CON6; /*!< [0x208]  */
    uint8_t _reserved20[8];
    __IO hw_ddr_phy_wr_deskew_con9_t WR_DESKEW_CON9; /*!< [0x214]  */
    uint8_t _reserved21[8];
    __IO hw_ddr_phy_wr_deskew_con12_t WR_DESKEW_CON12; /*!< [0x220]  */
    uint8_t _reserved22[8];
    __IO hw_ddr_phy_wr_deskew_con15_t WR_DESKEW_CON15; /*!< [0x22C]  */
    uint8_t _reserved23[8];
    __IO hw_ddr_phy_wr_deskew_con18_t WR_DESKEW_CON18; /*!< [0x238]  */
    uint8_t _reserved24[8];
    __IO hw_ddr_phy_wr_deskew_con21_t WR_DESKEW_CON21; /*!< [0x244]  */
    uint8_t _reserved25[8];
    __IO hw_ddr_phy_dm_deskew_con_t DM_DESKEW_CON; /*!< [0x250]  */
    uint8_t _reserved26[332];
    __I hw_ddr_phy_rdata0_t RDATA0;        /*!< [0x3A0]  */
    uint8_t _reserved27[8];
    __I hw_ddr_phy_stat0_t STAT0;          /*!< [0x3AC]  */
} hw_ddr_phy_t;
#pragma pack()

/*! @brief Macro to access all DDR_PHY registers. */
/*! @param x DDR_PHY module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_DDR_PHY_REGS(DDR_PHY_BASE)</code>. */
#define HW_DDR_PHY_REGS(x) (*(hw_ddr_phy_t *)(x))

/*
 * iMX7D ECSPI
 *
 * Enhanced Configurable SPI (ECSPI)
 *
 * Registers defined in this header file:
 * - HW_ECSPI_RXDATA - Receive Data Register
 * - HW_ECSPI_TXDATA - Transmit Data Register
 * - HW_ECSPI_CONREG - Control Register
 * - HW_ECSPI_CONFIGREG - Config Register
 * - HW_ECSPI_INTREG - Interrupt Control Register
 * - HW_ECSPI_DMAREG - DMA Control Register
 * - HW_ECSPI_STATREG - Status Register
 * - HW_ECSPI_PERIODREG - Sample Period Control Register
 * - HW_ECSPI_TESTREG - Test Control Register
 * - HW_ECSPI_MSGDATA - Message Data Register
 *
 * - hw_ecspi_t - Struct containing all module registers.
 */

#define HW_ECSPI_INSTANCE_COUNT (4U) /*!< Number of instances of the ECSPI module. */
#define HW_ECSPI1 (1U) /*!< Instance number for ECSPI1. */
#define HW_ECSPI2 (2U) /*!< Instance number for ECSPI2. */
#define HW_ECSPI3 (3U) /*!< Instance number for ECSPI3. */
#define HW_ECSPI4 (4U) /*!< Instance number for ECSPI4. */
#define ECSPI1_BASE           (0x30820000U) /*!< Base address for ECSPI1. */
#define ECSPI2_BASE           (0x30830000U) /*!< Base address for ECSPI2. */
#define ECSPI3_BASE           (0x30840000U) /*!< Base address for ECSPI3. */
#define ECSPI4_BASE           (0x30630000U) /*!< Base address for ECSPI4. */
/*! Array initializer of ECSPI base addresses. */
#define ECSPI_BASE_ADDRS      { ECSPI1_BASE, ECSPI2_BASE, ECSPI3_BASE, ECSPI4_BASE }

/*******************************************************************************
 * HW_ECSPI_RXDATA - Receive Data Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_RXDATA - Receive Data Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The Receive Data register (ECSPI_RXDATA) is a read-only register that forms
 * the top word of the 64 x 32 receive FIFO. This register holds the data received
 * from an external SPI device during a data transaction. Only word-sized read
 * operations are allowed.
 */
typedef union _hw_ecspi_rxdata
{
    uint32_t U;
    struct _hw_ecspi_rxdata_bitfields
    {
        uint32_t ECSPI_RXDATA : 32;    /*!< [31:0]  */
    } B;
} hw_ecspi_rxdata_t;

/*!
 * @name Constants and macros for entire ECSPI_RXDATA register
 */
/*@{*/
#define HW_ECSPI_RXDATA_ADDR(x)  ((uintptr_t)(x) + 0x0U)

#define HW_ECSPI_RXDATA(x)       (*(__I hw_ecspi_rxdata_t *) HW_ECSPI_RXDATA_ADDR(x))
#define HW_ECSPI_RXDATA_RD(x)    (HW_ECSPI_RXDATA(x).U)
/*@}*/

/*
 * Constants & macros for individual ECSPI_RXDATA bitfields
 */

/*!
 * @name Register ECSPI_RXDATA, field ECSPI_RXDATA[31:0] (RO)
 *
 * Receive Data. This register holds the top word of the receive data FIFO. The
 * FIFO is advanced for each read of this register. The data read is undefined
 * when the Receive Data Ready (RR) bit in the Interrupt Control/Status register is
 * cleared. Zeros are read when ECSPI is disabled.
 */
/*@{*/
#define BP_ECSPI_RXDATA_ECSPI_RXDATA (0U)  /*!< Bit position for ECSPI_RXDATA_ECSPI_RXDATA. */
#define BM_ECSPI_RXDATA_ECSPI_RXDATA (0xFFFFFFFFU) /*!< Bit mask for ECSPI_RXDATA_ECSPI_RXDATA. */
#define BS_ECSPI_RXDATA_ECSPI_RXDATA (32U) /*!< Bit field size in bits for ECSPI_RXDATA_ECSPI_RXDATA. */

/*! @brief Read current value of the ECSPI_RXDATA_ECSPI_RXDATA field. */
#define BR_ECSPI_RXDATA_ECSPI_RXDATA(x) (HW_ECSPI_RXDATA(x).U)
/*@}*/

/*******************************************************************************
 * HW_ECSPI_TXDATA - Transmit Data Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_TXDATA - Transmit Data Register (WO)
 *
 * Reset value: 0x00000000U
 *
 * The Transmit Data (ECSPI_TXDATA) register is a write-only data register that
 * forms the bottom word of the 64 x 32 TXFIFO. The TXFIFO can be written to as
 * long as it is not full, even when the SPI Exchange bit (XCH) in ECSPI_CONREG is
 * set. This allows software to write to the TXFIFO during a SPI data exchange
 * process. Writes to this register are ignored when the ECSPI is disabled
 * (ECSPI_CONREG[EN] bit is cleared).
 */
typedef union _hw_ecspi_txdata
{
    uint32_t U;
    struct _hw_ecspi_txdata_bitfields
    {
        uint32_t ECSPI_TXDATA : 32;    /*!< [31:0]  */
    } B;
} hw_ecspi_txdata_t;

/*!
 * @name Constants and macros for entire ECSPI_TXDATA register
 */
/*@{*/
#define HW_ECSPI_TXDATA_ADDR(x)  ((uintptr_t)(x) + 0x4U)

#define HW_ECSPI_TXDATA(x)       (*(__O hw_ecspi_txdata_t *) HW_ECSPI_TXDATA_ADDR(x))
#define HW_ECSPI_TXDATA_WR(x, v) (HW_ECSPI_TXDATA(x).U = (v))
/*@}*/

/*
 * Constants & macros for individual ECSPI_TXDATA bitfields
 */

/*!
 * @name Register ECSPI_TXDATA, field ECSPI_TXDATA[31:0] (WO)
 *
 * Transmit Data. This register holds the top word of data loaded into the FIFO.
 * Data written to this register must be a word operation. The number of bits
 * actually transmitted is determined by the BURST_LENGTH field of the
 * corresponding SPI Control register. If this field contains more bits than the number
 * specified by BURST_LENGTH, the extra bits are ignored. For example, to transfer 10
 * bits of data, a 32-bit word must be written to this register. Bits 9-0 are
 * shifted out and bits 31-10 are ignored. When the ECSPI is operating in Slave
 * mode, zeros are shifted out when the FIFO is empty. Zeros are read when ECSPI is
 * disabled.
 */
/*@{*/
#define BP_ECSPI_TXDATA_ECSPI_TXDATA (0U)  /*!< Bit position for ECSPI_TXDATA_ECSPI_TXDATA. */
#define BM_ECSPI_TXDATA_ECSPI_TXDATA (0xFFFFFFFFU) /*!< Bit mask for ECSPI_TXDATA_ECSPI_TXDATA. */
#define BS_ECSPI_TXDATA_ECSPI_TXDATA (32U) /*!< Bit field size in bits for ECSPI_TXDATA_ECSPI_TXDATA. */

/*! @brief Format value for bitfield ECSPI_TXDATA_ECSPI_TXDATA. */
#define BF_ECSPI_TXDATA_ECSPI_TXDATA(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_TXDATA_ECSPI_TXDATA) & BM_ECSPI_TXDATA_ECSPI_TXDATA)
/*@}*/

/*******************************************************************************
 * HW_ECSPI_CONREG - Control Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_CONREG - Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Control Register (ECSPI_CONREG) allows software to enable the ECSPI ,
 * configure its operating modes, specify the divider value, and SPI_RDY control
 * signal, and define the transfer length.
 */
typedef union _hw_ecspi_conreg
{
    uint32_t U;
    struct _hw_ecspi_conreg_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t HT : 1;               /*!< [1]  */
        uint32_t XCH : 1;              /*!< [2]  */
        uint32_t SMC : 1;              /*!< [3]  */
        uint32_t CHANNEL_MODE : 4;     /*!< [7:4]  */
        uint32_t POST_DIVIDER : 4;     /*!< [11:8]  */
        uint32_t PRE_DIVIDER : 4;      /*!< [15:12]  */
        uint32_t DRCTL : 2;            /*!< [17:16]  */
        uint32_t CHANNEL_SELECT : 2;   /*!< [19:18]  */
        uint32_t BURST_LENGTH : 12;    /*!< [31:20]  */
    } B;
} hw_ecspi_conreg_t;

/*!
 * @name Constants and macros for entire ECSPI_CONREG register
 */
/*@{*/
#define HW_ECSPI_CONREG_ADDR(x)  ((uintptr_t)(x) + 0x8U)

#define HW_ECSPI_CONREG(x)       (*(__IO hw_ecspi_conreg_t *) HW_ECSPI_CONREG_ADDR(x))
#define HW_ECSPI_CONREG_RD(x)    (HW_ECSPI_CONREG(x).U)
#define HW_ECSPI_CONREG_WR(x, v) (HW_ECSPI_CONREG(x).U = (v))
#define HW_ECSPI_CONREG_SET(x, v) (HW_ECSPI_CONREG_WR(x, HW_ECSPI_CONREG_RD(x) |  (v)))
#define HW_ECSPI_CONREG_CLR(x, v) (HW_ECSPI_CONREG_WR(x, HW_ECSPI_CONREG_RD(x) & ~(v)))
#define HW_ECSPI_CONREG_TOG(x, v) (HW_ECSPI_CONREG_WR(x, HW_ECSPI_CONREG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ECSPI_CONREG bitfields
 */

/*!
 * @name Register ECSPI_CONREG, field EN[0] (RW)
 *
 * SPI Block Enable Control. This bit enables the ECSPI. This bit must be set
 * before writing to other registers or initiating an exchange. Writing zero to
 * this bit disables the block and resets the internal logic with the exception of
 * the ECSPI_CONREG. The block's internal clocks are gated off whenever the block
 * is disabled.
 *
 * Values:
 * - 0 - Disable the block.
 * - 1 - Enable the block.
 */
/*@{*/
#define BP_ECSPI_CONREG_EN   (0U)          /*!< Bit position for ECSPI_CONREG_EN. */
#define BM_ECSPI_CONREG_EN   (0x00000001U) /*!< Bit mask for ECSPI_CONREG_EN. */
#define BS_ECSPI_CONREG_EN   (1U)          /*!< Bit field size in bits for ECSPI_CONREG_EN. */

/*! @brief Read current value of the ECSPI_CONREG_EN field. */
#define BR_ECSPI_CONREG_EN(x) (HW_ECSPI_CONREG(x).B.EN)

/*! @brief Format value for bitfield ECSPI_CONREG_EN. */
#define BF_ECSPI_CONREG_EN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_EN) & BM_ECSPI_CONREG_EN)

/*! @brief Set the EN field to a new value. */
#define BW_ECSPI_CONREG_EN(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_EN) | BF_ECSPI_CONREG_EN(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONREG, field HT[1] (RW)
 *
 * Hardware Trigger Enable. This bit is used in master mode only. It enables
 * hardware trigger (HT) mode. Note, HT mode is not supported by this product.
 *
 * Values:
 * - 0 - Disable HT mode.
 * - 1 - Enable HT mode.
 */
/*@{*/
#define BP_ECSPI_CONREG_HT   (1U)          /*!< Bit position for ECSPI_CONREG_HT. */
#define BM_ECSPI_CONREG_HT   (0x00000002U) /*!< Bit mask for ECSPI_CONREG_HT. */
#define BS_ECSPI_CONREG_HT   (1U)          /*!< Bit field size in bits for ECSPI_CONREG_HT. */

/*! @brief Read current value of the ECSPI_CONREG_HT field. */
#define BR_ECSPI_CONREG_HT(x) (HW_ECSPI_CONREG(x).B.HT)

/*! @brief Format value for bitfield ECSPI_CONREG_HT. */
#define BF_ECSPI_CONREG_HT(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_HT) & BM_ECSPI_CONREG_HT)

/*! @brief Set the HT field to a new value. */
#define BW_ECSPI_CONREG_HT(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_HT) | BF_ECSPI_CONREG_HT(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONREG, field XCH[2] (RW)
 *
 * SPI Exchange Bit. This bit applies only to channels configured in Master mode
 * (CHANNEL MODE = 1). If the Start Mode Control (SMC) bit is cleared, writing a
 * 1 to this bit starts one SPI burst or multiple SPI bursts according to the
 * SPI SS Wave Form Select (SS_CTL). The XCH bit remains set while either the data
 * exchange is in progress, or when the ECSPI is waiting for an active input if
 * SPIRDY is enabled through DRCTL. This bit is cleared automatically when all
 * data in the TXFIFO and the shift register has been shifted out.
 *
 * Values:
 * - 0 - Idle.
 * - 1 - Initiates exchange (write) or busy (read).
 */
/*@{*/
#define BP_ECSPI_CONREG_XCH  (2U)          /*!< Bit position for ECSPI_CONREG_XCH. */
#define BM_ECSPI_CONREG_XCH  (0x00000004U) /*!< Bit mask for ECSPI_CONREG_XCH. */
#define BS_ECSPI_CONREG_XCH  (1U)          /*!< Bit field size in bits for ECSPI_CONREG_XCH. */

/*! @brief Read current value of the ECSPI_CONREG_XCH field. */
#define BR_ECSPI_CONREG_XCH(x) (HW_ECSPI_CONREG(x).B.XCH)

/*! @brief Format value for bitfield ECSPI_CONREG_XCH. */
#define BF_ECSPI_CONREG_XCH(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_XCH) & BM_ECSPI_CONREG_XCH)

/*! @brief Set the XCH field to a new value. */
#define BW_ECSPI_CONREG_XCH(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_XCH) | BF_ECSPI_CONREG_XCH(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONREG, field SMC[3] (RW)
 *
 * Start Mode Control. This bit applies only to channels configured in Master
 * mode (CHANNEL MODE = 1). It controls how the ECSPI starts a SPI burst, either
 * through the SPI exchange bit, or immediately when the TXFIFO is written to.
 *
 * Values:
 * - 0 - SPI Exchange Bit (XCH) controls when a SPI burst can start. Setting the
 *     XCH bit will start a SPI burst or multiple bursts. This is controlled by
 *     the SPI SS Wave Form Select (SS_CTL). Refer to XCH and SS_CTL descriptions.
 * - 1 - Immediately starts a SPI burst when data is written in TXFIFO.
 */
/*@{*/
#define BP_ECSPI_CONREG_SMC  (3U)          /*!< Bit position for ECSPI_CONREG_SMC. */
#define BM_ECSPI_CONREG_SMC  (0x00000008U) /*!< Bit mask for ECSPI_CONREG_SMC. */
#define BS_ECSPI_CONREG_SMC  (1U)          /*!< Bit field size in bits for ECSPI_CONREG_SMC. */

/*! @brief Read current value of the ECSPI_CONREG_SMC field. */
#define BR_ECSPI_CONREG_SMC(x) (HW_ECSPI_CONREG(x).B.SMC)

/*! @brief Format value for bitfield ECSPI_CONREG_SMC. */
#define BF_ECSPI_CONREG_SMC(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_SMC) & BM_ECSPI_CONREG_SMC)

/*! @brief Set the SMC field to a new value. */
#define BW_ECSPI_CONREG_SMC(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_SMC) | BF_ECSPI_CONREG_SMC(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONREG, field CHANNEL_MODE[7:4] (RW)
 *
 * SPI CHANNEL MODE selects the mode for each SPI channel. CHANNEL MODE[3] is
 * for SPI channel 3. CHANNEL MODE[2] is for SPI channel 2. CHANNEL MODE[1] is for
 * SPI channel 1. CHANNEL MODE[0] is for SPI channel 0.
 *
 * Values:
 * - 0 - Slave mode.
 * - 1 - Master mode.
 */
/*@{*/
#define BP_ECSPI_CONREG_CHANNEL_MODE (4U)  /*!< Bit position for ECSPI_CONREG_CHANNEL_MODE. */
#define BM_ECSPI_CONREG_CHANNEL_MODE (0x000000F0U) /*!< Bit mask for ECSPI_CONREG_CHANNEL_MODE. */
#define BS_ECSPI_CONREG_CHANNEL_MODE (4U)  /*!< Bit field size in bits for ECSPI_CONREG_CHANNEL_MODE. */

/*! @brief Read current value of the ECSPI_CONREG_CHANNEL_MODE field. */
#define BR_ECSPI_CONREG_CHANNEL_MODE(x) (HW_ECSPI_CONREG(x).B.CHANNEL_MODE)

/*! @brief Format value for bitfield ECSPI_CONREG_CHANNEL_MODE. */
#define BF_ECSPI_CONREG_CHANNEL_MODE(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_CHANNEL_MODE) & BM_ECSPI_CONREG_CHANNEL_MODE)

/*! @brief Set the CHANNEL_MODE field to a new value. */
#define BW_ECSPI_CONREG_CHANNEL_MODE(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_CHANNEL_MODE) | BF_ECSPI_CONREG_CHANNEL_MODE(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONREG, field POST_DIVIDER[11:8] (RW)
 *
 * SPI Post Divider. ECSPI uses a two-stage divider to generate the SPI clock.
 * This field defines the post-divider of the reference clock using the equation:
 * 2 n .
 *
 * Values:
 * - 0000 - Divide by 1.
 * - 0001 - Divide by 2.
 * - 0010 - Divide by 4.
 * - 1110 - Divide by 2 14 .
 * - 1111 - Divide by 2 15 .
 */
/*@{*/
#define BP_ECSPI_CONREG_POST_DIVIDER (8U)  /*!< Bit position for ECSPI_CONREG_POST_DIVIDER. */
#define BM_ECSPI_CONREG_POST_DIVIDER (0x00000F00U) /*!< Bit mask for ECSPI_CONREG_POST_DIVIDER. */
#define BS_ECSPI_CONREG_POST_DIVIDER (4U)  /*!< Bit field size in bits for ECSPI_CONREG_POST_DIVIDER. */

/*! @brief Read current value of the ECSPI_CONREG_POST_DIVIDER field. */
#define BR_ECSPI_CONREG_POST_DIVIDER(x) (HW_ECSPI_CONREG(x).B.POST_DIVIDER)

/*! @brief Format value for bitfield ECSPI_CONREG_POST_DIVIDER. */
#define BF_ECSPI_CONREG_POST_DIVIDER(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_POST_DIVIDER) & BM_ECSPI_CONREG_POST_DIVIDER)

/*! @brief Set the POST_DIVIDER field to a new value. */
#define BW_ECSPI_CONREG_POST_DIVIDER(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_POST_DIVIDER) | BF_ECSPI_CONREG_POST_DIVIDER(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONREG, field PRE_DIVIDER[15:12] (RW)
 *
 * SPI Pre Divider. ECSPI uses a two-stage divider to generate the SPI clock.
 * This field defines the pre-divider of the reference clock.
 *
 * Values:
 * - 0000 - Divide by 1.
 * - 0001 - Divide by 2.
 * - 0010 - Divide by 3.
 * - 1101 - Divide by 14.
 * - 1110 - Divide by 15.
 * - 1111 - Divide by 16.
 */
/*@{*/
#define BP_ECSPI_CONREG_PRE_DIVIDER (12U)  /*!< Bit position for ECSPI_CONREG_PRE_DIVIDER. */
#define BM_ECSPI_CONREG_PRE_DIVIDER (0x0000F000U) /*!< Bit mask for ECSPI_CONREG_PRE_DIVIDER. */
#define BS_ECSPI_CONREG_PRE_DIVIDER (4U)   /*!< Bit field size in bits for ECSPI_CONREG_PRE_DIVIDER. */

/*! @brief Read current value of the ECSPI_CONREG_PRE_DIVIDER field. */
#define BR_ECSPI_CONREG_PRE_DIVIDER(x) (HW_ECSPI_CONREG(x).B.PRE_DIVIDER)

/*! @brief Format value for bitfield ECSPI_CONREG_PRE_DIVIDER. */
#define BF_ECSPI_CONREG_PRE_DIVIDER(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_PRE_DIVIDER) & BM_ECSPI_CONREG_PRE_DIVIDER)

/*! @brief Set the PRE_DIVIDER field to a new value. */
#define BW_ECSPI_CONREG_PRE_DIVIDER(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_PRE_DIVIDER) | BF_ECSPI_CONREG_PRE_DIVIDER(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONREG, field DRCTL[17:16] (RW)
 *
 * SPI Data Ready Control. This field selects the utilization of the SPI_RDY
 * signal in master mode. ECSPI checks this field before it starts an SPI burst.
 *
 * Values:
 * - 00 - The SPI_RDY signal is a don't care.
 * - 01 - Burst will be triggered by the falling edge of the SPI_RDY signal
 *     (edge-triggered).
 * - 10 - Burst will be triggered by a low level of the SPI_RDY signal
 *     (level-triggered).
 * - 11 - Reserved.
 */
/*@{*/
#define BP_ECSPI_CONREG_DRCTL (16U)        /*!< Bit position for ECSPI_CONREG_DRCTL. */
#define BM_ECSPI_CONREG_DRCTL (0x00030000U) /*!< Bit mask for ECSPI_CONREG_DRCTL. */
#define BS_ECSPI_CONREG_DRCTL (2U)         /*!< Bit field size in bits for ECSPI_CONREG_DRCTL. */

/*! @brief Read current value of the ECSPI_CONREG_DRCTL field. */
#define BR_ECSPI_CONREG_DRCTL(x) (HW_ECSPI_CONREG(x).B.DRCTL)

/*! @brief Format value for bitfield ECSPI_CONREG_DRCTL. */
#define BF_ECSPI_CONREG_DRCTL(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_DRCTL) & BM_ECSPI_CONREG_DRCTL)

/*! @brief Set the DRCTL field to a new value. */
#define BW_ECSPI_CONREG_DRCTL(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_DRCTL) | BF_ECSPI_CONREG_DRCTL(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONREG, field CHANNEL_SELECT[19:18] (RW)
 *
 * SPI CHANNEL SELECT bits. Select one of four external SPI Master/Slave
 * Devices. In master mode, these two bits select the external slave devices by
 * asserting the Chip Select (SSn) outputs. Only the selected Chip Select (SSn) signal
 * can be active at a given time; the remaining three signals will be negated.
 *
 * Values:
 * - 00 - Channel 0 is selected. Chip Select 0 (SS0) will be asserted.
 * - 01 - Channel 1 is selected. Chip Select 1 (SS1) will be asserted.
 * - 10 - Channel 2 is selected. Chip Select 2 (SS2) will be asserted.
 * - 11 - Channel 3 is selected. Chip Select 3 (SS3) will be asserted.
 */
/*@{*/
#define BP_ECSPI_CONREG_CHANNEL_SELECT (18U) /*!< Bit position for ECSPI_CONREG_CHANNEL_SELECT. */
#define BM_ECSPI_CONREG_CHANNEL_SELECT (0x000C0000U) /*!< Bit mask for ECSPI_CONREG_CHANNEL_SELECT. */
#define BS_ECSPI_CONREG_CHANNEL_SELECT (2U) /*!< Bit field size in bits for ECSPI_CONREG_CHANNEL_SELECT. */

/*! @brief Read current value of the ECSPI_CONREG_CHANNEL_SELECT field. */
#define BR_ECSPI_CONREG_CHANNEL_SELECT(x) (HW_ECSPI_CONREG(x).B.CHANNEL_SELECT)

/*! @brief Format value for bitfield ECSPI_CONREG_CHANNEL_SELECT. */
#define BF_ECSPI_CONREG_CHANNEL_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_CHANNEL_SELECT) & BM_ECSPI_CONREG_CHANNEL_SELECT)

/*! @brief Set the CHANNEL_SELECT field to a new value. */
#define BW_ECSPI_CONREG_CHANNEL_SELECT(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_CHANNEL_SELECT) | BF_ECSPI_CONREG_CHANNEL_SELECT(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONREG, field BURST_LENGTH[31:20] (RW)
 *
 * Burst Length. This field defines the length of a SPI burst to be transferred.
 * The Chip Select (SS) will remain asserted until all bits in a SPI burst are
 * shifted out. A maximum of 2^12 bits can be transferred in a single SPI burst.
 * In master mode, it controls the number of bits per SPI burst. Since the shift
 * register always loads 32-bit data from transmit FIFO, only the n
 * least-significant (n = BURST LENGTH + 1) will be shifted out. The remaining bits will be
 * ignored. Number of Valid Bits in a SPI burst.
 *
 * Values:
 * - 0 - A SPI burst contains the 1 LSB in a word.
 * - 1 - A SPI burst contains the 2 LSB in a word.
 * - 10 - A SPI burst contains the 3 LSB in a word.
 * - 11111 - A SPI burst contains all 32 bits in a word.
 * - 100000 - A SPI burst contains the 1 LSB in first word and all 32 bits in
 *     second word.
 * - 100001 - A SPI burst contains the 2 LSB in first word and all 32 bits in
 *     second word.
 * - 111111111110 - A SPI burst contains the 31 LSB in first word and 2^7 -1
 *     words.
 * - 111111111111 - A SPI burst contains 2^7 words.
 */
/*@{*/
#define BP_ECSPI_CONREG_BURST_LENGTH (20U) /*!< Bit position for ECSPI_CONREG_BURST_LENGTH. */
#define BM_ECSPI_CONREG_BURST_LENGTH (0xFFF00000U) /*!< Bit mask for ECSPI_CONREG_BURST_LENGTH. */
#define BS_ECSPI_CONREG_BURST_LENGTH (12U) /*!< Bit field size in bits for ECSPI_CONREG_BURST_LENGTH. */

/*! @brief Read current value of the ECSPI_CONREG_BURST_LENGTH field. */
#define BR_ECSPI_CONREG_BURST_LENGTH(x) (HW_ECSPI_CONREG(x).B.BURST_LENGTH)

/*! @brief Format value for bitfield ECSPI_CONREG_BURST_LENGTH. */
#define BF_ECSPI_CONREG_BURST_LENGTH(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONREG_BURST_LENGTH) & BM_ECSPI_CONREG_BURST_LENGTH)

/*! @brief Set the BURST_LENGTH field to a new value. */
#define BW_ECSPI_CONREG_BURST_LENGTH(x, v) (HW_ECSPI_CONREG_WR(x, (HW_ECSPI_CONREG_RD(x) & ~BM_ECSPI_CONREG_BURST_LENGTH) | BF_ECSPI_CONREG_BURST_LENGTH(v)))
/*@}*/

/*******************************************************************************
 * HW_ECSPI_CONFIGREG - Config Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_CONFIGREG - Config Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Config Register (ECSPI_CONFIGREG) allows software to configure each SPI
 * channel, configure its operating modes, specify the phase and polarity of the
 * clock, configure the Chip Select (SS), and define the HT transfer length. Note,
 * HT mode is not supported by this product.
 */
typedef union _hw_ecspi_configreg
{
    uint32_t U;
    struct _hw_ecspi_configreg_bitfields
    {
        uint32_t SCLK_PHA : 4;         /*!< [3:0]  */
        uint32_t SCLK_POL : 4;         /*!< [7:4]  */
        uint32_t SS_CTL : 4;           /*!< [11:8]  */
        uint32_t SS_POL : 4;           /*!< [15:12]  */
        uint32_t DATA_CTL : 4;         /*!< [19:16]  */
        uint32_t SCLK_CTL : 4;         /*!< [23:20]  */
        uint32_t HT_LENGTH : 5;        /*!< [28:24]  */
        uint32_t RESERVED0 : 3;        /*!< [31:29]  */
    } B;
} hw_ecspi_configreg_t;

/*!
 * @name Constants and macros for entire ECSPI_CONFIGREG register
 */
/*@{*/
#define HW_ECSPI_CONFIGREG_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_ECSPI_CONFIGREG(x)    (*(__IO hw_ecspi_configreg_t *) HW_ECSPI_CONFIGREG_ADDR(x))
#define HW_ECSPI_CONFIGREG_RD(x) (HW_ECSPI_CONFIGREG(x).U)
#define HW_ECSPI_CONFIGREG_WR(x, v) (HW_ECSPI_CONFIGREG(x).U = (v))
#define HW_ECSPI_CONFIGREG_SET(x, v) (HW_ECSPI_CONFIGREG_WR(x, HW_ECSPI_CONFIGREG_RD(x) |  (v)))
#define HW_ECSPI_CONFIGREG_CLR(x, v) (HW_ECSPI_CONFIGREG_WR(x, HW_ECSPI_CONFIGREG_RD(x) & ~(v)))
#define HW_ECSPI_CONFIGREG_TOG(x, v) (HW_ECSPI_CONFIGREG_WR(x, HW_ECSPI_CONFIGREG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ECSPI_CONFIGREG bitfields
 */

/*!
 * @name Register ECSPI_CONFIGREG, field SCLK_PHA[3:0] (RW)
 *
 * SPI Clock/Data Phase Control. This field controls the clock/data phase
 * relationship. See for more information. SCLK PHA[3] is for SPI channel 3. SCLK
 * PHA[2] is for SPI channel 2. SCLK PHA[1] is for SPI channel 1. SCLK PHA[0] is for
 * SPI channel 0.
 *
 * Values:
 * - 0 - Phase 0 operation.
 * - 1 - Phase 1 operation.
 */
/*@{*/
#define BP_ECSPI_CONFIGREG_SCLK_PHA (0U)   /*!< Bit position for ECSPI_CONFIGREG_SCLK_PHA. */
#define BM_ECSPI_CONFIGREG_SCLK_PHA (0x0000000FU) /*!< Bit mask for ECSPI_CONFIGREG_SCLK_PHA. */
#define BS_ECSPI_CONFIGREG_SCLK_PHA (4U)   /*!< Bit field size in bits for ECSPI_CONFIGREG_SCLK_PHA. */

/*! @brief Read current value of the ECSPI_CONFIGREG_SCLK_PHA field. */
#define BR_ECSPI_CONFIGREG_SCLK_PHA(x) (HW_ECSPI_CONFIGREG(x).B.SCLK_PHA)

/*! @brief Format value for bitfield ECSPI_CONFIGREG_SCLK_PHA. */
#define BF_ECSPI_CONFIGREG_SCLK_PHA(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONFIGREG_SCLK_PHA) & BM_ECSPI_CONFIGREG_SCLK_PHA)

/*! @brief Set the SCLK_PHA field to a new value. */
#define BW_ECSPI_CONFIGREG_SCLK_PHA(x, v) (HW_ECSPI_CONFIGREG_WR(x, (HW_ECSPI_CONFIGREG_RD(x) & ~BM_ECSPI_CONFIGREG_SCLK_PHA) | BF_ECSPI_CONFIGREG_SCLK_PHA(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONFIGREG, field SCLK_POL[7:4] (RW)
 *
 * SPI Clock Polarity Control. This field controls the polarity of the SCLK
 * signal. See for more information. SCLK_POL[3] is for SPI channel 3. SCLK_POL[2] is
 * for SPI channel 2. SCLK_POL[1] is for SPI channel 1. SCLK_POL[0] is for SPI
 * channel 0.
 *
 * Values:
 * - 0 - Active high polarity (0 = Idle).
 * - 1 - Active low polarity (1 = Idle).
 */
/*@{*/
#define BP_ECSPI_CONFIGREG_SCLK_POL (4U)   /*!< Bit position for ECSPI_CONFIGREG_SCLK_POL. */
#define BM_ECSPI_CONFIGREG_SCLK_POL (0x000000F0U) /*!< Bit mask for ECSPI_CONFIGREG_SCLK_POL. */
#define BS_ECSPI_CONFIGREG_SCLK_POL (4U)   /*!< Bit field size in bits for ECSPI_CONFIGREG_SCLK_POL. */

/*! @brief Read current value of the ECSPI_CONFIGREG_SCLK_POL field. */
#define BR_ECSPI_CONFIGREG_SCLK_POL(x) (HW_ECSPI_CONFIGREG(x).B.SCLK_POL)

/*! @brief Format value for bitfield ECSPI_CONFIGREG_SCLK_POL. */
#define BF_ECSPI_CONFIGREG_SCLK_POL(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONFIGREG_SCLK_POL) & BM_ECSPI_CONFIGREG_SCLK_POL)

/*! @brief Set the SCLK_POL field to a new value. */
#define BW_ECSPI_CONFIGREG_SCLK_POL(x, v) (HW_ECSPI_CONFIGREG_WR(x, (HW_ECSPI_CONFIGREG_RD(x) & ~BM_ECSPI_CONFIGREG_SCLK_POL) | BF_ECSPI_CONFIGREG_SCLK_POL(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONFIGREG, field SS_CTL[11:8] (RW)
 *
 * SPI SS Wave Form Select. In master mode, this field controls the output wave
 * form of the Chip Select (SS) signal when the SMC (Start Mode Control) bit is
 * cleared. The SS_CTL are ignored if the SMC bit is set. SS CTL[3] is for SPI
 * channel 3. SS CTL[2] is for SPI channel 2. SS CTL[1] is for SPI channel 1. SS
 * CTL[0] is for SPI channel 0. In slave mode, this bit controls when the SPI burst
 * is completed. An SPI burst is completed by the Chip Select (SS) signal edges.
 * (SSPOL = 0: rising edge; SSPOL = 1: falling edge) The RXFIFO is advanced
 * whenever a Chip Select (SS) signal edge is detected or the shift register contains
 * 32-bits of valid data.
 *
 * Values:
 * - 0 - In master mode - only one SPI burst will be transmitted.
 * - 1 - In master mode - Negate Chip Select (SS) signal between SPI bursts.
 *     Multiple SPI bursts will be transmitted. The SPI transfer will automatically
 *     stop when the TXFIFO is empty.
 * - 0 - In slave mode - an SPI burst is completed when the number of bits
 *     received in the shift register is equal to (BURST LENGTH + 1). Only the n
 *     least-significant bits (n = BURST LENGTH[4:0] + 1) of the first received word
 *     are valid. All bits subsequent to the first received word in RXFIFO are
 *     valid.
 * - 1 - Reserved
 */
/*@{*/
#define BP_ECSPI_CONFIGREG_SS_CTL (8U)     /*!< Bit position for ECSPI_CONFIGREG_SS_CTL. */
#define BM_ECSPI_CONFIGREG_SS_CTL (0x00000F00U) /*!< Bit mask for ECSPI_CONFIGREG_SS_CTL. */
#define BS_ECSPI_CONFIGREG_SS_CTL (4U)     /*!< Bit field size in bits for ECSPI_CONFIGREG_SS_CTL. */

/*! @brief Read current value of the ECSPI_CONFIGREG_SS_CTL field. */
#define BR_ECSPI_CONFIGREG_SS_CTL(x) (HW_ECSPI_CONFIGREG(x).B.SS_CTL)

/*! @brief Format value for bitfield ECSPI_CONFIGREG_SS_CTL. */
#define BF_ECSPI_CONFIGREG_SS_CTL(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONFIGREG_SS_CTL) & BM_ECSPI_CONFIGREG_SS_CTL)

/*! @brief Set the SS_CTL field to a new value. */
#define BW_ECSPI_CONFIGREG_SS_CTL(x, v) (HW_ECSPI_CONFIGREG_WR(x, (HW_ECSPI_CONFIGREG_RD(x) & ~BM_ECSPI_CONFIGREG_SS_CTL) | BF_ECSPI_CONFIGREG_SS_CTL(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONFIGREG, field SS_POL[15:12] (RW)
 *
 * SPI SS Polarity Select. In both Master and Slave modes, this field selects
 * the polarity of the Chip Select (SS) signal. SS POL[3] is for SPI channel 3. SS
 * POL[2] is for SPI channel 2. SS POL[1] is for SPI channel 1. SS POL[0] is for
 * SPI channel 0.
 *
 * Values:
 * - 0 - Active low.
 * - 1 - Active high.
 */
/*@{*/
#define BP_ECSPI_CONFIGREG_SS_POL (12U)    /*!< Bit position for ECSPI_CONFIGREG_SS_POL. */
#define BM_ECSPI_CONFIGREG_SS_POL (0x0000F000U) /*!< Bit mask for ECSPI_CONFIGREG_SS_POL. */
#define BS_ECSPI_CONFIGREG_SS_POL (4U)     /*!< Bit field size in bits for ECSPI_CONFIGREG_SS_POL. */

/*! @brief Read current value of the ECSPI_CONFIGREG_SS_POL field. */
#define BR_ECSPI_CONFIGREG_SS_POL(x) (HW_ECSPI_CONFIGREG(x).B.SS_POL)

/*! @brief Format value for bitfield ECSPI_CONFIGREG_SS_POL. */
#define BF_ECSPI_CONFIGREG_SS_POL(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONFIGREG_SS_POL) & BM_ECSPI_CONFIGREG_SS_POL)

/*! @brief Set the SS_POL field to a new value. */
#define BW_ECSPI_CONFIGREG_SS_POL(x, v) (HW_ECSPI_CONFIGREG_WR(x, (HW_ECSPI_CONFIGREG_RD(x) & ~BM_ECSPI_CONFIGREG_SS_POL) | BF_ECSPI_CONFIGREG_SS_POL(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONFIGREG, field DATA_CTL[19:16] (RW)
 *
 * DATA CTL. This field controls inactive state of the data line for each SPI
 * channel. DATA CTL[3] is for SPI channel 3. DATA CTL[2] is for SPI channel 2.
 * DATA CTL[1] is for SPI channel 1. DATA CTL[0] is for SPI channel 0.
 *
 * Values:
 * - 0 - Stay high.
 * - 1 - Stay low.
 */
/*@{*/
#define BP_ECSPI_CONFIGREG_DATA_CTL (16U)  /*!< Bit position for ECSPI_CONFIGREG_DATA_CTL. */
#define BM_ECSPI_CONFIGREG_DATA_CTL (0x000F0000U) /*!< Bit mask for ECSPI_CONFIGREG_DATA_CTL. */
#define BS_ECSPI_CONFIGREG_DATA_CTL (4U)   /*!< Bit field size in bits for ECSPI_CONFIGREG_DATA_CTL. */

/*! @brief Read current value of the ECSPI_CONFIGREG_DATA_CTL field. */
#define BR_ECSPI_CONFIGREG_DATA_CTL(x) (HW_ECSPI_CONFIGREG(x).B.DATA_CTL)

/*! @brief Format value for bitfield ECSPI_CONFIGREG_DATA_CTL. */
#define BF_ECSPI_CONFIGREG_DATA_CTL(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONFIGREG_DATA_CTL) & BM_ECSPI_CONFIGREG_DATA_CTL)

/*! @brief Set the DATA_CTL field to a new value. */
#define BW_ECSPI_CONFIGREG_DATA_CTL(x, v) (HW_ECSPI_CONFIGREG_WR(x, (HW_ECSPI_CONFIGREG_RD(x) & ~BM_ECSPI_CONFIGREG_DATA_CTL) | BF_ECSPI_CONFIGREG_DATA_CTL(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONFIGREG, field SCLK_CTL[23:20] (RW)
 *
 * SCLK CTL. This field controls the inactive state of SCLK for each SPI
 * channel. SCLK CTL[3] is for SPI channel 3. SCLK CTL[2] is for SPI channel 2. SCLK
 * CTL[1] is for SPI channel 1. SCLK CTL[0] is for SPI channel 0.
 *
 * Values:
 * - 0 - Stay low.
 * - 1 - Stay high.
 */
/*@{*/
#define BP_ECSPI_CONFIGREG_SCLK_CTL (20U)  /*!< Bit position for ECSPI_CONFIGREG_SCLK_CTL. */
#define BM_ECSPI_CONFIGREG_SCLK_CTL (0x00F00000U) /*!< Bit mask for ECSPI_CONFIGREG_SCLK_CTL. */
#define BS_ECSPI_CONFIGREG_SCLK_CTL (4U)   /*!< Bit field size in bits for ECSPI_CONFIGREG_SCLK_CTL. */

/*! @brief Read current value of the ECSPI_CONFIGREG_SCLK_CTL field. */
#define BR_ECSPI_CONFIGREG_SCLK_CTL(x) (HW_ECSPI_CONFIGREG(x).B.SCLK_CTL)

/*! @brief Format value for bitfield ECSPI_CONFIGREG_SCLK_CTL. */
#define BF_ECSPI_CONFIGREG_SCLK_CTL(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONFIGREG_SCLK_CTL) & BM_ECSPI_CONFIGREG_SCLK_CTL)

/*! @brief Set the SCLK_CTL field to a new value. */
#define BW_ECSPI_CONFIGREG_SCLK_CTL(x, v) (HW_ECSPI_CONFIGREG_WR(x, (HW_ECSPI_CONFIGREG_RD(x) & ~BM_ECSPI_CONFIGREG_SCLK_CTL) | BF_ECSPI_CONFIGREG_SCLK_CTL(v)))
/*@}*/

/*!
 * @name Register ECSPI_CONFIGREG, field HT_LENGTH[28:24] (RW)
 *
 * HT LENGTH. This field defines the message length in HT Mode. Note, HT mode is
 * not supported by this product. The length in bits of one message is (HT
 * LENGTH + 1).
 */
/*@{*/
#define BP_ECSPI_CONFIGREG_HT_LENGTH (24U) /*!< Bit position for ECSPI_CONFIGREG_HT_LENGTH. */
#define BM_ECSPI_CONFIGREG_HT_LENGTH (0x1F000000U) /*!< Bit mask for ECSPI_CONFIGREG_HT_LENGTH. */
#define BS_ECSPI_CONFIGREG_HT_LENGTH (5U)  /*!< Bit field size in bits for ECSPI_CONFIGREG_HT_LENGTH. */

/*! @brief Read current value of the ECSPI_CONFIGREG_HT_LENGTH field. */
#define BR_ECSPI_CONFIGREG_HT_LENGTH(x) (HW_ECSPI_CONFIGREG(x).B.HT_LENGTH)

/*! @brief Format value for bitfield ECSPI_CONFIGREG_HT_LENGTH. */
#define BF_ECSPI_CONFIGREG_HT_LENGTH(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_CONFIGREG_HT_LENGTH) & BM_ECSPI_CONFIGREG_HT_LENGTH)

/*! @brief Set the HT_LENGTH field to a new value. */
#define BW_ECSPI_CONFIGREG_HT_LENGTH(x, v) (HW_ECSPI_CONFIGREG_WR(x, (HW_ECSPI_CONFIGREG_RD(x) & ~BM_ECSPI_CONFIGREG_HT_LENGTH) | BF_ECSPI_CONFIGREG_HT_LENGTH(v)))
/*@}*/

/*******************************************************************************
 * HW_ECSPI_INTREG - Interrupt Control Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_INTREG - Interrupt Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Interrupt Control Register (ECSPI_INTREG) enables the generation of
 * interrupts to the host processor. If the ECSPI is disabled, this register reads
 * zero.
 */
typedef union _hw_ecspi_intreg
{
    uint32_t U;
    struct _hw_ecspi_intreg_bitfields
    {
        uint32_t TEEN : 1;             /*!< [0]  */
        uint32_t TDREN : 1;            /*!< [1]  */
        uint32_t TFEN : 1;             /*!< [2]  */
        uint32_t RREN : 1;             /*!< [3]  */
        uint32_t RDREN : 1;            /*!< [4]  */
        uint32_t RFEN : 1;             /*!< [5]  */
        uint32_t ROEN : 1;             /*!< [6]  */
        uint32_t TCEN : 1;             /*!< [7]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_ecspi_intreg_t;

/*!
 * @name Constants and macros for entire ECSPI_INTREG register
 */
/*@{*/
#define HW_ECSPI_INTREG_ADDR(x)  ((uintptr_t)(x) + 0x10U)

#define HW_ECSPI_INTREG(x)       (*(__IO hw_ecspi_intreg_t *) HW_ECSPI_INTREG_ADDR(x))
#define HW_ECSPI_INTREG_RD(x)    (HW_ECSPI_INTREG(x).U)
#define HW_ECSPI_INTREG_WR(x, v) (HW_ECSPI_INTREG(x).U = (v))
#define HW_ECSPI_INTREG_SET(x, v) (HW_ECSPI_INTREG_WR(x, HW_ECSPI_INTREG_RD(x) |  (v)))
#define HW_ECSPI_INTREG_CLR(x, v) (HW_ECSPI_INTREG_WR(x, HW_ECSPI_INTREG_RD(x) & ~(v)))
#define HW_ECSPI_INTREG_TOG(x, v) (HW_ECSPI_INTREG_WR(x, HW_ECSPI_INTREG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ECSPI_INTREG bitfields
 */

/*!
 * @name Register ECSPI_INTREG, field TEEN[0] (RW)
 *
 * TXFIFO Empty Interrupt enable. This bit enables the TXFIFO Empty Interrupt.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_INTREG_TEEN (0U)          /*!< Bit position for ECSPI_INTREG_TEEN. */
#define BM_ECSPI_INTREG_TEEN (0x00000001U) /*!< Bit mask for ECSPI_INTREG_TEEN. */
#define BS_ECSPI_INTREG_TEEN (1U)          /*!< Bit field size in bits for ECSPI_INTREG_TEEN. */

/*! @brief Read current value of the ECSPI_INTREG_TEEN field. */
#define BR_ECSPI_INTREG_TEEN(x) (HW_ECSPI_INTREG(x).B.TEEN)

/*! @brief Format value for bitfield ECSPI_INTREG_TEEN. */
#define BF_ECSPI_INTREG_TEEN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_INTREG_TEEN) & BM_ECSPI_INTREG_TEEN)

/*! @brief Set the TEEN field to a new value. */
#define BW_ECSPI_INTREG_TEEN(x, v) (HW_ECSPI_INTREG_WR(x, (HW_ECSPI_INTREG_RD(x) & ~BM_ECSPI_INTREG_TEEN) | BF_ECSPI_INTREG_TEEN(v)))
/*@}*/

/*!
 * @name Register ECSPI_INTREG, field TDREN[1] (RW)
 *
 * TXFIFO Data Request Interrupt enable. This bit enables the TXFIFO Data
 * Request Interrupt when the number of data entries in the TXFIFO is less than or
 * equal to TX_THRESHOLD.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_INTREG_TDREN (1U)         /*!< Bit position for ECSPI_INTREG_TDREN. */
#define BM_ECSPI_INTREG_TDREN (0x00000002U) /*!< Bit mask for ECSPI_INTREG_TDREN. */
#define BS_ECSPI_INTREG_TDREN (1U)         /*!< Bit field size in bits for ECSPI_INTREG_TDREN. */

/*! @brief Read current value of the ECSPI_INTREG_TDREN field. */
#define BR_ECSPI_INTREG_TDREN(x) (HW_ECSPI_INTREG(x).B.TDREN)

/*! @brief Format value for bitfield ECSPI_INTREG_TDREN. */
#define BF_ECSPI_INTREG_TDREN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_INTREG_TDREN) & BM_ECSPI_INTREG_TDREN)

/*! @brief Set the TDREN field to a new value. */
#define BW_ECSPI_INTREG_TDREN(x, v) (HW_ECSPI_INTREG_WR(x, (HW_ECSPI_INTREG_RD(x) & ~BM_ECSPI_INTREG_TDREN) | BF_ECSPI_INTREG_TDREN(v)))
/*@}*/

/*!
 * @name Register ECSPI_INTREG, field TFEN[2] (RW)
 *
 * TXFIFO Full Interrupt enable. This bit enables the TXFIFO Full Interrupt.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_INTREG_TFEN (2U)          /*!< Bit position for ECSPI_INTREG_TFEN. */
#define BM_ECSPI_INTREG_TFEN (0x00000004U) /*!< Bit mask for ECSPI_INTREG_TFEN. */
#define BS_ECSPI_INTREG_TFEN (1U)          /*!< Bit field size in bits for ECSPI_INTREG_TFEN. */

/*! @brief Read current value of the ECSPI_INTREG_TFEN field. */
#define BR_ECSPI_INTREG_TFEN(x) (HW_ECSPI_INTREG(x).B.TFEN)

/*! @brief Format value for bitfield ECSPI_INTREG_TFEN. */
#define BF_ECSPI_INTREG_TFEN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_INTREG_TFEN) & BM_ECSPI_INTREG_TFEN)

/*! @brief Set the TFEN field to a new value. */
#define BW_ECSPI_INTREG_TFEN(x, v) (HW_ECSPI_INTREG_WR(x, (HW_ECSPI_INTREG_RD(x) & ~BM_ECSPI_INTREG_TFEN) | BF_ECSPI_INTREG_TFEN(v)))
/*@}*/

/*!
 * @name Register ECSPI_INTREG, field RREN[3] (RW)
 *
 * RXFIFO Ready Interrupt enable. This bit enables the RXFIFO Ready Interrupt.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_INTREG_RREN (3U)          /*!< Bit position for ECSPI_INTREG_RREN. */
#define BM_ECSPI_INTREG_RREN (0x00000008U) /*!< Bit mask for ECSPI_INTREG_RREN. */
#define BS_ECSPI_INTREG_RREN (1U)          /*!< Bit field size in bits for ECSPI_INTREG_RREN. */

/*! @brief Read current value of the ECSPI_INTREG_RREN field. */
#define BR_ECSPI_INTREG_RREN(x) (HW_ECSPI_INTREG(x).B.RREN)

/*! @brief Format value for bitfield ECSPI_INTREG_RREN. */
#define BF_ECSPI_INTREG_RREN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_INTREG_RREN) & BM_ECSPI_INTREG_RREN)

/*! @brief Set the RREN field to a new value. */
#define BW_ECSPI_INTREG_RREN(x, v) (HW_ECSPI_INTREG_WR(x, (HW_ECSPI_INTREG_RD(x) & ~BM_ECSPI_INTREG_RREN) | BF_ECSPI_INTREG_RREN(v)))
/*@}*/

/*!
 * @name Register ECSPI_INTREG, field RDREN[4] (RW)
 *
 * RXFIFO Data Request Interrupt enable. This bit enables the RXFIFO Data
 * Request Interrupt when the number of data entries in the RXFIFO is greater than
 * RX_THRESHOLD.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_INTREG_RDREN (4U)         /*!< Bit position for ECSPI_INTREG_RDREN. */
#define BM_ECSPI_INTREG_RDREN (0x00000010U) /*!< Bit mask for ECSPI_INTREG_RDREN. */
#define BS_ECSPI_INTREG_RDREN (1U)         /*!< Bit field size in bits for ECSPI_INTREG_RDREN. */

/*! @brief Read current value of the ECSPI_INTREG_RDREN field. */
#define BR_ECSPI_INTREG_RDREN(x) (HW_ECSPI_INTREG(x).B.RDREN)

/*! @brief Format value for bitfield ECSPI_INTREG_RDREN. */
#define BF_ECSPI_INTREG_RDREN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_INTREG_RDREN) & BM_ECSPI_INTREG_RDREN)

/*! @brief Set the RDREN field to a new value. */
#define BW_ECSPI_INTREG_RDREN(x, v) (HW_ECSPI_INTREG_WR(x, (HW_ECSPI_INTREG_RD(x) & ~BM_ECSPI_INTREG_RDREN) | BF_ECSPI_INTREG_RDREN(v)))
/*@}*/

/*!
 * @name Register ECSPI_INTREG, field RFEN[5] (RW)
 *
 * RXFIFO Full Interrupt enable. This bit enables the RXFIFO Full Interrupt.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_INTREG_RFEN (5U)          /*!< Bit position for ECSPI_INTREG_RFEN. */
#define BM_ECSPI_INTREG_RFEN (0x00000020U) /*!< Bit mask for ECSPI_INTREG_RFEN. */
#define BS_ECSPI_INTREG_RFEN (1U)          /*!< Bit field size in bits for ECSPI_INTREG_RFEN. */

/*! @brief Read current value of the ECSPI_INTREG_RFEN field. */
#define BR_ECSPI_INTREG_RFEN(x) (HW_ECSPI_INTREG(x).B.RFEN)

/*! @brief Format value for bitfield ECSPI_INTREG_RFEN. */
#define BF_ECSPI_INTREG_RFEN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_INTREG_RFEN) & BM_ECSPI_INTREG_RFEN)

/*! @brief Set the RFEN field to a new value. */
#define BW_ECSPI_INTREG_RFEN(x, v) (HW_ECSPI_INTREG_WR(x, (HW_ECSPI_INTREG_RD(x) & ~BM_ECSPI_INTREG_RFEN) | BF_ECSPI_INTREG_RFEN(v)))
/*@}*/

/*!
 * @name Register ECSPI_INTREG, field ROEN[6] (RW)
 *
 * RXFIFO Overflow Interrupt enable. This bit enables the RXFIFO Overflow
 * Interrupt.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_INTREG_ROEN (6U)          /*!< Bit position for ECSPI_INTREG_ROEN. */
#define BM_ECSPI_INTREG_ROEN (0x00000040U) /*!< Bit mask for ECSPI_INTREG_ROEN. */
#define BS_ECSPI_INTREG_ROEN (1U)          /*!< Bit field size in bits for ECSPI_INTREG_ROEN. */

/*! @brief Read current value of the ECSPI_INTREG_ROEN field. */
#define BR_ECSPI_INTREG_ROEN(x) (HW_ECSPI_INTREG(x).B.ROEN)

/*! @brief Format value for bitfield ECSPI_INTREG_ROEN. */
#define BF_ECSPI_INTREG_ROEN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_INTREG_ROEN) & BM_ECSPI_INTREG_ROEN)

/*! @brief Set the ROEN field to a new value. */
#define BW_ECSPI_INTREG_ROEN(x, v) (HW_ECSPI_INTREG_WR(x, (HW_ECSPI_INTREG_RD(x) & ~BM_ECSPI_INTREG_ROEN) | BF_ECSPI_INTREG_ROEN(v)))
/*@}*/

/*!
 * @name Register ECSPI_INTREG, field TCEN[7] (RW)
 *
 * Transfer Completed Interrupt enable. This bit enables the Transfer Completed
 * Interrupt.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_INTREG_TCEN (7U)          /*!< Bit position for ECSPI_INTREG_TCEN. */
#define BM_ECSPI_INTREG_TCEN (0x00000080U) /*!< Bit mask for ECSPI_INTREG_TCEN. */
#define BS_ECSPI_INTREG_TCEN (1U)          /*!< Bit field size in bits for ECSPI_INTREG_TCEN. */

/*! @brief Read current value of the ECSPI_INTREG_TCEN field. */
#define BR_ECSPI_INTREG_TCEN(x) (HW_ECSPI_INTREG(x).B.TCEN)

/*! @brief Format value for bitfield ECSPI_INTREG_TCEN. */
#define BF_ECSPI_INTREG_TCEN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_INTREG_TCEN) & BM_ECSPI_INTREG_TCEN)

/*! @brief Set the TCEN field to a new value. */
#define BW_ECSPI_INTREG_TCEN(x, v) (HW_ECSPI_INTREG_WR(x, (HW_ECSPI_INTREG_RD(x) & ~BM_ECSPI_INTREG_TCEN) | BF_ECSPI_INTREG_TCEN(v)))
/*@}*/

/*******************************************************************************
 * HW_ECSPI_DMAREG - DMA Control Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_DMAREG - DMA Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Direct Memory Access Control Register (ECSPI_DMAREG) provides software a
 * way to use an on-chip DMA controller for ECSPI data. Internal DMA request
 * signals enable direct data transfers between the ECSPI FIFOs and system memory.
 * The ECSPI sends out DMA requests when the appropriate FIFO conditions are
 * matched. If the ECSPI is disabled, this register is read as 0.
 */
typedef union _hw_ecspi_dmareg
{
    uint32_t U;
    struct _hw_ecspi_dmareg_bitfields
    {
        uint32_t TX_THRESHOLD : 6;     /*!< [5:0]  */
        uint32_t RESERVED0 : 1;        /*!< [6]  */
        uint32_t TEDEN : 1;            /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t RX_THRESHOLD : 6;     /*!< [21:16]  */
        uint32_t RESERVED2 : 1;        /*!< [22]  */
        uint32_t RXDEN : 1;            /*!< [23]  */
        uint32_t RX_DMA_LENGTH : 6;    /*!< [29:24]  */
        uint32_t RESERVED3 : 1;        /*!< [30]  */
        uint32_t RXTDEN : 1;           /*!< [31]  */
    } B;
} hw_ecspi_dmareg_t;

/*!
 * @name Constants and macros for entire ECSPI_DMAREG register
 */
/*@{*/
#define HW_ECSPI_DMAREG_ADDR(x)  ((uintptr_t)(x) + 0x14U)

#define HW_ECSPI_DMAREG(x)       (*(__IO hw_ecspi_dmareg_t *) HW_ECSPI_DMAREG_ADDR(x))
#define HW_ECSPI_DMAREG_RD(x)    (HW_ECSPI_DMAREG(x).U)
#define HW_ECSPI_DMAREG_WR(x, v) (HW_ECSPI_DMAREG(x).U = (v))
#define HW_ECSPI_DMAREG_SET(x, v) (HW_ECSPI_DMAREG_WR(x, HW_ECSPI_DMAREG_RD(x) |  (v)))
#define HW_ECSPI_DMAREG_CLR(x, v) (HW_ECSPI_DMAREG_WR(x, HW_ECSPI_DMAREG_RD(x) & ~(v)))
#define HW_ECSPI_DMAREG_TOG(x, v) (HW_ECSPI_DMAREG_WR(x, HW_ECSPI_DMAREG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ECSPI_DMAREG bitfields
 */

/*!
 * @name Register ECSPI_DMAREG, field TX_THRESHOLD[5:0] (RW)
 *
 * TX THRESHOLD. This field defines the FIFO threshold that triggers a TX
 * DMA/INT request. A TX DMA/INT request is issued when the number of data entries in
 * the TXFIFO is not greater than TX_THRESHOLD.
 */
/*@{*/
#define BP_ECSPI_DMAREG_TX_THRESHOLD (0U)  /*!< Bit position for ECSPI_DMAREG_TX_THRESHOLD. */
#define BM_ECSPI_DMAREG_TX_THRESHOLD (0x0000003FU) /*!< Bit mask for ECSPI_DMAREG_TX_THRESHOLD. */
#define BS_ECSPI_DMAREG_TX_THRESHOLD (6U)  /*!< Bit field size in bits for ECSPI_DMAREG_TX_THRESHOLD. */

/*! @brief Read current value of the ECSPI_DMAREG_TX_THRESHOLD field. */
#define BR_ECSPI_DMAREG_TX_THRESHOLD(x) (HW_ECSPI_DMAREG(x).B.TX_THRESHOLD)

/*! @brief Format value for bitfield ECSPI_DMAREG_TX_THRESHOLD. */
#define BF_ECSPI_DMAREG_TX_THRESHOLD(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_DMAREG_TX_THRESHOLD) & BM_ECSPI_DMAREG_TX_THRESHOLD)

/*! @brief Set the TX_THRESHOLD field to a new value. */
#define BW_ECSPI_DMAREG_TX_THRESHOLD(x, v) (HW_ECSPI_DMAREG_WR(x, (HW_ECSPI_DMAREG_RD(x) & ~BM_ECSPI_DMAREG_TX_THRESHOLD) | BF_ECSPI_DMAREG_TX_THRESHOLD(v)))
/*@}*/

/*!
 * @name Register ECSPI_DMAREG, field TEDEN[7] (RW)
 *
 * TXFIFO Empty DMA Request Enable. This bit enables/disables the TXFIFO Empty
 * DMA Request.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_DMAREG_TEDEN (7U)         /*!< Bit position for ECSPI_DMAREG_TEDEN. */
#define BM_ECSPI_DMAREG_TEDEN (0x00000080U) /*!< Bit mask for ECSPI_DMAREG_TEDEN. */
#define BS_ECSPI_DMAREG_TEDEN (1U)         /*!< Bit field size in bits for ECSPI_DMAREG_TEDEN. */

/*! @brief Read current value of the ECSPI_DMAREG_TEDEN field. */
#define BR_ECSPI_DMAREG_TEDEN(x) (HW_ECSPI_DMAREG(x).B.TEDEN)

/*! @brief Format value for bitfield ECSPI_DMAREG_TEDEN. */
#define BF_ECSPI_DMAREG_TEDEN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_DMAREG_TEDEN) & BM_ECSPI_DMAREG_TEDEN)

/*! @brief Set the TEDEN field to a new value. */
#define BW_ECSPI_DMAREG_TEDEN(x, v) (HW_ECSPI_DMAREG_WR(x, (HW_ECSPI_DMAREG_RD(x) & ~BM_ECSPI_DMAREG_TEDEN) | BF_ECSPI_DMAREG_TEDEN(v)))
/*@}*/

/*!
 * @name Register ECSPI_DMAREG, field RX_THRESHOLD[21:16] (RW)
 *
 * RX THRESHOLD. This field defines the FIFO threshold that triggers a RX
 * DMA/INT request. A RX DMA/INT request is issued when the number of data entries in
 * the RXFIFO is greater than RX_THRESHOLD.
 */
/*@{*/
#define BP_ECSPI_DMAREG_RX_THRESHOLD (16U) /*!< Bit position for ECSPI_DMAREG_RX_THRESHOLD. */
#define BM_ECSPI_DMAREG_RX_THRESHOLD (0x003F0000U) /*!< Bit mask for ECSPI_DMAREG_RX_THRESHOLD. */
#define BS_ECSPI_DMAREG_RX_THRESHOLD (6U)  /*!< Bit field size in bits for ECSPI_DMAREG_RX_THRESHOLD. */

/*! @brief Read current value of the ECSPI_DMAREG_RX_THRESHOLD field. */
#define BR_ECSPI_DMAREG_RX_THRESHOLD(x) (HW_ECSPI_DMAREG(x).B.RX_THRESHOLD)

/*! @brief Format value for bitfield ECSPI_DMAREG_RX_THRESHOLD. */
#define BF_ECSPI_DMAREG_RX_THRESHOLD(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_DMAREG_RX_THRESHOLD) & BM_ECSPI_DMAREG_RX_THRESHOLD)

/*! @brief Set the RX_THRESHOLD field to a new value. */
#define BW_ECSPI_DMAREG_RX_THRESHOLD(x, v) (HW_ECSPI_DMAREG_WR(x, (HW_ECSPI_DMAREG_RD(x) & ~BM_ECSPI_DMAREG_RX_THRESHOLD) | BF_ECSPI_DMAREG_RX_THRESHOLD(v)))
/*@}*/

/*!
 * @name Register ECSPI_DMAREG, field RXDEN[23] (RW)
 *
 * RXFIFO DMA Request Enable. This bit enables/disables the RXFIFO DMA Request.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_DMAREG_RXDEN (23U)        /*!< Bit position for ECSPI_DMAREG_RXDEN. */
#define BM_ECSPI_DMAREG_RXDEN (0x00800000U) /*!< Bit mask for ECSPI_DMAREG_RXDEN. */
#define BS_ECSPI_DMAREG_RXDEN (1U)         /*!< Bit field size in bits for ECSPI_DMAREG_RXDEN. */

/*! @brief Read current value of the ECSPI_DMAREG_RXDEN field. */
#define BR_ECSPI_DMAREG_RXDEN(x) (HW_ECSPI_DMAREG(x).B.RXDEN)

/*! @brief Format value for bitfield ECSPI_DMAREG_RXDEN. */
#define BF_ECSPI_DMAREG_RXDEN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_DMAREG_RXDEN) & BM_ECSPI_DMAREG_RXDEN)

/*! @brief Set the RXDEN field to a new value. */
#define BW_ECSPI_DMAREG_RXDEN(x, v) (HW_ECSPI_DMAREG_WR(x, (HW_ECSPI_DMAREG_RD(x) & ~BM_ECSPI_DMAREG_RXDEN) | BF_ECSPI_DMAREG_RXDEN(v)))
/*@}*/

/*!
 * @name Register ECSPI_DMAREG, field RX_DMA_LENGTH[29:24] (RW)
 *
 * RX DMA LENGTH. This field defines the burst length of a DMA operation.
 * Applies only when RXTDEN is set.
 */
/*@{*/
#define BP_ECSPI_DMAREG_RX_DMA_LENGTH (24U) /*!< Bit position for ECSPI_DMAREG_RX_DMA_LENGTH. */
#define BM_ECSPI_DMAREG_RX_DMA_LENGTH (0x3F000000U) /*!< Bit mask for ECSPI_DMAREG_RX_DMA_LENGTH. */
#define BS_ECSPI_DMAREG_RX_DMA_LENGTH (6U) /*!< Bit field size in bits for ECSPI_DMAREG_RX_DMA_LENGTH. */

/*! @brief Read current value of the ECSPI_DMAREG_RX_DMA_LENGTH field. */
#define BR_ECSPI_DMAREG_RX_DMA_LENGTH(x) (HW_ECSPI_DMAREG(x).B.RX_DMA_LENGTH)

/*! @brief Format value for bitfield ECSPI_DMAREG_RX_DMA_LENGTH. */
#define BF_ECSPI_DMAREG_RX_DMA_LENGTH(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_DMAREG_RX_DMA_LENGTH) & BM_ECSPI_DMAREG_RX_DMA_LENGTH)

/*! @brief Set the RX_DMA_LENGTH field to a new value. */
#define BW_ECSPI_DMAREG_RX_DMA_LENGTH(x, v) (HW_ECSPI_DMAREG_WR(x, (HW_ECSPI_DMAREG_RD(x) & ~BM_ECSPI_DMAREG_RX_DMA_LENGTH) | BF_ECSPI_DMAREG_RX_DMA_LENGTH(v)))
/*@}*/

/*!
 * @name Register ECSPI_DMAREG, field RXTDEN[31] (RW)
 *
 * RXFIFO TAIL DMA Request Enable. This bit enables an internal counter that is
 * increased at each read of the RXFIFO. This counter is cleared automatically
 * when it reaches RX DMA LENGTH. If the number of words remaining in the RXFIFO is
 * greater than or equal to RX DMA LENGTH, a DMA request is generated even if it
 * is less than or equal to RX_THRESHOLD.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ECSPI_DMAREG_RXTDEN (31U)       /*!< Bit position for ECSPI_DMAREG_RXTDEN. */
#define BM_ECSPI_DMAREG_RXTDEN (0x80000000U) /*!< Bit mask for ECSPI_DMAREG_RXTDEN. */
#define BS_ECSPI_DMAREG_RXTDEN (1U)        /*!< Bit field size in bits for ECSPI_DMAREG_RXTDEN. */

/*! @brief Read current value of the ECSPI_DMAREG_RXTDEN field. */
#define BR_ECSPI_DMAREG_RXTDEN(x) (HW_ECSPI_DMAREG(x).B.RXTDEN)

/*! @brief Format value for bitfield ECSPI_DMAREG_RXTDEN. */
#define BF_ECSPI_DMAREG_RXTDEN(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_DMAREG_RXTDEN) & BM_ECSPI_DMAREG_RXTDEN)

/*! @brief Set the RXTDEN field to a new value. */
#define BW_ECSPI_DMAREG_RXTDEN(x, v) (HW_ECSPI_DMAREG_WR(x, (HW_ECSPI_DMAREG_RD(x) & ~BM_ECSPI_DMAREG_RXTDEN) | BF_ECSPI_DMAREG_RXTDEN(v)))
/*@}*/

/*******************************************************************************
 * HW_ECSPI_STATREG - Status Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_STATREG - Status Register (RW)
 *
 * Reset value: 0x00000003U
 *
 * The ECSPI Status Register (ECSPI_STATREG) reflects the status of the ECSPI's
 * operating condition. If the ECSPI is disabled, this register reads 0x0000_0003.
 */
typedef union _hw_ecspi_statreg
{
    uint32_t U;
    struct _hw_ecspi_statreg_bitfields
    {
        uint32_t TE : 1;               /*!< [0]  */
        uint32_t TDR : 1;              /*!< [1]  */
        uint32_t TF : 1;               /*!< [2]  */
        uint32_t RR : 1;               /*!< [3]  */
        uint32_t RDR : 1;              /*!< [4]  */
        uint32_t RF : 1;               /*!< [5]  */
        uint32_t RO : 1;               /*!< [6]  */
        uint32_t TC : 1;               /*!< [7]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_ecspi_statreg_t;

/*!
 * @name Constants and macros for entire ECSPI_STATREG register
 */
/*@{*/
#define HW_ECSPI_STATREG_ADDR(x) ((uintptr_t)(x) + 0x18U)

#define HW_ECSPI_STATREG(x)      (*(__IO hw_ecspi_statreg_t *) HW_ECSPI_STATREG_ADDR(x))
#define HW_ECSPI_STATREG_RD(x)   (HW_ECSPI_STATREG(x).U)
#define HW_ECSPI_STATREG_WR(x, v) (HW_ECSPI_STATREG(x).U = (v))
#define HW_ECSPI_STATREG_SET(x, v) (HW_ECSPI_STATREG_WR(x, HW_ECSPI_STATREG_RD(x) |  (v)))
#define HW_ECSPI_STATREG_CLR(x, v) (HW_ECSPI_STATREG_WR(x, HW_ECSPI_STATREG_RD(x) & ~(v)))
#define HW_ECSPI_STATREG_TOG(x, v) (HW_ECSPI_STATREG_WR(x, HW_ECSPI_STATREG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ECSPI_STATREG bitfields
 */

/*!
 * @name Register ECSPI_STATREG, field TE[0] (RO)
 *
 * TXFIFO Empty. This bit is set if the TXFIFO is empty.
 *
 * Values:
 * - 0 - TXFIFO contains one or more words.
 * - 1 - TXFIFO is empty.
 */
/*@{*/
#define BP_ECSPI_STATREG_TE  (0U)          /*!< Bit position for ECSPI_STATREG_TE. */
#define BM_ECSPI_STATREG_TE  (0x00000001U) /*!< Bit mask for ECSPI_STATREG_TE. */
#define BS_ECSPI_STATREG_TE  (1U)          /*!< Bit field size in bits for ECSPI_STATREG_TE. */

/*! @brief Read current value of the ECSPI_STATREG_TE field. */
#define BR_ECSPI_STATREG_TE(x) (HW_ECSPI_STATREG(x).B.TE)
/*@}*/

/*!
 * @name Register ECSPI_STATREG, field TDR[1] (RO)
 *
 * TXFIFO Data Request.
 *
 * Values:
 * - 0 - Number of valid data slots in TXFIFO is greater than TX_THRESHOLD.
 * - 1 - Number of valid data slots in TXFIFO is not greater than TX_THRESHOLD.
 */
/*@{*/
#define BP_ECSPI_STATREG_TDR (1U)          /*!< Bit position for ECSPI_STATREG_TDR. */
#define BM_ECSPI_STATREG_TDR (0x00000002U) /*!< Bit mask for ECSPI_STATREG_TDR. */
#define BS_ECSPI_STATREG_TDR (1U)          /*!< Bit field size in bits for ECSPI_STATREG_TDR. */

/*! @brief Read current value of the ECSPI_STATREG_TDR field. */
#define BR_ECSPI_STATREG_TDR(x) (HW_ECSPI_STATREG(x).B.TDR)
/*@}*/

/*!
 * @name Register ECSPI_STATREG, field TF[2] (RO)
 *
 * TXFIFO Full. This bit is set when if the TXFIFO is full.
 *
 * Values:
 * - 0 - TXFIFO is not Full.
 * - 1 - TXFIFO is Full.
 */
/*@{*/
#define BP_ECSPI_STATREG_TF  (2U)          /*!< Bit position for ECSPI_STATREG_TF. */
#define BM_ECSPI_STATREG_TF  (0x00000004U) /*!< Bit mask for ECSPI_STATREG_TF. */
#define BS_ECSPI_STATREG_TF  (1U)          /*!< Bit field size in bits for ECSPI_STATREG_TF. */

/*! @brief Read current value of the ECSPI_STATREG_TF field. */
#define BR_ECSPI_STATREG_TF(x) (HW_ECSPI_STATREG(x).B.TF)
/*@}*/

/*!
 * @name Register ECSPI_STATREG, field RR[3] (RO)
 *
 * RXFIFO Ready. This bit is set when one or more words are stored in the RXFIFO.
 *
 * Values:
 * - 0 - No valid data in RXFIFO.
 * - 1 - More than 1 word in RXFIFO.
 */
/*@{*/
#define BP_ECSPI_STATREG_RR  (3U)          /*!< Bit position for ECSPI_STATREG_RR. */
#define BM_ECSPI_STATREG_RR  (0x00000008U) /*!< Bit mask for ECSPI_STATREG_RR. */
#define BS_ECSPI_STATREG_RR  (1U)          /*!< Bit field size in bits for ECSPI_STATREG_RR. */

/*! @brief Read current value of the ECSPI_STATREG_RR field. */
#define BR_ECSPI_STATREG_RR(x) (HW_ECSPI_STATREG(x).B.RR)
/*@}*/

/*!
 * @name Register ECSPI_STATREG, field RDR[4] (RO)
 *
 * RXFIFO Data Request.
 *
 * Values:
 * - 0 - When RXTDE is set - Number of data entries in the RXFIFO is not greater
 *     than RX_THRESHOLD.
 * - 1 - When RXTDE is set - Number of data entries in the RXFIFO is greater
 *     than RX_THRESHOLD or a DMA TAIL DMA condition exists.
 * - 0 - When RXTDE is clear - Number of data entries in the RXFIFO is not
 *     greater than RX_THRESHOLD.
 * - 1 - When RXTDE is clear - Number of data entries in the RXFIFO is greater
 *     than RX_THRESHOLD.
 */
/*@{*/
#define BP_ECSPI_STATREG_RDR (4U)          /*!< Bit position for ECSPI_STATREG_RDR. */
#define BM_ECSPI_STATREG_RDR (0x00000010U) /*!< Bit mask for ECSPI_STATREG_RDR. */
#define BS_ECSPI_STATREG_RDR (1U)          /*!< Bit field size in bits for ECSPI_STATREG_RDR. */

/*! @brief Read current value of the ECSPI_STATREG_RDR field. */
#define BR_ECSPI_STATREG_RDR(x) (HW_ECSPI_STATREG(x).B.RDR)
/*@}*/

/*!
 * @name Register ECSPI_STATREG, field RF[5] (RO)
 *
 * RXFIFO Full. This bit is set when the RXFIFO is full.
 *
 * Values:
 * - 0 - Not Full.
 * - 1 - Full.
 */
/*@{*/
#define BP_ECSPI_STATREG_RF  (5U)          /*!< Bit position for ECSPI_STATREG_RF. */
#define BM_ECSPI_STATREG_RF  (0x00000020U) /*!< Bit mask for ECSPI_STATREG_RF. */
#define BS_ECSPI_STATREG_RF  (1U)          /*!< Bit field size in bits for ECSPI_STATREG_RF. */

/*! @brief Read current value of the ECSPI_STATREG_RF field. */
#define BR_ECSPI_STATREG_RF(x) (HW_ECSPI_STATREG(x).B.RF)
/*@}*/

/*!
 * @name Register ECSPI_STATREG, field RO[6] (W1C)
 *
 * RXFIFO Overflow. When set, this bit indicates that RXFIFO has overflowed.
 * Writing 1 to this bit clears it.
 *
 * Values:
 * - 0 - RXFIFO has no overflow.
 * - 1 - RXFIFO has overflowed.
 */
/*@{*/
#define BP_ECSPI_STATREG_RO  (6U)          /*!< Bit position for ECSPI_STATREG_RO. */
#define BM_ECSPI_STATREG_RO  (0x00000040U) /*!< Bit mask for ECSPI_STATREG_RO. */
#define BS_ECSPI_STATREG_RO  (1U)          /*!< Bit field size in bits for ECSPI_STATREG_RO. */

/*! @brief Read current value of the ECSPI_STATREG_RO field. */
#define BR_ECSPI_STATREG_RO(x) (HW_ECSPI_STATREG(x).B.RO)

/*! @brief Format value for bitfield ECSPI_STATREG_RO. */
#define BF_ECSPI_STATREG_RO(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_STATREG_RO) & BM_ECSPI_STATREG_RO)

/*! @brief Set the RO field to a new value. */
#define BW_ECSPI_STATREG_RO(x, v) (HW_ECSPI_STATREG_WR(x, (HW_ECSPI_STATREG_RD(x) & ~(BM_ECSPI_STATREG_RO | BM_ECSPI_STATREG_TC)) | BF_ECSPI_STATREG_RO(v)))
/*@}*/

/*!
 * @name Register ECSPI_STATREG, field TC[7] (W1C)
 *
 * Transfer Completed Status bit. Writing 1 to this bit clears it.
 *
 * Values:
 * - 0 - Transfer in progress.
 * - 1 - Transfer completed.
 */
/*@{*/
#define BP_ECSPI_STATREG_TC  (7U)          /*!< Bit position for ECSPI_STATREG_TC. */
#define BM_ECSPI_STATREG_TC  (0x00000080U) /*!< Bit mask for ECSPI_STATREG_TC. */
#define BS_ECSPI_STATREG_TC  (1U)          /*!< Bit field size in bits for ECSPI_STATREG_TC. */

/*! @brief Read current value of the ECSPI_STATREG_TC field. */
#define BR_ECSPI_STATREG_TC(x) (HW_ECSPI_STATREG(x).B.TC)

/*! @brief Format value for bitfield ECSPI_STATREG_TC. */
#define BF_ECSPI_STATREG_TC(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_STATREG_TC) & BM_ECSPI_STATREG_TC)

/*! @brief Set the TC field to a new value. */
#define BW_ECSPI_STATREG_TC(x, v) (HW_ECSPI_STATREG_WR(x, (HW_ECSPI_STATREG_RD(x) & ~(BM_ECSPI_STATREG_TC | BM_ECSPI_STATREG_RO)) | BF_ECSPI_STATREG_TC(v)))
/*@}*/

/*******************************************************************************
 * HW_ECSPI_PERIODREG - Sample Period Control Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_PERIODREG - Sample Period Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Sample Period Control Register (ECSPI_PERIODREG) provides software a way
 * to insert delays (wait states) between consecutive SPI transfers. Control bits
 * in this register select the clock source for the sample period counter and
 * the delay count indicating the number of wait states to be inserted between data
 * transfers. The delay counts apply only when the current channel is operating
 * in Master mode (ECSPI_CONREG[CHANNEL MODE] = 1).ECSPI_PERIODREG also contains
 * the CSD CTRL field used to insert a delay between the Chip Select's active
 * edge and the first SPI Clock edge.
 */
typedef union _hw_ecspi_periodreg
{
    uint32_t U;
    struct _hw_ecspi_periodreg_bitfields
    {
        uint32_t SAMPLE_PERIOD : 15;   /*!< [14:0]  */
        uint32_t CSRC : 1;             /*!< [15]  */
        uint32_t CSD_CTL : 6;          /*!< [21:16]  */
        uint32_t RESERVED0 : 10;       /*!< [31:22]  */
    } B;
} hw_ecspi_periodreg_t;

/*!
 * @name Constants and macros for entire ECSPI_PERIODREG register
 */
/*@{*/
#define HW_ECSPI_PERIODREG_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_ECSPI_PERIODREG(x)    (*(__IO hw_ecspi_periodreg_t *) HW_ECSPI_PERIODREG_ADDR(x))
#define HW_ECSPI_PERIODREG_RD(x) (HW_ECSPI_PERIODREG(x).U)
#define HW_ECSPI_PERIODREG_WR(x, v) (HW_ECSPI_PERIODREG(x).U = (v))
#define HW_ECSPI_PERIODREG_SET(x, v) (HW_ECSPI_PERIODREG_WR(x, HW_ECSPI_PERIODREG_RD(x) |  (v)))
#define HW_ECSPI_PERIODREG_CLR(x, v) (HW_ECSPI_PERIODREG_WR(x, HW_ECSPI_PERIODREG_RD(x) & ~(v)))
#define HW_ECSPI_PERIODREG_TOG(x, v) (HW_ECSPI_PERIODREG_WR(x, HW_ECSPI_PERIODREG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ECSPI_PERIODREG bitfields
 */

/*!
 * @name Register ECSPI_PERIODREG, field SAMPLE_PERIOD[14:0] (RW)
 *
 * Sample Period Control. These bits control the number of wait states to be
 * inserted in data transfers. During the idle clocks, the state of the SS output
 * will operate according to the SS_CTL control field in the ECSPI_CONREG register.
 *
 * Values:
 * - 0 - 0 wait states inserted
 * - 1 - 1 wait state inserted
 * - 111111111111110 - 32766 wait states inserted
 * - 111111111111111 - 32767 wait states inserted
 */
/*@{*/
#define BP_ECSPI_PERIODREG_SAMPLE_PERIOD (0U) /*!< Bit position for ECSPI_PERIODREG_SAMPLE_PERIOD. */
#define BM_ECSPI_PERIODREG_SAMPLE_PERIOD (0x00007FFFU) /*!< Bit mask for ECSPI_PERIODREG_SAMPLE_PERIOD. */
#define BS_ECSPI_PERIODREG_SAMPLE_PERIOD (15U) /*!< Bit field size in bits for ECSPI_PERIODREG_SAMPLE_PERIOD. */

/*! @brief Read current value of the ECSPI_PERIODREG_SAMPLE_PERIOD field. */
#define BR_ECSPI_PERIODREG_SAMPLE_PERIOD(x) (HW_ECSPI_PERIODREG(x).B.SAMPLE_PERIOD)

/*! @brief Format value for bitfield ECSPI_PERIODREG_SAMPLE_PERIOD. */
#define BF_ECSPI_PERIODREG_SAMPLE_PERIOD(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_PERIODREG_SAMPLE_PERIOD) & BM_ECSPI_PERIODREG_SAMPLE_PERIOD)

/*! @brief Set the SAMPLE_PERIOD field to a new value. */
#define BW_ECSPI_PERIODREG_SAMPLE_PERIOD(x, v) (HW_ECSPI_PERIODREG_WR(x, (HW_ECSPI_PERIODREG_RD(x) & ~BM_ECSPI_PERIODREG_SAMPLE_PERIOD) | BF_ECSPI_PERIODREG_SAMPLE_PERIOD(v)))
/*@}*/

/*!
 * @name Register ECSPI_PERIODREG, field CSRC[15] (RW)
 *
 * Clock Source Control. This bit selects the clock source for the sample period
 * counter.
 *
 * Values:
 * - 0 - SPI Clock (SCLK)
 * - 1 - Low-Frequency Reference Clock (32.768 KHz)
 */
/*@{*/
#define BP_ECSPI_PERIODREG_CSRC (15U)      /*!< Bit position for ECSPI_PERIODREG_CSRC. */
#define BM_ECSPI_PERIODREG_CSRC (0x00008000U) /*!< Bit mask for ECSPI_PERIODREG_CSRC. */
#define BS_ECSPI_PERIODREG_CSRC (1U)       /*!< Bit field size in bits for ECSPI_PERIODREG_CSRC. */

/*! @brief Read current value of the ECSPI_PERIODREG_CSRC field. */
#define BR_ECSPI_PERIODREG_CSRC(x) (HW_ECSPI_PERIODREG(x).B.CSRC)

/*! @brief Format value for bitfield ECSPI_PERIODREG_CSRC. */
#define BF_ECSPI_PERIODREG_CSRC(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_PERIODREG_CSRC) & BM_ECSPI_PERIODREG_CSRC)

/*! @brief Set the CSRC field to a new value. */
#define BW_ECSPI_PERIODREG_CSRC(x, v) (HW_ECSPI_PERIODREG_WR(x, (HW_ECSPI_PERIODREG_RD(x) & ~BM_ECSPI_PERIODREG_CSRC) | BF_ECSPI_PERIODREG_CSRC(v)))
/*@}*/

/*!
 * @name Register ECSPI_PERIODREG, field CSD_CTL[21:16] (RW)
 *
 * Chip Select Delay Control bits. This field defines how many SPI clocks will
 * be inserted between the chip select's active edge and the first SPI clock edge.
 * The range is from 0 to 63.
 */
/*@{*/
#define BP_ECSPI_PERIODREG_CSD_CTL (16U)   /*!< Bit position for ECSPI_PERIODREG_CSD_CTL. */
#define BM_ECSPI_PERIODREG_CSD_CTL (0x003F0000U) /*!< Bit mask for ECSPI_PERIODREG_CSD_CTL. */
#define BS_ECSPI_PERIODREG_CSD_CTL (6U)    /*!< Bit field size in bits for ECSPI_PERIODREG_CSD_CTL. */

/*! @brief Read current value of the ECSPI_PERIODREG_CSD_CTL field. */
#define BR_ECSPI_PERIODREG_CSD_CTL(x) (HW_ECSPI_PERIODREG(x).B.CSD_CTL)

/*! @brief Format value for bitfield ECSPI_PERIODREG_CSD_CTL. */
#define BF_ECSPI_PERIODREG_CSD_CTL(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_PERIODREG_CSD_CTL) & BM_ECSPI_PERIODREG_CSD_CTL)

/*! @brief Set the CSD_CTL field to a new value. */
#define BW_ECSPI_PERIODREG_CSD_CTL(x, v) (HW_ECSPI_PERIODREG_WR(x, (HW_ECSPI_PERIODREG_RD(x) & ~BM_ECSPI_PERIODREG_CSD_CTL) | BF_ECSPI_PERIODREG_CSD_CTL(v)))
/*@}*/

/*******************************************************************************
 * HW_ECSPI_TESTREG - Test Control Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_TESTREG - Test Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Test Control Register (ECSPI_TESTREG) provides software a mechanism to
 * internally connect the receive and transmit devices of the ECSPI , and monitor
 * the contents of the receive and transmit FIFOs.
 */
typedef union _hw_ecspi_testreg
{
    uint32_t U;
    struct _hw_ecspi_testreg_bitfields
    {
        uint32_t TXCNT : 7;            /*!< [6:0]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t RXCNT : 7;            /*!< [14:8]  */
        uint32_t RESERVED1 : 16;       /*!< [30:15]  */
        uint32_t LBC : 1;              /*!< [31]  */
    } B;
} hw_ecspi_testreg_t;

/*!
 * @name Constants and macros for entire ECSPI_TESTREG register
 */
/*@{*/
#define HW_ECSPI_TESTREG_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_ECSPI_TESTREG(x)      (*(__IO hw_ecspi_testreg_t *) HW_ECSPI_TESTREG_ADDR(x))
#define HW_ECSPI_TESTREG_RD(x)   (HW_ECSPI_TESTREG(x).U)
#define HW_ECSPI_TESTREG_WR(x, v) (HW_ECSPI_TESTREG(x).U = (v))
#define HW_ECSPI_TESTREG_SET(x, v) (HW_ECSPI_TESTREG_WR(x, HW_ECSPI_TESTREG_RD(x) |  (v)))
#define HW_ECSPI_TESTREG_CLR(x, v) (HW_ECSPI_TESTREG_WR(x, HW_ECSPI_TESTREG_RD(x) & ~(v)))
#define HW_ECSPI_TESTREG_TOG(x, v) (HW_ECSPI_TESTREG_WR(x, HW_ECSPI_TESTREG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ECSPI_TESTREG bitfields
 */

/*!
 * @name Register ECSPI_TESTREG, field TXCNT[6:0] (RW)
 *
 * TXFIFO Counter. This field indicates the number of words in the TXFIFO.
 */
/*@{*/
#define BP_ECSPI_TESTREG_TXCNT (0U)        /*!< Bit position for ECSPI_TESTREG_TXCNT. */
#define BM_ECSPI_TESTREG_TXCNT (0x0000007FU) /*!< Bit mask for ECSPI_TESTREG_TXCNT. */
#define BS_ECSPI_TESTREG_TXCNT (7U)        /*!< Bit field size in bits for ECSPI_TESTREG_TXCNT. */

/*! @brief Read current value of the ECSPI_TESTREG_TXCNT field. */
#define BR_ECSPI_TESTREG_TXCNT(x) (HW_ECSPI_TESTREG(x).B.TXCNT)

/*! @brief Format value for bitfield ECSPI_TESTREG_TXCNT. */
#define BF_ECSPI_TESTREG_TXCNT(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_TESTREG_TXCNT) & BM_ECSPI_TESTREG_TXCNT)

/*! @brief Set the TXCNT field to a new value. */
#define BW_ECSPI_TESTREG_TXCNT(x, v) (HW_ECSPI_TESTREG_WR(x, (HW_ECSPI_TESTREG_RD(x) & ~BM_ECSPI_TESTREG_TXCNT) | BF_ECSPI_TESTREG_TXCNT(v)))
/*@}*/

/*!
 * @name Register ECSPI_TESTREG, field RXCNT[14:8] (RW)
 *
 * RXFIFO Counter. This field indicates the number of words in the RXFIFO.
 */
/*@{*/
#define BP_ECSPI_TESTREG_RXCNT (8U)        /*!< Bit position for ECSPI_TESTREG_RXCNT. */
#define BM_ECSPI_TESTREG_RXCNT (0x00007F00U) /*!< Bit mask for ECSPI_TESTREG_RXCNT. */
#define BS_ECSPI_TESTREG_RXCNT (7U)        /*!< Bit field size in bits for ECSPI_TESTREG_RXCNT. */

/*! @brief Read current value of the ECSPI_TESTREG_RXCNT field. */
#define BR_ECSPI_TESTREG_RXCNT(x) (HW_ECSPI_TESTREG(x).B.RXCNT)

/*! @brief Format value for bitfield ECSPI_TESTREG_RXCNT. */
#define BF_ECSPI_TESTREG_RXCNT(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_TESTREG_RXCNT) & BM_ECSPI_TESTREG_RXCNT)

/*! @brief Set the RXCNT field to a new value. */
#define BW_ECSPI_TESTREG_RXCNT(x, v) (HW_ECSPI_TESTREG_WR(x, (HW_ECSPI_TESTREG_RD(x) & ~BM_ECSPI_TESTREG_RXCNT) | BF_ECSPI_TESTREG_RXCNT(v)))
/*@}*/

/*!
 * @name Register ECSPI_TESTREG, field LBC[31] (RW)
 *
 * Loop Back Control. This bit is used in Master mode only. When this bit is
 * set, the ECSPI connects the transmitter and receiver sections internally, and the
 * data shifted out from the most-significant bit of the shift register is
 * looped back into the least-significant bit of the Shift register. In this way, a
 * self-test of the complete transmit/receive path can be made. The output pins are
 * not affected, and the input pins are ignored.
 *
 * Values:
 * - 0 - Not connected.
 * - 1 - Transmitter and receiver sections internally connected for Loopback.
 */
/*@{*/
#define BP_ECSPI_TESTREG_LBC (31U)         /*!< Bit position for ECSPI_TESTREG_LBC. */
#define BM_ECSPI_TESTREG_LBC (0x80000000U) /*!< Bit mask for ECSPI_TESTREG_LBC. */
#define BS_ECSPI_TESTREG_LBC (1U)          /*!< Bit field size in bits for ECSPI_TESTREG_LBC. */

/*! @brief Read current value of the ECSPI_TESTREG_LBC field. */
#define BR_ECSPI_TESTREG_LBC(x) (HW_ECSPI_TESTREG(x).B.LBC)

/*! @brief Format value for bitfield ECSPI_TESTREG_LBC. */
#define BF_ECSPI_TESTREG_LBC(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_TESTREG_LBC) & BM_ECSPI_TESTREG_LBC)

/*! @brief Set the LBC field to a new value. */
#define BW_ECSPI_TESTREG_LBC(x, v) (HW_ECSPI_TESTREG_WR(x, (HW_ECSPI_TESTREG_RD(x) & ~BM_ECSPI_TESTREG_LBC) | BF_ECSPI_TESTREG_LBC(v)))
/*@}*/

/*******************************************************************************
 * HW_ECSPI_MSGDATA - Message Data Register
 ******************************************************************************/

/*!
 * @brief HW_ECSPI_MSGDATA - Message Data Register (WO)
 *
 * Reset value: 0x00000000U
 *
 * The Message Data Register (ECSPI_MSGDATA) forms the top word of the 16 x 32
 * MSG Data FIFO. Only word-size accesses are allowed for this register. Reads to
 * this register return zero, and writes to this register store data in the MSG
 * Data FIFO.
 */
typedef union _hw_ecspi_msgdata
{
    uint32_t U;
    struct _hw_ecspi_msgdata_bitfields
    {
        uint32_t ECSPI_MSGDATA : 32;   /*!< [31:0]  */
    } B;
} hw_ecspi_msgdata_t;

/*!
 * @name Constants and macros for entire ECSPI_MSGDATA register
 */
/*@{*/
#define HW_ECSPI_MSGDATA_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_ECSPI_MSGDATA(x)      (*(__O hw_ecspi_msgdata_t *) HW_ECSPI_MSGDATA_ADDR(x))
#define HW_ECSPI_MSGDATA_WR(x, v) (HW_ECSPI_MSGDATA(x).U = (v))
/*@}*/

/*
 * Constants & macros for individual ECSPI_MSGDATA bitfields
 */

/*!
 * @name Register ECSPI_MSGDATA, field ECSPI_MSGDATA[31:0] (WO)
 *
 * ECSPI_MSGDATA holds the top word of MSG Data FIFO. The MSG Data FIFO is
 * advanced for each write of this register. The data read is zero. The data written
 * to this register is stored in the MSG Data FIFO.
 */
/*@{*/
#define BP_ECSPI_MSGDATA_ECSPI_MSGDATA (0U) /*!< Bit position for ECSPI_MSGDATA_ECSPI_MSGDATA. */
#define BM_ECSPI_MSGDATA_ECSPI_MSGDATA (0xFFFFFFFFU) /*!< Bit mask for ECSPI_MSGDATA_ECSPI_MSGDATA. */
#define BS_ECSPI_MSGDATA_ECSPI_MSGDATA (32U) /*!< Bit field size in bits for ECSPI_MSGDATA_ECSPI_MSGDATA. */

/*! @brief Format value for bitfield ECSPI_MSGDATA_ECSPI_MSGDATA. */
#define BF_ECSPI_MSGDATA_ECSPI_MSGDATA(v) ((uint32_t)((uint32_t)(v) << BP_ECSPI_MSGDATA_ECSPI_MSGDATA) & BM_ECSPI_MSGDATA_ECSPI_MSGDATA)
/*@}*/

/*******************************************************************************
 * hw_ecspi_t - module struct
 ******************************************************************************/
/*!
 * @brief All ECSPI module registers.
 */
#pragma pack(1)
typedef struct _hw_ecspi
{
    __I hw_ecspi_rxdata_t RXDATA;          /*!< [0x0] Receive Data Register */
    __O hw_ecspi_txdata_t TXDATA;          /*!< [0x4] Transmit Data Register */
    __IO hw_ecspi_conreg_t CONREG;         /*!< [0x8] Control Register */
    __IO hw_ecspi_configreg_t CONFIGREG;   /*!< [0xC] Config Register */
    __IO hw_ecspi_intreg_t INTREG;         /*!< [0x10] Interrupt Control Register */
    __IO hw_ecspi_dmareg_t DMAREG;         /*!< [0x14] DMA Control Register */
    __IO hw_ecspi_statreg_t STATREG;       /*!< [0x18] Status Register */
    __IO hw_ecspi_periodreg_t PERIODREG;   /*!< [0x1C] Sample Period Control Register */
    __IO hw_ecspi_testreg_t TESTREG;       /*!< [0x20] Test Control Register */
    uint8_t _reserved0[28];
    __O hw_ecspi_msgdata_t MSGDATA;        /*!< [0x40] Message Data Register */
} hw_ecspi_t;
#pragma pack()

/*! @brief Macro to access all ECSPI registers. */
/*! @param x ECSPI module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_ECSPI_REGS(ECSPI1_BASE)</code>. */
#define HW_ECSPI_REGS(x) (*(hw_ecspi_t *)(x))

/*
 * iMX7D EIM
 *
 * External Interface Module (EIM)
 *
 * Registers defined in this header file:
 * - HW_EIM_CSnGCR1 - Chip Select n General Configuration Register 1
 * - HW_EIM_CSnGCR2 - Chip Select n General Configuration Register 2
 * - HW_EIM_CSnRCR1 - Chip Select n Read Configuration Register 1
 * - HW_EIM_CSnRCR2 - Chip Select n Read Configuration Register 2
 * - HW_EIM_CSnWCR1 - Chip Select n Write Configuration Register 1
 * - HW_EIM_CSnWCR2 - Chip Select n Write Configuration Register 2
 * - HW_EIM_WCR - EIM Configuration Register
 * - HW_EIM_DCR - DLL Control Register
 * - HW_EIM_DSR - DLL Status Register
 * - HW_EIM_WIAR - EIM IP Access Register
 * - HW_EIM_EAR - Error Address Register
 *
 * - hw_eim_t - Struct containing all module registers.
 */

#define HW_EIM_INSTANCE_COUNT (1U) /*!< Number of instances of the EIM module. */
#define HW_EIM (0U) /*!< Instance number for EIM. */
#define EIM_BASE              (0x30BC0000U) /*!< Base address for EIM. */
/*! Array initializer of EIM base addresses. */
#define EIM_BASE_ADDRS        { EIM_BASE }

/*******************************************************************************
 * HW_EIM_CSnGCR1 - Chip Select n General Configuration Register 1
 ******************************************************************************/

/*!
 * @brief HW_EIM_CSnGCR1 - Chip Select n General Configuration Register 1 (RW)
 *
 * Reset value: 0x00010080U
 */
typedef union _hw_eim_csngcr1
{
    uint32_t U;
    struct _hw_eim_csngcr1_bitfields
    {
        uint32_t CSEN : 1;             /*!< [0]  */
        uint32_t SWR : 1;              /*!< [1]  */
        uint32_t SRD : 1;              /*!< [2]  */
        uint32_t MUM : 1;              /*!< [3]  */
        uint32_t WFL : 1;              /*!< [4]  */
        uint32_t RFL : 1;              /*!< [5]  */
        uint32_t CRE : 1;              /*!< [6]  */
        uint32_t CREP : 1;             /*!< [7]  */
        uint32_t BL : 3;               /*!< [10:8]  */
        uint32_t WC : 1;               /*!< [11]  */
        uint32_t BCD : 2;              /*!< [13:12]  */
        uint32_t BCS : 2;              /*!< [15:14]  */
        uint32_t DSZ : 3;              /*!< [18:16]  */
        uint32_t SP : 1;               /*!< [19]  */
        uint32_t CSREC : 3;            /*!< [22:20]  */
        uint32_t AUS : 1;              /*!< [23]  */
        uint32_t GBC : 3;              /*!< [26:24]  */
        uint32_t WP : 1;               /*!< [27]  */
        uint32_t PSZ : 4;              /*!< [31:28]  */
    } B;
} hw_eim_csngcr1_t;

/*!
 * @name Constants and macros for entire EIM_CSnGCR1 register
 */
/*@{*/
#define HW_EIM_CSnGCR1_COUNT (6U)

#define HW_EIM_CSnGCR1_ADDR(x, n) ((uintptr_t)(x) + 0x0U + (0x18U * (n)))

#define HW_EIM_CSnGCR1(x, n)     (*(__IO hw_eim_csngcr1_t *) HW_EIM_CSnGCR1_ADDR(x, n))
#define HW_EIM_CSnGCR1_RD(x, n)  (HW_EIM_CSnGCR1(x, n).U)
#define HW_EIM_CSnGCR1_WR(x, n, v) (HW_EIM_CSnGCR1(x, n).U = (v))
#define HW_EIM_CSnGCR1_SET(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, HW_EIM_CSnGCR1_RD(x, n) |  (v)))
#define HW_EIM_CSnGCR1_CLR(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, HW_EIM_CSnGCR1_RD(x, n) & ~(v)))
#define HW_EIM_CSnGCR1_TOG(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, HW_EIM_CSnGCR1_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_CSnGCR1 bitfields
 */

/*!
 * @name Register EIM_CSnGCR1, field CSEN[0] (RW)
 *
 * CS Enable. This bit controls the operation of the chip select pin. CSEN is
 * set by a hardware reset for CSGCR0 to allow external boot operation. CSEN is
 * cleared by a hardware reset to CSGCR1-CSGCR5. Reset value for EIM_CS0GCR1 for
 * CSEN is 1. For EIM_CS1GCR1-CS1GCR5 reset value is 0.
 *
 * Values:
 * - 0 - Chip select function is disabled; attempts to access an address mapped
 *     by this chip select results in an error respond and no assertion of the
 *     chip select output
 * - 1 - Chip select is enabled, and is asserted when presented with a valid
 *     access.
 */
/*@{*/
#define BP_EIM_CSnGCR1_CSEN  (0U)          /*!< Bit position for EIM_CSnGCR1_CSEN. */
#define BM_EIM_CSnGCR1_CSEN  (0x00000001U) /*!< Bit mask for EIM_CSnGCR1_CSEN. */
#define BS_EIM_CSnGCR1_CSEN  (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_CSEN. */

/*! @brief Read current value of the EIM_CSnGCR1_CSEN field. */
#define BR_EIM_CSnGCR1_CSEN(x, n) (HW_EIM_CSnGCR1(x, n).B.CSEN)

/*! @brief Format value for bitfield EIM_CSnGCR1_CSEN. */
#define BF_EIM_CSnGCR1_CSEN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_CSEN) & BM_EIM_CSnGCR1_CSEN)

/*! @brief Set the CSEN field to a new value. */
#define BW_EIM_CSnGCR1_CSEN(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_CSEN) | BF_EIM_CSnGCR1_CSEN(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field SWR[1] (RW)
 *
 * Synchronous Write Data. This bit field determine the write accesses mode to
 * the External device of the chip select. The External device should be
 * configured to the same mode as this bit implicates. SWR is cleared by a hardware reset.
 * Sync. accesses supported only for 16/32 bit port.
 *
 * Values:
 * - 0 - write accesses are in Asynchronous mode
 * - 1 - write accesses are in Synchronous mode
 */
/*@{*/
#define BP_EIM_CSnGCR1_SWR   (1U)          /*!< Bit position for EIM_CSnGCR1_SWR. */
#define BM_EIM_CSnGCR1_SWR   (0x00000002U) /*!< Bit mask for EIM_CSnGCR1_SWR. */
#define BS_EIM_CSnGCR1_SWR   (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_SWR. */

/*! @brief Read current value of the EIM_CSnGCR1_SWR field. */
#define BR_EIM_CSnGCR1_SWR(x, n) (HW_EIM_CSnGCR1(x, n).B.SWR)

/*! @brief Format value for bitfield EIM_CSnGCR1_SWR. */
#define BF_EIM_CSnGCR1_SWR(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_SWR) & BM_EIM_CSnGCR1_SWR)

/*! @brief Set the SWR field to a new value. */
#define BW_EIM_CSnGCR1_SWR(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_SWR) | BF_EIM_CSnGCR1_SWR(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field SRD[2] (RW)
 *
 * Synchronous Read Data. This bit field determine the read accesses mode to the
 * External device of the chip select. The External device should be configured
 * to the same mode as this bit implicates. SRD is cleared by a hardware reset.
 * Sync. accesses supported only for 16/32 bit port.
 *
 * Values:
 * - 0 - read accesses are in Asynchronous mode
 * - 1 - read accesses are in Synchronous mode
 */
/*@{*/
#define BP_EIM_CSnGCR1_SRD   (2U)          /*!< Bit position for EIM_CSnGCR1_SRD. */
#define BM_EIM_CSnGCR1_SRD   (0x00000004U) /*!< Bit mask for EIM_CSnGCR1_SRD. */
#define BS_EIM_CSnGCR1_SRD   (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_SRD. */

/*! @brief Read current value of the EIM_CSnGCR1_SRD field. */
#define BR_EIM_CSnGCR1_SRD(x, n) (HW_EIM_CSnGCR1(x, n).B.SRD)

/*! @brief Format value for bitfield EIM_CSnGCR1_SRD. */
#define BF_EIM_CSnGCR1_SRD(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_SRD) & BM_EIM_CSnGCR1_SRD)

/*! @brief Set the SRD field to a new value. */
#define BW_EIM_CSnGCR1_SRD(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_SRD) | BF_EIM_CSnGCR1_SRD(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field MUM[3] (RW)
 *
 * Multiplexed Mode. This bit determines the address/data multiplexed mode for
 * asynchronous and synchronous accesses for 8 bit, 16 bit or 32 bit devices (DSZ
 * config. dependent). The reset value for EIM_CS0GCR1[MUM] = EIM_BOOT[2]. For
 * EIM_CS1GCR1 - EIM_CS5GCR1 the reset value is 0.
 *
 * Values:
 * - 0 - Multiplexed Mode disable
 * - 1 - Multiplexed Mode enable
 */
/*@{*/
#define BP_EIM_CSnGCR1_MUM   (3U)          /*!< Bit position for EIM_CSnGCR1_MUM. */
#define BM_EIM_CSnGCR1_MUM   (0x00000008U) /*!< Bit mask for EIM_CSnGCR1_MUM. */
#define BS_EIM_CSnGCR1_MUM   (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_MUM. */

/*! @brief Read current value of the EIM_CSnGCR1_MUM field. */
#define BR_EIM_CSnGCR1_MUM(x, n) (HW_EIM_CSnGCR1(x, n).B.MUM)

/*! @brief Format value for bitfield EIM_CSnGCR1_MUM. */
#define BF_EIM_CSnGCR1_MUM(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_MUM) & BM_EIM_CSnGCR1_MUM)

/*! @brief Set the MUM field to a new value. */
#define BW_EIM_CSnGCR1_MUM(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_MUM) | BF_EIM_CSnGCR1_MUM(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field WFL[4] (RW)
 *
 * Write Fix Latency. This bit field determine if the controller is monitoring
 * the WAIT signal from the External device connected to the chip select
 * (handshake mode - fix or variable data latency) or if it start data transfer according
 * to WWSC field, it only valid in synchronous mode. WFL is cleared by a hardware
 * reset. When WFL=1 Burst access is terminated on page boundary and resume on
 * the following page according to BL bit field configuration, because WAIT signal
 * is not monitored from the external device
 *
 * Values:
 * - 0 - the External device WAIT signal is being monitored, and it reflect the
 *     external data bus state
 * - 1 - the state of the External devices is determined internally (Fix latency
 *     mode only)
 */
/*@{*/
#define BP_EIM_CSnGCR1_WFL   (4U)          /*!< Bit position for EIM_CSnGCR1_WFL. */
#define BM_EIM_CSnGCR1_WFL   (0x00000010U) /*!< Bit mask for EIM_CSnGCR1_WFL. */
#define BS_EIM_CSnGCR1_WFL   (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_WFL. */

/*! @brief Read current value of the EIM_CSnGCR1_WFL field. */
#define BR_EIM_CSnGCR1_WFL(x, n) (HW_EIM_CSnGCR1(x, n).B.WFL)

/*! @brief Format value for bitfield EIM_CSnGCR1_WFL. */
#define BF_EIM_CSnGCR1_WFL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_WFL) & BM_EIM_CSnGCR1_WFL)

/*! @brief Set the WFL field to a new value. */
#define BW_EIM_CSnGCR1_WFL(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_WFL) | BF_EIM_CSnGCR1_WFL(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field RFL[5] (RW)
 *
 * Read Fix Latency. This bit field determine if the controller is monitoring
 * the WAIT signal from the External device connected to the chip select (handshake
 * mode - fix or variable data latency) or if it start sampling data according
 * to RWSC field, it only valid in synchronous mode. RFL is cleared by a hardware
 * reset. When RFL=1 Burst access is terminated on page boundary and resume on
 * the following page according to BL bit field configuration, because WAIT signal
 * is not monitored from the external device.
 *
 * Values:
 * - 0 - the External device WAIT signal is being monitored, and it reflect the
 *     external data bus state
 * - 1 - the state of the External devices is determined internally (Fix latency
 *     mode only)
 */
/*@{*/
#define BP_EIM_CSnGCR1_RFL   (5U)          /*!< Bit position for EIM_CSnGCR1_RFL. */
#define BM_EIM_CSnGCR1_RFL   (0x00000020U) /*!< Bit mask for EIM_CSnGCR1_RFL. */
#define BS_EIM_CSnGCR1_RFL   (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_RFL. */

/*! @brief Read current value of the EIM_CSnGCR1_RFL field. */
#define BR_EIM_CSnGCR1_RFL(x, n) (HW_EIM_CSnGCR1(x, n).B.RFL)

/*! @brief Format value for bitfield EIM_CSnGCR1_RFL. */
#define BF_EIM_CSnGCR1_RFL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_RFL) & BM_EIM_CSnGCR1_RFL)

/*! @brief Set the RFL field to a new value. */
#define BW_EIM_CSnGCR1_RFL(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_RFL) | BF_EIM_CSnGCR1_RFL(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field CRE[6] (RW)
 *
 * Configuration Register Enable. This bit indicates CRE memory pin state while
 * executing a memory register set command to PSRAM external device. CRE is
 * cleared by a hardware reset.
 *
 * Values:
 * - 0 - CRE signal use is disable
 * - 1 - CRE signal use is enable
 */
/*@{*/
#define BP_EIM_CSnGCR1_CRE   (6U)          /*!< Bit position for EIM_CSnGCR1_CRE. */
#define BM_EIM_CSnGCR1_CRE   (0x00000040U) /*!< Bit mask for EIM_CSnGCR1_CRE. */
#define BS_EIM_CSnGCR1_CRE   (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_CRE. */

/*! @brief Read current value of the EIM_CSnGCR1_CRE field. */
#define BR_EIM_CSnGCR1_CRE(x, n) (HW_EIM_CSnGCR1(x, n).B.CRE)

/*! @brief Format value for bitfield EIM_CSnGCR1_CRE. */
#define BF_EIM_CSnGCR1_CRE(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_CRE) & BM_EIM_CSnGCR1_CRE)

/*! @brief Set the CRE field to a new value. */
#define BW_EIM_CSnGCR1_CRE(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_CRE) | BF_EIM_CSnGCR1_CRE(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field CREP[7] (RW)
 *
 * Configuration Register Enable Polarity. This bit indicates CRE memory pin
 * assertion state, active-low or active-high, while executing a memory register set
 * command to the external device (PSRAM memory type). CREP is set by a hardware
 * reset. Whenever PSRAM is connected the CREP value must be correct also for
 * accesses where CRE is disabled. For Non-PSRAM memory CREP value should be 1.
 *
 * Values:
 * - 0 - CRE signal is active low
 * - 1 - CRE signal is active high
 */
/*@{*/
#define BP_EIM_CSnGCR1_CREP  (7U)          /*!< Bit position for EIM_CSnGCR1_CREP. */
#define BM_EIM_CSnGCR1_CREP  (0x00000080U) /*!< Bit mask for EIM_CSnGCR1_CREP. */
#define BS_EIM_CSnGCR1_CREP  (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_CREP. */

/*! @brief Read current value of the EIM_CSnGCR1_CREP field. */
#define BR_EIM_CSnGCR1_CREP(x, n) (HW_EIM_CSnGCR1(x, n).B.CREP)

/*! @brief Format value for bitfield EIM_CSnGCR1_CREP. */
#define BF_EIM_CSnGCR1_CREP(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_CREP) & BM_EIM_CSnGCR1_CREP)

/*! @brief Set the CREP field to a new value. */
#define BW_EIM_CSnGCR1_CREP(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_CREP) | BF_EIM_CSnGCR1_CREP(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field BL[10:8] (RW)
 *
 * Burst Length. The BL bit field indicates memory burst length in words (word
 * is defined by the DSZ field) and should be properly initialized for mixed
 * wrap/increment accesses support. Continuous BL value corresponds to continuous
 * burst length setting of the external memory device. For fix memory burst size,
 * type is always wrap. In case not matching wrap boundaries in both the memory (BL
 * field) and Master access on the current address, EIM update address on the
 * external device address bus and regenerates the access. BL is cleared by a
 * hardware reset. When APR=1, Page Read Mode is applied, BL determine the number of
 * words within the read page burst. BL is cleared by a hardware reset for
 * EIM_CS0GCR1 - EIM_CS5GCR1.
 *
 * Values:
 * - 000 - 4 words Memory wrap burst length (read page burst size when APR = 1)
 * - 001 - 8 words Memory wrap burst length (read page burst size when APR = 1)
 * - 010 - 16 words Memory wrap burst length (read page burst size when APR = 1)
 * - 011 - 32 words Memory wrap burst length (read page burst size when APR = 1)
 * - 100 - Continuous burst length (2 words read page burst size when APR = 1)
 * - 101 - Reserved
 * - 110 - Reserved
 * - 111 - Reserved
 */
/*@{*/
#define BP_EIM_CSnGCR1_BL    (8U)          /*!< Bit position for EIM_CSnGCR1_BL. */
#define BM_EIM_CSnGCR1_BL    (0x00000700U) /*!< Bit mask for EIM_CSnGCR1_BL. */
#define BS_EIM_CSnGCR1_BL    (3U)          /*!< Bit field size in bits for EIM_CSnGCR1_BL. */

/*! @brief Read current value of the EIM_CSnGCR1_BL field. */
#define BR_EIM_CSnGCR1_BL(x, n) (HW_EIM_CSnGCR1(x, n).B.BL)

/*! @brief Format value for bitfield EIM_CSnGCR1_BL. */
#define BF_EIM_CSnGCR1_BL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_BL) & BM_EIM_CSnGCR1_BL)

/*! @brief Set the BL field to a new value. */
#define BW_EIM_CSnGCR1_BL(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_BL) | BF_EIM_CSnGCR1_BL(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field WC[11] (RW)
 *
 * Write Continuous. The WI bit indicates that write access to the memory are
 * always continuous accesses regardless of the BL field value. WI is cleared by
 * hardware reset.
 *
 * Values:
 * - 0 - Write access burst length occurs according to BL value.
 * - 1 - Write access burst length is continuous.
 */
/*@{*/
#define BP_EIM_CSnGCR1_WC    (11U)         /*!< Bit position for EIM_CSnGCR1_WC. */
#define BM_EIM_CSnGCR1_WC    (0x00000800U) /*!< Bit mask for EIM_CSnGCR1_WC. */
#define BS_EIM_CSnGCR1_WC    (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_WC. */

/*! @brief Read current value of the EIM_CSnGCR1_WC field. */
#define BR_EIM_CSnGCR1_WC(x, n) (HW_EIM_CSnGCR1(x, n).B.WC)

/*! @brief Format value for bitfield EIM_CSnGCR1_WC. */
#define BF_EIM_CSnGCR1_WC(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_WC) & BM_EIM_CSnGCR1_WC)

/*! @brief Set the WC field to a new value. */
#define BW_EIM_CSnGCR1_WC(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_WC) | BF_EIM_CSnGCR1_WC(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field BCD[13:12] (RW)
 *
 * Burst Clock Divisor. This bit field contains the value used to program the
 * burst clock divisor for BCLK generation. It is used to divide the internal
 * EIMbus frequency. BCD is cleared by a hardware reset. For other then the mentioned
 * below frequency such as 104 MHz, EIM clock (input clock) should be adjust
 * accordingly.
 *
 * Values:
 * - 00 - Divide EIM clock by 1
 * - 01 - Divide EIM clock by 2
 * - 10 - Divide EIM clock by 3
 * - 11 - Divide EIM clock by 4
 */
/*@{*/
#define BP_EIM_CSnGCR1_BCD   (12U)         /*!< Bit position for EIM_CSnGCR1_BCD. */
#define BM_EIM_CSnGCR1_BCD   (0x00003000U) /*!< Bit mask for EIM_CSnGCR1_BCD. */
#define BS_EIM_CSnGCR1_BCD   (2U)          /*!< Bit field size in bits for EIM_CSnGCR1_BCD. */

/*! @brief Read current value of the EIM_CSnGCR1_BCD field. */
#define BR_EIM_CSnGCR1_BCD(x, n) (HW_EIM_CSnGCR1(x, n).B.BCD)

/*! @brief Format value for bitfield EIM_CSnGCR1_BCD. */
#define BF_EIM_CSnGCR1_BCD(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_BCD) & BM_EIM_CSnGCR1_BCD)

/*! @brief Set the BCD field to a new value. */
#define BW_EIM_CSnGCR1_BCD(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_BCD) | BF_EIM_CSnGCR1_BCD(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field BCS[15:14] (RW)
 *
 * Burst Clock Start. When SRD=1 or SWR=1,this bit field determines the number
 * of EIM clock cycles delay from start of access before the first rising edge of
 * BCLK is generated. When BCD=0 value of BCS=0 results in a half clock delay
 * after the start of access. For other values of BCD a one clock delay after the
 * start of access is applied, not an immediate assertion. BCS is cleared by a
 * hardware reset.
 *
 * Values:
 * - 00 - 0 EIM clock cycle additional delay
 * - 01 - 1 EIM clock cycle additional delay
 * - 10 - 2 EIM clock cycle additional delay
 * - 11 - 3 EIM clock cycle additional delay
 */
/*@{*/
#define BP_EIM_CSnGCR1_BCS   (14U)         /*!< Bit position for EIM_CSnGCR1_BCS. */
#define BM_EIM_CSnGCR1_BCS   (0x0000C000U) /*!< Bit mask for EIM_CSnGCR1_BCS. */
#define BS_EIM_CSnGCR1_BCS   (2U)          /*!< Bit field size in bits for EIM_CSnGCR1_BCS. */

/*! @brief Read current value of the EIM_CSnGCR1_BCS field. */
#define BR_EIM_CSnGCR1_BCS(x, n) (HW_EIM_CSnGCR1(x, n).B.BCS)

/*! @brief Format value for bitfield EIM_CSnGCR1_BCS. */
#define BF_EIM_CSnGCR1_BCS(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_BCS) & BM_EIM_CSnGCR1_BCS)

/*! @brief Set the BCS field to a new value. */
#define BW_EIM_CSnGCR1_BCS(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_BCS) | BF_EIM_CSnGCR1_BCS(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field DSZ[18:16] (RW)
 *
 * Data Port Size. This bit field defines the width of an external device's data
 * port as shown below. Only async. access supported for 8 bit port. The reset
 * value for EIM_CS0GCR1, DSZ[2] = 0, DSZ[1:0] = EIM_BOOT[1:0]. For EIM_CS1GCR1 -
 * EIM_CS5GCR1, the reset value is 0b001.
 *
 * Values:
 * - 000 - Reserved.
 * - 001 - 16 bit port resides on DATA[15:0]
 * - 010 - 16 bit port resides on DATA[31:16]
 * - 011 - 32 bit port resides on DATA[31:0]
 * - 100 - 8 bit port resides on DATA[7:0]
 * - 101 - 8 bit port resides on DATA[15:8]
 * - 110 - 8 bit port resides on DATA[23:16]
 * - 111 - 8 bit port resides on DATA[31:24]
 */
/*@{*/
#define BP_EIM_CSnGCR1_DSZ   (16U)         /*!< Bit position for EIM_CSnGCR1_DSZ. */
#define BM_EIM_CSnGCR1_DSZ   (0x00070000U) /*!< Bit mask for EIM_CSnGCR1_DSZ. */
#define BS_EIM_CSnGCR1_DSZ   (3U)          /*!< Bit field size in bits for EIM_CSnGCR1_DSZ. */

/*! @brief Read current value of the EIM_CSnGCR1_DSZ field. */
#define BR_EIM_CSnGCR1_DSZ(x, n) (HW_EIM_CSnGCR1(x, n).B.DSZ)

/*! @brief Format value for bitfield EIM_CSnGCR1_DSZ. */
#define BF_EIM_CSnGCR1_DSZ(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_DSZ) & BM_EIM_CSnGCR1_DSZ)

/*! @brief Set the DSZ field to a new value. */
#define BW_EIM_CSnGCR1_DSZ(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_DSZ) | BF_EIM_CSnGCR1_DSZ(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field SP[19] (RW)
 *
 * Supervisor Protect. This bit prevents accesses to the address range defined
 * by the corresponding chip select when the access is attempted in the User mode.
 * SP is cleared by a hardware reset.
 *
 * Values:
 * - 0 - User mode accesses are allowed in the memory range defined by chip
 *     select.
 * - 1 - User mode accesses are prohibited. All attempts to access an address
 *     mapped by this chip select in User mode results in an error response and no
 *     assertion of the chip select output.
 */
/*@{*/
#define BP_EIM_CSnGCR1_SP    (19U)         /*!< Bit position for EIM_CSnGCR1_SP. */
#define BM_EIM_CSnGCR1_SP    (0x00080000U) /*!< Bit mask for EIM_CSnGCR1_SP. */
#define BS_EIM_CSnGCR1_SP    (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_SP. */

/*! @brief Read current value of the EIM_CSnGCR1_SP field. */
#define BR_EIM_CSnGCR1_SP(x, n) (HW_EIM_CSnGCR1(x, n).B.SP)

/*! @brief Format value for bitfield EIM_CSnGCR1_SP. */
#define BF_EIM_CSnGCR1_SP(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_SP) & BM_EIM_CSnGCR1_SP)

/*! @brief Set the SP field to a new value. */
#define BW_EIM_CSnGCR1_SP(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_SP) | BF_EIM_CSnGCR1_SP(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field CSREC[22:20] (RW)
 *
 * CS Recovery. This bit field, according to the settings shown below,
 * determines the minimum pulse width of CS, OE, and WE control signals before executing a
 * new back to back access to the same chip select. CSREC is cleared by a
 * hardware reset. The reset value for EIM_CS0GCR1, CSREC[2:0] is 0b110. For
 * EIM_CS1GCR1 - EIM_CS5GCR, the reset value is 0b000. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles minimum width of CS, OE and WE signals (read
 *     async. mode only)
 * - 001 - 1 EIM clock cycles minimum width of CS, OE and WE signals
 * - 010 - 2 EIM clock cycles minimum width of CS, OE and WE signals
 * - 111 - 7 EIM clock cycles minimum width of CS, OE and WE signals
 */
/*@{*/
#define BP_EIM_CSnGCR1_CSREC (20U)         /*!< Bit position for EIM_CSnGCR1_CSREC. */
#define BM_EIM_CSnGCR1_CSREC (0x00700000U) /*!< Bit mask for EIM_CSnGCR1_CSREC. */
#define BS_EIM_CSnGCR1_CSREC (3U)          /*!< Bit field size in bits for EIM_CSnGCR1_CSREC. */

/*! @brief Read current value of the EIM_CSnGCR1_CSREC field. */
#define BR_EIM_CSnGCR1_CSREC(x, n) (HW_EIM_CSnGCR1(x, n).B.CSREC)

/*! @brief Format value for bitfield EIM_CSnGCR1_CSREC. */
#define BF_EIM_CSnGCR1_CSREC(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_CSREC) & BM_EIM_CSnGCR1_CSREC)

/*! @brief Set the CSREC field to a new value. */
#define BW_EIM_CSnGCR1_CSREC(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_CSREC) | BF_EIM_CSnGCR1_CSREC(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field AUS[23] (RW)
 *
 * Address UnShifted. This bit indicates an unshifted mode for address assertion
 * for the relevant chip select accesses. AUS bit is cleared by hardware reset.
 *
 * Values:
 * - 0 - Address shifted according to port size (DSZ config) (128 Mbyte maximum
 *     supported memory density).
 * - 1 - Address unshifted (32 Mbyte maximum supported memory density).
 */
/*@{*/
#define BP_EIM_CSnGCR1_AUS   (23U)         /*!< Bit position for EIM_CSnGCR1_AUS. */
#define BM_EIM_CSnGCR1_AUS   (0x00800000U) /*!< Bit mask for EIM_CSnGCR1_AUS. */
#define BS_EIM_CSnGCR1_AUS   (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_AUS. */

/*! @brief Read current value of the EIM_CSnGCR1_AUS field. */
#define BR_EIM_CSnGCR1_AUS(x, n) (HW_EIM_CSnGCR1(x, n).B.AUS)

/*! @brief Format value for bitfield EIM_CSnGCR1_AUS. */
#define BF_EIM_CSnGCR1_AUS(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_AUS) & BM_EIM_CSnGCR1_AUS)

/*! @brief Set the AUS field to a new value. */
#define BW_EIM_CSnGCR1_AUS(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_AUS) | BF_EIM_CSnGCR1_AUS(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field GBC[26:24] (RW)
 *
 * Gap Between Chip Selects. This bit field, according to the settings shown
 * below, determines the minimum time between end of access to the current chip
 * select and start of access to different chip select. GBC is cleared by a hardware
 * reset. Example settings:
 *
 * Values:
 * - 000 - minimum of 0 EIM clock cycles before next access from different chip
 *     select (async. mode only)
 * - 001 - minimum of 1 EIM clock cycles before next access from different chip
 *     select
 * - 010 - minimum of 2 EIM clock cycles before next access from different chip
 *     select
 * - 111 - minimum of 7 EIM clock cycles before next access from different chip
 *     select
 */
/*@{*/
#define BP_EIM_CSnGCR1_GBC   (24U)         /*!< Bit position for EIM_CSnGCR1_GBC. */
#define BM_EIM_CSnGCR1_GBC   (0x07000000U) /*!< Bit mask for EIM_CSnGCR1_GBC. */
#define BS_EIM_CSnGCR1_GBC   (3U)          /*!< Bit field size in bits for EIM_CSnGCR1_GBC. */

/*! @brief Read current value of the EIM_CSnGCR1_GBC field. */
#define BR_EIM_CSnGCR1_GBC(x, n) (HW_EIM_CSnGCR1(x, n).B.GBC)

/*! @brief Format value for bitfield EIM_CSnGCR1_GBC. */
#define BF_EIM_CSnGCR1_GBC(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_GBC) & BM_EIM_CSnGCR1_GBC)

/*! @brief Set the GBC field to a new value. */
#define BW_EIM_CSnGCR1_GBC(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_GBC) | BF_EIM_CSnGCR1_GBC(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field WP[27] (RW)
 *
 * Write Protect. This bit prevents writes to the address range defined by the
 * corresponding chip select. WP is cleared by a hardware reset.
 *
 * Values:
 * - 0 - Writes are allowed in the memory range defined by chip.
 * - 1 - Writes are prohibited. All attempts to write to an address mapped by
 *     this chip select result in a error response and no assertion of the chip
 *     select output.
 */
/*@{*/
#define BP_EIM_CSnGCR1_WP    (27U)         /*!< Bit position for EIM_CSnGCR1_WP. */
#define BM_EIM_CSnGCR1_WP    (0x08000000U) /*!< Bit mask for EIM_CSnGCR1_WP. */
#define BS_EIM_CSnGCR1_WP    (1U)          /*!< Bit field size in bits for EIM_CSnGCR1_WP. */

/*! @brief Read current value of the EIM_CSnGCR1_WP field. */
#define BR_EIM_CSnGCR1_WP(x, n) (HW_EIM_CSnGCR1(x, n).B.WP)

/*! @brief Format value for bitfield EIM_CSnGCR1_WP. */
#define BF_EIM_CSnGCR1_WP(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_WP) & BM_EIM_CSnGCR1_WP)

/*! @brief Set the WP field to a new value. */
#define BW_EIM_CSnGCR1_WP(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_WP) | BF_EIM_CSnGCR1_WP(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR1, field PSZ[31:28] (RW)
 *
 * Page Size. This bit field indicates memory page size in words (word is
 * defined by the DSZ field). PSZ is used when fix latency mode is applied, WFL=1 for
 * sync. write accesses, RFL=1 for sync. Read accesses. When working in fix
 * latency mode WAIT signal from the external device is not being monitored, PSZ is
 * used to determine if page boundary is reached and renewal of access is preformed.
 * This bit field is ignored when sync. Mode is disabled or fix latency mode is
 * not being used for write or read access separately. It can be valid for both
 * access type, read or write, or only for one type, according to configuration.
 * PSZ is cleared by a hardware reset.
 *
 * Values:
 * - 0000 - 8 words page size
 * - 0001 - 16 words page size
 * - 0010 - 32 words page size
 * - 0011 - 64 words page size
 * - 0100 - 128 words page size
 * - 0101 - 256 words page size
 * - 0110 - 512 words page size
 * - 0111 - 1024 (1k) words page size
 * - 1000 - 2048 (2k) words page size
 * - 1001 - - 1111 Reserved
 */
/*@{*/
#define BP_EIM_CSnGCR1_PSZ   (28U)         /*!< Bit position for EIM_CSnGCR1_PSZ. */
#define BM_EIM_CSnGCR1_PSZ   (0xF0000000U) /*!< Bit mask for EIM_CSnGCR1_PSZ. */
#define BS_EIM_CSnGCR1_PSZ   (4U)          /*!< Bit field size in bits for EIM_CSnGCR1_PSZ. */

/*! @brief Read current value of the EIM_CSnGCR1_PSZ field. */
#define BR_EIM_CSnGCR1_PSZ(x, n) (HW_EIM_CSnGCR1(x, n).B.PSZ)

/*! @brief Format value for bitfield EIM_CSnGCR1_PSZ. */
#define BF_EIM_CSnGCR1_PSZ(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR1_PSZ) & BM_EIM_CSnGCR1_PSZ)

/*! @brief Set the PSZ field to a new value. */
#define BW_EIM_CSnGCR1_PSZ(x, n, v) (HW_EIM_CSnGCR1_WR(x, n, (HW_EIM_CSnGCR1_RD(x, n) & ~BM_EIM_CSnGCR1_PSZ) | BF_EIM_CSnGCR1_PSZ(v)))
/*@}*/
/*******************************************************************************
 * HW_EIM_CSnGCR2 - Chip Select n General Configuration Register 2
 ******************************************************************************/

/*!
 * @brief HW_EIM_CSnGCR2 - Chip Select n General Configuration Register 2 (RW)
 *
 * Reset value: 0x00001000U
 */
typedef union _hw_eim_csngcr2
{
    uint32_t U;
    struct _hw_eim_csngcr2_bitfields
    {
        uint32_t ADH : 2;              /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t DAPS : 4;             /*!< [7:4]  */
        uint32_t DAE : 1;              /*!< [8]  */
        uint32_t DAP : 1;              /*!< [9]  */
        uint32_t RESERVED1 : 2;        /*!< [11:10]  */
        uint32_t MUX16_BYP_GRANT : 1;  /*!< [12]  */
        uint32_t RESERVED2 : 19;       /*!< [31:13]  */
    } B;
} hw_eim_csngcr2_t;

/*!
 * @name Constants and macros for entire EIM_CSnGCR2 register
 */
/*@{*/
#define HW_EIM_CSnGCR2_COUNT (6U)

#define HW_EIM_CSnGCR2_ADDR(x, n) ((uintptr_t)(x) + 0x4U + (0x18U * (n)))

#define HW_EIM_CSnGCR2(x, n)     (*(__IO hw_eim_csngcr2_t *) HW_EIM_CSnGCR2_ADDR(x, n))
#define HW_EIM_CSnGCR2_RD(x, n)  (HW_EIM_CSnGCR2(x, n).U)
#define HW_EIM_CSnGCR2_WR(x, n, v) (HW_EIM_CSnGCR2(x, n).U = (v))
#define HW_EIM_CSnGCR2_SET(x, n, v) (HW_EIM_CSnGCR2_WR(x, n, HW_EIM_CSnGCR2_RD(x, n) |  (v)))
#define HW_EIM_CSnGCR2_CLR(x, n, v) (HW_EIM_CSnGCR2_WR(x, n, HW_EIM_CSnGCR2_RD(x, n) & ~(v)))
#define HW_EIM_CSnGCR2_TOG(x, n, v) (HW_EIM_CSnGCR2_WR(x, n, HW_EIM_CSnGCR2_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_CSnGCR2 bitfields
 */

/*!
 * @name Register EIM_CSnGCR2, field ADH[1:0] (RW)
 *
 * Address hold time - This bit field determine the address hold time after ADV
 * negation when mum = 1 (muxed mode). When mum = 0 this bit has no effect. For
 * read accesses the field determines when the pads direction will be switched.
 * Reset value for EIM_CS0GCR2 for ADH is 10. For EIM_CS1GCR2-EIM_CS5GCR2 reset
 * value is 00.
 *
 * Values:
 * - 00 - 0 cycle after ADV negation
 * - 01 - 1 cycle after ADV negation
 * - 10 - 2 cycle after ADV negation
 * - 11 - Reserved
 */
/*@{*/
#define BP_EIM_CSnGCR2_ADH   (0U)          /*!< Bit position for EIM_CSnGCR2_ADH. */
#define BM_EIM_CSnGCR2_ADH   (0x00000003U) /*!< Bit mask for EIM_CSnGCR2_ADH. */
#define BS_EIM_CSnGCR2_ADH   (2U)          /*!< Bit field size in bits for EIM_CSnGCR2_ADH. */

/*! @brief Read current value of the EIM_CSnGCR2_ADH field. */
#define BR_EIM_CSnGCR2_ADH(x, n) (HW_EIM_CSnGCR2(x, n).B.ADH)

/*! @brief Format value for bitfield EIM_CSnGCR2_ADH. */
#define BF_EIM_CSnGCR2_ADH(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR2_ADH) & BM_EIM_CSnGCR2_ADH)

/*! @brief Set the ADH field to a new value. */
#define BW_EIM_CSnGCR2_ADH(x, n, v) (HW_EIM_CSnGCR2_WR(x, n, (HW_EIM_CSnGCR2_RD(x, n) & ~BM_EIM_CSnGCR2_ADH) | BF_EIM_CSnGCR2_ADH(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR2, field DAPS[7:4] (RW)
 *
 * Data Acknowledge Poling Start. This bit field determine the starting point of
 * DTACK input signal polling. DAPS is used only in asynchronous single read or
 * write accesses. Since DTACK is an async. signal the start point of DTACK
 * signal polling is at least 3 cycles after the start of access. DAPS is cleared by a
 * hardware reset. Example settings:
 *
 * Values:
 * - 0000 - 3 EIM clk cycle between start of access and first DTACK check
 * - 0001 - 4 EIM clk cycles between start of access and first DTACK check
 * - 0010 - 5 EIM clk cycles between start of access and first DTACK check
 * - 0111 - 10 EIM clk cycles between start of access and first DTACK check
 * - 1011 - 14 EIM clk cycles between start of access and first DTACK check
 * - 1111 - 18 EIM clk cycles between start of access and first DTACK check
 */
/*@{*/
#define BP_EIM_CSnGCR2_DAPS  (4U)          /*!< Bit position for EIM_CSnGCR2_DAPS. */
#define BM_EIM_CSnGCR2_DAPS  (0x000000F0U) /*!< Bit mask for EIM_CSnGCR2_DAPS. */
#define BS_EIM_CSnGCR2_DAPS  (4U)          /*!< Bit field size in bits for EIM_CSnGCR2_DAPS. */

/*! @brief Read current value of the EIM_CSnGCR2_DAPS field. */
#define BR_EIM_CSnGCR2_DAPS(x, n) (HW_EIM_CSnGCR2(x, n).B.DAPS)

/*! @brief Format value for bitfield EIM_CSnGCR2_DAPS. */
#define BF_EIM_CSnGCR2_DAPS(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR2_DAPS) & BM_EIM_CSnGCR2_DAPS)

/*! @brief Set the DAPS field to a new value. */
#define BW_EIM_CSnGCR2_DAPS(x, n, v) (HW_EIM_CSnGCR2_WR(x, n, (HW_EIM_CSnGCR2_RD(x, n) & ~BM_EIM_CSnGCR2_DAPS) | BF_EIM_CSnGCR2_DAPS(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR2, field DAE[8] (RW)
 *
 * Data Acknowledge Enable. This bit indicates external device is using DTACK
 * pin as strobe/terminator of an async. access. DTACK signal may be used only in
 * asynchronous single read (APR=0) or write accesses. DTACK poling start point is
 * set by DAPS bit field. polarity of DTACK is set by DAP bit field. DAE is
 * cleared by a hardware reset.
 *
 * Values:
 * - 0 - DTACK signal use is disable
 * - 1 - DTACK signal use is enable
 */
/*@{*/
#define BP_EIM_CSnGCR2_DAE   (8U)          /*!< Bit position for EIM_CSnGCR2_DAE. */
#define BM_EIM_CSnGCR2_DAE   (0x00000100U) /*!< Bit mask for EIM_CSnGCR2_DAE. */
#define BS_EIM_CSnGCR2_DAE   (1U)          /*!< Bit field size in bits for EIM_CSnGCR2_DAE. */

/*! @brief Read current value of the EIM_CSnGCR2_DAE field. */
#define BR_EIM_CSnGCR2_DAE(x, n) (HW_EIM_CSnGCR2(x, n).B.DAE)

/*! @brief Format value for bitfield EIM_CSnGCR2_DAE. */
#define BF_EIM_CSnGCR2_DAE(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR2_DAE) & BM_EIM_CSnGCR2_DAE)

/*! @brief Set the DAE field to a new value. */
#define BW_EIM_CSnGCR2_DAE(x, n, v) (HW_EIM_CSnGCR2_WR(x, n, (HW_EIM_CSnGCR2_RD(x, n) & ~BM_EIM_CSnGCR2_DAE) | BF_EIM_CSnGCR2_DAE(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR2, field DAP[9] (RW)
 *
 * Data Acknowledge Polarity. This bit indicates DTACK memory pin assertion
 * state, active-low or active-high, while executing an async access using DTACK
 * signal from the external device. DAP is cleared by a hardware reset.
 *
 * Values:
 * - 0 - DTACK signal is active high
 * - 1 - DTACK signal is active low
 */
/*@{*/
#define BP_EIM_CSnGCR2_DAP   (9U)          /*!< Bit position for EIM_CSnGCR2_DAP. */
#define BM_EIM_CSnGCR2_DAP   (0x00000200U) /*!< Bit mask for EIM_CSnGCR2_DAP. */
#define BS_EIM_CSnGCR2_DAP   (1U)          /*!< Bit field size in bits for EIM_CSnGCR2_DAP. */

/*! @brief Read current value of the EIM_CSnGCR2_DAP field. */
#define BR_EIM_CSnGCR2_DAP(x, n) (HW_EIM_CSnGCR2(x, n).B.DAP)

/*! @brief Format value for bitfield EIM_CSnGCR2_DAP. */
#define BF_EIM_CSnGCR2_DAP(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR2_DAP) & BM_EIM_CSnGCR2_DAP)

/*! @brief Set the DAP field to a new value. */
#define BW_EIM_CSnGCR2_DAP(x, n, v) (HW_EIM_CSnGCR2_WR(x, n, (HW_EIM_CSnGCR2_RD(x, n) & ~BM_EIM_CSnGCR2_DAP) | BF_EIM_CSnGCR2_DAP(v)))
/*@}*/

/*!
 * @name Register EIM_CSnGCR2, field MUX16_BYP_GRANT[12] (RW)
 *
 * Muxed 16 bypass grant. This bit when asserted causes EIM to bypass the
 * grant/ack. arbitration with NFC (only for 16 bit muxed mode accesses).
 *
 * Values:
 * - 0 - EIM waits for grant before driving a 16 bit muxed mode access to the
 *     memory.
 * - 1 - EIM ignores the grant signal and immediately drives a 16 bit muxed mode
 *     access to the memory.
 */
/*@{*/
#define BP_EIM_CSnGCR2_MUX16_BYP_GRANT (12U) /*!< Bit position for EIM_CSnGCR2_MUX16_BYP_GRANT. */
#define BM_EIM_CSnGCR2_MUX16_BYP_GRANT (0x00001000U) /*!< Bit mask for EIM_CSnGCR2_MUX16_BYP_GRANT. */
#define BS_EIM_CSnGCR2_MUX16_BYP_GRANT (1U) /*!< Bit field size in bits for EIM_CSnGCR2_MUX16_BYP_GRANT. */

/*! @brief Read current value of the EIM_CSnGCR2_MUX16_BYP_GRANT field. */
#define BR_EIM_CSnGCR2_MUX16_BYP_GRANT(x, n) (HW_EIM_CSnGCR2(x, n).B.MUX16_BYP_GRANT)

/*! @brief Format value for bitfield EIM_CSnGCR2_MUX16_BYP_GRANT. */
#define BF_EIM_CSnGCR2_MUX16_BYP_GRANT(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnGCR2_MUX16_BYP_GRANT) & BM_EIM_CSnGCR2_MUX16_BYP_GRANT)

/*! @brief Set the MUX16_BYP_GRANT field to a new value. */
#define BW_EIM_CSnGCR2_MUX16_BYP_GRANT(x, n, v) (HW_EIM_CSnGCR2_WR(x, n, (HW_EIM_CSnGCR2_RD(x, n) & ~BM_EIM_CSnGCR2_MUX16_BYP_GRANT) | BF_EIM_CSnGCR2_MUX16_BYP_GRANT(v)))
/*@}*/
/*******************************************************************************
 * HW_EIM_CSnRCR1 - Chip Select n Read Configuration Register 1
 ******************************************************************************/

/*!
 * @brief HW_EIM_CSnRCR1 - Chip Select n Read Configuration Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_eim_csnrcr1
{
    uint32_t U;
    struct _hw_eim_csnrcr1_bitfields
    {
        uint32_t RCSN : 3;             /*!< [2:0]  */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t RCSA : 3;             /*!< [6:4]  */
        uint32_t RESERVED1 : 1;        /*!< [7]  */
        uint32_t OEN : 3;              /*!< [10:8]  */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t OEA : 3;              /*!< [14:12]  */
        uint32_t RESERVED3 : 1;        /*!< [15]  */
        uint32_t RADVN : 3;            /*!< [18:16]  */
        uint32_t RAL : 1;              /*!< [19]  */
        uint32_t RADVA : 3;            /*!< [22:20]  */
        uint32_t RESERVED4 : 1;        /*!< [23]  */
        uint32_t RWSC : 6;             /*!< [29:24]  */
        uint32_t RESERVED5 : 2;        /*!< [31:30]  */
    } B;
} hw_eim_csnrcr1_t;

/*!
 * @name Constants and macros for entire EIM_CSnRCR1 register
 */
/*@{*/
#define HW_EIM_CSnRCR1_COUNT (6U)

#define HW_EIM_CSnRCR1_ADDR(x, n) ((uintptr_t)(x) + 0x8U + (0x18U * (n)))

#define HW_EIM_CSnRCR1(x, n)     (*(__IO hw_eim_csnrcr1_t *) HW_EIM_CSnRCR1_ADDR(x, n))
#define HW_EIM_CSnRCR1_RD(x, n)  (HW_EIM_CSnRCR1(x, n).U)
#define HW_EIM_CSnRCR1_WR(x, n, v) (HW_EIM_CSnRCR1(x, n).U = (v))
#define HW_EIM_CSnRCR1_SET(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, HW_EIM_CSnRCR1_RD(x, n) |  (v)))
#define HW_EIM_CSnRCR1_CLR(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, HW_EIM_CSnRCR1_RD(x, n) & ~(v)))
#define HW_EIM_CSnRCR1_TOG(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, HW_EIM_CSnRCR1_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_CSnRCR1 bitfields
 */

/*!
 * @name Register EIM_CSnRCR1, field RCSN[2:0] (RW)
 *
 * Read CS Negation. This bit field determines when CS signal is negated during
 * read cycles in asynchronous single mode only (SRD=0 & APR = 0), according to
 * the settings shown below. This bit field is ignored when SRD=1. RCSN is cleared
 * by a hardware reset. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between end of read access and CS negation
 * - 001 - 1 EIM clock cycles between end of read access and CS negation
 * - 010 - 2 EIM clock cycles between end of read access and CS negation
 * - 111 - 7 EIM clock cycles between end of read access and CS negation
 */
/*@{*/
#define BP_EIM_CSnRCR1_RCSN  (0U)          /*!< Bit position for EIM_CSnRCR1_RCSN. */
#define BM_EIM_CSnRCR1_RCSN  (0x00000007U) /*!< Bit mask for EIM_CSnRCR1_RCSN. */
#define BS_EIM_CSnRCR1_RCSN  (3U)          /*!< Bit field size in bits for EIM_CSnRCR1_RCSN. */

/*! @brief Read current value of the EIM_CSnRCR1_RCSN field. */
#define BR_EIM_CSnRCR1_RCSN(x, n) (HW_EIM_CSnRCR1(x, n).B.RCSN)

/*! @brief Format value for bitfield EIM_CSnRCR1_RCSN. */
#define BF_EIM_CSnRCR1_RCSN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR1_RCSN) & BM_EIM_CSnRCR1_RCSN)

/*! @brief Set the RCSN field to a new value. */
#define BW_EIM_CSnRCR1_RCSN(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, (HW_EIM_CSnRCR1_RD(x, n) & ~BM_EIM_CSnRCR1_RCSN) | BF_EIM_CSnRCR1_RCSN(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR1, field RCSA[6:4] (RW)
 *
 * Read CS Assertion. This bit field determines when CS signal is asserted
 * during read cycles (synchronous or asynchronous mode), according to the settings
 * shown below. RCSA is cleared by a hardware reset. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between beginning of read access and CS assertion
 * - 001 - 1 EIM clock cycles between beginning of read access and CS assertion
 * - 010 - 2 EIM clock cycles between beginning of read access and CS assertion
 * - 111 - 7 EIM clock cycles between beginning of read access and CS assertion
 */
/*@{*/
#define BP_EIM_CSnRCR1_RCSA  (4U)          /*!< Bit position for EIM_CSnRCR1_RCSA. */
#define BM_EIM_CSnRCR1_RCSA  (0x00000070U) /*!< Bit mask for EIM_CSnRCR1_RCSA. */
#define BS_EIM_CSnRCR1_RCSA  (3U)          /*!< Bit field size in bits for EIM_CSnRCR1_RCSA. */

/*! @brief Read current value of the EIM_CSnRCR1_RCSA field. */
#define BR_EIM_CSnRCR1_RCSA(x, n) (HW_EIM_CSnRCR1(x, n).B.RCSA)

/*! @brief Format value for bitfield EIM_CSnRCR1_RCSA. */
#define BF_EIM_CSnRCR1_RCSA(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR1_RCSA) & BM_EIM_CSnRCR1_RCSA)

/*! @brief Set the RCSA field to a new value. */
#define BW_EIM_CSnRCR1_RCSA(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, (HW_EIM_CSnRCR1_RD(x, n) & ~BM_EIM_CSnRCR1_RCSA) | BF_EIM_CSnRCR1_RCSA(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR1, field OEN[10:8] (RW)
 *
 * OE Negation. This bit field determines when OE signal is negated during read
 * cycles in asynchronous single mode only (SRD=0 & APR = 0), according to the
 * settings shown below. This bit field is ignored when SRD=1. OEN is cleared by a
 * hardware reset. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between end of access and OE negation
 * - 001 - 1 EIM clock cycles between end of access and OE negation
 * - 010 - 2 EIM clock cycles between end of access and OE negation
 * - 111 - 7 EIM clock cycles between end of access and OE negation
 */
/*@{*/
#define BP_EIM_CSnRCR1_OEN   (8U)          /*!< Bit position for EIM_CSnRCR1_OEN. */
#define BM_EIM_CSnRCR1_OEN   (0x00000700U) /*!< Bit mask for EIM_CSnRCR1_OEN. */
#define BS_EIM_CSnRCR1_OEN   (3U)          /*!< Bit field size in bits for EIM_CSnRCR1_OEN. */

/*! @brief Read current value of the EIM_CSnRCR1_OEN field. */
#define BR_EIM_CSnRCR1_OEN(x, n) (HW_EIM_CSnRCR1(x, n).B.OEN)

/*! @brief Format value for bitfield EIM_CSnRCR1_OEN. */
#define BF_EIM_CSnRCR1_OEN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR1_OEN) & BM_EIM_CSnRCR1_OEN)

/*! @brief Set the OEN field to a new value. */
#define BW_EIM_CSnRCR1_OEN(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, (HW_EIM_CSnRCR1_RD(x, n) & ~BM_EIM_CSnRCR1_OEN) | BF_EIM_CSnRCR1_OEN(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR1, field OEA[14:12] (RW)
 *
 * OE Assertion. This bit field determines when OE signal are asserted during
 * read cycles (synchronous or asynchronous mode), according to the settings shown
 * below. OEA is cleared by a hardware reset. In muxed mode OE assertion occurs
 * (OEA + RADVN + RADVA + ADH +1) EIM clock cycles from start of access. The reset
 * value for EIM_CS0RCR1[OEA] is 0b000 if EIM_BOOT[2] = 0. If EIM_BOOT[2] is 1,
 * the reset value for EIM_CS0RCR1 is 0b010. The reset value of this field for
 * EIM_CS1RCR1 - EIM_CS5RCR1 is 0b000. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between beginning of access and OE assertion
 * - 001 - 1 EIM clock cycles between beginning of access and OE assertion
 * - 010 - 2 EIM clock cycles between beginning of access and OE assertion
 * - 111 - 7 EIM clock cycles between beginning of access and OE assertion
 */
/*@{*/
#define BP_EIM_CSnRCR1_OEA   (12U)         /*!< Bit position for EIM_CSnRCR1_OEA. */
#define BM_EIM_CSnRCR1_OEA   (0x00007000U) /*!< Bit mask for EIM_CSnRCR1_OEA. */
#define BS_EIM_CSnRCR1_OEA   (3U)          /*!< Bit field size in bits for EIM_CSnRCR1_OEA. */

/*! @brief Read current value of the EIM_CSnRCR1_OEA field. */
#define BR_EIM_CSnRCR1_OEA(x, n) (HW_EIM_CSnRCR1(x, n).B.OEA)

/*! @brief Format value for bitfield EIM_CSnRCR1_OEA. */
#define BF_EIM_CSnRCR1_OEA(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR1_OEA) & BM_EIM_CSnRCR1_OEA)

/*! @brief Set the OEA field to a new value. */
#define BW_EIM_CSnRCR1_OEA(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, (HW_EIM_CSnRCR1_RD(x, n) & ~BM_EIM_CSnRCR1_OEA) | BF_EIM_CSnRCR1_OEA(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR1, field RADVN[18:16] (RW)
 *
 * ADV Negation. This bit field determines when ADV signal to memory is negated
 * during read accesses. When SRD=1 (synchronous read mode), ADV negation occurs
 * according to the following formula: (RADVN + RADVA + BCD + BCS + 1) EIM clock
 * cycles from start of access. When asynchronous read mode is applied (SRD=0)
 * and RAL=0 ADV negation occurs according to the following formula: (RADVN + RADVA
 * + 1) EIM clock cycles from start of access. RADVN is cleared by a hardware
 * reset. the reset value for EIM_CS0RCR1[RADVN] = 2. For EIM_CS1RCR1 -
 * EIM_CS5RCR1, the reset value is 0b000. This field should be configured so ADV negation
 * will occur before the end of access. For ADV negation at the same time with the
 * end of access user should RAL bit.
 */
/*@{*/
#define BP_EIM_CSnRCR1_RADVN (16U)         /*!< Bit position for EIM_CSnRCR1_RADVN. */
#define BM_EIM_CSnRCR1_RADVN (0x00070000U) /*!< Bit mask for EIM_CSnRCR1_RADVN. */
#define BS_EIM_CSnRCR1_RADVN (3U)          /*!< Bit field size in bits for EIM_CSnRCR1_RADVN. */

/*! @brief Read current value of the EIM_CSnRCR1_RADVN field. */
#define BR_EIM_CSnRCR1_RADVN(x, n) (HW_EIM_CSnRCR1(x, n).B.RADVN)

/*! @brief Format value for bitfield EIM_CSnRCR1_RADVN. */
#define BF_EIM_CSnRCR1_RADVN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR1_RADVN) & BM_EIM_CSnRCR1_RADVN)

/*! @brief Set the RADVN field to a new value. */
#define BW_EIM_CSnRCR1_RADVN(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, (HW_EIM_CSnRCR1_RD(x, n) & ~BM_EIM_CSnRCR1_RADVN) | BF_EIM_CSnRCR1_RADVN(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR1, field RAL[19] (RW)
 *
 * Read ADV Low. This bit field determine ADV signal negation time. When RAL=1,
 * RADVN bit field is ignored and ADV signal will stay asserted until end of
 * access. When RAL=0 negation of ADV signal is according to RADVN bit field
 * configuration.
 */
/*@{*/
#define BP_EIM_CSnRCR1_RAL   (19U)         /*!< Bit position for EIM_CSnRCR1_RAL. */
#define BM_EIM_CSnRCR1_RAL   (0x00080000U) /*!< Bit mask for EIM_CSnRCR1_RAL. */
#define BS_EIM_CSnRCR1_RAL   (1U)          /*!< Bit field size in bits for EIM_CSnRCR1_RAL. */

/*! @brief Read current value of the EIM_CSnRCR1_RAL field. */
#define BR_EIM_CSnRCR1_RAL(x, n) (HW_EIM_CSnRCR1(x, n).B.RAL)

/*! @brief Format value for bitfield EIM_CSnRCR1_RAL. */
#define BF_EIM_CSnRCR1_RAL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR1_RAL) & BM_EIM_CSnRCR1_RAL)

/*! @brief Set the RAL field to a new value. */
#define BW_EIM_CSnRCR1_RAL(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, (HW_EIM_CSnRCR1_RD(x, n) & ~BM_EIM_CSnRCR1_RAL) | BF_EIM_CSnRCR1_RAL(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR1, field RADVA[22:20] (RW)
 *
 * ADV Assertion. This bit field determines when ADV signal is asserted for
 * synchronous or asynchronous read modes according to the settings shown below.
 * RADVA is cleared by a hardware reset. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between beginning of access and ADV assertion
 * - 001 - 1 EIM clock cycles between beginning of access and ADV assertion
 * - 010 - 2 EIM clock cycles between beginning of access and ADV assertion
 * - 111 - 7 EIM clock cycles between beginning of access and ADV assertion
 */
/*@{*/
#define BP_EIM_CSnRCR1_RADVA (20U)         /*!< Bit position for EIM_CSnRCR1_RADVA. */
#define BM_EIM_CSnRCR1_RADVA (0x00700000U) /*!< Bit mask for EIM_CSnRCR1_RADVA. */
#define BS_EIM_CSnRCR1_RADVA (3U)          /*!< Bit field size in bits for EIM_CSnRCR1_RADVA. */

/*! @brief Read current value of the EIM_CSnRCR1_RADVA field. */
#define BR_EIM_CSnRCR1_RADVA(x, n) (HW_EIM_CSnRCR1(x, n).B.RADVA)

/*! @brief Format value for bitfield EIM_CSnRCR1_RADVA. */
#define BF_EIM_CSnRCR1_RADVA(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR1_RADVA) & BM_EIM_CSnRCR1_RADVA)

/*! @brief Set the RADVA field to a new value. */
#define BW_EIM_CSnRCR1_RADVA(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, (HW_EIM_CSnRCR1_RD(x, n) & ~BM_EIM_CSnRCR1_RADVA) | BF_EIM_CSnRCR1_RADVA(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR1, field RWSC[29:24] (RW)
 *
 * Read Wait State Control. This bit field programs the number of wait-states,
 * according to the settings shown below, for synchronous or asynchronous read
 * access to the external device connected to the chip select. When SRD=1 and RFL=0,
 * RWSC indicates the number of burst clock (BCLK) cycles from the start of an
 * access, before the controller can start sample data.Since WAIT signal can be
 * asserted one cycle before the first data can be sampled, the controller starts
 * evaluating the WAIT signal state one cycle before, this is referred as
 * handshake mode or variable latency mode. When SRD=1 and RFL=1, RWSC indicates the
 * number of burst clock (BCLK) cycles from the start of an access, until the
 * external device is ready for data transfer, this is referred as fix latency mode.
 * When SRD=0, RFL bit is ignored, RWSC indicates the asynchronous access length and
 * the number of EIM clock cycles from the start of access until the external
 * device is ready for data transfer. RWSC is cleared by a hardware reset. The
 * reset value for EIM_CS0RCR1, RWSC[5:0] = 0b011100. For CG1RCR1 - CS1RCR5 the reset
 * value is 0b000000. Example settings:
 *
 * Values:
 * - 000000 - Reserved
 * - 000001 - RWSC value is 1
 * - 000010 - RWSC value is 2
 * - 111101 - RWSC value is 61
 * - 111110 - RWSC value is 62
 * - 111111 - RWSC value is 63
 */
/*@{*/
#define BP_EIM_CSnRCR1_RWSC  (24U)         /*!< Bit position for EIM_CSnRCR1_RWSC. */
#define BM_EIM_CSnRCR1_RWSC  (0x3F000000U) /*!< Bit mask for EIM_CSnRCR1_RWSC. */
#define BS_EIM_CSnRCR1_RWSC  (6U)          /*!< Bit field size in bits for EIM_CSnRCR1_RWSC. */

/*! @brief Read current value of the EIM_CSnRCR1_RWSC field. */
#define BR_EIM_CSnRCR1_RWSC(x, n) (HW_EIM_CSnRCR1(x, n).B.RWSC)

/*! @brief Format value for bitfield EIM_CSnRCR1_RWSC. */
#define BF_EIM_CSnRCR1_RWSC(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR1_RWSC) & BM_EIM_CSnRCR1_RWSC)

/*! @brief Set the RWSC field to a new value. */
#define BW_EIM_CSnRCR1_RWSC(x, n, v) (HW_EIM_CSnRCR1_WR(x, n, (HW_EIM_CSnRCR1_RD(x, n) & ~BM_EIM_CSnRCR1_RWSC) | BF_EIM_CSnRCR1_RWSC(v)))
/*@}*/
/*******************************************************************************
 * HW_EIM_CSnRCR2 - Chip Select n Read Configuration Register 2
 ******************************************************************************/

/*!
 * @brief HW_EIM_CSnRCR2 - Chip Select n Read Configuration Register 2 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_eim_csnrcr2
{
    uint32_t U;
    struct _hw_eim_csnrcr2_bitfields
    {
        uint32_t RBEN : 3;             /*!< [2:0]  */
        uint32_t RBE : 1;              /*!< [3]  */
        uint32_t RBEA : 3;             /*!< [6:4]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t RL : 2;               /*!< [9:8]  */
        uint32_t RESERVED1 : 2;        /*!< [11:10]  */
        uint32_t PAT : 3;              /*!< [14:12]  */
        uint32_t APR : 1;              /*!< [15]  */
        uint32_t RESERVED2 : 16;       /*!< [31:16]  */
    } B;
} hw_eim_csnrcr2_t;

/*!
 * @name Constants and macros for entire EIM_CSnRCR2 register
 */
/*@{*/
#define HW_EIM_CSnRCR2_COUNT (6U)

#define HW_EIM_CSnRCR2_ADDR(x, n) ((uintptr_t)(x) + 0xCU + (0x18U * (n)))

#define HW_EIM_CSnRCR2(x, n)     (*(__IO hw_eim_csnrcr2_t *) HW_EIM_CSnRCR2_ADDR(x, n))
#define HW_EIM_CSnRCR2_RD(x, n)  (HW_EIM_CSnRCR2(x, n).U)
#define HW_EIM_CSnRCR2_WR(x, n, v) (HW_EIM_CSnRCR2(x, n).U = (v))
#define HW_EIM_CSnRCR2_SET(x, n, v) (HW_EIM_CSnRCR2_WR(x, n, HW_EIM_CSnRCR2_RD(x, n) |  (v)))
#define HW_EIM_CSnRCR2_CLR(x, n, v) (HW_EIM_CSnRCR2_WR(x, n, HW_EIM_CSnRCR2_RD(x, n) & ~(v)))
#define HW_EIM_CSnRCR2_TOG(x, n, v) (HW_EIM_CSnRCR2_WR(x, n, HW_EIM_CSnRCR2_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_CSnRCR2 bitfields
 */

/*!
 * @name Register EIM_CSnRCR2, field RBEN[2:0] (RW)
 *
 * Read BE Negation. This bit field determines when BE signal is negated during
 * read cycles in asynchronous single mode only (SRD=0 & APR=0), according to the
 * settings shown below. This bit field is ignored when SRD=1. RBEN is cleared
 * by a hardware reset. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between end of read access and BE negation
 * - 001 - 1 EIM clock cycles between end of read access and BE negation
 * - 010 - 2 EIM clock cycles between end of read access and BE negation
 * - 111 - 7 EIM clock cycles between end of read access and BE negation
 */
/*@{*/
#define BP_EIM_CSnRCR2_RBEN  (0U)          /*!< Bit position for EIM_CSnRCR2_RBEN. */
#define BM_EIM_CSnRCR2_RBEN  (0x00000007U) /*!< Bit mask for EIM_CSnRCR2_RBEN. */
#define BS_EIM_CSnRCR2_RBEN  (3U)          /*!< Bit field size in bits for EIM_CSnRCR2_RBEN. */

/*! @brief Read current value of the EIM_CSnRCR2_RBEN field. */
#define BR_EIM_CSnRCR2_RBEN(x, n) (HW_EIM_CSnRCR2(x, n).B.RBEN)

/*! @brief Format value for bitfield EIM_CSnRCR2_RBEN. */
#define BF_EIM_CSnRCR2_RBEN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR2_RBEN) & BM_EIM_CSnRCR2_RBEN)

/*! @brief Set the RBEN field to a new value. */
#define BW_EIM_CSnRCR2_RBEN(x, n, v) (HW_EIM_CSnRCR2_WR(x, n, (HW_EIM_CSnRCR2_RD(x, n) & ~BM_EIM_CSnRCR2_RBEN) | BF_EIM_CSnRCR2_RBEN(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR2, field RBE[3] (RW)
 *
 * Read BE enable. This bit field determines if BE will be asserted during read
 * access.
 *
 * Values:
 * - 0 - - BE are disabled during read access.
 */
/*@{*/
#define BP_EIM_CSnRCR2_RBE   (3U)          /*!< Bit position for EIM_CSnRCR2_RBE. */
#define BM_EIM_CSnRCR2_RBE   (0x00000008U) /*!< Bit mask for EIM_CSnRCR2_RBE. */
#define BS_EIM_CSnRCR2_RBE   (1U)          /*!< Bit field size in bits for EIM_CSnRCR2_RBE. */

/*! @brief Read current value of the EIM_CSnRCR2_RBE field. */
#define BR_EIM_CSnRCR2_RBE(x, n) (HW_EIM_CSnRCR2(x, n).B.RBE)

/*! @brief Format value for bitfield EIM_CSnRCR2_RBE. */
#define BF_EIM_CSnRCR2_RBE(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR2_RBE) & BM_EIM_CSnRCR2_RBE)

/*! @brief Set the RBE field to a new value. */
#define BW_EIM_CSnRCR2_RBE(x, n, v) (HW_EIM_CSnRCR2_WR(x, n, (HW_EIM_CSnRCR2_RD(x, n) & ~BM_EIM_CSnRCR2_RBE) | BF_EIM_CSnRCR2_RBE(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR2, field RBEA[6:4] (RW)
 *
 * Read BE Assertion. This bit field determines when BE signal is asserted
 * during read cycles (synchronous or asynchronous mode), according to the settings
 * shown below. RBEA is cleared by a hardware reset. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between beginning of read access and BE assertion
 * - 001 - 1 EIM clock cycles between beginning of read access and BE assertion
 * - 010 - 2 EIM clock cycles between beginning of read access and BE assertion
 * - 111 - 7 EIM clock cycles between beginning of read access and BE assertion
 */
/*@{*/
#define BP_EIM_CSnRCR2_RBEA  (4U)          /*!< Bit position for EIM_CSnRCR2_RBEA. */
#define BM_EIM_CSnRCR2_RBEA  (0x00000070U) /*!< Bit mask for EIM_CSnRCR2_RBEA. */
#define BS_EIM_CSnRCR2_RBEA  (3U)          /*!< Bit field size in bits for EIM_CSnRCR2_RBEA. */

/*! @brief Read current value of the EIM_CSnRCR2_RBEA field. */
#define BR_EIM_CSnRCR2_RBEA(x, n) (HW_EIM_CSnRCR2(x, n).B.RBEA)

/*! @brief Format value for bitfield EIM_CSnRCR2_RBEA. */
#define BF_EIM_CSnRCR2_RBEA(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR2_RBEA) & BM_EIM_CSnRCR2_RBEA)

/*! @brief Set the RBEA field to a new value. */
#define BW_EIM_CSnRCR2_RBEA(x, n, v) (HW_EIM_CSnRCR2_WR(x, n, (HW_EIM_CSnRCR2_RD(x, n) & ~BM_EIM_CSnRCR2_RBEA) | BF_EIM_CSnRCR2_RBEA(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR2, field RL[9:8] (RW)
 *
 * Read Latency. This bit field indicates cycle latency when executing a
 * synchronous read operation. The fields holds the feedback clock loop delay in aclk
 * cycle units. This field is cleared by a hardware reset.
 *
 * Values:
 * - 00 - Feedback clock loop delay is up to 1 cycle for BCD = 0 or 1.5 cycles
 *     for BCD != 0
 * - 01 - Feedback clock loop delay is up to 2 cycles for BCD = 0 or 2.5 cycles
 *     for BCD != 0
 * - 10 - Feedback clock loop delay is up to 3 cycles for BCD = 0 or 3.5 cycles
 *     for BCD != 0
 * - 11 - Feedback clock loop delay is up to 4 cycles for BCD = 0 or 4.5 cycles
 *     for BCD != 0
 */
/*@{*/
#define BP_EIM_CSnRCR2_RL    (8U)          /*!< Bit position for EIM_CSnRCR2_RL. */
#define BM_EIM_CSnRCR2_RL    (0x00000300U) /*!< Bit mask for EIM_CSnRCR2_RL. */
#define BS_EIM_CSnRCR2_RL    (2U)          /*!< Bit field size in bits for EIM_CSnRCR2_RL. */

/*! @brief Read current value of the EIM_CSnRCR2_RL field. */
#define BR_EIM_CSnRCR2_RL(x, n) (HW_EIM_CSnRCR2(x, n).B.RL)

/*! @brief Format value for bitfield EIM_CSnRCR2_RL. */
#define BF_EIM_CSnRCR2_RL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR2_RL) & BM_EIM_CSnRCR2_RL)

/*! @brief Set the RL field to a new value. */
#define BW_EIM_CSnRCR2_RL(x, n, v) (HW_EIM_CSnRCR2_WR(x, n, (HW_EIM_CSnRCR2_RD(x, n) & ~BM_EIM_CSnRCR2_RL) | BF_EIM_CSnRCR2_RL(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR2, field PAT[14:12] (RW)
 *
 * Page Access Time. This bit field is used in Asynchronous Page Read mode only
 * (APR=1). the initial access is set by RWSC as in regular asynchronous mode.
 * the consecutive address assertions width determine by PAT field according to the
 * settings shown below. when APR=0 this field is ignored. PAT is cleared by a
 * hardware reset for EIM_CS1GCR1 - EIM_CS5GCR1.
 *
 * Values:
 * - 000 - Address width is 2 EIM clock cycles
 * - 001 - Address width is 3 EIM clock cycles
 * - 010 - Address width is 4 EIM clock cycles
 * - 011 - Address width is 5 EIM clock cycles
 * - 100 - Address width is 6 EIM clock cycles
 * - 101 - Address width is 7 EIM clock cycles
 * - 110 - Address width is 8 EIM clock cycles
 * - 111 - Address width is 9 EIM clock cycles
 */
/*@{*/
#define BP_EIM_CSnRCR2_PAT   (12U)         /*!< Bit position for EIM_CSnRCR2_PAT. */
#define BM_EIM_CSnRCR2_PAT   (0x00007000U) /*!< Bit mask for EIM_CSnRCR2_PAT. */
#define BS_EIM_CSnRCR2_PAT   (3U)          /*!< Bit field size in bits for EIM_CSnRCR2_PAT. */

/*! @brief Read current value of the EIM_CSnRCR2_PAT field. */
#define BR_EIM_CSnRCR2_PAT(x, n) (HW_EIM_CSnRCR2(x, n).B.PAT)

/*! @brief Format value for bitfield EIM_CSnRCR2_PAT. */
#define BF_EIM_CSnRCR2_PAT(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR2_PAT) & BM_EIM_CSnRCR2_PAT)

/*! @brief Set the PAT field to a new value. */
#define BW_EIM_CSnRCR2_PAT(x, n, v) (HW_EIM_CSnRCR2_WR(x, n, (HW_EIM_CSnRCR2_RD(x, n) & ~BM_EIM_CSnRCR2_PAT) | BF_EIM_CSnRCR2_PAT(v)))
/*@}*/

/*!
 * @name Register EIM_CSnRCR2, field APR[15] (RW)
 *
 * Asynchronous Page Read. This bit field determine the asynchronous read mode
 * to the external device. When APR=0, the async. read access is done as single
 * word (where word is defined by the DSZ field). when APR=1, the async. read
 * access executed as page read. page size is according to BL field config.,
 * RCSN,RBEN,OEN and RADVN are being ignored. APR is cleared by a hardware reset for
 * EIM_CS1GCR1 - EIM_CS5GCR1. SRD=0 and MUM=0 must apply when APR=1
 */
/*@{*/
#define BP_EIM_CSnRCR2_APR   (15U)         /*!< Bit position for EIM_CSnRCR2_APR. */
#define BM_EIM_CSnRCR2_APR   (0x00008000U) /*!< Bit mask for EIM_CSnRCR2_APR. */
#define BS_EIM_CSnRCR2_APR   (1U)          /*!< Bit field size in bits for EIM_CSnRCR2_APR. */

/*! @brief Read current value of the EIM_CSnRCR2_APR field. */
#define BR_EIM_CSnRCR2_APR(x, n) (HW_EIM_CSnRCR2(x, n).B.APR)

/*! @brief Format value for bitfield EIM_CSnRCR2_APR. */
#define BF_EIM_CSnRCR2_APR(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnRCR2_APR) & BM_EIM_CSnRCR2_APR)

/*! @brief Set the APR field to a new value. */
#define BW_EIM_CSnRCR2_APR(x, n, v) (HW_EIM_CSnRCR2_WR(x, n, (HW_EIM_CSnRCR2_RD(x, n) & ~BM_EIM_CSnRCR2_APR) | BF_EIM_CSnRCR2_APR(v)))
/*@}*/
/*******************************************************************************
 * HW_EIM_CSnWCR1 - Chip Select n Write Configuration Register 1
 ******************************************************************************/

/*!
 * @brief HW_EIM_CSnWCR1 - Chip Select n Write Configuration Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_eim_csnwcr1
{
    uint32_t U;
    struct _hw_eim_csnwcr1_bitfields
    {
        uint32_t WCSN : 3;             /*!< [2:0]  */
        uint32_t WCSA : 3;             /*!< [5:3]  */
        uint32_t WEN : 3;              /*!< [8:6]  */
        uint32_t WEA : 3;              /*!< [11:9]  */
        uint32_t WBEN : 3;             /*!< [14:12]  */
        uint32_t WBEA : 3;             /*!< [17:15]  */
        uint32_t WADVN : 3;            /*!< [20:18]  */
        uint32_t WADVA : 3;            /*!< [23:21]  */
        uint32_t WWSC : 6;             /*!< [29:24]  */
        uint32_t WBED : 1;             /*!< [30]  */
        uint32_t WAL : 1;              /*!< [31]  */
    } B;
} hw_eim_csnwcr1_t;

/*!
 * @name Constants and macros for entire EIM_CSnWCR1 register
 */
/*@{*/
#define HW_EIM_CSnWCR1_COUNT (6U)

#define HW_EIM_CSnWCR1_ADDR(x, n) ((uintptr_t)(x) + 0x10U + (0x18U * (n)))

#define HW_EIM_CSnWCR1(x, n)     (*(__IO hw_eim_csnwcr1_t *) HW_EIM_CSnWCR1_ADDR(x, n))
#define HW_EIM_CSnWCR1_RD(x, n)  (HW_EIM_CSnWCR1(x, n).U)
#define HW_EIM_CSnWCR1_WR(x, n, v) (HW_EIM_CSnWCR1(x, n).U = (v))
#define HW_EIM_CSnWCR1_SET(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, HW_EIM_CSnWCR1_RD(x, n) |  (v)))
#define HW_EIM_CSnWCR1_CLR(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, HW_EIM_CSnWCR1_RD(x, n) & ~(v)))
#define HW_EIM_CSnWCR1_TOG(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, HW_EIM_CSnWCR1_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_CSnWCR1 bitfields
 */

/*!
 * @name Register EIM_CSnWCR1, field WCSN[2:0] (RW)
 *
 * Write CS Negation. This bit field determines when CS signal is negated during
 * write cycles in asynchronous mode only (SWR=0), according to the settings
 * shown below. This bit field is ignored when SWR=1. WCSN is cleared by a hardware
 * reset. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between end of read access and CS negation
 * - 001 - 1 EIM clock cycles between end of read access and CS negation
 * - 010 - 2 EIM clock cycles between end of read access and CS negation
 * - 111 - 7 EIM clock cycles between end of read access and CS negation
 */
/*@{*/
#define BP_EIM_CSnWCR1_WCSN  (0U)          /*!< Bit position for EIM_CSnWCR1_WCSN. */
#define BM_EIM_CSnWCR1_WCSN  (0x00000007U) /*!< Bit mask for EIM_CSnWCR1_WCSN. */
#define BS_EIM_CSnWCR1_WCSN  (3U)          /*!< Bit field size in bits for EIM_CSnWCR1_WCSN. */

/*! @brief Read current value of the EIM_CSnWCR1_WCSN field. */
#define BR_EIM_CSnWCR1_WCSN(x, n) (HW_EIM_CSnWCR1(x, n).B.WCSN)

/*! @brief Format value for bitfield EIM_CSnWCR1_WCSN. */
#define BF_EIM_CSnWCR1_WCSN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WCSN) & BM_EIM_CSnWCR1_WCSN)

/*! @brief Set the WCSN field to a new value. */
#define BW_EIM_CSnWCR1_WCSN(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WCSN) | BF_EIM_CSnWCR1_WCSN(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WCSA[5:3] (RW)
 *
 * Write CS Assertion. This bit field determines when CS signal is asserted
 * during write cycles (synchronous or asynchronous mode), according to the settings
 * shown below.this bit field is ignored when executing a read access to the
 * external device. WCSA is cleared by a hardware reset. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between beginning of write access and CS assertion
 * - 001 - 1 EIM clock cycles between beginning of write access and CS assertion
 * - 010 - 2 EIM clock cycles between beginning of write access and CS assertion
 * - 111 - 7 EIMclock cycles between beginning of write access and CS assertion
 */
/*@{*/
#define BP_EIM_CSnWCR1_WCSA  (3U)          /*!< Bit position for EIM_CSnWCR1_WCSA. */
#define BM_EIM_CSnWCR1_WCSA  (0x00000038U) /*!< Bit mask for EIM_CSnWCR1_WCSA. */
#define BS_EIM_CSnWCR1_WCSA  (3U)          /*!< Bit field size in bits for EIM_CSnWCR1_WCSA. */

/*! @brief Read current value of the EIM_CSnWCR1_WCSA field. */
#define BR_EIM_CSnWCR1_WCSA(x, n) (HW_EIM_CSnWCR1(x, n).B.WCSA)

/*! @brief Format value for bitfield EIM_CSnWCR1_WCSA. */
#define BF_EIM_CSnWCR1_WCSA(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WCSA) & BM_EIM_CSnWCR1_WCSA)

/*! @brief Set the WCSA field to a new value. */
#define BW_EIM_CSnWCR1_WCSA(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WCSA) | BF_EIM_CSnWCR1_WCSA(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WEN[8:6] (RW)
 *
 * WE Negation. This bit field determines when WE signal is negated during write
 * cycles in asynchronous mode only (SWR=0), according to the settings shown
 * below. This bit field is ignored when SWR=1. WEN is cleared by a hardware reset.
 * Reset value for EIM_CS0WCR for WEN is 2. For EIM_CS1WCR - EIM_CS5WCR reset
 * value is 000. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between beginning of access and WE assertion
 * - 001 - 1 EIM clock cycles between beginning of access and WE assertion
 * - 010 - 2 EIM clock cycles between beginning of access and WE assertion
 * - 111 - 7 EIM clock cycles between beginning of access and WE assertion
 */
/*@{*/
#define BP_EIM_CSnWCR1_WEN   (6U)          /*!< Bit position for EIM_CSnWCR1_WEN. */
#define BM_EIM_CSnWCR1_WEN   (0x000001C0U) /*!< Bit mask for EIM_CSnWCR1_WEN. */
#define BS_EIM_CSnWCR1_WEN   (3U)          /*!< Bit field size in bits for EIM_CSnWCR1_WEN. */

/*! @brief Read current value of the EIM_CSnWCR1_WEN field. */
#define BR_EIM_CSnWCR1_WEN(x, n) (HW_EIM_CSnWCR1(x, n).B.WEN)

/*! @brief Format value for bitfield EIM_CSnWCR1_WEN. */
#define BF_EIM_CSnWCR1_WEN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WEN) & BM_EIM_CSnWCR1_WEN)

/*! @brief Set the WEN field to a new value. */
#define BW_EIM_CSnWCR1_WEN(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WEN) | BF_EIM_CSnWCR1_WEN(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WEA[11:9] (RW)
 *
 * WE Assertion. This bit field determines when WE signal is asserted during
 * write cycles (synchronous or asynchronous mode), according to the settings shown
 * below. This bit field is ignored when executing a read access to the external
 * device. WEA is cleared by a hardware reset. Reset value for EIM_CS0WCR for WEA
 * is 2. For EIM_CS1WCR - EIM_CS5WCR reset value is 000. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between beginning of access and WE assertion
 * - 001 - 1 EIM clock cycles between beginning of access and WE assertion
 * - 010 - 2 EIM clock cycles between beginning of access and WE assertion
 * - 111 - 7 EIMclock cycles between beginning of access and WE assertion
 */
/*@{*/
#define BP_EIM_CSnWCR1_WEA   (9U)          /*!< Bit position for EIM_CSnWCR1_WEA. */
#define BM_EIM_CSnWCR1_WEA   (0x00000E00U) /*!< Bit mask for EIM_CSnWCR1_WEA. */
#define BS_EIM_CSnWCR1_WEA   (3U)          /*!< Bit field size in bits for EIM_CSnWCR1_WEA. */

/*! @brief Read current value of the EIM_CSnWCR1_WEA field. */
#define BR_EIM_CSnWCR1_WEA(x, n) (HW_EIM_CSnWCR1(x, n).B.WEA)

/*! @brief Format value for bitfield EIM_CSnWCR1_WEA. */
#define BF_EIM_CSnWCR1_WEA(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WEA) & BM_EIM_CSnWCR1_WEA)

/*! @brief Set the WEA field to a new value. */
#define BW_EIM_CSnWCR1_WEA(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WEA) | BF_EIM_CSnWCR1_WEA(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WBEN[14:12] (RW)
 *
 * BE[3:0] Negation. This bit field determines when BE[3:0] bus signal is
 * negated during write cycles in async. mode only (SWR=0), according to the settings
 * shown below. This bit field is ignored when SWR=1. BEN is cleared by a hardware
 * reset. Reset value for EIM_CS0WCR for WBEN is 2. For EIM_CS1WCR - EIM_CS5WCR
 * reset value is 000. Example settings: 000 0 EIM clock cycles between end of
 * access and WE negation 001 1 EIM clock cycles between end of access and WE
 * negation 010 2 EIM clock cycles between end of access and WE negation 111 7 EIM
 * clock cycles between end of access and WE negation
 */
/*@{*/
#define BP_EIM_CSnWCR1_WBEN  (12U)         /*!< Bit position for EIM_CSnWCR1_WBEN. */
#define BM_EIM_CSnWCR1_WBEN  (0x00007000U) /*!< Bit mask for EIM_CSnWCR1_WBEN. */
#define BS_EIM_CSnWCR1_WBEN  (3U)          /*!< Bit field size in bits for EIM_CSnWCR1_WBEN. */

/*! @brief Read current value of the EIM_CSnWCR1_WBEN field. */
#define BR_EIM_CSnWCR1_WBEN(x, n) (HW_EIM_CSnWCR1(x, n).B.WBEN)

/*! @brief Format value for bitfield EIM_CSnWCR1_WBEN. */
#define BF_EIM_CSnWCR1_WBEN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WBEN) & BM_EIM_CSnWCR1_WBEN)

/*! @brief Set the WBEN field to a new value. */
#define BW_EIM_CSnWCR1_WBEN(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WBEN) | BF_EIM_CSnWCR1_WBEN(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WBEA[17:15] (RW)
 *
 * BE Assertion. This bit field determines when BE signal is asserted during
 * write cycles in async. mode only (SWR=0), according to the settings shown below.
 * BEA is cleared by a hardware reset. Reset value for EIM_CS0WCR for WBEA is 2.
 * For EIM_CS1WCR - EIM_CS5WCR reset value is 000. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between beginning of access and BE assertion
 * - 001 - 1 EIM clock cycles between beginning of access and BE assertion
 * - 010 - 2 EIM clock cycles between beginning of access and BE assertion
 * - 111 - 7 EIM clock cycles between beginning of access and BE assertion
 */
/*@{*/
#define BP_EIM_CSnWCR1_WBEA  (15U)         /*!< Bit position for EIM_CSnWCR1_WBEA. */
#define BM_EIM_CSnWCR1_WBEA  (0x00038000U) /*!< Bit mask for EIM_CSnWCR1_WBEA. */
#define BS_EIM_CSnWCR1_WBEA  (3U)          /*!< Bit field size in bits for EIM_CSnWCR1_WBEA. */

/*! @brief Read current value of the EIM_CSnWCR1_WBEA field. */
#define BR_EIM_CSnWCR1_WBEA(x, n) (HW_EIM_CSnWCR1(x, n).B.WBEA)

/*! @brief Format value for bitfield EIM_CSnWCR1_WBEA. */
#define BF_EIM_CSnWCR1_WBEA(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WBEA) & BM_EIM_CSnWCR1_WBEA)

/*! @brief Set the WBEA field to a new value. */
#define BW_EIM_CSnWCR1_WBEA(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WBEA) | BF_EIM_CSnWCR1_WBEA(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WADVN[20:18] (RW)
 *
 * ADV Negation. This bit field determines when ADV signal to memory is negated
 * during write accesses. When SWR=1 (synchronous write mode), ADV negation
 * occurs according to the following formula: (WADVN + WADVA + BCD + BCS + 1) EIM
 * clock cycles. When asynchronous read mode is applied (SWR=0) ADV negation occurs
 * according to the following formula: (WADVN + WADVA + 1) EIM clock cycles. Reset
 * value for EIM_CS0WCR for WADVN is 2. For EIM_CS1WCR - EIM_CS5WCR reset value
 * is 000. This field should be configured so ADV negation will occur before the
 * end of access. For ADV negation at the same time as the end of access, S/W
 * should set the WAL bit.
 */
/*@{*/
#define BP_EIM_CSnWCR1_WADVN (18U)         /*!< Bit position for EIM_CSnWCR1_WADVN. */
#define BM_EIM_CSnWCR1_WADVN (0x001C0000U) /*!< Bit mask for EIM_CSnWCR1_WADVN. */
#define BS_EIM_CSnWCR1_WADVN (3U)          /*!< Bit field size in bits for EIM_CSnWCR1_WADVN. */

/*! @brief Read current value of the EIM_CSnWCR1_WADVN field. */
#define BR_EIM_CSnWCR1_WADVN(x, n) (HW_EIM_CSnWCR1(x, n).B.WADVN)

/*! @brief Format value for bitfield EIM_CSnWCR1_WADVN. */
#define BF_EIM_CSnWCR1_WADVN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WADVN) & BM_EIM_CSnWCR1_WADVN)

/*! @brief Set the WADVN field to a new value. */
#define BW_EIM_CSnWCR1_WADVN(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WADVN) | BF_EIM_CSnWCR1_WADVN(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WADVA[23:21] (RW)
 *
 * ADV Assertion. This bit field determines when ADV signal is asserted for
 * synchronous or asynchronous write modes according to the settings shown below.
 * WADVA is cleared by a hardware reset. Example settings:
 *
 * Values:
 * - 000 - 0 EIM clock cycles between beginning of access and ADV assertion
 * - 001 - 1 EIM clock cycles between beginning of access and ADV assertion
 * - 010 - 2 EIM clock cycles between beginning of access and ADV assertion
 * - 111 - 7 EIM clock cycles between beginning of access and ADV assertion
 */
/*@{*/
#define BP_EIM_CSnWCR1_WADVA (21U)         /*!< Bit position for EIM_CSnWCR1_WADVA. */
#define BM_EIM_CSnWCR1_WADVA (0x00E00000U) /*!< Bit mask for EIM_CSnWCR1_WADVA. */
#define BS_EIM_CSnWCR1_WADVA (3U)          /*!< Bit field size in bits for EIM_CSnWCR1_WADVA. */

/*! @brief Read current value of the EIM_CSnWCR1_WADVA field. */
#define BR_EIM_CSnWCR1_WADVA(x, n) (HW_EIM_CSnWCR1(x, n).B.WADVA)

/*! @brief Format value for bitfield EIM_CSnWCR1_WADVA. */
#define BF_EIM_CSnWCR1_WADVA(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WADVA) & BM_EIM_CSnWCR1_WADVA)

/*! @brief Set the WADVA field to a new value. */
#define BW_EIM_CSnWCR1_WADVA(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WADVA) | BF_EIM_CSnWCR1_WADVA(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WWSC[29:24] (RW)
 *
 * Write Wait State Control. This bit field programs the number of wait-states,
 * according to the settings shown below, for synchronous or asynchronous write
 * access to the external device connected to the chip select. When SWR=1 and
 * WFL=0, WWSC indicates the number of burst clock (BCLK) cycles from the start of an
 * access, before the memory can sample the first data.Since WAIT signal can be
 * asserted one cycle before the first data can be sampled, the controller starts
 * evaluating the WAIT signal state one cycle before, this is referred as
 * handshake mode or variable latency mode. When SWR=1 and WFL=1, WWSC indicates the
 * number of burst clock (BCLK) cycles from the start of an access, until the
 * external device is ready for data transfer, this is referred as fix latency mode.
 * When SWR=0, WFL bit is ignored, WWSC indicates the asynchronous access length
 * and the number of EIM clock cycles from the start of access until the external
 * device is ready for data transfer. WWSC is cleared by a hardware reset. The
 * reset value for EIM_CS0WCR1, WWSC[5:0] = 0b011100. For EIM_CS1WCR1 -
 * EIM_CS5WCR1, the reset value of this field is 0b000000. Example settings:
 *
 * Values:
 * - 000000 - Reserved
 * - 000001 - WWSC value is 1
 * - 000010 - WWSC value is 2
 * - 000011 - WWSC value is 3
 * - 111111 - WWSC value is 63
 */
/*@{*/
#define BP_EIM_CSnWCR1_WWSC  (24U)         /*!< Bit position for EIM_CSnWCR1_WWSC. */
#define BM_EIM_CSnWCR1_WWSC  (0x3F000000U) /*!< Bit mask for EIM_CSnWCR1_WWSC. */
#define BS_EIM_CSnWCR1_WWSC  (6U)          /*!< Bit field size in bits for EIM_CSnWCR1_WWSC. */

/*! @brief Read current value of the EIM_CSnWCR1_WWSC field. */
#define BR_EIM_CSnWCR1_WWSC(x, n) (HW_EIM_CSnWCR1(x, n).B.WWSC)

/*! @brief Format value for bitfield EIM_CSnWCR1_WWSC. */
#define BF_EIM_CSnWCR1_WWSC(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WWSC) & BM_EIM_CSnWCR1_WWSC)

/*! @brief Set the WWSC field to a new value. */
#define BW_EIM_CSnWCR1_WWSC(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WWSC) | BF_EIM_CSnWCR1_WWSC(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WBED[30] (RW)
 *
 * Write Byte Enable Disable. When asserted this bit prevent from IPP_DO_BE_B[x]
 * to be asserted during write accesses.This bit is cleared by hardware reset.
 */
/*@{*/
#define BP_EIM_CSnWCR1_WBED  (30U)         /*!< Bit position for EIM_CSnWCR1_WBED. */
#define BM_EIM_CSnWCR1_WBED  (0x40000000U) /*!< Bit mask for EIM_CSnWCR1_WBED. */
#define BS_EIM_CSnWCR1_WBED  (1U)          /*!< Bit field size in bits for EIM_CSnWCR1_WBED. */

/*! @brief Read current value of the EIM_CSnWCR1_WBED field. */
#define BR_EIM_CSnWCR1_WBED(x, n) (HW_EIM_CSnWCR1(x, n).B.WBED)

/*! @brief Format value for bitfield EIM_CSnWCR1_WBED. */
#define BF_EIM_CSnWCR1_WBED(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WBED) & BM_EIM_CSnWCR1_WBED)

/*! @brief Set the WBED field to a new value. */
#define BW_EIM_CSnWCR1_WBED(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WBED) | BF_EIM_CSnWCR1_WBED(v)))
/*@}*/

/*!
 * @name Register EIM_CSnWCR1, field WAL[31] (RW)
 *
 * Write ADV Low. This bit field determine ADV signal negation time in write
 * accesses. When WAL=1, WADVN bit field is ignored and ADV signal will stay
 * asserted until end of access. When WAL=0 negation of ADV signal is according to WADVN
 * bit field configuration.
 */
/*@{*/
#define BP_EIM_CSnWCR1_WAL   (31U)         /*!< Bit position for EIM_CSnWCR1_WAL. */
#define BM_EIM_CSnWCR1_WAL   (0x80000000U) /*!< Bit mask for EIM_CSnWCR1_WAL. */
#define BS_EIM_CSnWCR1_WAL   (1U)          /*!< Bit field size in bits for EIM_CSnWCR1_WAL. */

/*! @brief Read current value of the EIM_CSnWCR1_WAL field. */
#define BR_EIM_CSnWCR1_WAL(x, n) (HW_EIM_CSnWCR1(x, n).B.WAL)

/*! @brief Format value for bitfield EIM_CSnWCR1_WAL. */
#define BF_EIM_CSnWCR1_WAL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR1_WAL) & BM_EIM_CSnWCR1_WAL)

/*! @brief Set the WAL field to a new value. */
#define BW_EIM_CSnWCR1_WAL(x, n, v) (HW_EIM_CSnWCR1_WR(x, n, (HW_EIM_CSnWCR1_RD(x, n) & ~BM_EIM_CSnWCR1_WAL) | BF_EIM_CSnWCR1_WAL(v)))
/*@}*/
/*******************************************************************************
 * HW_EIM_CSnWCR2 - Chip Select n Write Configuration Register 2
 ******************************************************************************/

/*!
 * @brief HW_EIM_CSnWCR2 - Chip Select n Write Configuration Register 2 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_eim_csnwcr2
{
    uint32_t U;
    struct _hw_eim_csnwcr2_bitfields
    {
        uint32_t WBCDD : 1;            /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_eim_csnwcr2_t;

/*!
 * @name Constants and macros for entire EIM_CSnWCR2 register
 */
/*@{*/
#define HW_EIM_CSnWCR2_COUNT (6U)

#define HW_EIM_CSnWCR2_ADDR(x, n) ((uintptr_t)(x) + 0x14U + (0x18U * (n)))

#define HW_EIM_CSnWCR2(x, n)     (*(__IO hw_eim_csnwcr2_t *) HW_EIM_CSnWCR2_ADDR(x, n))
#define HW_EIM_CSnWCR2_RD(x, n)  (HW_EIM_CSnWCR2(x, n).U)
#define HW_EIM_CSnWCR2_WR(x, n, v) (HW_EIM_CSnWCR2(x, n).U = (v))
#define HW_EIM_CSnWCR2_SET(x, n, v) (HW_EIM_CSnWCR2_WR(x, n, HW_EIM_CSnWCR2_RD(x, n) |  (v)))
#define HW_EIM_CSnWCR2_CLR(x, n, v) (HW_EIM_CSnWCR2_WR(x, n, HW_EIM_CSnWCR2_RD(x, n) & ~(v)))
#define HW_EIM_CSnWCR2_TOG(x, n, v) (HW_EIM_CSnWCR2_WR(x, n, HW_EIM_CSnWCR2_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_CSnWCR2 bitfields
 */

/*!
 * @name Register EIM_CSnWCR2, field WBCDD[0] (RW)
 *
 * Write Burst Clock Divisor Decrement. If this bit is asserted and BCD value is
 * 0 sync. write access will be preformed as if BCD value is 1.When this bit is
 * negated or BCD value is not 0 this bit has no affect. This bit is cleared by
 * hardware reset.
 */
/*@{*/
#define BP_EIM_CSnWCR2_WBCDD (0U)          /*!< Bit position for EIM_CSnWCR2_WBCDD. */
#define BM_EIM_CSnWCR2_WBCDD (0x00000001U) /*!< Bit mask for EIM_CSnWCR2_WBCDD. */
#define BS_EIM_CSnWCR2_WBCDD (1U)          /*!< Bit field size in bits for EIM_CSnWCR2_WBCDD. */

/*! @brief Read current value of the EIM_CSnWCR2_WBCDD field. */
#define BR_EIM_CSnWCR2_WBCDD(x, n) (HW_EIM_CSnWCR2(x, n).B.WBCDD)

/*! @brief Format value for bitfield EIM_CSnWCR2_WBCDD. */
#define BF_EIM_CSnWCR2_WBCDD(v) ((uint32_t)((uint32_t)(v) << BP_EIM_CSnWCR2_WBCDD) & BM_EIM_CSnWCR2_WBCDD)

/*! @brief Set the WBCDD field to a new value. */
#define BW_EIM_CSnWCR2_WBCDD(x, n, v) (HW_EIM_CSnWCR2_WR(x, n, (HW_EIM_CSnWCR2_RD(x, n) & ~BM_EIM_CSnWCR2_WBCDD) | BF_EIM_CSnWCR2_WBCDD(v)))
/*@}*/

/*******************************************************************************
 * HW_EIM_WCR - EIM Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_EIM_WCR - EIM Configuration Register (RW)
 *
 * Reset value: 0x00000020U
 */
typedef union _hw_eim_wcr
{
    uint32_t U;
    struct _hw_eim_wcr_bitfields
    {
        uint32_t BCM : 1;              /*!< [0]  */
        uint32_t GBCD : 2;             /*!< [2:1]  */
        uint32_t CONT_BCLK_SEL : 1;    /*!< [3] Continuous BCLK select */
        uint32_t INTEN : 1;            /*!< [4]  */
        uint32_t INTPOL : 1;           /*!< [5]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t WDOG_EN : 1;          /*!< [8]  */
        uint32_t WDOG_LIMIT : 2;       /*!< [10:9]  */
        uint32_t FRUN_ACLK_EN : 1;     /*!< [11] Free run ACLK enable */
        uint32_t RESERVED1 : 20;       /*!< [31:12] Reserved */
    } B;
} hw_eim_wcr_t;

/*!
 * @name Constants and macros for entire EIM_WCR register
 */
/*@{*/
#define HW_EIM_WCR_ADDR(x)       ((uintptr_t)(x) + 0x90U)

#define HW_EIM_WCR(x)            (*(__IO hw_eim_wcr_t *) HW_EIM_WCR_ADDR(x))
#define HW_EIM_WCR_RD(x)         (HW_EIM_WCR(x).U)
#define HW_EIM_WCR_WR(x, v)      (HW_EIM_WCR(x).U = (v))
#define HW_EIM_WCR_SET(x, v)     (HW_EIM_WCR_WR(x, HW_EIM_WCR_RD(x) |  (v)))
#define HW_EIM_WCR_CLR(x, v)     (HW_EIM_WCR_WR(x, HW_EIM_WCR_RD(x) & ~(v)))
#define HW_EIM_WCR_TOG(x, v)     (HW_EIM_WCR_WR(x, HW_EIM_WCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_WCR bitfields
 */

/*!
 * @name Register EIM_WCR, field BCM[0] (RW)
 *
 * Burst Clock Mode. This bit selects the burst clock mode of operation. It is
 * used for system debug mode. BCM is cleared by a hardware reset. The BCLK
 * frequency in this mode is according to GBCD bit field. The BCLK phase is opposite to
 * the EIM clock in this mode if GBCD is 0. This bit should be used only in
 * async. accesses. No sync access can be executed if this bit is set. When this bit
 * is set bcd field shouldn't be configured to 0.
 *
 * Values:
 * - 0 - The burst clock runs only when accessing a chip select range with the
 *     SWR/SRD bits set. When the burst clock is not running it remains in a logic
 *     0 state. When the burst clock is running it is configured by the BCD and
 *     BCS bit fields in the chip select Configuration Register.
 * - 1 - The burst clock runs whenever ACLK is active (independent of chip
 *     select configuration)
 */
/*@{*/
#define BP_EIM_WCR_BCM       (0U)          /*!< Bit position for EIM_WCR_BCM. */
#define BM_EIM_WCR_BCM       (0x00000001U) /*!< Bit mask for EIM_WCR_BCM. */
#define BS_EIM_WCR_BCM       (1U)          /*!< Bit field size in bits for EIM_WCR_BCM. */

/*! @brief Read current value of the EIM_WCR_BCM field. */
#define BR_EIM_WCR_BCM(x)    (HW_EIM_WCR(x).B.BCM)

/*! @brief Format value for bitfield EIM_WCR_BCM. */
#define BF_EIM_WCR_BCM(v)    ((uint32_t)((uint32_t)(v) << BP_EIM_WCR_BCM) & BM_EIM_WCR_BCM)

/*! @brief Set the BCM field to a new value. */
#define BW_EIM_WCR_BCM(x, v) (HW_EIM_WCR_WR(x, (HW_EIM_WCR_RD(x) & ~BM_EIM_WCR_BCM) | BF_EIM_WCR_BCM(v)))
/*@}*/

/*!
 * @name Register EIM_WCR, field GBCD[2:1] (RW)
 *
 * General Burst Clock Divisor. When BCM bit is set, this bit field contains the
 * value used to program the burst clock divisor for Continuous BCLK generation.
 * The other BCD bit fields for each chip select are ignored. It is used to
 * divide the internal AXI bus frequency. When BCM=0 GBCD bit field has no influence.
 * GBCD is cleared by a hardware reset.
 *
 * Values:
 * - 00 - Divide EIM clock by 1
 * - 01 - Divide EIM clock by 2
 * - 10 - Divide EIM clock by 3
 * - 11 - Divide EIM clock by 4
 */
/*@{*/
#define BP_EIM_WCR_GBCD      (1U)          /*!< Bit position for EIM_WCR_GBCD. */
#define BM_EIM_WCR_GBCD      (0x00000006U) /*!< Bit mask for EIM_WCR_GBCD. */
#define BS_EIM_WCR_GBCD      (2U)          /*!< Bit field size in bits for EIM_WCR_GBCD. */

/*! @brief Read current value of the EIM_WCR_GBCD field. */
#define BR_EIM_WCR_GBCD(x)   (HW_EIM_WCR(x).B.GBCD)

/*! @brief Format value for bitfield EIM_WCR_GBCD. */
#define BF_EIM_WCR_GBCD(v)   ((uint32_t)((uint32_t)(v) << BP_EIM_WCR_GBCD) & BM_EIM_WCR_GBCD)

/*! @brief Set the GBCD field to a new value. */
#define BW_EIM_WCR_GBCD(x, v) (HW_EIM_WCR_WR(x, (HW_EIM_WCR_RD(x) & ~BM_EIM_WCR_GBCD) | BF_EIM_WCR_GBCD(v)))
/*@}*/

/*!
 * @name Register EIM_WCR, field CONT_BCLK_SEL[3] (RW)
 *
 * When this bit is set BCLK pin output continuous clock. Otherwize, BCLK will
 * output clock only when nesserary.
 *
 * Values:
 * - 0 - BCLK When nesserary
 * - 1 - BCLK Continuous
 */
/*@{*/
#define BP_EIM_WCR_CONT_BCLK_SEL (3U)      /*!< Bit position for EIM_WCR_CONT_BCLK_SEL. */
#define BM_EIM_WCR_CONT_BCLK_SEL (0x00000008U) /*!< Bit mask for EIM_WCR_CONT_BCLK_SEL. */
#define BS_EIM_WCR_CONT_BCLK_SEL (1U)      /*!< Bit field size in bits for EIM_WCR_CONT_BCLK_SEL. */

/*! @brief Read current value of the EIM_WCR_CONT_BCLK_SEL field. */
#define BR_EIM_WCR_CONT_BCLK_SEL(x) (HW_EIM_WCR(x).B.CONT_BCLK_SEL)

/*! @brief Format value for bitfield EIM_WCR_CONT_BCLK_SEL. */
#define BF_EIM_WCR_CONT_BCLK_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_WCR_CONT_BCLK_SEL) & BM_EIM_WCR_CONT_BCLK_SEL)

/*! @brief Set the CONT_BCLK_SEL field to a new value. */
#define BW_EIM_WCR_CONT_BCLK_SEL(x, v) (HW_EIM_WCR_WR(x, (HW_EIM_WCR_RD(x) & ~BM_EIM_WCR_CONT_BCLK_SEL) | BF_EIM_WCR_CONT_BCLK_SEL(v)))
/*@}*/

/*!
 * @name Register EIM_WCR, field INTEN[4] (RW)
 *
 * Interrupt Enable. When this bit is set the External signal RDY_INT as active
 * interrupt. When interrupt occurs, INT bit at the WCR will be set and t
 * EIM_EXT_INT signal will be asserted correspondingly. This bit is cleared by a
 * hardware reset.
 *
 * Values:
 * - 0 - External interrupt Disable
 * - 1 - External interrupt Enable
 */
/*@{*/
#define BP_EIM_WCR_INTEN     (4U)          /*!< Bit position for EIM_WCR_INTEN. */
#define BM_EIM_WCR_INTEN     (0x00000010U) /*!< Bit mask for EIM_WCR_INTEN. */
#define BS_EIM_WCR_INTEN     (1U)          /*!< Bit field size in bits for EIM_WCR_INTEN. */

/*! @brief Read current value of the EIM_WCR_INTEN field. */
#define BR_EIM_WCR_INTEN(x)  (HW_EIM_WCR(x).B.INTEN)

/*! @brief Format value for bitfield EIM_WCR_INTEN. */
#define BF_EIM_WCR_INTEN(v)  ((uint32_t)((uint32_t)(v) << BP_EIM_WCR_INTEN) & BM_EIM_WCR_INTEN)

/*! @brief Set the INTEN field to a new value. */
#define BW_EIM_WCR_INTEN(x, v) (HW_EIM_WCR_WR(x, (HW_EIM_WCR_RD(x) & ~BM_EIM_WCR_INTEN) | BF_EIM_WCR_INTEN(v)))
/*@}*/

/*!
 * @name Register EIM_WCR, field INTPOL[5] (RW)
 *
 * Interrupt Polarity. This bit field determines the polarity of the external
 * device interrupt.
 *
 * Values:
 * - 0 - External interrupt polarity is active low
 * - 1 - External interrupt polarity is active high
 */
/*@{*/
#define BP_EIM_WCR_INTPOL    (5U)          /*!< Bit position for EIM_WCR_INTPOL. */
#define BM_EIM_WCR_INTPOL    (0x00000020U) /*!< Bit mask for EIM_WCR_INTPOL. */
#define BS_EIM_WCR_INTPOL    (1U)          /*!< Bit field size in bits for EIM_WCR_INTPOL. */

/*! @brief Read current value of the EIM_WCR_INTPOL field. */
#define BR_EIM_WCR_INTPOL(x) (HW_EIM_WCR(x).B.INTPOL)

/*! @brief Format value for bitfield EIM_WCR_INTPOL. */
#define BF_EIM_WCR_INTPOL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_WCR_INTPOL) & BM_EIM_WCR_INTPOL)

/*! @brief Set the INTPOL field to a new value. */
#define BW_EIM_WCR_INTPOL(x, v) (HW_EIM_WCR_WR(x, (HW_EIM_WCR_RD(x) & ~BM_EIM_WCR_INTPOL) | BF_EIM_WCR_INTPOL(v)))
/*@}*/

/*!
 * @name Register EIM_WCR, field WDOG_EN[8] (RW)
 *
 * Memory WDOG enable. This bit controls the operation of the wdog counter that
 * terminates the EIM access.
 *
 * Values:
 * - 0 - Memory WDOG is Disabled
 * - 1 - Memory WDOG is Enabled
 */
/*@{*/
#define BP_EIM_WCR_WDOG_EN   (8U)          /*!< Bit position for EIM_WCR_WDOG_EN. */
#define BM_EIM_WCR_WDOG_EN   (0x00000100U) /*!< Bit mask for EIM_WCR_WDOG_EN. */
#define BS_EIM_WCR_WDOG_EN   (1U)          /*!< Bit field size in bits for EIM_WCR_WDOG_EN. */

/*! @brief Read current value of the EIM_WCR_WDOG_EN field. */
#define BR_EIM_WCR_WDOG_EN(x) (HW_EIM_WCR(x).B.WDOG_EN)

/*! @brief Format value for bitfield EIM_WCR_WDOG_EN. */
#define BF_EIM_WCR_WDOG_EN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_WCR_WDOG_EN) & BM_EIM_WCR_WDOG_EN)

/*! @brief Set the WDOG_EN field to a new value. */
#define BW_EIM_WCR_WDOG_EN(x, v) (HW_EIM_WCR_WR(x, (HW_EIM_WCR_RD(x) & ~BM_EIM_WCR_WDOG_EN) | BF_EIM_WCR_WDOG_EN(v)))
/*@}*/

/*!
 * @name Register EIM_WCR, field WDOG_LIMIT[10:9] (RW)
 *
 * Memory Watchdog (WDOG) cycle limit. This bit field determines the number of
 * BCLK cycles (ACLK cycles in dtack mode) before the WDOG counter terminates the
 * access and send an error response to the master.
 *
 * Values:
 * - 00 - 128 BCLK cycles
 * - 01 - 256 BCLK cycles
 * - 10 - 512 BCLK cycles
 * - 11 - 1024 BCLK cycles
 */
/*@{*/
#define BP_EIM_WCR_WDOG_LIMIT (9U)         /*!< Bit position for EIM_WCR_WDOG_LIMIT. */
#define BM_EIM_WCR_WDOG_LIMIT (0x00000600U) /*!< Bit mask for EIM_WCR_WDOG_LIMIT. */
#define BS_EIM_WCR_WDOG_LIMIT (2U)         /*!< Bit field size in bits for EIM_WCR_WDOG_LIMIT. */

/*! @brief Read current value of the EIM_WCR_WDOG_LIMIT field. */
#define BR_EIM_WCR_WDOG_LIMIT(x) (HW_EIM_WCR(x).B.WDOG_LIMIT)

/*! @brief Format value for bitfield EIM_WCR_WDOG_LIMIT. */
#define BF_EIM_WCR_WDOG_LIMIT(v) ((uint32_t)((uint32_t)(v) << BP_EIM_WCR_WDOG_LIMIT) & BM_EIM_WCR_WDOG_LIMIT)

/*! @brief Set the WDOG_LIMIT field to a new value. */
#define BW_EIM_WCR_WDOG_LIMIT(x, v) (HW_EIM_WCR_WR(x, (HW_EIM_WCR_RD(x) & ~BM_EIM_WCR_WDOG_LIMIT) | BF_EIM_WCR_WDOG_LIMIT(v)))
/*@}*/

/*!
 * @name Register EIM_WCR, field FRUN_ACLK_EN[11] (RW)
 */
/*@{*/
#define BP_EIM_WCR_FRUN_ACLK_EN (11U)      /*!< Bit position for EIM_WCR_FRUN_ACLK_EN. */
#define BM_EIM_WCR_FRUN_ACLK_EN (0x00000800U) /*!< Bit mask for EIM_WCR_FRUN_ACLK_EN. */
#define BS_EIM_WCR_FRUN_ACLK_EN (1U)       /*!< Bit field size in bits for EIM_WCR_FRUN_ACLK_EN. */

/*! @brief Read current value of the EIM_WCR_FRUN_ACLK_EN field. */
#define BR_EIM_WCR_FRUN_ACLK_EN(x) (HW_EIM_WCR(x).B.FRUN_ACLK_EN)

/*! @brief Format value for bitfield EIM_WCR_FRUN_ACLK_EN. */
#define BF_EIM_WCR_FRUN_ACLK_EN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_WCR_FRUN_ACLK_EN) & BM_EIM_WCR_FRUN_ACLK_EN)

/*! @brief Set the FRUN_ACLK_EN field to a new value. */
#define BW_EIM_WCR_FRUN_ACLK_EN(x, v) (HW_EIM_WCR_WR(x, (HW_EIM_WCR_RD(x) & ~BM_EIM_WCR_FRUN_ACLK_EN) | BF_EIM_WCR_FRUN_ACLK_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_EIM_DCR - DLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_EIM_DCR - DLL Control Register (RW)
 *
 * Reset value: 0x00140000U
 */
typedef union _hw_eim_dcr
{
    uint32_t U;
    struct _hw_eim_dcr_bitfields
    {
        uint32_t DLL_CTRL_ENABLE : 1;  /*!< [0]  */
        uint32_t DLL_CTRL_RESET : 1;   /*!< [1] DLL Reset Bit */
        uint32_t DLL_CTRL_SLV_FORCE_UPD : 1; /*!< [2]  */
        uint32_t DLL_CTRL_SLV_OFFSET_DEC : 1; /*!< [3] Slave Chain Offset
                                        * Decrease */
        uint32_t DLL_CTRL_SLV_OFFSET : 3; /*!< [6:4]  */
        uint32_t DLL_CTRL_GATE_UPDATE : 1; /*!< [7]  */
        uint32_t DLL_CTRL_SLV_OVERRIDE : 1; /*!< [8]  */
        uint32_t DLL_CTRL_SLV_OVERRIDE_VAL : 7; /*!< [15:9]  */
        uint32_t DLL_CTRL_REF_INITIAL_VAL : 7; /*!< [22:16]  */
        uint32_t DLL_CTRL_SLV_UPDATE_INT : 5; /*!< [27:23] Slave DLL Update
                                        * Interval */
        uint32_t DLL_CTRL_REF_UPDATE_INT : 4; /*!< [31:28] Reference DLL
                                        * Update Interval */
    } B;
} hw_eim_dcr_t;

/*!
 * @name Constants and macros for entire EIM_DCR register
 */
/*@{*/
#define HW_EIM_DCR_ADDR(x)       ((uintptr_t)(x) + 0x94U)

#define HW_EIM_DCR(x)            (*(__IO hw_eim_dcr_t *) HW_EIM_DCR_ADDR(x))
#define HW_EIM_DCR_RD(x)         (HW_EIM_DCR(x).U)
#define HW_EIM_DCR_WR(x, v)      (HW_EIM_DCR(x).U = (v))
#define HW_EIM_DCR_SET(x, v)     (HW_EIM_DCR_WR(x, HW_EIM_DCR_RD(x) |  (v)))
#define HW_EIM_DCR_CLR(x, v)     (HW_EIM_DCR_WR(x, HW_EIM_DCR_RD(x) & ~(v)))
#define HW_EIM_DCR_TOG(x, v)     (HW_EIM_DCR_WR(x, HW_EIM_DCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_DCR bitfields
 */

/*!
 * @name Register EIM_DCR, field DLL_CTRL_ENABLE[0] (RW)
 *
 * Set this bit to 1 to enable the DLL and delay chain; otherwise; set to 0 to
 * bypasses DLL. Note that using the slave delay line override feature with
 * SLV_OVERRIDE and SLV_OVERRIDE VAL, the DLL does not need to be enabled
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_ENABLE (0U)    /*!< Bit position for EIM_DCR_DLL_CTRL_ENABLE. */
#define BM_EIM_DCR_DLL_CTRL_ENABLE (0x00000001U) /*!< Bit mask for EIM_DCR_DLL_CTRL_ENABLE. */
#define BS_EIM_DCR_DLL_CTRL_ENABLE (1U)    /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_ENABLE. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_ENABLE field. */
#define BR_EIM_DCR_DLL_CTRL_ENABLE(x) (HW_EIM_DCR(x).B.DLL_CTRL_ENABLE)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_ENABLE. */
#define BF_EIM_DCR_DLL_CTRL_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_ENABLE) & BM_EIM_DCR_DLL_CTRL_ENABLE)

/*! @brief Set the DLL_CTRL_ENABLE field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_ENABLE(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_ENABLE) | BF_EIM_DCR_DLL_CTRL_ENABLE(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_RESET[1] (RW)
 *
 * Setting this bit to 1 force a reset on DLL. This will cause the DLL to lose
 * lock and re-lock. This signal is used by the DLL as edge-sensitive, so in order
 * to create a subsequent reset, RESET must be taken low and then asserted again
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_RESET (1U)     /*!< Bit position for EIM_DCR_DLL_CTRL_RESET. */
#define BM_EIM_DCR_DLL_CTRL_RESET (0x00000002U) /*!< Bit mask for EIM_DCR_DLL_CTRL_RESET. */
#define BS_EIM_DCR_DLL_CTRL_RESET (1U)     /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_RESET. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_RESET field. */
#define BR_EIM_DCR_DLL_CTRL_RESET(x) (HW_EIM_DCR(x).B.DLL_CTRL_RESET)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_RESET. */
#define BF_EIM_DCR_DLL_CTRL_RESET(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_RESET) & BM_EIM_DCR_DLL_CTRL_RESET)

/*! @brief Set the DLL_CTRL_RESET field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_RESET(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_RESET) | BF_EIM_DCR_DLL_CTRL_RESET(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_SLV_FORCE_UPD[2] (RW)
 *
 * Setting this bit to 1, forces the slave delay line to update to the DLL
 * calibrated value immediately. The slave delay line shall update automatically based
 * on the SLV_UPDATE_INT interval or when a DLL lock condition is sensed.
 * Subsequent forcing of the slave-line update can only occur if SLV_FORCE_UP is set
 * back to 0 and then asserted again (edge triggered). Be sure to use it when EIM
 * is idle.
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD (2U) /*!< Bit position for EIM_DCR_DLL_CTRL_SLV_FORCE_UPD. */
#define BM_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD (0x00000004U) /*!< Bit mask for EIM_DCR_DLL_CTRL_SLV_FORCE_UPD. */
#define BS_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD (1U) /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_SLV_FORCE_UPD. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_SLV_FORCE_UPD field. */
#define BR_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD(x) (HW_EIM_DCR(x).B.DLL_CTRL_SLV_FORCE_UPD)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_SLV_FORCE_UPD. */
#define BF_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD) & BM_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD)

/*! @brief Set the DLL_CTRL_SLV_FORCE_UPD field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD) | BF_EIM_DCR_DLL_CTRL_SLV_FORCE_UPD(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_SLV_OFFSET_DEC[3] (RW)
 *
 * Decrease(or increase) the value defined by DLL_CTRL_SLV_OFFSET when
 * calculating DLL_STS_SLV_SEL
 *
 * Values:
 * - 0 - DLL_STS_SLV_SEL = DLL_STS_REF_SEL + DLL_CTRL_SLV_OFFSET
 * - 1 - DLL_STS_SLV_SEL = DLL_STS_REF_SEL - DLL_CTRL_SLV_OFFSET
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC (3U) /*!< Bit position for EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC. */
#define BM_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC (0x00000008U) /*!< Bit mask for EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC. */
#define BS_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC (1U) /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC field. */
#define BR_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC(x) (HW_EIM_DCR(x).B.DLL_CTRL_SLV_OFFSET_DEC)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC. */
#define BF_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC) & BM_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC)

/*! @brief Set the DLL_CTRL_SLV_OFFSET_DEC field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC) | BF_EIM_DCR_DLL_CTRL_SLV_OFFSET_DEC(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_SLV_OFFSET[6:4] (RW)
 *
 * OFFSET value for DLL_CTRL_SLV_SEL
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_SLV_OFFSET (4U) /*!< Bit position for EIM_DCR_DLL_CTRL_SLV_OFFSET. */
#define BM_EIM_DCR_DLL_CTRL_SLV_OFFSET (0x00000070U) /*!< Bit mask for EIM_DCR_DLL_CTRL_SLV_OFFSET. */
#define BS_EIM_DCR_DLL_CTRL_SLV_OFFSET (3U) /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_SLV_OFFSET. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_SLV_OFFSET field. */
#define BR_EIM_DCR_DLL_CTRL_SLV_OFFSET(x) (HW_EIM_DCR(x).B.DLL_CTRL_SLV_OFFSET)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_SLV_OFFSET. */
#define BF_EIM_DCR_DLL_CTRL_SLV_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_SLV_OFFSET) & BM_EIM_DCR_DLL_CTRL_SLV_OFFSET)

/*! @brief Set the DLL_CTRL_SLV_OFFSET field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_SLV_OFFSET(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_SLV_OFFSET) | BF_EIM_DCR_DLL_CTRL_SLV_OFFSET(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_GATE_UPDATE[7] (RW)
 *
 * Set this bit to 1 to force DLL not update from now on. Since when clock
 * exists, glitches might appear during update. This bit is used by software if we met
 * such kind of condition. Set it to 0 to let DLL update automatically
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_GATE_UPDATE (7U) /*!< Bit position for EIM_DCR_DLL_CTRL_GATE_UPDATE. */
#define BM_EIM_DCR_DLL_CTRL_GATE_UPDATE (0x00000080U) /*!< Bit mask for EIM_DCR_DLL_CTRL_GATE_UPDATE. */
#define BS_EIM_DCR_DLL_CTRL_GATE_UPDATE (1U) /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_GATE_UPDATE. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_GATE_UPDATE field. */
#define BR_EIM_DCR_DLL_CTRL_GATE_UPDATE(x) (HW_EIM_DCR(x).B.DLL_CTRL_GATE_UPDATE)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_GATE_UPDATE. */
#define BF_EIM_DCR_DLL_CTRL_GATE_UPDATE(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_GATE_UPDATE) & BM_EIM_DCR_DLL_CTRL_GATE_UPDATE)

/*! @brief Set the DLL_CTRL_GATE_UPDATE field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_GATE_UPDATE(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_GATE_UPDATE) | BF_EIM_DCR_DLL_CTRL_GATE_UPDATE(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_SLV_OVERRIDE[8] (RW)
 *
 * Set this bit to 1 to Enable manual override for slave delay chain using
 * SLV_OVERRIDE_VAL; to set 0 to disable manual override. This feature does not
 * require the DLL to be enabled using the ENABLE bit. In fact to reduce power, if
 * SLV_OVERRIDE is used, it is recommended to disable the DLL with ENABLE=0
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_SLV_OVERRIDE (8U) /*!< Bit position for EIM_DCR_DLL_CTRL_SLV_OVERRIDE. */
#define BM_EIM_DCR_DLL_CTRL_SLV_OVERRIDE (0x00000100U) /*!< Bit mask for EIM_DCR_DLL_CTRL_SLV_OVERRIDE. */
#define BS_EIM_DCR_DLL_CTRL_SLV_OVERRIDE (1U) /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_SLV_OVERRIDE. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_SLV_OVERRIDE field. */
#define BR_EIM_DCR_DLL_CTRL_SLV_OVERRIDE(x) (HW_EIM_DCR(x).B.DLL_CTRL_SLV_OVERRIDE)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_SLV_OVERRIDE. */
#define BF_EIM_DCR_DLL_CTRL_SLV_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_SLV_OVERRIDE) & BM_EIM_DCR_DLL_CTRL_SLV_OVERRIDE)

/*! @brief Set the DLL_CTRL_SLV_OVERRIDE field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_SLV_OVERRIDE(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_SLV_OVERRIDE) | BF_EIM_DCR_DLL_CTRL_SLV_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_SLV_OVERRIDE_VAL[15:9] (RW)
 *
 * When SLV_OVERRIDE=1 This field is used to select 1 of 128 physical taps
 * manually. A value of 0 selects tap 1, and a value of 0x7f selects tap 128.
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL (9U) /*!< Bit position for EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BM_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL (0x0000FE00U) /*!< Bit mask for EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BS_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL (7U) /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL field. */
#define BR_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL(x) (HW_EIM_DCR(x).B.DLL_CTRL_SLV_OVERRIDE_VAL)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BF_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL) & BM_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL)

/*! @brief Set the DLL_CTRL_SLV_OVERRIDE_VAL field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL) | BF_EIM_DCR_DLL_CTRL_SLV_OVERRIDE_VAL(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_REF_INITIAL_VAL[22:16] (RW)
 *
 * This field is used to select the initial value of reference chain before DLL
 * enabled. It's recommended to set the initial value close to the locked value
 * to accelerate the locking.
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL (16U) /*!< Bit position for EIM_DCR_DLL_CTRL_REF_INITIAL_VAL. */
#define BM_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL (0x007F0000U) /*!< Bit mask for EIM_DCR_DLL_CTRL_REF_INITIAL_VAL. */
#define BS_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL (7U) /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_REF_INITIAL_VAL. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_REF_INITIAL_VAL field. */
#define BR_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL(x) (HW_EIM_DCR(x).B.DLL_CTRL_REF_INITIAL_VAL)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_REF_INITIAL_VAL. */
#define BF_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL) & BM_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL)

/*! @brief Set the DLL_CTRL_REF_INITIAL_VAL field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL) | BF_EIM_DCR_DLL_CTRL_REF_INITIAL_VAL(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_SLV_UPDATE_INT[27:23] (RW)
 *
 * If default 0 is used, it means 256 cycles of ref_clock. A value of 0x0f
 * results in 15 cycles and so on. Note that software can always cause an update of
 * the slave-delay line using the SLV_FORCE_UPDATE register. Note that the slave
 * delay line will also update automatically when the reference DLL transitions to
 * a locked state (from an un-locked state).
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT (23U) /*!< Bit position for EIM_DCR_DLL_CTRL_SLV_UPDATE_INT. */
#define BM_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT (0x0F800000U) /*!< Bit mask for EIM_DCR_DLL_CTRL_SLV_UPDATE_INT. */
#define BS_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT (5U) /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_SLV_UPDATE_INT. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_SLV_UPDATE_INT field. */
#define BR_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT(x) (HW_EIM_DCR(x).B.DLL_CTRL_SLV_UPDATE_INT)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_SLV_UPDATE_INT. */
#define BF_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT) & BM_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT)

/*! @brief Set the DLL_CTRL_SLV_UPDATE_INT field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT) | BF_EIM_DCR_DLL_CTRL_SLV_UPDATE_INT(v)))
/*@}*/

/*!
 * @name Register EIM_DCR, field DLL_CTRL_REF_UPDATE_INT[31:28] (RW)
 *
 * DLL control loop update interval. The interval cycle is (2 + REF_UPDATE_INT)
 * * ref_clock. By default, the DLL control loop shall update every two ref_clock
 * cycles. It should be noted that increasing the reference delay-line update
 * interval reduces the ability of the DLL to adjust to fast changes in conditions
 * that may effect the delay (such as voltage and temperature)
 */
/*@{*/
#define BP_EIM_DCR_DLL_CTRL_REF_UPDATE_INT (28U) /*!< Bit position for EIM_DCR_DLL_CTRL_REF_UPDATE_INT. */
#define BM_EIM_DCR_DLL_CTRL_REF_UPDATE_INT (0xF0000000U) /*!< Bit mask for EIM_DCR_DLL_CTRL_REF_UPDATE_INT. */
#define BS_EIM_DCR_DLL_CTRL_REF_UPDATE_INT (4U) /*!< Bit field size in bits for EIM_DCR_DLL_CTRL_REF_UPDATE_INT. */

/*! @brief Read current value of the EIM_DCR_DLL_CTRL_REF_UPDATE_INT field. */
#define BR_EIM_DCR_DLL_CTRL_REF_UPDATE_INT(x) (HW_EIM_DCR(x).B.DLL_CTRL_REF_UPDATE_INT)

/*! @brief Format value for bitfield EIM_DCR_DLL_CTRL_REF_UPDATE_INT. */
#define BF_EIM_DCR_DLL_CTRL_REF_UPDATE_INT(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DCR_DLL_CTRL_REF_UPDATE_INT) & BM_EIM_DCR_DLL_CTRL_REF_UPDATE_INT)

/*! @brief Set the DLL_CTRL_REF_UPDATE_INT field to a new value. */
#define BW_EIM_DCR_DLL_CTRL_REF_UPDATE_INT(x, v) (HW_EIM_DCR_WR(x, (HW_EIM_DCR_RD(x) & ~BM_EIM_DCR_DLL_CTRL_REF_UPDATE_INT) | BF_EIM_DCR_DLL_CTRL_REF_UPDATE_INT(v)))
/*@}*/

/*******************************************************************************
 * HW_EIM_DSR - DLL Status Register
 ******************************************************************************/

/*!
 * @brief HW_EIM_DSR - DLL Status Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_eim_dsr
{
    uint32_t U;
    struct _hw_eim_dsr_bitfields
    {
        uint32_t DLL_STS_SLV_LOCK : 1; /*!< [0]  */
        uint32_t DLL_STS_REF_LOCK : 1; /*!< [1]  */
        uint32_t DLL_STS_SLV_SEL : 7;  /*!< [8:2]  */
        uint32_t DLL_STS_REF_SEL : 7;  /*!< [15:9]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16] Reserved */
    } B;
} hw_eim_dsr_t;

/*!
 * @name Constants and macros for entire EIM_DSR register
 */
/*@{*/
#define HW_EIM_DSR_ADDR(x)       ((uintptr_t)(x) + 0x98U)

#define HW_EIM_DSR(x)            (*(__IO hw_eim_dsr_t *) HW_EIM_DSR_ADDR(x))
#define HW_EIM_DSR_RD(x)         (HW_EIM_DSR(x).U)
#define HW_EIM_DSR_WR(x, v)      (HW_EIM_DSR(x).U = (v))
#define HW_EIM_DSR_SET(x, v)     (HW_EIM_DSR_WR(x, HW_EIM_DSR_RD(x) |  (v)))
#define HW_EIM_DSR_CLR(x, v)     (HW_EIM_DSR_WR(x, HW_EIM_DSR_RD(x) & ~(v)))
#define HW_EIM_DSR_TOG(x, v)     (HW_EIM_DSR_WR(x, HW_EIM_DSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_DSR bitfields
 */

/*!
 * @name Register EIM_DSR, field DLL_STS_SLV_LOCK[0] (RW)
 *
 * Slave delay-line lock status. This signifies that a valid delay has been set
 * to the slave-delay line and that the slave-delay line is implementing the
 * programmed delay value
 */
/*@{*/
#define BP_EIM_DSR_DLL_STS_SLV_LOCK (0U)   /*!< Bit position for EIM_DSR_DLL_STS_SLV_LOCK. */
#define BM_EIM_DSR_DLL_STS_SLV_LOCK (0x00000001U) /*!< Bit mask for EIM_DSR_DLL_STS_SLV_LOCK. */
#define BS_EIM_DSR_DLL_STS_SLV_LOCK (1U)   /*!< Bit field size in bits for EIM_DSR_DLL_STS_SLV_LOCK. */

/*! @brief Read current value of the EIM_DSR_DLL_STS_SLV_LOCK field. */
#define BR_EIM_DSR_DLL_STS_SLV_LOCK(x) (HW_EIM_DSR(x).B.DLL_STS_SLV_LOCK)

/*! @brief Format value for bitfield EIM_DSR_DLL_STS_SLV_LOCK. */
#define BF_EIM_DSR_DLL_STS_SLV_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DSR_DLL_STS_SLV_LOCK) & BM_EIM_DSR_DLL_STS_SLV_LOCK)

/*! @brief Set the DLL_STS_SLV_LOCK field to a new value. */
#define BW_EIM_DSR_DLL_STS_SLV_LOCK(x, v) (HW_EIM_DSR_WR(x, (HW_EIM_DSR_RD(x) & ~BM_EIM_DSR_DLL_STS_SLV_LOCK) | BF_EIM_DSR_DLL_STS_SLV_LOCK(v)))
/*@}*/

/*!
 * @name Register EIM_DSR, field DLL_STS_REF_LOCK[1] (RW)
 *
 * Reference DLL lock status. This signifies that the DLL has detected and
 * locked to feedback BCLK, allowing the slave delay-line to perform programmed clock
 * delays
 */
/*@{*/
#define BP_EIM_DSR_DLL_STS_REF_LOCK (1U)   /*!< Bit position for EIM_DSR_DLL_STS_REF_LOCK. */
#define BM_EIM_DSR_DLL_STS_REF_LOCK (0x00000002U) /*!< Bit mask for EIM_DSR_DLL_STS_REF_LOCK. */
#define BS_EIM_DSR_DLL_STS_REF_LOCK (1U)   /*!< Bit field size in bits for EIM_DSR_DLL_STS_REF_LOCK. */

/*! @brief Read current value of the EIM_DSR_DLL_STS_REF_LOCK field. */
#define BR_EIM_DSR_DLL_STS_REF_LOCK(x) (HW_EIM_DSR(x).B.DLL_STS_REF_LOCK)

/*! @brief Format value for bitfield EIM_DSR_DLL_STS_REF_LOCK. */
#define BF_EIM_DSR_DLL_STS_REF_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DSR_DLL_STS_REF_LOCK) & BM_EIM_DSR_DLL_STS_REF_LOCK)

/*! @brief Set the DLL_STS_REF_LOCK field to a new value. */
#define BW_EIM_DSR_DLL_STS_REF_LOCK(x, v) (HW_EIM_DSR_WR(x, (HW_EIM_DSR_RD(x) & ~BM_EIM_DSR_DLL_STS_REF_LOCK) | BF_EIM_DSR_DLL_STS_REF_LOCK(v)))
/*@}*/

/*!
 * @name Register EIM_DSR, field DLL_STS_SLV_SEL[8:2] (RW)
 *
 * Slave delay line select status. This is the instant value generated from
 * reference chain. Since only when ref_lock is detected can the reference chain get
 * updated, this value should be the right value next be update to the slave line
 * when reference is locked.
 */
/*@{*/
#define BP_EIM_DSR_DLL_STS_SLV_SEL (2U)    /*!< Bit position for EIM_DSR_DLL_STS_SLV_SEL. */
#define BM_EIM_DSR_DLL_STS_SLV_SEL (0x000001FCU) /*!< Bit mask for EIM_DSR_DLL_STS_SLV_SEL. */
#define BS_EIM_DSR_DLL_STS_SLV_SEL (7U)    /*!< Bit field size in bits for EIM_DSR_DLL_STS_SLV_SEL. */

/*! @brief Read current value of the EIM_DSR_DLL_STS_SLV_SEL field. */
#define BR_EIM_DSR_DLL_STS_SLV_SEL(x) (HW_EIM_DSR(x).B.DLL_STS_SLV_SEL)

/*! @brief Format value for bitfield EIM_DSR_DLL_STS_SLV_SEL. */
#define BF_EIM_DSR_DLL_STS_SLV_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DSR_DLL_STS_SLV_SEL) & BM_EIM_DSR_DLL_STS_SLV_SEL)

/*! @brief Set the DLL_STS_SLV_SEL field to a new value. */
#define BW_EIM_DSR_DLL_STS_SLV_SEL(x, v) (HW_EIM_DSR_WR(x, (HW_EIM_DSR_RD(x) & ~BM_EIM_DSR_DLL_STS_SLV_SEL) | BF_EIM_DSR_DLL_STS_SLV_SEL(v)))
/*@}*/

/*!
 * @name Register EIM_DSR, field DLL_STS_REF_SEL[15:9] (RW)
 *
 * Reference delay line select taps. Be noted this is encoded by 7 bits for
 * 127taps.
 */
/*@{*/
#define BP_EIM_DSR_DLL_STS_REF_SEL (9U)    /*!< Bit position for EIM_DSR_DLL_STS_REF_SEL. */
#define BM_EIM_DSR_DLL_STS_REF_SEL (0x0000FE00U) /*!< Bit mask for EIM_DSR_DLL_STS_REF_SEL. */
#define BS_EIM_DSR_DLL_STS_REF_SEL (7U)    /*!< Bit field size in bits for EIM_DSR_DLL_STS_REF_SEL. */

/*! @brief Read current value of the EIM_DSR_DLL_STS_REF_SEL field. */
#define BR_EIM_DSR_DLL_STS_REF_SEL(x) (HW_EIM_DSR(x).B.DLL_STS_REF_SEL)

/*! @brief Format value for bitfield EIM_DSR_DLL_STS_REF_SEL. */
#define BF_EIM_DSR_DLL_STS_REF_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EIM_DSR_DLL_STS_REF_SEL) & BM_EIM_DSR_DLL_STS_REF_SEL)

/*! @brief Set the DLL_STS_REF_SEL field to a new value. */
#define BW_EIM_DSR_DLL_STS_REF_SEL(x, v) (HW_EIM_DSR_WR(x, (HW_EIM_DSR_RD(x) & ~BM_EIM_DSR_DLL_STS_REF_SEL) | BF_EIM_DSR_DLL_STS_REF_SEL(v)))
/*@}*/

/*******************************************************************************
 * HW_EIM_WIAR - EIM IP Access Register
 ******************************************************************************/

/*!
 * @brief HW_EIM_WIAR - EIM IP Access Register (RW)
 *
 * Reset value: 0x00000010U
 */
typedef union _hw_eim_wiar
{
    uint32_t U;
    struct _hw_eim_wiar_bitfields
    {
        uint32_t IPS_REQ : 1;          /*!< [0]  */
        uint32_t IPS_ACK : 1;          /*!< [1]  */
        uint32_t INT : 1;              /*!< [2]  */
        uint32_t ERRST : 1;            /*!< [3]  */
        uint32_t ACLK_EN : 1;          /*!< [4]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_eim_wiar_t;

/*!
 * @name Constants and macros for entire EIM_WIAR register
 */
/*@{*/
#define HW_EIM_WIAR_ADDR(x)      ((uintptr_t)(x) + 0x9CU)

#define HW_EIM_WIAR(x)           (*(__IO hw_eim_wiar_t *) HW_EIM_WIAR_ADDR(x))
#define HW_EIM_WIAR_RD(x)        (HW_EIM_WIAR(x).U)
#define HW_EIM_WIAR_WR(x, v)     (HW_EIM_WIAR(x).U = (v))
#define HW_EIM_WIAR_SET(x, v)    (HW_EIM_WIAR_WR(x, HW_EIM_WIAR_RD(x) |  (v)))
#define HW_EIM_WIAR_CLR(x, v)    (HW_EIM_WIAR_WR(x, HW_EIM_WIAR_RD(x) & ~(v)))
#define HW_EIM_WIAR_TOG(x, v)    (HW_EIM_WIAR_WR(x, HW_EIM_WIAR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_WIAR bitfields
 */

/*!
 * @name Register EIM_WIAR, field IPS_REQ[0] (RW)
 *
 * IPS request. The Master requests to access one of the IPS registers.Dutring
 * such access the EIM should not preform any AXI/memory accesses. The EIM
 * finishes the AXI accesses that already starts and asserts the IPS_ACK bit.
 *
 * Values:
 * - 0 - No Master requests ips access
 * - 1 - Master requests ips access
 */
/*@{*/
#define BP_EIM_WIAR_IPS_REQ  (0U)          /*!< Bit position for EIM_WIAR_IPS_REQ. */
#define BM_EIM_WIAR_IPS_REQ  (0x00000001U) /*!< Bit mask for EIM_WIAR_IPS_REQ. */
#define BS_EIM_WIAR_IPS_REQ  (1U)          /*!< Bit field size in bits for EIM_WIAR_IPS_REQ. */

/*! @brief Read current value of the EIM_WIAR_IPS_REQ field. */
#define BR_EIM_WIAR_IPS_REQ(x) (HW_EIM_WIAR(x).B.IPS_REQ)

/*! @brief Format value for bitfield EIM_WIAR_IPS_REQ. */
#define BF_EIM_WIAR_IPS_REQ(v) ((uint32_t)((uint32_t)(v) << BP_EIM_WIAR_IPS_REQ) & BM_EIM_WIAR_IPS_REQ)

/*! @brief Set the IPS_REQ field to a new value. */
#define BW_EIM_WIAR_IPS_REQ(x, v) (HW_EIM_WIAR_WR(x, (HW_EIM_WIAR_RD(x) & ~BM_EIM_WIAR_IPS_REQ) | BF_EIM_WIAR_IPS_REQ(v)))
/*@}*/

/*!
 * @name Register EIM_WIAR, field IPS_ACK[1] (RW)
 *
 * IPS ACK. The EIM is ready for ips access. There is no active AXI access and
 * no new AXI access is accepted till this bit is cleared. This bit is cleared by
 * the master after it completes the ips accesses.
 *
 * Values:
 * - 0 - Master cannot access ips.
 * - 1 - Master can access ips.
 */
/*@{*/
#define BP_EIM_WIAR_IPS_ACK  (1U)          /*!< Bit position for EIM_WIAR_IPS_ACK. */
#define BM_EIM_WIAR_IPS_ACK  (0x00000002U) /*!< Bit mask for EIM_WIAR_IPS_ACK. */
#define BS_EIM_WIAR_IPS_ACK  (1U)          /*!< Bit field size in bits for EIM_WIAR_IPS_ACK. */

/*! @brief Read current value of the EIM_WIAR_IPS_ACK field. */
#define BR_EIM_WIAR_IPS_ACK(x) (HW_EIM_WIAR(x).B.IPS_ACK)

/*! @brief Format value for bitfield EIM_WIAR_IPS_ACK. */
#define BF_EIM_WIAR_IPS_ACK(v) ((uint32_t)((uint32_t)(v) << BP_EIM_WIAR_IPS_ACK) & BM_EIM_WIAR_IPS_ACK)

/*! @brief Set the IPS_ACK field to a new value. */
#define BW_EIM_WIAR_IPS_ACK(x, v) (HW_EIM_WIAR_WR(x, (HW_EIM_WIAR_RD(x) & ~BM_EIM_WIAR_IPS_ACK) | BF_EIM_WIAR_IPS_ACK(v)))
/*@}*/

/*!
 * @name Register EIM_WIAR, field INT[2] (RW)
 *
 * Interrupt. This bit indicates interrupt assertion by an external device
 * according to RDY_INT signal. When polling this bit, INT=0 indicates interrupt not
 * occurred and INT=1 indicates assertion of the external device interrupt. This
 * bit is cleared by a hardware reset.
 */
/*@{*/
#define BP_EIM_WIAR_INT      (2U)          /*!< Bit position for EIM_WIAR_INT. */
#define BM_EIM_WIAR_INT      (0x00000004U) /*!< Bit mask for EIM_WIAR_INT. */
#define BS_EIM_WIAR_INT      (1U)          /*!< Bit field size in bits for EIM_WIAR_INT. */

/*! @brief Read current value of the EIM_WIAR_INT field. */
#define BR_EIM_WIAR_INT(x)   (HW_EIM_WIAR(x).B.INT)

/*! @brief Format value for bitfield EIM_WIAR_INT. */
#define BF_EIM_WIAR_INT(v)   ((uint32_t)((uint32_t)(v) << BP_EIM_WIAR_INT) & BM_EIM_WIAR_INT)

/*! @brief Set the INT field to a new value. */
#define BW_EIM_WIAR_INT(x, v) (HW_EIM_WIAR_WR(x, (HW_EIM_WIAR_RD(x) & ~BM_EIM_WIAR_INT) | BF_EIM_WIAR_INT(v)))
/*@}*/

/*!
 * @name Register EIM_WIAR, field ERRST[3] (RW)
 *
 * READY After Reset. This bit controls the initial ready/busy status for
 * external devices on CS0 immediately after hardware reset. This is a sticky bit which
 * is cleared once the RDY_INT signal is asserted by the external device. When
 * ERRST = 1 the first fetch access from EIM to the external device located on CS0
 * will be pending until RDY_INT signal indicates that the external device is
 * ready, then EIM will execute the access. Reset value for ERRST is EIM_BOOT[4].
 *
 * Values:
 * - 0 - RDY_INT After Reset Disable
 * - 1 - RDY_INT After Reset Enable
 */
/*@{*/
#define BP_EIM_WIAR_ERRST    (3U)          /*!< Bit position for EIM_WIAR_ERRST. */
#define BM_EIM_WIAR_ERRST    (0x00000008U) /*!< Bit mask for EIM_WIAR_ERRST. */
#define BS_EIM_WIAR_ERRST    (1U)          /*!< Bit field size in bits for EIM_WIAR_ERRST. */

/*! @brief Read current value of the EIM_WIAR_ERRST field. */
#define BR_EIM_WIAR_ERRST(x) (HW_EIM_WIAR(x).B.ERRST)

/*! @brief Format value for bitfield EIM_WIAR_ERRST. */
#define BF_EIM_WIAR_ERRST(v) ((uint32_t)((uint32_t)(v) << BP_EIM_WIAR_ERRST) & BM_EIM_WIAR_ERRST)

/*! @brief Set the ERRST field to a new value. */
#define BW_EIM_WIAR_ERRST(x, v) (HW_EIM_WIAR_WR(x, (HW_EIM_WIAR_RD(x) & ~BM_EIM_WIAR_ERRST) | BF_EIM_WIAR_ERRST(v)))
/*@}*/

/*!
 * @name Register EIM_WIAR, field ACLK_EN[4] (RW)
 *
 * ACLK enable. This bit gates the ACLK for the EIM except from FFs that get
 * ipg_aclk_s. After reset ACLK is enabled.
 *
 * Values:
 * - 0 - ACLK is disabled
 * - 1 - ACLK is enabled
 */
/*@{*/
#define BP_EIM_WIAR_ACLK_EN  (4U)          /*!< Bit position for EIM_WIAR_ACLK_EN. */
#define BM_EIM_WIAR_ACLK_EN  (0x00000010U) /*!< Bit mask for EIM_WIAR_ACLK_EN. */
#define BS_EIM_WIAR_ACLK_EN  (1U)          /*!< Bit field size in bits for EIM_WIAR_ACLK_EN. */

/*! @brief Read current value of the EIM_WIAR_ACLK_EN field. */
#define BR_EIM_WIAR_ACLK_EN(x) (HW_EIM_WIAR(x).B.ACLK_EN)

/*! @brief Format value for bitfield EIM_WIAR_ACLK_EN. */
#define BF_EIM_WIAR_ACLK_EN(v) ((uint32_t)((uint32_t)(v) << BP_EIM_WIAR_ACLK_EN) & BM_EIM_WIAR_ACLK_EN)

/*! @brief Set the ACLK_EN field to a new value. */
#define BW_EIM_WIAR_ACLK_EN(x, v) (HW_EIM_WIAR_WR(x, (HW_EIM_WIAR_RD(x) & ~BM_EIM_WIAR_ACLK_EN) | BF_EIM_WIAR_ACLK_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_EIM_EAR - Error Address Register
 ******************************************************************************/

/*!
 * @brief HW_EIM_EAR - Error Address Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_eim_ear
{
    uint32_t U;
    struct _hw_eim_ear_bitfields
    {
        uint32_t Error_ADDR : 32;      /*!< [31:0]  */
    } B;
} hw_eim_ear_t;

/*!
 * @name Constants and macros for entire EIM_EAR register
 */
/*@{*/
#define HW_EIM_EAR_ADDR(x)       ((uintptr_t)(x) + 0xA0U)

#define HW_EIM_EAR(x)            (*(__IO hw_eim_ear_t *) HW_EIM_EAR_ADDR(x))
#define HW_EIM_EAR_RD(x)         (HW_EIM_EAR(x).U)
#define HW_EIM_EAR_WR(x, v)      (HW_EIM_EAR(x).U = (v))
#define HW_EIM_EAR_SET(x, v)     (HW_EIM_EAR_WR(x, HW_EIM_EAR_RD(x) |  (v)))
#define HW_EIM_EAR_CLR(x, v)     (HW_EIM_EAR_WR(x, HW_EIM_EAR_RD(x) & ~(v)))
#define HW_EIM_EAR_TOG(x, v)     (HW_EIM_EAR_WR(x, HW_EIM_EAR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EIM_EAR bitfields
 */

/*!
 * @name Register EIM_EAR, field Error_ADDR[31:0] (RW)
 *
 * Error Address. This bit field holds the AXI address of the last access that
 * caused error. This register is read only register.
 */
/*@{*/
#define BP_EIM_EAR_Error_ADDR (0U)         /*!< Bit position for EIM_EAR_Error_ADDR. */
#define BM_EIM_EAR_Error_ADDR (0xFFFFFFFFU) /*!< Bit mask for EIM_EAR_Error_ADDR. */
#define BS_EIM_EAR_Error_ADDR (32U)        /*!< Bit field size in bits for EIM_EAR_Error_ADDR. */

/*! @brief Read current value of the EIM_EAR_Error_ADDR field. */
#define BR_EIM_EAR_Error_ADDR(x) (HW_EIM_EAR(x).U)

/*! @brief Format value for bitfield EIM_EAR_Error_ADDR. */
#define BF_EIM_EAR_Error_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_EIM_EAR_Error_ADDR) & BM_EIM_EAR_Error_ADDR)

/*! @brief Set the Error_ADDR field to a new value. */
#define BW_EIM_EAR_Error_ADDR(x, v) (HW_EIM_EAR_WR(x, v))
/*@}*/

/*******************************************************************************
 * hw_eim_t - module struct
 ******************************************************************************/
/*!
 * @brief All EIM module registers.
 */
#pragma pack(1)
typedef struct _hw_eim
{
    struct {
        __IO hw_eim_csngcr1_t CSnGCR1;     /*!< [0x0] Chip Select n General Configuration Register 1 */
        __IO hw_eim_csngcr2_t CSnGCR2;     /*!< [0x4] Chip Select n General Configuration Register 2 */
        __IO hw_eim_csnrcr1_t CSnRCR1;     /*!< [0x8] Chip Select n Read Configuration Register 1 */
        __IO hw_eim_csnrcr2_t CSnRCR2;     /*!< [0xC] Chip Select n Read Configuration Register 2 */
        __IO hw_eim_csnwcr1_t CSnWCR1;     /*!< [0x10] Chip Select n Write Configuration Register 1 */
        __IO hw_eim_csnwcr2_t CSnWCR2;     /*!< [0x14] Chip Select n Write Configuration Register 2 */
    } CSCR[6];
    __IO hw_eim_wcr_t WCR;                 /*!< [0x90] EIM Configuration Register */
    __IO hw_eim_dcr_t DCR;                 /*!< [0x94] DLL Control Register */
    __IO hw_eim_dsr_t DSR;                 /*!< [0x98] DLL Status Register */
    __IO hw_eim_wiar_t WIAR;               /*!< [0x9C] EIM IP Access Register */
    __IO hw_eim_ear_t EAR;                 /*!< [0xA0] Error Address Register */
} hw_eim_t;
#pragma pack()

/*! @brief Macro to access all EIM registers. */
/*! @param x EIM module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_EIM_REGS(EIM_BASE)</code>. */
#define HW_EIM_REGS(x) (*(hw_eim_t *)(x))

/*
 * iMX7D ENET
 *
 * Ethernet MAC (ENET)
 *
 * Registers defined in this header file:
 * - HW_ENET_EIR - Interrupt Event Register
 * - HW_ENET_EIMR - Interrupt Mask Register
 * - HW_ENET_RDAR - Receive Descriptor Active Register - Ring 0
 * - HW_ENET_TDAR - Transmit Descriptor Active Register - Ring 0
 * - HW_ENET_ECR - Ethernet Control Register
 * - HW_ENET_MMFR - MII Management Frame Register
 * - HW_ENET_MSCR - MII Speed Control Register
 * - HW_ENET_MIBC - MIB Control Register
 * - HW_ENET_RCR - Receive Control Register
 * - HW_ENET_TCR - Transmit Control Register
 * - HW_ENET_PALR - Physical Address Lower Register
 * - HW_ENET_PAUR - Physical Address Upper Register
 * - HW_ENET_OPD - Opcode/Pause Duration Register
 * - HW_ENET_TXICn - Transmit Interrupt Coalescing Register
 * - HW_ENET_RXICn - Receive Interrupt Coalescing Register
 * - HW_ENET_IAUR - Descriptor Individual Upper Address Register
 * - HW_ENET_IALR - Descriptor Individual Lower Address Register
 * - HW_ENET_GAUR - Descriptor Group Upper Address Register
 * - HW_ENET_GALR - Descriptor Group Lower Address Register
 * - HW_ENET_TFWR - Transmit FIFO Watermark Register
 * - HW_ENET_RDSR1 - Receive Descriptor Ring 1 Start Register
 * - HW_ENET_TDSR1 - Transmit Buffer Descriptor Ring 1 Start Register
 * - HW_ENET_MRBR1 - Maximum Receive Buffer Size Register - Ring 1
 * - HW_ENET_RDSR2 - Receive Descriptor Ring 2 Start Register
 * - HW_ENET_TDSR2 - Transmit Buffer Descriptor Ring 2 Start Register
 * - HW_ENET_MRBR2 - Maximum Receive Buffer Size Register - Ring 2
 * - HW_ENET_RDSR - Receive Descriptor Ring 0 Start Register
 * - HW_ENET_TDSR - Transmit Buffer Descriptor Ring 0 Start Register
 * - HW_ENET_MRBR - Maximum Receive Buffer Size Register - Ring 0
 * - HW_ENET_RSFL - Receive FIFO Section Full Threshold
 * - HW_ENET_RSEM - Receive FIFO Section Empty Threshold
 * - HW_ENET_RAEM - Receive FIFO Almost Empty Threshold
 * - HW_ENET_RAFL - Receive FIFO Almost Full Threshold
 * - HW_ENET_TSEM - Transmit FIFO Section Empty Threshold
 * - HW_ENET_TAEM - Transmit FIFO Almost Empty Threshold
 * - HW_ENET_TAFL - Transmit FIFO Almost Full Threshold
 * - HW_ENET_TIPG - Transmit Inter-Packet Gap
 * - HW_ENET_FTRL - Frame Truncation Length
 * - HW_ENET_TACC - Transmit Accelerator Function Configuration
 * - HW_ENET_RACC - Receive Accelerator Function Configuration
 * - HW_ENET_RCMR1 - Receive Classification Match Register for Class n
 * - HW_ENET_RCMR2 - Receive Classification Match Register for Class n
 * - HW_ENET_DMA1CFG - DMA Class Based Configuration
 * - HW_ENET_DMA2CFG - DMA Class Based Configuration
 * - HW_ENET_RDAR1 - Receive Descriptor Active Register - Ring 1
 * - HW_ENET_TDAR1 - Transmit Descriptor Active Register - Ring 1
 * - HW_ENET_RDAR2 - Receive Descriptor Active Register - Ring 2
 * - HW_ENET_TDAR2 - Transmit Descriptor Active Register - Ring 2
 * - HW_ENET_QOS - QOS Scheme
 * - HW_ENET_RMON_T_DROP - Reserved Statistic Register
 * - HW_ENET_RMON_T_PACKETS - Tx Packet Count Statistic Register
 * - HW_ENET_RMON_T_BC_PKT - Tx Broadcast Packets Statistic Register
 * - HW_ENET_RMON_T_MC_PKT - Tx Multicast Packets Statistic Register
 * - HW_ENET_RMON_T_CRC_ALIGN - Tx Packets with CRC/Align Error Statistic Register
 * - HW_ENET_RMON_T_UNDERSIZE - Tx Packets Less Than Bytes and Good CRC Statistic Register
 * - HW_ENET_RMON_T_OVERSIZE - Tx Packets GT MAX_FL bytes and Good CRC Statistic Register
 * - HW_ENET_RMON_T_FRAG - Tx Packets Less Than 64 Bytes and Bad CRC Statistic Register
 * - HW_ENET_RMON_T_JAB - Tx Packets Greater Than MAX_FL bytes and Bad CRC Statistic Register
 * - HW_ENET_RMON_T_COL - Tx Collision Count Statistic Register
 * - HW_ENET_RMON_T_P64 - Tx 64-Byte Packets Statistic Register
 * - HW_ENET_RMON_T_P65TO127 - Tx 65- to 127-byte Packets Statistic Register
 * - HW_ENET_RMON_T_P128TO255 - Tx 128- to 255-byte Packets Statistic Register
 * - HW_ENET_RMON_T_P256TO511 - Tx 256- to 511-byte Packets Statistic Register
 * - HW_ENET_RMON_T_P512TO1023 - Tx 512- to 1023-byte Packets Statistic Register
 * - HW_ENET_RMON_T_P1024TO2047 - Tx 1024- to 2047-byte Packets Statistic Register
 * - HW_ENET_RMON_T_P_GTE2048 - Tx Packets Greater Than 2048 Bytes Statistic Register
 * - HW_ENET_RMON_T_OCTETS - Tx Octets Statistic Register
 * - HW_ENET_IEEE_T_DROP - Reserved Statistic Register
 * - HW_ENET_IEEE_T_FRAME_OK - Frames Transmitted OK Statistic Register
 * - HW_ENET_IEEE_T_1COL - Frames Transmitted with Single Collision Statistic Register
 * - HW_ENET_IEEE_T_MCOL - Frames Transmitted with Multiple Collisions Statistic Register
 * - HW_ENET_IEEE_T_DEF - Frames Transmitted after Deferral Delay Statistic Register
 * - HW_ENET_IEEE_T_LCOL - Frames Transmitted with Late Collision Statistic Register
 * - HW_ENET_IEEE_T_EXCOL - Frames Transmitted with Excessive Collisions Statistic Register
 * - HW_ENET_IEEE_T_MACERR - Frames Transmitted with Tx FIFO Underrun Statistic Register
 * - HW_ENET_IEEE_T_CSERR - Frames Transmitted with Carrier Sense Error Statistic Register
 * - HW_ENET_IEEE_T_SQE - Reserved Statistic Register
 * - HW_ENET_IEEE_T_FDXFC - Flow Control Pause Frames Transmitted Statistic Register
 * - HW_ENET_IEEE_T_OCTETS_OK - Octet Count for Frames Transmitted w/o Error Statistic Register
 * - HW_ENET_RMON_R_PACKETS - Rx Packet Count Statistic Register
 * - HW_ENET_RMON_R_BC_PKT - Rx Broadcast Packets Statistic Register
 * - HW_ENET_RMON_R_MC_PKT - Rx Multicast Packets Statistic Register
 * - HW_ENET_RMON_R_CRC_ALIGN - Rx Packets with CRC/Align Error Statistic Register
 * - HW_ENET_RMON_R_UNDERSIZE - Rx Packets with Less Than 64 Bytes and Good CRC Statistic Register
 * - HW_ENET_RMON_R_OVERSIZE - Rx Packets Greater Than MAX_FL and Good CRC Statistic Register
 * - HW_ENET_RMON_R_FRAG - Rx Packets Less Than 64 Bytes and Bad CRC Statistic Register
 * - HW_ENET_RMON_R_JAB - Rx Packets Greater Than MAX_FL Bytes and Bad CRC Statistic Register
 * - HW_ENET_RMON_R_RESVD_0 - Reserved Statistic Register
 * - HW_ENET_RMON_R_P64 - Rx 64-Byte Packets Statistic Register
 * - HW_ENET_RMON_R_P65TO127 - Rx 65- to 127-Byte Packets Statistic Register
 * - HW_ENET_RMON_R_P128TO255 - Rx 128- to 255-Byte Packets Statistic Register
 * - HW_ENET_RMON_R_P256TO511 - Rx 256- to 511-Byte Packets Statistic Register
 * - HW_ENET_RMON_R_P512TO1023 - Rx 512- to 1023-Byte Packets Statistic Register
 * - HW_ENET_RMON_R_P1024TO2047 - Rx 1024- to 2047-Byte Packets Statistic Register
 * - HW_ENET_RMON_R_P_GTE2048 - Rx Packets Greater than 2048 Bytes Statistic Register
 * - HW_ENET_RMON_R_OCTETS - Rx Octets Statistic Register
 * - HW_ENET_IEEE_R_DROP - Frames not Counted Correctly Statistic Register
 * - HW_ENET_IEEE_R_FRAME_OK - Frames Received OK Statistic Register
 * - HW_ENET_IEEE_R_CRC - Frames Received with CRC Error Statistic Register
 * - HW_ENET_IEEE_R_ALIGN - Frames Received with Alignment Error Statistic Register
 * - HW_ENET_IEEE_R_MACERR - Receive FIFO Overflow Count Statistic Register
 * - HW_ENET_IEEE_R_FDXFC - Flow Control Pause Frames Received Statistic Register
 * - HW_ENET_IEEE_R_OCTETS_OK - Octet Count for Frames Received without Error Statistic Register
 * - HW_ENET_ATCR - Adjustable Timer Control Register
 * - HW_ENET_ATVR - Timer Value Register
 * - HW_ENET_ATOFF - Timer Offset Register
 * - HW_ENET_ATPER - Timer Period Register
 * - HW_ENET_ATCOR - Timer Correction Register
 * - HW_ENET_ATINC - Time-Stamping Clock Period Register
 * - HW_ENET_ATSTMP - Timestamp of Last Transmitted Frame
 * - HW_ENET_TGSR - Timer Global Status Register
 * - HW_ENET_TCSRn - Timer Control Status Register
 * - HW_ENET_TCCRn - Timer Compare Capture Register
 *
 * - hw_enet_t - Struct containing all module registers.
 */

#define HW_ENET_INSTANCE_COUNT (2U) /*!< Number of instances of the ENET module. */
#define HW_ENET1 (0U) /*!< Instance number for ENET1. */
#define HW_ENET2 (1U) /*!< Instance number for ENET2. */
#define ENET1_BASE            (0x30BE0000U) /*!< Base address for ENET1. */
#define ENET2_BASE            (0x30BF0000U) /*!< Base address for ENET2. */
/*! Array initializer of ENET base addresses. */
#define ENET_BASE_ADDRS       { ENET1_BASE, ENET2_BASE }

/*******************************************************************************
 * HW_ENET_EIR - Interrupt Event Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_EIR - Interrupt Event Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * When an event occurs that sets a bit in EIR, an interrupt occurs if the
 * corresponding bit in the interrupt mask register (EIMR) is also set. Writing a 1 to
 * an EIR bit clears it; writing 0 has no effect. This register is cleared upon
 * hardware reset. TxBD[INT] and RxBD[INT] must be set to 1 to allow setting the
 * corresponding EIR register flags in enhanced mode, ENET_ECR[EN1588] = 1.
 * Legacy mode does not require these flags to be enabled.
 */
typedef union _hw_enet_eir
{
    uint32_t U;
    struct _hw_enet_eir_bitfields
    {
        uint32_t RXB1 : 1;             /*!< [0] Receive buffer interrupt, class 1 */
        uint32_t RXF1 : 1;             /*!< [1] Receive frame interrupt, class 1 */
        uint32_t TXB1 : 1;             /*!< [2] Transmit buffer interrupt, class 1 */
        uint32_t TXF1 : 1;             /*!< [3] Transmit frame interrupt, class 1 */
        uint32_t RXB2 : 1;             /*!< [4] Receive buffer interrupt, class 2 */
        uint32_t RXF2 : 1;             /*!< [5] Receive frame interrupt, class 2 */
        uint32_t TXB2 : 1;             /*!< [6] Transmit buffer interrupt, class 2 */
        uint32_t TXF2 : 1;             /*!< [7] Transmit frame interrupt, class 2 */
        uint32_t RESERVED0 : 4;        /*!< [11:8]  */
        uint32_t RXFLUSH_0 : 1;        /*!< [12]  */
        uint32_t RXFLUSH_1 : 1;        /*!< [13]  */
        uint32_t RXFLUSH_2 : 1;        /*!< [14]  */
        uint32_t TS_TIMER : 1;         /*!< [15] Timestamp Timer */
        uint32_t TS_AVAIL : 1;         /*!< [16] Transmit Timestamp Available */
        uint32_t WAKEUP : 1;           /*!< [17] Node Wakeup Request Indication */
        uint32_t PLR : 1;              /*!< [18] Payload Receive Error */
        uint32_t UN : 1;               /*!< [19] Transmit FIFO Underrun */
        uint32_t RL : 1;               /*!< [20] Collision Retry Limit */
        uint32_t LC : 1;               /*!< [21] Late Collision */
        uint32_t EBERR : 1;            /*!< [22] Ethernet Bus Error */
        uint32_t MII : 1;              /*!< [23] MII Interrupt. */
        uint32_t RXB : 1;              /*!< [24] Receive Buffer Interrupt */
        uint32_t RXF : 1;              /*!< [25] Receive Frame Interrupt */
        uint32_t TXB : 1;              /*!< [26] Transmit Buffer Interrupt */
        uint32_t TXF : 1;              /*!< [27] Transmit Frame Interrupt */
        uint32_t GRA : 1;              /*!< [28] Graceful Stop Complete */
        uint32_t BABT : 1;             /*!< [29] Babbling Transmit Error */
        uint32_t BABR : 1;             /*!< [30] Babbling Receive Error */
        uint32_t RESERVED1 : 1;        /*!< [31]  */
    } B;
} hw_enet_eir_t;

/*!
 * @name Constants and macros for entire ENET_EIR register
 */
/*@{*/
#define HW_ENET_EIR_ADDR(x)      ((uintptr_t)(x) + 0x4U)

#define HW_ENET_EIR(x)           (*(__IO hw_enet_eir_t *) HW_ENET_EIR_ADDR(x))
#define HW_ENET_EIR_RD(x)        (HW_ENET_EIR(x).U)
#define HW_ENET_EIR_WR(x, v)     (HW_ENET_EIR(x).U = (v))
#define HW_ENET_EIR_SET(x, v)    (HW_ENET_EIR_WR(x, HW_ENET_EIR_RD(x) |  (v)))
#define HW_ENET_EIR_CLR(x, v)    (HW_ENET_EIR_WR(x, HW_ENET_EIR_RD(x) & ~(v)))
#define HW_ENET_EIR_TOG(x, v)    (HW_ENET_EIR_WR(x, HW_ENET_EIR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_EIR bitfields
 */

/*!
 * @name Register ENET_EIR, field RXB1[0] (W1C)
 *
 * This field indicates that a receive buffer descriptor, that not the last in
 * the frame, has been updated (ring/class 1).
 */
/*@{*/
#define BP_ENET_EIR_RXB1     (0U)          /*!< Bit position for ENET_EIR_RXB1. */
#define BM_ENET_EIR_RXB1     (0x00000001U) /*!< Bit mask for ENET_EIR_RXB1. */
#define BS_ENET_EIR_RXB1     (1U)          /*!< Bit field size in bits for ENET_EIR_RXB1. */

/*! @brief Read current value of the ENET_EIR_RXB1 field. */
#define BR_ENET_EIR_RXB1(x)  (HW_ENET_EIR(x).B.RXB1)

/*! @brief Format value for bitfield ENET_EIR_RXB1. */
#define BF_ENET_EIR_RXB1(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RXB1) & BM_ENET_EIR_RXB1)

/*! @brief Set the RXB1 field to a new value. */
#define BW_ENET_EIR_RXB1(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RXB1(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field RXF1[1] (W1C)
 *
 * This field indicates that a frame has been received and the last
 * corresponding buffer descriptor has been updated (ring/class 1).
 */
/*@{*/
#define BP_ENET_EIR_RXF1     (1U)          /*!< Bit position for ENET_EIR_RXF1. */
#define BM_ENET_EIR_RXF1     (0x00000002U) /*!< Bit mask for ENET_EIR_RXF1. */
#define BS_ENET_EIR_RXF1     (1U)          /*!< Bit field size in bits for ENET_EIR_RXF1. */

/*! @brief Read current value of the ENET_EIR_RXF1 field. */
#define BR_ENET_EIR_RXF1(x)  (HW_ENET_EIR(x).B.RXF1)

/*! @brief Format value for bitfield ENET_EIR_RXF1. */
#define BF_ENET_EIR_RXF1(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RXF1) & BM_ENET_EIR_RXF1)

/*! @brief Set the RXF1 field to a new value. */
#define BW_ENET_EIR_RXF1(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RXF1 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RXF1(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field TXB1[2] (W1C)
 *
 * This field indicates that a transmit buffer descriptor has been updated
 * (ring/class 1).
 */
/*@{*/
#define BP_ENET_EIR_TXB1     (2U)          /*!< Bit position for ENET_EIR_TXB1. */
#define BM_ENET_EIR_TXB1     (0x00000004U) /*!< Bit mask for ENET_EIR_TXB1. */
#define BS_ENET_EIR_TXB1     (1U)          /*!< Bit field size in bits for ENET_EIR_TXB1. */

/*! @brief Read current value of the ENET_EIR_TXB1 field. */
#define BR_ENET_EIR_TXB1(x)  (HW_ENET_EIR(x).B.TXB1)

/*! @brief Format value for bitfield ENET_EIR_TXB1. */
#define BF_ENET_EIR_TXB1(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_TXB1) & BM_ENET_EIR_TXB1)

/*! @brief Set the TXB1 field to a new value. */
#define BW_ENET_EIR_TXB1(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_TXB1 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_TXB1(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field TXF1[3] (W1C)
 *
 * This bit indicates that a frame has been transmitted and the last
 * corresponding buffer descriptor has been updated (ring/class 1).
 */
/*@{*/
#define BP_ENET_EIR_TXF1     (3U)          /*!< Bit position for ENET_EIR_TXF1. */
#define BM_ENET_EIR_TXF1     (0x00000008U) /*!< Bit mask for ENET_EIR_TXF1. */
#define BS_ENET_EIR_TXF1     (1U)          /*!< Bit field size in bits for ENET_EIR_TXF1. */

/*! @brief Read current value of the ENET_EIR_TXF1 field. */
#define BR_ENET_EIR_TXF1(x)  (HW_ENET_EIR(x).B.TXF1)

/*! @brief Format value for bitfield ENET_EIR_TXF1. */
#define BF_ENET_EIR_TXF1(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_TXF1) & BM_ENET_EIR_TXF1)

/*! @brief Set the TXF1 field to a new value. */
#define BW_ENET_EIR_TXF1(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_TXF1(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field RXB2[4] (W1C)
 *
 * This field indicates that a receive buffer descriptor, that not the last in
 * the frame, has been updated (ring/class 2).
 */
/*@{*/
#define BP_ENET_EIR_RXB2     (4U)          /*!< Bit position for ENET_EIR_RXB2. */
#define BM_ENET_EIR_RXB2     (0x00000010U) /*!< Bit mask for ENET_EIR_RXB2. */
#define BS_ENET_EIR_RXB2     (1U)          /*!< Bit field size in bits for ENET_EIR_RXB2. */

/*! @brief Read current value of the ENET_EIR_RXB2 field. */
#define BR_ENET_EIR_RXB2(x)  (HW_ENET_EIR(x).B.RXB2)

/*! @brief Format value for bitfield ENET_EIR_RXB2. */
#define BF_ENET_EIR_RXB2(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RXB2) & BM_ENET_EIR_RXB2)

/*! @brief Set the RXB2 field to a new value. */
#define BW_ENET_EIR_RXB2(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RXB2(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field RXF2[5] (W1C)
 *
 * This field indicates that a frame has been received and the last
 * corresponding buffer descriptor has been updated (ring/class 2).
 */
/*@{*/
#define BP_ENET_EIR_RXF2     (5U)          /*!< Bit position for ENET_EIR_RXF2. */
#define BM_ENET_EIR_RXF2     (0x00000020U) /*!< Bit mask for ENET_EIR_RXF2. */
#define BS_ENET_EIR_RXF2     (1U)          /*!< Bit field size in bits for ENET_EIR_RXF2. */

/*! @brief Read current value of the ENET_EIR_RXF2 field. */
#define BR_ENET_EIR_RXF2(x)  (HW_ENET_EIR(x).B.RXF2)

/*! @brief Format value for bitfield ENET_EIR_RXF2. */
#define BF_ENET_EIR_RXF2(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RXF2) & BM_ENET_EIR_RXF2)

/*! @brief Set the RXF2 field to a new value. */
#define BW_ENET_EIR_RXF2(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RXF2 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RXF2(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field TXB2[6] (W1C)
 *
 * This field indicates that a transmit buffer descriptor has been updated
 * (ring/class 2).
 */
/*@{*/
#define BP_ENET_EIR_TXB2     (6U)          /*!< Bit position for ENET_EIR_TXB2. */
#define BM_ENET_EIR_TXB2     (0x00000040U) /*!< Bit mask for ENET_EIR_TXB2. */
#define BS_ENET_EIR_TXB2     (1U)          /*!< Bit field size in bits for ENET_EIR_TXB2. */

/*! @brief Read current value of the ENET_EIR_TXB2 field. */
#define BR_ENET_EIR_TXB2(x)  (HW_ENET_EIR(x).B.TXB2)

/*! @brief Format value for bitfield ENET_EIR_TXB2. */
#define BF_ENET_EIR_TXB2(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_TXB2) & BM_ENET_EIR_TXB2)

/*! @brief Set the TXB2 field to a new value. */
#define BW_ENET_EIR_TXB2(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_TXB2 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_TXB2(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field TXF2[7] (W1C)
 *
 * This bit indicates that a frame has been transmitted and the last
 * corresponding buffer descriptor has been updated (ring/class 2).
 */
/*@{*/
#define BP_ENET_EIR_TXF2     (7U)          /*!< Bit position for ENET_EIR_TXF2. */
#define BM_ENET_EIR_TXF2     (0x00000080U) /*!< Bit mask for ENET_EIR_TXF2. */
#define BS_ENET_EIR_TXF2     (1U)          /*!< Bit field size in bits for ENET_EIR_TXF2. */

/*! @brief Read current value of the ENET_EIR_TXF2 field. */
#define BR_ENET_EIR_TXF2(x)  (HW_ENET_EIR(x).B.TXF2)

/*! @brief Format value for bitfield ENET_EIR_TXF2. */
#define BF_ENET_EIR_TXF2(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_TXF2) & BM_ENET_EIR_TXF2)

/*! @brief Set the TXF2 field to a new value. */
#define BW_ENET_EIR_TXF2(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_TXF2(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field RXFLUSH_0[12] (W1C)
 *
 * RX DMA Ring 0 flush indication. . This ring's RX frame has been flushed due
 * to either RDAR[RDAR] or RxBD[E] being clear and only if QOS[RXFLUSH_0] is
 * enabled.
 */
/*@{*/
#define BP_ENET_EIR_RXFLUSH_0 (12U)        /*!< Bit position for ENET_EIR_RXFLUSH_0. */
#define BM_ENET_EIR_RXFLUSH_0 (0x00001000U) /*!< Bit mask for ENET_EIR_RXFLUSH_0. */
#define BS_ENET_EIR_RXFLUSH_0 (1U)         /*!< Bit field size in bits for ENET_EIR_RXFLUSH_0. */

/*! @brief Read current value of the ENET_EIR_RXFLUSH_0 field. */
#define BR_ENET_EIR_RXFLUSH_0(x) (HW_ENET_EIR(x).B.RXFLUSH_0)

/*! @brief Format value for bitfield ENET_EIR_RXFLUSH_0. */
#define BF_ENET_EIR_RXFLUSH_0(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RXFLUSH_0) & BM_ENET_EIR_RXFLUSH_0)

/*! @brief Set the RXFLUSH_0 field to a new value. */
#define BW_ENET_EIR_RXFLUSH_0(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RXFLUSH_0(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field RXFLUSH_1[13] (W1C)
 *
 * RX DMA Ring 1 flush indication. This ring's RX frame has been flushed due to
 * either RDAR1[RDAR] or RxBD[E] being clear and only if QOS[RXFLUSH_1] is
 * enabled.
 */
/*@{*/
#define BP_ENET_EIR_RXFLUSH_1 (13U)        /*!< Bit position for ENET_EIR_RXFLUSH_1. */
#define BM_ENET_EIR_RXFLUSH_1 (0x00002000U) /*!< Bit mask for ENET_EIR_RXFLUSH_1. */
#define BS_ENET_EIR_RXFLUSH_1 (1U)         /*!< Bit field size in bits for ENET_EIR_RXFLUSH_1. */

/*! @brief Read current value of the ENET_EIR_RXFLUSH_1 field. */
#define BR_ENET_EIR_RXFLUSH_1(x) (HW_ENET_EIR(x).B.RXFLUSH_1)

/*! @brief Format value for bitfield ENET_EIR_RXFLUSH_1. */
#define BF_ENET_EIR_RXFLUSH_1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RXFLUSH_1) & BM_ENET_EIR_RXFLUSH_1)

/*! @brief Set the RXFLUSH_1 field to a new value. */
#define BW_ENET_EIR_RXFLUSH_1(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RXFLUSH_1(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field RXFLUSH_2[14] (W1C)
 *
 * RX DMA Ring 2 flush indication. This ring's RX frame has been flushed due to
 * either RDAR2[RDAR] or RxBD[E] being clear and only if QOS[RXFLUSH_2] is
 * enabled.
 */
/*@{*/
#define BP_ENET_EIR_RXFLUSH_2 (14U)        /*!< Bit position for ENET_EIR_RXFLUSH_2. */
#define BM_ENET_EIR_RXFLUSH_2 (0x00004000U) /*!< Bit mask for ENET_EIR_RXFLUSH_2. */
#define BS_ENET_EIR_RXFLUSH_2 (1U)         /*!< Bit field size in bits for ENET_EIR_RXFLUSH_2. */

/*! @brief Read current value of the ENET_EIR_RXFLUSH_2 field. */
#define BR_ENET_EIR_RXFLUSH_2(x) (HW_ENET_EIR(x).B.RXFLUSH_2)

/*! @brief Format value for bitfield ENET_EIR_RXFLUSH_2. */
#define BF_ENET_EIR_RXFLUSH_2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RXFLUSH_2) & BM_ENET_EIR_RXFLUSH_2)

/*! @brief Set the RXFLUSH_2 field to a new value. */
#define BW_ENET_EIR_RXFLUSH_2(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RXFLUSH_2(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field TS_TIMER[15] (W1C)
 *
 * The adjustable timer reached the period event. A period event interrupt can
 * be generated if ATCR[PEREN] is set and the timer wraps according to the
 * periodic setting in the ATPER register. Set the timer period value before setting
 * ATCR[PEREN].
 */
/*@{*/
#define BP_ENET_EIR_TS_TIMER (15U)         /*!< Bit position for ENET_EIR_TS_TIMER. */
#define BM_ENET_EIR_TS_TIMER (0x00008000U) /*!< Bit mask for ENET_EIR_TS_TIMER. */
#define BS_ENET_EIR_TS_TIMER (1U)          /*!< Bit field size in bits for ENET_EIR_TS_TIMER. */

/*! @brief Read current value of the ENET_EIR_TS_TIMER field. */
#define BR_ENET_EIR_TS_TIMER(x) (HW_ENET_EIR(x).B.TS_TIMER)

/*! @brief Format value for bitfield ENET_EIR_TS_TIMER. */
#define BF_ENET_EIR_TS_TIMER(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_TS_TIMER) & BM_ENET_EIR_TS_TIMER)

/*! @brief Set the TS_TIMER field to a new value. */
#define BW_ENET_EIR_TS_TIMER(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_TS_TIMER(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field TS_AVAIL[16] (W1C)
 *
 * Indicates that the timestamp of the last transmitted timing frame is
 * available in the ATSTMP register.
 */
/*@{*/
#define BP_ENET_EIR_TS_AVAIL (16U)         /*!< Bit position for ENET_EIR_TS_AVAIL. */
#define BM_ENET_EIR_TS_AVAIL (0x00010000U) /*!< Bit mask for ENET_EIR_TS_AVAIL. */
#define BS_ENET_EIR_TS_AVAIL (1U)          /*!< Bit field size in bits for ENET_EIR_TS_AVAIL. */

/*! @brief Read current value of the ENET_EIR_TS_AVAIL field. */
#define BR_ENET_EIR_TS_AVAIL(x) (HW_ENET_EIR(x).B.TS_AVAIL)

/*! @brief Format value for bitfield ENET_EIR_TS_AVAIL. */
#define BF_ENET_EIR_TS_AVAIL(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_TS_AVAIL) & BM_ENET_EIR_TS_AVAIL)

/*! @brief Set the TS_AVAIL field to a new value. */
#define BW_ENET_EIR_TS_AVAIL(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_TS_AVAIL(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field WAKEUP[17] (W1C)
 *
 * Read-only status bit to indicate that a magic packet has been detected. Will
 * act only if ECR[MAGICEN] is set.
 */
/*@{*/
#define BP_ENET_EIR_WAKEUP   (17U)         /*!< Bit position for ENET_EIR_WAKEUP. */
#define BM_ENET_EIR_WAKEUP   (0x00020000U) /*!< Bit mask for ENET_EIR_WAKEUP. */
#define BS_ENET_EIR_WAKEUP   (1U)          /*!< Bit field size in bits for ENET_EIR_WAKEUP. */

/*! @brief Read current value of the ENET_EIR_WAKEUP field. */
#define BR_ENET_EIR_WAKEUP(x) (HW_ENET_EIR(x).B.WAKEUP)

/*! @brief Format value for bitfield ENET_EIR_WAKEUP. */
#define BF_ENET_EIR_WAKEUP(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_WAKEUP) & BM_ENET_EIR_WAKEUP)

/*! @brief Set the WAKEUP field to a new value. */
#define BW_ENET_EIR_WAKEUP(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_WAKEUP | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_WAKEUP(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field PLR[18] (W1C)
 *
 * Indicates a frame was received with a payload length error. See Frame
 * Length/Type Verification: Payload Length Check for more information.
 */
/*@{*/
#define BP_ENET_EIR_PLR      (18U)         /*!< Bit position for ENET_EIR_PLR. */
#define BM_ENET_EIR_PLR      (0x00040000U) /*!< Bit mask for ENET_EIR_PLR. */
#define BS_ENET_EIR_PLR      (1U)          /*!< Bit field size in bits for ENET_EIR_PLR. */

/*! @brief Read current value of the ENET_EIR_PLR field. */
#define BR_ENET_EIR_PLR(x)   (HW_ENET_EIR(x).B.PLR)

/*! @brief Format value for bitfield ENET_EIR_PLR. */
#define BF_ENET_EIR_PLR(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_PLR) & BM_ENET_EIR_PLR)

/*! @brief Set the PLR field to a new value. */
#define BW_ENET_EIR_PLR(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_PLR | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_PLR(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field UN[19] (W1C)
 *
 * Indicates the transmit FIFO became empty before the complete frame was
 * transmitted. A bad CRC is appended to the frame fragment and the remainder of the
 * frame is discarded.
 */
/*@{*/
#define BP_ENET_EIR_UN       (19U)         /*!< Bit position for ENET_EIR_UN. */
#define BM_ENET_EIR_UN       (0x00080000U) /*!< Bit mask for ENET_EIR_UN. */
#define BS_ENET_EIR_UN       (1U)          /*!< Bit field size in bits for ENET_EIR_UN. */

/*! @brief Read current value of the ENET_EIR_UN field. */
#define BR_ENET_EIR_UN(x)    (HW_ENET_EIR(x).B.UN)

/*! @brief Format value for bitfield ENET_EIR_UN. */
#define BF_ENET_EIR_UN(v)    ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_UN) & BM_ENET_EIR_UN)

/*! @brief Set the UN field to a new value. */
#define BW_ENET_EIR_UN(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_UN | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_UN(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field RL[20] (W1C)
 *
 * Indicates a collision occurred on each of 16 successive attempts to transmit
 * the frame. The frame is discarded without being transmitted and transmission
 * of the next frame commences. This error can only occur in half-duplex mode.
 */
/*@{*/
#define BP_ENET_EIR_RL       (20U)         /*!< Bit position for ENET_EIR_RL. */
#define BM_ENET_EIR_RL       (0x00100000U) /*!< Bit mask for ENET_EIR_RL. */
#define BS_ENET_EIR_RL       (1U)          /*!< Bit field size in bits for ENET_EIR_RL. */

/*! @brief Read current value of the ENET_EIR_RL field. */
#define BR_ENET_EIR_RL(x)    (HW_ENET_EIR(x).B.RL)

/*! @brief Format value for bitfield ENET_EIR_RL. */
#define BF_ENET_EIR_RL(v)    ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RL) & BM_ENET_EIR_RL)

/*! @brief Set the RL field to a new value. */
#define BW_ENET_EIR_RL(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RL | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RL(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field LC[21] (W1C)
 *
 * Indicates a collision occurred beyond the collision window (slot time) in
 * half-duplex mode. The frame truncates with a bad CRC and the remainder of the
 * frame is discarded.
 */
/*@{*/
#define BP_ENET_EIR_LC       (21U)         /*!< Bit position for ENET_EIR_LC. */
#define BM_ENET_EIR_LC       (0x00200000U) /*!< Bit mask for ENET_EIR_LC. */
#define BS_ENET_EIR_LC       (1U)          /*!< Bit field size in bits for ENET_EIR_LC. */

/*! @brief Read current value of the ENET_EIR_LC field. */
#define BR_ENET_EIR_LC(x)    (HW_ENET_EIR(x).B.LC)

/*! @brief Format value for bitfield ENET_EIR_LC. */
#define BF_ENET_EIR_LC(v)    ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_LC) & BM_ENET_EIR_LC)

/*! @brief Set the LC field to a new value. */
#define BW_ENET_EIR_LC(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_LC | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_LC(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field EBERR[22] (W1C)
 *
 * Indicates a system bus error occurred when a uDMA transaction is underway.
 * When this bit is set, ECR[ETHEREN] is cleared, halting frame processing by the
 * MAC. When this occurs, software must ensure proper actions, possibly resetting
 * the system, to resume normal operation.
 */
/*@{*/
#define BP_ENET_EIR_EBERR    (22U)         /*!< Bit position for ENET_EIR_EBERR. */
#define BM_ENET_EIR_EBERR    (0x00400000U) /*!< Bit mask for ENET_EIR_EBERR. */
#define BS_ENET_EIR_EBERR    (1U)          /*!< Bit field size in bits for ENET_EIR_EBERR. */

/*! @brief Read current value of the ENET_EIR_EBERR field. */
#define BR_ENET_EIR_EBERR(x) (HW_ENET_EIR(x).B.EBERR)

/*! @brief Format value for bitfield ENET_EIR_EBERR. */
#define BF_ENET_EIR_EBERR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_EBERR) & BM_ENET_EIR_EBERR)

/*! @brief Set the EBERR field to a new value. */
#define BW_ENET_EIR_EBERR(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_EBERR | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_EBERR(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field MII[23] (W1C)
 *
 * Indicates that the MII has completed the data transfer requested.
 */
/*@{*/
#define BP_ENET_EIR_MII      (23U)         /*!< Bit position for ENET_EIR_MII. */
#define BM_ENET_EIR_MII      (0x00800000U) /*!< Bit mask for ENET_EIR_MII. */
#define BS_ENET_EIR_MII      (1U)          /*!< Bit field size in bits for ENET_EIR_MII. */

/*! @brief Read current value of the ENET_EIR_MII field. */
#define BR_ENET_EIR_MII(x)   (HW_ENET_EIR(x).B.MII)

/*! @brief Format value for bitfield ENET_EIR_MII. */
#define BF_ENET_EIR_MII(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_MII) & BM_ENET_EIR_MII)

/*! @brief Set the MII field to a new value. */
#define BW_ENET_EIR_MII(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_MII | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_MII(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field RXB[24] (W1C)
 *
 * Indicates a receive buffer descriptor is not the last in the frame has been
 * updated.
 */
/*@{*/
#define BP_ENET_EIR_RXB      (24U)         /*!< Bit position for ENET_EIR_RXB. */
#define BM_ENET_EIR_RXB      (0x01000000U) /*!< Bit mask for ENET_EIR_RXB. */
#define BS_ENET_EIR_RXB      (1U)          /*!< Bit field size in bits for ENET_EIR_RXB. */

/*! @brief Read current value of the ENET_EIR_RXB field. */
#define BR_ENET_EIR_RXB(x)   (HW_ENET_EIR(x).B.RXB)

/*! @brief Format value for bitfield ENET_EIR_RXB. */
#define BF_ENET_EIR_RXB(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RXB) & BM_ENET_EIR_RXB)

/*! @brief Set the RXB field to a new value. */
#define BW_ENET_EIR_RXB(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RXB | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RXB(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field RXF[25] (W1C)
 *
 * Indicates a frame has been received and the last corresponding buffer
 * descriptor has been updated.
 */
/*@{*/
#define BP_ENET_EIR_RXF      (25U)         /*!< Bit position for ENET_EIR_RXF. */
#define BM_ENET_EIR_RXF      (0x02000000U) /*!< Bit mask for ENET_EIR_RXF. */
#define BS_ENET_EIR_RXF      (1U)          /*!< Bit field size in bits for ENET_EIR_RXF. */

/*! @brief Read current value of the ENET_EIR_RXF field. */
#define BR_ENET_EIR_RXF(x)   (HW_ENET_EIR(x).B.RXF)

/*! @brief Format value for bitfield ENET_EIR_RXF. */
#define BF_ENET_EIR_RXF(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_RXF) & BM_ENET_EIR_RXF)

/*! @brief Set the RXF field to a new value. */
#define BW_ENET_EIR_RXF(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_RXF | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_RXF(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field TXB[26] (W1C)
 *
 * Indicates a transmit buffer descriptor has been updated.
 */
/*@{*/
#define BP_ENET_EIR_TXB      (26U)         /*!< Bit position for ENET_EIR_TXB. */
#define BM_ENET_EIR_TXB      (0x04000000U) /*!< Bit mask for ENET_EIR_TXB. */
#define BS_ENET_EIR_TXB      (1U)          /*!< Bit field size in bits for ENET_EIR_TXB. */

/*! @brief Read current value of the ENET_EIR_TXB field. */
#define BR_ENET_EIR_TXB(x)   (HW_ENET_EIR(x).B.TXB)

/*! @brief Format value for bitfield ENET_EIR_TXB. */
#define BF_ENET_EIR_TXB(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_TXB) & BM_ENET_EIR_TXB)

/*! @brief Set the TXB field to a new value. */
#define BW_ENET_EIR_TXB(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_TXB | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_TXB(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field TXF[27] (W1C)
 *
 * Indicates a frame has been transmitted and the last corresponding buffer
 * descriptor has been updated.
 */
/*@{*/
#define BP_ENET_EIR_TXF      (27U)         /*!< Bit position for ENET_EIR_TXF. */
#define BM_ENET_EIR_TXF      (0x08000000U) /*!< Bit mask for ENET_EIR_TXF. */
#define BS_ENET_EIR_TXF      (1U)          /*!< Bit field size in bits for ENET_EIR_TXF. */

/*! @brief Read current value of the ENET_EIR_TXF field. */
#define BR_ENET_EIR_TXF(x)   (HW_ENET_EIR(x).B.TXF)

/*! @brief Format value for bitfield ENET_EIR_TXF. */
#define BF_ENET_EIR_TXF(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_TXF) & BM_ENET_EIR_TXF)

/*! @brief Set the TXF field to a new value. */
#define BW_ENET_EIR_TXF(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_TXF | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_TXF(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field GRA[28] (W1C)
 *
 * This interrupt is asserted after the transmitter is put into a pause state
 * after completion of the frame currently being transmitted. See Graceful Transmit
 * Stop (GTS) for conditions that lead to graceful stop. The GRA interrupt is
 * asserted only when the TX transitions into the stopped state. If this bit is
 * cleared by writing 1 and the TX is still stopped, the bit is not set again.
 */
/*@{*/
#define BP_ENET_EIR_GRA      (28U)         /*!< Bit position for ENET_EIR_GRA. */
#define BM_ENET_EIR_GRA      (0x10000000U) /*!< Bit mask for ENET_EIR_GRA. */
#define BS_ENET_EIR_GRA      (1U)          /*!< Bit field size in bits for ENET_EIR_GRA. */

/*! @brief Read current value of the ENET_EIR_GRA field. */
#define BR_ENET_EIR_GRA(x)   (HW_ENET_EIR(x).B.GRA)

/*! @brief Format value for bitfield ENET_EIR_GRA. */
#define BF_ENET_EIR_GRA(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_GRA) & BM_ENET_EIR_GRA)

/*! @brief Set the GRA field to a new value. */
#define BW_ENET_EIR_GRA(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_GRA | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_BABT | BM_ENET_EIR_BABR)) | BF_ENET_EIR_GRA(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field BABT[29] (W1C)
 *
 * Indicates the transmitted frame length exceeds RCR[MAX_FL] bytes. Usually
 * this condition is caused when a frame that is too long is placed into the
 * transmit data buffer(s). Truncation does not occur.
 */
/*@{*/
#define BP_ENET_EIR_BABT     (29U)         /*!< Bit position for ENET_EIR_BABT. */
#define BM_ENET_EIR_BABT     (0x20000000U) /*!< Bit mask for ENET_EIR_BABT. */
#define BS_ENET_EIR_BABT     (1U)          /*!< Bit field size in bits for ENET_EIR_BABT. */

/*! @brief Read current value of the ENET_EIR_BABT field. */
#define BR_ENET_EIR_BABT(x)  (HW_ENET_EIR(x).B.BABT)

/*! @brief Format value for bitfield ENET_EIR_BABT. */
#define BF_ENET_EIR_BABT(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_BABT) & BM_ENET_EIR_BABT)

/*! @brief Set the BABT field to a new value. */
#define BW_ENET_EIR_BABT(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_BABT | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABR)) | BF_ENET_EIR_BABT(v)))
/*@}*/

/*!
 * @name Register ENET_EIR, field BABR[30] (W1C)
 *
 * Indicates a frame was received with length in excess of RCR[MAX_FL] bytes.
 */
/*@{*/
#define BP_ENET_EIR_BABR     (30U)         /*!< Bit position for ENET_EIR_BABR. */
#define BM_ENET_EIR_BABR     (0x40000000U) /*!< Bit mask for ENET_EIR_BABR. */
#define BS_ENET_EIR_BABR     (1U)          /*!< Bit field size in bits for ENET_EIR_BABR. */

/*! @brief Read current value of the ENET_EIR_BABR field. */
#define BR_ENET_EIR_BABR(x)  (HW_ENET_EIR(x).B.BABR)

/*! @brief Format value for bitfield ENET_EIR_BABR. */
#define BF_ENET_EIR_BABR(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIR_BABR) & BM_ENET_EIR_BABR)

/*! @brief Set the BABR field to a new value. */
#define BW_ENET_EIR_BABR(x, v) (HW_ENET_EIR_WR(x, (HW_ENET_EIR_RD(x) & ~(BM_ENET_EIR_BABR | BM_ENET_EIR_RXB1 | BM_ENET_EIR_RXF1 | BM_ENET_EIR_TXB1 | BM_ENET_EIR_TXF1 | BM_ENET_EIR_RXB2 | BM_ENET_EIR_RXF2 | BM_ENET_EIR_TXB2 | BM_ENET_EIR_TXF2 | BM_ENET_EIR_RXFLUSH_0 | BM_ENET_EIR_RXFLUSH_1 | BM_ENET_EIR_RXFLUSH_2 | BM_ENET_EIR_TS_TIMER | BM_ENET_EIR_TS_AVAIL | BM_ENET_EIR_WAKEUP | BM_ENET_EIR_PLR | BM_ENET_EIR_UN | BM_ENET_EIR_RL | BM_ENET_EIR_LC | BM_ENET_EIR_EBERR | BM_ENET_EIR_MII | BM_ENET_EIR_RXB | BM_ENET_EIR_RXF | BM_ENET_EIR_TXB | BM_ENET_EIR_TXF | BM_ENET_EIR_GRA | BM_ENET_EIR_BABT)) | BF_ENET_EIR_BABR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_EIMR - Interrupt Mask Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_EIMR - Interrupt Mask Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * EIMR controls which interrupt events are allowed to generate actual
 * interrupts. A hardware reset clears this register. If the corresponding bits in the EIR
 * and EIMR registers are set, an interrupt is generated. The interrupt signal
 * remains asserted until a 1 is written to the EIR field (write 1 to clear) or a
 * 0 is written to the EIMR field.
 */
typedef union _hw_enet_eimr
{
    uint32_t U;
    struct _hw_enet_eimr_bitfields
    {
        uint32_t RXB1 : 1;             /*!< [0] Receive buffer interrupt, class 1 */
        uint32_t RXF1 : 1;             /*!< [1] Receive frame interrupt, class 1 */
        uint32_t TXB1 : 1;             /*!< [2] Transmit buffer interrupt, class 1 */
        uint32_t TXF1 : 1;             /*!< [3] Transmit frame interrupt, class 1 */
        uint32_t RXB2 : 1;             /*!< [4] Receive buffer interrupt, class 2 */
        uint32_t RXF2 : 1;             /*!< [5] Receive frame interrupt, class 2 */
        uint32_t TXB2 : 1;             /*!< [6] Transmit buffer interrupt, class 2 */
        uint32_t TXF2 : 1;             /*!< [7] Transmit frame interrupt, class 2 */
        uint32_t RESERVED0 : 4;        /*!< [11:8]  */
        uint32_t RXFLUSH_0 : 1;        /*!< [12]  */
        uint32_t RXFLUSH_1 : 1;        /*!< [13]  */
        uint32_t RXFLUSH_2 : 1;        /*!< [14]  */
        uint32_t TS_TIMER : 1;         /*!< [15] TS_TIMER Interrupt Mask */
        uint32_t TS_AVAIL : 1;         /*!< [16] TS_AVAIL Interrupt Mask */
        uint32_t WAKEUP : 1;           /*!< [17] WAKEUP Interrupt Mask */
        uint32_t PLR : 1;              /*!< [18] PLR Interrupt Mask */
        uint32_t UN : 1;               /*!< [19] UN Interrupt Mask */
        uint32_t RL : 1;               /*!< [20] RL Interrupt Mask */
        uint32_t LC : 1;               /*!< [21] LC Interrupt Mask */
        uint32_t EBERR : 1;            /*!< [22] EBERR Interrupt Mask */
        uint32_t MII : 1;              /*!< [23] MII Interrupt Mask */
        uint32_t RXB : 1;              /*!< [24] RXB Interrupt Mask */
        uint32_t RXF : 1;              /*!< [25] RXF Interrupt Mask */
        uint32_t TXB : 1;              /*!< [26] TXB Interrupt Mask */
        uint32_t TXF : 1;              /*!< [27] TXF Interrupt Mask */
        uint32_t GRA : 1;              /*!< [28] GRA Interrupt Mask */
        uint32_t BABT : 1;             /*!< [29] BABT Interrupt Mask */
        uint32_t BABR : 1;             /*!< [30] BABR Interrupt Mask */
        uint32_t RESERVED1 : 1;        /*!< [31]  */
    } B;
} hw_enet_eimr_t;

/*!
 * @name Constants and macros for entire ENET_EIMR register
 */
/*@{*/
#define HW_ENET_EIMR_ADDR(x)     ((uintptr_t)(x) + 0x8U)

#define HW_ENET_EIMR(x)          (*(__IO hw_enet_eimr_t *) HW_ENET_EIMR_ADDR(x))
#define HW_ENET_EIMR_RD(x)       (HW_ENET_EIMR(x).U)
#define HW_ENET_EIMR_WR(x, v)    (HW_ENET_EIMR(x).U = (v))
#define HW_ENET_EIMR_SET(x, v)   (HW_ENET_EIMR_WR(x, HW_ENET_EIMR_RD(x) |  (v)))
#define HW_ENET_EIMR_CLR(x, v)   (HW_ENET_EIMR_WR(x, HW_ENET_EIMR_RD(x) & ~(v)))
#define HW_ENET_EIMR_TOG(x, v)   (HW_ENET_EIMR_WR(x, HW_ENET_EIMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_EIMR bitfields
 */

/*!
 * @name Register ENET_EIMR, field RXB1[0] (RW)
 *
 * Corresponds to interrupt source EIR[RXB1] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. EIR[RXB1] reflects the state
 * of the interrupt signal even if the corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RXB1    (0U)          /*!< Bit position for ENET_EIMR_RXB1. */
#define BM_ENET_EIMR_RXB1    (0x00000001U) /*!< Bit mask for ENET_EIMR_RXB1. */
#define BS_ENET_EIMR_RXB1    (1U)          /*!< Bit field size in bits for ENET_EIMR_RXB1. */

/*! @brief Read current value of the ENET_EIMR_RXB1 field. */
#define BR_ENET_EIMR_RXB1(x) (HW_ENET_EIMR(x).B.RXB1)

/*! @brief Format value for bitfield ENET_EIMR_RXB1. */
#define BF_ENET_EIMR_RXB1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RXB1) & BM_ENET_EIMR_RXB1)

/*! @brief Set the RXB1 field to a new value. */
#define BW_ENET_EIMR_RXB1(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RXB1) | BF_ENET_EIMR_RXB1(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field RXF1[1] (RW)
 *
 * Corresponds to interrupt source EIR[RXF1] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. EIR[RXF1] reflects the state
 * of the interrupt signal even if the corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RXF1    (1U)          /*!< Bit position for ENET_EIMR_RXF1. */
#define BM_ENET_EIMR_RXF1    (0x00000002U) /*!< Bit mask for ENET_EIMR_RXF1. */
#define BS_ENET_EIMR_RXF1    (1U)          /*!< Bit field size in bits for ENET_EIMR_RXF1. */

/*! @brief Read current value of the ENET_EIMR_RXF1 field. */
#define BR_ENET_EIMR_RXF1(x) (HW_ENET_EIMR(x).B.RXF1)

/*! @brief Format value for bitfield ENET_EIMR_RXF1. */
#define BF_ENET_EIMR_RXF1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RXF1) & BM_ENET_EIMR_RXF1)

/*! @brief Set the RXF1 field to a new value. */
#define BW_ENET_EIMR_RXF1(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RXF1) | BF_ENET_EIMR_RXF1(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field TXB1[2] (RW)
 *
 * Corresponds to interrupt source EIR[TXB1] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. EIR[TXB1] reflects the state
 * of the interrupt signal even if the corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_TXB1    (2U)          /*!< Bit position for ENET_EIMR_TXB1. */
#define BM_ENET_EIMR_TXB1    (0x00000004U) /*!< Bit mask for ENET_EIMR_TXB1. */
#define BS_ENET_EIMR_TXB1    (1U)          /*!< Bit field size in bits for ENET_EIMR_TXB1. */

/*! @brief Read current value of the ENET_EIMR_TXB1 field. */
#define BR_ENET_EIMR_TXB1(x) (HW_ENET_EIMR(x).B.TXB1)

/*! @brief Format value for bitfield ENET_EIMR_TXB1. */
#define BF_ENET_EIMR_TXB1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_TXB1) & BM_ENET_EIMR_TXB1)

/*! @brief Set the TXB1 field to a new value. */
#define BW_ENET_EIMR_TXB1(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_TXB1) | BF_ENET_EIMR_TXB1(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field TXF1[3] (RW)
 *
 * Corresponds to interrupt source EIR[TXF1] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. EIR[TXF1] reflects the state
 * of the interrupt signal even if the corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_TXF1    (3U)          /*!< Bit position for ENET_EIMR_TXF1. */
#define BM_ENET_EIMR_TXF1    (0x00000008U) /*!< Bit mask for ENET_EIMR_TXF1. */
#define BS_ENET_EIMR_TXF1    (1U)          /*!< Bit field size in bits for ENET_EIMR_TXF1. */

/*! @brief Read current value of the ENET_EIMR_TXF1 field. */
#define BR_ENET_EIMR_TXF1(x) (HW_ENET_EIMR(x).B.TXF1)

/*! @brief Format value for bitfield ENET_EIMR_TXF1. */
#define BF_ENET_EIMR_TXF1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_TXF1) & BM_ENET_EIMR_TXF1)

/*! @brief Set the TXF1 field to a new value. */
#define BW_ENET_EIMR_TXF1(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_TXF1) | BF_ENET_EIMR_TXF1(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field RXB2[4] (RW)
 *
 * Corresponds to interrupt source EIR[RXB2] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. EIR[RXB2] reflects the state
 * of the interrupt signal even if the corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RXB2    (4U)          /*!< Bit position for ENET_EIMR_RXB2. */
#define BM_ENET_EIMR_RXB2    (0x00000010U) /*!< Bit mask for ENET_EIMR_RXB2. */
#define BS_ENET_EIMR_RXB2    (1U)          /*!< Bit field size in bits for ENET_EIMR_RXB2. */

/*! @brief Read current value of the ENET_EIMR_RXB2 field. */
#define BR_ENET_EIMR_RXB2(x) (HW_ENET_EIMR(x).B.RXB2)

/*! @brief Format value for bitfield ENET_EIMR_RXB2. */
#define BF_ENET_EIMR_RXB2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RXB2) & BM_ENET_EIMR_RXB2)

/*! @brief Set the RXB2 field to a new value. */
#define BW_ENET_EIMR_RXB2(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RXB2) | BF_ENET_EIMR_RXB2(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field RXF2[5] (RW)
 *
 * Corresponds to interrupt source EIR[RXF2] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. EIR[RXF2] reflects the state
 * of the interrupt signal even if the corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RXF2    (5U)          /*!< Bit position for ENET_EIMR_RXF2. */
#define BM_ENET_EIMR_RXF2    (0x00000020U) /*!< Bit mask for ENET_EIMR_RXF2. */
#define BS_ENET_EIMR_RXF2    (1U)          /*!< Bit field size in bits for ENET_EIMR_RXF2. */

/*! @brief Read current value of the ENET_EIMR_RXF2 field. */
#define BR_ENET_EIMR_RXF2(x) (HW_ENET_EIMR(x).B.RXF2)

/*! @brief Format value for bitfield ENET_EIMR_RXF2. */
#define BF_ENET_EIMR_RXF2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RXF2) & BM_ENET_EIMR_RXF2)

/*! @brief Set the RXF2 field to a new value. */
#define BW_ENET_EIMR_RXF2(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RXF2) | BF_ENET_EIMR_RXF2(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field TXB2[6] (RW)
 *
 * Corresponds to interrupt source EIR[TXB2] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. EIR[TXB2] reflects the state
 * of the interrupt signal even if the corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_TXB2    (6U)          /*!< Bit position for ENET_EIMR_TXB2. */
#define BM_ENET_EIMR_TXB2    (0x00000040U) /*!< Bit mask for ENET_EIMR_TXB2. */
#define BS_ENET_EIMR_TXB2    (1U)          /*!< Bit field size in bits for ENET_EIMR_TXB2. */

/*! @brief Read current value of the ENET_EIMR_TXB2 field. */
#define BR_ENET_EIMR_TXB2(x) (HW_ENET_EIMR(x).B.TXB2)

/*! @brief Format value for bitfield ENET_EIMR_TXB2. */
#define BF_ENET_EIMR_TXB2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_TXB2) & BM_ENET_EIMR_TXB2)

/*! @brief Set the TXB2 field to a new value. */
#define BW_ENET_EIMR_TXB2(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_TXB2) | BF_ENET_EIMR_TXB2(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field TXF2[7] (RW)
 *
 * Corresponds to interrupt source EIR[TXF2] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. EIR[TXF2] reflects the state
 * of the interrupt signal even if the corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_TXF2    (7U)          /*!< Bit position for ENET_EIMR_TXF2. */
#define BM_ENET_EIMR_TXF2    (0x00000080U) /*!< Bit mask for ENET_EIMR_TXF2. */
#define BS_ENET_EIMR_TXF2    (1U)          /*!< Bit field size in bits for ENET_EIMR_TXF2. */

/*! @brief Read current value of the ENET_EIMR_TXF2 field. */
#define BR_ENET_EIMR_TXF2(x) (HW_ENET_EIMR(x).B.TXF2)

/*! @brief Format value for bitfield ENET_EIMR_TXF2. */
#define BF_ENET_EIMR_TXF2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_TXF2) & BM_ENET_EIMR_TXF2)

/*! @brief Set the TXF2 field to a new value. */
#define BW_ENET_EIMR_TXF2(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_TXF2) | BF_ENET_EIMR_TXF2(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field RXFLUSH_0[12] (RW)
 *
 * Corresponds to interrupt source EIR[RXFLUSH_0] and determines whether an
 * interrupt condition can generate an interrupt. At every module clock, the EIR
 * samples the signal generated by the interrupting source. EIR[RXFLUSH_0] reflects
 * the state of the interrupt signal even if the corresponding EIMR field is
 * cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RXFLUSH_0 (12U)       /*!< Bit position for ENET_EIMR_RXFLUSH_0. */
#define BM_ENET_EIMR_RXFLUSH_0 (0x00001000U) /*!< Bit mask for ENET_EIMR_RXFLUSH_0. */
#define BS_ENET_EIMR_RXFLUSH_0 (1U)        /*!< Bit field size in bits for ENET_EIMR_RXFLUSH_0. */

/*! @brief Read current value of the ENET_EIMR_RXFLUSH_0 field. */
#define BR_ENET_EIMR_RXFLUSH_0(x) (HW_ENET_EIMR(x).B.RXFLUSH_0)

/*! @brief Format value for bitfield ENET_EIMR_RXFLUSH_0. */
#define BF_ENET_EIMR_RXFLUSH_0(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RXFLUSH_0) & BM_ENET_EIMR_RXFLUSH_0)

/*! @brief Set the RXFLUSH_0 field to a new value. */
#define BW_ENET_EIMR_RXFLUSH_0(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RXFLUSH_0) | BF_ENET_EIMR_RXFLUSH_0(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field RXFLUSH_1[13] (RW)
 *
 * Corresponds to interrupt source EIR[RXFLUSH_1] and determines whether an
 * interrupt condition can generate an interrupt. At every module clock, the EIR
 * samples the signal generated by the interrupting source. EIR[RXFLUSH_1] reflects
 * the state of the interrupt signal even if the corresponding EIMR field is
 * cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RXFLUSH_1 (13U)       /*!< Bit position for ENET_EIMR_RXFLUSH_1. */
#define BM_ENET_EIMR_RXFLUSH_1 (0x00002000U) /*!< Bit mask for ENET_EIMR_RXFLUSH_1. */
#define BS_ENET_EIMR_RXFLUSH_1 (1U)        /*!< Bit field size in bits for ENET_EIMR_RXFLUSH_1. */

/*! @brief Read current value of the ENET_EIMR_RXFLUSH_1 field. */
#define BR_ENET_EIMR_RXFLUSH_1(x) (HW_ENET_EIMR(x).B.RXFLUSH_1)

/*! @brief Format value for bitfield ENET_EIMR_RXFLUSH_1. */
#define BF_ENET_EIMR_RXFLUSH_1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RXFLUSH_1) & BM_ENET_EIMR_RXFLUSH_1)

/*! @brief Set the RXFLUSH_1 field to a new value. */
#define BW_ENET_EIMR_RXFLUSH_1(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RXFLUSH_1) | BF_ENET_EIMR_RXFLUSH_1(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field RXFLUSH_2[14] (RW)
 *
 * Corresponds to interrupt source EIR[RXFLUSH_2] and determines whether an
 * interrupt condition can generate an interrupt. At every module clock, the EIR
 * samples the signal generated by the interrupting source. EIR[RXFLUSH_2] reflects
 * the state of the interrupt signal even if the corresponding EIMR field is
 * cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RXFLUSH_2 (14U)       /*!< Bit position for ENET_EIMR_RXFLUSH_2. */
#define BM_ENET_EIMR_RXFLUSH_2 (0x00004000U) /*!< Bit mask for ENET_EIMR_RXFLUSH_2. */
#define BS_ENET_EIMR_RXFLUSH_2 (1U)        /*!< Bit field size in bits for ENET_EIMR_RXFLUSH_2. */

/*! @brief Read current value of the ENET_EIMR_RXFLUSH_2 field. */
#define BR_ENET_EIMR_RXFLUSH_2(x) (HW_ENET_EIMR(x).B.RXFLUSH_2)

/*! @brief Format value for bitfield ENET_EIMR_RXFLUSH_2. */
#define BF_ENET_EIMR_RXFLUSH_2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RXFLUSH_2) & BM_ENET_EIMR_RXFLUSH_2)

/*! @brief Set the RXFLUSH_2 field to a new value. */
#define BW_ENET_EIMR_RXFLUSH_2(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RXFLUSH_2) | BF_ENET_EIMR_RXFLUSH_2(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field TS_TIMER[15] (RW)
 *
 * Corresponds to interrupt source EIR[TS_TIMER] register and determines whether
 * an interrupt condition can generate an interrupt. At every module clock, the
 * EIR samples the signal generated by the interrupting source. The corresponding
 * EIR TS_TIMER field reflects the state of the interrupt signal even if the
 * corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_TS_TIMER (15U)        /*!< Bit position for ENET_EIMR_TS_TIMER. */
#define BM_ENET_EIMR_TS_TIMER (0x00008000U) /*!< Bit mask for ENET_EIMR_TS_TIMER. */
#define BS_ENET_EIMR_TS_TIMER (1U)         /*!< Bit field size in bits for ENET_EIMR_TS_TIMER. */

/*! @brief Read current value of the ENET_EIMR_TS_TIMER field. */
#define BR_ENET_EIMR_TS_TIMER(x) (HW_ENET_EIMR(x).B.TS_TIMER)

/*! @brief Format value for bitfield ENET_EIMR_TS_TIMER. */
#define BF_ENET_EIMR_TS_TIMER(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_TS_TIMER) & BM_ENET_EIMR_TS_TIMER)

/*! @brief Set the TS_TIMER field to a new value. */
#define BW_ENET_EIMR_TS_TIMER(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_TS_TIMER) | BF_ENET_EIMR_TS_TIMER(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field TS_AVAIL[16] (RW)
 *
 * Corresponds to interrupt source EIR[TS_AVAIL] register and determines whether
 * an interrupt condition can generate an interrupt. At every module clock, the
 * EIR samples the signal generated by the interrupting source. The corresponding
 * EIR TS_AVAIL field reflects the state of the interrupt signal even if the
 * corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_TS_AVAIL (16U)        /*!< Bit position for ENET_EIMR_TS_AVAIL. */
#define BM_ENET_EIMR_TS_AVAIL (0x00010000U) /*!< Bit mask for ENET_EIMR_TS_AVAIL. */
#define BS_ENET_EIMR_TS_AVAIL (1U)         /*!< Bit field size in bits for ENET_EIMR_TS_AVAIL. */

/*! @brief Read current value of the ENET_EIMR_TS_AVAIL field. */
#define BR_ENET_EIMR_TS_AVAIL(x) (HW_ENET_EIMR(x).B.TS_AVAIL)

/*! @brief Format value for bitfield ENET_EIMR_TS_AVAIL. */
#define BF_ENET_EIMR_TS_AVAIL(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_TS_AVAIL) & BM_ENET_EIMR_TS_AVAIL)

/*! @brief Set the TS_AVAIL field to a new value. */
#define BW_ENET_EIMR_TS_AVAIL(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_TS_AVAIL) | BF_ENET_EIMR_TS_AVAIL(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field WAKEUP[17] (RW)
 *
 * Corresponds to interrupt source EIR[WAKEUP] register and determines whether
 * an interrupt condition can generate an interrupt. At every module clock, the
 * EIR samples the signal generated by the interrupting source. The corresponding
 * EIR WAKEUP field reflects the state of the interrupt signal even if the
 * corresponding EIMR field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_WAKEUP  (17U)         /*!< Bit position for ENET_EIMR_WAKEUP. */
#define BM_ENET_EIMR_WAKEUP  (0x00020000U) /*!< Bit mask for ENET_EIMR_WAKEUP. */
#define BS_ENET_EIMR_WAKEUP  (1U)          /*!< Bit field size in bits for ENET_EIMR_WAKEUP. */

/*! @brief Read current value of the ENET_EIMR_WAKEUP field. */
#define BR_ENET_EIMR_WAKEUP(x) (HW_ENET_EIMR(x).B.WAKEUP)

/*! @brief Format value for bitfield ENET_EIMR_WAKEUP. */
#define BF_ENET_EIMR_WAKEUP(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_WAKEUP) & BM_ENET_EIMR_WAKEUP)

/*! @brief Set the WAKEUP field to a new value. */
#define BW_ENET_EIMR_WAKEUP(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_WAKEUP) | BF_ENET_EIMR_WAKEUP(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field PLR[18] (RW)
 *
 * Corresponds to interrupt source EIR[PLR] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR PLR field
 * reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_PLR     (18U)         /*!< Bit position for ENET_EIMR_PLR. */
#define BM_ENET_EIMR_PLR     (0x00040000U) /*!< Bit mask for ENET_EIMR_PLR. */
#define BS_ENET_EIMR_PLR     (1U)          /*!< Bit field size in bits for ENET_EIMR_PLR. */

/*! @brief Read current value of the ENET_EIMR_PLR field. */
#define BR_ENET_EIMR_PLR(x)  (HW_ENET_EIMR(x).B.PLR)

/*! @brief Format value for bitfield ENET_EIMR_PLR. */
#define BF_ENET_EIMR_PLR(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_PLR) & BM_ENET_EIMR_PLR)

/*! @brief Set the PLR field to a new value. */
#define BW_ENET_EIMR_PLR(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_PLR) | BF_ENET_EIMR_PLR(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field UN[19] (RW)
 *
 * Corresponds to interrupt source EIR[UN] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples the
 * signal generated by the interrupting source. The corresponding EIR UN field
 * reflects the state of the interrupt signal even if the corresponding EIMR field
 * is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_UN      (19U)         /*!< Bit position for ENET_EIMR_UN. */
#define BM_ENET_EIMR_UN      (0x00080000U) /*!< Bit mask for ENET_EIMR_UN. */
#define BS_ENET_EIMR_UN      (1U)          /*!< Bit field size in bits for ENET_EIMR_UN. */

/*! @brief Read current value of the ENET_EIMR_UN field. */
#define BR_ENET_EIMR_UN(x)   (HW_ENET_EIMR(x).B.UN)

/*! @brief Format value for bitfield ENET_EIMR_UN. */
#define BF_ENET_EIMR_UN(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_UN) & BM_ENET_EIMR_UN)

/*! @brief Set the UN field to a new value. */
#define BW_ENET_EIMR_UN(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_UN) | BF_ENET_EIMR_UN(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field RL[20] (RW)
 *
 * Corresponds to interrupt source EIR[RL] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples the
 * signal generated by the interrupting source. The corresponding EIR RL field
 * reflects the state of the interrupt signal even if the corresponding EIMR field
 * is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RL      (20U)         /*!< Bit position for ENET_EIMR_RL. */
#define BM_ENET_EIMR_RL      (0x00100000U) /*!< Bit mask for ENET_EIMR_RL. */
#define BS_ENET_EIMR_RL      (1U)          /*!< Bit field size in bits for ENET_EIMR_RL. */

/*! @brief Read current value of the ENET_EIMR_RL field. */
#define BR_ENET_EIMR_RL(x)   (HW_ENET_EIMR(x).B.RL)

/*! @brief Format value for bitfield ENET_EIMR_RL. */
#define BF_ENET_EIMR_RL(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RL) & BM_ENET_EIMR_RL)

/*! @brief Set the RL field to a new value. */
#define BW_ENET_EIMR_RL(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RL) | BF_ENET_EIMR_RL(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field LC[21] (RW)
 *
 * Corresponds to interrupt source EIR[LC] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples the
 * signal generated by the interrupting source. The corresponding EIR LC field
 * reflects the state of the interrupt signal even if the corresponding EIMR field
 * is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_LC      (21U)         /*!< Bit position for ENET_EIMR_LC. */
#define BM_ENET_EIMR_LC      (0x00200000U) /*!< Bit mask for ENET_EIMR_LC. */
#define BS_ENET_EIMR_LC      (1U)          /*!< Bit field size in bits for ENET_EIMR_LC. */

/*! @brief Read current value of the ENET_EIMR_LC field. */
#define BR_ENET_EIMR_LC(x)   (HW_ENET_EIMR(x).B.LC)

/*! @brief Format value for bitfield ENET_EIMR_LC. */
#define BF_ENET_EIMR_LC(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_LC) & BM_ENET_EIMR_LC)

/*! @brief Set the LC field to a new value. */
#define BW_ENET_EIMR_LC(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_LC) | BF_ENET_EIMR_LC(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field EBERR[22] (RW)
 *
 * Corresponds to interrupt source EIR[EBERR] and determines whether an
 * interrupt condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR EBERR
 * field reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_EBERR   (22U)         /*!< Bit position for ENET_EIMR_EBERR. */
#define BM_ENET_EIMR_EBERR   (0x00400000U) /*!< Bit mask for ENET_EIMR_EBERR. */
#define BS_ENET_EIMR_EBERR   (1U)          /*!< Bit field size in bits for ENET_EIMR_EBERR. */

/*! @brief Read current value of the ENET_EIMR_EBERR field. */
#define BR_ENET_EIMR_EBERR(x) (HW_ENET_EIMR(x).B.EBERR)

/*! @brief Format value for bitfield ENET_EIMR_EBERR. */
#define BF_ENET_EIMR_EBERR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_EBERR) & BM_ENET_EIMR_EBERR)

/*! @brief Set the EBERR field to a new value. */
#define BW_ENET_EIMR_EBERR(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_EBERR) | BF_ENET_EIMR_EBERR(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field MII[23] (RW)
 *
 * Corresponds to interrupt source EIR[MII] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR MII field
 * reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_MII     (23U)         /*!< Bit position for ENET_EIMR_MII. */
#define BM_ENET_EIMR_MII     (0x00800000U) /*!< Bit mask for ENET_EIMR_MII. */
#define BS_ENET_EIMR_MII     (1U)          /*!< Bit field size in bits for ENET_EIMR_MII. */

/*! @brief Read current value of the ENET_EIMR_MII field. */
#define BR_ENET_EIMR_MII(x)  (HW_ENET_EIMR(x).B.MII)

/*! @brief Format value for bitfield ENET_EIMR_MII. */
#define BF_ENET_EIMR_MII(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_MII) & BM_ENET_EIMR_MII)

/*! @brief Set the MII field to a new value. */
#define BW_ENET_EIMR_MII(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_MII) | BF_ENET_EIMR_MII(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field RXB[24] (RW)
 *
 * Corresponds to interrupt source EIR[RXB] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR RXB field
 * reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RXB     (24U)         /*!< Bit position for ENET_EIMR_RXB. */
#define BM_ENET_EIMR_RXB     (0x01000000U) /*!< Bit mask for ENET_EIMR_RXB. */
#define BS_ENET_EIMR_RXB     (1U)          /*!< Bit field size in bits for ENET_EIMR_RXB. */

/*! @brief Read current value of the ENET_EIMR_RXB field. */
#define BR_ENET_EIMR_RXB(x)  (HW_ENET_EIMR(x).B.RXB)

/*! @brief Format value for bitfield ENET_EIMR_RXB. */
#define BF_ENET_EIMR_RXB(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RXB) & BM_ENET_EIMR_RXB)

/*! @brief Set the RXB field to a new value. */
#define BW_ENET_EIMR_RXB(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RXB) | BF_ENET_EIMR_RXB(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field RXF[25] (RW)
 *
 * Corresponds to interrupt source EIR[RXF] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR RXF field
 * reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 */
/*@{*/
#define BP_ENET_EIMR_RXF     (25U)         /*!< Bit position for ENET_EIMR_RXF. */
#define BM_ENET_EIMR_RXF     (0x02000000U) /*!< Bit mask for ENET_EIMR_RXF. */
#define BS_ENET_EIMR_RXF     (1U)          /*!< Bit field size in bits for ENET_EIMR_RXF. */

/*! @brief Read current value of the ENET_EIMR_RXF field. */
#define BR_ENET_EIMR_RXF(x)  (HW_ENET_EIMR(x).B.RXF)

/*! @brief Format value for bitfield ENET_EIMR_RXF. */
#define BF_ENET_EIMR_RXF(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_RXF) & BM_ENET_EIMR_RXF)

/*! @brief Set the RXF field to a new value. */
#define BW_ENET_EIMR_RXF(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_RXF) | BF_ENET_EIMR_RXF(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field TXB[26] (RW)
 *
 * Corresponds to interrupt source EIR[TXB] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR TXF field
 * reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 *
 * Values:
 * - 0 - The corresponding interrupt source is masked.
 * - 1 - The corresponding interrupt source is not masked.
 */
/*@{*/
#define BP_ENET_EIMR_TXB     (26U)         /*!< Bit position for ENET_EIMR_TXB. */
#define BM_ENET_EIMR_TXB     (0x04000000U) /*!< Bit mask for ENET_EIMR_TXB. */
#define BS_ENET_EIMR_TXB     (1U)          /*!< Bit field size in bits for ENET_EIMR_TXB. */

/*! @brief Read current value of the ENET_EIMR_TXB field. */
#define BR_ENET_EIMR_TXB(x)  (HW_ENET_EIMR(x).B.TXB)

/*! @brief Format value for bitfield ENET_EIMR_TXB. */
#define BF_ENET_EIMR_TXB(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_TXB) & BM_ENET_EIMR_TXB)

/*! @brief Set the TXB field to a new value. */
#define BW_ENET_EIMR_TXB(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_TXB) | BF_ENET_EIMR_TXB(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field TXF[27] (RW)
 *
 * Corresponds to interrupt source EIR[TXF] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR TXF field
 * reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 *
 * Values:
 * - 0 - The corresponding interrupt source is masked.
 * - 1 - The corresponding interrupt source is not masked.
 */
/*@{*/
#define BP_ENET_EIMR_TXF     (27U)         /*!< Bit position for ENET_EIMR_TXF. */
#define BM_ENET_EIMR_TXF     (0x08000000U) /*!< Bit mask for ENET_EIMR_TXF. */
#define BS_ENET_EIMR_TXF     (1U)          /*!< Bit field size in bits for ENET_EIMR_TXF. */

/*! @brief Read current value of the ENET_EIMR_TXF field. */
#define BR_ENET_EIMR_TXF(x)  (HW_ENET_EIMR(x).B.TXF)

/*! @brief Format value for bitfield ENET_EIMR_TXF. */
#define BF_ENET_EIMR_TXF(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_TXF) & BM_ENET_EIMR_TXF)

/*! @brief Set the TXF field to a new value. */
#define BW_ENET_EIMR_TXF(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_TXF) | BF_ENET_EIMR_TXF(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field GRA[28] (RW)
 *
 * Corresponds to interrupt source EIR[GRA] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR GRA field
 * reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 *
 * Values:
 * - 0 - The corresponding interrupt source is masked.
 * - 1 - The corresponding interrupt source is not masked.
 */
/*@{*/
#define BP_ENET_EIMR_GRA     (28U)         /*!< Bit position for ENET_EIMR_GRA. */
#define BM_ENET_EIMR_GRA     (0x10000000U) /*!< Bit mask for ENET_EIMR_GRA. */
#define BS_ENET_EIMR_GRA     (1U)          /*!< Bit field size in bits for ENET_EIMR_GRA. */

/*! @brief Read current value of the ENET_EIMR_GRA field. */
#define BR_ENET_EIMR_GRA(x)  (HW_ENET_EIMR(x).B.GRA)

/*! @brief Format value for bitfield ENET_EIMR_GRA. */
#define BF_ENET_EIMR_GRA(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_GRA) & BM_ENET_EIMR_GRA)

/*! @brief Set the GRA field to a new value. */
#define BW_ENET_EIMR_GRA(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_GRA) | BF_ENET_EIMR_GRA(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field BABT[29] (RW)
 *
 * Corresponds to interrupt source EIR[BABT] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR BABT
 * field reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 *
 * Values:
 * - 0 - The corresponding interrupt source is masked.
 * - 1 - The corresponding interrupt source is not masked.
 */
/*@{*/
#define BP_ENET_EIMR_BABT    (29U)         /*!< Bit position for ENET_EIMR_BABT. */
#define BM_ENET_EIMR_BABT    (0x20000000U) /*!< Bit mask for ENET_EIMR_BABT. */
#define BS_ENET_EIMR_BABT    (1U)          /*!< Bit field size in bits for ENET_EIMR_BABT. */

/*! @brief Read current value of the ENET_EIMR_BABT field. */
#define BR_ENET_EIMR_BABT(x) (HW_ENET_EIMR(x).B.BABT)

/*! @brief Format value for bitfield ENET_EIMR_BABT. */
#define BF_ENET_EIMR_BABT(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_BABT) & BM_ENET_EIMR_BABT)

/*! @brief Set the BABT field to a new value. */
#define BW_ENET_EIMR_BABT(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_BABT) | BF_ENET_EIMR_BABT(v)))
/*@}*/

/*!
 * @name Register ENET_EIMR, field BABR[30] (RW)
 *
 * Corresponds to interrupt source EIR[BABR] and determines whether an interrupt
 * condition can generate an interrupt. At every module clock, the EIR samples
 * the signal generated by the interrupting source. The corresponding EIR BABR
 * field reflects the state of the interrupt signal even if the corresponding EIMR
 * field is cleared.
 *
 * Values:
 * - 0 - The corresponding interrupt source is masked.
 * - 1 - The corresponding interrupt source is not masked.
 */
/*@{*/
#define BP_ENET_EIMR_BABR    (30U)         /*!< Bit position for ENET_EIMR_BABR. */
#define BM_ENET_EIMR_BABR    (0x40000000U) /*!< Bit mask for ENET_EIMR_BABR. */
#define BS_ENET_EIMR_BABR    (1U)          /*!< Bit field size in bits for ENET_EIMR_BABR. */

/*! @brief Read current value of the ENET_EIMR_BABR field. */
#define BR_ENET_EIMR_BABR(x) (HW_ENET_EIMR(x).B.BABR)

/*! @brief Format value for bitfield ENET_EIMR_BABR. */
#define BF_ENET_EIMR_BABR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_EIMR_BABR) & BM_ENET_EIMR_BABR)

/*! @brief Set the BABR field to a new value. */
#define BW_ENET_EIMR_BABR(x, v) (HW_ENET_EIMR_WR(x, (HW_ENET_EIMR_RD(x) & ~BM_ENET_EIMR_BABR) | BF_ENET_EIMR_BABR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RDAR - Receive Descriptor Active Register - Ring 0
 ******************************************************************************/

/*!
 * @brief HW_ENET_RDAR - Receive Descriptor Active Register - Ring 0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * RDAR is a command register, written by the user, to indicate that the receive
 * descriptor ring 0 has been updated, that is, that the driver produced empty
 * receive buffers with the empty bit set.
 */
typedef union _hw_enet_rdar
{
    uint32_t U;
    struct _hw_enet_rdar_bitfields
    {
        uint32_t RESERVED0 : 24;       /*!< [23:0]  */
        uint32_t RDAR : 1;             /*!< [24] Receive Descriptor Active */
        uint32_t RESERVED1 : 7;        /*!< [31:25]  */
    } B;
} hw_enet_rdar_t;

/*!
 * @name Constants and macros for entire ENET_RDAR register
 */
/*@{*/
#define HW_ENET_RDAR_ADDR(x)     ((uintptr_t)(x) + 0x10U)

#define HW_ENET_RDAR(x)          (*(__IO hw_enet_rdar_t *) HW_ENET_RDAR_ADDR(x))
#define HW_ENET_RDAR_RD(x)       (HW_ENET_RDAR(x).U)
#define HW_ENET_RDAR_WR(x, v)    (HW_ENET_RDAR(x).U = (v))
#define HW_ENET_RDAR_SET(x, v)   (HW_ENET_RDAR_WR(x, HW_ENET_RDAR_RD(x) |  (v)))
#define HW_ENET_RDAR_CLR(x, v)   (HW_ENET_RDAR_WR(x, HW_ENET_RDAR_RD(x) & ~(v)))
#define HW_ENET_RDAR_TOG(x, v)   (HW_ENET_RDAR_WR(x, HW_ENET_RDAR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RDAR bitfields
 */

/*!
 * @name Register ENET_RDAR, field RDAR[24] (RW)
 *
 * Always set to 1 when this register is written, regardless of the value
 * written. This field is cleared by the MAC device when no additional empty
 * descriptors remain in the receive ring. It is also cleared when ECR[ETHEREN] transitions
 * from set to cleared or when ECR[RESET] is set.
 */
/*@{*/
#define BP_ENET_RDAR_RDAR    (24U)         /*!< Bit position for ENET_RDAR_RDAR. */
#define BM_ENET_RDAR_RDAR    (0x01000000U) /*!< Bit mask for ENET_RDAR_RDAR. */
#define BS_ENET_RDAR_RDAR    (1U)          /*!< Bit field size in bits for ENET_RDAR_RDAR. */

/*! @brief Read current value of the ENET_RDAR_RDAR field. */
#define BR_ENET_RDAR_RDAR(x) (HW_ENET_RDAR(x).B.RDAR)

/*! @brief Format value for bitfield ENET_RDAR_RDAR. */
#define BF_ENET_RDAR_RDAR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RDAR_RDAR) & BM_ENET_RDAR_RDAR)

/*! @brief Set the RDAR field to a new value. */
#define BW_ENET_RDAR_RDAR(x, v) (HW_ENET_RDAR_WR(x, (HW_ENET_RDAR_RD(x) & ~BM_ENET_RDAR_RDAR) | BF_ENET_RDAR_RDAR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TDAR - Transmit Descriptor Active Register - Ring 0
 ******************************************************************************/

/*!
 * @brief HW_ENET_TDAR - Transmit Descriptor Active Register - Ring 0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The TDAR is a command register that the user writes to indicate that the
 * transmit descriptor ring 0 has been updated, that is, that transmit buffers have
 * been produced by the driver with the ready bit set in the buffer descriptor.
 * The TDAR register is cleared at reset, when ECR[ETHEREN] transitions from set to
 * cleared, or when ECR[RESET] is set.
 */
typedef union _hw_enet_tdar
{
    uint32_t U;
    struct _hw_enet_tdar_bitfields
    {
        uint32_t RESERVED0 : 24;       /*!< [23:0]  */
        uint32_t TDAR : 1;             /*!< [24] Transmit Descriptor Active */
        uint32_t RESERVED1 : 7;        /*!< [31:25]  */
    } B;
} hw_enet_tdar_t;

/*!
 * @name Constants and macros for entire ENET_TDAR register
 */
/*@{*/
#define HW_ENET_TDAR_ADDR(x)     ((uintptr_t)(x) + 0x14U)

#define HW_ENET_TDAR(x)          (*(__IO hw_enet_tdar_t *) HW_ENET_TDAR_ADDR(x))
#define HW_ENET_TDAR_RD(x)       (HW_ENET_TDAR(x).U)
#define HW_ENET_TDAR_WR(x, v)    (HW_ENET_TDAR(x).U = (v))
#define HW_ENET_TDAR_SET(x, v)   (HW_ENET_TDAR_WR(x, HW_ENET_TDAR_RD(x) |  (v)))
#define HW_ENET_TDAR_CLR(x, v)   (HW_ENET_TDAR_WR(x, HW_ENET_TDAR_RD(x) & ~(v)))
#define HW_ENET_TDAR_TOG(x, v)   (HW_ENET_TDAR_WR(x, HW_ENET_TDAR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TDAR bitfields
 */

/*!
 * @name Register ENET_TDAR, field TDAR[24] (RW)
 *
 * Always set to 1 when this register is written, regardless of the value
 * written. This bit is cleared by the MAC device when no additional ready descriptors
 * remain in the transmit ring. Also cleared when ECR[ETHEREN] transitions from
 * set to cleared or when ECR[RESET] is set.
 */
/*@{*/
#define BP_ENET_TDAR_TDAR    (24U)         /*!< Bit position for ENET_TDAR_TDAR. */
#define BM_ENET_TDAR_TDAR    (0x01000000U) /*!< Bit mask for ENET_TDAR_TDAR. */
#define BS_ENET_TDAR_TDAR    (1U)          /*!< Bit field size in bits for ENET_TDAR_TDAR. */

/*! @brief Read current value of the ENET_TDAR_TDAR field. */
#define BR_ENET_TDAR_TDAR(x) (HW_ENET_TDAR(x).B.TDAR)

/*! @brief Format value for bitfield ENET_TDAR_TDAR. */
#define BF_ENET_TDAR_TDAR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TDAR_TDAR) & BM_ENET_TDAR_TDAR)

/*! @brief Set the TDAR field to a new value. */
#define BW_ENET_TDAR_TDAR(x, v) (HW_ENET_TDAR_WR(x, (HW_ENET_TDAR_RD(x) & ~BM_ENET_TDAR_TDAR) | BF_ENET_TDAR_TDAR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_ECR - Ethernet Control Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_ECR - Ethernet Control Register (RW)
 *
 * Reset value: 0x70000000U
 *
 * ECR is a read/write user register, though hardware may also alter fields in
 * this register. It controls many of the high level features of the Ethernet MAC,
 * including legacy FEC support through the EN1588 field.
 */
typedef union _hw_enet_ecr
{
    uint32_t U;
    struct _hw_enet_ecr_bitfields
    {
        uint32_t RESET : 1;            /*!< [0] Ethernet MAC Reset */
        uint32_t ETHEREN : 1;          /*!< [1] Ethernet Enable */
        uint32_t MAGICEN : 1;          /*!< [2] Magic Packet Detection Enable */
        uint32_t SLEEP : 1;            /*!< [3] Sleep Mode Enable */
        uint32_t EN1588 : 1;           /*!< [4] EN1588 Enable */
        uint32_t SPEED : 1;            /*!< [5]  */
        uint32_t DBGEN : 1;            /*!< [6] Debug Enable */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t DBSWP : 1;            /*!< [8] Descriptor Byte Swapping Enable */
        uint32_t SVLANEN : 1;          /*!< [9] S-VLAN enable */
        uint32_t VLANUSE2ND : 1;       /*!< [10] VLAN use second tag */
        uint32_t SVLANDBL : 1;         /*!< [11] S-VLAN double tag */
        uint32_t RESERVED1 : 20;       /*!< [31:12]  */
    } B;
} hw_enet_ecr_t;

/*!
 * @name Constants and macros for entire ENET_ECR register
 */
/*@{*/
#define HW_ENET_ECR_ADDR(x)      ((uintptr_t)(x) + 0x24U)

#define HW_ENET_ECR(x)           (*(__IO hw_enet_ecr_t *) HW_ENET_ECR_ADDR(x))
#define HW_ENET_ECR_RD(x)        (HW_ENET_ECR(x).U)
#define HW_ENET_ECR_WR(x, v)     (HW_ENET_ECR(x).U = (v))
#define HW_ENET_ECR_SET(x, v)    (HW_ENET_ECR_WR(x, HW_ENET_ECR_RD(x) |  (v)))
#define HW_ENET_ECR_CLR(x, v)    (HW_ENET_ECR_WR(x, HW_ENET_ECR_RD(x) & ~(v)))
#define HW_ENET_ECR_TOG(x, v)    (HW_ENET_ECR_WR(x, HW_ENET_ECR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_ECR bitfields
 */

/*!
 * @name Register ENET_ECR, field RESET[0] (RW)
 *
 * When this field is set, it clears the ETHEREN field.
 */
/*@{*/
#define BP_ENET_ECR_RESET    (0U)          /*!< Bit position for ENET_ECR_RESET. */
#define BM_ENET_ECR_RESET    (0x00000001U) /*!< Bit mask for ENET_ECR_RESET. */
#define BS_ENET_ECR_RESET    (1U)          /*!< Bit field size in bits for ENET_ECR_RESET. */

/*! @brief Read current value of the ENET_ECR_RESET field. */
#define BR_ENET_ECR_RESET(x) (HW_ENET_ECR(x).B.RESET)

/*! @brief Format value for bitfield ENET_ECR_RESET. */
#define BF_ENET_ECR_RESET(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_RESET) & BM_ENET_ECR_RESET)

/*! @brief Set the RESET field to a new value. */
#define BW_ENET_ECR_RESET(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_RESET) | BF_ENET_ECR_RESET(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field ETHEREN[1] (RW)
 *
 * Enables/disables the Ethernet MAC. When the MAC is disabled, the buffer
 * descriptors for an aborted transmit frame are not updated. The uDMA, buffer
 * descriptor, and FIFO control logic are reset, including the buffer descriptor and
 * FIFO pointers. Hardware clears this field under the following conditions: RESET
 * is set by software An error condition causes the EBERR field to set. ETHEREN
 * must be set at the very last step during ENET
 * configuration/setup/initialization, only after all other ENET-related registers have been configured. If ETHEREN
 * is cleared to 0 by software then next time ETHEREN is set, the EIR interrupts
 * must cleared to 0 due to previous pending interrupts.
 *
 * Values:
 * - 0 - Reception immediately stops and transmission stops after a bad CRC is
 *     appended to any currently transmitted frame.
 * - 1 - MAC is enabled, and reception and transmission are possible.
 */
/*@{*/
#define BP_ENET_ECR_ETHEREN  (1U)          /*!< Bit position for ENET_ECR_ETHEREN. */
#define BM_ENET_ECR_ETHEREN  (0x00000002U) /*!< Bit mask for ENET_ECR_ETHEREN. */
#define BS_ENET_ECR_ETHEREN  (1U)          /*!< Bit field size in bits for ENET_ECR_ETHEREN. */

/*! @brief Read current value of the ENET_ECR_ETHEREN field. */
#define BR_ENET_ECR_ETHEREN(x) (HW_ENET_ECR(x).B.ETHEREN)

/*! @brief Format value for bitfield ENET_ECR_ETHEREN. */
#define BF_ENET_ECR_ETHEREN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_ETHEREN) & BM_ENET_ECR_ETHEREN)

/*! @brief Set the ETHEREN field to a new value. */
#define BW_ENET_ECR_ETHEREN(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_ETHEREN) | BF_ENET_ECR_ETHEREN(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field MAGICEN[2] (RW)
 *
 * Enables/disables magic packet detection. MAGICEN is relevant only if the
 * SLEEP field is set. If MAGICEN is set, changing the SLEEP field enables/disables
 * sleep mode and magic packet detection.
 *
 * Values:
 * - 0 - Magic detection logic disabled.
 * - 1 - The MAC core detects magic packets and asserts EIR[WAKEUP] when a frame
 *     is detected.
 */
/*@{*/
#define BP_ENET_ECR_MAGICEN  (2U)          /*!< Bit position for ENET_ECR_MAGICEN. */
#define BM_ENET_ECR_MAGICEN  (0x00000004U) /*!< Bit mask for ENET_ECR_MAGICEN. */
#define BS_ENET_ECR_MAGICEN  (1U)          /*!< Bit field size in bits for ENET_ECR_MAGICEN. */

/*! @brief Read current value of the ENET_ECR_MAGICEN field. */
#define BR_ENET_ECR_MAGICEN(x) (HW_ENET_ECR(x).B.MAGICEN)

/*! @brief Format value for bitfield ENET_ECR_MAGICEN. */
#define BF_ENET_ECR_MAGICEN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_MAGICEN) & BM_ENET_ECR_MAGICEN)

/*! @brief Set the MAGICEN field to a new value. */
#define BW_ENET_ECR_MAGICEN(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_MAGICEN) | BF_ENET_ECR_MAGICEN(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field SLEEP[3] (RW)
 *
 * Values:
 * - 0 - Normal operating mode.
 * - 1 - Sleep mode.
 */
/*@{*/
#define BP_ENET_ECR_SLEEP    (3U)          /*!< Bit position for ENET_ECR_SLEEP. */
#define BM_ENET_ECR_SLEEP    (0x00000008U) /*!< Bit mask for ENET_ECR_SLEEP. */
#define BS_ENET_ECR_SLEEP    (1U)          /*!< Bit field size in bits for ENET_ECR_SLEEP. */

/*! @brief Read current value of the ENET_ECR_SLEEP field. */
#define BR_ENET_ECR_SLEEP(x) (HW_ENET_ECR(x).B.SLEEP)

/*! @brief Format value for bitfield ENET_ECR_SLEEP. */
#define BF_ENET_ECR_SLEEP(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_SLEEP) & BM_ENET_ECR_SLEEP)

/*! @brief Set the SLEEP field to a new value. */
#define BW_ENET_ECR_SLEEP(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_SLEEP) | BF_ENET_ECR_SLEEP(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field EN1588[4] (RW)
 *
 * Enables enhanced functionality of the MAC.
 *
 * Values:
 * - 0 - Legacy FEC buffer descriptors and functions enabled.
 * - 1 - Enhanced frame time-stamping functions enabled.
 */
/*@{*/
#define BP_ENET_ECR_EN1588   (4U)          /*!< Bit position for ENET_ECR_EN1588. */
#define BM_ENET_ECR_EN1588   (0x00000010U) /*!< Bit mask for ENET_ECR_EN1588. */
#define BS_ENET_ECR_EN1588   (1U)          /*!< Bit field size in bits for ENET_ECR_EN1588. */

/*! @brief Read current value of the ENET_ECR_EN1588 field. */
#define BR_ENET_ECR_EN1588(x) (HW_ENET_ECR(x).B.EN1588)

/*! @brief Format value for bitfield ENET_ECR_EN1588. */
#define BF_ENET_ECR_EN1588(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_EN1588) & BM_ENET_ECR_EN1588)

/*! @brief Set the EN1588 field to a new value. */
#define BW_ENET_ECR_EN1588(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_EN1588) | BF_ENET_ECR_EN1588(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field SPEED[5] (RW)
 *
 * Selects between 10/100-Mbit/s and 1000-Mbit/s modes of operation.
 *
 * Values:
 * - 0 - 10/100-Mbit/s mode
 * - 1 - 1000-Mbit/s mode
 */
/*@{*/
#define BP_ENET_ECR_SPEED    (5U)          /*!< Bit position for ENET_ECR_SPEED. */
#define BM_ENET_ECR_SPEED    (0x00000020U) /*!< Bit mask for ENET_ECR_SPEED. */
#define BS_ENET_ECR_SPEED    (1U)          /*!< Bit field size in bits for ENET_ECR_SPEED. */

/*! @brief Read current value of the ENET_ECR_SPEED field. */
#define BR_ENET_ECR_SPEED(x) (HW_ENET_ECR(x).B.SPEED)

/*! @brief Format value for bitfield ENET_ECR_SPEED. */
#define BF_ENET_ECR_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_SPEED) & BM_ENET_ECR_SPEED)

/*! @brief Set the SPEED field to a new value. */
#define BW_ENET_ECR_SPEED(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_SPEED) | BF_ENET_ECR_SPEED(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field DBGEN[6] (RW)
 *
 * Enables the MAC to enter hardware freeze mode when the device enters debug
 * mode.
 *
 * Values:
 * - 0 - MAC continues operation in debug mode.
 * - 1 - MAC enters hardware freeze mode when the processor is in debug mode.
 */
/*@{*/
#define BP_ENET_ECR_DBGEN    (6U)          /*!< Bit position for ENET_ECR_DBGEN. */
#define BM_ENET_ECR_DBGEN    (0x00000040U) /*!< Bit mask for ENET_ECR_DBGEN. */
#define BS_ENET_ECR_DBGEN    (1U)          /*!< Bit field size in bits for ENET_ECR_DBGEN. */

/*! @brief Read current value of the ENET_ECR_DBGEN field. */
#define BR_ENET_ECR_DBGEN(x) (HW_ENET_ECR(x).B.DBGEN)

/*! @brief Format value for bitfield ENET_ECR_DBGEN. */
#define BF_ENET_ECR_DBGEN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_DBGEN) & BM_ENET_ECR_DBGEN)

/*! @brief Set the DBGEN field to a new value. */
#define BW_ENET_ECR_DBGEN(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_DBGEN) | BF_ENET_ECR_DBGEN(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field DBSWP[8] (RW)
 *
 * Swaps the byte locations of the buffer descriptors. This field must be
 * written to 1 after reset.
 *
 * Values:
 * - 0 - The buffer descriptor bytes are not swapped to support big-endian
 *     devices.
 * - 1 - The buffer descriptor bytes are swapped to support little-endian
 *     devices.
 */
/*@{*/
#define BP_ENET_ECR_DBSWP    (8U)          /*!< Bit position for ENET_ECR_DBSWP. */
#define BM_ENET_ECR_DBSWP    (0x00000100U) /*!< Bit mask for ENET_ECR_DBSWP. */
#define BS_ENET_ECR_DBSWP    (1U)          /*!< Bit field size in bits for ENET_ECR_DBSWP. */

/*! @brief Read current value of the ENET_ECR_DBSWP field. */
#define BR_ENET_ECR_DBSWP(x) (HW_ENET_ECR(x).B.DBSWP)

/*! @brief Format value for bitfield ENET_ECR_DBSWP. */
#define BF_ENET_ECR_DBSWP(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_DBSWP) & BM_ENET_ECR_DBSWP)

/*! @brief Set the DBSWP field to a new value. */
#define BW_ENET_ECR_DBSWP(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_DBSWP) | BF_ENET_ECR_DBSWP(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field SVLANEN[9] (RW)
 *
 * Enable additional detection of S-VLAN tag according to IEEE802.1Q.
 *
 * Values:
 * - 0 - Only the EtherType 0x8100 will be considered for VLAN detection.
 * - 1 - The EtherType 0x88a8 will be considered in addition to 0x8100 (C-VLAN)
 *     to identify a VLAN frame in receive. When a VLAN frame is identified, the
 *     two bytes following the VLAN type are extracted and used by the
 *     classification match comparators, RCMRn.
 */
/*@{*/
#define BP_ENET_ECR_SVLANEN  (9U)          /*!< Bit position for ENET_ECR_SVLANEN. */
#define BM_ENET_ECR_SVLANEN  (0x00000200U) /*!< Bit mask for ENET_ECR_SVLANEN. */
#define BS_ENET_ECR_SVLANEN  (1U)          /*!< Bit field size in bits for ENET_ECR_SVLANEN. */

/*! @brief Read current value of the ENET_ECR_SVLANEN field. */
#define BR_ENET_ECR_SVLANEN(x) (HW_ENET_ECR(x).B.SVLANEN)

/*! @brief Format value for bitfield ENET_ECR_SVLANEN. */
#define BF_ENET_ECR_SVLANEN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_SVLANEN) & BM_ENET_ECR_SVLANEN)

/*! @brief Set the SVLANEN field to a new value. */
#define BW_ENET_ECR_SVLANEN(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_SVLANEN) | BF_ENET_ECR_SVLANEN(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field VLANUSE2ND[10] (RW)
 *
 * Values:
 * - 0 - Always extract data from the first VLAN tag if it exists.
 * - 1 - When a double-tagged frame is detected, the data of the second tag is
 *     extracted for further processing. A double-tagged frame is defined as: The
 *     first tag can be a C-VLAN or a S-VLAN (if SVLAN_ENA = 1) The second tag
 *     must be a C-VLAN
 */
/*@{*/
#define BP_ENET_ECR_VLANUSE2ND (10U)       /*!< Bit position for ENET_ECR_VLANUSE2ND. */
#define BM_ENET_ECR_VLANUSE2ND (0x00000400U) /*!< Bit mask for ENET_ECR_VLANUSE2ND. */
#define BS_ENET_ECR_VLANUSE2ND (1U)        /*!< Bit field size in bits for ENET_ECR_VLANUSE2ND. */

/*! @brief Read current value of the ENET_ECR_VLANUSE2ND field. */
#define BR_ENET_ECR_VLANUSE2ND(x) (HW_ENET_ECR(x).B.VLANUSE2ND)

/*! @brief Format value for bitfield ENET_ECR_VLANUSE2ND. */
#define BF_ENET_ECR_VLANUSE2ND(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_VLANUSE2ND) & BM_ENET_ECR_VLANUSE2ND)

/*! @brief Set the VLANUSE2ND field to a new value. */
#define BW_ENET_ECR_VLANUSE2ND(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_VLANUSE2ND) | BF_ENET_ECR_VLANUSE2ND(v)))
/*@}*/

/*!
 * @name Register ENET_ECR, field SVLANDBL[11] (RW)
 *
 * If enabled, S-VLAN detection requires a double-tagged frame to define a frame
 * as being a VLAN frame. The following rules apply: If the first tag is the
 * S-VLAN type, it must be followed by a second tag with the C-VLAN type to declare
 * the frame as VLAN frame. If the first tag is the S-VLAN type but no 2nd tag
 * follows, it is not considered a VLAN frame but instead treated as an untagged
 * frame. If the first tag is the C-VLAN type, it is considered a VLAN frame as
 * normal. VLANUSE2ND can be used to determine from which tag the data should be
 * extracted. This applies only if SVLAN_EN = 1, ignored otherwise.
 */
/*@{*/
#define BP_ENET_ECR_SVLANDBL (11U)         /*!< Bit position for ENET_ECR_SVLANDBL. */
#define BM_ENET_ECR_SVLANDBL (0x00000800U) /*!< Bit mask for ENET_ECR_SVLANDBL. */
#define BS_ENET_ECR_SVLANDBL (1U)          /*!< Bit field size in bits for ENET_ECR_SVLANDBL. */

/*! @brief Read current value of the ENET_ECR_SVLANDBL field. */
#define BR_ENET_ECR_SVLANDBL(x) (HW_ENET_ECR(x).B.SVLANDBL)

/*! @brief Format value for bitfield ENET_ECR_SVLANDBL. */
#define BF_ENET_ECR_SVLANDBL(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ECR_SVLANDBL) & BM_ENET_ECR_SVLANDBL)

/*! @brief Set the SVLANDBL field to a new value. */
#define BW_ENET_ECR_SVLANDBL(x, v) (HW_ENET_ECR_WR(x, (HW_ENET_ECR_RD(x) & ~BM_ENET_ECR_SVLANDBL) | BF_ENET_ECR_SVLANDBL(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_MMFR - MII Management Frame Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_MMFR - MII Management Frame Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Writing to MMFR triggers a management frame transaction to the PHY device
 * unless MSCR is programmed to zero. If MSCR is changed from zero to non-zero
 * during a write to MMFR, an MII frame is generated with the data previously written
 * to the MMFR. This allows MMFR and MSCR to be programmed in either order if
 * MSCR is currently zero. If the MMFR register is written while frame generation is
 * in progress, the frame contents are altered. Software must use the EIR[MII]
 * interrupt indication to avoid writing to the MMFR register while frame
 * generation is in progress.
 */
typedef union _hw_enet_mmfr
{
    uint32_t U;
    struct _hw_enet_mmfr_bitfields
    {
        uint32_t DATA : 16;            /*!< [15:0] Management Frame Data */
        uint32_t TA : 2;               /*!< [17:16] Turn Around */
        uint32_t RA : 5;               /*!< [22:18] Register Address */
        uint32_t PA : 5;               /*!< [27:23] PHY Address */
        uint32_t OP : 2;               /*!< [29:28] Operation Code */
        uint32_t ST : 2;               /*!< [31:30] Start Of Frame Delimiter */
    } B;
} hw_enet_mmfr_t;

/*!
 * @name Constants and macros for entire ENET_MMFR register
 */
/*@{*/
#define HW_ENET_MMFR_ADDR(x)     ((uintptr_t)(x) + 0x40U)

#define HW_ENET_MMFR(x)          (*(__IO hw_enet_mmfr_t *) HW_ENET_MMFR_ADDR(x))
#define HW_ENET_MMFR_RD(x)       (HW_ENET_MMFR(x).U)
#define HW_ENET_MMFR_WR(x, v)    (HW_ENET_MMFR(x).U = (v))
#define HW_ENET_MMFR_SET(x, v)   (HW_ENET_MMFR_WR(x, HW_ENET_MMFR_RD(x) |  (v)))
#define HW_ENET_MMFR_CLR(x, v)   (HW_ENET_MMFR_WR(x, HW_ENET_MMFR_RD(x) & ~(v)))
#define HW_ENET_MMFR_TOG(x, v)   (HW_ENET_MMFR_WR(x, HW_ENET_MMFR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_MMFR bitfields
 */

/*!
 * @name Register ENET_MMFR, field DATA[15:0] (RW)
 *
 * This is the field for data to be written to or read from the PHY register.
 */
/*@{*/
#define BP_ENET_MMFR_DATA    (0U)          /*!< Bit position for ENET_MMFR_DATA. */
#define BM_ENET_MMFR_DATA    (0x0000FFFFU) /*!< Bit mask for ENET_MMFR_DATA. */
#define BS_ENET_MMFR_DATA    (16U)         /*!< Bit field size in bits for ENET_MMFR_DATA. */

/*! @brief Read current value of the ENET_MMFR_DATA field. */
#define BR_ENET_MMFR_DATA(x) (HW_ENET_MMFR(x).B.DATA)

/*! @brief Format value for bitfield ENET_MMFR_DATA. */
#define BF_ENET_MMFR_DATA(v) ((uint32_t)((uint32_t)(v) << BP_ENET_MMFR_DATA) & BM_ENET_MMFR_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_ENET_MMFR_DATA(x, v) (HW_ENET_MMFR_WR(x, (HW_ENET_MMFR_RD(x) & ~BM_ENET_MMFR_DATA) | BF_ENET_MMFR_DATA(v)))
/*@}*/

/*!
 * @name Register ENET_MMFR, field TA[17:16] (RW)
 *
 * This field must be programmed to 10 to generate a valid MII management frame.
 */
/*@{*/
#define BP_ENET_MMFR_TA      (16U)         /*!< Bit position for ENET_MMFR_TA. */
#define BM_ENET_MMFR_TA      (0x00030000U) /*!< Bit mask for ENET_MMFR_TA. */
#define BS_ENET_MMFR_TA      (2U)          /*!< Bit field size in bits for ENET_MMFR_TA. */

/*! @brief Read current value of the ENET_MMFR_TA field. */
#define BR_ENET_MMFR_TA(x)   (HW_ENET_MMFR(x).B.TA)

/*! @brief Format value for bitfield ENET_MMFR_TA. */
#define BF_ENET_MMFR_TA(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_MMFR_TA) & BM_ENET_MMFR_TA)

/*! @brief Set the TA field to a new value. */
#define BW_ENET_MMFR_TA(x, v) (HW_ENET_MMFR_WR(x, (HW_ENET_MMFR_RD(x) & ~BM_ENET_MMFR_TA) | BF_ENET_MMFR_TA(v)))
/*@}*/

/*!
 * @name Register ENET_MMFR, field RA[22:18] (RW)
 *
 * See (Clause 22) or (Clause 45) for correct value.
 */
/*@{*/
#define BP_ENET_MMFR_RA      (18U)         /*!< Bit position for ENET_MMFR_RA. */
#define BM_ENET_MMFR_RA      (0x007C0000U) /*!< Bit mask for ENET_MMFR_RA. */
#define BS_ENET_MMFR_RA      (5U)          /*!< Bit field size in bits for ENET_MMFR_RA. */

/*! @brief Read current value of the ENET_MMFR_RA field. */
#define BR_ENET_MMFR_RA(x)   (HW_ENET_MMFR(x).B.RA)

/*! @brief Format value for bitfield ENET_MMFR_RA. */
#define BF_ENET_MMFR_RA(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_MMFR_RA) & BM_ENET_MMFR_RA)

/*! @brief Set the RA field to a new value. */
#define BW_ENET_MMFR_RA(x, v) (HW_ENET_MMFR_WR(x, (HW_ENET_MMFR_RD(x) & ~BM_ENET_MMFR_RA) | BF_ENET_MMFR_RA(v)))
/*@}*/

/*!
 * @name Register ENET_MMFR, field PA[27:23] (RW)
 *
 * See (Clause 22) or (Clause 45) for correct value.
 */
/*@{*/
#define BP_ENET_MMFR_PA      (23U)         /*!< Bit position for ENET_MMFR_PA. */
#define BM_ENET_MMFR_PA      (0x0F800000U) /*!< Bit mask for ENET_MMFR_PA. */
#define BS_ENET_MMFR_PA      (5U)          /*!< Bit field size in bits for ENET_MMFR_PA. */

/*! @brief Read current value of the ENET_MMFR_PA field. */
#define BR_ENET_MMFR_PA(x)   (HW_ENET_MMFR(x).B.PA)

/*! @brief Format value for bitfield ENET_MMFR_PA. */
#define BF_ENET_MMFR_PA(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_MMFR_PA) & BM_ENET_MMFR_PA)

/*! @brief Set the PA field to a new value. */
#define BW_ENET_MMFR_PA(x, v) (HW_ENET_MMFR_WR(x, (HW_ENET_MMFR_RD(x) & ~BM_ENET_MMFR_PA) | BF_ENET_MMFR_PA(v)))
/*@}*/

/*!
 * @name Register ENET_MMFR, field OP[29:28] (RW)
 *
 * See (Clause 22) or (Clause 45) for correct value.
 */
/*@{*/
#define BP_ENET_MMFR_OP      (28U)         /*!< Bit position for ENET_MMFR_OP. */
#define BM_ENET_MMFR_OP      (0x30000000U) /*!< Bit mask for ENET_MMFR_OP. */
#define BS_ENET_MMFR_OP      (2U)          /*!< Bit field size in bits for ENET_MMFR_OP. */

/*! @brief Read current value of the ENET_MMFR_OP field. */
#define BR_ENET_MMFR_OP(x)   (HW_ENET_MMFR(x).B.OP)

/*! @brief Format value for bitfield ENET_MMFR_OP. */
#define BF_ENET_MMFR_OP(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_MMFR_OP) & BM_ENET_MMFR_OP)

/*! @brief Set the OP field to a new value. */
#define BW_ENET_MMFR_OP(x, v) (HW_ENET_MMFR_WR(x, (HW_ENET_MMFR_RD(x) & ~BM_ENET_MMFR_OP) | BF_ENET_MMFR_OP(v)))
/*@}*/

/*!
 * @name Register ENET_MMFR, field ST[31:30] (RW)
 *
 * See (Clause 22) or (Clause 45) for correct value.
 */
/*@{*/
#define BP_ENET_MMFR_ST      (30U)         /*!< Bit position for ENET_MMFR_ST. */
#define BM_ENET_MMFR_ST      (0xC0000000U) /*!< Bit mask for ENET_MMFR_ST. */
#define BS_ENET_MMFR_ST      (2U)          /*!< Bit field size in bits for ENET_MMFR_ST. */

/*! @brief Read current value of the ENET_MMFR_ST field. */
#define BR_ENET_MMFR_ST(x)   (HW_ENET_MMFR(x).B.ST)

/*! @brief Format value for bitfield ENET_MMFR_ST. */
#define BF_ENET_MMFR_ST(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_MMFR_ST) & BM_ENET_MMFR_ST)

/*! @brief Set the ST field to a new value. */
#define BW_ENET_MMFR_ST(x, v) (HW_ENET_MMFR_WR(x, (HW_ENET_MMFR_RD(x) & ~BM_ENET_MMFR_ST) | BF_ENET_MMFR_ST(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_MSCR - MII Speed Control Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_MSCR - MII Speed Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * MSCR provides control of the MII clock (MDC pin) frequency and allows a
 * preamble drop on the MII management frame. The MII_SPEED field must be programmed
 * with a value to provide an MDC frequency of less than or equal to 2.5 MHz to be
 * compliant with the IEEE 802.3 MII specification. The MII_SPEED must be set to
 * a non-zero value to source a read or write management frame. After the
 * management frame is complete, the MSCR register may optionally be cleared to turn
 * off MDC. The MDC signal generated has a 50% duty cycle except when MII_SPEED
 * changes during operation. This change takes effect following a rising or falling
 * edge of MDC. For example, if the internal module clock (i.e., IPS bus clock)
 * is 25 MHz, programming MII_SPEED to 0x4 results in an MDC as given in the
 * following equation: MII clock frequency = 25 MHz / ((4 + 1) x 2) = 2.5 MHz The
 * following table shows the optimum values for MII_SPEED as a function of IPS bus
 * clock frequency. Programming Examples for MSCR Internal module clock frequency
 * MSCR [MII_SPEED] MDC frequency 25 MHz 0x4 2.50 MHz 33 MHz 0x6 2.36 MHz 40 MHz
 * 0x7 2.50 MHz 50 MHz 0x9 2.50 MHz 66 MHz 0xD 2.36 MHz
 */
typedef union _hw_enet_mscr
{
    uint32_t U;
    struct _hw_enet_mscr_bitfields
    {
        uint32_t RESERVED0 : 1;        /*!< [0]  */
        uint32_t MII_SPEED : 6;        /*!< [6:1] MII Speed */
        uint32_t DIS_PRE : 1;          /*!< [7] Disable Preamble */
        uint32_t HOLDTIME : 3;         /*!< [10:8] Hold time On MDIO Output */
        uint32_t RESERVED1 : 21;       /*!< [31:11]  */
    } B;
} hw_enet_mscr_t;

/*!
 * @name Constants and macros for entire ENET_MSCR register
 */
/*@{*/
#define HW_ENET_MSCR_ADDR(x)     ((uintptr_t)(x) + 0x44U)

#define HW_ENET_MSCR(x)          (*(__IO hw_enet_mscr_t *) HW_ENET_MSCR_ADDR(x))
#define HW_ENET_MSCR_RD(x)       (HW_ENET_MSCR(x).U)
#define HW_ENET_MSCR_WR(x, v)    (HW_ENET_MSCR(x).U = (v))
#define HW_ENET_MSCR_SET(x, v)   (HW_ENET_MSCR_WR(x, HW_ENET_MSCR_RD(x) |  (v)))
#define HW_ENET_MSCR_CLR(x, v)   (HW_ENET_MSCR_WR(x, HW_ENET_MSCR_RD(x) & ~(v)))
#define HW_ENET_MSCR_TOG(x, v)   (HW_ENET_MSCR_WR(x, HW_ENET_MSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_MSCR bitfields
 */

/*!
 * @name Register ENET_MSCR, field MII_SPEED[6:1] (RW)
 *
 * Controls the frequency of the MII management interface clock (MDC) relative
 * to the internal module clock. A value of 0 in this field turns off MDC and
 * leaves it in low voltage state. Any non-zero value results in the MDC frequency
 * of: 1/((MII_SPEED + 1) x 2) of the internal module clock frequency
 */
/*@{*/
#define BP_ENET_MSCR_MII_SPEED (1U)        /*!< Bit position for ENET_MSCR_MII_SPEED. */
#define BM_ENET_MSCR_MII_SPEED (0x0000007EU) /*!< Bit mask for ENET_MSCR_MII_SPEED. */
#define BS_ENET_MSCR_MII_SPEED (6U)        /*!< Bit field size in bits for ENET_MSCR_MII_SPEED. */

/*! @brief Read current value of the ENET_MSCR_MII_SPEED field. */
#define BR_ENET_MSCR_MII_SPEED(x) (HW_ENET_MSCR(x).B.MII_SPEED)

/*! @brief Format value for bitfield ENET_MSCR_MII_SPEED. */
#define BF_ENET_MSCR_MII_SPEED(v) ((uint32_t)((uint32_t)(v) << BP_ENET_MSCR_MII_SPEED) & BM_ENET_MSCR_MII_SPEED)

/*! @brief Set the MII_SPEED field to a new value. */
#define BW_ENET_MSCR_MII_SPEED(x, v) (HW_ENET_MSCR_WR(x, (HW_ENET_MSCR_RD(x) & ~BM_ENET_MSCR_MII_SPEED) | BF_ENET_MSCR_MII_SPEED(v)))
/*@}*/

/*!
 * @name Register ENET_MSCR, field DIS_PRE[7] (RW)
 *
 * Enables/disables prepending a preamble to the MII management frame. The MII
 * standard allows the preamble to be dropped if the attached PHY devices do not
 * require it.
 *
 * Values:
 * - 0 - Preamble enabled.
 * - 1 - Preamble (32 ones) is not prepended to the MII management frame.
 */
/*@{*/
#define BP_ENET_MSCR_DIS_PRE (7U)          /*!< Bit position for ENET_MSCR_DIS_PRE. */
#define BM_ENET_MSCR_DIS_PRE (0x00000080U) /*!< Bit mask for ENET_MSCR_DIS_PRE. */
#define BS_ENET_MSCR_DIS_PRE (1U)          /*!< Bit field size in bits for ENET_MSCR_DIS_PRE. */

/*! @brief Read current value of the ENET_MSCR_DIS_PRE field. */
#define BR_ENET_MSCR_DIS_PRE(x) (HW_ENET_MSCR(x).B.DIS_PRE)

/*! @brief Format value for bitfield ENET_MSCR_DIS_PRE. */
#define BF_ENET_MSCR_DIS_PRE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_MSCR_DIS_PRE) & BM_ENET_MSCR_DIS_PRE)

/*! @brief Set the DIS_PRE field to a new value. */
#define BW_ENET_MSCR_DIS_PRE(x, v) (HW_ENET_MSCR_WR(x, (HW_ENET_MSCR_RD(x) & ~BM_ENET_MSCR_DIS_PRE) | BF_ENET_MSCR_DIS_PRE(v)))
/*@}*/

/*!
 * @name Register ENET_MSCR, field HOLDTIME[10:8] (RW)
 *
 * IEEE802.3 clause 22 defines a minimum of 10 ns for the hold time on the MDIO
 * output. Depending on the host bus frequency, the setting may need to be
 * increased.
 *
 * Values:
 * - 000 - 1 internal module clock cycle
 * - 001 - 2 internal module clock cycles
 * - 010 - 3 internal module clock cycles
 * - 111 - 8 internal module clock cycles
 */
/*@{*/
#define BP_ENET_MSCR_HOLDTIME (8U)         /*!< Bit position for ENET_MSCR_HOLDTIME. */
#define BM_ENET_MSCR_HOLDTIME (0x00000700U) /*!< Bit mask for ENET_MSCR_HOLDTIME. */
#define BS_ENET_MSCR_HOLDTIME (3U)         /*!< Bit field size in bits for ENET_MSCR_HOLDTIME. */

/*! @brief Read current value of the ENET_MSCR_HOLDTIME field. */
#define BR_ENET_MSCR_HOLDTIME(x) (HW_ENET_MSCR(x).B.HOLDTIME)

/*! @brief Format value for bitfield ENET_MSCR_HOLDTIME. */
#define BF_ENET_MSCR_HOLDTIME(v) ((uint32_t)((uint32_t)(v) << BP_ENET_MSCR_HOLDTIME) & BM_ENET_MSCR_HOLDTIME)

/*! @brief Set the HOLDTIME field to a new value. */
#define BW_ENET_MSCR_HOLDTIME(x, v) (HW_ENET_MSCR_WR(x, (HW_ENET_MSCR_RD(x) & ~BM_ENET_MSCR_HOLDTIME) | BF_ENET_MSCR_HOLDTIME(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_MIBC - MIB Control Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_MIBC - MIB Control Register (RW)
 *
 * Reset value: 0xC0000000U
 *
 * MIBC is a read/write register controlling and observing the state of the MIB
 * block. Access this register to disable the MIB block operation or clear the
 * MIB counters. The MIB_DIS field resets to 1.
 */
typedef union _hw_enet_mibc
{
    uint32_t U;
    struct _hw_enet_mibc_bitfields
    {
        uint32_t RESERVED0 : 29;       /*!< [28:0]  */
        uint32_t MIB_CLEAR : 1;        /*!< [29] MIB Clear */
        uint32_t MIB_IDLE : 1;         /*!< [30] MIB Idle */
        uint32_t MIB_DIS : 1;          /*!< [31] Disable MIB Logic */
    } B;
} hw_enet_mibc_t;

/*!
 * @name Constants and macros for entire ENET_MIBC register
 */
/*@{*/
#define HW_ENET_MIBC_ADDR(x)     ((uintptr_t)(x) + 0x64U)

#define HW_ENET_MIBC(x)          (*(__IO hw_enet_mibc_t *) HW_ENET_MIBC_ADDR(x))
#define HW_ENET_MIBC_RD(x)       (HW_ENET_MIBC(x).U)
#define HW_ENET_MIBC_WR(x, v)    (HW_ENET_MIBC(x).U = (v))
#define HW_ENET_MIBC_SET(x, v)   (HW_ENET_MIBC_WR(x, HW_ENET_MIBC_RD(x) |  (v)))
#define HW_ENET_MIBC_CLR(x, v)   (HW_ENET_MIBC_WR(x, HW_ENET_MIBC_RD(x) & ~(v)))
#define HW_ENET_MIBC_TOG(x, v)   (HW_ENET_MIBC_WR(x, HW_ENET_MIBC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_MIBC bitfields
 */

/*!
 * @name Register ENET_MIBC, field MIB_CLEAR[29] (RW)
 *
 * This field is not self-clearing. To clear the MIB counters set and then clear
 * this field.
 *
 * Values:
 * - 0 - See note above.
 * - 1 - All statistics counters are reset to 0.
 */
/*@{*/
#define BP_ENET_MIBC_MIB_CLEAR (29U)       /*!< Bit position for ENET_MIBC_MIB_CLEAR. */
#define BM_ENET_MIBC_MIB_CLEAR (0x20000000U) /*!< Bit mask for ENET_MIBC_MIB_CLEAR. */
#define BS_ENET_MIBC_MIB_CLEAR (1U)        /*!< Bit field size in bits for ENET_MIBC_MIB_CLEAR. */

/*! @brief Read current value of the ENET_MIBC_MIB_CLEAR field. */
#define BR_ENET_MIBC_MIB_CLEAR(x) (HW_ENET_MIBC(x).B.MIB_CLEAR)

/*! @brief Format value for bitfield ENET_MIBC_MIB_CLEAR. */
#define BF_ENET_MIBC_MIB_CLEAR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_MIBC_MIB_CLEAR) & BM_ENET_MIBC_MIB_CLEAR)

/*! @brief Set the MIB_CLEAR field to a new value. */
#define BW_ENET_MIBC_MIB_CLEAR(x, v) (HW_ENET_MIBC_WR(x, (HW_ENET_MIBC_RD(x) & ~BM_ENET_MIBC_MIB_CLEAR) | BF_ENET_MIBC_MIB_CLEAR(v)))
/*@}*/

/*!
 * @name Register ENET_MIBC, field MIB_IDLE[30] (RO)
 *
 * Values:
 * - 0 - The MIB block is updating MIB counters.
 * - 1 - The MIB block is not currently updating any MIB counters.
 */
/*@{*/
#define BP_ENET_MIBC_MIB_IDLE (30U)        /*!< Bit position for ENET_MIBC_MIB_IDLE. */
#define BM_ENET_MIBC_MIB_IDLE (0x40000000U) /*!< Bit mask for ENET_MIBC_MIB_IDLE. */
#define BS_ENET_MIBC_MIB_IDLE (1U)         /*!< Bit field size in bits for ENET_MIBC_MIB_IDLE. */

/*! @brief Read current value of the ENET_MIBC_MIB_IDLE field. */
#define BR_ENET_MIBC_MIB_IDLE(x) (HW_ENET_MIBC(x).B.MIB_IDLE)
/*@}*/

/*!
 * @name Register ENET_MIBC, field MIB_DIS[31] (RW)
 *
 * If this control field is set,
 *
 * Values:
 * - 0 - MIB logic is enabled.
 * - 1 - MIB logic is disabled. The MIB logic halts and does not update any MIB
 *     counters.
 */
/*@{*/
#define BP_ENET_MIBC_MIB_DIS (31U)         /*!< Bit position for ENET_MIBC_MIB_DIS. */
#define BM_ENET_MIBC_MIB_DIS (0x80000000U) /*!< Bit mask for ENET_MIBC_MIB_DIS. */
#define BS_ENET_MIBC_MIB_DIS (1U)          /*!< Bit field size in bits for ENET_MIBC_MIB_DIS. */

/*! @brief Read current value of the ENET_MIBC_MIB_DIS field. */
#define BR_ENET_MIBC_MIB_DIS(x) (HW_ENET_MIBC(x).B.MIB_DIS)

/*! @brief Format value for bitfield ENET_MIBC_MIB_DIS. */
#define BF_ENET_MIBC_MIB_DIS(v) ((uint32_t)((uint32_t)(v) << BP_ENET_MIBC_MIB_DIS) & BM_ENET_MIBC_MIB_DIS)

/*! @brief Set the MIB_DIS field to a new value. */
#define BW_ENET_MIBC_MIB_DIS(x, v) (HW_ENET_MIBC_WR(x, (HW_ENET_MIBC_RD(x) & ~BM_ENET_MIBC_MIB_DIS) | BF_ENET_MIBC_MIB_DIS(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RCR - Receive Control Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RCR - Receive Control Register (RW)
 *
 * Reset value: 0x05EE0001U
 */
typedef union _hw_enet_rcr
{
    uint32_t U;
    struct _hw_enet_rcr_bitfields
    {
        uint32_t LOOP : 1;             /*!< [0] Internal Loopback */
        uint32_t DRT : 1;              /*!< [1] Disable Receive On Transmit */
        uint32_t MII_MODE : 1;         /*!< [2] Media Independent Interface Mode */
        uint32_t PROM : 1;             /*!< [3] Promiscuous Mode */
        uint32_t BC_REJ : 1;           /*!< [4] Broadcast Frame Reject */
        uint32_t FCE : 1;              /*!< [5] Flow Control Enable */
        uint32_t RGMII_EN : 1;         /*!< [6] RGMII Mode Enable */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t RMII_MODE : 1;        /*!< [8] RMII Mode Enable */
        uint32_t RMII_10T : 1;         /*!< [9]  */
        uint32_t RESERVED1 : 2;        /*!< [11:10]  */
        uint32_t PADEN : 1;            /*!< [12] Enable Frame Padding Remove On Receive
                                        * */
        uint32_t PAUFWD : 1;           /*!< [13] Terminate/Forward Pause Frames */
        uint32_t CRCFWD : 1;           /*!< [14] Terminate/Forward Received CRC */
        uint32_t CFEN : 1;             /*!< [15] MAC Control Frame Enable */
        uint32_t MAX_FL : 14;          /*!< [29:16] Maximum Frame Length */
        uint32_t NLC : 1;              /*!< [30] Payload Length Check Disable */
        uint32_t GRS : 1;              /*!< [31] Graceful Receive Stopped */
    } B;
} hw_enet_rcr_t;

/*!
 * @name Constants and macros for entire ENET_RCR register
 */
/*@{*/
#define HW_ENET_RCR_ADDR(x)      ((uintptr_t)(x) + 0x84U)

#define HW_ENET_RCR(x)           (*(__IO hw_enet_rcr_t *) HW_ENET_RCR_ADDR(x))
#define HW_ENET_RCR_RD(x)        (HW_ENET_RCR(x).U)
#define HW_ENET_RCR_WR(x, v)     (HW_ENET_RCR(x).U = (v))
#define HW_ENET_RCR_SET(x, v)    (HW_ENET_RCR_WR(x, HW_ENET_RCR_RD(x) |  (v)))
#define HW_ENET_RCR_CLR(x, v)    (HW_ENET_RCR_WR(x, HW_ENET_RCR_RD(x) & ~(v)))
#define HW_ENET_RCR_TOG(x, v)    (HW_ENET_RCR_WR(x, HW_ENET_RCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RCR bitfields
 */

/*!
 * @name Register ENET_RCR, field LOOP[0] (RW)
 *
 * This is an MII internal loopback, therefore MII_MODE must be written to 1 and
 * RMII_MODE must be written to 0.
 *
 * Values:
 * - 0 - Loopback disabled.
 * - 1 - Transmitted frames are looped back internal to the device and transmit
 *     MII output signals are not asserted. DRT must be cleared.
 */
/*@{*/
#define BP_ENET_RCR_LOOP     (0U)          /*!< Bit position for ENET_RCR_LOOP. */
#define BM_ENET_RCR_LOOP     (0x00000001U) /*!< Bit mask for ENET_RCR_LOOP. */
#define BS_ENET_RCR_LOOP     (1U)          /*!< Bit field size in bits for ENET_RCR_LOOP. */

/*! @brief Read current value of the ENET_RCR_LOOP field. */
#define BR_ENET_RCR_LOOP(x)  (HW_ENET_RCR(x).B.LOOP)

/*! @brief Format value for bitfield ENET_RCR_LOOP. */
#define BF_ENET_RCR_LOOP(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_LOOP) & BM_ENET_RCR_LOOP)

/*! @brief Set the LOOP field to a new value. */
#define BW_ENET_RCR_LOOP(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_LOOP) | BF_ENET_RCR_LOOP(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field DRT[1] (RW)
 *
 * Values:
 * - 0 - Receive path operates independently of transmit (i.e., full-duplex
 *     mode). Can also be used to monitor transmit activity in half-duplex mode.
 * - 1 - Disable reception of frames while transmitting. (Normally used for
 *     half-duplex mode.)
 */
/*@{*/
#define BP_ENET_RCR_DRT      (1U)          /*!< Bit position for ENET_RCR_DRT. */
#define BM_ENET_RCR_DRT      (0x00000002U) /*!< Bit mask for ENET_RCR_DRT. */
#define BS_ENET_RCR_DRT      (1U)          /*!< Bit field size in bits for ENET_RCR_DRT. */

/*! @brief Read current value of the ENET_RCR_DRT field. */
#define BR_ENET_RCR_DRT(x)   (HW_ENET_RCR(x).B.DRT)

/*! @brief Format value for bitfield ENET_RCR_DRT. */
#define BF_ENET_RCR_DRT(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_DRT) & BM_ENET_RCR_DRT)

/*! @brief Set the DRT field to a new value. */
#define BW_ENET_RCR_DRT(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_DRT) | BF_ENET_RCR_DRT(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field MII_MODE[2] (RW)
 *
 * This field must always be set.
 *
 * Values:
 * - 0 - Reserved.
 * - 1 - MII or RMII mode, as indicated by the RMII_MODE field.
 */
/*@{*/
#define BP_ENET_RCR_MII_MODE (2U)          /*!< Bit position for ENET_RCR_MII_MODE. */
#define BM_ENET_RCR_MII_MODE (0x00000004U) /*!< Bit mask for ENET_RCR_MII_MODE. */
#define BS_ENET_RCR_MII_MODE (1U)          /*!< Bit field size in bits for ENET_RCR_MII_MODE. */

/*! @brief Read current value of the ENET_RCR_MII_MODE field. */
#define BR_ENET_RCR_MII_MODE(x) (HW_ENET_RCR(x).B.MII_MODE)

/*! @brief Format value for bitfield ENET_RCR_MII_MODE. */
#define BF_ENET_RCR_MII_MODE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_MII_MODE) & BM_ENET_RCR_MII_MODE)

/*! @brief Set the MII_MODE field to a new value. */
#define BW_ENET_RCR_MII_MODE(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_MII_MODE) | BF_ENET_RCR_MII_MODE(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field PROM[3] (RW)
 *
 * All frames are accepted regardless of address matching.
 *
 * Values:
 * - 0 - Disabled.
 * - 1 - Enabled.
 */
/*@{*/
#define BP_ENET_RCR_PROM     (3U)          /*!< Bit position for ENET_RCR_PROM. */
#define BM_ENET_RCR_PROM     (0x00000008U) /*!< Bit mask for ENET_RCR_PROM. */
#define BS_ENET_RCR_PROM     (1U)          /*!< Bit field size in bits for ENET_RCR_PROM. */

/*! @brief Read current value of the ENET_RCR_PROM field. */
#define BR_ENET_RCR_PROM(x)  (HW_ENET_RCR(x).B.PROM)

/*! @brief Format value for bitfield ENET_RCR_PROM. */
#define BF_ENET_RCR_PROM(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_PROM) & BM_ENET_RCR_PROM)

/*! @brief Set the PROM field to a new value. */
#define BW_ENET_RCR_PROM(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_PROM) | BF_ENET_RCR_PROM(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field BC_REJ[4] (RW)
 *
 * If set, frames with destination address (DA) equal to 0xFFFF_FFFF_FFFF are
 * rejected unless the PROM field is set. If BC_REJ and PROM are set, frames with
 * broadcast DA are accepted and the MISS (M) is set in the receive buffer
 * descriptor.
 */
/*@{*/
#define BP_ENET_RCR_BC_REJ   (4U)          /*!< Bit position for ENET_RCR_BC_REJ. */
#define BM_ENET_RCR_BC_REJ   (0x00000010U) /*!< Bit mask for ENET_RCR_BC_REJ. */
#define BS_ENET_RCR_BC_REJ   (1U)          /*!< Bit field size in bits for ENET_RCR_BC_REJ. */

/*! @brief Read current value of the ENET_RCR_BC_REJ field. */
#define BR_ENET_RCR_BC_REJ(x) (HW_ENET_RCR(x).B.BC_REJ)

/*! @brief Format value for bitfield ENET_RCR_BC_REJ. */
#define BF_ENET_RCR_BC_REJ(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_BC_REJ) & BM_ENET_RCR_BC_REJ)

/*! @brief Set the BC_REJ field to a new value. */
#define BW_ENET_RCR_BC_REJ(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_BC_REJ) | BF_ENET_RCR_BC_REJ(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field FCE[5] (RW)
 *
 * If set, the receiver detects PAUSE frames. Upon PAUSE frame detection, the
 * transmitter stops transmitting data frames for a given duration.
 */
/*@{*/
#define BP_ENET_RCR_FCE      (5U)          /*!< Bit position for ENET_RCR_FCE. */
#define BM_ENET_RCR_FCE      (0x00000020U) /*!< Bit mask for ENET_RCR_FCE. */
#define BS_ENET_RCR_FCE      (1U)          /*!< Bit field size in bits for ENET_RCR_FCE. */

/*! @brief Read current value of the ENET_RCR_FCE field. */
#define BR_ENET_RCR_FCE(x)   (HW_ENET_RCR(x).B.FCE)

/*! @brief Format value for bitfield ENET_RCR_FCE. */
#define BF_ENET_RCR_FCE(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_FCE) & BM_ENET_RCR_FCE)

/*! @brief Set the FCE field to a new value. */
#define BW_ENET_RCR_FCE(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_FCE) | BF_ENET_RCR_FCE(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field RGMII_EN[6] (RW)
 *
 * Do not set both RCR[RGMII_EN] and RCR[RMII_MODE].
 *
 * Values:
 * - 0 - MAC configured for non-RGMII operation
 * - 1 - MAC configured for RGMII operation. If ECR[SPEED] is set, the MAC is in
 *     RGMII 1000-Mbit/s mode. If ECR[SPEED] is cleared, the MAC is in RGMII
 *     10/100-Mbit/s mode.
 */
/*@{*/
#define BP_ENET_RCR_RGMII_EN (6U)          /*!< Bit position for ENET_RCR_RGMII_EN. */
#define BM_ENET_RCR_RGMII_EN (0x00000040U) /*!< Bit mask for ENET_RCR_RGMII_EN. */
#define BS_ENET_RCR_RGMII_EN (1U)          /*!< Bit field size in bits for ENET_RCR_RGMII_EN. */

/*! @brief Read current value of the ENET_RCR_RGMII_EN field. */
#define BR_ENET_RCR_RGMII_EN(x) (HW_ENET_RCR(x).B.RGMII_EN)

/*! @brief Format value for bitfield ENET_RCR_RGMII_EN. */
#define BF_ENET_RCR_RGMII_EN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_RGMII_EN) & BM_ENET_RCR_RGMII_EN)

/*! @brief Set the RGMII_EN field to a new value. */
#define BW_ENET_RCR_RGMII_EN(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_RGMII_EN) | BF_ENET_RCR_RGMII_EN(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field RMII_MODE[8] (RW)
 *
 * Specifies whether the MAC is configured for MII mode or RMII operation , when
 * ECR[SPEED] is cleared . Do not set both RCR[RGMII_EN] and RCR[RMII_MODE].
 *
 * Values:
 * - 0 - MAC configured for MII mode.
 * - 1 - MAC configured for RMII operation.
 */
/*@{*/
#define BP_ENET_RCR_RMII_MODE (8U)         /*!< Bit position for ENET_RCR_RMII_MODE. */
#define BM_ENET_RCR_RMII_MODE (0x00000100U) /*!< Bit mask for ENET_RCR_RMII_MODE. */
#define BS_ENET_RCR_RMII_MODE (1U)         /*!< Bit field size in bits for ENET_RCR_RMII_MODE. */

/*! @brief Read current value of the ENET_RCR_RMII_MODE field. */
#define BR_ENET_RCR_RMII_MODE(x) (HW_ENET_RCR(x).B.RMII_MODE)

/*! @brief Format value for bitfield ENET_RCR_RMII_MODE. */
#define BF_ENET_RCR_RMII_MODE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_RMII_MODE) & BM_ENET_RCR_RMII_MODE)

/*! @brief Set the RMII_MODE field to a new value. */
#define BW_ENET_RCR_RMII_MODE(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_RMII_MODE) | BF_ENET_RCR_RMII_MODE(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field RMII_10T[9] (RW)
 *
 * Enables 10-Mbit/s mode of the RMII or RGMII .
 *
 * Values:
 * - 0 - 100-Mbit/s operation.
 * - 1 - 10-Mbit/s operation.
 */
/*@{*/
#define BP_ENET_RCR_RMII_10T (9U)          /*!< Bit position for ENET_RCR_RMII_10T. */
#define BM_ENET_RCR_RMII_10T (0x00000200U) /*!< Bit mask for ENET_RCR_RMII_10T. */
#define BS_ENET_RCR_RMII_10T (1U)          /*!< Bit field size in bits for ENET_RCR_RMII_10T. */

/*! @brief Read current value of the ENET_RCR_RMII_10T field. */
#define BR_ENET_RCR_RMII_10T(x) (HW_ENET_RCR(x).B.RMII_10T)

/*! @brief Format value for bitfield ENET_RCR_RMII_10T. */
#define BF_ENET_RCR_RMII_10T(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_RMII_10T) & BM_ENET_RCR_RMII_10T)

/*! @brief Set the RMII_10T field to a new value. */
#define BW_ENET_RCR_RMII_10T(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_RMII_10T) | BF_ENET_RCR_RMII_10T(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field PADEN[12] (RW)
 *
 * Specifies whether the MAC removes padding from received frames.
 *
 * Values:
 * - 0 - No padding is removed on receive by the MAC.
 * - 1 - Padding is removed from received frames.
 */
/*@{*/
#define BP_ENET_RCR_PADEN    (12U)         /*!< Bit position for ENET_RCR_PADEN. */
#define BM_ENET_RCR_PADEN    (0x00001000U) /*!< Bit mask for ENET_RCR_PADEN. */
#define BS_ENET_RCR_PADEN    (1U)          /*!< Bit field size in bits for ENET_RCR_PADEN. */

/*! @brief Read current value of the ENET_RCR_PADEN field. */
#define BR_ENET_RCR_PADEN(x) (HW_ENET_RCR(x).B.PADEN)

/*! @brief Format value for bitfield ENET_RCR_PADEN. */
#define BF_ENET_RCR_PADEN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_PADEN) & BM_ENET_RCR_PADEN)

/*! @brief Set the PADEN field to a new value. */
#define BW_ENET_RCR_PADEN(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_PADEN) | BF_ENET_RCR_PADEN(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field PAUFWD[13] (RW)
 *
 * Specifies whether pause frames are terminated or forwarded.
 *
 * Values:
 * - 0 - Pause frames are terminated and discarded in the MAC.
 * - 1 - Pause frames are forwarded to the user application.
 */
/*@{*/
#define BP_ENET_RCR_PAUFWD   (13U)         /*!< Bit position for ENET_RCR_PAUFWD. */
#define BM_ENET_RCR_PAUFWD   (0x00002000U) /*!< Bit mask for ENET_RCR_PAUFWD. */
#define BS_ENET_RCR_PAUFWD   (1U)          /*!< Bit field size in bits for ENET_RCR_PAUFWD. */

/*! @brief Read current value of the ENET_RCR_PAUFWD field. */
#define BR_ENET_RCR_PAUFWD(x) (HW_ENET_RCR(x).B.PAUFWD)

/*! @brief Format value for bitfield ENET_RCR_PAUFWD. */
#define BF_ENET_RCR_PAUFWD(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_PAUFWD) & BM_ENET_RCR_PAUFWD)

/*! @brief Set the PAUFWD field to a new value. */
#define BW_ENET_RCR_PAUFWD(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_PAUFWD) | BF_ENET_RCR_PAUFWD(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field CRCFWD[14] (RW)
 *
 * Specifies whether the CRC field of received frames is transmitted or
 * stripped. If padding function is enabled (PADEN = 1), CRCFWD is ignored and the CRC
 * field is checked and always terminated and removed.
 *
 * Values:
 * - 0 - The CRC field of received frames is transmitted to the user application.
 * - 1 - The CRC field is stripped from the frame.
 */
/*@{*/
#define BP_ENET_RCR_CRCFWD   (14U)         /*!< Bit position for ENET_RCR_CRCFWD. */
#define BM_ENET_RCR_CRCFWD   (0x00004000U) /*!< Bit mask for ENET_RCR_CRCFWD. */
#define BS_ENET_RCR_CRCFWD   (1U)          /*!< Bit field size in bits for ENET_RCR_CRCFWD. */

/*! @brief Read current value of the ENET_RCR_CRCFWD field. */
#define BR_ENET_RCR_CRCFWD(x) (HW_ENET_RCR(x).B.CRCFWD)

/*! @brief Format value for bitfield ENET_RCR_CRCFWD. */
#define BF_ENET_RCR_CRCFWD(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_CRCFWD) & BM_ENET_RCR_CRCFWD)

/*! @brief Set the CRCFWD field to a new value. */
#define BW_ENET_RCR_CRCFWD(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_CRCFWD) | BF_ENET_RCR_CRCFWD(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field CFEN[15] (RW)
 *
 * Enables/disables the MAC control frame.
 *
 * Values:
 * - 0 - MAC control frames with any opcode other than 0x0001 (pause frame) are
 *     accepted and forwarded to the client interface.
 * - 1 - MAC control frames with any opcode other than 0x0001 (pause frame) are
 *     silently discarded.
 */
/*@{*/
#define BP_ENET_RCR_CFEN     (15U)         /*!< Bit position for ENET_RCR_CFEN. */
#define BM_ENET_RCR_CFEN     (0x00008000U) /*!< Bit mask for ENET_RCR_CFEN. */
#define BS_ENET_RCR_CFEN     (1U)          /*!< Bit field size in bits for ENET_RCR_CFEN. */

/*! @brief Read current value of the ENET_RCR_CFEN field. */
#define BR_ENET_RCR_CFEN(x)  (HW_ENET_RCR(x).B.CFEN)

/*! @brief Format value for bitfield ENET_RCR_CFEN. */
#define BF_ENET_RCR_CFEN(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_CFEN) & BM_ENET_RCR_CFEN)

/*! @brief Set the CFEN field to a new value. */
#define BW_ENET_RCR_CFEN(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_CFEN) | BF_ENET_RCR_CFEN(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field MAX_FL[29:16] (RW)
 *
 * Resets to decimal 1518. Length is measured starting at DA and includes the
 * CRC at the end of the frame. Transmit frames longer than MAX_FL cause the BABT
 * interrupt to occur. Receive frames longer than MAX_FL cause the BABR interrupt
 * to occur and set the LG field in the end of frame receive buffer descriptor.
 * The recommended default value to be programmed is 1518 or 1522 if VLAN tags are
 * supported.
 */
/*@{*/
#define BP_ENET_RCR_MAX_FL   (16U)         /*!< Bit position for ENET_RCR_MAX_FL. */
#define BM_ENET_RCR_MAX_FL   (0x3FFF0000U) /*!< Bit mask for ENET_RCR_MAX_FL. */
#define BS_ENET_RCR_MAX_FL   (14U)         /*!< Bit field size in bits for ENET_RCR_MAX_FL. */

/*! @brief Read current value of the ENET_RCR_MAX_FL field. */
#define BR_ENET_RCR_MAX_FL(x) (HW_ENET_RCR(x).B.MAX_FL)

/*! @brief Format value for bitfield ENET_RCR_MAX_FL. */
#define BF_ENET_RCR_MAX_FL(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_MAX_FL) & BM_ENET_RCR_MAX_FL)

/*! @brief Set the MAX_FL field to a new value. */
#define BW_ENET_RCR_MAX_FL(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_MAX_FL) | BF_ENET_RCR_MAX_FL(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field NLC[30] (RW)
 *
 * Enables/disables a payload length check.
 *
 * Values:
 * - 0 - The payload length check is disabled.
 * - 1 - The core checks the frame's payload length with the frame length/type
 *     field. Errors are indicated in the EIR[PLC] field.
 */
/*@{*/
#define BP_ENET_RCR_NLC      (30U)         /*!< Bit position for ENET_RCR_NLC. */
#define BM_ENET_RCR_NLC      (0x40000000U) /*!< Bit mask for ENET_RCR_NLC. */
#define BS_ENET_RCR_NLC      (1U)          /*!< Bit field size in bits for ENET_RCR_NLC. */

/*! @brief Read current value of the ENET_RCR_NLC field. */
#define BR_ENET_RCR_NLC(x)   (HW_ENET_RCR(x).B.NLC)

/*! @brief Format value for bitfield ENET_RCR_NLC. */
#define BF_ENET_RCR_NLC(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_RCR_NLC) & BM_ENET_RCR_NLC)

/*! @brief Set the NLC field to a new value. */
#define BW_ENET_RCR_NLC(x, v) (HW_ENET_RCR_WR(x, (HW_ENET_RCR_RD(x) & ~BM_ENET_RCR_NLC) | BF_ENET_RCR_NLC(v)))
/*@}*/

/*!
 * @name Register ENET_RCR, field GRS[31] (RO)
 *
 * Read-only status indicating that the MAC receive datapath is stopped.
 */
/*@{*/
#define BP_ENET_RCR_GRS      (31U)         /*!< Bit position for ENET_RCR_GRS. */
#define BM_ENET_RCR_GRS      (0x80000000U) /*!< Bit mask for ENET_RCR_GRS. */
#define BS_ENET_RCR_GRS      (1U)          /*!< Bit field size in bits for ENET_RCR_GRS. */

/*! @brief Read current value of the ENET_RCR_GRS field. */
#define BR_ENET_RCR_GRS(x)   (HW_ENET_RCR(x).B.GRS)
/*@}*/

/*******************************************************************************
 * HW_ENET_TCR - Transmit Control Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_TCR - Transmit Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * TCR is read/write and configures the transmit block. This register is cleared
 * at system reset. FDEN can only be modified when ECR[ETHEREN] is cleared.
 */
typedef union _hw_enet_tcr
{
    uint32_t U;
    struct _hw_enet_tcr_bitfields
    {
        uint32_t GTS : 1;              /*!< [0] Graceful Transmit Stop */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t FDEN : 1;             /*!< [2] Full-Duplex Enable */
        uint32_t TFC_PAUSE : 1;        /*!< [3] Transmit Frame Control Pause */
        uint32_t RFC_PAUSE : 1;        /*!< [4] Receive Frame Control Pause */
        uint32_t ADDSEL : 3;           /*!< [7:5] Source MAC Address Select On Transmit
                                        * */
        uint32_t ADDINS : 1;           /*!< [8] Set MAC Address On Transmit */
        uint32_t CRCFWD : 1;           /*!< [9] Forward Frame From Application With CRC
                                        * */
        uint32_t RESERVED1 : 22;       /*!< [31:10]  */
    } B;
} hw_enet_tcr_t;

/*!
 * @name Constants and macros for entire ENET_TCR register
 */
/*@{*/
#define HW_ENET_TCR_ADDR(x)      ((uintptr_t)(x) + 0xC4U)

#define HW_ENET_TCR(x)           (*(__IO hw_enet_tcr_t *) HW_ENET_TCR_ADDR(x))
#define HW_ENET_TCR_RD(x)        (HW_ENET_TCR(x).U)
#define HW_ENET_TCR_WR(x, v)     (HW_ENET_TCR(x).U = (v))
#define HW_ENET_TCR_SET(x, v)    (HW_ENET_TCR_WR(x, HW_ENET_TCR_RD(x) |  (v)))
#define HW_ENET_TCR_CLR(x, v)    (HW_ENET_TCR_WR(x, HW_ENET_TCR_RD(x) & ~(v)))
#define HW_ENET_TCR_TOG(x, v)    (HW_ENET_TCR_WR(x, HW_ENET_TCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TCR bitfields
 */

/*!
 * @name Register ENET_TCR, field GTS[0] (RW)
 *
 * When this field is set, MAC stops transmission after any frame currently
 * transmitted is complete and EIR[GRA] is set. If frame transmission is not
 * currently underway, the GRA interrupt is asserted immediately. After transmission
 * finishes, clear GTS to restart. The next frame in the transmit FIFO is then
 * transmitted. If an early collision occurs during transmission when GTS is set,
 * transmission stops after the collision. The frame is transmitted again after GTS is
 * cleared. There may be old frames in the transmit FIFO that transmit when GTS
 * is reasserted. To avoid this, clear ECR[ETHEREN] following the GRA interrupt.
 */
/*@{*/
#define BP_ENET_TCR_GTS      (0U)          /*!< Bit position for ENET_TCR_GTS. */
#define BM_ENET_TCR_GTS      (0x00000001U) /*!< Bit mask for ENET_TCR_GTS. */
#define BS_ENET_TCR_GTS      (1U)          /*!< Bit field size in bits for ENET_TCR_GTS. */

/*! @brief Read current value of the ENET_TCR_GTS field. */
#define BR_ENET_TCR_GTS(x)   (HW_ENET_TCR(x).B.GTS)

/*! @brief Format value for bitfield ENET_TCR_GTS. */
#define BF_ENET_TCR_GTS(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_TCR_GTS) & BM_ENET_TCR_GTS)

/*! @brief Set the GTS field to a new value. */
#define BW_ENET_TCR_GTS(x, v) (HW_ENET_TCR_WR(x, (HW_ENET_TCR_RD(x) & ~BM_ENET_TCR_GTS) | BF_ENET_TCR_GTS(v)))
/*@}*/

/*!
 * @name Register ENET_TCR, field FDEN[2] (RW)
 *
 * If this field is set, frames transmit independent of carrier sense and
 * collision inputs. Only modify this bit when ECR[ETHEREN] is cleared.
 */
/*@{*/
#define BP_ENET_TCR_FDEN     (2U)          /*!< Bit position for ENET_TCR_FDEN. */
#define BM_ENET_TCR_FDEN     (0x00000004U) /*!< Bit mask for ENET_TCR_FDEN. */
#define BS_ENET_TCR_FDEN     (1U)          /*!< Bit field size in bits for ENET_TCR_FDEN. */

/*! @brief Read current value of the ENET_TCR_FDEN field. */
#define BR_ENET_TCR_FDEN(x)  (HW_ENET_TCR(x).B.FDEN)

/*! @brief Format value for bitfield ENET_TCR_FDEN. */
#define BF_ENET_TCR_FDEN(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_TCR_FDEN) & BM_ENET_TCR_FDEN)

/*! @brief Set the FDEN field to a new value. */
#define BW_ENET_TCR_FDEN(x, v) (HW_ENET_TCR_WR(x, (HW_ENET_TCR_RD(x) & ~BM_ENET_TCR_FDEN) | BF_ENET_TCR_FDEN(v)))
/*@}*/

/*!
 * @name Register ENET_TCR, field TFC_PAUSE[3] (RW)
 *
 * Pauses frame transmission. When this field is set, EIR[GRA] is set. With
 * transmission of data frames stopped, the MAC transmits a MAC control PAUSE frame.
 * Next, the MAC clears TFC_PAUSE and resumes transmitting data frames. If the
 * transmitter pauses due to user assertion of GTS or reception of a PAUSE frame,
 * the MAC may continue transmitting a MAC control PAUSE frame.
 *
 * Values:
 * - 0 - No PAUSE frame transmitted.
 * - 1 - The MAC stops transmission of data frames after the current
 *     transmission is complete.
 */
/*@{*/
#define BP_ENET_TCR_TFC_PAUSE (3U)         /*!< Bit position for ENET_TCR_TFC_PAUSE. */
#define BM_ENET_TCR_TFC_PAUSE (0x00000008U) /*!< Bit mask for ENET_TCR_TFC_PAUSE. */
#define BS_ENET_TCR_TFC_PAUSE (1U)         /*!< Bit field size in bits for ENET_TCR_TFC_PAUSE. */

/*! @brief Read current value of the ENET_TCR_TFC_PAUSE field. */
#define BR_ENET_TCR_TFC_PAUSE(x) (HW_ENET_TCR(x).B.TFC_PAUSE)

/*! @brief Format value for bitfield ENET_TCR_TFC_PAUSE. */
#define BF_ENET_TCR_TFC_PAUSE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TCR_TFC_PAUSE) & BM_ENET_TCR_TFC_PAUSE)

/*! @brief Set the TFC_PAUSE field to a new value. */
#define BW_ENET_TCR_TFC_PAUSE(x, v) (HW_ENET_TCR_WR(x, (HW_ENET_TCR_RD(x) & ~BM_ENET_TCR_TFC_PAUSE) | BF_ENET_TCR_TFC_PAUSE(v)))
/*@}*/

/*!
 * @name Register ENET_TCR, field RFC_PAUSE[4] (RO)
 *
 * This status field is set when a full-duplex flow control pause frame is
 * received and the transmitter pauses for the duration defined in this pause frame.
 * This field automatically clears when the pause duration is complete.
 */
/*@{*/
#define BP_ENET_TCR_RFC_PAUSE (4U)         /*!< Bit position for ENET_TCR_RFC_PAUSE. */
#define BM_ENET_TCR_RFC_PAUSE (0x00000010U) /*!< Bit mask for ENET_TCR_RFC_PAUSE. */
#define BS_ENET_TCR_RFC_PAUSE (1U)         /*!< Bit field size in bits for ENET_TCR_RFC_PAUSE. */

/*! @brief Read current value of the ENET_TCR_RFC_PAUSE field. */
#define BR_ENET_TCR_RFC_PAUSE(x) (HW_ENET_TCR(x).B.RFC_PAUSE)
/*@}*/

/*!
 * @name Register ENET_TCR, field ADDSEL[7:5] (RW)
 *
 * If ADDINS is set, indicates the MAC address that overwrites the source MAC
 * address.
 *
 * Values:
 * - 000 - Node MAC address programmed on PADDR1/2 registers.
 * - 100 - Reserved.
 * - 101 - Reserved.
 * - 110 - Reserved.
 */
/*@{*/
#define BP_ENET_TCR_ADDSEL   (5U)          /*!< Bit position for ENET_TCR_ADDSEL. */
#define BM_ENET_TCR_ADDSEL   (0x000000E0U) /*!< Bit mask for ENET_TCR_ADDSEL. */
#define BS_ENET_TCR_ADDSEL   (3U)          /*!< Bit field size in bits for ENET_TCR_ADDSEL. */

/*! @brief Read current value of the ENET_TCR_ADDSEL field. */
#define BR_ENET_TCR_ADDSEL(x) (HW_ENET_TCR(x).B.ADDSEL)

/*! @brief Format value for bitfield ENET_TCR_ADDSEL. */
#define BF_ENET_TCR_ADDSEL(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TCR_ADDSEL) & BM_ENET_TCR_ADDSEL)

/*! @brief Set the ADDSEL field to a new value. */
#define BW_ENET_TCR_ADDSEL(x, v) (HW_ENET_TCR_WR(x, (HW_ENET_TCR_RD(x) & ~BM_ENET_TCR_ADDSEL) | BF_ENET_TCR_ADDSEL(v)))
/*@}*/

/*!
 * @name Register ENET_TCR, field ADDINS[8] (RW)
 *
 * Values:
 * - 0 - The source MAC address is not modified by the MAC.
 * - 1 - The MAC overwrites the source MAC address with the programmed MAC
 *     address according to ADDSEL.
 */
/*@{*/
#define BP_ENET_TCR_ADDINS   (8U)          /*!< Bit position for ENET_TCR_ADDINS. */
#define BM_ENET_TCR_ADDINS   (0x00000100U) /*!< Bit mask for ENET_TCR_ADDINS. */
#define BS_ENET_TCR_ADDINS   (1U)          /*!< Bit field size in bits for ENET_TCR_ADDINS. */

/*! @brief Read current value of the ENET_TCR_ADDINS field. */
#define BR_ENET_TCR_ADDINS(x) (HW_ENET_TCR(x).B.ADDINS)

/*! @brief Format value for bitfield ENET_TCR_ADDINS. */
#define BF_ENET_TCR_ADDINS(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TCR_ADDINS) & BM_ENET_TCR_ADDINS)

/*! @brief Set the ADDINS field to a new value. */
#define BW_ENET_TCR_ADDINS(x, v) (HW_ENET_TCR_WR(x, (HW_ENET_TCR_RD(x) & ~BM_ENET_TCR_ADDINS) | BF_ENET_TCR_ADDINS(v)))
/*@}*/

/*!
 * @name Register ENET_TCR, field CRCFWD[9] (RW)
 *
 * Values:
 * - 0 - TxBD[TC] controls whether the frame has a CRC from the application.
 * - 1 - The transmitter does not append any CRC to transmitted frames, as it is
 *     expecting a frame with CRC from the application.
 */
/*@{*/
#define BP_ENET_TCR_CRCFWD   (9U)          /*!< Bit position for ENET_TCR_CRCFWD. */
#define BM_ENET_TCR_CRCFWD   (0x00000200U) /*!< Bit mask for ENET_TCR_CRCFWD. */
#define BS_ENET_TCR_CRCFWD   (1U)          /*!< Bit field size in bits for ENET_TCR_CRCFWD. */

/*! @brief Read current value of the ENET_TCR_CRCFWD field. */
#define BR_ENET_TCR_CRCFWD(x) (HW_ENET_TCR(x).B.CRCFWD)

/*! @brief Format value for bitfield ENET_TCR_CRCFWD. */
#define BF_ENET_TCR_CRCFWD(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TCR_CRCFWD) & BM_ENET_TCR_CRCFWD)

/*! @brief Set the CRCFWD field to a new value. */
#define BW_ENET_TCR_CRCFWD(x, v) (HW_ENET_TCR_WR(x, (HW_ENET_TCR_RD(x) & ~BM_ENET_TCR_CRCFWD) | BF_ENET_TCR_CRCFWD(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_PALR - Physical Address Lower Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_PALR - Physical Address Lower Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * PALR contains the lower 32 bits (bytes 0, 1, 2, 3) of the 48-bit address used
 * in the address recognition process to compare with the destination address
 * (DA) field of receive frames with an individual DA. In addition, this register
 * is used in bytes 0 through 3 of the six-byte source address field when
 * transmitting PAUSE frames.
 */
typedef union _hw_enet_palr
{
    uint32_t U;
    struct _hw_enet_palr_bitfields
    {
        uint32_t PADDR1 : 32;          /*!< [31:0] Pause Address */
    } B;
} hw_enet_palr_t;

/*!
 * @name Constants and macros for entire ENET_PALR register
 */
/*@{*/
#define HW_ENET_PALR_ADDR(x)     ((uintptr_t)(x) + 0xE4U)

#define HW_ENET_PALR(x)          (*(__IO hw_enet_palr_t *) HW_ENET_PALR_ADDR(x))
#define HW_ENET_PALR_RD(x)       (HW_ENET_PALR(x).U)
#define HW_ENET_PALR_WR(x, v)    (HW_ENET_PALR(x).U = (v))
#define HW_ENET_PALR_SET(x, v)   (HW_ENET_PALR_WR(x, HW_ENET_PALR_RD(x) |  (v)))
#define HW_ENET_PALR_CLR(x, v)   (HW_ENET_PALR_WR(x, HW_ENET_PALR_RD(x) & ~(v)))
#define HW_ENET_PALR_TOG(x, v)   (HW_ENET_PALR_WR(x, HW_ENET_PALR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_PALR bitfields
 */

/*!
 * @name Register ENET_PALR, field PADDR1[31:0] (RW)
 *
 * Bytes 0 (bits 31:24), 1 (bits 23:16), 2 (bits 15:8), and 3 (bits 7:0) of the
 * 6-byte individual address are used for exact match and the source address
 * field in PAUSE frames.
 */
/*@{*/
#define BP_ENET_PALR_PADDR1  (0U)          /*!< Bit position for ENET_PALR_PADDR1. */
#define BM_ENET_PALR_PADDR1  (0xFFFFFFFFU) /*!< Bit mask for ENET_PALR_PADDR1. */
#define BS_ENET_PALR_PADDR1  (32U)         /*!< Bit field size in bits for ENET_PALR_PADDR1. */

/*! @brief Read current value of the ENET_PALR_PADDR1 field. */
#define BR_ENET_PALR_PADDR1(x) (HW_ENET_PALR(x).U)

/*! @brief Format value for bitfield ENET_PALR_PADDR1. */
#define BF_ENET_PALR_PADDR1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_PALR_PADDR1) & BM_ENET_PALR_PADDR1)

/*! @brief Set the PADDR1 field to a new value. */
#define BW_ENET_PALR_PADDR1(x, v) (HW_ENET_PALR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_ENET_PAUR - Physical Address Upper Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_PAUR - Physical Address Upper Register (RW)
 *
 * Reset value: 0x00008808U
 *
 * PAUR contains the upper 16 bits (bytes 4 and 5) of the 48-bit address used in
 * the address recognition process to compare with the destination address (DA)
 * field of receive frames with an individual DA. In addition, this register is
 * used in bytes 4 and 5 of the six-byte source address field when transmitting
 * PAUSE frames. Bits 15:0 of PAUR contain a constant type field (0x8808) for
 * transmission of PAUSE frames.
 */
typedef union _hw_enet_paur
{
    uint32_t U;
    struct _hw_enet_paur_bitfields
    {
        uint32_t TYPE : 16;            /*!< [15:0] Type Field In PAUSE Frames */
        uint32_t PADDR2 : 16;          /*!< [31:16]  */
    } B;
} hw_enet_paur_t;

/*!
 * @name Constants and macros for entire ENET_PAUR register
 */
/*@{*/
#define HW_ENET_PAUR_ADDR(x)     ((uintptr_t)(x) + 0xE8U)

#define HW_ENET_PAUR(x)          (*(__IO hw_enet_paur_t *) HW_ENET_PAUR_ADDR(x))
#define HW_ENET_PAUR_RD(x)       (HW_ENET_PAUR(x).U)
#define HW_ENET_PAUR_WR(x, v)    (HW_ENET_PAUR(x).U = (v))
#define HW_ENET_PAUR_SET(x, v)   (HW_ENET_PAUR_WR(x, HW_ENET_PAUR_RD(x) |  (v)))
#define HW_ENET_PAUR_CLR(x, v)   (HW_ENET_PAUR_WR(x, HW_ENET_PAUR_RD(x) & ~(v)))
#define HW_ENET_PAUR_TOG(x, v)   (HW_ENET_PAUR_WR(x, HW_ENET_PAUR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_PAUR bitfields
 */

/*!
 * @name Register ENET_PAUR, field TYPE[15:0] (RO)
 *
 * These fields have a constant value of 0x8808.
 */
/*@{*/
#define BP_ENET_PAUR_TYPE    (0U)          /*!< Bit position for ENET_PAUR_TYPE. */
#define BM_ENET_PAUR_TYPE    (0x0000FFFFU) /*!< Bit mask for ENET_PAUR_TYPE. */
#define BS_ENET_PAUR_TYPE    (16U)         /*!< Bit field size in bits for ENET_PAUR_TYPE. */

/*! @brief Read current value of the ENET_PAUR_TYPE field. */
#define BR_ENET_PAUR_TYPE(x) (HW_ENET_PAUR(x).B.TYPE)
/*@}*/

/*!
 * @name Register ENET_PAUR, field PADDR2[31:16] (RW)
 *
 * Bytes 4 (bits 31:24) and 5 (bits 23:16) of the 6-byte individual address used
 * for exact match, and the source address field in PAUSE frames.
 */
/*@{*/
#define BP_ENET_PAUR_PADDR2  (16U)         /*!< Bit position for ENET_PAUR_PADDR2. */
#define BM_ENET_PAUR_PADDR2  (0xFFFF0000U) /*!< Bit mask for ENET_PAUR_PADDR2. */
#define BS_ENET_PAUR_PADDR2  (16U)         /*!< Bit field size in bits for ENET_PAUR_PADDR2. */

/*! @brief Read current value of the ENET_PAUR_PADDR2 field. */
#define BR_ENET_PAUR_PADDR2(x) (HW_ENET_PAUR(x).B.PADDR2)

/*! @brief Format value for bitfield ENET_PAUR_PADDR2. */
#define BF_ENET_PAUR_PADDR2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_PAUR_PADDR2) & BM_ENET_PAUR_PADDR2)

/*! @brief Set the PADDR2 field to a new value. */
#define BW_ENET_PAUR_PADDR2(x, v) (HW_ENET_PAUR_WR(x, (HW_ENET_PAUR_RD(x) & ~BM_ENET_PAUR_PADDR2) | BF_ENET_PAUR_PADDR2(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_OPD - Opcode/Pause Duration Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_OPD - Opcode/Pause Duration Register (RW)
 *
 * Reset value: 0x00010000U
 *
 * OPD is read/write accessible. This register contains the 16-bit opcode and
 * 16-bit pause duration fields used in transmission of a PAUSE frame. The opcode
 * field is a constant value, 0x0001. When another node detects a PAUSE frame,
 * that node pauses transmission for the duration specified in the pause duration
 * field. The lower 16 bits of this register are not reset and you must initialize
 * it.
 */
typedef union _hw_enet_opd
{
    uint32_t U;
    struct _hw_enet_opd_bitfields
    {
        uint32_t PAUSE_DUR : 16;       /*!< [15:0] Pause Duration */
        uint32_t OPCODE : 16;          /*!< [31:16] Opcode Field In PAUSE Frames */
    } B;
} hw_enet_opd_t;

/*!
 * @name Constants and macros for entire ENET_OPD register
 */
/*@{*/
#define HW_ENET_OPD_ADDR(x)      ((uintptr_t)(x) + 0xECU)

#define HW_ENET_OPD(x)           (*(__IO hw_enet_opd_t *) HW_ENET_OPD_ADDR(x))
#define HW_ENET_OPD_RD(x)        (HW_ENET_OPD(x).U)
#define HW_ENET_OPD_WR(x, v)     (HW_ENET_OPD(x).U = (v))
#define HW_ENET_OPD_SET(x, v)    (HW_ENET_OPD_WR(x, HW_ENET_OPD_RD(x) |  (v)))
#define HW_ENET_OPD_CLR(x, v)    (HW_ENET_OPD_WR(x, HW_ENET_OPD_RD(x) & ~(v)))
#define HW_ENET_OPD_TOG(x, v)    (HW_ENET_OPD_WR(x, HW_ENET_OPD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_OPD bitfields
 */

/*!
 * @name Register ENET_OPD, field PAUSE_DUR[15:0] (RW)
 *
 * Pause duration field used in PAUSE frames.
 */
/*@{*/
#define BP_ENET_OPD_PAUSE_DUR (0U)         /*!< Bit position for ENET_OPD_PAUSE_DUR. */
#define BM_ENET_OPD_PAUSE_DUR (0x0000FFFFU) /*!< Bit mask for ENET_OPD_PAUSE_DUR. */
#define BS_ENET_OPD_PAUSE_DUR (16U)        /*!< Bit field size in bits for ENET_OPD_PAUSE_DUR. */

/*! @brief Read current value of the ENET_OPD_PAUSE_DUR field. */
#define BR_ENET_OPD_PAUSE_DUR(x) (HW_ENET_OPD(x).B.PAUSE_DUR)

/*! @brief Format value for bitfield ENET_OPD_PAUSE_DUR. */
#define BF_ENET_OPD_PAUSE_DUR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_OPD_PAUSE_DUR) & BM_ENET_OPD_PAUSE_DUR)

/*! @brief Set the PAUSE_DUR field to a new value. */
#define BW_ENET_OPD_PAUSE_DUR(x, v) (HW_ENET_OPD_WR(x, (HW_ENET_OPD_RD(x) & ~BM_ENET_OPD_PAUSE_DUR) | BF_ENET_OPD_PAUSE_DUR(v)))
/*@}*/

/*!
 * @name Register ENET_OPD, field OPCODE[31:16] (RO)
 *
 * These fields have a constant value of 0x0001.
 */
/*@{*/
#define BP_ENET_OPD_OPCODE   (16U)         /*!< Bit position for ENET_OPD_OPCODE. */
#define BM_ENET_OPD_OPCODE   (0xFFFF0000U) /*!< Bit mask for ENET_OPD_OPCODE. */
#define BS_ENET_OPD_OPCODE   (16U)         /*!< Bit field size in bits for ENET_OPD_OPCODE. */

/*! @brief Read current value of the ENET_OPD_OPCODE field. */
#define BR_ENET_OPD_OPCODE(x) (HW_ENET_OPD(x).B.OPCODE)
/*@}*/

/*******************************************************************************
 * HW_ENET_TXICn - Transmit Interrupt Coalescing Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_TXICn - Transmit Interrupt Coalescing Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * See Interrupt coalescence for more information.
 */
typedef union _hw_enet_txicn
{
    uint32_t U;
    struct _hw_enet_txicn_bitfields
    {
        uint32_t ICTT : 16;            /*!< [15:0] Interrupt coalescing timer threshold
                                        * */
        uint32_t RESERVED0 : 4;        /*!< [19:16] This field must be set to 0. */
        uint32_t ICFT : 8;             /*!< [27:20] Interrupt coalescing frame count
                                        * threshold */
        uint32_t RESERVED1 : 2;        /*!< [29:28] This field must be set to 0. */
        uint32_t ICCS : 1;             /*!< [30] Interrupt Coalescing Timer Clock Source
                                        * Select */
        uint32_t ICEN : 1;             /*!< [31] Interrupt Coalescing Enable */
    } B;
} hw_enet_txicn_t;

/*!
 * @name Constants and macros for entire ENET_TXICn register
 */
/*@{*/
#define HW_ENET_TXICn_COUNT (3U)

#define HW_ENET_TXICn_ADDR(x, n) ((uintptr_t)(x) + 0xF0U + (0x4U * (n)))

#define HW_ENET_TXICn(x, n)      (*(__IO hw_enet_txicn_t *) HW_ENET_TXICn_ADDR(x, n))
#define HW_ENET_TXICn_RD(x, n)   (HW_ENET_TXICn(x, n).U)
#define HW_ENET_TXICn_WR(x, n, v) (HW_ENET_TXICn(x, n).U = (v))
#define HW_ENET_TXICn_SET(x, n, v) (HW_ENET_TXICn_WR(x, n, HW_ENET_TXICn_RD(x, n) |  (v)))
#define HW_ENET_TXICn_CLR(x, n, v) (HW_ENET_TXICn_WR(x, n, HW_ENET_TXICn_RD(x, n) & ~(v)))
#define HW_ENET_TXICn_TOG(x, n, v) (HW_ENET_TXICn_WR(x, n, HW_ENET_TXICn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TXICn bitfields
 */

/*!
 * @name Register ENET_TXICn, field ICTT[15:0] (RW)
 *
 * Interrupt coalescing timer threshold in units of 64 clock periods. This value
 * determines the maximum amount of time after transmitting a frame before
 * raising an interrupt. The threshold timer is disabled after expiring or number of
 * frame transmission defined by ICFT and starts again upon transmission of the
 * next first frame. Must be greater than zero to avoid unpredictable behavior.
 */
/*@{*/
#define BP_ENET_TXICn_ICTT   (0U)          /*!< Bit position for ENET_TXICn_ICTT. */
#define BM_ENET_TXICn_ICTT   (0x0000FFFFU) /*!< Bit mask for ENET_TXICn_ICTT. */
#define BS_ENET_TXICn_ICTT   (16U)         /*!< Bit field size in bits for ENET_TXICn_ICTT. */

/*! @brief Read current value of the ENET_TXICn_ICTT field. */
#define BR_ENET_TXICn_ICTT(x, n) (HW_ENET_TXICn(x, n).B.ICTT)

/*! @brief Format value for bitfield ENET_TXICn_ICTT. */
#define BF_ENET_TXICn_ICTT(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TXICn_ICTT) & BM_ENET_TXICn_ICTT)

/*! @brief Set the ICTT field to a new value. */
#define BW_ENET_TXICn_ICTT(x, n, v) (HW_ENET_TXICn_WR(x, n, (HW_ENET_TXICn_RD(x, n) & ~BM_ENET_TXICn_ICTT) | BF_ENET_TXICn_ICTT(v)))
/*@}*/

/*!
 * @name Register ENET_TXICn, field ICFT[27:20] (RW)
 *
 * This value determines the number of frames needed to be transmitted for
 * raising an interrupt. Frame counter restarts after reaching this threshold value or
 * after the expiring of the coalescing timer. Must be greater than zero to
 * avoid unpredictable behavior.
 */
/*@{*/
#define BP_ENET_TXICn_ICFT   (20U)         /*!< Bit position for ENET_TXICn_ICFT. */
#define BM_ENET_TXICn_ICFT   (0x0FF00000U) /*!< Bit mask for ENET_TXICn_ICFT. */
#define BS_ENET_TXICn_ICFT   (8U)          /*!< Bit field size in bits for ENET_TXICn_ICFT. */

/*! @brief Read current value of the ENET_TXICn_ICFT field. */
#define BR_ENET_TXICn_ICFT(x, n) (HW_ENET_TXICn(x, n).B.ICFT)

/*! @brief Format value for bitfield ENET_TXICn_ICFT. */
#define BF_ENET_TXICn_ICFT(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TXICn_ICFT) & BM_ENET_TXICn_ICFT)

/*! @brief Set the ICFT field to a new value. */
#define BW_ENET_TXICn_ICFT(x, n, v) (HW_ENET_TXICn_WR(x, n, (HW_ENET_TXICn_RD(x, n) & ~BM_ENET_TXICn_ICFT) | BF_ENET_TXICn_ICFT(v)))
/*@}*/

/*!
 * @name Register ENET_TXICn, field ICCS[30] (RW)
 *
 * Values:
 * - 0 - Use MII/GMII TX clocks.
 * - 1 - Use ENET system clock.
 */
/*@{*/
#define BP_ENET_TXICn_ICCS   (30U)         /*!< Bit position for ENET_TXICn_ICCS. */
#define BM_ENET_TXICn_ICCS   (0x40000000U) /*!< Bit mask for ENET_TXICn_ICCS. */
#define BS_ENET_TXICn_ICCS   (1U)          /*!< Bit field size in bits for ENET_TXICn_ICCS. */

/*! @brief Read current value of the ENET_TXICn_ICCS field. */
#define BR_ENET_TXICn_ICCS(x, n) (HW_ENET_TXICn(x, n).B.ICCS)

/*! @brief Format value for bitfield ENET_TXICn_ICCS. */
#define BF_ENET_TXICn_ICCS(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TXICn_ICCS) & BM_ENET_TXICn_ICCS)

/*! @brief Set the ICCS field to a new value. */
#define BW_ENET_TXICn_ICCS(x, n, v) (HW_ENET_TXICn_WR(x, n, (HW_ENET_TXICn_RD(x, n) & ~BM_ENET_TXICn_ICCS) | BF_ENET_TXICn_ICCS(v)))
/*@}*/

/*!
 * @name Register ENET_TXICn, field ICEN[31] (RW)
 *
 * Values:
 * - 0 - Disable Interrupt coalescing.
 * - 1 - Enable Interrupt coalescing.
 */
/*@{*/
#define BP_ENET_TXICn_ICEN   (31U)         /*!< Bit position for ENET_TXICn_ICEN. */
#define BM_ENET_TXICn_ICEN   (0x80000000U) /*!< Bit mask for ENET_TXICn_ICEN. */
#define BS_ENET_TXICn_ICEN   (1U)          /*!< Bit field size in bits for ENET_TXICn_ICEN. */

/*! @brief Read current value of the ENET_TXICn_ICEN field. */
#define BR_ENET_TXICn_ICEN(x, n) (HW_ENET_TXICn(x, n).B.ICEN)

/*! @brief Format value for bitfield ENET_TXICn_ICEN. */
#define BF_ENET_TXICn_ICEN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TXICn_ICEN) & BM_ENET_TXICn_ICEN)

/*! @brief Set the ICEN field to a new value. */
#define BW_ENET_TXICn_ICEN(x, n, v) (HW_ENET_TXICn_WR(x, n, (HW_ENET_TXICn_RD(x, n) & ~BM_ENET_TXICn_ICEN) | BF_ENET_TXICn_ICEN(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RXICn - Receive Interrupt Coalescing Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RXICn - Receive Interrupt Coalescing Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * See Interrupt coalescence for more information.
 */
typedef union _hw_enet_rxicn
{
    uint32_t U;
    struct _hw_enet_rxicn_bitfields
    {
        uint32_t ICTT : 16;            /*!< [15:0] Interrupt coalescing timer threshold
                                        * */
        uint32_t RESERVED0 : 4;        /*!< [19:16] This field must be set to 0. */
        uint32_t ICFT : 8;             /*!< [27:20] Interrupt coalescing frame count
                                        * threshold */
        uint32_t RESERVED1 : 2;        /*!< [29:28] This field must be set to 0. */
        uint32_t ICCS : 1;             /*!< [30] Interrupt Coalescing Timer Clock Source
                                        * Select */
        uint32_t ICEN : 1;             /*!< [31] Interrupt Coalescing Enable */
    } B;
} hw_enet_rxicn_t;

/*!
 * @name Constants and macros for entire ENET_RXICn register
 */
/*@{*/
#define HW_ENET_RXICn_COUNT (3U)

#define HW_ENET_RXICn_ADDR(x, n) ((uintptr_t)(x) + 0x100U + (0x4U * (n)))

#define HW_ENET_RXICn(x, n)      (*(__IO hw_enet_rxicn_t *) HW_ENET_RXICn_ADDR(x, n))
#define HW_ENET_RXICn_RD(x, n)   (HW_ENET_RXICn(x, n).U)
#define HW_ENET_RXICn_WR(x, n, v) (HW_ENET_RXICn(x, n).U = (v))
#define HW_ENET_RXICn_SET(x, n, v) (HW_ENET_RXICn_WR(x, n, HW_ENET_RXICn_RD(x, n) |  (v)))
#define HW_ENET_RXICn_CLR(x, n, v) (HW_ENET_RXICn_WR(x, n, HW_ENET_RXICn_RD(x, n) & ~(v)))
#define HW_ENET_RXICn_TOG(x, n, v) (HW_ENET_RXICn_WR(x, n, HW_ENET_RXICn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RXICn bitfields
 */

/*!
 * @name Register ENET_RXICn, field ICTT[15:0] (RW)
 *
 * Interrupt coalescing timer threshold in units of 64 clock periods. This value
 * determines the maximum amount of time after receiving a frame before raising
 * an interrupt. The threshold timer is disabled after expiring or number of
 * frame reception defined by ICFT and starts again upon reception of the next first
 * frame. Must be greater than zero to avoid unpredictable behavior.
 */
/*@{*/
#define BP_ENET_RXICn_ICTT   (0U)          /*!< Bit position for ENET_RXICn_ICTT. */
#define BM_ENET_RXICn_ICTT   (0x0000FFFFU) /*!< Bit mask for ENET_RXICn_ICTT. */
#define BS_ENET_RXICn_ICTT   (16U)         /*!< Bit field size in bits for ENET_RXICn_ICTT. */

/*! @brief Read current value of the ENET_RXICn_ICTT field. */
#define BR_ENET_RXICn_ICTT(x, n) (HW_ENET_RXICn(x, n).B.ICTT)

/*! @brief Format value for bitfield ENET_RXICn_ICTT. */
#define BF_ENET_RXICn_ICTT(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RXICn_ICTT) & BM_ENET_RXICn_ICTT)

/*! @brief Set the ICTT field to a new value. */
#define BW_ENET_RXICn_ICTT(x, n, v) (HW_ENET_RXICn_WR(x, n, (HW_ENET_RXICn_RD(x, n) & ~BM_ENET_RXICn_ICTT) | BF_ENET_RXICn_ICTT(v)))
/*@}*/

/*!
 * @name Register ENET_RXICn, field ICFT[27:20] (RW)
 *
 * This value determines the number of frames needed to be received for raising
 * an interrupt. Frame counter restarts after reaching this threshold value or
 * after the expiring of the coalescing timer. Must be greater than zero to avoid
 * unpredictable behavior.
 */
/*@{*/
#define BP_ENET_RXICn_ICFT   (20U)         /*!< Bit position for ENET_RXICn_ICFT. */
#define BM_ENET_RXICn_ICFT   (0x0FF00000U) /*!< Bit mask for ENET_RXICn_ICFT. */
#define BS_ENET_RXICn_ICFT   (8U)          /*!< Bit field size in bits for ENET_RXICn_ICFT. */

/*! @brief Read current value of the ENET_RXICn_ICFT field. */
#define BR_ENET_RXICn_ICFT(x, n) (HW_ENET_RXICn(x, n).B.ICFT)

/*! @brief Format value for bitfield ENET_RXICn_ICFT. */
#define BF_ENET_RXICn_ICFT(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RXICn_ICFT) & BM_ENET_RXICn_ICFT)

/*! @brief Set the ICFT field to a new value. */
#define BW_ENET_RXICn_ICFT(x, n, v) (HW_ENET_RXICn_WR(x, n, (HW_ENET_RXICn_RD(x, n) & ~BM_ENET_RXICn_ICFT) | BF_ENET_RXICn_ICFT(v)))
/*@}*/

/*!
 * @name Register ENET_RXICn, field ICCS[30] (RW)
 *
 * Values:
 * - 0 - Use MII/GMII TX clocks.
 * - 1 - Use ENET system clock.
 */
/*@{*/
#define BP_ENET_RXICn_ICCS   (30U)         /*!< Bit position for ENET_RXICn_ICCS. */
#define BM_ENET_RXICn_ICCS   (0x40000000U) /*!< Bit mask for ENET_RXICn_ICCS. */
#define BS_ENET_RXICn_ICCS   (1U)          /*!< Bit field size in bits for ENET_RXICn_ICCS. */

/*! @brief Read current value of the ENET_RXICn_ICCS field. */
#define BR_ENET_RXICn_ICCS(x, n) (HW_ENET_RXICn(x, n).B.ICCS)

/*! @brief Format value for bitfield ENET_RXICn_ICCS. */
#define BF_ENET_RXICn_ICCS(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RXICn_ICCS) & BM_ENET_RXICn_ICCS)

/*! @brief Set the ICCS field to a new value. */
#define BW_ENET_RXICn_ICCS(x, n, v) (HW_ENET_RXICn_WR(x, n, (HW_ENET_RXICn_RD(x, n) & ~BM_ENET_RXICn_ICCS) | BF_ENET_RXICn_ICCS(v)))
/*@}*/

/*!
 * @name Register ENET_RXICn, field ICEN[31] (RW)
 *
 * Values:
 * - 0 - Disable Interrupt coalescing.
 * - 1 - Enable Interrupt coalescing.
 */
/*@{*/
#define BP_ENET_RXICn_ICEN   (31U)         /*!< Bit position for ENET_RXICn_ICEN. */
#define BM_ENET_RXICn_ICEN   (0x80000000U) /*!< Bit mask for ENET_RXICn_ICEN. */
#define BS_ENET_RXICn_ICEN   (1U)          /*!< Bit field size in bits for ENET_RXICn_ICEN. */

/*! @brief Read current value of the ENET_RXICn_ICEN field. */
#define BR_ENET_RXICn_ICEN(x, n) (HW_ENET_RXICn(x, n).B.ICEN)

/*! @brief Format value for bitfield ENET_RXICn_ICEN. */
#define BF_ENET_RXICn_ICEN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RXICn_ICEN) & BM_ENET_RXICn_ICEN)

/*! @brief Set the ICEN field to a new value. */
#define BW_ENET_RXICn_ICEN(x, n, v) (HW_ENET_RXICn_WR(x, n, (HW_ENET_RXICn_RD(x, n) & ~BM_ENET_RXICn_ICEN) | BF_ENET_RXICn_ICEN(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_IAUR - Descriptor Individual Upper Address Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IAUR - Descriptor Individual Upper Address Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * IAUR contains the upper 32 bits of the 64-bit individual address hash table.
 * The address recognition process uses this table to check for a possible match
 * with the destination address (DA) field of receive frames with an individual
 * DA. This register is not reset and you must initialize it.
 */
typedef union _hw_enet_iaur
{
    uint32_t U;
    struct _hw_enet_iaur_bitfields
    {
        uint32_t IADDR1 : 32;          /*!< [31:0]  */
    } B;
} hw_enet_iaur_t;

/*!
 * @name Constants and macros for entire ENET_IAUR register
 */
/*@{*/
#define HW_ENET_IAUR_ADDR(x)     ((uintptr_t)(x) + 0x118U)

#define HW_ENET_IAUR(x)          (*(__IO hw_enet_iaur_t *) HW_ENET_IAUR_ADDR(x))
#define HW_ENET_IAUR_RD(x)       (HW_ENET_IAUR(x).U)
#define HW_ENET_IAUR_WR(x, v)    (HW_ENET_IAUR(x).U = (v))
#define HW_ENET_IAUR_SET(x, v)   (HW_ENET_IAUR_WR(x, HW_ENET_IAUR_RD(x) |  (v)))
#define HW_ENET_IAUR_CLR(x, v)   (HW_ENET_IAUR_WR(x, HW_ENET_IAUR_RD(x) & ~(v)))
#define HW_ENET_IAUR_TOG(x, v)   (HW_ENET_IAUR_WR(x, HW_ENET_IAUR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_IAUR bitfields
 */

/*!
 * @name Register ENET_IAUR, field IADDR1[31:0] (RW)
 *
 * Contains the upper 32 bits of the 64-bit hash table used in the address
 * recognition process for receive frames with a unicast address. Bit 31 of IADDR1
 * contains hash index bit 63. Bit 0 of IADDR1 contains hash index bit 32.
 */
/*@{*/
#define BP_ENET_IAUR_IADDR1  (0U)          /*!< Bit position for ENET_IAUR_IADDR1. */
#define BM_ENET_IAUR_IADDR1  (0xFFFFFFFFU) /*!< Bit mask for ENET_IAUR_IADDR1. */
#define BS_ENET_IAUR_IADDR1  (32U)         /*!< Bit field size in bits for ENET_IAUR_IADDR1. */

/*! @brief Read current value of the ENET_IAUR_IADDR1 field. */
#define BR_ENET_IAUR_IADDR1(x) (HW_ENET_IAUR(x).U)

/*! @brief Format value for bitfield ENET_IAUR_IADDR1. */
#define BF_ENET_IAUR_IADDR1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_IAUR_IADDR1) & BM_ENET_IAUR_IADDR1)

/*! @brief Set the IADDR1 field to a new value. */
#define BW_ENET_IAUR_IADDR1(x, v) (HW_ENET_IAUR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_ENET_IALR - Descriptor Individual Lower Address Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IALR - Descriptor Individual Lower Address Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * IALR contains the lower 32 bits of the 64-bit individual address hash table.
 * The address recognition process uses this table to check for a possible match
 * with the DA field of receive frames with an individual DA. This register is
 * not reset and you must initialize it.
 */
typedef union _hw_enet_ialr
{
    uint32_t U;
    struct _hw_enet_ialr_bitfields
    {
        uint32_t IADDR2 : 32;          /*!< [31:0]  */
    } B;
} hw_enet_ialr_t;

/*!
 * @name Constants and macros for entire ENET_IALR register
 */
/*@{*/
#define HW_ENET_IALR_ADDR(x)     ((uintptr_t)(x) + 0x11CU)

#define HW_ENET_IALR(x)          (*(__IO hw_enet_ialr_t *) HW_ENET_IALR_ADDR(x))
#define HW_ENET_IALR_RD(x)       (HW_ENET_IALR(x).U)
#define HW_ENET_IALR_WR(x, v)    (HW_ENET_IALR(x).U = (v))
#define HW_ENET_IALR_SET(x, v)   (HW_ENET_IALR_WR(x, HW_ENET_IALR_RD(x) |  (v)))
#define HW_ENET_IALR_CLR(x, v)   (HW_ENET_IALR_WR(x, HW_ENET_IALR_RD(x) & ~(v)))
#define HW_ENET_IALR_TOG(x, v)   (HW_ENET_IALR_WR(x, HW_ENET_IALR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_IALR bitfields
 */

/*!
 * @name Register ENET_IALR, field IADDR2[31:0] (RW)
 *
 * Contains the lower 32 bits of the 64-bit hash table used in the address
 * recognition process for receive frames with a unicast address. Bit 31 of IADDR2
 * contains hash index bit 31. Bit 0 of IADDR2 contains hash index bit 0.
 */
/*@{*/
#define BP_ENET_IALR_IADDR2  (0U)          /*!< Bit position for ENET_IALR_IADDR2. */
#define BM_ENET_IALR_IADDR2  (0xFFFFFFFFU) /*!< Bit mask for ENET_IALR_IADDR2. */
#define BS_ENET_IALR_IADDR2  (32U)         /*!< Bit field size in bits for ENET_IALR_IADDR2. */

/*! @brief Read current value of the ENET_IALR_IADDR2 field. */
#define BR_ENET_IALR_IADDR2(x) (HW_ENET_IALR(x).U)

/*! @brief Format value for bitfield ENET_IALR_IADDR2. */
#define BF_ENET_IALR_IADDR2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_IALR_IADDR2) & BM_ENET_IALR_IADDR2)

/*! @brief Set the IADDR2 field to a new value. */
#define BW_ENET_IALR_IADDR2(x, v) (HW_ENET_IALR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_ENET_GAUR - Descriptor Group Upper Address Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_GAUR - Descriptor Group Upper Address Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GAUR contains the upper 32 bits of the 64-bit hash table used in the address
 * recognition process for receive frames with a multicast address. You must
 * initialize this register.
 */
typedef union _hw_enet_gaur
{
    uint32_t U;
    struct _hw_enet_gaur_bitfields
    {
        uint32_t GADDR1 : 32;          /*!< [31:0]  */
    } B;
} hw_enet_gaur_t;

/*!
 * @name Constants and macros for entire ENET_GAUR register
 */
/*@{*/
#define HW_ENET_GAUR_ADDR(x)     ((uintptr_t)(x) + 0x120U)

#define HW_ENET_GAUR(x)          (*(__IO hw_enet_gaur_t *) HW_ENET_GAUR_ADDR(x))
#define HW_ENET_GAUR_RD(x)       (HW_ENET_GAUR(x).U)
#define HW_ENET_GAUR_WR(x, v)    (HW_ENET_GAUR(x).U = (v))
#define HW_ENET_GAUR_SET(x, v)   (HW_ENET_GAUR_WR(x, HW_ENET_GAUR_RD(x) |  (v)))
#define HW_ENET_GAUR_CLR(x, v)   (HW_ENET_GAUR_WR(x, HW_ENET_GAUR_RD(x) & ~(v)))
#define HW_ENET_GAUR_TOG(x, v)   (HW_ENET_GAUR_WR(x, HW_ENET_GAUR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_GAUR bitfields
 */

/*!
 * @name Register ENET_GAUR, field GADDR1[31:0] (RW)
 *
 * Contains the upper 32 bits of the 64-bit hash table used in the address
 * recognition process for receive frames with a multicast address. Bit 31 of GADDR1
 * contains hash index bit 63. Bit 0 of GADDR1 contains hash index bit 32.
 */
/*@{*/
#define BP_ENET_GAUR_GADDR1  (0U)          /*!< Bit position for ENET_GAUR_GADDR1. */
#define BM_ENET_GAUR_GADDR1  (0xFFFFFFFFU) /*!< Bit mask for ENET_GAUR_GADDR1. */
#define BS_ENET_GAUR_GADDR1  (32U)         /*!< Bit field size in bits for ENET_GAUR_GADDR1. */

/*! @brief Read current value of the ENET_GAUR_GADDR1 field. */
#define BR_ENET_GAUR_GADDR1(x) (HW_ENET_GAUR(x).U)

/*! @brief Format value for bitfield ENET_GAUR_GADDR1. */
#define BF_ENET_GAUR_GADDR1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_GAUR_GADDR1) & BM_ENET_GAUR_GADDR1)

/*! @brief Set the GADDR1 field to a new value. */
#define BW_ENET_GAUR_GADDR1(x, v) (HW_ENET_GAUR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_ENET_GALR - Descriptor Group Lower Address Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_GALR - Descriptor Group Lower Address Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GALR contains the lower 32 bits of the 64-bit hash table used in the address
 * recognition process for receive frames with a multicast address. You must
 * initialize this register.
 */
typedef union _hw_enet_galr
{
    uint32_t U;
    struct _hw_enet_galr_bitfields
    {
        uint32_t GADDR2 : 32;          /*!< [31:0]  */
    } B;
} hw_enet_galr_t;

/*!
 * @name Constants and macros for entire ENET_GALR register
 */
/*@{*/
#define HW_ENET_GALR_ADDR(x)     ((uintptr_t)(x) + 0x124U)

#define HW_ENET_GALR(x)          (*(__IO hw_enet_galr_t *) HW_ENET_GALR_ADDR(x))
#define HW_ENET_GALR_RD(x)       (HW_ENET_GALR(x).U)
#define HW_ENET_GALR_WR(x, v)    (HW_ENET_GALR(x).U = (v))
#define HW_ENET_GALR_SET(x, v)   (HW_ENET_GALR_WR(x, HW_ENET_GALR_RD(x) |  (v)))
#define HW_ENET_GALR_CLR(x, v)   (HW_ENET_GALR_WR(x, HW_ENET_GALR_RD(x) & ~(v)))
#define HW_ENET_GALR_TOG(x, v)   (HW_ENET_GALR_WR(x, HW_ENET_GALR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_GALR bitfields
 */

/*!
 * @name Register ENET_GALR, field GADDR2[31:0] (RW)
 *
 * Contains the lower 32 bits of the 64-bit hash table used in the address
 * recognition process for receive frames with a multicast address. Bit 31 of GADDR2
 * contains hash index bit 31. Bit 0 of GADDR2 contains hash index bit 0.
 */
/*@{*/
#define BP_ENET_GALR_GADDR2  (0U)          /*!< Bit position for ENET_GALR_GADDR2. */
#define BM_ENET_GALR_GADDR2  (0xFFFFFFFFU) /*!< Bit mask for ENET_GALR_GADDR2. */
#define BS_ENET_GALR_GADDR2  (32U)         /*!< Bit field size in bits for ENET_GALR_GADDR2. */

/*! @brief Read current value of the ENET_GALR_GADDR2 field. */
#define BR_ENET_GALR_GADDR2(x) (HW_ENET_GALR(x).U)

/*! @brief Format value for bitfield ENET_GALR_GADDR2. */
#define BF_ENET_GALR_GADDR2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_GALR_GADDR2) & BM_ENET_GALR_GADDR2)

/*! @brief Set the GADDR2 field to a new value. */
#define BW_ENET_GALR_GADDR2(x, v) (HW_ENET_GALR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_ENET_TFWR - Transmit FIFO Watermark Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_TFWR - Transmit FIFO Watermark Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * If TFWR[STRFWD] is cleared, TFWR[TFWR] controls the amount of data required
 * in the transmit FIFO before transmission of a frame can begin. This allows you
 * to minimize transmit latency (TFWR = 00 or 01) or allow for larger bus access
 * latency (TFWR = 11) due to contention for the system bus. Setting the
 * watermark to a high value minimizes the risk of transmit FIFO underrun due to
 * contention for the system bus. The byte counts associated with the TFWR field may need
 * to be modified to match a given system requirement, for example, worst-case
 * bus access latency by the transmit data uDMA channel. When the FIFO level
 * reaches the value the TFWR field and when the STR_FWD is set to '0', the MAC
 * transmit control logic starts frame transmission even before the end-of-frame is
 * available in the FIFO (cut-through operation). If a complete frame has a size
 * smaller than the threshold programmed with TFWR, the MAC also transmits the Frame
 * to the line. To enable store and forward on the Transmit path, set STR_FWD to
 * '1'. In this case, the MAC starts to transmit data only when a complete frame
 * is stored in the Transmit FIFO.
 */
typedef union _hw_enet_tfwr
{
    uint32_t U;
    struct _hw_enet_tfwr_bitfields
    {
        uint32_t TFWR : 6;             /*!< [5:0] Transmit FIFO Write */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t STRFWD : 1;           /*!< [8] Store And Forward Enable */
        uint32_t RESERVED1 : 23;       /*!< [31:9]  */
    } B;
} hw_enet_tfwr_t;

/*!
 * @name Constants and macros for entire ENET_TFWR register
 */
/*@{*/
#define HW_ENET_TFWR_ADDR(x)     ((uintptr_t)(x) + 0x144U)

#define HW_ENET_TFWR(x)          (*(__IO hw_enet_tfwr_t *) HW_ENET_TFWR_ADDR(x))
#define HW_ENET_TFWR_RD(x)       (HW_ENET_TFWR(x).U)
#define HW_ENET_TFWR_WR(x, v)    (HW_ENET_TFWR(x).U = (v))
#define HW_ENET_TFWR_SET(x, v)   (HW_ENET_TFWR_WR(x, HW_ENET_TFWR_RD(x) |  (v)))
#define HW_ENET_TFWR_CLR(x, v)   (HW_ENET_TFWR_WR(x, HW_ENET_TFWR_RD(x) & ~(v)))
#define HW_ENET_TFWR_TOG(x, v)   (HW_ENET_TFWR_WR(x, HW_ENET_TFWR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TFWR bitfields
 */

/*!
 * @name Register ENET_TFWR, field TFWR[5:0] (RW)
 *
 * If TFWR[STRFWD] is cleared, this field indicates the number of bytes, in
 * steps of 64 bytes, written to the transmit FIFO before transmission of a frame
 * begins. If a frame with less than the threshold is written, it is still sent
 * independently of this threshold setting. The threshold is relevant only if the
 * frame is larger than the threshold given.
 *
 * Values:
 * - 000000 - 64 bytes written.
 * - 000001 - 64 bytes written.
 * - 000010 - 128 bytes written.
 * - 000011 - 192 bytes written.
 * - 111111 - 4032 bytes written.
 */
/*@{*/
#define BP_ENET_TFWR_TFWR    (0U)          /*!< Bit position for ENET_TFWR_TFWR. */
#define BM_ENET_TFWR_TFWR    (0x0000003FU) /*!< Bit mask for ENET_TFWR_TFWR. */
#define BS_ENET_TFWR_TFWR    (6U)          /*!< Bit field size in bits for ENET_TFWR_TFWR. */

/*! @brief Read current value of the ENET_TFWR_TFWR field. */
#define BR_ENET_TFWR_TFWR(x) (HW_ENET_TFWR(x).B.TFWR)

/*! @brief Format value for bitfield ENET_TFWR_TFWR. */
#define BF_ENET_TFWR_TFWR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TFWR_TFWR) & BM_ENET_TFWR_TFWR)

/*! @brief Set the TFWR field to a new value. */
#define BW_ENET_TFWR_TFWR(x, v) (HW_ENET_TFWR_WR(x, (HW_ENET_TFWR_RD(x) & ~BM_ENET_TFWR_TFWR) | BF_ENET_TFWR_TFWR(v)))
/*@}*/

/*!
 * @name Register ENET_TFWR, field STRFWD[8] (RW)
 *
 * Values:
 * - 0 - Reset. The transmission start threshold is programmed in TFWR[TFWR].
 * - 1 - Enabled.
 */
/*@{*/
#define BP_ENET_TFWR_STRFWD  (8U)          /*!< Bit position for ENET_TFWR_STRFWD. */
#define BM_ENET_TFWR_STRFWD  (0x00000100U) /*!< Bit mask for ENET_TFWR_STRFWD. */
#define BS_ENET_TFWR_STRFWD  (1U)          /*!< Bit field size in bits for ENET_TFWR_STRFWD. */

/*! @brief Read current value of the ENET_TFWR_STRFWD field. */
#define BR_ENET_TFWR_STRFWD(x) (HW_ENET_TFWR(x).B.STRFWD)

/*! @brief Format value for bitfield ENET_TFWR_STRFWD. */
#define BF_ENET_TFWR_STRFWD(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TFWR_STRFWD) & BM_ENET_TFWR_STRFWD)

/*! @brief Set the STRFWD field to a new value. */
#define BW_ENET_TFWR_STRFWD(x, v) (HW_ENET_TFWR_WR(x, (HW_ENET_TFWR_RD(x) & ~BM_ENET_TFWR_STRFWD) | BF_ENET_TFWR_STRFWD(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RDSR1 - Receive Descriptor Ring 1 Start Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RDSR1 - Receive Descriptor Ring 1 Start Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * RDSR1 points to the beginning of circular receive buffer descriptor queue 1
 * in external memory. This pointer must be 64-bit aligned (bits 29-31 must be
 * zero); however, for optimal performance the pointer should be 512-bit aligned,
 * that is, evenly divisible by 64. This register must be initialized prior to
 * operation.
 */
typedef union _hw_enet_rdsr1
{
    uint32_t U;
    struct _hw_enet_rdsr1_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t R_DES_START : 29;     /*!< [31:3]  */
    } B;
} hw_enet_rdsr1_t;

/*!
 * @name Constants and macros for entire ENET_RDSR1 register
 */
/*@{*/
#define HW_ENET_RDSR1_ADDR(x)    ((uintptr_t)(x) + 0x160U)

#define HW_ENET_RDSR1(x)         (*(__IO hw_enet_rdsr1_t *) HW_ENET_RDSR1_ADDR(x))
#define HW_ENET_RDSR1_RD(x)      (HW_ENET_RDSR1(x).U)
#define HW_ENET_RDSR1_WR(x, v)   (HW_ENET_RDSR1(x).U = (v))
#define HW_ENET_RDSR1_SET(x, v)  (HW_ENET_RDSR1_WR(x, HW_ENET_RDSR1_RD(x) |  (v)))
#define HW_ENET_RDSR1_CLR(x, v)  (HW_ENET_RDSR1_WR(x, HW_ENET_RDSR1_RD(x) & ~(v)))
#define HW_ENET_RDSR1_TOG(x, v)  (HW_ENET_RDSR1_WR(x, HW_ENET_RDSR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RDSR1 bitfields
 */

/*!
 * @name Register ENET_RDSR1, field R_DES_START[31:3] (RW)
 *
 * Pointer to the beginning of the receive buffer descriptor queue 1.
 */
/*@{*/
#define BP_ENET_RDSR1_R_DES_START (3U)     /*!< Bit position for ENET_RDSR1_R_DES_START. */
#define BM_ENET_RDSR1_R_DES_START (0xFFFFFFF8U) /*!< Bit mask for ENET_RDSR1_R_DES_START. */
#define BS_ENET_RDSR1_R_DES_START (29U)    /*!< Bit field size in bits for ENET_RDSR1_R_DES_START. */

/*! @brief Read current value of the ENET_RDSR1_R_DES_START field. */
#define BR_ENET_RDSR1_R_DES_START(x) (HW_ENET_RDSR1(x).B.R_DES_START)

/*! @brief Format value for bitfield ENET_RDSR1_R_DES_START. */
#define BF_ENET_RDSR1_R_DES_START(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RDSR1_R_DES_START) & BM_ENET_RDSR1_R_DES_START)

/*! @brief Set the R_DES_START field to a new value. */
#define BW_ENET_RDSR1_R_DES_START(x, v) (HW_ENET_RDSR1_WR(x, (HW_ENET_RDSR1_RD(x) & ~BM_ENET_RDSR1_R_DES_START) | BF_ENET_RDSR1_R_DES_START(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TDSR1 - Transmit Buffer Descriptor Ring 1 Start Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_TDSR1 - Transmit Buffer Descriptor Ring 1 Start Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * TDSR1 provides a pointer to the beginning of the circular transmit buffer
 * descriptor queue 1 in external memory. This pointer must be 64-bit aligned (bits
 * 29-31 must be zero); however, for optimal performance the pointer should be
 * 512-bit aligned, that is, evenly divisible by 64. This register must be
 * initialized prior to operation.
 */
typedef union _hw_enet_tdsr1
{
    uint32_t U;
    struct _hw_enet_tdsr1_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t X_DES_START : 29;     /*!< [31:3]  */
    } B;
} hw_enet_tdsr1_t;

/*!
 * @name Constants and macros for entire ENET_TDSR1 register
 */
/*@{*/
#define HW_ENET_TDSR1_ADDR(x)    ((uintptr_t)(x) + 0x164U)

#define HW_ENET_TDSR1(x)         (*(__IO hw_enet_tdsr1_t *) HW_ENET_TDSR1_ADDR(x))
#define HW_ENET_TDSR1_RD(x)      (HW_ENET_TDSR1(x).U)
#define HW_ENET_TDSR1_WR(x, v)   (HW_ENET_TDSR1(x).U = (v))
#define HW_ENET_TDSR1_SET(x, v)  (HW_ENET_TDSR1_WR(x, HW_ENET_TDSR1_RD(x) |  (v)))
#define HW_ENET_TDSR1_CLR(x, v)  (HW_ENET_TDSR1_WR(x, HW_ENET_TDSR1_RD(x) & ~(v)))
#define HW_ENET_TDSR1_TOG(x, v)  (HW_ENET_TDSR1_WR(x, HW_ENET_TDSR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TDSR1 bitfields
 */

/*!
 * @name Register ENET_TDSR1, field X_DES_START[31:3] (RW)
 *
 * Pointer to the beginning of transmit buffer descriptor queue 1.
 */
/*@{*/
#define BP_ENET_TDSR1_X_DES_START (3U)     /*!< Bit position for ENET_TDSR1_X_DES_START. */
#define BM_ENET_TDSR1_X_DES_START (0xFFFFFFF8U) /*!< Bit mask for ENET_TDSR1_X_DES_START. */
#define BS_ENET_TDSR1_X_DES_START (29U)    /*!< Bit field size in bits for ENET_TDSR1_X_DES_START. */

/*! @brief Read current value of the ENET_TDSR1_X_DES_START field. */
#define BR_ENET_TDSR1_X_DES_START(x) (HW_ENET_TDSR1(x).B.X_DES_START)

/*! @brief Format value for bitfield ENET_TDSR1_X_DES_START. */
#define BF_ENET_TDSR1_X_DES_START(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TDSR1_X_DES_START) & BM_ENET_TDSR1_X_DES_START)

/*! @brief Set the X_DES_START field to a new value. */
#define BW_ENET_TDSR1_X_DES_START(x, v) (HW_ENET_TDSR1_WR(x, (HW_ENET_TDSR1_RD(x) & ~BM_ENET_TDSR1_X_DES_START) | BF_ENET_TDSR1_X_DES_START(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_MRBR1 - Maximum Receive Buffer Size Register - Ring 1
 ******************************************************************************/

/*!
 * @brief HW_ENET_MRBR1 - Maximum Receive Buffer Size Register - Ring 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * MRBR1 is a user-programmable register that dictates the maximum size of all
 * ring-1 receive buffers. This value should take into consideration that the
 * receive CRC is always written into the last receive buffer. To allow one maximum
 * size frame per buffer, MRBR1 must be set to RCR[MAX_FL] or larger. R_BUF_SIZE
 * is concatentated with the four least-significant bits of this register and are
 * used as the maximum receive buffer size. To properly align the buffer, MRBR1
 * must be evenly divisible by 64. To ensure this, set the lower two bits of
 * R_BUF_ZIZE to zero. The lower four bits are already set to zero by the device. To
 * minimize bus usage (descriptor fetches), set MRBR1 greater than or equal to 256
 * bytes. This register must be initialized before operation.
 */
typedef union _hw_enet_mrbr1
{
    uint32_t U;
    struct _hw_enet_mrbr1_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0] This field, which is always zero,
                                        * is the four least-significant bits of the maximum receive buffer size. */
        uint32_t R_BUF_SIZE : 7;       /*!< [10:4]  */
        uint32_t RESERVED1 : 21;       /*!< [31:11]  */
    } B;
} hw_enet_mrbr1_t;

/*!
 * @name Constants and macros for entire ENET_MRBR1 register
 */
/*@{*/
#define HW_ENET_MRBR1_ADDR(x)    ((uintptr_t)(x) + 0x168U)

#define HW_ENET_MRBR1(x)         (*(__IO hw_enet_mrbr1_t *) HW_ENET_MRBR1_ADDR(x))
#define HW_ENET_MRBR1_RD(x)      (HW_ENET_MRBR1(x).U)
#define HW_ENET_MRBR1_WR(x, v)   (HW_ENET_MRBR1(x).U = (v))
#define HW_ENET_MRBR1_SET(x, v)  (HW_ENET_MRBR1_WR(x, HW_ENET_MRBR1_RD(x) |  (v)))
#define HW_ENET_MRBR1_CLR(x, v)  (HW_ENET_MRBR1_WR(x, HW_ENET_MRBR1_RD(x) & ~(v)))
#define HW_ENET_MRBR1_TOG(x, v)  (HW_ENET_MRBR1_WR(x, HW_ENET_MRBR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_MRBR1 bitfields
 */

/*!
 * @name Register ENET_MRBR1, field R_BUF_SIZE[10:4] (RW)
 *
 * Receive buffer size in bytes. This value, concatenated with the four
 * least-significant bits of this register (which are always zero), is the effective
 * maximum receive buffer size.
 */
/*@{*/
#define BP_ENET_MRBR1_R_BUF_SIZE (4U)      /*!< Bit position for ENET_MRBR1_R_BUF_SIZE. */
#define BM_ENET_MRBR1_R_BUF_SIZE (0x000007F0U) /*!< Bit mask for ENET_MRBR1_R_BUF_SIZE. */
#define BS_ENET_MRBR1_R_BUF_SIZE (7U)      /*!< Bit field size in bits for ENET_MRBR1_R_BUF_SIZE. */

/*! @brief Read current value of the ENET_MRBR1_R_BUF_SIZE field. */
#define BR_ENET_MRBR1_R_BUF_SIZE(x) (HW_ENET_MRBR1(x).B.R_BUF_SIZE)

/*! @brief Format value for bitfield ENET_MRBR1_R_BUF_SIZE. */
#define BF_ENET_MRBR1_R_BUF_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_MRBR1_R_BUF_SIZE) & BM_ENET_MRBR1_R_BUF_SIZE)

/*! @brief Set the R_BUF_SIZE field to a new value. */
#define BW_ENET_MRBR1_R_BUF_SIZE(x, v) (HW_ENET_MRBR1_WR(x, (HW_ENET_MRBR1_RD(x) & ~BM_ENET_MRBR1_R_BUF_SIZE) | BF_ENET_MRBR1_R_BUF_SIZE(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RDSR2 - Receive Descriptor Ring 2 Start Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RDSR2 - Receive Descriptor Ring 2 Start Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * RDSR points to the beginning of circular receive buffer descriptor queue 2 in
 * external memory. This pointer must be 64-bit aligned (bits 29-31 must be
 * zero); however, for optimal performance the pointer should be 512-bit aligned,
 * that is, evenly divisible by 64. This register must be initialized prior to
 * operation
 */
typedef union _hw_enet_rdsr2
{
    uint32_t U;
    struct _hw_enet_rdsr2_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t R_DES_START : 29;     /*!< [31:3]  */
    } B;
} hw_enet_rdsr2_t;

/*!
 * @name Constants and macros for entire ENET_RDSR2 register
 */
/*@{*/
#define HW_ENET_RDSR2_ADDR(x)    ((uintptr_t)(x) + 0x16CU)

#define HW_ENET_RDSR2(x)         (*(__IO hw_enet_rdsr2_t *) HW_ENET_RDSR2_ADDR(x))
#define HW_ENET_RDSR2_RD(x)      (HW_ENET_RDSR2(x).U)
#define HW_ENET_RDSR2_WR(x, v)   (HW_ENET_RDSR2(x).U = (v))
#define HW_ENET_RDSR2_SET(x, v)  (HW_ENET_RDSR2_WR(x, HW_ENET_RDSR2_RD(x) |  (v)))
#define HW_ENET_RDSR2_CLR(x, v)  (HW_ENET_RDSR2_WR(x, HW_ENET_RDSR2_RD(x) & ~(v)))
#define HW_ENET_RDSR2_TOG(x, v)  (HW_ENET_RDSR2_WR(x, HW_ENET_RDSR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RDSR2 bitfields
 */

/*!
 * @name Register ENET_RDSR2, field R_DES_START[31:3] (RW)
 *
 * Pointer to the beginning of receive buffer descriptor queue 2.
 */
/*@{*/
#define BP_ENET_RDSR2_R_DES_START (3U)     /*!< Bit position for ENET_RDSR2_R_DES_START. */
#define BM_ENET_RDSR2_R_DES_START (0xFFFFFFF8U) /*!< Bit mask for ENET_RDSR2_R_DES_START. */
#define BS_ENET_RDSR2_R_DES_START (29U)    /*!< Bit field size in bits for ENET_RDSR2_R_DES_START. */

/*! @brief Read current value of the ENET_RDSR2_R_DES_START field. */
#define BR_ENET_RDSR2_R_DES_START(x) (HW_ENET_RDSR2(x).B.R_DES_START)

/*! @brief Format value for bitfield ENET_RDSR2_R_DES_START. */
#define BF_ENET_RDSR2_R_DES_START(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RDSR2_R_DES_START) & BM_ENET_RDSR2_R_DES_START)

/*! @brief Set the R_DES_START field to a new value. */
#define BW_ENET_RDSR2_R_DES_START(x, v) (HW_ENET_RDSR2_WR(x, (HW_ENET_RDSR2_RD(x) & ~BM_ENET_RDSR2_R_DES_START) | BF_ENET_RDSR2_R_DES_START(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TDSR2 - Transmit Buffer Descriptor Ring 2 Start Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_TDSR2 - Transmit Buffer Descriptor Ring 2 Start Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * TDSR2 provides a pointer to the beginning of circular transmit buffer
 * descriptor queue 2 in external memory. This pointer must be 64-bit aligned (bits
 * 29-31 must be zero); however, for optimal performance the pointer should be
 * 512-bit aligned, that is, evenly divisible by 64. This register must be initialized
 * prior to operation
 */
typedef union _hw_enet_tdsr2
{
    uint32_t U;
    struct _hw_enet_tdsr2_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t X_DES_START : 29;     /*!< [31:3]  */
    } B;
} hw_enet_tdsr2_t;

/*!
 * @name Constants and macros for entire ENET_TDSR2 register
 */
/*@{*/
#define HW_ENET_TDSR2_ADDR(x)    ((uintptr_t)(x) + 0x170U)

#define HW_ENET_TDSR2(x)         (*(__IO hw_enet_tdsr2_t *) HW_ENET_TDSR2_ADDR(x))
#define HW_ENET_TDSR2_RD(x)      (HW_ENET_TDSR2(x).U)
#define HW_ENET_TDSR2_WR(x, v)   (HW_ENET_TDSR2(x).U = (v))
#define HW_ENET_TDSR2_SET(x, v)  (HW_ENET_TDSR2_WR(x, HW_ENET_TDSR2_RD(x) |  (v)))
#define HW_ENET_TDSR2_CLR(x, v)  (HW_ENET_TDSR2_WR(x, HW_ENET_TDSR2_RD(x) & ~(v)))
#define HW_ENET_TDSR2_TOG(x, v)  (HW_ENET_TDSR2_WR(x, HW_ENET_TDSR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TDSR2 bitfields
 */

/*!
 * @name Register ENET_TDSR2, field X_DES_START[31:3] (RW)
 *
 * Pointer to the beginning of transmit buffer descriptor queue 2.
 */
/*@{*/
#define BP_ENET_TDSR2_X_DES_START (3U)     /*!< Bit position for ENET_TDSR2_X_DES_START. */
#define BM_ENET_TDSR2_X_DES_START (0xFFFFFFF8U) /*!< Bit mask for ENET_TDSR2_X_DES_START. */
#define BS_ENET_TDSR2_X_DES_START (29U)    /*!< Bit field size in bits for ENET_TDSR2_X_DES_START. */

/*! @brief Read current value of the ENET_TDSR2_X_DES_START field. */
#define BR_ENET_TDSR2_X_DES_START(x) (HW_ENET_TDSR2(x).B.X_DES_START)

/*! @brief Format value for bitfield ENET_TDSR2_X_DES_START. */
#define BF_ENET_TDSR2_X_DES_START(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TDSR2_X_DES_START) & BM_ENET_TDSR2_X_DES_START)

/*! @brief Set the X_DES_START field to a new value. */
#define BW_ENET_TDSR2_X_DES_START(x, v) (HW_ENET_TDSR2_WR(x, (HW_ENET_TDSR2_RD(x) & ~BM_ENET_TDSR2_X_DES_START) | BF_ENET_TDSR2_X_DES_START(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_MRBR2 - Maximum Receive Buffer Size Register - Ring 2
 ******************************************************************************/

/*!
 * @brief HW_ENET_MRBR2 - Maximum Receive Buffer Size Register - Ring 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * MRBR2 is a user-programmable register that dictates the maximum size of all
 * ring-2 receive buffers. This value should take into consideration that the
 * receive CRC is always written into the last receive buffer. To allow one maximum
 * size frame per buffer, MRBR2 must be set to RCR[MAX_FL] or larger. R_BUF_SIZE
 * is concatentated with the four least-significant bits of this register and are
 * used as the maximum receive buffer size. To properly align the buffer, MRBR2
 * must be evenly divisible by 64. To ensure this, set the lower two bits of
 * R_BUF_SIZE to zero. The lower four bits are already set to zero by the device. To
 * minimize bus usage (descriptor fetches), set MRBR2 greater than or equal to 256
 * bytes. This register must be initialized prior to operation
 */
typedef union _hw_enet_mrbr2
{
    uint32_t U;
    struct _hw_enet_mrbr2_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0] This field, which is always zero,
                                        * is the four least-significant bits of the maximum receive buffer size. */
        uint32_t R_BUF_SIZE : 7;       /*!< [10:4]  */
        uint32_t RESERVED1 : 21;       /*!< [31:11]  */
    } B;
} hw_enet_mrbr2_t;

/*!
 * @name Constants and macros for entire ENET_MRBR2 register
 */
/*@{*/
#define HW_ENET_MRBR2_ADDR(x)    ((uintptr_t)(x) + 0x174U)

#define HW_ENET_MRBR2(x)         (*(__IO hw_enet_mrbr2_t *) HW_ENET_MRBR2_ADDR(x))
#define HW_ENET_MRBR2_RD(x)      (HW_ENET_MRBR2(x).U)
#define HW_ENET_MRBR2_WR(x, v)   (HW_ENET_MRBR2(x).U = (v))
#define HW_ENET_MRBR2_SET(x, v)  (HW_ENET_MRBR2_WR(x, HW_ENET_MRBR2_RD(x) |  (v)))
#define HW_ENET_MRBR2_CLR(x, v)  (HW_ENET_MRBR2_WR(x, HW_ENET_MRBR2_RD(x) & ~(v)))
#define HW_ENET_MRBR2_TOG(x, v)  (HW_ENET_MRBR2_WR(x, HW_ENET_MRBR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_MRBR2 bitfields
 */

/*!
 * @name Register ENET_MRBR2, field R_BUF_SIZE[10:4] (RW)
 *
 * Receive buffer size in bytes. This value, concatenated with the four
 * least-significant bits of this register (which are always zero), is the effective
 * maximum receive buffer size.
 */
/*@{*/
#define BP_ENET_MRBR2_R_BUF_SIZE (4U)      /*!< Bit position for ENET_MRBR2_R_BUF_SIZE. */
#define BM_ENET_MRBR2_R_BUF_SIZE (0x000007F0U) /*!< Bit mask for ENET_MRBR2_R_BUF_SIZE. */
#define BS_ENET_MRBR2_R_BUF_SIZE (7U)      /*!< Bit field size in bits for ENET_MRBR2_R_BUF_SIZE. */

/*! @brief Read current value of the ENET_MRBR2_R_BUF_SIZE field. */
#define BR_ENET_MRBR2_R_BUF_SIZE(x) (HW_ENET_MRBR2(x).B.R_BUF_SIZE)

/*! @brief Format value for bitfield ENET_MRBR2_R_BUF_SIZE. */
#define BF_ENET_MRBR2_R_BUF_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_MRBR2_R_BUF_SIZE) & BM_ENET_MRBR2_R_BUF_SIZE)

/*! @brief Set the R_BUF_SIZE field to a new value. */
#define BW_ENET_MRBR2_R_BUF_SIZE(x, v) (HW_ENET_MRBR2_WR(x, (HW_ENET_MRBR2_RD(x) & ~BM_ENET_MRBR2_R_BUF_SIZE) | BF_ENET_MRBR2_R_BUF_SIZE(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RDSR - Receive Descriptor Ring 0 Start Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RDSR - Receive Descriptor Ring 0 Start Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * RDSR points to the beginning of the circular receive buffer descriptor queue
 * in external memory. This pointer must be 64-bit aligned (bits 29-31 must be
 * zero); however, for optimal performance the pointer should be 512-bit aligned,
 * that is, evenly divisible by 64. This register must be initialized prior to
 * operation
 */
typedef union _hw_enet_rdsr
{
    uint32_t U;
    struct _hw_enet_rdsr_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t R_DES_START : 29;     /*!< [31:3]  */
    } B;
} hw_enet_rdsr_t;

/*!
 * @name Constants and macros for entire ENET_RDSR register
 */
/*@{*/
#define HW_ENET_RDSR_ADDR(x)     ((uintptr_t)(x) + 0x180U)

#define HW_ENET_RDSR(x)          (*(__IO hw_enet_rdsr_t *) HW_ENET_RDSR_ADDR(x))
#define HW_ENET_RDSR_RD(x)       (HW_ENET_RDSR(x).U)
#define HW_ENET_RDSR_WR(x, v)    (HW_ENET_RDSR(x).U = (v))
#define HW_ENET_RDSR_SET(x, v)   (HW_ENET_RDSR_WR(x, HW_ENET_RDSR_RD(x) |  (v)))
#define HW_ENET_RDSR_CLR(x, v)   (HW_ENET_RDSR_WR(x, HW_ENET_RDSR_RD(x) & ~(v)))
#define HW_ENET_RDSR_TOG(x, v)   (HW_ENET_RDSR_WR(x, HW_ENET_RDSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RDSR bitfields
 */

/*!
 * @name Register ENET_RDSR, field R_DES_START[31:3] (RW)
 *
 * Pointer to the beginning of the receive buffer descriptor queue. 0
 */
/*@{*/
#define BP_ENET_RDSR_R_DES_START (3U)      /*!< Bit position for ENET_RDSR_R_DES_START. */
#define BM_ENET_RDSR_R_DES_START (0xFFFFFFF8U) /*!< Bit mask for ENET_RDSR_R_DES_START. */
#define BS_ENET_RDSR_R_DES_START (29U)     /*!< Bit field size in bits for ENET_RDSR_R_DES_START. */

/*! @brief Read current value of the ENET_RDSR_R_DES_START field. */
#define BR_ENET_RDSR_R_DES_START(x) (HW_ENET_RDSR(x).B.R_DES_START)

/*! @brief Format value for bitfield ENET_RDSR_R_DES_START. */
#define BF_ENET_RDSR_R_DES_START(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RDSR_R_DES_START) & BM_ENET_RDSR_R_DES_START)

/*! @brief Set the R_DES_START field to a new value. */
#define BW_ENET_RDSR_R_DES_START(x, v) (HW_ENET_RDSR_WR(x, (HW_ENET_RDSR_RD(x) & ~BM_ENET_RDSR_R_DES_START) | BF_ENET_RDSR_R_DES_START(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TDSR - Transmit Buffer Descriptor Ring 0 Start Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_TDSR - Transmit Buffer Descriptor Ring 0 Start Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * TDSR provides a pointer to the beginning of the circular transmit buffer
 * descriptor queue 0 in external memory. This pointer must be 64-bit aligned (bits
 * 29-31 must be zero); however, for optimal performance the pointer should be
 * 512-bit aligned, that is, evenly divisible by 64. This register must be
 * initialized prior to operation.
 */
typedef union _hw_enet_tdsr
{
    uint32_t U;
    struct _hw_enet_tdsr_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t X_DES_START : 29;     /*!< [31:3]  */
    } B;
} hw_enet_tdsr_t;

/*!
 * @name Constants and macros for entire ENET_TDSR register
 */
/*@{*/
#define HW_ENET_TDSR_ADDR(x)     ((uintptr_t)(x) + 0x184U)

#define HW_ENET_TDSR(x)          (*(__IO hw_enet_tdsr_t *) HW_ENET_TDSR_ADDR(x))
#define HW_ENET_TDSR_RD(x)       (HW_ENET_TDSR(x).U)
#define HW_ENET_TDSR_WR(x, v)    (HW_ENET_TDSR(x).U = (v))
#define HW_ENET_TDSR_SET(x, v)   (HW_ENET_TDSR_WR(x, HW_ENET_TDSR_RD(x) |  (v)))
#define HW_ENET_TDSR_CLR(x, v)   (HW_ENET_TDSR_WR(x, HW_ENET_TDSR_RD(x) & ~(v)))
#define HW_ENET_TDSR_TOG(x, v)   (HW_ENET_TDSR_WR(x, HW_ENET_TDSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TDSR bitfields
 */

/*!
 * @name Register ENET_TDSR, field X_DES_START[31:3] (RW)
 *
 * Pointer to the beginning of the transmit buffer descriptor queue.
 */
/*@{*/
#define BP_ENET_TDSR_X_DES_START (3U)      /*!< Bit position for ENET_TDSR_X_DES_START. */
#define BM_ENET_TDSR_X_DES_START (0xFFFFFFF8U) /*!< Bit mask for ENET_TDSR_X_DES_START. */
#define BS_ENET_TDSR_X_DES_START (29U)     /*!< Bit field size in bits for ENET_TDSR_X_DES_START. */

/*! @brief Read current value of the ENET_TDSR_X_DES_START field. */
#define BR_ENET_TDSR_X_DES_START(x) (HW_ENET_TDSR(x).B.X_DES_START)

/*! @brief Format value for bitfield ENET_TDSR_X_DES_START. */
#define BF_ENET_TDSR_X_DES_START(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TDSR_X_DES_START) & BM_ENET_TDSR_X_DES_START)

/*! @brief Set the X_DES_START field to a new value. */
#define BW_ENET_TDSR_X_DES_START(x, v) (HW_ENET_TDSR_WR(x, (HW_ENET_TDSR_RD(x) & ~BM_ENET_TDSR_X_DES_START) | BF_ENET_TDSR_X_DES_START(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_MRBR - Maximum Receive Buffer Size Register - Ring 0
 ******************************************************************************/

/*!
 * @brief HW_ENET_MRBR - Maximum Receive Buffer Size Register - Ring 0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The MRBR is a user-programmable register that dictates the maximum size of
 * all ring-0 receive buffers. This value should take into consideration that the
 * receive CRC is always written into the last receive buffer. R_BUF_SIZE is
 * concatentated with the four least-significant bits of this register and are used as
 * the maximum receive buffer size. To allow one maximum size frame per buffer,
 * MRBR must be set to RCR[MAX_FL] or larger. To properly align the buffer, MRBR
 * must be evenly divisible by 64. To ensure this, set the lower two bits of
 * R_BUF_SIZE to zero. The lower four bits of this register are already set to zero
 * by the device. To minimize bus usage (descriptor fetches), set MRBR greater
 * than or equal to 256 bytes. This register must be initialized before operation.
 */
typedef union _hw_enet_mrbr
{
    uint32_t U;
    struct _hw_enet_mrbr_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0] This field, which is always zero,
                                        * is the four least-significant bits of the maximum receive buffer size. */
        uint32_t R_BUF_SIZE : 7;       /*!< [10:4]  */
        uint32_t RESERVED1 : 21;       /*!< [31:11]  */
    } B;
} hw_enet_mrbr_t;

/*!
 * @name Constants and macros for entire ENET_MRBR register
 */
/*@{*/
#define HW_ENET_MRBR_ADDR(x)     ((uintptr_t)(x) + 0x188U)

#define HW_ENET_MRBR(x)          (*(__IO hw_enet_mrbr_t *) HW_ENET_MRBR_ADDR(x))
#define HW_ENET_MRBR_RD(x)       (HW_ENET_MRBR(x).U)
#define HW_ENET_MRBR_WR(x, v)    (HW_ENET_MRBR(x).U = (v))
#define HW_ENET_MRBR_SET(x, v)   (HW_ENET_MRBR_WR(x, HW_ENET_MRBR_RD(x) |  (v)))
#define HW_ENET_MRBR_CLR(x, v)   (HW_ENET_MRBR_WR(x, HW_ENET_MRBR_RD(x) & ~(v)))
#define HW_ENET_MRBR_TOG(x, v)   (HW_ENET_MRBR_WR(x, HW_ENET_MRBR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_MRBR bitfields
 */

/*!
 * @name Register ENET_MRBR, field R_BUF_SIZE[10:4] (RW)
 *
 * Receive buffer size in bytes. This value, concatenated with the four
 * least-significant bits of this register (which are always zero), is the effective
 * maximum receive buffer size.
 */
/*@{*/
#define BP_ENET_MRBR_R_BUF_SIZE (4U)       /*!< Bit position for ENET_MRBR_R_BUF_SIZE. */
#define BM_ENET_MRBR_R_BUF_SIZE (0x000007F0U) /*!< Bit mask for ENET_MRBR_R_BUF_SIZE. */
#define BS_ENET_MRBR_R_BUF_SIZE (7U)       /*!< Bit field size in bits for ENET_MRBR_R_BUF_SIZE. */

/*! @brief Read current value of the ENET_MRBR_R_BUF_SIZE field. */
#define BR_ENET_MRBR_R_BUF_SIZE(x) (HW_ENET_MRBR(x).B.R_BUF_SIZE)

/*! @brief Format value for bitfield ENET_MRBR_R_BUF_SIZE. */
#define BF_ENET_MRBR_R_BUF_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_MRBR_R_BUF_SIZE) & BM_ENET_MRBR_R_BUF_SIZE)

/*! @brief Set the R_BUF_SIZE field to a new value. */
#define BW_ENET_MRBR_R_BUF_SIZE(x, v) (HW_ENET_MRBR_WR(x, (HW_ENET_MRBR_RD(x) & ~BM_ENET_MRBR_R_BUF_SIZE) | BF_ENET_MRBR_R_BUF_SIZE(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RSFL - Receive FIFO Section Full Threshold
 ******************************************************************************/

/*!
 * @brief HW_ENET_RSFL - Receive FIFO Section Full Threshold (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rsfl
{
    uint32_t U;
    struct _hw_enet_rsfl_bitfields
    {
        uint32_t RX_SECTION_FULL : 10; /*!< [9:0] Value Of Receive FIFO
                                        * Section Full Threshold */
        uint32_t RESERVED0 : 22;       /*!< [31:10]  */
    } B;
} hw_enet_rsfl_t;

/*!
 * @name Constants and macros for entire ENET_RSFL register
 */
/*@{*/
#define HW_ENET_RSFL_ADDR(x)     ((uintptr_t)(x) + 0x190U)

#define HW_ENET_RSFL(x)          (*(__IO hw_enet_rsfl_t *) HW_ENET_RSFL_ADDR(x))
#define HW_ENET_RSFL_RD(x)       (HW_ENET_RSFL(x).U)
#define HW_ENET_RSFL_WR(x, v)    (HW_ENET_RSFL(x).U = (v))
#define HW_ENET_RSFL_SET(x, v)   (HW_ENET_RSFL_WR(x, HW_ENET_RSFL_RD(x) |  (v)))
#define HW_ENET_RSFL_CLR(x, v)   (HW_ENET_RSFL_WR(x, HW_ENET_RSFL_RD(x) & ~(v)))
#define HW_ENET_RSFL_TOG(x, v)   (HW_ENET_RSFL_WR(x, HW_ENET_RSFL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RSFL bitfields
 */

/*!
 * @name Register ENET_RSFL, field RX_SECTION_FULL[9:0] (RW)
 *
 * Value, in 64-bit words, of the receive FIFO section full threshold. Clear
 * this field to enable store and forward on the RX FIFO. When programming a value
 * greater than 0 (cut-through operation), it must be greater than
 * RAEM[RX_ALMOST_EMPTY]. When the FIFO level reaches the value in this field, data is available
 * in the Receive FIFO (cut-through operation).
 */
/*@{*/
#define BP_ENET_RSFL_RX_SECTION_FULL (0U)  /*!< Bit position for ENET_RSFL_RX_SECTION_FULL. */
#define BM_ENET_RSFL_RX_SECTION_FULL (0x000003FFU) /*!< Bit mask for ENET_RSFL_RX_SECTION_FULL. */
#define BS_ENET_RSFL_RX_SECTION_FULL (10U) /*!< Bit field size in bits for ENET_RSFL_RX_SECTION_FULL. */

/*! @brief Read current value of the ENET_RSFL_RX_SECTION_FULL field. */
#define BR_ENET_RSFL_RX_SECTION_FULL(x) (HW_ENET_RSFL(x).B.RX_SECTION_FULL)

/*! @brief Format value for bitfield ENET_RSFL_RX_SECTION_FULL. */
#define BF_ENET_RSFL_RX_SECTION_FULL(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RSFL_RX_SECTION_FULL) & BM_ENET_RSFL_RX_SECTION_FULL)

/*! @brief Set the RX_SECTION_FULL field to a new value. */
#define BW_ENET_RSFL_RX_SECTION_FULL(x, v) (HW_ENET_RSFL_WR(x, (HW_ENET_RSFL_RD(x) & ~BM_ENET_RSFL_RX_SECTION_FULL) | BF_ENET_RSFL_RX_SECTION_FULL(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RSEM - Receive FIFO Section Empty Threshold
 ******************************************************************************/

/*!
 * @brief HW_ENET_RSEM - Receive FIFO Section Empty Threshold (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rsem
{
    uint32_t U;
    struct _hw_enet_rsem_bitfields
    {
        uint32_t RX_SECTION_EMPTY : 10; /*!< [9:0] Value Of The Receive FIFO
                                        * Section Empty Threshold */
        uint32_t RESERVED0 : 6;        /*!< [15:10]  */
        uint32_t STAT_SECTION_EMPTY : 5; /*!< [20:16] RX Status FIFO Section
                                        * Empty Threshold */
        uint32_t RESERVED1 : 11;       /*!< [31:21]  */
    } B;
} hw_enet_rsem_t;

/*!
 * @name Constants and macros for entire ENET_RSEM register
 */
/*@{*/
#define HW_ENET_RSEM_ADDR(x)     ((uintptr_t)(x) + 0x194U)

#define HW_ENET_RSEM(x)          (*(__IO hw_enet_rsem_t *) HW_ENET_RSEM_ADDR(x))
#define HW_ENET_RSEM_RD(x)       (HW_ENET_RSEM(x).U)
#define HW_ENET_RSEM_WR(x, v)    (HW_ENET_RSEM(x).U = (v))
#define HW_ENET_RSEM_SET(x, v)   (HW_ENET_RSEM_WR(x, HW_ENET_RSEM_RD(x) |  (v)))
#define HW_ENET_RSEM_CLR(x, v)   (HW_ENET_RSEM_WR(x, HW_ENET_RSEM_RD(x) & ~(v)))
#define HW_ENET_RSEM_TOG(x, v)   (HW_ENET_RSEM_WR(x, HW_ENET_RSEM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RSEM bitfields
 */

/*!
 * @name Register ENET_RSEM, field RX_SECTION_EMPTY[9:0] (RW)
 *
 * Value, in 64-bit words, of the receive FIFO section empty threshold. When the
 * FIFO has reached this level, a pause frame will be issued. A value of 0
 * disables automatic pause frame generation. When the FIFO level goes below the value
 * programmed in this field, an XON pause frame is issued to indicate the FIFO
 * congestion is cleared to the remote Ethernet client. The section-empty
 * threshold indications from both FIFOs are OR'ed to cause XOFF pause frame generation.
 */
/*@{*/
#define BP_ENET_RSEM_RX_SECTION_EMPTY (0U) /*!< Bit position for ENET_RSEM_RX_SECTION_EMPTY. */
#define BM_ENET_RSEM_RX_SECTION_EMPTY (0x000003FFU) /*!< Bit mask for ENET_RSEM_RX_SECTION_EMPTY. */
#define BS_ENET_RSEM_RX_SECTION_EMPTY (10U) /*!< Bit field size in bits for ENET_RSEM_RX_SECTION_EMPTY. */

/*! @brief Read current value of the ENET_RSEM_RX_SECTION_EMPTY field. */
#define BR_ENET_RSEM_RX_SECTION_EMPTY(x) (HW_ENET_RSEM(x).B.RX_SECTION_EMPTY)

/*! @brief Format value for bitfield ENET_RSEM_RX_SECTION_EMPTY. */
#define BF_ENET_RSEM_RX_SECTION_EMPTY(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RSEM_RX_SECTION_EMPTY) & BM_ENET_RSEM_RX_SECTION_EMPTY)

/*! @brief Set the RX_SECTION_EMPTY field to a new value. */
#define BW_ENET_RSEM_RX_SECTION_EMPTY(x, v) (HW_ENET_RSEM_WR(x, (HW_ENET_RSEM_RD(x) & ~BM_ENET_RSEM_RX_SECTION_EMPTY) | BF_ENET_RSEM_RX_SECTION_EMPTY(v)))
/*@}*/

/*!
 * @name Register ENET_RSEM, field STAT_SECTION_EMPTY[20:16] (RW)
 *
 * Defines number of frames in the receive FIFO, independent of its size, that
 * can be accepted. If the limit is reached, reception will continue normally,
 * however a pause frame will be triggered to indicate a possible congestion to the
 * remote device to avoid FIFO overflow. A value of 0 disables automatic pause
 * frame generation
 */
/*@{*/
#define BP_ENET_RSEM_STAT_SECTION_EMPTY (16U) /*!< Bit position for ENET_RSEM_STAT_SECTION_EMPTY. */
#define BM_ENET_RSEM_STAT_SECTION_EMPTY (0x001F0000U) /*!< Bit mask for ENET_RSEM_STAT_SECTION_EMPTY. */
#define BS_ENET_RSEM_STAT_SECTION_EMPTY (5U) /*!< Bit field size in bits for ENET_RSEM_STAT_SECTION_EMPTY. */

/*! @brief Read current value of the ENET_RSEM_STAT_SECTION_EMPTY field. */
#define BR_ENET_RSEM_STAT_SECTION_EMPTY(x) (HW_ENET_RSEM(x).B.STAT_SECTION_EMPTY)

/*! @brief Format value for bitfield ENET_RSEM_STAT_SECTION_EMPTY. */
#define BF_ENET_RSEM_STAT_SECTION_EMPTY(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RSEM_STAT_SECTION_EMPTY) & BM_ENET_RSEM_STAT_SECTION_EMPTY)

/*! @brief Set the STAT_SECTION_EMPTY field to a new value. */
#define BW_ENET_RSEM_STAT_SECTION_EMPTY(x, v) (HW_ENET_RSEM_WR(x, (HW_ENET_RSEM_RD(x) & ~BM_ENET_RSEM_STAT_SECTION_EMPTY) | BF_ENET_RSEM_STAT_SECTION_EMPTY(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RAEM - Receive FIFO Almost Empty Threshold
 ******************************************************************************/

/*!
 * @brief HW_ENET_RAEM - Receive FIFO Almost Empty Threshold (RW)
 *
 * Reset value: 0x00000004U
 */
typedef union _hw_enet_raem
{
    uint32_t U;
    struct _hw_enet_raem_bitfields
    {
        uint32_t RX_ALMOST_EMPTY : 10; /*!< [9:0] Value Of The Receive FIFO
                                        * Almost Empty Threshold */
        uint32_t RESERVED0 : 22;       /*!< [31:10]  */
    } B;
} hw_enet_raem_t;

/*!
 * @name Constants and macros for entire ENET_RAEM register
 */
/*@{*/
#define HW_ENET_RAEM_ADDR(x)     ((uintptr_t)(x) + 0x198U)

#define HW_ENET_RAEM(x)          (*(__IO hw_enet_raem_t *) HW_ENET_RAEM_ADDR(x))
#define HW_ENET_RAEM_RD(x)       (HW_ENET_RAEM(x).U)
#define HW_ENET_RAEM_WR(x, v)    (HW_ENET_RAEM(x).U = (v))
#define HW_ENET_RAEM_SET(x, v)   (HW_ENET_RAEM_WR(x, HW_ENET_RAEM_RD(x) |  (v)))
#define HW_ENET_RAEM_CLR(x, v)   (HW_ENET_RAEM_WR(x, HW_ENET_RAEM_RD(x) & ~(v)))
#define HW_ENET_RAEM_TOG(x, v)   (HW_ENET_RAEM_WR(x, HW_ENET_RAEM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RAEM bitfields
 */

/*!
 * @name Register ENET_RAEM, field RX_ALMOST_EMPTY[9:0] (RW)
 *
 * Value, in 64-bit words, of the receive FIFO almost empty threshold. When the
 * FIFO level reaches the value programmed in this field and the end-of-frame has
 * not been received for the frame yet, the core receive read control stops FIFO
 * read (and subsequently stops transferring data to the MAC client
 * application). It continues to deliver the frame, if again more data than the threshold or
 * the end-of-frame is available in the FIFO. A minimum value of 4 should be set.
 */
/*@{*/
#define BP_ENET_RAEM_RX_ALMOST_EMPTY (0U)  /*!< Bit position for ENET_RAEM_RX_ALMOST_EMPTY. */
#define BM_ENET_RAEM_RX_ALMOST_EMPTY (0x000003FFU) /*!< Bit mask for ENET_RAEM_RX_ALMOST_EMPTY. */
#define BS_ENET_RAEM_RX_ALMOST_EMPTY (10U) /*!< Bit field size in bits for ENET_RAEM_RX_ALMOST_EMPTY. */

/*! @brief Read current value of the ENET_RAEM_RX_ALMOST_EMPTY field. */
#define BR_ENET_RAEM_RX_ALMOST_EMPTY(x) (HW_ENET_RAEM(x).B.RX_ALMOST_EMPTY)

/*! @brief Format value for bitfield ENET_RAEM_RX_ALMOST_EMPTY. */
#define BF_ENET_RAEM_RX_ALMOST_EMPTY(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RAEM_RX_ALMOST_EMPTY) & BM_ENET_RAEM_RX_ALMOST_EMPTY)

/*! @brief Set the RX_ALMOST_EMPTY field to a new value. */
#define BW_ENET_RAEM_RX_ALMOST_EMPTY(x, v) (HW_ENET_RAEM_WR(x, (HW_ENET_RAEM_RD(x) & ~BM_ENET_RAEM_RX_ALMOST_EMPTY) | BF_ENET_RAEM_RX_ALMOST_EMPTY(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RAFL - Receive FIFO Almost Full Threshold
 ******************************************************************************/

/*!
 * @brief HW_ENET_RAFL - Receive FIFO Almost Full Threshold (RW)
 *
 * Reset value: 0x00000004U
 */
typedef union _hw_enet_rafl
{
    uint32_t U;
    struct _hw_enet_rafl_bitfields
    {
        uint32_t RX_ALMOST_FULL : 10;  /*!< [9:0] Value Of The Receive FIFO
                                        * Almost Full Threshold */
        uint32_t RESERVED0 : 22;       /*!< [31:10]  */
    } B;
} hw_enet_rafl_t;

/*!
 * @name Constants and macros for entire ENET_RAFL register
 */
/*@{*/
#define HW_ENET_RAFL_ADDR(x)     ((uintptr_t)(x) + 0x19CU)

#define HW_ENET_RAFL(x)          (*(__IO hw_enet_rafl_t *) HW_ENET_RAFL_ADDR(x))
#define HW_ENET_RAFL_RD(x)       (HW_ENET_RAFL(x).U)
#define HW_ENET_RAFL_WR(x, v)    (HW_ENET_RAFL(x).U = (v))
#define HW_ENET_RAFL_SET(x, v)   (HW_ENET_RAFL_WR(x, HW_ENET_RAFL_RD(x) |  (v)))
#define HW_ENET_RAFL_CLR(x, v)   (HW_ENET_RAFL_WR(x, HW_ENET_RAFL_RD(x) & ~(v)))
#define HW_ENET_RAFL_TOG(x, v)   (HW_ENET_RAFL_WR(x, HW_ENET_RAFL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RAFL bitfields
 */

/*!
 * @name Register ENET_RAFL, field RX_ALMOST_FULL[9:0] (RW)
 *
 * Value, in 64-bit words, of the receive FIFO almost full threshold. When the
 * FIFO level comes close to the maximum, so that there is no more space for at
 * least RX_ALMOST_FULL number of words, the MAC stops writing data in the FIFO and
 * truncates the received frame to avoid FIFO overflow. The corresponding error
 * status will be set when the frame is delivered to the application. A minimum
 * value of 4 should be set.
 */
/*@{*/
#define BP_ENET_RAFL_RX_ALMOST_FULL (0U)   /*!< Bit position for ENET_RAFL_RX_ALMOST_FULL. */
#define BM_ENET_RAFL_RX_ALMOST_FULL (0x000003FFU) /*!< Bit mask for ENET_RAFL_RX_ALMOST_FULL. */
#define BS_ENET_RAFL_RX_ALMOST_FULL (10U)  /*!< Bit field size in bits for ENET_RAFL_RX_ALMOST_FULL. */

/*! @brief Read current value of the ENET_RAFL_RX_ALMOST_FULL field. */
#define BR_ENET_RAFL_RX_ALMOST_FULL(x) (HW_ENET_RAFL(x).B.RX_ALMOST_FULL)

/*! @brief Format value for bitfield ENET_RAFL_RX_ALMOST_FULL. */
#define BF_ENET_RAFL_RX_ALMOST_FULL(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RAFL_RX_ALMOST_FULL) & BM_ENET_RAFL_RX_ALMOST_FULL)

/*! @brief Set the RX_ALMOST_FULL field to a new value. */
#define BW_ENET_RAFL_RX_ALMOST_FULL(x, v) (HW_ENET_RAFL_WR(x, (HW_ENET_RAFL_RD(x) & ~BM_ENET_RAFL_RX_ALMOST_FULL) | BF_ENET_RAFL_RX_ALMOST_FULL(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TSEM - Transmit FIFO Section Empty Threshold
 ******************************************************************************/

/*!
 * @brief HW_ENET_TSEM - Transmit FIFO Section Empty Threshold (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_tsem
{
    uint32_t U;
    struct _hw_enet_tsem_bitfields
    {
        uint32_t TX_SECTION_EMPTY : 10; /*!< [9:0] Value Of The Transmit FIFO
                                        * Section Empty Threshold */
        uint32_t RESERVED0 : 22;       /*!< [31:10]  */
    } B;
} hw_enet_tsem_t;

/*!
 * @name Constants and macros for entire ENET_TSEM register
 */
/*@{*/
#define HW_ENET_TSEM_ADDR(x)     ((uintptr_t)(x) + 0x1A0U)

#define HW_ENET_TSEM(x)          (*(__IO hw_enet_tsem_t *) HW_ENET_TSEM_ADDR(x))
#define HW_ENET_TSEM_RD(x)       (HW_ENET_TSEM(x).U)
#define HW_ENET_TSEM_WR(x, v)    (HW_ENET_TSEM(x).U = (v))
#define HW_ENET_TSEM_SET(x, v)   (HW_ENET_TSEM_WR(x, HW_ENET_TSEM_RD(x) |  (v)))
#define HW_ENET_TSEM_CLR(x, v)   (HW_ENET_TSEM_WR(x, HW_ENET_TSEM_RD(x) & ~(v)))
#define HW_ENET_TSEM_TOG(x, v)   (HW_ENET_TSEM_WR(x, HW_ENET_TSEM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TSEM bitfields
 */

/*!
 * @name Register ENET_TSEM, field TX_SECTION_EMPTY[9:0] (RW)
 *
 * Value, in 64-bit words, of the transmit FIFO section empty threshold. See
 * Transmit FIFO for more information.
 */
/*@{*/
#define BP_ENET_TSEM_TX_SECTION_EMPTY (0U) /*!< Bit position for ENET_TSEM_TX_SECTION_EMPTY. */
#define BM_ENET_TSEM_TX_SECTION_EMPTY (0x000003FFU) /*!< Bit mask for ENET_TSEM_TX_SECTION_EMPTY. */
#define BS_ENET_TSEM_TX_SECTION_EMPTY (10U) /*!< Bit field size in bits for ENET_TSEM_TX_SECTION_EMPTY. */

/*! @brief Read current value of the ENET_TSEM_TX_SECTION_EMPTY field. */
#define BR_ENET_TSEM_TX_SECTION_EMPTY(x) (HW_ENET_TSEM(x).B.TX_SECTION_EMPTY)

/*! @brief Format value for bitfield ENET_TSEM_TX_SECTION_EMPTY. */
#define BF_ENET_TSEM_TX_SECTION_EMPTY(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TSEM_TX_SECTION_EMPTY) & BM_ENET_TSEM_TX_SECTION_EMPTY)

/*! @brief Set the TX_SECTION_EMPTY field to a new value. */
#define BW_ENET_TSEM_TX_SECTION_EMPTY(x, v) (HW_ENET_TSEM_WR(x, (HW_ENET_TSEM_RD(x) & ~BM_ENET_TSEM_TX_SECTION_EMPTY) | BF_ENET_TSEM_TX_SECTION_EMPTY(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TAEM - Transmit FIFO Almost Empty Threshold
 ******************************************************************************/

/*!
 * @brief HW_ENET_TAEM - Transmit FIFO Almost Empty Threshold (RW)
 *
 * Reset value: 0x00000004U
 */
typedef union _hw_enet_taem
{
    uint32_t U;
    struct _hw_enet_taem_bitfields
    {
        uint32_t TX_ALMOST_EMPTY : 10; /*!< [9:0] Value of Transmit FIFO
                                        * Almost Empty Threshold */
        uint32_t RESERVED0 : 22;       /*!< [31:10]  */
    } B;
} hw_enet_taem_t;

/*!
 * @name Constants and macros for entire ENET_TAEM register
 */
/*@{*/
#define HW_ENET_TAEM_ADDR(x)     ((uintptr_t)(x) + 0x1A4U)

#define HW_ENET_TAEM(x)          (*(__IO hw_enet_taem_t *) HW_ENET_TAEM_ADDR(x))
#define HW_ENET_TAEM_RD(x)       (HW_ENET_TAEM(x).U)
#define HW_ENET_TAEM_WR(x, v)    (HW_ENET_TAEM(x).U = (v))
#define HW_ENET_TAEM_SET(x, v)   (HW_ENET_TAEM_WR(x, HW_ENET_TAEM_RD(x) |  (v)))
#define HW_ENET_TAEM_CLR(x, v)   (HW_ENET_TAEM_WR(x, HW_ENET_TAEM_RD(x) & ~(v)))
#define HW_ENET_TAEM_TOG(x, v)   (HW_ENET_TAEM_WR(x, HW_ENET_TAEM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TAEM bitfields
 */

/*!
 * @name Register ENET_TAEM, field TX_ALMOST_EMPTY[9:0] (RW)
 *
 * Value, in 64-bit words, of the transmit FIFO almost empty threshold. When the
 * FIFO level reaches the value programmed in this field, and no end-of-frame is
 * available for the frame, the MAC transmit logic, to avoid FIFO underflow,
 * stops reading the FIFO and transmits a frame with an MII error indication. See
 * Transmit FIFO for more information. A minimum value of 4 should be set.
 */
/*@{*/
#define BP_ENET_TAEM_TX_ALMOST_EMPTY (0U)  /*!< Bit position for ENET_TAEM_TX_ALMOST_EMPTY. */
#define BM_ENET_TAEM_TX_ALMOST_EMPTY (0x000003FFU) /*!< Bit mask for ENET_TAEM_TX_ALMOST_EMPTY. */
#define BS_ENET_TAEM_TX_ALMOST_EMPTY (10U) /*!< Bit field size in bits for ENET_TAEM_TX_ALMOST_EMPTY. */

/*! @brief Read current value of the ENET_TAEM_TX_ALMOST_EMPTY field. */
#define BR_ENET_TAEM_TX_ALMOST_EMPTY(x) (HW_ENET_TAEM(x).B.TX_ALMOST_EMPTY)

/*! @brief Format value for bitfield ENET_TAEM_TX_ALMOST_EMPTY. */
#define BF_ENET_TAEM_TX_ALMOST_EMPTY(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TAEM_TX_ALMOST_EMPTY) & BM_ENET_TAEM_TX_ALMOST_EMPTY)

/*! @brief Set the TX_ALMOST_EMPTY field to a new value. */
#define BW_ENET_TAEM_TX_ALMOST_EMPTY(x, v) (HW_ENET_TAEM_WR(x, (HW_ENET_TAEM_RD(x) & ~BM_ENET_TAEM_TX_ALMOST_EMPTY) | BF_ENET_TAEM_TX_ALMOST_EMPTY(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TAFL - Transmit FIFO Almost Full Threshold
 ******************************************************************************/

/*!
 * @brief HW_ENET_TAFL - Transmit FIFO Almost Full Threshold (RW)
 *
 * Reset value: 0x00000008U
 */
typedef union _hw_enet_tafl
{
    uint32_t U;
    struct _hw_enet_tafl_bitfields
    {
        uint32_t TX_ALMOST_FULL : 10;  /*!< [9:0] Value Of The Transmit FIFO
                                        * Almost Full Threshold */
        uint32_t RESERVED0 : 22;       /*!< [31:10]  */
    } B;
} hw_enet_tafl_t;

/*!
 * @name Constants and macros for entire ENET_TAFL register
 */
/*@{*/
#define HW_ENET_TAFL_ADDR(x)     ((uintptr_t)(x) + 0x1A8U)

#define HW_ENET_TAFL(x)          (*(__IO hw_enet_tafl_t *) HW_ENET_TAFL_ADDR(x))
#define HW_ENET_TAFL_RD(x)       (HW_ENET_TAFL(x).U)
#define HW_ENET_TAFL_WR(x, v)    (HW_ENET_TAFL(x).U = (v))
#define HW_ENET_TAFL_SET(x, v)   (HW_ENET_TAFL_WR(x, HW_ENET_TAFL_RD(x) |  (v)))
#define HW_ENET_TAFL_CLR(x, v)   (HW_ENET_TAFL_WR(x, HW_ENET_TAFL_RD(x) & ~(v)))
#define HW_ENET_TAFL_TOG(x, v)   (HW_ENET_TAFL_WR(x, HW_ENET_TAFL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TAFL bitfields
 */

/*!
 * @name Register ENET_TAFL, field TX_ALMOST_FULL[9:0] (RW)
 *
 * Value, in 64-bit words, of the transmit FIFO almost full threshold. A minimum
 * value of six is required . A recommended value of at least 8 should be set
 * allowing a latency of two clock cycles to the application. If more latency is
 * required the value can be increased as necessary (latency = TAFL - 5). When the
 * FIFO level comes close to the maximum, so that there is no more space for at
 * least TX_ALMOST_FULL number of words, the pin ff_tx_rdy is deasserted. If the
 * application does not react on this signal, the FIFO write control logic, to
 * avoid FIFO overflow, truncates the current frame and sets the error status. As a
 * result, the frame will be transmitted with an GMII/MII error indication. See
 * Transmit FIFO for more information. A FIFO overflow is a fatal error and
 * requires a global reset on the transmit datapath or at least deassertion of ETHEREN.
 */
/*@{*/
#define BP_ENET_TAFL_TX_ALMOST_FULL (0U)   /*!< Bit position for ENET_TAFL_TX_ALMOST_FULL. */
#define BM_ENET_TAFL_TX_ALMOST_FULL (0x000003FFU) /*!< Bit mask for ENET_TAFL_TX_ALMOST_FULL. */
#define BS_ENET_TAFL_TX_ALMOST_FULL (10U)  /*!< Bit field size in bits for ENET_TAFL_TX_ALMOST_FULL. */

/*! @brief Read current value of the ENET_TAFL_TX_ALMOST_FULL field. */
#define BR_ENET_TAFL_TX_ALMOST_FULL(x) (HW_ENET_TAFL(x).B.TX_ALMOST_FULL)

/*! @brief Format value for bitfield ENET_TAFL_TX_ALMOST_FULL. */
#define BF_ENET_TAFL_TX_ALMOST_FULL(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TAFL_TX_ALMOST_FULL) & BM_ENET_TAFL_TX_ALMOST_FULL)

/*! @brief Set the TX_ALMOST_FULL field to a new value. */
#define BW_ENET_TAFL_TX_ALMOST_FULL(x, v) (HW_ENET_TAFL_WR(x, (HW_ENET_TAFL_RD(x) & ~BM_ENET_TAFL_TX_ALMOST_FULL) | BF_ENET_TAFL_TX_ALMOST_FULL(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TIPG - Transmit Inter-Packet Gap
 ******************************************************************************/

/*!
 * @brief HW_ENET_TIPG - Transmit Inter-Packet Gap (RW)
 *
 * Reset value: 0x0000000CU
 */
typedef union _hw_enet_tipg
{
    uint32_t U;
    struct _hw_enet_tipg_bitfields
    {
        uint32_t IPG : 5;              /*!< [4:0] Transmit Inter-Packet Gap */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_enet_tipg_t;

/*!
 * @name Constants and macros for entire ENET_TIPG register
 */
/*@{*/
#define HW_ENET_TIPG_ADDR(x)     ((uintptr_t)(x) + 0x1ACU)

#define HW_ENET_TIPG(x)          (*(__IO hw_enet_tipg_t *) HW_ENET_TIPG_ADDR(x))
#define HW_ENET_TIPG_RD(x)       (HW_ENET_TIPG(x).U)
#define HW_ENET_TIPG_WR(x, v)    (HW_ENET_TIPG(x).U = (v))
#define HW_ENET_TIPG_SET(x, v)   (HW_ENET_TIPG_WR(x, HW_ENET_TIPG_RD(x) |  (v)))
#define HW_ENET_TIPG_CLR(x, v)   (HW_ENET_TIPG_WR(x, HW_ENET_TIPG_RD(x) & ~(v)))
#define HW_ENET_TIPG_TOG(x, v)   (HW_ENET_TIPG_WR(x, HW_ENET_TIPG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TIPG bitfields
 */

/*!
 * @name Register ENET_TIPG, field IPG[4:0] (RW)
 *
 * Indicates the IPG, in bytes, between transmitted frames. Valid values range
 * from 8 to 26. If the written value is less than 8 or greater than 26, the
 * internal (effective) IPG is 12. The IPG value read will be the value that was
 * written, even if it is out of range.
 */
/*@{*/
#define BP_ENET_TIPG_IPG     (0U)          /*!< Bit position for ENET_TIPG_IPG. */
#define BM_ENET_TIPG_IPG     (0x0000001FU) /*!< Bit mask for ENET_TIPG_IPG. */
#define BS_ENET_TIPG_IPG     (5U)          /*!< Bit field size in bits for ENET_TIPG_IPG. */

/*! @brief Read current value of the ENET_TIPG_IPG field. */
#define BR_ENET_TIPG_IPG(x)  (HW_ENET_TIPG(x).B.IPG)

/*! @brief Format value for bitfield ENET_TIPG_IPG. */
#define BF_ENET_TIPG_IPG(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_TIPG_IPG) & BM_ENET_TIPG_IPG)

/*! @brief Set the IPG field to a new value. */
#define BW_ENET_TIPG_IPG(x, v) (HW_ENET_TIPG_WR(x, (HW_ENET_TIPG_RD(x) & ~BM_ENET_TIPG_IPG) | BF_ENET_TIPG_IPG(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_FTRL - Frame Truncation Length
 ******************************************************************************/

/*!
 * @brief HW_ENET_FTRL - Frame Truncation Length (RW)
 *
 * Reset value: 0x000007FFU
 */
typedef union _hw_enet_ftrl
{
    uint32_t U;
    struct _hw_enet_ftrl_bitfields
    {
        uint32_t TRUNC_FL : 14;        /*!< [13:0] Frame Truncation Length */
        uint32_t RESERVED0 : 18;       /*!< [31:14]  */
    } B;
} hw_enet_ftrl_t;

/*!
 * @name Constants and macros for entire ENET_FTRL register
 */
/*@{*/
#define HW_ENET_FTRL_ADDR(x)     ((uintptr_t)(x) + 0x1B0U)

#define HW_ENET_FTRL(x)          (*(__IO hw_enet_ftrl_t *) HW_ENET_FTRL_ADDR(x))
#define HW_ENET_FTRL_RD(x)       (HW_ENET_FTRL(x).U)
#define HW_ENET_FTRL_WR(x, v)    (HW_ENET_FTRL(x).U = (v))
#define HW_ENET_FTRL_SET(x, v)   (HW_ENET_FTRL_WR(x, HW_ENET_FTRL_RD(x) |  (v)))
#define HW_ENET_FTRL_CLR(x, v)   (HW_ENET_FTRL_WR(x, HW_ENET_FTRL_RD(x) & ~(v)))
#define HW_ENET_FTRL_TOG(x, v)   (HW_ENET_FTRL_WR(x, HW_ENET_FTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_FTRL bitfields
 */

/*!
 * @name Register ENET_FTRL, field TRUNC_FL[13:0] (RW)
 *
 * Indicates the value a receive frame is truncated, if it is greater than this
 * value. Must be greater than or equal to RCR[MAX_FL]. Truncation happens at
 * TRUNC_FL. However, when truncation occurs, the application (FIFO) may receive
 * less data, guaranteeing that it never receives more than the set limit.
 */
/*@{*/
#define BP_ENET_FTRL_TRUNC_FL (0U)         /*!< Bit position for ENET_FTRL_TRUNC_FL. */
#define BM_ENET_FTRL_TRUNC_FL (0x00003FFFU) /*!< Bit mask for ENET_FTRL_TRUNC_FL. */
#define BS_ENET_FTRL_TRUNC_FL (14U)        /*!< Bit field size in bits for ENET_FTRL_TRUNC_FL. */

/*! @brief Read current value of the ENET_FTRL_TRUNC_FL field. */
#define BR_ENET_FTRL_TRUNC_FL(x) (HW_ENET_FTRL(x).B.TRUNC_FL)

/*! @brief Format value for bitfield ENET_FTRL_TRUNC_FL. */
#define BF_ENET_FTRL_TRUNC_FL(v) ((uint32_t)((uint32_t)(v) << BP_ENET_FTRL_TRUNC_FL) & BM_ENET_FTRL_TRUNC_FL)

/*! @brief Set the TRUNC_FL field to a new value. */
#define BW_ENET_FTRL_TRUNC_FL(x, v) (HW_ENET_FTRL_WR(x, (HW_ENET_FTRL_RD(x) & ~BM_ENET_FTRL_TRUNC_FL) | BF_ENET_FTRL_TRUNC_FL(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TACC - Transmit Accelerator Function Configuration
 ******************************************************************************/

/*!
 * @brief HW_ENET_TACC - Transmit Accelerator Function Configuration (RW)
 *
 * Reset value: 0x00000000U
 *
 * TACC controls accelerator actions when sending frames. The register can be
 * changed before or after each frame, but it must remain unmodified during frame
 * writes into the transmit FIFO. The TFWR[STRFWD] field must be set to use the
 * checksum feature.
 */
typedef union _hw_enet_tacc
{
    uint32_t U;
    struct _hw_enet_tacc_bitfields
    {
        uint32_t SHIFT16 : 1;          /*!< [0] TX FIFO Shift-16 */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t IPCHK : 1;            /*!< [3]  */
        uint32_t PROCHK : 1;           /*!< [4]  */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_enet_tacc_t;

/*!
 * @name Constants and macros for entire ENET_TACC register
 */
/*@{*/
#define HW_ENET_TACC_ADDR(x)     ((uintptr_t)(x) + 0x1C0U)

#define HW_ENET_TACC(x)          (*(__IO hw_enet_tacc_t *) HW_ENET_TACC_ADDR(x))
#define HW_ENET_TACC_RD(x)       (HW_ENET_TACC(x).U)
#define HW_ENET_TACC_WR(x, v)    (HW_ENET_TACC(x).U = (v))
#define HW_ENET_TACC_SET(x, v)   (HW_ENET_TACC_WR(x, HW_ENET_TACC_RD(x) |  (v)))
#define HW_ENET_TACC_CLR(x, v)   (HW_ENET_TACC_WR(x, HW_ENET_TACC_RD(x) & ~(v)))
#define HW_ENET_TACC_TOG(x, v)   (HW_ENET_TACC_WR(x, HW_ENET_TACC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TACC bitfields
 */

/*!
 * @name Register ENET_TACC, field SHIFT16[0] (RW)
 *
 * Values:
 * - 0 - Disabled.
 * - 1 - Indicates to the transmit data FIFO that the written frames contain two
 *     additional octets before the frame data. This means the actual frame
 *     begins at bit 16 of the first word written into the FIFO. This function allows
 *     putting the frame payload on a 32-bit boundary in memory, as the 14-byte
 *     Ethernet header is extended to a 16-byte header.
 */
/*@{*/
#define BP_ENET_TACC_SHIFT16 (0U)          /*!< Bit position for ENET_TACC_SHIFT16. */
#define BM_ENET_TACC_SHIFT16 (0x00000001U) /*!< Bit mask for ENET_TACC_SHIFT16. */
#define BS_ENET_TACC_SHIFT16 (1U)          /*!< Bit field size in bits for ENET_TACC_SHIFT16. */

/*! @brief Read current value of the ENET_TACC_SHIFT16 field. */
#define BR_ENET_TACC_SHIFT16(x) (HW_ENET_TACC(x).B.SHIFT16)

/*! @brief Format value for bitfield ENET_TACC_SHIFT16. */
#define BF_ENET_TACC_SHIFT16(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TACC_SHIFT16) & BM_ENET_TACC_SHIFT16)

/*! @brief Set the SHIFT16 field to a new value. */
#define BW_ENET_TACC_SHIFT16(x, v) (HW_ENET_TACC_WR(x, (HW_ENET_TACC_RD(x) & ~BM_ENET_TACC_SHIFT16) | BF_ENET_TACC_SHIFT16(v)))
/*@}*/

/*!
 * @name Register ENET_TACC, field IPCHK[3] (RW)
 *
 * Enables insertion of IP header checksum.
 *
 * Values:
 * - 0 - Checksum is not inserted.
 * - 1 - If an IP frame is transmitted, the checksum is inserted automatically.
 *     The IP header checksum field must be cleared. If a non-IP frame is
 *     transmitted the frame is not modified.
 */
/*@{*/
#define BP_ENET_TACC_IPCHK   (3U)          /*!< Bit position for ENET_TACC_IPCHK. */
#define BM_ENET_TACC_IPCHK   (0x00000008U) /*!< Bit mask for ENET_TACC_IPCHK. */
#define BS_ENET_TACC_IPCHK   (1U)          /*!< Bit field size in bits for ENET_TACC_IPCHK. */

/*! @brief Read current value of the ENET_TACC_IPCHK field. */
#define BR_ENET_TACC_IPCHK(x) (HW_ENET_TACC(x).B.IPCHK)

/*! @brief Format value for bitfield ENET_TACC_IPCHK. */
#define BF_ENET_TACC_IPCHK(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TACC_IPCHK) & BM_ENET_TACC_IPCHK)

/*! @brief Set the IPCHK field to a new value. */
#define BW_ENET_TACC_IPCHK(x, v) (HW_ENET_TACC_WR(x, (HW_ENET_TACC_RD(x) & ~BM_ENET_TACC_IPCHK) | BF_ENET_TACC_IPCHK(v)))
/*@}*/

/*!
 * @name Register ENET_TACC, field PROCHK[4] (RW)
 *
 * Enables insertion of protocol checksum.
 *
 * Values:
 * - 0 - Checksum not inserted.
 * - 1 - If an IP frame with a known protocol is transmitted, the checksum is
 *     inserted automatically into the frame. The checksum field must be cleared.
 *     The other frames are not modified.
 */
/*@{*/
#define BP_ENET_TACC_PROCHK  (4U)          /*!< Bit position for ENET_TACC_PROCHK. */
#define BM_ENET_TACC_PROCHK  (0x00000010U) /*!< Bit mask for ENET_TACC_PROCHK. */
#define BS_ENET_TACC_PROCHK  (1U)          /*!< Bit field size in bits for ENET_TACC_PROCHK. */

/*! @brief Read current value of the ENET_TACC_PROCHK field. */
#define BR_ENET_TACC_PROCHK(x) (HW_ENET_TACC(x).B.PROCHK)

/*! @brief Format value for bitfield ENET_TACC_PROCHK. */
#define BF_ENET_TACC_PROCHK(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TACC_PROCHK) & BM_ENET_TACC_PROCHK)

/*! @brief Set the PROCHK field to a new value. */
#define BW_ENET_TACC_PROCHK(x, v) (HW_ENET_TACC_WR(x, (HW_ENET_TACC_RD(x) & ~BM_ENET_TACC_PROCHK) | BF_ENET_TACC_PROCHK(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RACC - Receive Accelerator Function Configuration
 ******************************************************************************/

/*!
 * @brief HW_ENET_RACC - Receive Accelerator Function Configuration (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_racc
{
    uint32_t U;
    struct _hw_enet_racc_bitfields
    {
        uint32_t PADREM : 1;           /*!< [0] Enable Padding Removal For Short IP
                                        * Frames */
        uint32_t IPDIS : 1;            /*!< [1] Enable Discard Of Frames With Wrong IPv4
                                        * Header Checksum */
        uint32_t PRODIS : 1;           /*!< [2] Enable Discard Of Frames With Wrong
                                        * Protocol Checksum */
        uint32_t RESERVED0 : 3;        /*!< [5:3]  */
        uint32_t LINEDIS : 1;          /*!< [6] Enable Discard Of Frames With MAC
                                        * Layer Errors */
        uint32_t SHIFT16 : 1;          /*!< [7] RX FIFO Shift-16 */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_enet_racc_t;

/*!
 * @name Constants and macros for entire ENET_RACC register
 */
/*@{*/
#define HW_ENET_RACC_ADDR(x)     ((uintptr_t)(x) + 0x1C4U)

#define HW_ENET_RACC(x)          (*(__IO hw_enet_racc_t *) HW_ENET_RACC_ADDR(x))
#define HW_ENET_RACC_RD(x)       (HW_ENET_RACC(x).U)
#define HW_ENET_RACC_WR(x, v)    (HW_ENET_RACC(x).U = (v))
#define HW_ENET_RACC_SET(x, v)   (HW_ENET_RACC_WR(x, HW_ENET_RACC_RD(x) |  (v)))
#define HW_ENET_RACC_CLR(x, v)   (HW_ENET_RACC_WR(x, HW_ENET_RACC_RD(x) & ~(v)))
#define HW_ENET_RACC_TOG(x, v)   (HW_ENET_RACC_WR(x, HW_ENET_RACC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RACC bitfields
 */

/*!
 * @name Register ENET_RACC, field PADREM[0] (RW)
 *
 * Values:
 * - 0 - Padding not removed.
 * - 1 - Any bytes following the IP payload section of the frame are removed
 *     from the frame.
 */
/*@{*/
#define BP_ENET_RACC_PADREM  (0U)          /*!< Bit position for ENET_RACC_PADREM. */
#define BM_ENET_RACC_PADREM  (0x00000001U) /*!< Bit mask for ENET_RACC_PADREM. */
#define BS_ENET_RACC_PADREM  (1U)          /*!< Bit field size in bits for ENET_RACC_PADREM. */

/*! @brief Read current value of the ENET_RACC_PADREM field. */
#define BR_ENET_RACC_PADREM(x) (HW_ENET_RACC(x).B.PADREM)

/*! @brief Format value for bitfield ENET_RACC_PADREM. */
#define BF_ENET_RACC_PADREM(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RACC_PADREM) & BM_ENET_RACC_PADREM)

/*! @brief Set the PADREM field to a new value. */
#define BW_ENET_RACC_PADREM(x, v) (HW_ENET_RACC_WR(x, (HW_ENET_RACC_RD(x) & ~BM_ENET_RACC_PADREM) | BF_ENET_RACC_PADREM(v)))
/*@}*/

/*!
 * @name Register ENET_RACC, field IPDIS[1] (RW)
 *
 * Values:
 * - 0 - Frames with wrong IPv4 header checksum are not discarded.
 * - 1 - If an IPv4 frame is received with a mismatching header checksum, the
 *     frame is discarded. IPv6 has no header checksum and is not affected by this
 *     setting. Discarding is only available when the RX FIFO operates in store
 *     and forward mode (RSFL cleared).
 */
/*@{*/
#define BP_ENET_RACC_IPDIS   (1U)          /*!< Bit position for ENET_RACC_IPDIS. */
#define BM_ENET_RACC_IPDIS   (0x00000002U) /*!< Bit mask for ENET_RACC_IPDIS. */
#define BS_ENET_RACC_IPDIS   (1U)          /*!< Bit field size in bits for ENET_RACC_IPDIS. */

/*! @brief Read current value of the ENET_RACC_IPDIS field. */
#define BR_ENET_RACC_IPDIS(x) (HW_ENET_RACC(x).B.IPDIS)

/*! @brief Format value for bitfield ENET_RACC_IPDIS. */
#define BF_ENET_RACC_IPDIS(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RACC_IPDIS) & BM_ENET_RACC_IPDIS)

/*! @brief Set the IPDIS field to a new value. */
#define BW_ENET_RACC_IPDIS(x, v) (HW_ENET_RACC_WR(x, (HW_ENET_RACC_RD(x) & ~BM_ENET_RACC_IPDIS) | BF_ENET_RACC_IPDIS(v)))
/*@}*/

/*!
 * @name Register ENET_RACC, field PRODIS[2] (RW)
 *
 * Values:
 * - 0 - Frames with wrong checksum are not discarded.
 * - 1 - If a TCP/IP, UDP/IP, or ICMP/IP frame is received that has a wrong TCP,
 *     UDP, or ICMP checksum, the frame is discarded. Discarding is only
 *     available when the RX FIFO operates in store and forward mode (RSFL cleared).
 */
/*@{*/
#define BP_ENET_RACC_PRODIS  (2U)          /*!< Bit position for ENET_RACC_PRODIS. */
#define BM_ENET_RACC_PRODIS  (0x00000004U) /*!< Bit mask for ENET_RACC_PRODIS. */
#define BS_ENET_RACC_PRODIS  (1U)          /*!< Bit field size in bits for ENET_RACC_PRODIS. */

/*! @brief Read current value of the ENET_RACC_PRODIS field. */
#define BR_ENET_RACC_PRODIS(x) (HW_ENET_RACC(x).B.PRODIS)

/*! @brief Format value for bitfield ENET_RACC_PRODIS. */
#define BF_ENET_RACC_PRODIS(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RACC_PRODIS) & BM_ENET_RACC_PRODIS)

/*! @brief Set the PRODIS field to a new value. */
#define BW_ENET_RACC_PRODIS(x, v) (HW_ENET_RACC_WR(x, (HW_ENET_RACC_RD(x) & ~BM_ENET_RACC_PRODIS) | BF_ENET_RACC_PRODIS(v)))
/*@}*/

/*!
 * @name Register ENET_RACC, field LINEDIS[6] (RW)
 *
 * Values:
 * - 0 - Frames with errors are not discarded.
 * - 1 - Any frame received with a CRC, length, or PHY error is automatically
 *     discarded and not forwarded to the user application interface.
 */
/*@{*/
#define BP_ENET_RACC_LINEDIS (6U)          /*!< Bit position for ENET_RACC_LINEDIS. */
#define BM_ENET_RACC_LINEDIS (0x00000040U) /*!< Bit mask for ENET_RACC_LINEDIS. */
#define BS_ENET_RACC_LINEDIS (1U)          /*!< Bit field size in bits for ENET_RACC_LINEDIS. */

/*! @brief Read current value of the ENET_RACC_LINEDIS field. */
#define BR_ENET_RACC_LINEDIS(x) (HW_ENET_RACC(x).B.LINEDIS)

/*! @brief Format value for bitfield ENET_RACC_LINEDIS. */
#define BF_ENET_RACC_LINEDIS(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RACC_LINEDIS) & BM_ENET_RACC_LINEDIS)

/*! @brief Set the LINEDIS field to a new value. */
#define BW_ENET_RACC_LINEDIS(x, v) (HW_ENET_RACC_WR(x, (HW_ENET_RACC_RD(x) & ~BM_ENET_RACC_LINEDIS) | BF_ENET_RACC_LINEDIS(v)))
/*@}*/

/*!
 * @name Register ENET_RACC, field SHIFT16[7] (RW)
 *
 * When this field is set, the actual frame data starts at bit 16 of the first
 * word read from the RX FIFO aligning the Ethernet payload on a 32-bit boundary.
 * This function only affects the FIFO storage and has no influence on the
 * statistics, which use the actual length of the frame received.
 *
 * Values:
 * - 0 - Disabled.
 * - 1 - Instructs the MAC to write two additional bytes in front of each frame
 *     received into the RX FIFO.
 */
/*@{*/
#define BP_ENET_RACC_SHIFT16 (7U)          /*!< Bit position for ENET_RACC_SHIFT16. */
#define BM_ENET_RACC_SHIFT16 (0x00000080U) /*!< Bit mask for ENET_RACC_SHIFT16. */
#define BS_ENET_RACC_SHIFT16 (1U)          /*!< Bit field size in bits for ENET_RACC_SHIFT16. */

/*! @brief Read current value of the ENET_RACC_SHIFT16 field. */
#define BR_ENET_RACC_SHIFT16(x) (HW_ENET_RACC(x).B.SHIFT16)

/*! @brief Format value for bitfield ENET_RACC_SHIFT16. */
#define BF_ENET_RACC_SHIFT16(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RACC_SHIFT16) & BM_ENET_RACC_SHIFT16)

/*! @brief Set the SHIFT16 field to a new value. */
#define BW_ENET_RACC_SHIFT16(x, v) (HW_ENET_RACC_WR(x, (HW_ENET_RACC_RD(x) & ~BM_ENET_RACC_SHIFT16) | BF_ENET_RACC_SHIFT16(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RCMR1 - Receive Classification Match Register for Class n
 ******************************************************************************/

/*!
 * @brief HW_ENET_RCMR1 - Receive Classification Match Register for Class n (RW)
 *
 * Reset value: 0x00000000U
 *
 * This match register allows specifying up to four priorities, which are tested
 * (OR'ed) simultaneously. The match detection uses the extracted VLAN field
 * according to the rules for VLAN detection configured through the ECR register. If
 * both match registers, RCMR1 and RCMR2, report a match at the same time, only
 * the class 1 match is indicated as the final result.
 */
typedef union _hw_enet_rcmr1
{
    uint32_t U;
    struct _hw_enet_rcmr1_bitfields
    {
        uint32_t CMP0 : 3;             /*!< [2:0] Compare 0 */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t CMP1 : 3;             /*!< [6:4] Compare 1 */
        uint32_t RESERVED1 : 1;        /*!< [7]  */
        uint32_t CMP2 : 3;             /*!< [10:8] Compare 2 */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t CMP3 : 3;             /*!< [14:12] Compare 3 */
        uint32_t RESERVED3 : 1;        /*!< [15]  */
        uint32_t MATCHEN : 1;          /*!< [16] Match Enable */
        uint32_t RESERVED4 : 15;       /*!< [31:17]  */
    } B;
} hw_enet_rcmr1_t;

/*!
 * @name Constants and macros for entire ENET_RCMR1 register
 */
/*@{*/
#define HW_ENET_RCMR1_ADDR(x)    ((uintptr_t)(x) + 0x1C8U)

#define HW_ENET_RCMR1(x)         (*(__IO hw_enet_rcmr1_t *) HW_ENET_RCMR1_ADDR(x))
#define HW_ENET_RCMR1_RD(x)      (HW_ENET_RCMR1(x).U)
#define HW_ENET_RCMR1_WR(x, v)   (HW_ENET_RCMR1(x).U = (v))
#define HW_ENET_RCMR1_SET(x, v)  (HW_ENET_RCMR1_WR(x, HW_ENET_RCMR1_RD(x) |  (v)))
#define HW_ENET_RCMR1_CLR(x, v)  (HW_ENET_RCMR1_WR(x, HW_ENET_RCMR1_RD(x) & ~(v)))
#define HW_ENET_RCMR1_TOG(x, v)  (HW_ENET_RCMR1_WR(x, HW_ENET_RCMR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RCMR1 bitfields
 */

/*!
 * @name Register ENET_RCMR1, field CMP0[2:0] (RW)
 *
 * A three-bit value that will be compared with the frame's VLAN priority field
 * (if a VLAN frame is received). All four compare values, CMP0..3, will be used
 * in parallel. If any of the values match, a match for the class is reported (if
 * MATCHEN is 1).To implement a single priority match, all four compare values
 * must be set to the same value.
 */
/*@{*/
#define BP_ENET_RCMR1_CMP0   (0U)          /*!< Bit position for ENET_RCMR1_CMP0. */
#define BM_ENET_RCMR1_CMP0   (0x00000007U) /*!< Bit mask for ENET_RCMR1_CMP0. */
#define BS_ENET_RCMR1_CMP0   (3U)          /*!< Bit field size in bits for ENET_RCMR1_CMP0. */

/*! @brief Read current value of the ENET_RCMR1_CMP0 field. */
#define BR_ENET_RCMR1_CMP0(x) (HW_ENET_RCMR1(x).B.CMP0)

/*! @brief Format value for bitfield ENET_RCMR1_CMP0. */
#define BF_ENET_RCMR1_CMP0(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR1_CMP0) & BM_ENET_RCMR1_CMP0)

/*! @brief Set the CMP0 field to a new value. */
#define BW_ENET_RCMR1_CMP0(x, v) (HW_ENET_RCMR1_WR(x, (HW_ENET_RCMR1_RD(x) & ~BM_ENET_RCMR1_CMP0) | BF_ENET_RCMR1_CMP0(v)))
/*@}*/

/*!
 * @name Register ENET_RCMR1, field CMP1[6:4] (RW)
 *
 * Second value to compare against. If unused it must be set to the same value
 * as CMP0.
 */
/*@{*/
#define BP_ENET_RCMR1_CMP1   (4U)          /*!< Bit position for ENET_RCMR1_CMP1. */
#define BM_ENET_RCMR1_CMP1   (0x00000070U) /*!< Bit mask for ENET_RCMR1_CMP1. */
#define BS_ENET_RCMR1_CMP1   (3U)          /*!< Bit field size in bits for ENET_RCMR1_CMP1. */

/*! @brief Read current value of the ENET_RCMR1_CMP1 field. */
#define BR_ENET_RCMR1_CMP1(x) (HW_ENET_RCMR1(x).B.CMP1)

/*! @brief Format value for bitfield ENET_RCMR1_CMP1. */
#define BF_ENET_RCMR1_CMP1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR1_CMP1) & BM_ENET_RCMR1_CMP1)

/*! @brief Set the CMP1 field to a new value. */
#define BW_ENET_RCMR1_CMP1(x, v) (HW_ENET_RCMR1_WR(x, (HW_ENET_RCMR1_RD(x) & ~BM_ENET_RCMR1_CMP1) | BF_ENET_RCMR1_CMP1(v)))
/*@}*/

/*!
 * @name Register ENET_RCMR1, field CMP2[10:8] (RW)
 *
 * Third value to compare against. If unused it must be set to the same value as
 * CMP0.
 */
/*@{*/
#define BP_ENET_RCMR1_CMP2   (8U)          /*!< Bit position for ENET_RCMR1_CMP2. */
#define BM_ENET_RCMR1_CMP2   (0x00000700U) /*!< Bit mask for ENET_RCMR1_CMP2. */
#define BS_ENET_RCMR1_CMP2   (3U)          /*!< Bit field size in bits for ENET_RCMR1_CMP2. */

/*! @brief Read current value of the ENET_RCMR1_CMP2 field. */
#define BR_ENET_RCMR1_CMP2(x) (HW_ENET_RCMR1(x).B.CMP2)

/*! @brief Format value for bitfield ENET_RCMR1_CMP2. */
#define BF_ENET_RCMR1_CMP2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR1_CMP2) & BM_ENET_RCMR1_CMP2)

/*! @brief Set the CMP2 field to a new value. */
#define BW_ENET_RCMR1_CMP2(x, v) (HW_ENET_RCMR1_WR(x, (HW_ENET_RCMR1_RD(x) & ~BM_ENET_RCMR1_CMP2) | BF_ENET_RCMR1_CMP2(v)))
/*@}*/

/*!
 * @name Register ENET_RCMR1, field CMP3[14:12] (RW)
 *
 * Fourth value to compare against. If unused it must be set to the same value
 * as CMP0.
 */
/*@{*/
#define BP_ENET_RCMR1_CMP3   (12U)         /*!< Bit position for ENET_RCMR1_CMP3. */
#define BM_ENET_RCMR1_CMP3   (0x00007000U) /*!< Bit mask for ENET_RCMR1_CMP3. */
#define BS_ENET_RCMR1_CMP3   (3U)          /*!< Bit field size in bits for ENET_RCMR1_CMP3. */

/*! @brief Read current value of the ENET_RCMR1_CMP3 field. */
#define BR_ENET_RCMR1_CMP3(x) (HW_ENET_RCMR1(x).B.CMP3)

/*! @brief Format value for bitfield ENET_RCMR1_CMP3. */
#define BF_ENET_RCMR1_CMP3(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR1_CMP3) & BM_ENET_RCMR1_CMP3)

/*! @brief Set the CMP3 field to a new value. */
#define BW_ENET_RCMR1_CMP3(x, v) (HW_ENET_RCMR1_WR(x, (HW_ENET_RCMR1_RD(x) & ~BM_ENET_RCMR1_CMP3) | BF_ENET_RCMR1_CMP3(v)))
/*@}*/

/*!
 * @name Register ENET_RCMR1, field MATCHEN[16] (RW)
 *
 * A comparison is done only on incoming VLAN frames. If no VLAN frame is
 * received no match will occur. If both match registers have overlapping compare
 * values and hence can match both on the same frame, only class 1 will be indicated
 * and the class 2 match is ignored.
 *
 * Values:
 * - 0 - Disabled (default): no compares will occur and the classification
 *     indicator for this class will never assert.
 * - 1 - The register contents are valid and a comparison with all compare
 *     values is done when a VLAN frame is received.
 */
/*@{*/
#define BP_ENET_RCMR1_MATCHEN (16U)        /*!< Bit position for ENET_RCMR1_MATCHEN. */
#define BM_ENET_RCMR1_MATCHEN (0x00010000U) /*!< Bit mask for ENET_RCMR1_MATCHEN. */
#define BS_ENET_RCMR1_MATCHEN (1U)         /*!< Bit field size in bits for ENET_RCMR1_MATCHEN. */

/*! @brief Read current value of the ENET_RCMR1_MATCHEN field. */
#define BR_ENET_RCMR1_MATCHEN(x) (HW_ENET_RCMR1(x).B.MATCHEN)

/*! @brief Format value for bitfield ENET_RCMR1_MATCHEN. */
#define BF_ENET_RCMR1_MATCHEN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR1_MATCHEN) & BM_ENET_RCMR1_MATCHEN)

/*! @brief Set the MATCHEN field to a new value. */
#define BW_ENET_RCMR1_MATCHEN(x, v) (HW_ENET_RCMR1_WR(x, (HW_ENET_RCMR1_RD(x) & ~BM_ENET_RCMR1_MATCHEN) | BF_ENET_RCMR1_MATCHEN(v)))
/*@}*/
/*******************************************************************************
 * HW_ENET_RCMR2 - Receive Classification Match Register for Class n
 ******************************************************************************/

/*!
 * @brief HW_ENET_RCMR2 - Receive Classification Match Register for Class n (RW)
 *
 * Reset value: 0x00000000U
 *
 * This match register allows specifying up to four priorities, which are tested
 * (OR'ed) simultaneously. The match detection uses the extracted VLAN field
 * according to the rules for VLAN detection configured through the ECR register. If
 * both match registers, RCMR1 and RCMR2, report a match at the same time, only
 * the class 1 match is indicated as the final result.
 */
typedef union _hw_enet_rcmr2
{
    uint32_t U;
    struct _hw_enet_rcmr2_bitfields
    {
        uint32_t CMP0 : 3;             /*!< [2:0] Compare 0 */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t CMP1 : 3;             /*!< [6:4] Compare 1 */
        uint32_t RESERVED1 : 1;        /*!< [7]  */
        uint32_t CMP2 : 3;             /*!< [10:8] Compare 2 */
        uint32_t RESERVED2 : 1;        /*!< [11]  */
        uint32_t CMP3 : 3;             /*!< [14:12] Compare 3 */
        uint32_t RESERVED3 : 1;        /*!< [15]  */
        uint32_t MATCHEN : 1;          /*!< [16] Match Enable */
        uint32_t RESERVED4 : 15;       /*!< [31:17]  */
    } B;
} hw_enet_rcmr2_t;

/*!
 * @name Constants and macros for entire ENET_RCMR2 register
 */
/*@{*/
#define HW_ENET_RCMR2_ADDR(x)    ((uintptr_t)(x) + 0x1CCU)

#define HW_ENET_RCMR2(x)         (*(__IO hw_enet_rcmr2_t *) HW_ENET_RCMR2_ADDR(x))
#define HW_ENET_RCMR2_RD(x)      (HW_ENET_RCMR2(x).U)
#define HW_ENET_RCMR2_WR(x, v)   (HW_ENET_RCMR2(x).U = (v))
#define HW_ENET_RCMR2_SET(x, v)  (HW_ENET_RCMR2_WR(x, HW_ENET_RCMR2_RD(x) |  (v)))
#define HW_ENET_RCMR2_CLR(x, v)  (HW_ENET_RCMR2_WR(x, HW_ENET_RCMR2_RD(x) & ~(v)))
#define HW_ENET_RCMR2_TOG(x, v)  (HW_ENET_RCMR2_WR(x, HW_ENET_RCMR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RCMR2 bitfields
 */

/*!
 * @name Register ENET_RCMR2, field CMP0[2:0] (RW)
 *
 * A three-bit value that will be compared with the frame's VLAN priority field
 * (if a VLAN frame is received). All four compare values, CMP0..3, will be used
 * in parallel. If any of the values match, a match for the class is reported (if
 * MATCHEN is 1).To implement a single priority match, all four compare values
 * must be set to the same value.
 */
/*@{*/
#define BP_ENET_RCMR2_CMP0   (0U)          /*!< Bit position for ENET_RCMR2_CMP0. */
#define BM_ENET_RCMR2_CMP0   (0x00000007U) /*!< Bit mask for ENET_RCMR2_CMP0. */
#define BS_ENET_RCMR2_CMP0   (3U)          /*!< Bit field size in bits for ENET_RCMR2_CMP0. */

/*! @brief Read current value of the ENET_RCMR2_CMP0 field. */
#define BR_ENET_RCMR2_CMP0(x) (HW_ENET_RCMR2(x).B.CMP0)

/*! @brief Format value for bitfield ENET_RCMR2_CMP0. */
#define BF_ENET_RCMR2_CMP0(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR2_CMP0) & BM_ENET_RCMR2_CMP0)

/*! @brief Set the CMP0 field to a new value. */
#define BW_ENET_RCMR2_CMP0(x, v) (HW_ENET_RCMR2_WR(x, (HW_ENET_RCMR2_RD(x) & ~BM_ENET_RCMR2_CMP0) | BF_ENET_RCMR2_CMP0(v)))
/*@}*/

/*!
 * @name Register ENET_RCMR2, field CMP1[6:4] (RW)
 *
 * Second value to compare against. If unused it must be set to the same value
 * as CMP0.
 */
/*@{*/
#define BP_ENET_RCMR2_CMP1   (4U)          /*!< Bit position for ENET_RCMR2_CMP1. */
#define BM_ENET_RCMR2_CMP1   (0x00000070U) /*!< Bit mask for ENET_RCMR2_CMP1. */
#define BS_ENET_RCMR2_CMP1   (3U)          /*!< Bit field size in bits for ENET_RCMR2_CMP1. */

/*! @brief Read current value of the ENET_RCMR2_CMP1 field. */
#define BR_ENET_RCMR2_CMP1(x) (HW_ENET_RCMR2(x).B.CMP1)

/*! @brief Format value for bitfield ENET_RCMR2_CMP1. */
#define BF_ENET_RCMR2_CMP1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR2_CMP1) & BM_ENET_RCMR2_CMP1)

/*! @brief Set the CMP1 field to a new value. */
#define BW_ENET_RCMR2_CMP1(x, v) (HW_ENET_RCMR2_WR(x, (HW_ENET_RCMR2_RD(x) & ~BM_ENET_RCMR2_CMP1) | BF_ENET_RCMR2_CMP1(v)))
/*@}*/

/*!
 * @name Register ENET_RCMR2, field CMP2[10:8] (RW)
 *
 * Third value to compare against. If unused it must be set to the same value as
 * CMP0.
 */
/*@{*/
#define BP_ENET_RCMR2_CMP2   (8U)          /*!< Bit position for ENET_RCMR2_CMP2. */
#define BM_ENET_RCMR2_CMP2   (0x00000700U) /*!< Bit mask for ENET_RCMR2_CMP2. */
#define BS_ENET_RCMR2_CMP2   (3U)          /*!< Bit field size in bits for ENET_RCMR2_CMP2. */

/*! @brief Read current value of the ENET_RCMR2_CMP2 field. */
#define BR_ENET_RCMR2_CMP2(x) (HW_ENET_RCMR2(x).B.CMP2)

/*! @brief Format value for bitfield ENET_RCMR2_CMP2. */
#define BF_ENET_RCMR2_CMP2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR2_CMP2) & BM_ENET_RCMR2_CMP2)

/*! @brief Set the CMP2 field to a new value. */
#define BW_ENET_RCMR2_CMP2(x, v) (HW_ENET_RCMR2_WR(x, (HW_ENET_RCMR2_RD(x) & ~BM_ENET_RCMR2_CMP2) | BF_ENET_RCMR2_CMP2(v)))
/*@}*/

/*!
 * @name Register ENET_RCMR2, field CMP3[14:12] (RW)
 *
 * Fourth value to compare against. If unused it must be set to the same value
 * as CMP0.
 */
/*@{*/
#define BP_ENET_RCMR2_CMP3   (12U)         /*!< Bit position for ENET_RCMR2_CMP3. */
#define BM_ENET_RCMR2_CMP3   (0x00007000U) /*!< Bit mask for ENET_RCMR2_CMP3. */
#define BS_ENET_RCMR2_CMP3   (3U)          /*!< Bit field size in bits for ENET_RCMR2_CMP3. */

/*! @brief Read current value of the ENET_RCMR2_CMP3 field. */
#define BR_ENET_RCMR2_CMP3(x) (HW_ENET_RCMR2(x).B.CMP3)

/*! @brief Format value for bitfield ENET_RCMR2_CMP3. */
#define BF_ENET_RCMR2_CMP3(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR2_CMP3) & BM_ENET_RCMR2_CMP3)

/*! @brief Set the CMP3 field to a new value. */
#define BW_ENET_RCMR2_CMP3(x, v) (HW_ENET_RCMR2_WR(x, (HW_ENET_RCMR2_RD(x) & ~BM_ENET_RCMR2_CMP3) | BF_ENET_RCMR2_CMP3(v)))
/*@}*/

/*!
 * @name Register ENET_RCMR2, field MATCHEN[16] (RW)
 *
 * A comparison is done only on incoming VLAN frames. If no VLAN frame is
 * received no match will occur. If both match registers have overlapping compare
 * values and hence can match both on the same frame, only class 1 will be indicated
 * and the class 2 match is ignored.
 *
 * Values:
 * - 0 - Disabled (default): no compares will occur and the classification
 *     indicator for this class will never assert.
 * - 1 - The register contents are valid and a comparison with all compare
 *     values is done when a VLAN frame is received.
 */
/*@{*/
#define BP_ENET_RCMR2_MATCHEN (16U)        /*!< Bit position for ENET_RCMR2_MATCHEN. */
#define BM_ENET_RCMR2_MATCHEN (0x00010000U) /*!< Bit mask for ENET_RCMR2_MATCHEN. */
#define BS_ENET_RCMR2_MATCHEN (1U)         /*!< Bit field size in bits for ENET_RCMR2_MATCHEN. */

/*! @brief Read current value of the ENET_RCMR2_MATCHEN field. */
#define BR_ENET_RCMR2_MATCHEN(x) (HW_ENET_RCMR2(x).B.MATCHEN)

/*! @brief Format value for bitfield ENET_RCMR2_MATCHEN. */
#define BF_ENET_RCMR2_MATCHEN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RCMR2_MATCHEN) & BM_ENET_RCMR2_MATCHEN)

/*! @brief Set the MATCHEN field to a new value. */
#define BW_ENET_RCMR2_MATCHEN(x, v) (HW_ENET_RCMR2_WR(x, (HW_ENET_RCMR2_RD(x) & ~BM_ENET_RCMR2_MATCHEN) | BF_ENET_RCMR2_MATCHEN(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_DMA1CFG - DMA Class Based Configuration
 ******************************************************************************/

/*!
 * @brief HW_ENET_DMA1CFG - DMA Class Based Configuration (RW)
 *
 * Reset value: 0x00000000U
 *
 * The DMA class based configuration registers are used to configure the DMA
 * controller interface to support the additional class 1 (buffer descriptor ring 1)
 * and class 2 (buffer descriptor ring 2) traffic and define configuration
 * options such as bandwidth allocation as needed.The registers are cleared when
 * ECR[ETHEREN] becomes 0.
 */
typedef union _hw_enet_dma1cfg
{
    uint32_t U;
    struct _hw_enet_dma1cfg_bitfields
    {
        uint32_t IDLE_SLOPE : 16;      /*!< [15:0] Idle slope */
        uint32_t DMA_CLASS_EN : 1;     /*!< [16] DMA class enable */
        uint32_t CALC_NOIPG : 1;       /*!< [17] Calculate no IPG */
        uint32_t RESERVED0 : 14;       /*!< [31:18]  */
    } B;
} hw_enet_dma1cfg_t;

/*!
 * @name Constants and macros for entire ENET_DMA1CFG register
 */
/*@{*/
#define HW_ENET_DMA1CFG_ADDR(x)  ((uintptr_t)(x) + 0x1D8U)

#define HW_ENET_DMA1CFG(x)       (*(__IO hw_enet_dma1cfg_t *) HW_ENET_DMA1CFG_ADDR(x))
#define HW_ENET_DMA1CFG_RD(x)    (HW_ENET_DMA1CFG(x).U)
#define HW_ENET_DMA1CFG_WR(x, v) (HW_ENET_DMA1CFG(x).U = (v))
#define HW_ENET_DMA1CFG_SET(x, v) (HW_ENET_DMA1CFG_WR(x, HW_ENET_DMA1CFG_RD(x) |  (v)))
#define HW_ENET_DMA1CFG_CLR(x, v) (HW_ENET_DMA1CFG_WR(x, HW_ENET_DMA1CFG_RD(x) & ~(v)))
#define HW_ENET_DMA1CFG_TOG(x, v) (HW_ENET_DMA1CFG_WR(x, HW_ENET_DMA1CFG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_DMA1CFG bitfields
 */

/*!
 * @name Register ENET_DMA1CFG, field IDLE_SLOPE[15:0] (RW)
 *
 * 16-bit value to define the per class idle slope setting used by the credit
 * based shaper defining allocated bandwidth for the class. This value is used to
 * calculate the BW (bandwidth) fraction, given by the equation, BW fraction =
 * 1/(1+512/IDLE_SLOPE). Idle slope is restricted to certain values. For values less
 * than 128, idle slope = 2^n, where n = 0, 1, 2, ...6. For values equal to or
 * greater than 128, idle slope = 128*m, where m = 1, 2, 3, ...12. Example 1. BW
 * fraction = 0.20 = 1/(1+(512/128)); therefore idleslope = 128. Example 2. BW
 * fraction = 0.33 = 1/(1+(512/256)); therefore idleslope = 256. Example 3. BW
 * fraction = 0.75 = 1/(1+(512/1536)); therefore idleslope = 1536. For AVB
 * applications, the BW fraction of class 1 and class 2 combined must not exceed .75.
 */
/*@{*/
#define BP_ENET_DMA1CFG_IDLE_SLOPE (0U)    /*!< Bit position for ENET_DMA1CFG_IDLE_SLOPE. */
#define BM_ENET_DMA1CFG_IDLE_SLOPE (0x0000FFFFU) /*!< Bit mask for ENET_DMA1CFG_IDLE_SLOPE. */
#define BS_ENET_DMA1CFG_IDLE_SLOPE (16U)   /*!< Bit field size in bits for ENET_DMA1CFG_IDLE_SLOPE. */

/*! @brief Read current value of the ENET_DMA1CFG_IDLE_SLOPE field. */
#define BR_ENET_DMA1CFG_IDLE_SLOPE(x) (HW_ENET_DMA1CFG(x).B.IDLE_SLOPE)

/*! @brief Format value for bitfield ENET_DMA1CFG_IDLE_SLOPE. */
#define BF_ENET_DMA1CFG_IDLE_SLOPE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_DMA1CFG_IDLE_SLOPE) & BM_ENET_DMA1CFG_IDLE_SLOPE)

/*! @brief Set the IDLE_SLOPE field to a new value. */
#define BW_ENET_DMA1CFG_IDLE_SLOPE(x, v) (HW_ENET_DMA1CFG_WR(x, (HW_ENET_DMA1CFG_RD(x) & ~BM_ENET_DMA1CFG_IDLE_SLOPE) | BF_ENET_DMA1CFG_IDLE_SLOPE(v)))
/*@}*/

/*!
 * @name Register ENET_DMA1CFG, field DMA_CLASS_EN[16] (RW)
 *
 * Values:
 * - 0 - The DMA controller's channel for the class is not used. Disabling the
 *     DMA controller of a class also requires disabling the class match
 *     comparator for the class (see registers RCMRn). When class 1 and class 2 queues are
 *     disabled then their frames will be placed in queue 0.
 * - 1 - Enable the DMA controller to support the corresponding descriptor ring
 *     for this class of traffic.
 */
/*@{*/
#define BP_ENET_DMA1CFG_DMA_CLASS_EN (16U) /*!< Bit position for ENET_DMA1CFG_DMA_CLASS_EN. */
#define BM_ENET_DMA1CFG_DMA_CLASS_EN (0x00010000U) /*!< Bit mask for ENET_DMA1CFG_DMA_CLASS_EN. */
#define BS_ENET_DMA1CFG_DMA_CLASS_EN (1U)  /*!< Bit field size in bits for ENET_DMA1CFG_DMA_CLASS_EN. */

/*! @brief Read current value of the ENET_DMA1CFG_DMA_CLASS_EN field. */
#define BR_ENET_DMA1CFG_DMA_CLASS_EN(x) (HW_ENET_DMA1CFG(x).B.DMA_CLASS_EN)

/*! @brief Format value for bitfield ENET_DMA1CFG_DMA_CLASS_EN. */
#define BF_ENET_DMA1CFG_DMA_CLASS_EN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_DMA1CFG_DMA_CLASS_EN) & BM_ENET_DMA1CFG_DMA_CLASS_EN)

/*! @brief Set the DMA_CLASS_EN field to a new value. */
#define BW_ENET_DMA1CFG_DMA_CLASS_EN(x, v) (HW_ENET_DMA1CFG_WR(x, (HW_ENET_DMA1CFG_RD(x) & ~BM_ENET_DMA1CFG_DMA_CLASS_EN) | BF_ENET_DMA1CFG_DMA_CLASS_EN(v)))
/*@}*/

/*!
 * @name Register ENET_DMA1CFG, field CALC_NOIPG[17] (RW)
 *
 * Disable inclusion of IPG bytes for bandwidth calculations.
 *
 * Values:
 * - 0 - The traffic shaper function should consider 12 octets of IPG in
 *     addition to the frame data transferred for a frame when doing bandwidth
 *     calculations. This is the default.
 * - 1 - Addition of 12 bytes for the IPG should be omitted when calculating the
 *     bandwidth (for traffic shaping, when writing a frame into the transmit
 *     FIFO, the shaper will usually consider 12 bytes of IPG for every frame as
 *     part of the bandwidth allocated by the frame. This addition can be
 *     suppressed, meaning short frames will become more bandwidth than large frames due
 *     to the relation of data to IPG overhead).
 */
/*@{*/
#define BP_ENET_DMA1CFG_CALC_NOIPG (17U)   /*!< Bit position for ENET_DMA1CFG_CALC_NOIPG. */
#define BM_ENET_DMA1CFG_CALC_NOIPG (0x00020000U) /*!< Bit mask for ENET_DMA1CFG_CALC_NOIPG. */
#define BS_ENET_DMA1CFG_CALC_NOIPG (1U)    /*!< Bit field size in bits for ENET_DMA1CFG_CALC_NOIPG. */

/*! @brief Read current value of the ENET_DMA1CFG_CALC_NOIPG field. */
#define BR_ENET_DMA1CFG_CALC_NOIPG(x) (HW_ENET_DMA1CFG(x).B.CALC_NOIPG)

/*! @brief Format value for bitfield ENET_DMA1CFG_CALC_NOIPG. */
#define BF_ENET_DMA1CFG_CALC_NOIPG(v) ((uint32_t)((uint32_t)(v) << BP_ENET_DMA1CFG_CALC_NOIPG) & BM_ENET_DMA1CFG_CALC_NOIPG)

/*! @brief Set the CALC_NOIPG field to a new value. */
#define BW_ENET_DMA1CFG_CALC_NOIPG(x, v) (HW_ENET_DMA1CFG_WR(x, (HW_ENET_DMA1CFG_RD(x) & ~BM_ENET_DMA1CFG_CALC_NOIPG) | BF_ENET_DMA1CFG_CALC_NOIPG(v)))
/*@}*/
/*******************************************************************************
 * HW_ENET_DMA2CFG - DMA Class Based Configuration
 ******************************************************************************/

/*!
 * @brief HW_ENET_DMA2CFG - DMA Class Based Configuration (RW)
 *
 * Reset value: 0x00000000U
 *
 * The DMA class based configuration registers are used to configure the DMA
 * controller interface to support the additional class 1 (buffer descriptor ring 1)
 * and class 2 (buffer descriptor ring 2) traffic and define configuration
 * options such as bandwidth allocation as needed.The registers are cleared when
 * ECR[ETHEREN] becomes 0.
 */
typedef union _hw_enet_dma2cfg
{
    uint32_t U;
    struct _hw_enet_dma2cfg_bitfields
    {
        uint32_t IDLE_SLOPE : 16;      /*!< [15:0] Idle slope */
        uint32_t DMA_CLASS_EN : 1;     /*!< [16] DMA class enable */
        uint32_t CALC_NOIPG : 1;       /*!< [17] Calculate no IPG */
        uint32_t RESERVED0 : 14;       /*!< [31:18]  */
    } B;
} hw_enet_dma2cfg_t;

/*!
 * @name Constants and macros for entire ENET_DMA2CFG register
 */
/*@{*/
#define HW_ENET_DMA2CFG_ADDR(x)  ((uintptr_t)(x) + 0x1DCU)

#define HW_ENET_DMA2CFG(x)       (*(__IO hw_enet_dma2cfg_t *) HW_ENET_DMA2CFG_ADDR(x))
#define HW_ENET_DMA2CFG_RD(x)    (HW_ENET_DMA2CFG(x).U)
#define HW_ENET_DMA2CFG_WR(x, v) (HW_ENET_DMA2CFG(x).U = (v))
#define HW_ENET_DMA2CFG_SET(x, v) (HW_ENET_DMA2CFG_WR(x, HW_ENET_DMA2CFG_RD(x) |  (v)))
#define HW_ENET_DMA2CFG_CLR(x, v) (HW_ENET_DMA2CFG_WR(x, HW_ENET_DMA2CFG_RD(x) & ~(v)))
#define HW_ENET_DMA2CFG_TOG(x, v) (HW_ENET_DMA2CFG_WR(x, HW_ENET_DMA2CFG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_DMA2CFG bitfields
 */

/*!
 * @name Register ENET_DMA2CFG, field IDLE_SLOPE[15:0] (RW)
 *
 * 16-bit value to define the per class idle slope setting used by the credit
 * based shaper defining allocated bandwidth for the class. This value is used to
 * calculate the BW (bandwidth) fraction, given by the equation, BW fraction =
 * 1/(1+512/IDLE_SLOPE). Idle slope is restricted to certain values. For values less
 * than 128, idle slope = 2^n, where n = 0, 1, 2, ...6. For values equal to or
 * greater than 128, idle slope = 128*m, where m = 1, 2, 3, ...12. Example 1. BW
 * fraction = 0.20 = 1/(1+(512/128)); therefore idleslope = 128. Example 2. BW
 * fraction = 0.33 = 1/(1+(512/256)); therefore idleslope = 256. Example 3. BW
 * fraction = 0.75 = 1/(1+(512/1536)); therefore idleslope = 1536. For AVB
 * applications, the BW fraction of class 1 and class 2 combined must not exceed .75.
 */
/*@{*/
#define BP_ENET_DMA2CFG_IDLE_SLOPE (0U)    /*!< Bit position for ENET_DMA2CFG_IDLE_SLOPE. */
#define BM_ENET_DMA2CFG_IDLE_SLOPE (0x0000FFFFU) /*!< Bit mask for ENET_DMA2CFG_IDLE_SLOPE. */
#define BS_ENET_DMA2CFG_IDLE_SLOPE (16U)   /*!< Bit field size in bits for ENET_DMA2CFG_IDLE_SLOPE. */

/*! @brief Read current value of the ENET_DMA2CFG_IDLE_SLOPE field. */
#define BR_ENET_DMA2CFG_IDLE_SLOPE(x) (HW_ENET_DMA2CFG(x).B.IDLE_SLOPE)

/*! @brief Format value for bitfield ENET_DMA2CFG_IDLE_SLOPE. */
#define BF_ENET_DMA2CFG_IDLE_SLOPE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_DMA2CFG_IDLE_SLOPE) & BM_ENET_DMA2CFG_IDLE_SLOPE)

/*! @brief Set the IDLE_SLOPE field to a new value. */
#define BW_ENET_DMA2CFG_IDLE_SLOPE(x, v) (HW_ENET_DMA2CFG_WR(x, (HW_ENET_DMA2CFG_RD(x) & ~BM_ENET_DMA2CFG_IDLE_SLOPE) | BF_ENET_DMA2CFG_IDLE_SLOPE(v)))
/*@}*/

/*!
 * @name Register ENET_DMA2CFG, field DMA_CLASS_EN[16] (RW)
 *
 * Values:
 * - 0 - The DMA controller's channel for the class is not used. Disabling the
 *     DMA controller of a class also requires disabling the class match
 *     comparator for the class (see registers RCMRn). When class 1 and class 2 queues are
 *     disabled then their frames will be placed in queue 0.
 * - 1 - Enable the DMA controller to support the corresponding descriptor ring
 *     for this class of traffic.
 */
/*@{*/
#define BP_ENET_DMA2CFG_DMA_CLASS_EN (16U) /*!< Bit position for ENET_DMA2CFG_DMA_CLASS_EN. */
#define BM_ENET_DMA2CFG_DMA_CLASS_EN (0x00010000U) /*!< Bit mask for ENET_DMA2CFG_DMA_CLASS_EN. */
#define BS_ENET_DMA2CFG_DMA_CLASS_EN (1U)  /*!< Bit field size in bits for ENET_DMA2CFG_DMA_CLASS_EN. */

/*! @brief Read current value of the ENET_DMA2CFG_DMA_CLASS_EN field. */
#define BR_ENET_DMA2CFG_DMA_CLASS_EN(x) (HW_ENET_DMA2CFG(x).B.DMA_CLASS_EN)

/*! @brief Format value for bitfield ENET_DMA2CFG_DMA_CLASS_EN. */
#define BF_ENET_DMA2CFG_DMA_CLASS_EN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_DMA2CFG_DMA_CLASS_EN) & BM_ENET_DMA2CFG_DMA_CLASS_EN)

/*! @brief Set the DMA_CLASS_EN field to a new value. */
#define BW_ENET_DMA2CFG_DMA_CLASS_EN(x, v) (HW_ENET_DMA2CFG_WR(x, (HW_ENET_DMA2CFG_RD(x) & ~BM_ENET_DMA2CFG_DMA_CLASS_EN) | BF_ENET_DMA2CFG_DMA_CLASS_EN(v)))
/*@}*/

/*!
 * @name Register ENET_DMA2CFG, field CALC_NOIPG[17] (RW)
 *
 * Disable inclusion of IPG bytes for bandwidth calculations.
 *
 * Values:
 * - 0 - The traffic shaper function should consider 12 octets of IPG in
 *     addition to the frame data transferred for a frame when doing bandwidth
 *     calculations. This is the default.
 * - 1 - Addition of 12 bytes for the IPG should be omitted when calculating the
 *     bandwidth (for traffic shaping, when writing a frame into the transmit
 *     FIFO, the shaper will usually consider 12 bytes of IPG for every frame as
 *     part of the bandwidth allocated by the frame. This addition can be
 *     suppressed, meaning short frames will become more bandwidth than large frames due
 *     to the relation of data to IPG overhead).
 */
/*@{*/
#define BP_ENET_DMA2CFG_CALC_NOIPG (17U)   /*!< Bit position for ENET_DMA2CFG_CALC_NOIPG. */
#define BM_ENET_DMA2CFG_CALC_NOIPG (0x00020000U) /*!< Bit mask for ENET_DMA2CFG_CALC_NOIPG. */
#define BS_ENET_DMA2CFG_CALC_NOIPG (1U)    /*!< Bit field size in bits for ENET_DMA2CFG_CALC_NOIPG. */

/*! @brief Read current value of the ENET_DMA2CFG_CALC_NOIPG field. */
#define BR_ENET_DMA2CFG_CALC_NOIPG(x) (HW_ENET_DMA2CFG(x).B.CALC_NOIPG)

/*! @brief Format value for bitfield ENET_DMA2CFG_CALC_NOIPG. */
#define BF_ENET_DMA2CFG_CALC_NOIPG(v) ((uint32_t)((uint32_t)(v) << BP_ENET_DMA2CFG_CALC_NOIPG) & BM_ENET_DMA2CFG_CALC_NOIPG)

/*! @brief Set the CALC_NOIPG field to a new value. */
#define BW_ENET_DMA2CFG_CALC_NOIPG(x, v) (HW_ENET_DMA2CFG_WR(x, (HW_ENET_DMA2CFG_RD(x) & ~BM_ENET_DMA2CFG_CALC_NOIPG) | BF_ENET_DMA2CFG_CALC_NOIPG(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RDAR1 - Receive Descriptor Active Register - Ring 1
 ******************************************************************************/

/*!
 * @brief HW_ENET_RDAR1 - Receive Descriptor Active Register - Ring 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * RDAR1 is a command register, written by the user, to indicate that the
 * receive descriptor ring 1 has been updated, that is, that the driver produced empty
 * receive buffers with the empty bit set.
 */
typedef union _hw_enet_rdar1
{
    uint32_t U;
    struct _hw_enet_rdar1_bitfields
    {
        uint32_t RESERVED0 : 24;       /*!< [23:0]  */
        uint32_t RDAR : 1;             /*!< [24] Receive Descriptor Active */
        uint32_t RESERVED1 : 7;        /*!< [31:25]  */
    } B;
} hw_enet_rdar1_t;

/*!
 * @name Constants and macros for entire ENET_RDAR1 register
 */
/*@{*/
#define HW_ENET_RDAR1_ADDR(x)    ((uintptr_t)(x) + 0x1E0U)

#define HW_ENET_RDAR1(x)         (*(__IO hw_enet_rdar1_t *) HW_ENET_RDAR1_ADDR(x))
#define HW_ENET_RDAR1_RD(x)      (HW_ENET_RDAR1(x).U)
#define HW_ENET_RDAR1_WR(x, v)   (HW_ENET_RDAR1(x).U = (v))
#define HW_ENET_RDAR1_SET(x, v)  (HW_ENET_RDAR1_WR(x, HW_ENET_RDAR1_RD(x) |  (v)))
#define HW_ENET_RDAR1_CLR(x, v)  (HW_ENET_RDAR1_WR(x, HW_ENET_RDAR1_RD(x) & ~(v)))
#define HW_ENET_RDAR1_TOG(x, v)  (HW_ENET_RDAR1_WR(x, HW_ENET_RDAR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RDAR1 bitfields
 */

/*!
 * @name Register ENET_RDAR1, field RDAR[24] (RW)
 *
 * Always set to 1 when this register is written, regardless of the value
 * written. This field is cleared by the MAC device when no additional empty
 * descriptors remain in the receive ring. It is also cleared when ECR[ETHEREN] transitions
 * from set to cleared or when ECR[RESET] is set.
 */
/*@{*/
#define BP_ENET_RDAR1_RDAR   (24U)         /*!< Bit position for ENET_RDAR1_RDAR. */
#define BM_ENET_RDAR1_RDAR   (0x01000000U) /*!< Bit mask for ENET_RDAR1_RDAR. */
#define BS_ENET_RDAR1_RDAR   (1U)          /*!< Bit field size in bits for ENET_RDAR1_RDAR. */

/*! @brief Read current value of the ENET_RDAR1_RDAR field. */
#define BR_ENET_RDAR1_RDAR(x) (HW_ENET_RDAR1(x).B.RDAR)

/*! @brief Format value for bitfield ENET_RDAR1_RDAR. */
#define BF_ENET_RDAR1_RDAR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RDAR1_RDAR) & BM_ENET_RDAR1_RDAR)

/*! @brief Set the RDAR field to a new value. */
#define BW_ENET_RDAR1_RDAR(x, v) (HW_ENET_RDAR1_WR(x, (HW_ENET_RDAR1_RD(x) & ~BM_ENET_RDAR1_RDAR) | BF_ENET_RDAR1_RDAR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TDAR1 - Transmit Descriptor Active Register - Ring 1
 ******************************************************************************/

/*!
 * @brief HW_ENET_TDAR1 - Transmit Descriptor Active Register - Ring 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * TDAR1 is a command register that the user writes to indicate that transmit
 * descriptor ring 1 has been updated, that is, that transmit buffers have been
 * produced by the driver with the ready bit set in the buffer descriptor. The TDAR
 * register is cleared at reset, when ECR[ETHEREN] transitions from set to
 * cleared, or when ECR[RESET] is set.
 */
typedef union _hw_enet_tdar1
{
    uint32_t U;
    struct _hw_enet_tdar1_bitfields
    {
        uint32_t RESERVED0 : 24;       /*!< [23:0]  */
        uint32_t TDAR : 1;             /*!< [24] Transmit Descriptor Active */
        uint32_t RESERVED1 : 7;        /*!< [31:25]  */
    } B;
} hw_enet_tdar1_t;

/*!
 * @name Constants and macros for entire ENET_TDAR1 register
 */
/*@{*/
#define HW_ENET_TDAR1_ADDR(x)    ((uintptr_t)(x) + 0x1E4U)

#define HW_ENET_TDAR1(x)         (*(__IO hw_enet_tdar1_t *) HW_ENET_TDAR1_ADDR(x))
#define HW_ENET_TDAR1_RD(x)      (HW_ENET_TDAR1(x).U)
#define HW_ENET_TDAR1_WR(x, v)   (HW_ENET_TDAR1(x).U = (v))
#define HW_ENET_TDAR1_SET(x, v)  (HW_ENET_TDAR1_WR(x, HW_ENET_TDAR1_RD(x) |  (v)))
#define HW_ENET_TDAR1_CLR(x, v)  (HW_ENET_TDAR1_WR(x, HW_ENET_TDAR1_RD(x) & ~(v)))
#define HW_ENET_TDAR1_TOG(x, v)  (HW_ENET_TDAR1_WR(x, HW_ENET_TDAR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TDAR1 bitfields
 */

/*!
 * @name Register ENET_TDAR1, field TDAR[24] (RW)
 *
 * Always set to 1 when this register is written, regardless of the value
 * written. This bit is cleared by the MAC device when no additional ready descriptors
 * remain in the transmit ring. Also cleared when ECR[ETHEREN] transitions from
 * set to cleared or when ECR[RESET] is set.
 */
/*@{*/
#define BP_ENET_TDAR1_TDAR   (24U)         /*!< Bit position for ENET_TDAR1_TDAR. */
#define BM_ENET_TDAR1_TDAR   (0x01000000U) /*!< Bit mask for ENET_TDAR1_TDAR. */
#define BS_ENET_TDAR1_TDAR   (1U)          /*!< Bit field size in bits for ENET_TDAR1_TDAR. */

/*! @brief Read current value of the ENET_TDAR1_TDAR field. */
#define BR_ENET_TDAR1_TDAR(x) (HW_ENET_TDAR1(x).B.TDAR)

/*! @brief Format value for bitfield ENET_TDAR1_TDAR. */
#define BF_ENET_TDAR1_TDAR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TDAR1_TDAR) & BM_ENET_TDAR1_TDAR)

/*! @brief Set the TDAR field to a new value. */
#define BW_ENET_TDAR1_TDAR(x, v) (HW_ENET_TDAR1_WR(x, (HW_ENET_TDAR1_RD(x) & ~BM_ENET_TDAR1_TDAR) | BF_ENET_TDAR1_TDAR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RDAR2 - Receive Descriptor Active Register - Ring 2
 ******************************************************************************/

/*!
 * @brief HW_ENET_RDAR2 - Receive Descriptor Active Register - Ring 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * RDAR2 is a command register, written by the user, to indicate that the
 * receive descriptor ring 2 has been updated, that is, that the driver produced empty
 * receive buffers with the empty bit set.
 */
typedef union _hw_enet_rdar2
{
    uint32_t U;
    struct _hw_enet_rdar2_bitfields
    {
        uint32_t RESERVED0 : 24;       /*!< [23:0]  */
        uint32_t RDAR : 1;             /*!< [24] Receive Descriptor Active */
        uint32_t RESERVED1 : 7;        /*!< [31:25]  */
    } B;
} hw_enet_rdar2_t;

/*!
 * @name Constants and macros for entire ENET_RDAR2 register
 */
/*@{*/
#define HW_ENET_RDAR2_ADDR(x)    ((uintptr_t)(x) + 0x1E8U)

#define HW_ENET_RDAR2(x)         (*(__IO hw_enet_rdar2_t *) HW_ENET_RDAR2_ADDR(x))
#define HW_ENET_RDAR2_RD(x)      (HW_ENET_RDAR2(x).U)
#define HW_ENET_RDAR2_WR(x, v)   (HW_ENET_RDAR2(x).U = (v))
#define HW_ENET_RDAR2_SET(x, v)  (HW_ENET_RDAR2_WR(x, HW_ENET_RDAR2_RD(x) |  (v)))
#define HW_ENET_RDAR2_CLR(x, v)  (HW_ENET_RDAR2_WR(x, HW_ENET_RDAR2_RD(x) & ~(v)))
#define HW_ENET_RDAR2_TOG(x, v)  (HW_ENET_RDAR2_WR(x, HW_ENET_RDAR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_RDAR2 bitfields
 */

/*!
 * @name Register ENET_RDAR2, field RDAR[24] (RW)
 *
 * Always set to 1 when this register is written, regardless of the value
 * written. This field is cleared by the MAC device when no additional empty
 * descriptors remain in the receive ring. It is also cleared when ECR[ETHEREN] transitions
 * from set to cleared or when ECR[RESET] is set.
 */
/*@{*/
#define BP_ENET_RDAR2_RDAR   (24U)         /*!< Bit position for ENET_RDAR2_RDAR. */
#define BM_ENET_RDAR2_RDAR   (0x01000000U) /*!< Bit mask for ENET_RDAR2_RDAR. */
#define BS_ENET_RDAR2_RDAR   (1U)          /*!< Bit field size in bits for ENET_RDAR2_RDAR. */

/*! @brief Read current value of the ENET_RDAR2_RDAR field. */
#define BR_ENET_RDAR2_RDAR(x) (HW_ENET_RDAR2(x).B.RDAR)

/*! @brief Format value for bitfield ENET_RDAR2_RDAR. */
#define BF_ENET_RDAR2_RDAR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_RDAR2_RDAR) & BM_ENET_RDAR2_RDAR)

/*! @brief Set the RDAR field to a new value. */
#define BW_ENET_RDAR2_RDAR(x, v) (HW_ENET_RDAR2_WR(x, (HW_ENET_RDAR2_RD(x) & ~BM_ENET_RDAR2_RDAR) | BF_ENET_RDAR2_RDAR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TDAR2 - Transmit Descriptor Active Register - Ring 2
 ******************************************************************************/

/*!
 * @brief HW_ENET_TDAR2 - Transmit Descriptor Active Register - Ring 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * TDAR2 is a command register that the user writes to indicate that transmit
 * descriptor ring 2 has been updated, that is, that transmit buffers have been
 * produced by the driver with the ready bit set in the buffer descriptor.
 */
typedef union _hw_enet_tdar2
{
    uint32_t U;
    struct _hw_enet_tdar2_bitfields
    {
        uint32_t RESERVED0 : 24;       /*!< [23:0]  */
        uint32_t TDAR : 1;             /*!< [24] Transmit Descriptor Active */
        uint32_t RESERVED1 : 7;        /*!< [31:25]  */
    } B;
} hw_enet_tdar2_t;

/*!
 * @name Constants and macros for entire ENET_TDAR2 register
 */
/*@{*/
#define HW_ENET_TDAR2_ADDR(x)    ((uintptr_t)(x) + 0x1ECU)

#define HW_ENET_TDAR2(x)         (*(__IO hw_enet_tdar2_t *) HW_ENET_TDAR2_ADDR(x))
#define HW_ENET_TDAR2_RD(x)      (HW_ENET_TDAR2(x).U)
#define HW_ENET_TDAR2_WR(x, v)   (HW_ENET_TDAR2(x).U = (v))
#define HW_ENET_TDAR2_SET(x, v)  (HW_ENET_TDAR2_WR(x, HW_ENET_TDAR2_RD(x) |  (v)))
#define HW_ENET_TDAR2_CLR(x, v)  (HW_ENET_TDAR2_WR(x, HW_ENET_TDAR2_RD(x) & ~(v)))
#define HW_ENET_TDAR2_TOG(x, v)  (HW_ENET_TDAR2_WR(x, HW_ENET_TDAR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TDAR2 bitfields
 */

/*!
 * @name Register ENET_TDAR2, field TDAR[24] (RW)
 *
 * Always set to 1 when this register is written, regardless of the value
 * written. This bit is cleared by the MAC device when no additional ready descriptors
 * remain in the transmit ring. Also cleared when ECR[ETHEREN] transitions from
 * set to cleared or when ECR[RESET] is set.
 */
/*@{*/
#define BP_ENET_TDAR2_TDAR   (24U)         /*!< Bit position for ENET_TDAR2_TDAR. */
#define BM_ENET_TDAR2_TDAR   (0x01000000U) /*!< Bit mask for ENET_TDAR2_TDAR. */
#define BS_ENET_TDAR2_TDAR   (1U)          /*!< Bit field size in bits for ENET_TDAR2_TDAR. */

/*! @brief Read current value of the ENET_TDAR2_TDAR field. */
#define BR_ENET_TDAR2_TDAR(x) (HW_ENET_TDAR2(x).B.TDAR)

/*! @brief Format value for bitfield ENET_TDAR2_TDAR. */
#define BF_ENET_TDAR2_TDAR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TDAR2_TDAR) & BM_ENET_TDAR2_TDAR)

/*! @brief Set the TDAR field to a new value. */
#define BW_ENET_TDAR2_TDAR(x, v) (HW_ENET_TDAR2_WR(x, (HW_ENET_TDAR2_RD(x) & ~BM_ENET_TDAR2_TDAR) | BF_ENET_TDAR2_TDAR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_QOS - QOS Scheme
 ******************************************************************************/

/*!
 * @brief HW_ENET_QOS - QOS Scheme (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register sets the QOS scheme. When both class 1 and class 2 are
 * disabled, RX flushing for these rings must also be disabled.
 */
typedef union _hw_enet_qos
{
    uint32_t U;
    struct _hw_enet_qos_bitfields
    {
        uint32_t TX_SCHEME : 3;        /*!< [2:0] TX scheme configuration */
        uint32_t RX_FLUSH0 : 1;        /*!< [3] RX Flush Ring 0 */
        uint32_t RX_FLUSH1 : 1;        /*!< [4] RX Flush Ring 1 */
        uint32_t RX_FLUSH2 : 1;        /*!< [5] RX Flush Ring 2 */
        uint32_t RESERVED0 : 26;       /*!< [31:6]  */
    } B;
} hw_enet_qos_t;

/*!
 * @name Constants and macros for entire ENET_QOS register
 */
/*@{*/
#define HW_ENET_QOS_ADDR(x)      ((uintptr_t)(x) + 0x1F0U)

#define HW_ENET_QOS(x)           (*(__IO hw_enet_qos_t *) HW_ENET_QOS_ADDR(x))
#define HW_ENET_QOS_RD(x)        (HW_ENET_QOS(x).U)
#define HW_ENET_QOS_WR(x, v)     (HW_ENET_QOS(x).U = (v))
#define HW_ENET_QOS_SET(x, v)    (HW_ENET_QOS_WR(x, HW_ENET_QOS_RD(x) |  (v)))
#define HW_ENET_QOS_CLR(x, v)    (HW_ENET_QOS_WR(x, HW_ENET_QOS_RD(x) & ~(v)))
#define HW_ENET_QOS_TOG(x, v)    (HW_ENET_QOS_WR(x, HW_ENET_QOS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_QOS bitfields
 */

/*!
 * @name Register ENET_QOS, field TX_SCHEME[2:0] (RW)
 *
 * Configuration information for DMA to select transmitter queue
 * selection/arbitration scheme.
 *
 * Values:
 * - 000 - Credit-based scheme
 * - 001 - Round-robin scheme
 */
/*@{*/
#define BP_ENET_QOS_TX_SCHEME (0U)         /*!< Bit position for ENET_QOS_TX_SCHEME. */
#define BM_ENET_QOS_TX_SCHEME (0x00000007U) /*!< Bit mask for ENET_QOS_TX_SCHEME. */
#define BS_ENET_QOS_TX_SCHEME (3U)         /*!< Bit field size in bits for ENET_QOS_TX_SCHEME. */

/*! @brief Read current value of the ENET_QOS_TX_SCHEME field. */
#define BR_ENET_QOS_TX_SCHEME(x) (HW_ENET_QOS(x).B.TX_SCHEME)

/*! @brief Format value for bitfield ENET_QOS_TX_SCHEME. */
#define BF_ENET_QOS_TX_SCHEME(v) ((uint32_t)((uint32_t)(v) << BP_ENET_QOS_TX_SCHEME) & BM_ENET_QOS_TX_SCHEME)

/*! @brief Set the TX_SCHEME field to a new value. */
#define BW_ENET_QOS_TX_SCHEME(x, v) (HW_ENET_QOS_WR(x, (HW_ENET_QOS_RD(x) & ~BM_ENET_QOS_TX_SCHEME) | BF_ENET_QOS_TX_SCHEME(v)))
/*@}*/

/*!
 * @name Register ENET_QOS, field RX_FLUSH0[3] (RW)
 *
 * Enable or disable RX Flush for ring 0. See Receive flushing.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ENET_QOS_RX_FLUSH0 (3U)         /*!< Bit position for ENET_QOS_RX_FLUSH0. */
#define BM_ENET_QOS_RX_FLUSH0 (0x00000008U) /*!< Bit mask for ENET_QOS_RX_FLUSH0. */
#define BS_ENET_QOS_RX_FLUSH0 (1U)         /*!< Bit field size in bits for ENET_QOS_RX_FLUSH0. */

/*! @brief Read current value of the ENET_QOS_RX_FLUSH0 field. */
#define BR_ENET_QOS_RX_FLUSH0(x) (HW_ENET_QOS(x).B.RX_FLUSH0)

/*! @brief Format value for bitfield ENET_QOS_RX_FLUSH0. */
#define BF_ENET_QOS_RX_FLUSH0(v) ((uint32_t)((uint32_t)(v) << BP_ENET_QOS_RX_FLUSH0) & BM_ENET_QOS_RX_FLUSH0)

/*! @brief Set the RX_FLUSH0 field to a new value. */
#define BW_ENET_QOS_RX_FLUSH0(x, v) (HW_ENET_QOS_WR(x, (HW_ENET_QOS_RD(x) & ~BM_ENET_QOS_RX_FLUSH0) | BF_ENET_QOS_RX_FLUSH0(v)))
/*@}*/

/*!
 * @name Register ENET_QOS, field RX_FLUSH1[4] (RW)
 *
 * Enable or disable RX Flush for ring 1. See Receive flushing.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ENET_QOS_RX_FLUSH1 (4U)         /*!< Bit position for ENET_QOS_RX_FLUSH1. */
#define BM_ENET_QOS_RX_FLUSH1 (0x00000010U) /*!< Bit mask for ENET_QOS_RX_FLUSH1. */
#define BS_ENET_QOS_RX_FLUSH1 (1U)         /*!< Bit field size in bits for ENET_QOS_RX_FLUSH1. */

/*! @brief Read current value of the ENET_QOS_RX_FLUSH1 field. */
#define BR_ENET_QOS_RX_FLUSH1(x) (HW_ENET_QOS(x).B.RX_FLUSH1)

/*! @brief Format value for bitfield ENET_QOS_RX_FLUSH1. */
#define BF_ENET_QOS_RX_FLUSH1(v) ((uint32_t)((uint32_t)(v) << BP_ENET_QOS_RX_FLUSH1) & BM_ENET_QOS_RX_FLUSH1)

/*! @brief Set the RX_FLUSH1 field to a new value. */
#define BW_ENET_QOS_RX_FLUSH1(x, v) (HW_ENET_QOS_WR(x, (HW_ENET_QOS_RD(x) & ~BM_ENET_QOS_RX_FLUSH1) | BF_ENET_QOS_RX_FLUSH1(v)))
/*@}*/

/*!
 * @name Register ENET_QOS, field RX_FLUSH2[5] (RW)
 *
 * Enable or disable RX Flush for ring 2. See Receive flushing.
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_ENET_QOS_RX_FLUSH2 (5U)         /*!< Bit position for ENET_QOS_RX_FLUSH2. */
#define BM_ENET_QOS_RX_FLUSH2 (0x00000020U) /*!< Bit mask for ENET_QOS_RX_FLUSH2. */
#define BS_ENET_QOS_RX_FLUSH2 (1U)         /*!< Bit field size in bits for ENET_QOS_RX_FLUSH2. */

/*! @brief Read current value of the ENET_QOS_RX_FLUSH2 field. */
#define BR_ENET_QOS_RX_FLUSH2(x) (HW_ENET_QOS(x).B.RX_FLUSH2)

/*! @brief Format value for bitfield ENET_QOS_RX_FLUSH2. */
#define BF_ENET_QOS_RX_FLUSH2(v) ((uint32_t)((uint32_t)(v) << BP_ENET_QOS_RX_FLUSH2) & BM_ENET_QOS_RX_FLUSH2)

/*! @brief Set the RX_FLUSH2 field to a new value. */
#define BW_ENET_QOS_RX_FLUSH2(x, v) (HW_ENET_QOS_WR(x, (HW_ENET_QOS_RD(x) & ~BM_ENET_QOS_RX_FLUSH2) | BF_ENET_QOS_RX_FLUSH2(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_DROP - Reserved Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_DROP - Reserved Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_drop
{
    uint32_t U;
    struct _hw_enet_rmon_t_drop_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0] This read-only field always has
                                        * the value 0. */
    } B;
} hw_enet_rmon_t_drop_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_DROP register
 */
/*@{*/
#define HW_ENET_RMON_T_DROP_ADDR(x) ((uintptr_t)(x) + 0x200U)

#define HW_ENET_RMON_T_DROP(x)   (*(__I hw_enet_rmon_t_drop_t *) HW_ENET_RMON_T_DROP_ADDR(x))
#define HW_ENET_RMON_T_DROP_RD(x) (HW_ENET_RMON_T_DROP(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_DROP bitfields
 */

/*******************************************************************************
 * HW_ENET_RMON_T_PACKETS - Tx Packet Count Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_PACKETS - Tx Packet Count Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_packets
{
    uint32_t U;
    struct _hw_enet_rmon_t_packets_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Packet count */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_packets_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_PACKETS register
 */
/*@{*/
#define HW_ENET_RMON_T_PACKETS_ADDR(x) ((uintptr_t)(x) + 0x204U)

#define HW_ENET_RMON_T_PACKETS(x) (*(__I hw_enet_rmon_t_packets_t *) HW_ENET_RMON_T_PACKETS_ADDR(x))
#define HW_ENET_RMON_T_PACKETS_RD(x) (HW_ENET_RMON_T_PACKETS(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_PACKETS bitfields
 */

/*!
 * @name Register ENET_RMON_T_PACKETS, field TXPKTS[15:0] (RO)
 *
 * Transmit packet count
 */
/*@{*/
#define BP_ENET_RMON_T_PACKETS_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_PACKETS_TXPKTS. */
#define BM_ENET_RMON_T_PACKETS_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_PACKETS_TXPKTS. */
#define BS_ENET_RMON_T_PACKETS_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_PACKETS_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_PACKETS_TXPKTS field. */
#define BR_ENET_RMON_T_PACKETS_TXPKTS(x) (HW_ENET_RMON_T_PACKETS(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_BC_PKT - Tx Broadcast Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_BC_PKT - Tx Broadcast Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * RMON Tx Broadcast Packets
 */
typedef union _hw_enet_rmon_t_bc_pkt
{
    uint32_t U;
    struct _hw_enet_rmon_t_bc_pkt_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Broadcast packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_bc_pkt_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_BC_PKT register
 */
/*@{*/
#define HW_ENET_RMON_T_BC_PKT_ADDR(x) ((uintptr_t)(x) + 0x208U)

#define HW_ENET_RMON_T_BC_PKT(x) (*(__I hw_enet_rmon_t_bc_pkt_t *) HW_ENET_RMON_T_BC_PKT_ADDR(x))
#define HW_ENET_RMON_T_BC_PKT_RD(x) (HW_ENET_RMON_T_BC_PKT(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_BC_PKT bitfields
 */

/*!
 * @name Register ENET_RMON_T_BC_PKT, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_BC_PKT_TXPKTS (0U)  /*!< Bit position for ENET_RMON_T_BC_PKT_TXPKTS. */
#define BM_ENET_RMON_T_BC_PKT_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_BC_PKT_TXPKTS. */
#define BS_ENET_RMON_T_BC_PKT_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_BC_PKT_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_BC_PKT_TXPKTS field. */
#define BR_ENET_RMON_T_BC_PKT_TXPKTS(x) (HW_ENET_RMON_T_BC_PKT(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_MC_PKT - Tx Multicast Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_MC_PKT - Tx Multicast Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_mc_pkt
{
    uint32_t U;
    struct _hw_enet_rmon_t_mc_pkt_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Multicast packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_mc_pkt_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_MC_PKT register
 */
/*@{*/
#define HW_ENET_RMON_T_MC_PKT_ADDR(x) ((uintptr_t)(x) + 0x20CU)

#define HW_ENET_RMON_T_MC_PKT(x) (*(__I hw_enet_rmon_t_mc_pkt_t *) HW_ENET_RMON_T_MC_PKT_ADDR(x))
#define HW_ENET_RMON_T_MC_PKT_RD(x) (HW_ENET_RMON_T_MC_PKT(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_MC_PKT bitfields
 */

/*!
 * @name Register ENET_RMON_T_MC_PKT, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_MC_PKT_TXPKTS (0U)  /*!< Bit position for ENET_RMON_T_MC_PKT_TXPKTS. */
#define BM_ENET_RMON_T_MC_PKT_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_MC_PKT_TXPKTS. */
#define BS_ENET_RMON_T_MC_PKT_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_MC_PKT_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_MC_PKT_TXPKTS field. */
#define BR_ENET_RMON_T_MC_PKT_TXPKTS(x) (HW_ENET_RMON_T_MC_PKT(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_CRC_ALIGN - Tx Packets with CRC/Align Error Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_CRC_ALIGN - Tx Packets with CRC/Align Error Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_crc_align
{
    uint32_t U;
    struct _hw_enet_rmon_t_crc_align_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Packets with CRC/align error */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_crc_align_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_CRC_ALIGN register
 */
/*@{*/
#define HW_ENET_RMON_T_CRC_ALIGN_ADDR(x) ((uintptr_t)(x) + 0x210U)

#define HW_ENET_RMON_T_CRC_ALIGN(x) (*(__I hw_enet_rmon_t_crc_align_t *) HW_ENET_RMON_T_CRC_ALIGN_ADDR(x))
#define HW_ENET_RMON_T_CRC_ALIGN_RD(x) (HW_ENET_RMON_T_CRC_ALIGN(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_CRC_ALIGN bitfields
 */

/*!
 * @name Register ENET_RMON_T_CRC_ALIGN, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_CRC_ALIGN_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_CRC_ALIGN_TXPKTS. */
#define BM_ENET_RMON_T_CRC_ALIGN_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_CRC_ALIGN_TXPKTS. */
#define BS_ENET_RMON_T_CRC_ALIGN_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_CRC_ALIGN_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_CRC_ALIGN_TXPKTS field. */
#define BR_ENET_RMON_T_CRC_ALIGN_TXPKTS(x) (HW_ENET_RMON_T_CRC_ALIGN(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_UNDERSIZE - Tx Packets Less Than Bytes and Good CRC Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_UNDERSIZE - Tx Packets Less Than Bytes and Good CRC Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_undersize
{
    uint32_t U;
    struct _hw_enet_rmon_t_undersize_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of transmit packets less
                                        * than 64 bytes with good CRC */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_undersize_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_UNDERSIZE register
 */
/*@{*/
#define HW_ENET_RMON_T_UNDERSIZE_ADDR(x) ((uintptr_t)(x) + 0x214U)

#define HW_ENET_RMON_T_UNDERSIZE(x) (*(__I hw_enet_rmon_t_undersize_t *) HW_ENET_RMON_T_UNDERSIZE_ADDR(x))
#define HW_ENET_RMON_T_UNDERSIZE_RD(x) (HW_ENET_RMON_T_UNDERSIZE(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_UNDERSIZE bitfields
 */

/*!
 * @name Register ENET_RMON_T_UNDERSIZE, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_UNDERSIZE_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_UNDERSIZE_TXPKTS. */
#define BM_ENET_RMON_T_UNDERSIZE_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_UNDERSIZE_TXPKTS. */
#define BS_ENET_RMON_T_UNDERSIZE_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_UNDERSIZE_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_UNDERSIZE_TXPKTS field. */
#define BR_ENET_RMON_T_UNDERSIZE_TXPKTS(x) (HW_ENET_RMON_T_UNDERSIZE(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_OVERSIZE - Tx Packets GT MAX_FL bytes and Good CRC Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_OVERSIZE - Tx Packets GT MAX_FL bytes and Good CRC Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_oversize
{
    uint32_t U;
    struct _hw_enet_rmon_t_oversize_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of transmit packets greater
                                        * than MAX_FL bytes with good CRC */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_oversize_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_OVERSIZE register
 */
/*@{*/
#define HW_ENET_RMON_T_OVERSIZE_ADDR(x) ((uintptr_t)(x) + 0x218U)

#define HW_ENET_RMON_T_OVERSIZE(x) (*(__I hw_enet_rmon_t_oversize_t *) HW_ENET_RMON_T_OVERSIZE_ADDR(x))
#define HW_ENET_RMON_T_OVERSIZE_RD(x) (HW_ENET_RMON_T_OVERSIZE(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_OVERSIZE bitfields
 */

/*!
 * @name Register ENET_RMON_T_OVERSIZE, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_OVERSIZE_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_OVERSIZE_TXPKTS. */
#define BM_ENET_RMON_T_OVERSIZE_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_OVERSIZE_TXPKTS. */
#define BS_ENET_RMON_T_OVERSIZE_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_OVERSIZE_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_OVERSIZE_TXPKTS field. */
#define BR_ENET_RMON_T_OVERSIZE_TXPKTS(x) (HW_ENET_RMON_T_OVERSIZE(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_FRAG - Tx Packets Less Than 64 Bytes and Bad CRC Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_FRAG - Tx Packets Less Than 64 Bytes and Bad CRC Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * .
 */
typedef union _hw_enet_rmon_t_frag
{
    uint32_t U;
    struct _hw_enet_rmon_t_frag_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of packets less than 64
                                        * bytes with bad CRC */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_frag_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_FRAG register
 */
/*@{*/
#define HW_ENET_RMON_T_FRAG_ADDR(x) ((uintptr_t)(x) + 0x21CU)

#define HW_ENET_RMON_T_FRAG(x)   (*(__I hw_enet_rmon_t_frag_t *) HW_ENET_RMON_T_FRAG_ADDR(x))
#define HW_ENET_RMON_T_FRAG_RD(x) (HW_ENET_RMON_T_FRAG(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_FRAG bitfields
 */

/*!
 * @name Register ENET_RMON_T_FRAG, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_FRAG_TXPKTS (0U)    /*!< Bit position for ENET_RMON_T_FRAG_TXPKTS. */
#define BM_ENET_RMON_T_FRAG_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_FRAG_TXPKTS. */
#define BS_ENET_RMON_T_FRAG_TXPKTS (16U)   /*!< Bit field size in bits for ENET_RMON_T_FRAG_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_FRAG_TXPKTS field. */
#define BR_ENET_RMON_T_FRAG_TXPKTS(x) (HW_ENET_RMON_T_FRAG(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_JAB - Tx Packets Greater Than MAX_FL bytes and Bad CRC Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_JAB - Tx Packets Greater Than MAX_FL bytes and Bad CRC Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_jab
{
    uint32_t U;
    struct _hw_enet_rmon_t_jab_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of transmit packets greater
                                        * than MAX_FL bytes and bad CRC */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_jab_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_JAB register
 */
/*@{*/
#define HW_ENET_RMON_T_JAB_ADDR(x) ((uintptr_t)(x) + 0x220U)

#define HW_ENET_RMON_T_JAB(x)    (*(__I hw_enet_rmon_t_jab_t *) HW_ENET_RMON_T_JAB_ADDR(x))
#define HW_ENET_RMON_T_JAB_RD(x) (HW_ENET_RMON_T_JAB(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_JAB bitfields
 */

/*!
 * @name Register ENET_RMON_T_JAB, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_JAB_TXPKTS (0U)     /*!< Bit position for ENET_RMON_T_JAB_TXPKTS. */
#define BM_ENET_RMON_T_JAB_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_JAB_TXPKTS. */
#define BS_ENET_RMON_T_JAB_TXPKTS (16U)    /*!< Bit field size in bits for ENET_RMON_T_JAB_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_JAB_TXPKTS field. */
#define BR_ENET_RMON_T_JAB_TXPKTS(x) (HW_ENET_RMON_T_JAB(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_COL - Tx Collision Count Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_COL - Tx Collision Count Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_col
{
    uint32_t U;
    struct _hw_enet_rmon_t_col_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of transmit collisions */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_col_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_COL register
 */
/*@{*/
#define HW_ENET_RMON_T_COL_ADDR(x) ((uintptr_t)(x) + 0x224U)

#define HW_ENET_RMON_T_COL(x)    (*(__I hw_enet_rmon_t_col_t *) HW_ENET_RMON_T_COL_ADDR(x))
#define HW_ENET_RMON_T_COL_RD(x) (HW_ENET_RMON_T_COL(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_COL bitfields
 */

/*!
 * @name Register ENET_RMON_T_COL, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_COL_TXPKTS (0U)     /*!< Bit position for ENET_RMON_T_COL_TXPKTS. */
#define BM_ENET_RMON_T_COL_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_COL_TXPKTS. */
#define BS_ENET_RMON_T_COL_TXPKTS (16U)    /*!< Bit field size in bits for ENET_RMON_T_COL_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_COL_TXPKTS field. */
#define BR_ENET_RMON_T_COL_TXPKTS(x) (HW_ENET_RMON_T_COL(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_P64 - Tx 64-Byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_P64 - Tx 64-Byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * .
 */
typedef union _hw_enet_rmon_t_p64
{
    uint32_t U;
    struct _hw_enet_rmon_t_p64_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of 64-byte transmit packets
                                        * */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_p64_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_P64 register
 */
/*@{*/
#define HW_ENET_RMON_T_P64_ADDR(x) ((uintptr_t)(x) + 0x228U)

#define HW_ENET_RMON_T_P64(x)    (*(__I hw_enet_rmon_t_p64_t *) HW_ENET_RMON_T_P64_ADDR(x))
#define HW_ENET_RMON_T_P64_RD(x) (HW_ENET_RMON_T_P64(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_P64 bitfields
 */

/*!
 * @name Register ENET_RMON_T_P64, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_P64_TXPKTS (0U)     /*!< Bit position for ENET_RMON_T_P64_TXPKTS. */
#define BM_ENET_RMON_T_P64_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_P64_TXPKTS. */
#define BS_ENET_RMON_T_P64_TXPKTS (16U)    /*!< Bit field size in bits for ENET_RMON_T_P64_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_P64_TXPKTS field. */
#define BR_ENET_RMON_T_P64_TXPKTS(x) (HW_ENET_RMON_T_P64(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_P65TO127 - Tx 65- to 127-byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_P65TO127 - Tx 65- to 127-byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_p65to127
{
    uint32_t U;
    struct _hw_enet_rmon_t_p65to127_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of 65- to 127-byte transmit
                                        * packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_p65to127_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_P65TO127 register
 */
/*@{*/
#define HW_ENET_RMON_T_P65TO127_ADDR(x) ((uintptr_t)(x) + 0x22CU)

#define HW_ENET_RMON_T_P65TO127(x) (*(__I hw_enet_rmon_t_p65to127_t *) HW_ENET_RMON_T_P65TO127_ADDR(x))
#define HW_ENET_RMON_T_P65TO127_RD(x) (HW_ENET_RMON_T_P65TO127(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_P65TO127 bitfields
 */

/*!
 * @name Register ENET_RMON_T_P65TO127, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_P65TO127_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_P65TO127_TXPKTS. */
#define BM_ENET_RMON_T_P65TO127_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_P65TO127_TXPKTS. */
#define BS_ENET_RMON_T_P65TO127_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_P65TO127_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_P65TO127_TXPKTS field. */
#define BR_ENET_RMON_T_P65TO127_TXPKTS(x) (HW_ENET_RMON_T_P65TO127(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_P128TO255 - Tx 128- to 255-byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_P128TO255 - Tx 128- to 255-byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_p128to255
{
    uint32_t U;
    struct _hw_enet_rmon_t_p128to255_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of 128- to 255-byte transmit
                                        * packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_p128to255_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_P128TO255 register
 */
/*@{*/
#define HW_ENET_RMON_T_P128TO255_ADDR(x) ((uintptr_t)(x) + 0x230U)

#define HW_ENET_RMON_T_P128TO255(x) (*(__I hw_enet_rmon_t_p128to255_t *) HW_ENET_RMON_T_P128TO255_ADDR(x))
#define HW_ENET_RMON_T_P128TO255_RD(x) (HW_ENET_RMON_T_P128TO255(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_P128TO255 bitfields
 */

/*!
 * @name Register ENET_RMON_T_P128TO255, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_P128TO255_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_P128TO255_TXPKTS. */
#define BM_ENET_RMON_T_P128TO255_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_P128TO255_TXPKTS. */
#define BS_ENET_RMON_T_P128TO255_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_P128TO255_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_P128TO255_TXPKTS field. */
#define BR_ENET_RMON_T_P128TO255_TXPKTS(x) (HW_ENET_RMON_T_P128TO255(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_P256TO511 - Tx 256- to 511-byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_P256TO511 - Tx 256- to 511-byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_p256to511
{
    uint32_t U;
    struct _hw_enet_rmon_t_p256to511_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of 256- to 511-byte transmit
                                        * packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_p256to511_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_P256TO511 register
 */
/*@{*/
#define HW_ENET_RMON_T_P256TO511_ADDR(x) ((uintptr_t)(x) + 0x234U)

#define HW_ENET_RMON_T_P256TO511(x) (*(__I hw_enet_rmon_t_p256to511_t *) HW_ENET_RMON_T_P256TO511_ADDR(x))
#define HW_ENET_RMON_T_P256TO511_RD(x) (HW_ENET_RMON_T_P256TO511(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_P256TO511 bitfields
 */

/*!
 * @name Register ENET_RMON_T_P256TO511, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_P256TO511_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_P256TO511_TXPKTS. */
#define BM_ENET_RMON_T_P256TO511_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_P256TO511_TXPKTS. */
#define BS_ENET_RMON_T_P256TO511_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_P256TO511_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_P256TO511_TXPKTS field. */
#define BR_ENET_RMON_T_P256TO511_TXPKTS(x) (HW_ENET_RMON_T_P256TO511(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_P512TO1023 - Tx 512- to 1023-byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_P512TO1023 - Tx 512- to 1023-byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * .
 */
typedef union _hw_enet_rmon_t_p512to1023
{
    uint32_t U;
    struct _hw_enet_rmon_t_p512to1023_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of 512- to 1023-byte
                                        * transmit packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_p512to1023_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_P512TO1023 register
 */
/*@{*/
#define HW_ENET_RMON_T_P512TO1023_ADDR(x) ((uintptr_t)(x) + 0x238U)

#define HW_ENET_RMON_T_P512TO1023(x) (*(__I hw_enet_rmon_t_p512to1023_t *) HW_ENET_RMON_T_P512TO1023_ADDR(x))
#define HW_ENET_RMON_T_P512TO1023_RD(x) (HW_ENET_RMON_T_P512TO1023(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_P512TO1023 bitfields
 */

/*!
 * @name Register ENET_RMON_T_P512TO1023, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_P512TO1023_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_P512TO1023_TXPKTS. */
#define BM_ENET_RMON_T_P512TO1023_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_P512TO1023_TXPKTS. */
#define BS_ENET_RMON_T_P512TO1023_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_P512TO1023_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_P512TO1023_TXPKTS field. */
#define BR_ENET_RMON_T_P512TO1023_TXPKTS(x) (HW_ENET_RMON_T_P512TO1023(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_P1024TO2047 - Tx 1024- to 2047-byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_P1024TO2047 - Tx 1024- to 2047-byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_p1024to2047
{
    uint32_t U;
    struct _hw_enet_rmon_t_p1024to2047_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of 1024- to 2047-byte
                                        * transmit packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_p1024to2047_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_P1024TO2047 register
 */
/*@{*/
#define HW_ENET_RMON_T_P1024TO2047_ADDR(x) ((uintptr_t)(x) + 0x23CU)

#define HW_ENET_RMON_T_P1024TO2047(x) (*(__I hw_enet_rmon_t_p1024to2047_t *) HW_ENET_RMON_T_P1024TO2047_ADDR(x))
#define HW_ENET_RMON_T_P1024TO2047_RD(x) (HW_ENET_RMON_T_P1024TO2047(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_P1024TO2047 bitfields
 */

/*!
 * @name Register ENET_RMON_T_P1024TO2047, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_P1024TO2047_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_P1024TO2047_TXPKTS. */
#define BM_ENET_RMON_T_P1024TO2047_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_P1024TO2047_TXPKTS. */
#define BS_ENET_RMON_T_P1024TO2047_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_P1024TO2047_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_P1024TO2047_TXPKTS field. */
#define BR_ENET_RMON_T_P1024TO2047_TXPKTS(x) (HW_ENET_RMON_T_P1024TO2047(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_P_GTE2048 - Tx Packets Greater Than 2048 Bytes Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_P_GTE2048 - Tx Packets Greater Than 2048 Bytes Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_p_gte2048
{
    uint32_t U;
    struct _hw_enet_rmon_t_p_gte2048_bitfields
    {
        uint32_t TXPKTS : 16;          /*!< [15:0] Number of transmit packets greater
                                        * than 2048 bytes */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_t_p_gte2048_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_P_GTE2048 register
 */
/*@{*/
#define HW_ENET_RMON_T_P_GTE2048_ADDR(x) ((uintptr_t)(x) + 0x240U)

#define HW_ENET_RMON_T_P_GTE2048(x) (*(__I hw_enet_rmon_t_p_gte2048_t *) HW_ENET_RMON_T_P_GTE2048_ADDR(x))
#define HW_ENET_RMON_T_P_GTE2048_RD(x) (HW_ENET_RMON_T_P_GTE2048(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_P_GTE2048 bitfields
 */

/*!
 * @name Register ENET_RMON_T_P_GTE2048, field TXPKTS[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_P_GTE2048_TXPKTS (0U) /*!< Bit position for ENET_RMON_T_P_GTE2048_TXPKTS. */
#define BM_ENET_RMON_T_P_GTE2048_TXPKTS (0x0000FFFFU) /*!< Bit mask for ENET_RMON_T_P_GTE2048_TXPKTS. */
#define BS_ENET_RMON_T_P_GTE2048_TXPKTS (16U) /*!< Bit field size in bits for ENET_RMON_T_P_GTE2048_TXPKTS. */

/*! @brief Read current value of the ENET_RMON_T_P_GTE2048_TXPKTS field. */
#define BR_ENET_RMON_T_P_GTE2048_TXPKTS(x) (HW_ENET_RMON_T_P_GTE2048(x).B.TXPKTS)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_T_OCTETS - Tx Octets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_T_OCTETS - Tx Octets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_t_octets
{
    uint32_t U;
    struct _hw_enet_rmon_t_octets_bitfields
    {
        uint32_t TXOCTS : 32;          /*!< [31:0] Number of transmit octets */
    } B;
} hw_enet_rmon_t_octets_t;

/*!
 * @name Constants and macros for entire ENET_RMON_T_OCTETS register
 */
/*@{*/
#define HW_ENET_RMON_T_OCTETS_ADDR(x) ((uintptr_t)(x) + 0x244U)

#define HW_ENET_RMON_T_OCTETS(x) (*(__I hw_enet_rmon_t_octets_t *) HW_ENET_RMON_T_OCTETS_ADDR(x))
#define HW_ENET_RMON_T_OCTETS_RD(x) (HW_ENET_RMON_T_OCTETS(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_T_OCTETS bitfields
 */

/*!
 * @name Register ENET_RMON_T_OCTETS, field TXOCTS[31:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_T_OCTETS_TXOCTS (0U)  /*!< Bit position for ENET_RMON_T_OCTETS_TXOCTS. */
#define BM_ENET_RMON_T_OCTETS_TXOCTS (0xFFFFFFFFU) /*!< Bit mask for ENET_RMON_T_OCTETS_TXOCTS. */
#define BS_ENET_RMON_T_OCTETS_TXOCTS (32U) /*!< Bit field size in bits for ENET_RMON_T_OCTETS_TXOCTS. */

/*! @brief Read current value of the ENET_RMON_T_OCTETS_TXOCTS field. */
#define BR_ENET_RMON_T_OCTETS_TXOCTS(x) (HW_ENET_RMON_T_OCTETS(x).U)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_DROP - Reserved Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_DROP - Reserved Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_drop
{
    uint32_t U;
    struct _hw_enet_ieee_t_drop_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0] This read-only field always has
                                        * the value 0. */
    } B;
} hw_enet_ieee_t_drop_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_DROP register
 */
/*@{*/
#define HW_ENET_IEEE_T_DROP_ADDR(x) ((uintptr_t)(x) + 0x248U)

#define HW_ENET_IEEE_T_DROP(x)   (*(__I hw_enet_ieee_t_drop_t *) HW_ENET_IEEE_T_DROP_ADDR(x))
#define HW_ENET_IEEE_T_DROP_RD(x) (HW_ENET_IEEE_T_DROP(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_DROP bitfields
 */

/*******************************************************************************
 * HW_ENET_IEEE_T_FRAME_OK - Frames Transmitted OK Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_FRAME_OK - Frames Transmitted OK Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_frame_ok
{
    uint32_t U;
    struct _hw_enet_ieee_t_frame_ok_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames transmitted OK */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_frame_ok_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_FRAME_OK register
 */
/*@{*/
#define HW_ENET_IEEE_T_FRAME_OK_ADDR(x) ((uintptr_t)(x) + 0x24CU)

#define HW_ENET_IEEE_T_FRAME_OK(x) (*(__I hw_enet_ieee_t_frame_ok_t *) HW_ENET_IEEE_T_FRAME_OK_ADDR(x))
#define HW_ENET_IEEE_T_FRAME_OK_RD(x) (HW_ENET_IEEE_T_FRAME_OK(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_FRAME_OK bitfields
 */

/*!
 * @name Register ENET_IEEE_T_FRAME_OK, field COUNT[15:0] (RO)
 *
 * Does not increment for the broadcast frames when broadcast reject is enabled
 * and promiscuous mode is disabled within the receive control register (RCR).
 */
/*@{*/
#define BP_ENET_IEEE_T_FRAME_OK_COUNT (0U) /*!< Bit position for ENET_IEEE_T_FRAME_OK_COUNT. */
#define BM_ENET_IEEE_T_FRAME_OK_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_FRAME_OK_COUNT. */
#define BS_ENET_IEEE_T_FRAME_OK_COUNT (16U) /*!< Bit field size in bits for ENET_IEEE_T_FRAME_OK_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_FRAME_OK_COUNT field. */
#define BR_ENET_IEEE_T_FRAME_OK_COUNT(x) (HW_ENET_IEEE_T_FRAME_OK(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_1COL - Frames Transmitted with Single Collision Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_1COL - Frames Transmitted with Single Collision Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_1col
{
    uint32_t U;
    struct _hw_enet_ieee_t_1col_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames transmitted with
                                        * one collision */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_1col_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_1COL register
 */
/*@{*/
#define HW_ENET_IEEE_T_1COL_ADDR(x) ((uintptr_t)(x) + 0x250U)

#define HW_ENET_IEEE_T_1COL(x)   (*(__I hw_enet_ieee_t_1col_t *) HW_ENET_IEEE_T_1COL_ADDR(x))
#define HW_ENET_IEEE_T_1COL_RD(x) (HW_ENET_IEEE_T_1COL(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_1COL bitfields
 */

/*!
 * @name Register ENET_IEEE_T_1COL, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_T_1COL_COUNT (0U)     /*!< Bit position for ENET_IEEE_T_1COL_COUNT. */
#define BM_ENET_IEEE_T_1COL_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_1COL_COUNT. */
#define BS_ENET_IEEE_T_1COL_COUNT (16U)    /*!< Bit field size in bits for ENET_IEEE_T_1COL_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_1COL_COUNT field. */
#define BR_ENET_IEEE_T_1COL_COUNT(x) (HW_ENET_IEEE_T_1COL(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_MCOL - Frames Transmitted with Multiple Collisions Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_MCOL - Frames Transmitted with Multiple Collisions Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_mcol
{
    uint32_t U;
    struct _hw_enet_ieee_t_mcol_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames transmitted with
                                        * multiple collisions */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_mcol_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_MCOL register
 */
/*@{*/
#define HW_ENET_IEEE_T_MCOL_ADDR(x) ((uintptr_t)(x) + 0x254U)

#define HW_ENET_IEEE_T_MCOL(x)   (*(__I hw_enet_ieee_t_mcol_t *) HW_ENET_IEEE_T_MCOL_ADDR(x))
#define HW_ENET_IEEE_T_MCOL_RD(x) (HW_ENET_IEEE_T_MCOL(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_MCOL bitfields
 */

/*!
 * @name Register ENET_IEEE_T_MCOL, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_T_MCOL_COUNT (0U)     /*!< Bit position for ENET_IEEE_T_MCOL_COUNT. */
#define BM_ENET_IEEE_T_MCOL_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_MCOL_COUNT. */
#define BS_ENET_IEEE_T_MCOL_COUNT (16U)    /*!< Bit field size in bits for ENET_IEEE_T_MCOL_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_MCOL_COUNT field. */
#define BR_ENET_IEEE_T_MCOL_COUNT(x) (HW_ENET_IEEE_T_MCOL(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_DEF - Frames Transmitted after Deferral Delay Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_DEF - Frames Transmitted after Deferral Delay Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_def
{
    uint32_t U;
    struct _hw_enet_ieee_t_def_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames transmitted with
                                        * deferral delay */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_def_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_DEF register
 */
/*@{*/
#define HW_ENET_IEEE_T_DEF_ADDR(x) ((uintptr_t)(x) + 0x258U)

#define HW_ENET_IEEE_T_DEF(x)    (*(__I hw_enet_ieee_t_def_t *) HW_ENET_IEEE_T_DEF_ADDR(x))
#define HW_ENET_IEEE_T_DEF_RD(x) (HW_ENET_IEEE_T_DEF(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_DEF bitfields
 */

/*!
 * @name Register ENET_IEEE_T_DEF, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_T_DEF_COUNT (0U)      /*!< Bit position for ENET_IEEE_T_DEF_COUNT. */
#define BM_ENET_IEEE_T_DEF_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_DEF_COUNT. */
#define BS_ENET_IEEE_T_DEF_COUNT (16U)     /*!< Bit field size in bits for ENET_IEEE_T_DEF_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_DEF_COUNT field. */
#define BR_ENET_IEEE_T_DEF_COUNT(x) (HW_ENET_IEEE_T_DEF(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_LCOL - Frames Transmitted with Late Collision Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_LCOL - Frames Transmitted with Late Collision Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_lcol
{
    uint32_t U;
    struct _hw_enet_ieee_t_lcol_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames transmitted with
                                        * late collision */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_lcol_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_LCOL register
 */
/*@{*/
#define HW_ENET_IEEE_T_LCOL_ADDR(x) ((uintptr_t)(x) + 0x25CU)

#define HW_ENET_IEEE_T_LCOL(x)   (*(__I hw_enet_ieee_t_lcol_t *) HW_ENET_IEEE_T_LCOL_ADDR(x))
#define HW_ENET_IEEE_T_LCOL_RD(x) (HW_ENET_IEEE_T_LCOL(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_LCOL bitfields
 */

/*!
 * @name Register ENET_IEEE_T_LCOL, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_T_LCOL_COUNT (0U)     /*!< Bit position for ENET_IEEE_T_LCOL_COUNT. */
#define BM_ENET_IEEE_T_LCOL_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_LCOL_COUNT. */
#define BS_ENET_IEEE_T_LCOL_COUNT (16U)    /*!< Bit field size in bits for ENET_IEEE_T_LCOL_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_LCOL_COUNT field. */
#define BR_ENET_IEEE_T_LCOL_COUNT(x) (HW_ENET_IEEE_T_LCOL(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_EXCOL - Frames Transmitted with Excessive Collisions Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_EXCOL - Frames Transmitted with Excessive Collisions Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_excol
{
    uint32_t U;
    struct _hw_enet_ieee_t_excol_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames transmitted with
                                        * excessive collisions */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_excol_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_EXCOL register
 */
/*@{*/
#define HW_ENET_IEEE_T_EXCOL_ADDR(x) ((uintptr_t)(x) + 0x260U)

#define HW_ENET_IEEE_T_EXCOL(x)  (*(__I hw_enet_ieee_t_excol_t *) HW_ENET_IEEE_T_EXCOL_ADDR(x))
#define HW_ENET_IEEE_T_EXCOL_RD(x) (HW_ENET_IEEE_T_EXCOL(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_EXCOL bitfields
 */

/*!
 * @name Register ENET_IEEE_T_EXCOL, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_T_EXCOL_COUNT (0U)    /*!< Bit position for ENET_IEEE_T_EXCOL_COUNT. */
#define BM_ENET_IEEE_T_EXCOL_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_EXCOL_COUNT. */
#define BS_ENET_IEEE_T_EXCOL_COUNT (16U)   /*!< Bit field size in bits for ENET_IEEE_T_EXCOL_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_EXCOL_COUNT field. */
#define BR_ENET_IEEE_T_EXCOL_COUNT(x) (HW_ENET_IEEE_T_EXCOL(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_MACERR - Frames Transmitted with Tx FIFO Underrun Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_MACERR - Frames Transmitted with Tx FIFO Underrun Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_macerr
{
    uint32_t U;
    struct _hw_enet_ieee_t_macerr_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames transmitted with
                                        * transmit FIFO underrun */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_macerr_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_MACERR register
 */
/*@{*/
#define HW_ENET_IEEE_T_MACERR_ADDR(x) ((uintptr_t)(x) + 0x264U)

#define HW_ENET_IEEE_T_MACERR(x) (*(__I hw_enet_ieee_t_macerr_t *) HW_ENET_IEEE_T_MACERR_ADDR(x))
#define HW_ENET_IEEE_T_MACERR_RD(x) (HW_ENET_IEEE_T_MACERR(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_MACERR bitfields
 */

/*!
 * @name Register ENET_IEEE_T_MACERR, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_T_MACERR_COUNT (0U)   /*!< Bit position for ENET_IEEE_T_MACERR_COUNT. */
#define BM_ENET_IEEE_T_MACERR_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_MACERR_COUNT. */
#define BS_ENET_IEEE_T_MACERR_COUNT (16U)  /*!< Bit field size in bits for ENET_IEEE_T_MACERR_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_MACERR_COUNT field. */
#define BR_ENET_IEEE_T_MACERR_COUNT(x) (HW_ENET_IEEE_T_MACERR(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_CSERR - Frames Transmitted with Carrier Sense Error Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_CSERR - Frames Transmitted with Carrier Sense Error Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_cserr
{
    uint32_t U;
    struct _hw_enet_ieee_t_cserr_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames transmitted with
                                        * carrier sense error */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_cserr_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_CSERR register
 */
/*@{*/
#define HW_ENET_IEEE_T_CSERR_ADDR(x) ((uintptr_t)(x) + 0x268U)

#define HW_ENET_IEEE_T_CSERR(x)  (*(__I hw_enet_ieee_t_cserr_t *) HW_ENET_IEEE_T_CSERR_ADDR(x))
#define HW_ENET_IEEE_T_CSERR_RD(x) (HW_ENET_IEEE_T_CSERR(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_CSERR bitfields
 */

/*!
 * @name Register ENET_IEEE_T_CSERR, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_T_CSERR_COUNT (0U)    /*!< Bit position for ENET_IEEE_T_CSERR_COUNT. */
#define BM_ENET_IEEE_T_CSERR_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_CSERR_COUNT. */
#define BS_ENET_IEEE_T_CSERR_COUNT (16U)   /*!< Bit field size in bits for ENET_IEEE_T_CSERR_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_CSERR_COUNT field. */
#define BR_ENET_IEEE_T_CSERR_COUNT(x) (HW_ENET_IEEE_T_CSERR(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_SQE - Reserved Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_SQE - Reserved Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_sqe
{
    uint32_t U;
    struct _hw_enet_ieee_t_sqe_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_sqe_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_SQE register
 */
/*@{*/
#define HW_ENET_IEEE_T_SQE_ADDR(x) ((uintptr_t)(x) + 0x26CU)

#define HW_ENET_IEEE_T_SQE(x)    (*(__I hw_enet_ieee_t_sqe_t *) HW_ENET_IEEE_T_SQE_ADDR(x))
#define HW_ENET_IEEE_T_SQE_RD(x) (HW_ENET_IEEE_T_SQE(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_SQE bitfields
 */

/*!
 * @name Register ENET_IEEE_T_SQE, field COUNT[15:0] (RO)
 *
 * This read-only field is reserved and always has the value 0. Counter not
 * implemented as no SQE information is available.
 */
/*@{*/
#define BP_ENET_IEEE_T_SQE_COUNT (0U)      /*!< Bit position for ENET_IEEE_T_SQE_COUNT. */
#define BM_ENET_IEEE_T_SQE_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_SQE_COUNT. */
#define BS_ENET_IEEE_T_SQE_COUNT (16U)     /*!< Bit field size in bits for ENET_IEEE_T_SQE_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_SQE_COUNT field. */
#define BR_ENET_IEEE_T_SQE_COUNT(x) (HW_ENET_IEEE_T_SQE(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_FDXFC - Flow Control Pause Frames Transmitted Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_FDXFC - Flow Control Pause Frames Transmitted Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_fdxfc
{
    uint32_t U;
    struct _hw_enet_ieee_t_fdxfc_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of flow-control pause frames
                                        * transmitted */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_t_fdxfc_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_FDXFC register
 */
/*@{*/
#define HW_ENET_IEEE_T_FDXFC_ADDR(x) ((uintptr_t)(x) + 0x270U)

#define HW_ENET_IEEE_T_FDXFC(x)  (*(__I hw_enet_ieee_t_fdxfc_t *) HW_ENET_IEEE_T_FDXFC_ADDR(x))
#define HW_ENET_IEEE_T_FDXFC_RD(x) (HW_ENET_IEEE_T_FDXFC(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_FDXFC bitfields
 */

/*!
 * @name Register ENET_IEEE_T_FDXFC, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_T_FDXFC_COUNT (0U)    /*!< Bit position for ENET_IEEE_T_FDXFC_COUNT. */
#define BM_ENET_IEEE_T_FDXFC_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_T_FDXFC_COUNT. */
#define BS_ENET_IEEE_T_FDXFC_COUNT (16U)   /*!< Bit field size in bits for ENET_IEEE_T_FDXFC_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_FDXFC_COUNT field. */
#define BR_ENET_IEEE_T_FDXFC_COUNT(x) (HW_ENET_IEEE_T_FDXFC(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_T_OCTETS_OK - Octet Count for Frames Transmitted w/o Error Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_T_OCTETS_OK - Octet Count for Frames Transmitted w/o Error Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_t_octets_ok
{
    uint32_t U;
    struct _hw_enet_ieee_t_octets_ok_bitfields
    {
        uint32_t COUNT : 32;           /*!< [31:0] Octet count for frames transmitted
                                        * without error Counts total octets (includes header and FCS fields). */
    } B;
} hw_enet_ieee_t_octets_ok_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_T_OCTETS_OK register
 */
/*@{*/
#define HW_ENET_IEEE_T_OCTETS_OK_ADDR(x) ((uintptr_t)(x) + 0x274U)

#define HW_ENET_IEEE_T_OCTETS_OK(x) (*(__I hw_enet_ieee_t_octets_ok_t *) HW_ENET_IEEE_T_OCTETS_OK_ADDR(x))
#define HW_ENET_IEEE_T_OCTETS_OK_RD(x) (HW_ENET_IEEE_T_OCTETS_OK(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_T_OCTETS_OK bitfields
 */

/*!
 * @name Register ENET_IEEE_T_OCTETS_OK, field COUNT[31:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_T_OCTETS_OK_COUNT (0U) /*!< Bit position for ENET_IEEE_T_OCTETS_OK_COUNT. */
#define BM_ENET_IEEE_T_OCTETS_OK_COUNT (0xFFFFFFFFU) /*!< Bit mask for ENET_IEEE_T_OCTETS_OK_COUNT. */
#define BS_ENET_IEEE_T_OCTETS_OK_COUNT (32U) /*!< Bit field size in bits for ENET_IEEE_T_OCTETS_OK_COUNT. */

/*! @brief Read current value of the ENET_IEEE_T_OCTETS_OK_COUNT field. */
#define BR_ENET_IEEE_T_OCTETS_OK_COUNT(x) (HW_ENET_IEEE_T_OCTETS_OK(x).U)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_PACKETS - Rx Packet Count Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_PACKETS - Rx Packet Count Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_packets
{
    uint32_t U;
    struct _hw_enet_rmon_r_packets_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of packets received */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_packets_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_PACKETS register
 */
/*@{*/
#define HW_ENET_RMON_R_PACKETS_ADDR(x) ((uintptr_t)(x) + 0x284U)

#define HW_ENET_RMON_R_PACKETS(x) (*(__I hw_enet_rmon_r_packets_t *) HW_ENET_RMON_R_PACKETS_ADDR(x))
#define HW_ENET_RMON_R_PACKETS_RD(x) (HW_ENET_RMON_R_PACKETS(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_PACKETS bitfields
 */

/*!
 * @name Register ENET_RMON_R_PACKETS, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_PACKETS_COUNT (0U)  /*!< Bit position for ENET_RMON_R_PACKETS_COUNT. */
#define BM_ENET_RMON_R_PACKETS_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_PACKETS_COUNT. */
#define BS_ENET_RMON_R_PACKETS_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_PACKETS_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_PACKETS_COUNT field. */
#define BR_ENET_RMON_R_PACKETS_COUNT(x) (HW_ENET_RMON_R_PACKETS(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_BC_PKT - Rx Broadcast Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_BC_PKT - Rx Broadcast Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_bc_pkt
{
    uint32_t U;
    struct _hw_enet_rmon_r_bc_pkt_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of receive broadcast packets
                                        * */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_bc_pkt_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_BC_PKT register
 */
/*@{*/
#define HW_ENET_RMON_R_BC_PKT_ADDR(x) ((uintptr_t)(x) + 0x288U)

#define HW_ENET_RMON_R_BC_PKT(x) (*(__I hw_enet_rmon_r_bc_pkt_t *) HW_ENET_RMON_R_BC_PKT_ADDR(x))
#define HW_ENET_RMON_R_BC_PKT_RD(x) (HW_ENET_RMON_R_BC_PKT(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_BC_PKT bitfields
 */

/*!
 * @name Register ENET_RMON_R_BC_PKT, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_BC_PKT_COUNT (0U)   /*!< Bit position for ENET_RMON_R_BC_PKT_COUNT. */
#define BM_ENET_RMON_R_BC_PKT_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_BC_PKT_COUNT. */
#define BS_ENET_RMON_R_BC_PKT_COUNT (16U)  /*!< Bit field size in bits for ENET_RMON_R_BC_PKT_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_BC_PKT_COUNT field. */
#define BR_ENET_RMON_R_BC_PKT_COUNT(x) (HW_ENET_RMON_R_BC_PKT(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_MC_PKT - Rx Multicast Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_MC_PKT - Rx Multicast Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_mc_pkt
{
    uint32_t U;
    struct _hw_enet_rmon_r_mc_pkt_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of receive multicast packets
                                        * */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_mc_pkt_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_MC_PKT register
 */
/*@{*/
#define HW_ENET_RMON_R_MC_PKT_ADDR(x) ((uintptr_t)(x) + 0x28CU)

#define HW_ENET_RMON_R_MC_PKT(x) (*(__I hw_enet_rmon_r_mc_pkt_t *) HW_ENET_RMON_R_MC_PKT_ADDR(x))
#define HW_ENET_RMON_R_MC_PKT_RD(x) (HW_ENET_RMON_R_MC_PKT(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_MC_PKT bitfields
 */

/*!
 * @name Register ENET_RMON_R_MC_PKT, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_MC_PKT_COUNT (0U)   /*!< Bit position for ENET_RMON_R_MC_PKT_COUNT. */
#define BM_ENET_RMON_R_MC_PKT_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_MC_PKT_COUNT. */
#define BS_ENET_RMON_R_MC_PKT_COUNT (16U)  /*!< Bit field size in bits for ENET_RMON_R_MC_PKT_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_MC_PKT_COUNT field. */
#define BR_ENET_RMON_R_MC_PKT_COUNT(x) (HW_ENET_RMON_R_MC_PKT(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_CRC_ALIGN - Rx Packets with CRC/Align Error Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_CRC_ALIGN - Rx Packets with CRC/Align Error Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_crc_align
{
    uint32_t U;
    struct _hw_enet_rmon_r_crc_align_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of receive packets with CRC
                                        * or align error */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_crc_align_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_CRC_ALIGN register
 */
/*@{*/
#define HW_ENET_RMON_R_CRC_ALIGN_ADDR(x) ((uintptr_t)(x) + 0x290U)

#define HW_ENET_RMON_R_CRC_ALIGN(x) (*(__I hw_enet_rmon_r_crc_align_t *) HW_ENET_RMON_R_CRC_ALIGN_ADDR(x))
#define HW_ENET_RMON_R_CRC_ALIGN_RD(x) (HW_ENET_RMON_R_CRC_ALIGN(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_CRC_ALIGN bitfields
 */

/*!
 * @name Register ENET_RMON_R_CRC_ALIGN, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_CRC_ALIGN_COUNT (0U) /*!< Bit position for ENET_RMON_R_CRC_ALIGN_COUNT. */
#define BM_ENET_RMON_R_CRC_ALIGN_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_CRC_ALIGN_COUNT. */
#define BS_ENET_RMON_R_CRC_ALIGN_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_CRC_ALIGN_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_CRC_ALIGN_COUNT field. */
#define BR_ENET_RMON_R_CRC_ALIGN_COUNT(x) (HW_ENET_RMON_R_CRC_ALIGN(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_UNDERSIZE - Rx Packets with Less Than 64 Bytes and Good CRC Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_UNDERSIZE - Rx Packets with Less Than 64 Bytes and Good CRC Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_undersize
{
    uint32_t U;
    struct _hw_enet_rmon_r_undersize_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of receive packets with less
                                        * than 64 bytes and good CRC */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_undersize_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_UNDERSIZE register
 */
/*@{*/
#define HW_ENET_RMON_R_UNDERSIZE_ADDR(x) ((uintptr_t)(x) + 0x294U)

#define HW_ENET_RMON_R_UNDERSIZE(x) (*(__I hw_enet_rmon_r_undersize_t *) HW_ENET_RMON_R_UNDERSIZE_ADDR(x))
#define HW_ENET_RMON_R_UNDERSIZE_RD(x) (HW_ENET_RMON_R_UNDERSIZE(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_UNDERSIZE bitfields
 */

/*!
 * @name Register ENET_RMON_R_UNDERSIZE, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_UNDERSIZE_COUNT (0U) /*!< Bit position for ENET_RMON_R_UNDERSIZE_COUNT. */
#define BM_ENET_RMON_R_UNDERSIZE_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_UNDERSIZE_COUNT. */
#define BS_ENET_RMON_R_UNDERSIZE_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_UNDERSIZE_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_UNDERSIZE_COUNT field. */
#define BR_ENET_RMON_R_UNDERSIZE_COUNT(x) (HW_ENET_RMON_R_UNDERSIZE(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_OVERSIZE - Rx Packets Greater Than MAX_FL and Good CRC Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_OVERSIZE - Rx Packets Greater Than MAX_FL and Good CRC Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_oversize
{
    uint32_t U;
    struct _hw_enet_rmon_r_oversize_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of receive packets greater
                                        * than MAX_FL and good CRC */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_oversize_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_OVERSIZE register
 */
/*@{*/
#define HW_ENET_RMON_R_OVERSIZE_ADDR(x) ((uintptr_t)(x) + 0x298U)

#define HW_ENET_RMON_R_OVERSIZE(x) (*(__I hw_enet_rmon_r_oversize_t *) HW_ENET_RMON_R_OVERSIZE_ADDR(x))
#define HW_ENET_RMON_R_OVERSIZE_RD(x) (HW_ENET_RMON_R_OVERSIZE(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_OVERSIZE bitfields
 */

/*!
 * @name Register ENET_RMON_R_OVERSIZE, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_OVERSIZE_COUNT (0U) /*!< Bit position for ENET_RMON_R_OVERSIZE_COUNT. */
#define BM_ENET_RMON_R_OVERSIZE_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_OVERSIZE_COUNT. */
#define BS_ENET_RMON_R_OVERSIZE_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_OVERSIZE_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_OVERSIZE_COUNT field. */
#define BR_ENET_RMON_R_OVERSIZE_COUNT(x) (HW_ENET_RMON_R_OVERSIZE(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_FRAG - Rx Packets Less Than 64 Bytes and Bad CRC Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_FRAG - Rx Packets Less Than 64 Bytes and Bad CRC Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_frag
{
    uint32_t U;
    struct _hw_enet_rmon_r_frag_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of receive packets with less
                                        * than 64 bytes and bad CRC */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_frag_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_FRAG register
 */
/*@{*/
#define HW_ENET_RMON_R_FRAG_ADDR(x) ((uintptr_t)(x) + 0x29CU)

#define HW_ENET_RMON_R_FRAG(x)   (*(__I hw_enet_rmon_r_frag_t *) HW_ENET_RMON_R_FRAG_ADDR(x))
#define HW_ENET_RMON_R_FRAG_RD(x) (HW_ENET_RMON_R_FRAG(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_FRAG bitfields
 */

/*!
 * @name Register ENET_RMON_R_FRAG, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_FRAG_COUNT (0U)     /*!< Bit position for ENET_RMON_R_FRAG_COUNT. */
#define BM_ENET_RMON_R_FRAG_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_FRAG_COUNT. */
#define BS_ENET_RMON_R_FRAG_COUNT (16U)    /*!< Bit field size in bits for ENET_RMON_R_FRAG_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_FRAG_COUNT field. */
#define BR_ENET_RMON_R_FRAG_COUNT(x) (HW_ENET_RMON_R_FRAG(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_JAB - Rx Packets Greater Than MAX_FL Bytes and Bad CRC Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_JAB - Rx Packets Greater Than MAX_FL Bytes and Bad CRC Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_jab
{
    uint32_t U;
    struct _hw_enet_rmon_r_jab_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of receive packets greater
                                        * than MAX_FL and bad CRC */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_jab_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_JAB register
 */
/*@{*/
#define HW_ENET_RMON_R_JAB_ADDR(x) ((uintptr_t)(x) + 0x2A0U)

#define HW_ENET_RMON_R_JAB(x)    (*(__I hw_enet_rmon_r_jab_t *) HW_ENET_RMON_R_JAB_ADDR(x))
#define HW_ENET_RMON_R_JAB_RD(x) (HW_ENET_RMON_R_JAB(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_JAB bitfields
 */

/*!
 * @name Register ENET_RMON_R_JAB, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_JAB_COUNT (0U)      /*!< Bit position for ENET_RMON_R_JAB_COUNT. */
#define BM_ENET_RMON_R_JAB_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_JAB_COUNT. */
#define BS_ENET_RMON_R_JAB_COUNT (16U)     /*!< Bit field size in bits for ENET_RMON_R_JAB_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_JAB_COUNT field. */
#define BR_ENET_RMON_R_JAB_COUNT(x) (HW_ENET_RMON_R_JAB(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_RESVD_0 - Reserved Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_RESVD_0 - Reserved Statistic Register (ROZ)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_resvd_0
{
    uint32_t U;
    struct _hw_enet_rmon_r_resvd_0_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_enet_rmon_r_resvd_0_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_RESVD_0 register
 */
/*@{*/
#define HW_ENET_RMON_R_RESVD_0_ADDR(x) ((uintptr_t)(x) + 0x2A4U)

#define HW_ENET_RMON_R_RESVD_0(x) (*(__I hw_enet_rmon_r_resvd_0_t *) HW_ENET_RMON_R_RESVD_0_ADDR(x))
#define HW_ENET_RMON_R_RESVD_0_RD(x) (HW_ENET_RMON_R_RESVD_0(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_RESVD_0 bitfields
 */

/*******************************************************************************
 * HW_ENET_RMON_R_P64 - Rx 64-Byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_P64 - Rx 64-Byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_p64
{
    uint32_t U;
    struct _hw_enet_rmon_r_p64_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of 64-byte receive packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_p64_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_P64 register
 */
/*@{*/
#define HW_ENET_RMON_R_P64_ADDR(x) ((uintptr_t)(x) + 0x2A8U)

#define HW_ENET_RMON_R_P64(x)    (*(__I hw_enet_rmon_r_p64_t *) HW_ENET_RMON_R_P64_ADDR(x))
#define HW_ENET_RMON_R_P64_RD(x) (HW_ENET_RMON_R_P64(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_P64 bitfields
 */

/*!
 * @name Register ENET_RMON_R_P64, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_P64_COUNT (0U)      /*!< Bit position for ENET_RMON_R_P64_COUNT. */
#define BM_ENET_RMON_R_P64_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_P64_COUNT. */
#define BS_ENET_RMON_R_P64_COUNT (16U)     /*!< Bit field size in bits for ENET_RMON_R_P64_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_P64_COUNT field. */
#define BR_ENET_RMON_R_P64_COUNT(x) (HW_ENET_RMON_R_P64(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_P65TO127 - Rx 65- to 127-Byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_P65TO127 - Rx 65- to 127-Byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_p65to127
{
    uint32_t U;
    struct _hw_enet_rmon_r_p65to127_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of 65- to 127-byte recieve
                                        * packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_p65to127_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_P65TO127 register
 */
/*@{*/
#define HW_ENET_RMON_R_P65TO127_ADDR(x) ((uintptr_t)(x) + 0x2ACU)

#define HW_ENET_RMON_R_P65TO127(x) (*(__I hw_enet_rmon_r_p65to127_t *) HW_ENET_RMON_R_P65TO127_ADDR(x))
#define HW_ENET_RMON_R_P65TO127_RD(x) (HW_ENET_RMON_R_P65TO127(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_P65TO127 bitfields
 */

/*!
 * @name Register ENET_RMON_R_P65TO127, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_P65TO127_COUNT (0U) /*!< Bit position for ENET_RMON_R_P65TO127_COUNT. */
#define BM_ENET_RMON_R_P65TO127_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_P65TO127_COUNT. */
#define BS_ENET_RMON_R_P65TO127_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_P65TO127_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_P65TO127_COUNT field. */
#define BR_ENET_RMON_R_P65TO127_COUNT(x) (HW_ENET_RMON_R_P65TO127(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_P128TO255 - Rx 128- to 255-Byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_P128TO255 - Rx 128- to 255-Byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_p128to255
{
    uint32_t U;
    struct _hw_enet_rmon_r_p128to255_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of 128- to 255-byte recieve
                                        * packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_p128to255_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_P128TO255 register
 */
/*@{*/
#define HW_ENET_RMON_R_P128TO255_ADDR(x) ((uintptr_t)(x) + 0x2B0U)

#define HW_ENET_RMON_R_P128TO255(x) (*(__I hw_enet_rmon_r_p128to255_t *) HW_ENET_RMON_R_P128TO255_ADDR(x))
#define HW_ENET_RMON_R_P128TO255_RD(x) (HW_ENET_RMON_R_P128TO255(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_P128TO255 bitfields
 */

/*!
 * @name Register ENET_RMON_R_P128TO255, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_P128TO255_COUNT (0U) /*!< Bit position for ENET_RMON_R_P128TO255_COUNT. */
#define BM_ENET_RMON_R_P128TO255_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_P128TO255_COUNT. */
#define BS_ENET_RMON_R_P128TO255_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_P128TO255_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_P128TO255_COUNT field. */
#define BR_ENET_RMON_R_P128TO255_COUNT(x) (HW_ENET_RMON_R_P128TO255(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_P256TO511 - Rx 256- to 511-Byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_P256TO511 - Rx 256- to 511-Byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_p256to511
{
    uint32_t U;
    struct _hw_enet_rmon_r_p256to511_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of 256- to 511-byte recieve
                                        * packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_p256to511_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_P256TO511 register
 */
/*@{*/
#define HW_ENET_RMON_R_P256TO511_ADDR(x) ((uintptr_t)(x) + 0x2B4U)

#define HW_ENET_RMON_R_P256TO511(x) (*(__I hw_enet_rmon_r_p256to511_t *) HW_ENET_RMON_R_P256TO511_ADDR(x))
#define HW_ENET_RMON_R_P256TO511_RD(x) (HW_ENET_RMON_R_P256TO511(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_P256TO511 bitfields
 */

/*!
 * @name Register ENET_RMON_R_P256TO511, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_P256TO511_COUNT (0U) /*!< Bit position for ENET_RMON_R_P256TO511_COUNT. */
#define BM_ENET_RMON_R_P256TO511_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_P256TO511_COUNT. */
#define BS_ENET_RMON_R_P256TO511_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_P256TO511_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_P256TO511_COUNT field. */
#define BR_ENET_RMON_R_P256TO511_COUNT(x) (HW_ENET_RMON_R_P256TO511(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_P512TO1023 - Rx 512- to 1023-Byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_P512TO1023 - Rx 512- to 1023-Byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_p512to1023
{
    uint32_t U;
    struct _hw_enet_rmon_r_p512to1023_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of 512- to 1023-byte recieve
                                        * packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_p512to1023_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_P512TO1023 register
 */
/*@{*/
#define HW_ENET_RMON_R_P512TO1023_ADDR(x) ((uintptr_t)(x) + 0x2B8U)

#define HW_ENET_RMON_R_P512TO1023(x) (*(__I hw_enet_rmon_r_p512to1023_t *) HW_ENET_RMON_R_P512TO1023_ADDR(x))
#define HW_ENET_RMON_R_P512TO1023_RD(x) (HW_ENET_RMON_R_P512TO1023(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_P512TO1023 bitfields
 */

/*!
 * @name Register ENET_RMON_R_P512TO1023, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_P512TO1023_COUNT (0U) /*!< Bit position for ENET_RMON_R_P512TO1023_COUNT. */
#define BM_ENET_RMON_R_P512TO1023_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_P512TO1023_COUNT. */
#define BS_ENET_RMON_R_P512TO1023_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_P512TO1023_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_P512TO1023_COUNT field. */
#define BR_ENET_RMON_R_P512TO1023_COUNT(x) (HW_ENET_RMON_R_P512TO1023(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_P1024TO2047 - Rx 1024- to 2047-Byte Packets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_P1024TO2047 - Rx 1024- to 2047-Byte Packets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_p1024to2047
{
    uint32_t U;
    struct _hw_enet_rmon_r_p1024to2047_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of 1024- to 2047-byte recieve
                                        * packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_p1024to2047_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_P1024TO2047 register
 */
/*@{*/
#define HW_ENET_RMON_R_P1024TO2047_ADDR(x) ((uintptr_t)(x) + 0x2BCU)

#define HW_ENET_RMON_R_P1024TO2047(x) (*(__I hw_enet_rmon_r_p1024to2047_t *) HW_ENET_RMON_R_P1024TO2047_ADDR(x))
#define HW_ENET_RMON_R_P1024TO2047_RD(x) (HW_ENET_RMON_R_P1024TO2047(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_P1024TO2047 bitfields
 */

/*!
 * @name Register ENET_RMON_R_P1024TO2047, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_P1024TO2047_COUNT (0U) /*!< Bit position for ENET_RMON_R_P1024TO2047_COUNT. */
#define BM_ENET_RMON_R_P1024TO2047_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_P1024TO2047_COUNT. */
#define BS_ENET_RMON_R_P1024TO2047_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_P1024TO2047_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_P1024TO2047_COUNT field. */
#define BR_ENET_RMON_R_P1024TO2047_COUNT(x) (HW_ENET_RMON_R_P1024TO2047(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_P_GTE2048 - Rx Packets Greater than 2048 Bytes Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_P_GTE2048 - Rx Packets Greater than 2048 Bytes Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_p_gte2048
{
    uint32_t U;
    struct _hw_enet_rmon_r_p_gte2048_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of greater-than-2048-byte
                                        * recieve packets */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_rmon_r_p_gte2048_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_P_GTE2048 register
 */
/*@{*/
#define HW_ENET_RMON_R_P_GTE2048_ADDR(x) ((uintptr_t)(x) + 0x2C0U)

#define HW_ENET_RMON_R_P_GTE2048(x) (*(__I hw_enet_rmon_r_p_gte2048_t *) HW_ENET_RMON_R_P_GTE2048_ADDR(x))
#define HW_ENET_RMON_R_P_GTE2048_RD(x) (HW_ENET_RMON_R_P_GTE2048(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_P_GTE2048 bitfields
 */

/*!
 * @name Register ENET_RMON_R_P_GTE2048, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_P_GTE2048_COUNT (0U) /*!< Bit position for ENET_RMON_R_P_GTE2048_COUNT. */
#define BM_ENET_RMON_R_P_GTE2048_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_RMON_R_P_GTE2048_COUNT. */
#define BS_ENET_RMON_R_P_GTE2048_COUNT (16U) /*!< Bit field size in bits for ENET_RMON_R_P_GTE2048_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_P_GTE2048_COUNT field. */
#define BR_ENET_RMON_R_P_GTE2048_COUNT(x) (HW_ENET_RMON_R_P_GTE2048(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_RMON_R_OCTETS - Rx Octets Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_RMON_R_OCTETS - Rx Octets Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_rmon_r_octets
{
    uint32_t U;
    struct _hw_enet_rmon_r_octets_bitfields
    {
        uint32_t COUNT : 32;           /*!< [31:0] Number of receive octets */
    } B;
} hw_enet_rmon_r_octets_t;

/*!
 * @name Constants and macros for entire ENET_RMON_R_OCTETS register
 */
/*@{*/
#define HW_ENET_RMON_R_OCTETS_ADDR(x) ((uintptr_t)(x) + 0x2C4U)

#define HW_ENET_RMON_R_OCTETS(x) (*(__I hw_enet_rmon_r_octets_t *) HW_ENET_RMON_R_OCTETS_ADDR(x))
#define HW_ENET_RMON_R_OCTETS_RD(x) (HW_ENET_RMON_R_OCTETS(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_RMON_R_OCTETS bitfields
 */

/*!
 * @name Register ENET_RMON_R_OCTETS, field COUNT[31:0] (RO)
 */
/*@{*/
#define BP_ENET_RMON_R_OCTETS_COUNT (0U)   /*!< Bit position for ENET_RMON_R_OCTETS_COUNT. */
#define BM_ENET_RMON_R_OCTETS_COUNT (0xFFFFFFFFU) /*!< Bit mask for ENET_RMON_R_OCTETS_COUNT. */
#define BS_ENET_RMON_R_OCTETS_COUNT (32U)  /*!< Bit field size in bits for ENET_RMON_R_OCTETS_COUNT. */

/*! @brief Read current value of the ENET_RMON_R_OCTETS_COUNT field. */
#define BR_ENET_RMON_R_OCTETS_COUNT(x) (HW_ENET_RMON_R_OCTETS(x).U)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_R_DROP - Frames not Counted Correctly Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_R_DROP - Frames not Counted Correctly Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * Counter increments if a frame with invalid or missing SFD character is
 * detected and has been dropped. None of the other counters increments if this counter
 * increments.
 */
typedef union _hw_enet_ieee_r_drop
{
    uint32_t U;
    struct _hw_enet_ieee_r_drop_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Frame count */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_r_drop_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_R_DROP register
 */
/*@{*/
#define HW_ENET_IEEE_R_DROP_ADDR(x) ((uintptr_t)(x) + 0x2C8U)

#define HW_ENET_IEEE_R_DROP(x)   (*(__I hw_enet_ieee_r_drop_t *) HW_ENET_IEEE_R_DROP_ADDR(x))
#define HW_ENET_IEEE_R_DROP_RD(x) (HW_ENET_IEEE_R_DROP(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_R_DROP bitfields
 */

/*!
 * @name Register ENET_IEEE_R_DROP, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_R_DROP_COUNT (0U)     /*!< Bit position for ENET_IEEE_R_DROP_COUNT. */
#define BM_ENET_IEEE_R_DROP_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_R_DROP_COUNT. */
#define BS_ENET_IEEE_R_DROP_COUNT (16U)    /*!< Bit field size in bits for ENET_IEEE_R_DROP_COUNT. */

/*! @brief Read current value of the ENET_IEEE_R_DROP_COUNT field. */
#define BR_ENET_IEEE_R_DROP_COUNT(x) (HW_ENET_IEEE_R_DROP(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_R_FRAME_OK - Frames Received OK Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_R_FRAME_OK - Frames Received OK Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_r_frame_ok
{
    uint32_t U;
    struct _hw_enet_ieee_r_frame_ok_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames received OK */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_r_frame_ok_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_R_FRAME_OK register
 */
/*@{*/
#define HW_ENET_IEEE_R_FRAME_OK_ADDR(x) ((uintptr_t)(x) + 0x2CCU)

#define HW_ENET_IEEE_R_FRAME_OK(x) (*(__I hw_enet_ieee_r_frame_ok_t *) HW_ENET_IEEE_R_FRAME_OK_ADDR(x))
#define HW_ENET_IEEE_R_FRAME_OK_RD(x) (HW_ENET_IEEE_R_FRAME_OK(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_R_FRAME_OK bitfields
 */

/*!
 * @name Register ENET_IEEE_R_FRAME_OK, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_R_FRAME_OK_COUNT (0U) /*!< Bit position for ENET_IEEE_R_FRAME_OK_COUNT. */
#define BM_ENET_IEEE_R_FRAME_OK_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_R_FRAME_OK_COUNT. */
#define BS_ENET_IEEE_R_FRAME_OK_COUNT (16U) /*!< Bit field size in bits for ENET_IEEE_R_FRAME_OK_COUNT. */

/*! @brief Read current value of the ENET_IEEE_R_FRAME_OK_COUNT field. */
#define BR_ENET_IEEE_R_FRAME_OK_COUNT(x) (HW_ENET_IEEE_R_FRAME_OK(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_R_CRC - Frames Received with CRC Error Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_R_CRC - Frames Received with CRC Error Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_r_crc
{
    uint32_t U;
    struct _hw_enet_ieee_r_crc_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames received with CRC
                                        * error */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_r_crc_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_R_CRC register
 */
/*@{*/
#define HW_ENET_IEEE_R_CRC_ADDR(x) ((uintptr_t)(x) + 0x2D0U)

#define HW_ENET_IEEE_R_CRC(x)    (*(__I hw_enet_ieee_r_crc_t *) HW_ENET_IEEE_R_CRC_ADDR(x))
#define HW_ENET_IEEE_R_CRC_RD(x) (HW_ENET_IEEE_R_CRC(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_R_CRC bitfields
 */

/*!
 * @name Register ENET_IEEE_R_CRC, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_R_CRC_COUNT (0U)      /*!< Bit position for ENET_IEEE_R_CRC_COUNT. */
#define BM_ENET_IEEE_R_CRC_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_R_CRC_COUNT. */
#define BS_ENET_IEEE_R_CRC_COUNT (16U)     /*!< Bit field size in bits for ENET_IEEE_R_CRC_COUNT. */

/*! @brief Read current value of the ENET_IEEE_R_CRC_COUNT field. */
#define BR_ENET_IEEE_R_CRC_COUNT(x) (HW_ENET_IEEE_R_CRC(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_R_ALIGN - Frames Received with Alignment Error Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_R_ALIGN - Frames Received with Alignment Error Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_r_align
{
    uint32_t U;
    struct _hw_enet_ieee_r_align_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of frames received with
                                        * alignment error */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_r_align_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_R_ALIGN register
 */
/*@{*/
#define HW_ENET_IEEE_R_ALIGN_ADDR(x) ((uintptr_t)(x) + 0x2D4U)

#define HW_ENET_IEEE_R_ALIGN(x)  (*(__I hw_enet_ieee_r_align_t *) HW_ENET_IEEE_R_ALIGN_ADDR(x))
#define HW_ENET_IEEE_R_ALIGN_RD(x) (HW_ENET_IEEE_R_ALIGN(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_R_ALIGN bitfields
 */

/*!
 * @name Register ENET_IEEE_R_ALIGN, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_R_ALIGN_COUNT (0U)    /*!< Bit position for ENET_IEEE_R_ALIGN_COUNT. */
#define BM_ENET_IEEE_R_ALIGN_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_R_ALIGN_COUNT. */
#define BS_ENET_IEEE_R_ALIGN_COUNT (16U)   /*!< Bit field size in bits for ENET_IEEE_R_ALIGN_COUNT. */

/*! @brief Read current value of the ENET_IEEE_R_ALIGN_COUNT field. */
#define BR_ENET_IEEE_R_ALIGN_COUNT(x) (HW_ENET_IEEE_R_ALIGN(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_R_MACERR - Receive FIFO Overflow Count Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_R_MACERR - Receive FIFO Overflow Count Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_r_macerr
{
    uint32_t U;
    struct _hw_enet_ieee_r_macerr_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Receive FIFO overflow count */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_r_macerr_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_R_MACERR register
 */
/*@{*/
#define HW_ENET_IEEE_R_MACERR_ADDR(x) ((uintptr_t)(x) + 0x2D8U)

#define HW_ENET_IEEE_R_MACERR(x) (*(__I hw_enet_ieee_r_macerr_t *) HW_ENET_IEEE_R_MACERR_ADDR(x))
#define HW_ENET_IEEE_R_MACERR_RD(x) (HW_ENET_IEEE_R_MACERR(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_R_MACERR bitfields
 */

/*!
 * @name Register ENET_IEEE_R_MACERR, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_R_MACERR_COUNT (0U)   /*!< Bit position for ENET_IEEE_R_MACERR_COUNT. */
#define BM_ENET_IEEE_R_MACERR_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_R_MACERR_COUNT. */
#define BS_ENET_IEEE_R_MACERR_COUNT (16U)  /*!< Bit field size in bits for ENET_IEEE_R_MACERR_COUNT. */

/*! @brief Read current value of the ENET_IEEE_R_MACERR_COUNT field. */
#define BR_ENET_IEEE_R_MACERR_COUNT(x) (HW_ENET_IEEE_R_MACERR(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_R_FDXFC - Flow Control Pause Frames Received Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_R_FDXFC - Flow Control Pause Frames Received Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_r_fdxfc
{
    uint32_t U;
    struct _hw_enet_ieee_r_fdxfc_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Number of flow-control pause frames
                                        * received */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_enet_ieee_r_fdxfc_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_R_FDXFC register
 */
/*@{*/
#define HW_ENET_IEEE_R_FDXFC_ADDR(x) ((uintptr_t)(x) + 0x2DCU)

#define HW_ENET_IEEE_R_FDXFC(x)  (*(__I hw_enet_ieee_r_fdxfc_t *) HW_ENET_IEEE_R_FDXFC_ADDR(x))
#define HW_ENET_IEEE_R_FDXFC_RD(x) (HW_ENET_IEEE_R_FDXFC(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_R_FDXFC bitfields
 */

/*!
 * @name Register ENET_IEEE_R_FDXFC, field COUNT[15:0] (RO)
 */
/*@{*/
#define BP_ENET_IEEE_R_FDXFC_COUNT (0U)    /*!< Bit position for ENET_IEEE_R_FDXFC_COUNT. */
#define BM_ENET_IEEE_R_FDXFC_COUNT (0x0000FFFFU) /*!< Bit mask for ENET_IEEE_R_FDXFC_COUNT. */
#define BS_ENET_IEEE_R_FDXFC_COUNT (16U)   /*!< Bit field size in bits for ENET_IEEE_R_FDXFC_COUNT. */

/*! @brief Read current value of the ENET_IEEE_R_FDXFC_COUNT field. */
#define BR_ENET_IEEE_R_FDXFC_COUNT(x) (HW_ENET_IEEE_R_FDXFC(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * HW_ENET_IEEE_R_OCTETS_OK - Octet Count for Frames Received without Error Statistic Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_IEEE_R_OCTETS_OK - Octet Count for Frames Received without Error Statistic Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_ieee_r_octets_ok
{
    uint32_t U;
    struct _hw_enet_ieee_r_octets_ok_bitfields
    {
        uint32_t COUNT : 32;           /*!< [31:0] Number of octets for frames received
                                        * without error */
    } B;
} hw_enet_ieee_r_octets_ok_t;

/*!
 * @name Constants and macros for entire ENET_IEEE_R_OCTETS_OK register
 */
/*@{*/
#define HW_ENET_IEEE_R_OCTETS_OK_ADDR(x) ((uintptr_t)(x) + 0x2E0U)

#define HW_ENET_IEEE_R_OCTETS_OK(x) (*(__I hw_enet_ieee_r_octets_ok_t *) HW_ENET_IEEE_R_OCTETS_OK_ADDR(x))
#define HW_ENET_IEEE_R_OCTETS_OK_RD(x) (HW_ENET_IEEE_R_OCTETS_OK(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_IEEE_R_OCTETS_OK bitfields
 */

/*!
 * @name Register ENET_IEEE_R_OCTETS_OK, field COUNT[31:0] (RO)
 *
 * Counts total octets (includes header and FCS fields). Does not increment for
 * the broadcast frames when broadcast reject is enabled and promiscuous mode is
 * disabled within the receive control register (RCR).
 */
/*@{*/
#define BP_ENET_IEEE_R_OCTETS_OK_COUNT (0U) /*!< Bit position for ENET_IEEE_R_OCTETS_OK_COUNT. */
#define BM_ENET_IEEE_R_OCTETS_OK_COUNT (0xFFFFFFFFU) /*!< Bit mask for ENET_IEEE_R_OCTETS_OK_COUNT. */
#define BS_ENET_IEEE_R_OCTETS_OK_COUNT (32U) /*!< Bit field size in bits for ENET_IEEE_R_OCTETS_OK_COUNT. */

/*! @brief Read current value of the ENET_IEEE_R_OCTETS_OK_COUNT field. */
#define BR_ENET_IEEE_R_OCTETS_OK_COUNT(x) (HW_ENET_IEEE_R_OCTETS_OK(x).U)
/*@}*/

/*******************************************************************************
 * HW_ENET_ATCR - Adjustable Timer Control Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_ATCR - Adjustable Timer Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * ATCR command fields can trigger the corresponding events directly. It is not
 * necessary to preserve any of the configuration fields when a command field is
 * set in the register, that is, no read-modify-write is required.
 */
typedef union _hw_enet_atcr
{
    uint32_t U;
    struct _hw_enet_atcr_bitfields
    {
        uint32_t EN : 1;               /*!< [0] Enable Timer */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t OFFEN : 1;            /*!< [2] Enable One-Shot Offset Event */
        uint32_t OFFRST : 1;           /*!< [3] Reset Timer On Offset Event */
        uint32_t PEREN : 1;            /*!< [4] Enable Periodical Event */
        uint32_t RESERVED1 : 2;        /*!< [6:5]  */
        uint32_t PINPER : 1;           /*!< [7]  */
        uint32_t RESERVED2 : 1;        /*!< [8]  */
        uint32_t RESTART : 1;          /*!< [9] Reset Timer */
        uint32_t RESERVED3 : 1;        /*!< [10]  */
        uint32_t CAPTURE : 1;          /*!< [11] Capture Timer Value */
        uint32_t RESERVED4 : 1;        /*!< [12]  */
        uint32_t SLAVE : 1;            /*!< [13] Enable Timer Slave Mode */
        uint32_t RESERVED5 : 18;       /*!< [31:14]  */
    } B;
} hw_enet_atcr_t;

/*!
 * @name Constants and macros for entire ENET_ATCR register
 */
/*@{*/
#define HW_ENET_ATCR_ADDR(x)     ((uintptr_t)(x) + 0x400U)

#define HW_ENET_ATCR(x)          (*(__IO hw_enet_atcr_t *) HW_ENET_ATCR_ADDR(x))
#define HW_ENET_ATCR_RD(x)       (HW_ENET_ATCR(x).U)
#define HW_ENET_ATCR_WR(x, v)    (HW_ENET_ATCR(x).U = (v))
#define HW_ENET_ATCR_SET(x, v)   (HW_ENET_ATCR_WR(x, HW_ENET_ATCR_RD(x) |  (v)))
#define HW_ENET_ATCR_CLR(x, v)   (HW_ENET_ATCR_WR(x, HW_ENET_ATCR_RD(x) & ~(v)))
#define HW_ENET_ATCR_TOG(x, v)   (HW_ENET_ATCR_WR(x, HW_ENET_ATCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_ATCR bitfields
 */

/*!
 * @name Register ENET_ATCR, field EN[0] (RW)
 *
 * Values:
 * - 0 - The timer stops at the current value.
 * - 1 - The timer starts incrementing.
 */
/*@{*/
#define BP_ENET_ATCR_EN      (0U)          /*!< Bit position for ENET_ATCR_EN. */
#define BM_ENET_ATCR_EN      (0x00000001U) /*!< Bit mask for ENET_ATCR_EN. */
#define BS_ENET_ATCR_EN      (1U)          /*!< Bit field size in bits for ENET_ATCR_EN. */

/*! @brief Read current value of the ENET_ATCR_EN field. */
#define BR_ENET_ATCR_EN(x)   (HW_ENET_ATCR(x).B.EN)

/*! @brief Format value for bitfield ENET_ATCR_EN. */
#define BF_ENET_ATCR_EN(v)   ((uint32_t)((uint32_t)(v) << BP_ENET_ATCR_EN) & BM_ENET_ATCR_EN)

/*! @brief Set the EN field to a new value. */
#define BW_ENET_ATCR_EN(x, v) (HW_ENET_ATCR_WR(x, (HW_ENET_ATCR_RD(x) & ~BM_ENET_ATCR_EN) | BF_ENET_ATCR_EN(v)))
/*@}*/

/*!
 * @name Register ENET_ATCR, field OFFEN[2] (RW)
 *
 * Values:
 * - 0 - Disable.
 * - 1 - The timer can be reset to zero when the given offset time is reached
 *     (offset event). The field is cleared when the offset event is reached, so no
 *     further event occurs until the field is set again. The timer offset value
 *     must be set before setting this field.
 */
/*@{*/
#define BP_ENET_ATCR_OFFEN   (2U)          /*!< Bit position for ENET_ATCR_OFFEN. */
#define BM_ENET_ATCR_OFFEN   (0x00000004U) /*!< Bit mask for ENET_ATCR_OFFEN. */
#define BS_ENET_ATCR_OFFEN   (1U)          /*!< Bit field size in bits for ENET_ATCR_OFFEN. */

/*! @brief Read current value of the ENET_ATCR_OFFEN field. */
#define BR_ENET_ATCR_OFFEN(x) (HW_ENET_ATCR(x).B.OFFEN)

/*! @brief Format value for bitfield ENET_ATCR_OFFEN. */
#define BF_ENET_ATCR_OFFEN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATCR_OFFEN) & BM_ENET_ATCR_OFFEN)

/*! @brief Set the OFFEN field to a new value. */
#define BW_ENET_ATCR_OFFEN(x, v) (HW_ENET_ATCR_WR(x, (HW_ENET_ATCR_RD(x) & ~BM_ENET_ATCR_OFFEN) | BF_ENET_ATCR_OFFEN(v)))
/*@}*/

/*!
 * @name Register ENET_ATCR, field OFFRST[3] (RW)
 *
 * Values:
 * - 0 - The timer is not affected and no action occurs, besides clearing OFFEN,
 *     when the offset is reached.
 * - 1 - If OFFEN is set, the timer resets to zero when the offset setting is
 *     reached. The offset event does not cause a timer interrupt.
 */
/*@{*/
#define BP_ENET_ATCR_OFFRST  (3U)          /*!< Bit position for ENET_ATCR_OFFRST. */
#define BM_ENET_ATCR_OFFRST  (0x00000008U) /*!< Bit mask for ENET_ATCR_OFFRST. */
#define BS_ENET_ATCR_OFFRST  (1U)          /*!< Bit field size in bits for ENET_ATCR_OFFRST. */

/*! @brief Read current value of the ENET_ATCR_OFFRST field. */
#define BR_ENET_ATCR_OFFRST(x) (HW_ENET_ATCR(x).B.OFFRST)

/*! @brief Format value for bitfield ENET_ATCR_OFFRST. */
#define BF_ENET_ATCR_OFFRST(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATCR_OFFRST) & BM_ENET_ATCR_OFFRST)

/*! @brief Set the OFFRST field to a new value. */
#define BW_ENET_ATCR_OFFRST(x, v) (HW_ENET_ATCR_WR(x, (HW_ENET_ATCR_RD(x) & ~BM_ENET_ATCR_OFFRST) | BF_ENET_ATCR_OFFRST(v)))
/*@}*/

/*!
 * @name Register ENET_ATCR, field PEREN[4] (RW)
 *
 * Values:
 * - 0 - Disable.
 * - 1 - A period event interrupt can be generated (EIR[TS_TIMER]) and the event
 *     signal output is asserted when the timer wraps around according to the
 *     periodic setting ATPER. The timer period value must be set before setting
 *     this bit. Not all devices contain the event signal output. See the chip
 *     configuration details.
 */
/*@{*/
#define BP_ENET_ATCR_PEREN   (4U)          /*!< Bit position for ENET_ATCR_PEREN. */
#define BM_ENET_ATCR_PEREN   (0x00000010U) /*!< Bit mask for ENET_ATCR_PEREN. */
#define BS_ENET_ATCR_PEREN   (1U)          /*!< Bit field size in bits for ENET_ATCR_PEREN. */

/*! @brief Read current value of the ENET_ATCR_PEREN field. */
#define BR_ENET_ATCR_PEREN(x) (HW_ENET_ATCR(x).B.PEREN)

/*! @brief Format value for bitfield ENET_ATCR_PEREN. */
#define BF_ENET_ATCR_PEREN(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATCR_PEREN) & BM_ENET_ATCR_PEREN)

/*! @brief Set the PEREN field to a new value. */
#define BW_ENET_ATCR_PEREN(x, v) (HW_ENET_ATCR_WR(x, (HW_ENET_ATCR_RD(x) & ~BM_ENET_ATCR_PEREN) | BF_ENET_ATCR_PEREN(v)))
/*@}*/

/*!
 * @name Register ENET_ATCR, field PINPER[7] (RW)
 *
 * Enables event signal output assertion on period event. Not all devices
 * contain the event signal output. See the chip configuration details.
 *
 * Values:
 * - 0 - Disable.
 * - 1 - Enable.
 */
/*@{*/
#define BP_ENET_ATCR_PINPER  (7U)          /*!< Bit position for ENET_ATCR_PINPER. */
#define BM_ENET_ATCR_PINPER  (0x00000080U) /*!< Bit mask for ENET_ATCR_PINPER. */
#define BS_ENET_ATCR_PINPER  (1U)          /*!< Bit field size in bits for ENET_ATCR_PINPER. */

/*! @brief Read current value of the ENET_ATCR_PINPER field. */
#define BR_ENET_ATCR_PINPER(x) (HW_ENET_ATCR(x).B.PINPER)

/*! @brief Format value for bitfield ENET_ATCR_PINPER. */
#define BF_ENET_ATCR_PINPER(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATCR_PINPER) & BM_ENET_ATCR_PINPER)

/*! @brief Set the PINPER field to a new value. */
#define BW_ENET_ATCR_PINPER(x, v) (HW_ENET_ATCR_WR(x, (HW_ENET_ATCR_RD(x) & ~BM_ENET_ATCR_PINPER) | BF_ENET_ATCR_PINPER(v)))
/*@}*/

/*!
 * @name Register ENET_ATCR, field RESTART[9] (RW)
 *
 * Resets the timer to zero. This has no effect on the counter enable. If the
 * counter is enabled when this field is set, the timer is reset to zero and starts
 * counting from there. When set, all other fields are ignored during a write.
 * This field automatically clears to 0 after the command completes. The Reset
 * Timer command requires at least 6 clock cycles of either the register clock or
 * the 1588/timestamp clock, whichever is greater, to complete.
 */
/*@{*/
#define BP_ENET_ATCR_RESTART (9U)          /*!< Bit position for ENET_ATCR_RESTART. */
#define BM_ENET_ATCR_RESTART (0x00000200U) /*!< Bit mask for ENET_ATCR_RESTART. */
#define BS_ENET_ATCR_RESTART (1U)          /*!< Bit field size in bits for ENET_ATCR_RESTART. */

/*! @brief Read current value of the ENET_ATCR_RESTART field. */
#define BR_ENET_ATCR_RESTART(x) (HW_ENET_ATCR(x).B.RESTART)

/*! @brief Format value for bitfield ENET_ATCR_RESTART. */
#define BF_ENET_ATCR_RESTART(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATCR_RESTART) & BM_ENET_ATCR_RESTART)

/*! @brief Set the RESTART field to a new value. */
#define BW_ENET_ATCR_RESTART(x, v) (HW_ENET_ATCR_WR(x, (HW_ENET_ATCR_RD(x) & ~BM_ENET_ATCR_RESTART) | BF_ENET_ATCR_RESTART(v)))
/*@}*/

/*!
 * @name Register ENET_ATCR, field CAPTURE[11] (RW)
 *
 * When this field is set, all other fields are ignored during a write. This
 * field automatically clears to 0 after the command completes. To ensure that the
 * correct time value is read from the ATVR register, a minimum amount of time
 * must elapse from issuing this command to reading the ATVR register. This minimum
 * time is defined by the greater of either six register clock cycles or six
 * 1588/timestamp clock cycles.
 *
 * Values:
 * - 0 - No effect.
 * - 1 - The current time is captured and can be read from the ATVR register.
 */
/*@{*/
#define BP_ENET_ATCR_CAPTURE (11U)         /*!< Bit position for ENET_ATCR_CAPTURE. */
#define BM_ENET_ATCR_CAPTURE (0x00000800U) /*!< Bit mask for ENET_ATCR_CAPTURE. */
#define BS_ENET_ATCR_CAPTURE (1U)          /*!< Bit field size in bits for ENET_ATCR_CAPTURE. */

/*! @brief Read current value of the ENET_ATCR_CAPTURE field. */
#define BR_ENET_ATCR_CAPTURE(x) (HW_ENET_ATCR(x).B.CAPTURE)

/*! @brief Format value for bitfield ENET_ATCR_CAPTURE. */
#define BF_ENET_ATCR_CAPTURE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATCR_CAPTURE) & BM_ENET_ATCR_CAPTURE)

/*! @brief Set the CAPTURE field to a new value. */
#define BW_ENET_ATCR_CAPTURE(x, v) (HW_ENET_ATCR_WR(x, (HW_ENET_ATCR_RD(x) & ~BM_ENET_ATCR_CAPTURE) | BF_ENET_ATCR_CAPTURE(v)))
/*@}*/

/*!
 * @name Register ENET_ATCR, field SLAVE[13] (RW)
 *
 * Values:
 * - 0 - The timer is active and all configuration fields in this register are
 *     relevant.
 * - 1 - The internal timer is disabled and the externally provided timer value
 *     is used. All other fields, except CAPTURE, in this register have no
 *     effect. CAPTURE can still be used to capture the current timer value.
 */
/*@{*/
#define BP_ENET_ATCR_SLAVE   (13U)         /*!< Bit position for ENET_ATCR_SLAVE. */
#define BM_ENET_ATCR_SLAVE   (0x00002000U) /*!< Bit mask for ENET_ATCR_SLAVE. */
#define BS_ENET_ATCR_SLAVE   (1U)          /*!< Bit field size in bits for ENET_ATCR_SLAVE. */

/*! @brief Read current value of the ENET_ATCR_SLAVE field. */
#define BR_ENET_ATCR_SLAVE(x) (HW_ENET_ATCR(x).B.SLAVE)

/*! @brief Format value for bitfield ENET_ATCR_SLAVE. */
#define BF_ENET_ATCR_SLAVE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATCR_SLAVE) & BM_ENET_ATCR_SLAVE)

/*! @brief Set the SLAVE field to a new value. */
#define BW_ENET_ATCR_SLAVE(x, v) (HW_ENET_ATCR_WR(x, (HW_ENET_ATCR_RD(x) & ~BM_ENET_ATCR_SLAVE) | BF_ENET_ATCR_SLAVE(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_ATVR - Timer Value Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_ATVR - Timer Value Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_atvr
{
    uint32_t U;
    struct _hw_enet_atvr_bitfields
    {
        uint32_t ATIME : 32;           /*!< [31:0]  */
    } B;
} hw_enet_atvr_t;

/*!
 * @name Constants and macros for entire ENET_ATVR register
 */
/*@{*/
#define HW_ENET_ATVR_ADDR(x)     ((uintptr_t)(x) + 0x404U)

#define HW_ENET_ATVR(x)          (*(__IO hw_enet_atvr_t *) HW_ENET_ATVR_ADDR(x))
#define HW_ENET_ATVR_RD(x)       (HW_ENET_ATVR(x).U)
#define HW_ENET_ATVR_WR(x, v)    (HW_ENET_ATVR(x).U = (v))
#define HW_ENET_ATVR_SET(x, v)   (HW_ENET_ATVR_WR(x, HW_ENET_ATVR_RD(x) |  (v)))
#define HW_ENET_ATVR_CLR(x, v)   (HW_ENET_ATVR_WR(x, HW_ENET_ATVR_RD(x) & ~(v)))
#define HW_ENET_ATVR_TOG(x, v)   (HW_ENET_ATVR_WR(x, HW_ENET_ATVR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_ATVR bitfields
 */

/*!
 * @name Register ENET_ATVR, field ATIME[31:0] (RW)
 *
 * A write sets the timer. A read returns the last captured value. To read the
 * current value, issue a capture command (i.e., set ATCR[CAPTURE]) prior to
 * reading this register.
 */
/*@{*/
#define BP_ENET_ATVR_ATIME   (0U)          /*!< Bit position for ENET_ATVR_ATIME. */
#define BM_ENET_ATVR_ATIME   (0xFFFFFFFFU) /*!< Bit mask for ENET_ATVR_ATIME. */
#define BS_ENET_ATVR_ATIME   (32U)         /*!< Bit field size in bits for ENET_ATVR_ATIME. */

/*! @brief Read current value of the ENET_ATVR_ATIME field. */
#define BR_ENET_ATVR_ATIME(x) (HW_ENET_ATVR(x).U)

/*! @brief Format value for bitfield ENET_ATVR_ATIME. */
#define BF_ENET_ATVR_ATIME(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATVR_ATIME) & BM_ENET_ATVR_ATIME)

/*! @brief Set the ATIME field to a new value. */
#define BW_ENET_ATVR_ATIME(x, v) (HW_ENET_ATVR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_ENET_ATOFF - Timer Offset Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_ATOFF - Timer Offset Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_atoff
{
    uint32_t U;
    struct _hw_enet_atoff_bitfields
    {
        uint32_t OFFSET : 32;          /*!< [31:0]  */
    } B;
} hw_enet_atoff_t;

/*!
 * @name Constants and macros for entire ENET_ATOFF register
 */
/*@{*/
#define HW_ENET_ATOFF_ADDR(x)    ((uintptr_t)(x) + 0x408U)

#define HW_ENET_ATOFF(x)         (*(__IO hw_enet_atoff_t *) HW_ENET_ATOFF_ADDR(x))
#define HW_ENET_ATOFF_RD(x)      (HW_ENET_ATOFF(x).U)
#define HW_ENET_ATOFF_WR(x, v)   (HW_ENET_ATOFF(x).U = (v))
#define HW_ENET_ATOFF_SET(x, v)  (HW_ENET_ATOFF_WR(x, HW_ENET_ATOFF_RD(x) |  (v)))
#define HW_ENET_ATOFF_CLR(x, v)  (HW_ENET_ATOFF_WR(x, HW_ENET_ATOFF_RD(x) & ~(v)))
#define HW_ENET_ATOFF_TOG(x, v)  (HW_ENET_ATOFF_WR(x, HW_ENET_ATOFF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_ATOFF bitfields
 */

/*!
 * @name Register ENET_ATOFF, field OFFSET[31:0] (RW)
 *
 * Offset value for one-shot event generation. When the timer reaches the value,
 * an event can be generated to reset the counter. If the increment value in
 * ATINC is given in true nanoseconds, this value is also given in true nanoseconds.
 */
/*@{*/
#define BP_ENET_ATOFF_OFFSET (0U)          /*!< Bit position for ENET_ATOFF_OFFSET. */
#define BM_ENET_ATOFF_OFFSET (0xFFFFFFFFU) /*!< Bit mask for ENET_ATOFF_OFFSET. */
#define BS_ENET_ATOFF_OFFSET (32U)         /*!< Bit field size in bits for ENET_ATOFF_OFFSET. */

/*! @brief Read current value of the ENET_ATOFF_OFFSET field. */
#define BR_ENET_ATOFF_OFFSET(x) (HW_ENET_ATOFF(x).U)

/*! @brief Format value for bitfield ENET_ATOFF_OFFSET. */
#define BF_ENET_ATOFF_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATOFF_OFFSET) & BM_ENET_ATOFF_OFFSET)

/*! @brief Set the OFFSET field to a new value. */
#define BW_ENET_ATOFF_OFFSET(x, v) (HW_ENET_ATOFF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_ENET_ATPER - Timer Period Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_ATPER - Timer Period Register (RW)
 *
 * Reset value: 0x3B9ACA00U
 */
typedef union _hw_enet_atper
{
    uint32_t U;
    struct _hw_enet_atper_bitfields
    {
        uint32_t PERIOD : 32;          /*!< [31:0]  */
    } B;
} hw_enet_atper_t;

/*!
 * @name Constants and macros for entire ENET_ATPER register
 */
/*@{*/
#define HW_ENET_ATPER_ADDR(x)    ((uintptr_t)(x) + 0x40CU)

#define HW_ENET_ATPER(x)         (*(__IO hw_enet_atper_t *) HW_ENET_ATPER_ADDR(x))
#define HW_ENET_ATPER_RD(x)      (HW_ENET_ATPER(x).U)
#define HW_ENET_ATPER_WR(x, v)   (HW_ENET_ATPER(x).U = (v))
#define HW_ENET_ATPER_SET(x, v)  (HW_ENET_ATPER_WR(x, HW_ENET_ATPER_RD(x) |  (v)))
#define HW_ENET_ATPER_CLR(x, v)  (HW_ENET_ATPER_WR(x, HW_ENET_ATPER_RD(x) & ~(v)))
#define HW_ENET_ATPER_TOG(x, v)  (HW_ENET_ATPER_WR(x, HW_ENET_ATPER_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_ATPER bitfields
 */

/*!
 * @name Register ENET_ATPER, field PERIOD[31:0] (RW)
 *
 * Value for generating periodic events. Each instance the timer reaches this
 * value, the period event occurs and the timer restarts. If the increment value in
 * ATINC is given in true nanoseconds, this value is also given in true
 * nanoseconds. The value should be initialized to 1,000,000,000 (1✕109) to represent a
 * timer wrap around of one second. The increment value set in ATINC should be
 * set to the true nanoseconds of the period of clock ts_clk, hence implementing a
 * true 1 second counter. The value of PERIOD has the following constraint: 232
 * − ENET_ATINC[INC_COR] − 3✕ENET_ATINC[INC] >= PERIOD > 0.
 */
/*@{*/
#define BP_ENET_ATPER_PERIOD (0U)          /*!< Bit position for ENET_ATPER_PERIOD. */
#define BM_ENET_ATPER_PERIOD (0xFFFFFFFFU) /*!< Bit mask for ENET_ATPER_PERIOD. */
#define BS_ENET_ATPER_PERIOD (32U)         /*!< Bit field size in bits for ENET_ATPER_PERIOD. */

/*! @brief Read current value of the ENET_ATPER_PERIOD field. */
#define BR_ENET_ATPER_PERIOD(x) (HW_ENET_ATPER(x).U)

/*! @brief Format value for bitfield ENET_ATPER_PERIOD. */
#define BF_ENET_ATPER_PERIOD(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATPER_PERIOD) & BM_ENET_ATPER_PERIOD)

/*! @brief Set the PERIOD field to a new value. */
#define BW_ENET_ATPER_PERIOD(x, v) (HW_ENET_ATPER_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_ENET_ATCOR - Timer Correction Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_ATCOR - Timer Correction Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_atcor
{
    uint32_t U;
    struct _hw_enet_atcor_bitfields
    {
        uint32_t COR : 31;             /*!< [30:0] Correction Counter Wrap-Around Value */
        uint32_t RESERVED0 : 1;        /*!< [31]  */
    } B;
} hw_enet_atcor_t;

/*!
 * @name Constants and macros for entire ENET_ATCOR register
 */
/*@{*/
#define HW_ENET_ATCOR_ADDR(x)    ((uintptr_t)(x) + 0x410U)

#define HW_ENET_ATCOR(x)         (*(__IO hw_enet_atcor_t *) HW_ENET_ATCOR_ADDR(x))
#define HW_ENET_ATCOR_RD(x)      (HW_ENET_ATCOR(x).U)
#define HW_ENET_ATCOR_WR(x, v)   (HW_ENET_ATCOR(x).U = (v))
#define HW_ENET_ATCOR_SET(x, v)  (HW_ENET_ATCOR_WR(x, HW_ENET_ATCOR_RD(x) |  (v)))
#define HW_ENET_ATCOR_CLR(x, v)  (HW_ENET_ATCOR_WR(x, HW_ENET_ATCOR_RD(x) & ~(v)))
#define HW_ENET_ATCOR_TOG(x, v)  (HW_ENET_ATCOR_WR(x, HW_ENET_ATCOR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_ATCOR bitfields
 */

/*!
 * @name Register ENET_ATCOR, field COR[30:0] (RW)
 *
 * Defines after how many timer clock cycles (ts_clk) the correction counter
 * should be reset and trigger a correction increment on the timer. The amount of
 * correction is defined in ATINC[INC_CORR]. A value of 0 disables the correction
 * counter and no corrections occur. This value is given in clock cycles, not in
 * nanoseconds as all other values.
 */
/*@{*/
#define BP_ENET_ATCOR_COR    (0U)          /*!< Bit position for ENET_ATCOR_COR. */
#define BM_ENET_ATCOR_COR    (0x7FFFFFFFU) /*!< Bit mask for ENET_ATCOR_COR. */
#define BS_ENET_ATCOR_COR    (31U)         /*!< Bit field size in bits for ENET_ATCOR_COR. */

/*! @brief Read current value of the ENET_ATCOR_COR field. */
#define BR_ENET_ATCOR_COR(x) (HW_ENET_ATCOR(x).B.COR)

/*! @brief Format value for bitfield ENET_ATCOR_COR. */
#define BF_ENET_ATCOR_COR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATCOR_COR) & BM_ENET_ATCOR_COR)

/*! @brief Set the COR field to a new value. */
#define BW_ENET_ATCOR_COR(x, v) (HW_ENET_ATCOR_WR(x, (HW_ENET_ATCOR_RD(x) & ~BM_ENET_ATCOR_COR) | BF_ENET_ATCOR_COR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_ATINC - Time-Stamping Clock Period Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_ATINC - Time-Stamping Clock Period Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_atinc
{
    uint32_t U;
    struct _hw_enet_atinc_bitfields
    {
        uint32_t INC : 7;              /*!< [6:0] Clock Period Of The Timestamping Clock
                                        * (ts_clk) In Nanoseconds */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t INC_CORR : 7;         /*!< [14:8] Correction Increment Value */
        uint32_t RESERVED1 : 17;       /*!< [31:15]  */
    } B;
} hw_enet_atinc_t;

/*!
 * @name Constants and macros for entire ENET_ATINC register
 */
/*@{*/
#define HW_ENET_ATINC_ADDR(x)    ((uintptr_t)(x) + 0x414U)

#define HW_ENET_ATINC(x)         (*(__IO hw_enet_atinc_t *) HW_ENET_ATINC_ADDR(x))
#define HW_ENET_ATINC_RD(x)      (HW_ENET_ATINC(x).U)
#define HW_ENET_ATINC_WR(x, v)   (HW_ENET_ATINC(x).U = (v))
#define HW_ENET_ATINC_SET(x, v)  (HW_ENET_ATINC_WR(x, HW_ENET_ATINC_RD(x) |  (v)))
#define HW_ENET_ATINC_CLR(x, v)  (HW_ENET_ATINC_WR(x, HW_ENET_ATINC_RD(x) & ~(v)))
#define HW_ENET_ATINC_TOG(x, v)  (HW_ENET_ATINC_WR(x, HW_ENET_ATINC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_ATINC bitfields
 */

/*!
 * @name Register ENET_ATINC, field INC[6:0] (RW)
 *
 * The timer increments by this amount each clock cycle. For example, set to 10
 * for 100 MHz, 8 for 125 MHz, 5 for 200 MHz. For highest precision, use a value
 * that is an integer fraction of the period set in ATPER.
 */
/*@{*/
#define BP_ENET_ATINC_INC    (0U)          /*!< Bit position for ENET_ATINC_INC. */
#define BM_ENET_ATINC_INC    (0x0000007FU) /*!< Bit mask for ENET_ATINC_INC. */
#define BS_ENET_ATINC_INC    (7U)          /*!< Bit field size in bits for ENET_ATINC_INC. */

/*! @brief Read current value of the ENET_ATINC_INC field. */
#define BR_ENET_ATINC_INC(x) (HW_ENET_ATINC(x).B.INC)

/*! @brief Format value for bitfield ENET_ATINC_INC. */
#define BF_ENET_ATINC_INC(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATINC_INC) & BM_ENET_ATINC_INC)

/*! @brief Set the INC field to a new value. */
#define BW_ENET_ATINC_INC(x, v) (HW_ENET_ATINC_WR(x, (HW_ENET_ATINC_RD(x) & ~BM_ENET_ATINC_INC) | BF_ENET_ATINC_INC(v)))
/*@}*/

/*!
 * @name Register ENET_ATINC, field INC_CORR[14:8] (RW)
 *
 * This value is added every time the correction timer expires (every clock
 * cycle given in ATCOR). A value less than INC slows down the timer. A value greater
 * than INC speeds up the timer.
 */
/*@{*/
#define BP_ENET_ATINC_INC_CORR (8U)        /*!< Bit position for ENET_ATINC_INC_CORR. */
#define BM_ENET_ATINC_INC_CORR (0x00007F00U) /*!< Bit mask for ENET_ATINC_INC_CORR. */
#define BS_ENET_ATINC_INC_CORR (7U)        /*!< Bit field size in bits for ENET_ATINC_INC_CORR. */

/*! @brief Read current value of the ENET_ATINC_INC_CORR field. */
#define BR_ENET_ATINC_INC_CORR(x) (HW_ENET_ATINC(x).B.INC_CORR)

/*! @brief Format value for bitfield ENET_ATINC_INC_CORR. */
#define BF_ENET_ATINC_INC_CORR(v) ((uint32_t)((uint32_t)(v) << BP_ENET_ATINC_INC_CORR) & BM_ENET_ATINC_INC_CORR)

/*! @brief Set the INC_CORR field to a new value. */
#define BW_ENET_ATINC_INC_CORR(x, v) (HW_ENET_ATINC_WR(x, (HW_ENET_ATINC_RD(x) & ~BM_ENET_ATINC_INC_CORR) | BF_ENET_ATINC_INC_CORR(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_ATSTMP - Timestamp of Last Transmitted Frame
 ******************************************************************************/

/*!
 * @brief HW_ENET_ATSTMP - Timestamp of Last Transmitted Frame (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_atstmp
{
    uint32_t U;
    struct _hw_enet_atstmp_bitfields
    {
        uint32_t TIMESTAMP : 32;       /*!< [31:0]  */
    } B;
} hw_enet_atstmp_t;

/*!
 * @name Constants and macros for entire ENET_ATSTMP register
 */
/*@{*/
#define HW_ENET_ATSTMP_ADDR(x)   ((uintptr_t)(x) + 0x418U)

#define HW_ENET_ATSTMP(x)        (*(__I hw_enet_atstmp_t *) HW_ENET_ATSTMP_ADDR(x))
#define HW_ENET_ATSTMP_RD(x)     (HW_ENET_ATSTMP(x).U)
/*@}*/

/*
 * Constants & macros for individual ENET_ATSTMP bitfields
 */

/*!
 * @name Register ENET_ATSTMP, field TIMESTAMP[31:0] (RO)
 *
 * Timestamp of the last frame transmitted by the core that had TxBD[TS] set .
 * This register is only valid when EIR[TS_AVAIL] is set.
 */
/*@{*/
#define BP_ENET_ATSTMP_TIMESTAMP (0U)      /*!< Bit position for ENET_ATSTMP_TIMESTAMP. */
#define BM_ENET_ATSTMP_TIMESTAMP (0xFFFFFFFFU) /*!< Bit mask for ENET_ATSTMP_TIMESTAMP. */
#define BS_ENET_ATSTMP_TIMESTAMP (32U)     /*!< Bit field size in bits for ENET_ATSTMP_TIMESTAMP. */

/*! @brief Read current value of the ENET_ATSTMP_TIMESTAMP field. */
#define BR_ENET_ATSTMP_TIMESTAMP(x) (HW_ENET_ATSTMP(x).U)
/*@}*/

/*******************************************************************************
 * HW_ENET_TGSR - Timer Global Status Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_TGSR - Timer Global Status Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_tgsr
{
    uint32_t U;
    struct _hw_enet_tgsr_bitfields
    {
        uint32_t TF0 : 1;              /*!< [0] Copy Of Timer Flag For Channel 0 */
        uint32_t TF1 : 1;              /*!< [1] Copy Of Timer Flag For Channel 1 */
        uint32_t TF2 : 1;              /*!< [2] Copy Of Timer Flag For Channel 2 */
        uint32_t TF3 : 1;              /*!< [3] Copy Of Timer Flag For Channel 3 */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_enet_tgsr_t;

/*!
 * @name Constants and macros for entire ENET_TGSR register
 */
/*@{*/
#define HW_ENET_TGSR_ADDR(x)     ((uintptr_t)(x) + 0x604U)

#define HW_ENET_TGSR(x)          (*(__IO hw_enet_tgsr_t *) HW_ENET_TGSR_ADDR(x))
#define HW_ENET_TGSR_RD(x)       (HW_ENET_TGSR(x).U)
#define HW_ENET_TGSR_WR(x, v)    (HW_ENET_TGSR(x).U = (v))
#define HW_ENET_TGSR_SET(x, v)   (HW_ENET_TGSR_WR(x, HW_ENET_TGSR_RD(x) |  (v)))
#define HW_ENET_TGSR_CLR(x, v)   (HW_ENET_TGSR_WR(x, HW_ENET_TGSR_RD(x) & ~(v)))
#define HW_ENET_TGSR_TOG(x, v)   (HW_ENET_TGSR_WR(x, HW_ENET_TGSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TGSR bitfields
 */

/*!
 * @name Register ENET_TGSR, field TF0[0] (W1C)
 *
 * Values:
 * - 0 - Timer Flag for Channel 0 is clear
 * - 1 - Timer Flag for Channel 0 is set
 */
/*@{*/
#define BP_ENET_TGSR_TF0     (0U)          /*!< Bit position for ENET_TGSR_TF0. */
#define BM_ENET_TGSR_TF0     (0x00000001U) /*!< Bit mask for ENET_TGSR_TF0. */
#define BS_ENET_TGSR_TF0     (1U)          /*!< Bit field size in bits for ENET_TGSR_TF0. */

/*! @brief Read current value of the ENET_TGSR_TF0 field. */
#define BR_ENET_TGSR_TF0(x)  (HW_ENET_TGSR(x).B.TF0)

/*! @brief Format value for bitfield ENET_TGSR_TF0. */
#define BF_ENET_TGSR_TF0(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_TGSR_TF0) & BM_ENET_TGSR_TF0)

/*! @brief Set the TF0 field to a new value. */
#define BW_ENET_TGSR_TF0(x, v) (HW_ENET_TGSR_WR(x, (HW_ENET_TGSR_RD(x) & ~(BM_ENET_TGSR_TF0 | BM_ENET_TGSR_TF1 | BM_ENET_TGSR_TF2 | BM_ENET_TGSR_TF3)) | BF_ENET_TGSR_TF0(v)))
/*@}*/

/*!
 * @name Register ENET_TGSR, field TF1[1] (W1C)
 *
 * Values:
 * - 0 - Timer Flag for Channel 1 is clear
 * - 1 - Timer Flag for Channel 1 is set
 */
/*@{*/
#define BP_ENET_TGSR_TF1     (1U)          /*!< Bit position for ENET_TGSR_TF1. */
#define BM_ENET_TGSR_TF1     (0x00000002U) /*!< Bit mask for ENET_TGSR_TF1. */
#define BS_ENET_TGSR_TF1     (1U)          /*!< Bit field size in bits for ENET_TGSR_TF1. */

/*! @brief Read current value of the ENET_TGSR_TF1 field. */
#define BR_ENET_TGSR_TF1(x)  (HW_ENET_TGSR(x).B.TF1)

/*! @brief Format value for bitfield ENET_TGSR_TF1. */
#define BF_ENET_TGSR_TF1(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_TGSR_TF1) & BM_ENET_TGSR_TF1)

/*! @brief Set the TF1 field to a new value. */
#define BW_ENET_TGSR_TF1(x, v) (HW_ENET_TGSR_WR(x, (HW_ENET_TGSR_RD(x) & ~(BM_ENET_TGSR_TF1 | BM_ENET_TGSR_TF0 | BM_ENET_TGSR_TF2 | BM_ENET_TGSR_TF3)) | BF_ENET_TGSR_TF1(v)))
/*@}*/

/*!
 * @name Register ENET_TGSR, field TF2[2] (W1C)
 *
 * Values:
 * - 0 - Timer Flag for Channel 2 is clear
 * - 1 - Timer Flag for Channel 2 is set
 */
/*@{*/
#define BP_ENET_TGSR_TF2     (2U)          /*!< Bit position for ENET_TGSR_TF2. */
#define BM_ENET_TGSR_TF2     (0x00000004U) /*!< Bit mask for ENET_TGSR_TF2. */
#define BS_ENET_TGSR_TF2     (1U)          /*!< Bit field size in bits for ENET_TGSR_TF2. */

/*! @brief Read current value of the ENET_TGSR_TF2 field. */
#define BR_ENET_TGSR_TF2(x)  (HW_ENET_TGSR(x).B.TF2)

/*! @brief Format value for bitfield ENET_TGSR_TF2. */
#define BF_ENET_TGSR_TF2(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_TGSR_TF2) & BM_ENET_TGSR_TF2)

/*! @brief Set the TF2 field to a new value. */
#define BW_ENET_TGSR_TF2(x, v) (HW_ENET_TGSR_WR(x, (HW_ENET_TGSR_RD(x) & ~(BM_ENET_TGSR_TF2 | BM_ENET_TGSR_TF0 | BM_ENET_TGSR_TF1 | BM_ENET_TGSR_TF3)) | BF_ENET_TGSR_TF2(v)))
/*@}*/

/*!
 * @name Register ENET_TGSR, field TF3[3] (W1C)
 *
 * Values:
 * - 0 - Timer Flag for Channel 3 is clear
 * - 1 - Timer Flag for Channel 3 is set
 */
/*@{*/
#define BP_ENET_TGSR_TF3     (3U)          /*!< Bit position for ENET_TGSR_TF3. */
#define BM_ENET_TGSR_TF3     (0x00000008U) /*!< Bit mask for ENET_TGSR_TF3. */
#define BS_ENET_TGSR_TF3     (1U)          /*!< Bit field size in bits for ENET_TGSR_TF3. */

/*! @brief Read current value of the ENET_TGSR_TF3 field. */
#define BR_ENET_TGSR_TF3(x)  (HW_ENET_TGSR(x).B.TF3)

/*! @brief Format value for bitfield ENET_TGSR_TF3. */
#define BF_ENET_TGSR_TF3(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_TGSR_TF3) & BM_ENET_TGSR_TF3)

/*! @brief Set the TF3 field to a new value. */
#define BW_ENET_TGSR_TF3(x, v) (HW_ENET_TGSR_WR(x, (HW_ENET_TGSR_RD(x) & ~(BM_ENET_TGSR_TF3 | BM_ENET_TGSR_TF0 | BM_ENET_TGSR_TF1 | BM_ENET_TGSR_TF2)) | BF_ENET_TGSR_TF3(v)))
/*@}*/

/*******************************************************************************
 * HW_ENET_TCSRn - Timer Control Status Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_TCSRn - Timer Control Status Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_tcsrn
{
    uint32_t U;
    struct _hw_enet_tcsrn_bitfields
    {
        uint32_t TDRE : 1;             /*!< [0] Timer DMA Request Enable */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t TMODE : 4;            /*!< [5:2] Timer Mode */
        uint32_t TIE : 1;              /*!< [6] Timer Interrupt Enable */
        uint32_t TF : 1;               /*!< [7] Timer Flag */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_enet_tcsrn_t;

/*!
 * @name Constants and macros for entire ENET_TCSRn register
 */
/*@{*/
#define HW_ENET_TCSRn_COUNT (4U)

#define HW_ENET_TCSRn_ADDR(x, n) ((uintptr_t)(x) + 0x608U + (0x8U * (n)))

#define HW_ENET_TCSRn(x, n)      (*(__IO hw_enet_tcsrn_t *) HW_ENET_TCSRn_ADDR(x, n))
#define HW_ENET_TCSRn_RD(x, n)   (HW_ENET_TCSRn(x, n).U)
#define HW_ENET_TCSRn_WR(x, n, v) (HW_ENET_TCSRn(x, n).U = (v))
#define HW_ENET_TCSRn_SET(x, n, v) (HW_ENET_TCSRn_WR(x, n, HW_ENET_TCSRn_RD(x, n) |  (v)))
#define HW_ENET_TCSRn_CLR(x, n, v) (HW_ENET_TCSRn_WR(x, n, HW_ENET_TCSRn_RD(x, n) & ~(v)))
#define HW_ENET_TCSRn_TOG(x, n, v) (HW_ENET_TCSRn_WR(x, n, HW_ENET_TCSRn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TCSRn bitfields
 */

/*!
 * @name Register ENET_TCSRn, field TDRE[0] (RW)
 *
 * Values:
 * - 0 - DMA request is disabled
 * - 1 - DMA request is enabled
 */
/*@{*/
#define BP_ENET_TCSRn_TDRE   (0U)          /*!< Bit position for ENET_TCSRn_TDRE. */
#define BM_ENET_TCSRn_TDRE   (0x00000001U) /*!< Bit mask for ENET_TCSRn_TDRE. */
#define BS_ENET_TCSRn_TDRE   (1U)          /*!< Bit field size in bits for ENET_TCSRn_TDRE. */

/*! @brief Read current value of the ENET_TCSRn_TDRE field. */
#define BR_ENET_TCSRn_TDRE(x, n) (HW_ENET_TCSRn(x, n).B.TDRE)

/*! @brief Format value for bitfield ENET_TCSRn_TDRE. */
#define BF_ENET_TCSRn_TDRE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TCSRn_TDRE) & BM_ENET_TCSRn_TDRE)

/*! @brief Set the TDRE field to a new value. */
#define BW_ENET_TCSRn_TDRE(x, n, v) (HW_ENET_TCSRn_WR(x, n, (HW_ENET_TCSRn_RD(x, n) & ~(BM_ENET_TCSRn_TDRE | BM_ENET_TCSRn_TF)) | BF_ENET_TCSRn_TDRE(v)))
/*@}*/

/*!
 * @name Register ENET_TCSRn, field TMODE[5:2] (RW)
 *
 * Updating the Timer Mode field takes a few cycles to register because it is
 * synchronized to the 1588 clock. The version of Timer Mode returned on a read is
 * from the 1588 clock domain. When changing Timer Mode, always disable the
 * channel and read this register to verify the channel is disabled first.
 *
 * Values:
 * - 0000 - Timer Channel is disabled.
 * - 0001 - Timer Channel is configured for Input Capture on rising edge.
 * - 0010 - Timer Channel is configured for Input Capture on falling edge.
 * - 0011 - Timer Channel is configured for Input Capture on both edges.
 * - 0100 - Timer Channel is configured for Output Compare - software only.
 * - 0101 - Timer Channel is configured for Output Compare - toggle output on
 *     compare.
 * - 0110 - Timer Channel is configured for Output Compare - clear output on
 *     compare.
 * - 0111 - Timer Channel is configured for Output Compare - set output on
 *     compare.
 * - 1000 - Reserved
 * - 1010 - Timer Channel is configured for Output Compare - clear output on
 *     compare, set output on overflow.
 * - 1110 - Timer Channel is configured for Output Compare - pulse output low on
 *     compare for one 1588-clock cycle.
 * - 1111 - Timer Channel is configured for Output Compare - pulse output high
 *     on compare for one 1588-clock cycle.
 */
/*@{*/
#define BP_ENET_TCSRn_TMODE  (2U)          /*!< Bit position for ENET_TCSRn_TMODE. */
#define BM_ENET_TCSRn_TMODE  (0x0000003CU) /*!< Bit mask for ENET_TCSRn_TMODE. */
#define BS_ENET_TCSRn_TMODE  (4U)          /*!< Bit field size in bits for ENET_TCSRn_TMODE. */

/*! @brief Read current value of the ENET_TCSRn_TMODE field. */
#define BR_ENET_TCSRn_TMODE(x, n) (HW_ENET_TCSRn(x, n).B.TMODE)

/*! @brief Format value for bitfield ENET_TCSRn_TMODE. */
#define BF_ENET_TCSRn_TMODE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TCSRn_TMODE) & BM_ENET_TCSRn_TMODE)

/*! @brief Set the TMODE field to a new value. */
#define BW_ENET_TCSRn_TMODE(x, n, v) (HW_ENET_TCSRn_WR(x, n, (HW_ENET_TCSRn_RD(x, n) & ~(BM_ENET_TCSRn_TMODE | BM_ENET_TCSRn_TF)) | BF_ENET_TCSRn_TMODE(v)))
/*@}*/

/*!
 * @name Register ENET_TCSRn, field TIE[6] (RW)
 *
 * Values:
 * - 0 - Interrupt is disabled
 * - 1 - Interrupt is enabled
 */
/*@{*/
#define BP_ENET_TCSRn_TIE    (6U)          /*!< Bit position for ENET_TCSRn_TIE. */
#define BM_ENET_TCSRn_TIE    (0x00000040U) /*!< Bit mask for ENET_TCSRn_TIE. */
#define BS_ENET_TCSRn_TIE    (1U)          /*!< Bit field size in bits for ENET_TCSRn_TIE. */

/*! @brief Read current value of the ENET_TCSRn_TIE field. */
#define BR_ENET_TCSRn_TIE(x, n) (HW_ENET_TCSRn(x, n).B.TIE)

/*! @brief Format value for bitfield ENET_TCSRn_TIE. */
#define BF_ENET_TCSRn_TIE(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TCSRn_TIE) & BM_ENET_TCSRn_TIE)

/*! @brief Set the TIE field to a new value. */
#define BW_ENET_TCSRn_TIE(x, n, v) (HW_ENET_TCSRn_WR(x, n, (HW_ENET_TCSRn_RD(x, n) & ~(BM_ENET_TCSRn_TIE | BM_ENET_TCSRn_TF)) | BF_ENET_TCSRn_TIE(v)))
/*@}*/

/*!
 * @name Register ENET_TCSRn, field TF[7] (W1C)
 *
 * Sets when input capture or output compare occurs. This flag is double
 * buffered between the module clock and 1588 clock domains. When this field is 1, it
 * can be cleared to 0 by writing 1 to it.
 *
 * Values:
 * - 0 - Input Capture or Output Compare has not occurred.
 * - 1 - Input Capture or Output Compare has occurred.
 */
/*@{*/
#define BP_ENET_TCSRn_TF     (7U)          /*!< Bit position for ENET_TCSRn_TF. */
#define BM_ENET_TCSRn_TF     (0x00000080U) /*!< Bit mask for ENET_TCSRn_TF. */
#define BS_ENET_TCSRn_TF     (1U)          /*!< Bit field size in bits for ENET_TCSRn_TF. */

/*! @brief Read current value of the ENET_TCSRn_TF field. */
#define BR_ENET_TCSRn_TF(x, n) (HW_ENET_TCSRn(x, n).B.TF)

/*! @brief Format value for bitfield ENET_TCSRn_TF. */
#define BF_ENET_TCSRn_TF(v)  ((uint32_t)((uint32_t)(v) << BP_ENET_TCSRn_TF) & BM_ENET_TCSRn_TF)

/*! @brief Set the TF field to a new value. */
#define BW_ENET_TCSRn_TF(x, n, v) (HW_ENET_TCSRn_WR(x, n, (HW_ENET_TCSRn_RD(x, n) & ~BM_ENET_TCSRn_TF) | BF_ENET_TCSRn_TF(v)))
/*@}*/
/*******************************************************************************
 * HW_ENET_TCCRn - Timer Compare Capture Register
 ******************************************************************************/

/*!
 * @brief HW_ENET_TCCRn - Timer Compare Capture Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_enet_tccrn
{
    uint32_t U;
    struct _hw_enet_tccrn_bitfields
    {
        uint32_t TCC : 32;             /*!< [31:0] Timer Capture Compare */
    } B;
} hw_enet_tccrn_t;

/*!
 * @name Constants and macros for entire ENET_TCCRn register
 */
/*@{*/
#define HW_ENET_TCCRn_COUNT (4U)

#define HW_ENET_TCCRn_ADDR(x, n) ((uintptr_t)(x) + 0x60CU + (0x8U * (n)))

#define HW_ENET_TCCRn(x, n)      (*(__IO hw_enet_tccrn_t *) HW_ENET_TCCRn_ADDR(x, n))
#define HW_ENET_TCCRn_RD(x, n)   (HW_ENET_TCCRn(x, n).U)
#define HW_ENET_TCCRn_WR(x, n, v) (HW_ENET_TCCRn(x, n).U = (v))
#define HW_ENET_TCCRn_SET(x, n, v) (HW_ENET_TCCRn_WR(x, n, HW_ENET_TCCRn_RD(x, n) |  (v)))
#define HW_ENET_TCCRn_CLR(x, n, v) (HW_ENET_TCCRn_WR(x, n, HW_ENET_TCCRn_RD(x, n) & ~(v)))
#define HW_ENET_TCCRn_TOG(x, n, v) (HW_ENET_TCCRn_WR(x, n, HW_ENET_TCCRn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ENET_TCCRn bitfields
 */

/*!
 * @name Register ENET_TCCRn, field TCC[31:0] (RW)
 *
 * This register is double buffered between the module clock and 1588 clock
 * domains. When configured for compare, the 1588 clock domain updates with the value
 * in the module clock domain whenever the Timer Channel is first enabled and on
 * each subsequent compare. Write to this register with the first compare value
 * before enabling the Timer Channel. When the Timer Channel is enabled, write
 * the second compare value either immediately, or at least before the first
 * compare occurs. After each compare, write the next compare value before the previous
 * compare occurs and before clearing the Timer Flag. The compare occurs one
 * 1588 clock cycle after the IEEE 1588 Counter increments past the compare value in
 * the 1588 clock domain. If the compare value is less than the value of the
 * 1588 Counter when the Timer Channel is first enabled, then the compare does not
 * occur until following the next overflow of the 1588 Counter. If the compare
 * value is greater than the IEEE 1588 Counter when the 1588 Counter overflows, or
 * the compare value is less than the value of the IEEE 1588 Counter after the
 * overflow, then the compare occurs one 1588 clock cycle following the overflow.
 * When configured for capture, the value of the IEEE 1588 Counter is captured into
 * the 1588 clock domain and then updated into the module clock domain, provided
 * the Timer Flag is clear. Always read the capture value before clearing the
 * Timer Flag.
 */
/*@{*/
#define BP_ENET_TCCRn_TCC    (0U)          /*!< Bit position for ENET_TCCRn_TCC. */
#define BM_ENET_TCCRn_TCC    (0xFFFFFFFFU) /*!< Bit mask for ENET_TCCRn_TCC. */
#define BS_ENET_TCCRn_TCC    (32U)         /*!< Bit field size in bits for ENET_TCCRn_TCC. */

/*! @brief Read current value of the ENET_TCCRn_TCC field. */
#define BR_ENET_TCCRn_TCC(x, n) (HW_ENET_TCCRn(x, n).U)

/*! @brief Format value for bitfield ENET_TCCRn_TCC. */
#define BF_ENET_TCCRn_TCC(v) ((uint32_t)((uint32_t)(v) << BP_ENET_TCCRn_TCC) & BM_ENET_TCCRn_TCC)

/*! @brief Set the TCC field to a new value. */
#define BW_ENET_TCCRn_TCC(x, n, v) (HW_ENET_TCCRn_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * hw_enet_t - module struct
 ******************************************************************************/
/*!
 * @brief All ENET module registers.
 */
#pragma pack(1)
typedef struct _hw_enet
{
    uint8_t _reserved0[4];
    __IO hw_enet_eir_t EIR;                /*!< [0x4] Interrupt Event Register */
    __IO hw_enet_eimr_t EIMR;              /*!< [0x8] Interrupt Mask Register */
    uint8_t _reserved1[4];
    __IO hw_enet_rdar_t RDAR;              /*!< [0x10] Receive Descriptor Active Register - Ring 0 */
    __IO hw_enet_tdar_t TDAR;              /*!< [0x14] Transmit Descriptor Active Register - Ring 0 */
    uint8_t _reserved2[12];
    __IO hw_enet_ecr_t ECR;                /*!< [0x24] Ethernet Control Register */
    uint8_t _reserved3[24];
    __IO hw_enet_mmfr_t MMFR;              /*!< [0x40] MII Management Frame Register */
    __IO hw_enet_mscr_t MSCR;              /*!< [0x44] MII Speed Control Register */
    uint8_t _reserved4[28];
    __IO hw_enet_mibc_t MIBC;              /*!< [0x64] MIB Control Register */
    uint8_t _reserved5[28];
    __IO hw_enet_rcr_t RCR;                /*!< [0x84] Receive Control Register */
    uint8_t _reserved6[60];
    __IO hw_enet_tcr_t TCR;                /*!< [0xC4] Transmit Control Register */
    uint8_t _reserved7[28];
    __IO hw_enet_palr_t PALR;              /*!< [0xE4] Physical Address Lower Register */
    __IO hw_enet_paur_t PAUR;              /*!< [0xE8] Physical Address Upper Register */
    __IO hw_enet_opd_t OPD;                /*!< [0xEC] Opcode/Pause Duration Register */
    __IO hw_enet_txicn_t TXICn[3];         /*!< [0xF0] Transmit Interrupt Coalescing Register */
    uint8_t _reserved8[4];
    __IO hw_enet_rxicn_t RXICn[3];         /*!< [0x100] Receive Interrupt Coalescing Register */
    uint8_t _reserved9[12];
    __IO hw_enet_iaur_t IAUR;              /*!< [0x118] Descriptor Individual Upper Address Register */
    __IO hw_enet_ialr_t IALR;              /*!< [0x11C] Descriptor Individual Lower Address Register */
    __IO hw_enet_gaur_t GAUR;              /*!< [0x120] Descriptor Group Upper Address Register */
    __IO hw_enet_galr_t GALR;              /*!< [0x124] Descriptor Group Lower Address Register */
    uint8_t _reserved10[28];
    __IO hw_enet_tfwr_t TFWR;              /*!< [0x144] Transmit FIFO Watermark Register */
    uint8_t _reserved11[24];
    __IO hw_enet_rdsr1_t RDSR1;            /*!< [0x160] Receive Descriptor Ring 1 Start Register */
    __IO hw_enet_tdsr1_t TDSR1;            /*!< [0x164] Transmit Buffer Descriptor Ring 1 Start Register */
    __IO hw_enet_mrbr1_t MRBR1;            /*!< [0x168] Maximum Receive Buffer Size Register - Ring 1 */
    __IO hw_enet_rdsr2_t RDSR2;            /*!< [0x16C] Receive Descriptor Ring 2 Start Register */
    __IO hw_enet_tdsr2_t TDSR2;            /*!< [0x170] Transmit Buffer Descriptor Ring 2 Start Register */
    __IO hw_enet_mrbr2_t MRBR2;            /*!< [0x174] Maximum Receive Buffer Size Register - Ring 2 */
    uint8_t _reserved12[8];
    __IO hw_enet_rdsr_t RDSR;              /*!< [0x180] Receive Descriptor Ring 0 Start Register */
    __IO hw_enet_tdsr_t TDSR;              /*!< [0x184] Transmit Buffer Descriptor Ring 0 Start Register */
    __IO hw_enet_mrbr_t MRBR;              /*!< [0x188] Maximum Receive Buffer Size Register - Ring 0 */
    uint8_t _reserved13[4];
    __IO hw_enet_rsfl_t RSFL;              /*!< [0x190] Receive FIFO Section Full Threshold */
    __IO hw_enet_rsem_t RSEM;              /*!< [0x194] Receive FIFO Section Empty Threshold */
    __IO hw_enet_raem_t RAEM;              /*!< [0x198] Receive FIFO Almost Empty Threshold */
    __IO hw_enet_rafl_t RAFL;              /*!< [0x19C] Receive FIFO Almost Full Threshold */
    __IO hw_enet_tsem_t TSEM;              /*!< [0x1A0] Transmit FIFO Section Empty Threshold */
    __IO hw_enet_taem_t TAEM;              /*!< [0x1A4] Transmit FIFO Almost Empty Threshold */
    __IO hw_enet_tafl_t TAFL;              /*!< [0x1A8] Transmit FIFO Almost Full Threshold */
    __IO hw_enet_tipg_t TIPG;              /*!< [0x1AC] Transmit Inter-Packet Gap */
    __IO hw_enet_ftrl_t FTRL;              /*!< [0x1B0] Frame Truncation Length */
    uint8_t _reserved14[12];
    __IO hw_enet_tacc_t TACC;              /*!< [0x1C0] Transmit Accelerator Function Configuration */
    __IO hw_enet_racc_t RACC;              /*!< [0x1C4] Receive Accelerator Function Configuration */
    __IO hw_enet_rcmr1_t RCMR1;            /*!< [0x1C8] Receive Classification Match Register for Class n */
    __IO hw_enet_rcmr2_t RCMR2;            /*!< [0x1CC] Receive Classification Match Register for Class n */
    uint8_t _reserved15[8];
    __IO hw_enet_dma1cfg_t DMA1CFG;        /*!< [0x1D8] DMA Class Based Configuration */
    __IO hw_enet_dma2cfg_t DMA2CFG;        /*!< [0x1DC] DMA Class Based Configuration */
    __IO hw_enet_rdar1_t RDAR1;            /*!< [0x1E0] Receive Descriptor Active Register - Ring 1 */
    __IO hw_enet_tdar1_t TDAR1;            /*!< [0x1E4] Transmit Descriptor Active Register - Ring 1 */
    __IO hw_enet_rdar2_t RDAR2;            /*!< [0x1E8] Receive Descriptor Active Register - Ring 2 */
    __IO hw_enet_tdar2_t TDAR2;            /*!< [0x1EC] Transmit Descriptor Active Register - Ring 2 */
    __IO hw_enet_qos_t QOS;                /*!< [0x1F0] QOS Scheme */
    uint8_t _reserved16[12];
    __I hw_enet_rmon_t_drop_t RMON_T_DROP; /*!< [0x200] Reserved Statistic Register */
    __I hw_enet_rmon_t_packets_t RMON_T_PACKETS; /*!< [0x204] Tx Packet Count Statistic Register */
    __I hw_enet_rmon_t_bc_pkt_t RMON_T_BC_PKT; /*!< [0x208] Tx Broadcast Packets Statistic Register */
    __I hw_enet_rmon_t_mc_pkt_t RMON_T_MC_PKT; /*!< [0x20C] Tx Multicast Packets Statistic Register */
    __I hw_enet_rmon_t_crc_align_t RMON_T_CRC_ALIGN; /*!< [0x210] Tx Packets with CRC/Align Error Statistic Register */
    __I hw_enet_rmon_t_undersize_t RMON_T_UNDERSIZE; /*!< [0x214] Tx Packets Less Than Bytes and Good CRC Statistic Register */
    __I hw_enet_rmon_t_oversize_t RMON_T_OVERSIZE; /*!< [0x218] Tx Packets GT MAX_FL bytes and Good CRC Statistic Register */
    __I hw_enet_rmon_t_frag_t RMON_T_FRAG; /*!< [0x21C] Tx Packets Less Than 64 Bytes and Bad CRC Statistic Register */
    __I hw_enet_rmon_t_jab_t RMON_T_JAB;   /*!< [0x220] Tx Packets Greater Than MAX_FL bytes and Bad CRC Statistic Register */
    __I hw_enet_rmon_t_col_t RMON_T_COL;   /*!< [0x224] Tx Collision Count Statistic Register */
    __I hw_enet_rmon_t_p64_t RMON_T_P64;   /*!< [0x228] Tx 64-Byte Packets Statistic Register */
    __I hw_enet_rmon_t_p65to127_t RMON_T_P65TO127; /*!< [0x22C] Tx 65- to 127-byte Packets Statistic Register */
    __I hw_enet_rmon_t_p128to255_t RMON_T_P128TO255; /*!< [0x230] Tx 128- to 255-byte Packets Statistic Register */
    __I hw_enet_rmon_t_p256to511_t RMON_T_P256TO511; /*!< [0x234] Tx 256- to 511-byte Packets Statistic Register */
    __I hw_enet_rmon_t_p512to1023_t RMON_T_P512TO1023; /*!< [0x238] Tx 512- to 1023-byte Packets Statistic Register */
    __I hw_enet_rmon_t_p1024to2047_t RMON_T_P1024TO2047; /*!< [0x23C] Tx 1024- to 2047-byte Packets Statistic Register */
    __I hw_enet_rmon_t_p_gte2048_t RMON_T_P_GTE2048; /*!< [0x240] Tx Packets Greater Than 2048 Bytes Statistic Register */
    __I hw_enet_rmon_t_octets_t RMON_T_OCTETS; /*!< [0x244] Tx Octets Statistic Register */
    __I hw_enet_ieee_t_drop_t IEEE_T_DROP; /*!< [0x248] Reserved Statistic Register */
    __I hw_enet_ieee_t_frame_ok_t IEEE_T_FRAME_OK; /*!< [0x24C] Frames Transmitted OK Statistic Register */
    __I hw_enet_ieee_t_1col_t IEEE_T_1COL; /*!< [0x250] Frames Transmitted with Single Collision Statistic Register */
    __I hw_enet_ieee_t_mcol_t IEEE_T_MCOL; /*!< [0x254] Frames Transmitted with Multiple Collisions Statistic Register */
    __I hw_enet_ieee_t_def_t IEEE_T_DEF;   /*!< [0x258] Frames Transmitted after Deferral Delay Statistic Register */
    __I hw_enet_ieee_t_lcol_t IEEE_T_LCOL; /*!< [0x25C] Frames Transmitted with Late Collision Statistic Register */
    __I hw_enet_ieee_t_excol_t IEEE_T_EXCOL; /*!< [0x260] Frames Transmitted with Excessive Collisions Statistic Register */
    __I hw_enet_ieee_t_macerr_t IEEE_T_MACERR; /*!< [0x264] Frames Transmitted with Tx FIFO Underrun Statistic Register */
    __I hw_enet_ieee_t_cserr_t IEEE_T_CSERR; /*!< [0x268] Frames Transmitted with Carrier Sense Error Statistic Register */
    __I hw_enet_ieee_t_sqe_t IEEE_T_SQE;   /*!< [0x26C] Reserved Statistic Register */
    __I hw_enet_ieee_t_fdxfc_t IEEE_T_FDXFC; /*!< [0x270] Flow Control Pause Frames Transmitted Statistic Register */
    __I hw_enet_ieee_t_octets_ok_t IEEE_T_OCTETS_OK; /*!< [0x274] Octet Count for Frames Transmitted w/o Error Statistic Register */
    uint8_t _reserved17[12];
    __I hw_enet_rmon_r_packets_t RMON_R_PACKETS; /*!< [0x284] Rx Packet Count Statistic Register */
    __I hw_enet_rmon_r_bc_pkt_t RMON_R_BC_PKT; /*!< [0x288] Rx Broadcast Packets Statistic Register */
    __I hw_enet_rmon_r_mc_pkt_t RMON_R_MC_PKT; /*!< [0x28C] Rx Multicast Packets Statistic Register */
    __I hw_enet_rmon_r_crc_align_t RMON_R_CRC_ALIGN; /*!< [0x290] Rx Packets with CRC/Align Error Statistic Register */
    __I hw_enet_rmon_r_undersize_t RMON_R_UNDERSIZE; /*!< [0x294] Rx Packets with Less Than 64 Bytes and Good CRC Statistic Register */
    __I hw_enet_rmon_r_oversize_t RMON_R_OVERSIZE; /*!< [0x298] Rx Packets Greater Than MAX_FL and Good CRC Statistic Register */
    __I hw_enet_rmon_r_frag_t RMON_R_FRAG; /*!< [0x29C] Rx Packets Less Than 64 Bytes and Bad CRC Statistic Register */
    __I hw_enet_rmon_r_jab_t RMON_R_JAB;   /*!< [0x2A0] Rx Packets Greater Than MAX_FL Bytes and Bad CRC Statistic Register */
    __I hw_enet_rmon_r_resvd_0_t RMON_R_RESVD_0; /*!< [0x2A4] Reserved Statistic Register */
    __I hw_enet_rmon_r_p64_t RMON_R_P64;   /*!< [0x2A8] Rx 64-Byte Packets Statistic Register */
    __I hw_enet_rmon_r_p65to127_t RMON_R_P65TO127; /*!< [0x2AC] Rx 65- to 127-Byte Packets Statistic Register */
    __I hw_enet_rmon_r_p128to255_t RMON_R_P128TO255; /*!< [0x2B0] Rx 128- to 255-Byte Packets Statistic Register */
    __I hw_enet_rmon_r_p256to511_t RMON_R_P256TO511; /*!< [0x2B4] Rx 256- to 511-Byte Packets Statistic Register */
    __I hw_enet_rmon_r_p512to1023_t RMON_R_P512TO1023; /*!< [0x2B8] Rx 512- to 1023-Byte Packets Statistic Register */
    __I hw_enet_rmon_r_p1024to2047_t RMON_R_P1024TO2047; /*!< [0x2BC] Rx 1024- to 2047-Byte Packets Statistic Register */
    __I hw_enet_rmon_r_p_gte2048_t RMON_R_P_GTE2048; /*!< [0x2C0] Rx Packets Greater than 2048 Bytes Statistic Register */
    __I hw_enet_rmon_r_octets_t RMON_R_OCTETS; /*!< [0x2C4] Rx Octets Statistic Register */
    __I hw_enet_ieee_r_drop_t IEEE_R_DROP; /*!< [0x2C8] Frames not Counted Correctly Statistic Register */
    __I hw_enet_ieee_r_frame_ok_t IEEE_R_FRAME_OK; /*!< [0x2CC] Frames Received OK Statistic Register */
    __I hw_enet_ieee_r_crc_t IEEE_R_CRC;   /*!< [0x2D0] Frames Received with CRC Error Statistic Register */
    __I hw_enet_ieee_r_align_t IEEE_R_ALIGN; /*!< [0x2D4] Frames Received with Alignment Error Statistic Register */
    __I hw_enet_ieee_r_macerr_t IEEE_R_MACERR; /*!< [0x2D8] Receive FIFO Overflow Count Statistic Register */
    __I hw_enet_ieee_r_fdxfc_t IEEE_R_FDXFC; /*!< [0x2DC] Flow Control Pause Frames Received Statistic Register */
    __I hw_enet_ieee_r_octets_ok_t IEEE_R_OCTETS_OK; /*!< [0x2E0] Octet Count for Frames Received without Error Statistic Register */
    uint8_t _reserved18[284];
    __IO hw_enet_atcr_t ATCR;              /*!< [0x400] Adjustable Timer Control Register */
    __IO hw_enet_atvr_t ATVR;              /*!< [0x404] Timer Value Register */
    __IO hw_enet_atoff_t ATOFF;            /*!< [0x408] Timer Offset Register */
    __IO hw_enet_atper_t ATPER;            /*!< [0x40C] Timer Period Register */
    __IO hw_enet_atcor_t ATCOR;            /*!< [0x410] Timer Correction Register */
    __IO hw_enet_atinc_t ATINC;            /*!< [0x414] Time-Stamping Clock Period Register */
    __I hw_enet_atstmp_t ATSTMP;           /*!< [0x418] Timestamp of Last Transmitted Frame */
    uint8_t _reserved19[488];
    __IO hw_enet_tgsr_t TGSR;              /*!< [0x604] Timer Global Status Register */
    struct {
        __IO hw_enet_tcsrn_t TCSRn;        /*!< [0x608] Timer Control Status Register */
        __IO hw_enet_tccrn_t TCCRn;        /*!< [0x60C] Timer Compare Capture Register */
    } CHANNEL[4];
} hw_enet_t;
#pragma pack()

/*! @brief Macro to access all ENET registers. */
/*! @param x ENET module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_ENET_REGS(ENET1_BASE)</code>. */
#define HW_ENET_REGS(x) (*(hw_enet_t *)(x))

/*
 * iMX7D EPDC
 *
 * Electrophoretic Display Controller (EPDC)
 *
 * Registers defined in this header file:
 * - HW_EPDC_CTRL - EPDC Control Register
 * - HW_EPDC_WB_ADDR_TCE - EPDC Working Buffer Address for TCE
 * - HW_EPDC_WVADDR - EPDC Waveform Address Pointer
 * - HW_EPDC_WB_ADDR - EPDC Working Buffer Address
 * - HW_EPDC_RES - EPDC Screen Resolution
 * - HW_EPDC_FORMAT - EPDC Format Control Register
 * - HW_EPDC_WB_FIELD0 - Working Buffer Field Setting
 * - HW_EPDC_WB_FIELD1 - Working Buffer Field Setting
 * - HW_EPDC_WB_FIELD2 - Working Buffer Field Setting
 * - HW_EPDC_WB_FIELD3 - Working Buffer Field Setting
 * - HW_EPDC_FIFOCTRL - EPDC FIFO control register
 * - HW_EPDC_UPD_ADDR - EPDC Update Region Address
 * - HW_EPDC_UPD_STRIDE - EPDC Update Region Stride
 * - HW_EPDC_UPD_CORD - EPDC Update Command Co-ordinate
 * - HW_EPDC_UPD_SIZE - EPDC Update Command Size
 * - HW_EPDC_UPD_CTRL - EPDC Update Command Control
 * - HW_EPDC_UPD_FIXED - EPDC Update Fixed Pixel Control
 * - HW_EPDC_TEMP - EPDC Temperature Register
 * - HW_EPDC_AUTOWV_LUT - Waveform Mode Lookup Table Control Register.
 * - HW_EPDC_LUT_STANDBY1 - EPDC LUT Standby Register for LUT 31~0
 * - HW_EPDC_LUT_STANDBY2 - EPDC LUT Standby Registerr for LUT 63~32
 * - HW_EPDC_TCE_CTRL - EPDC Timing Control Engine Control Register
 * - HW_EPDC_TCE_SDCFG - EPDC Timing Control Engine Source-Driver Config Register
 * - HW_EPDC_TCE_GDCFG - EPDC Timing Control Engine Gate-Driver Config Register
 * - HW_EPDC_TCE_HSCAN1 - EPDC Timing Control Engine Horizontal Timing Register 1
 * - HW_EPDC_TCE_HSCAN2 - EPDC Timing Control Engine Horizontal Timing Register 2
 * - HW_EPDC_TCE_VSCAN - EPDC Timing Control Engine Vertical Timing Register
 * - HW_EPDC_TCE_OE - EPDC Timing Control Engine OE timing control Register
 * - HW_EPDC_TCE_POLARITY - EPDC Timing Control Engine Driver Polarity Register
 * - HW_EPDC_TCE_TIMING1 - EPDC Timing Control Engine Timing Register 1
 * - HW_EPDC_TCE_TIMING2 - EPDC Timing Control Engine Timing Register 2
 * - HW_EPDC_TCE_TIMING3 - EPDC Timing Control Engine Timing Register 3
 * - HW_EPDC_PIGEON_CTRL0 - EPDC Pigeon Mode Control Register 0
 * - HW_EPDC_PIGEON_CTRL1 - EPDC Pigeon Mode Control Register 1
 * - HW_EPDC_IRQ_MASK1 - EPDC IRQ Mask Register for LUT 0~31
 * - HW_EPDC_IRQ_MASK2 - EPDC IRQ Mask Register for LUT 32~63
 * - HW_EPDC_IRQ1 - EPDC Interrupt Register for LUT 0~31
 * - HW_EPDC_IRQ2 - EPDC Interrupt Registerr for LUT 32~63
 * - HW_EPDC_IRQ_MASK - EPDC IRQ Mask Register
 * - HW_EPDC_IRQ - EPDC Interrupt Register
 * - HW_EPDC_STATUS_LUTS1 - EPDC Status Register - LUTs
 * - HW_EPDC_STATUS_LUTS2 - EPDC Status Register - LUTs
 * - HW_EPDC_STATUS_NEXTLUT - EPDC Status Register - Next Available LUT
 * - HW_EPDC_STATUS_COL1 - EPDC LUT Collision Status
 * - HW_EPDC_STATUS_COL2 - EPDC LUT Collision Status
 * - HW_EPDC_STATUS - EPDC General Status Register
 * - HW_EPDC_UPD_COL_CORD - EPDC Collision Region Co-ordinate
 * - HW_EPDC_UPD_COL_SIZE - EPDC Collision Region Size
 * - HW_EPDC_HIST1_PARAM - 1-level Histogram Parameter Register.
 * - HW_EPDC_HIST2_PARAM - 2-level Histogram Parameter Register.
 * - HW_EPDC_HIST4_PARAM - 4-level Histogram Parameter Register.
 * - HW_EPDC_HIST8_PARAM0 - 8-level Histogram Parameter 0 Register.
 * - HW_EPDC_HIST8_PARAM1 - 8-level Histogram Parameter 1 Register.
 * - HW_EPDC_HIST16_PARAM0 - 16-level Histogram Parameter 0 Register.
 * - HW_EPDC_HIST16_PARAM1 - 16-level Histogram Parameter Register.
 * - HW_EPDC_HIST16_PARAM2 - 16-level Histogram Parameter Register.
 * - HW_EPDC_HIST16_PARAM3 - 16-level Histogram Parameter Register.
 * - HW_EPDC_GPIO - EPDC General Purpose I/O Debug register
 * - HW_EPDC_VERSION - EPDC Version Register
 * - HW_EPDC_PIGEON_0_0 - Panel Interface Signal Generator Register 0_0
 * - HW_EPDC_PIGEON_0_1 - Panel Interface Signal Generator Register 0_1
 * - HW_EPDC_PIGEON_0_2 - Panel Interface Signal Generator Register 0_1
 * - HW_EPDC_PIGEON_1_0 - Panel Interface Signal Generator Register 1_0
 * - HW_EPDC_PIGEON_1_1 - Panel Interface Signal Generator Register 1_1
 * - HW_EPDC_PIGEON_1_2 - Panel Interface Signal Generator Register 1_1
 * - HW_EPDC_PIGEON_2_0 - Panel Interface Signal Generator Register 2_0
 * - HW_EPDC_PIGEON_2_1 - Panel Interface Signal Generator Register 2_1
 * - HW_EPDC_PIGEON_2_2 - Panel Interface Signal Generator Register 2_1
 * - HW_EPDC_PIGEON_3_0 - Panel Interface Signal Generator Register 3_0
 * - HW_EPDC_PIGEON_3_1 - Panel Interface Signal Generator Register 3_1
 * - HW_EPDC_PIGEON_3_2 - Panel Interface Signal Generator Register 3_1
 * - HW_EPDC_PIGEON_4_0 - Panel Interface Signal Generator Register 4_0
 * - HW_EPDC_PIGEON_4_1 - Panel Interface Signal Generator Register 4_1
 * - HW_EPDC_PIGEON_4_2 - Panel Interface Signal Generator Register 4_1
 * - HW_EPDC_PIGEON_5_0 - Panel Interface Signal Generator Register 5_0
 * - HW_EPDC_PIGEON_5_1 - Panel Interface Signal Generator Register 5_1
 * - HW_EPDC_PIGEON_5_2 - Panel Interface Signal Generator Register 5_1
 * - HW_EPDC_PIGEON_6_0 - Panel Interface Signal Generator Register 6_0
 * - HW_EPDC_PIGEON_6_1 - Panel Interface Signal Generator Register 6_1
 * - HW_EPDC_PIGEON_6_2 - Panel Interface Signal Generator Register 6_1
 * - HW_EPDC_PIGEON_7_0 - Panel Interface Signal Generator Register 7_0
 * - HW_EPDC_PIGEON_7_1 - Panel Interface Signal Generator Register 7_1
 * - HW_EPDC_PIGEON_7_2 - Panel Interface Signal Generator Register 7_1
 * - HW_EPDC_PIGEON_8_0 - Panel Interface Signal Generator Register 8_0
 * - HW_EPDC_PIGEON_8_1 - Panel Interface Signal Generator Register 8_1
 * - HW_EPDC_PIGEON_8_2 - Panel Interface Signal Generator Register 8_1
 * - HW_EPDC_PIGEON_9_0 - Panel Interface Signal Generator Register 9_0
 * - HW_EPDC_PIGEON_9_1 - Panel Interface Signal Generator Register 9_1
 * - HW_EPDC_PIGEON_9_2 - Panel Interface Signal Generator Register 9_1
 * - HW_EPDC_PIGEON_10_0 - Panel Interface Signal Generator Register 10_0
 * - HW_EPDC_PIGEON_10_1 - Panel Interface Signal Generator Register 10_1
 * - HW_EPDC_PIGEON_10_2 - Panel Interface Signal Generator Register 10_1
 * - HW_EPDC_PIGEON_11_0 - Panel Interface Signal Generator Register 11_0
 * - HW_EPDC_PIGEON_11_1 - Panel Interface Signal Generator Register 11_1
 * - HW_EPDC_PIGEON_11_2 - Panel Interface Signal Generator Register 11_1
 * - HW_EPDC_PIGEON_12_0 - Panel Interface Signal Generator Register 12_0
 * - HW_EPDC_PIGEON_12_1 - Panel Interface Signal Generator Register 12_1
 * - HW_EPDC_PIGEON_12_2 - Panel Interface Signal Generator Register 12_1
 * - HW_EPDC_PIGEON_13_0 - Panel Interface Signal Generator Register 13_0
 * - HW_EPDC_PIGEON_13_1 - Panel Interface Signal Generator Register 13_1
 * - HW_EPDC_PIGEON_13_2 - Panel Interface Signal Generator Register 13_1
 * - HW_EPDC_PIGEON_14_0 - Panel Interface Signal Generator Register 14_0
 * - HW_EPDC_PIGEON_14_1 - Panel Interface Signal Generator Register 14_1
 * - HW_EPDC_PIGEON_14_2 - Panel Interface Signal Generator Register 14_1
 * - HW_EPDC_PIGEON_15_0 - Panel Interface Signal Generator Register 15_0
 * - HW_EPDC_PIGEON_15_1 - Panel Interface Signal Generator Register 15_1
 * - HW_EPDC_PIGEON_15_2 - Panel Interface Signal Generator Register 15_1
 * - HW_EPDC_PIGEON_16_0 - Panel Interface Signal Generator Register 16_0
 * - HW_EPDC_PIGEON_16_1 - Panel Interface Signal Generator Register 16_1
 * - HW_EPDC_PIGEON_16_2 - Panel Interface Signal Generator Register 16_1
 *
 * - hw_epdc_t - Struct containing all module registers.
 */

#define HW_EPDC_INSTANCE_COUNT (1U) /*!< Number of instances of the EPDC module. */
#define HW_EPDC (0U) /*!< Instance number for EPDC. */
#define EPDC_BASE             (0x306F0000U) /*!< Base address for EPDC. */
/*! Array initializer of EPDC base addresses. */
#define EPDC_BASE_ADDRS       { EPDC_BASE }

/*******************************************************************************
 * HW_EPDC_CTRL - EPDC Control Register
 ******************************************************************************/

/*!
 * @brief HW_EPDC_CTRL - EPDC Control Register (RW)
 *
 * Reset value: 0xC0000000U
 *
 * EPDC Main control register This register controls various high-level
 * functions of the EPDC EXAMPLE /- Reset -/ __raw_writel(EPDC_CTRL_SFTRST,
 * EPDC_CTRL_SET); while (!(__raw_readl(EPDC_CTRL) & EPDC_CTRL_CLKGATE)) ;
 * __raw_writel(EPDC_CTRL_SFTRST, EPDC_CTRL_CLEAR); /- Enable clock gating (clear to enable) -/
 * __raw_writel(EPDC_CTRL_CLKGATE, EPDC_CTRL_CLEAR); while (__raw_readl(EPDC_CTRL) &
 * (EPDC_CTRL_SFTRST | EPDC_CTRL_CLKGATE)) ; /- EPDC_CTRL -/ reg_val =
 * __raw_readl(EPDC_CTRL); reg_val &= ~EPDC_CTRL_UPD_DATA_SWIZZLE_MASK; reg_val |=
 * EPDC_CTRL_UPD_DATA_SWIZZLE_NO_SWAP; reg_val &= ~EPDC_CTRL_LUT_DATA_SWIZZLE_MASK;
 * reg_val |= EPDC_CTRL_LUT_DATA_SWIZZLE_NO_SWAP; __raw_writel(reg_val, EPDC_CTRL_SET);
 */
typedef union _hw_epdc_ctrl
{
    uint32_t U;
    struct _hw_epdc_ctrl_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t LUT_DATA_SWIZZLE : 2; /*!< [5:4]  */
        uint32_t UPD_DATA_SWIZZLE : 2; /*!< [7:6]  */
        uint32_t RESERVED1 : 22;       /*!< [29:8]  */
        uint32_t CLKGATE : 1;          /*!< [30]  */
        uint32_t SFTRST : 1;           /*!< [31]  */
    } B;
} hw_epdc_ctrl_t;

/*!
 * @name Constants and macros for entire EPDC_CTRL register
 */
/*@{*/
#define HW_EPDC_CTRL_ADDR(x)     ((uintptr_t)(x) + 0x0U)
#define HW_EPDC_CTRL_SET_ADDR(x) (HW_EPDC_CTRL_ADDR(x) + 0x4U)
#define HW_EPDC_CTRL_CLR_ADDR(x) (HW_EPDC_CTRL_ADDR(x) + 0x8U)
#define HW_EPDC_CTRL_TOG_ADDR(x) (HW_EPDC_CTRL_ADDR(x) + 0xCU)

#define HW_EPDC_CTRL(x)          (*(__IO hw_epdc_ctrl_t *) HW_EPDC_CTRL_ADDR(x))
#define HW_EPDC_CTRL_RD(x)       (HW_EPDC_CTRL(x).U)
#define HW_EPDC_CTRL_WR(x, v)    (HW_EPDC_CTRL(x).U = (v))
#define HW_EPDC_CTRL_SET(x, v)   ((*(uint32_t *) HW_EPDC_CTRL_SET_ADDR(x)) = (v))
#define HW_EPDC_CTRL_CLR(x, v)   ((*(uint32_t *) HW_EPDC_CTRL_CLR_ADDR(x)) = (v))
#define HW_EPDC_CTRL_TOG(x, v)   ((*(uint32_t *) HW_EPDC_CTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_CTRL bitfields
 */

/*!
 * @name Register EPDC_CTRL, field LUT_DATA_SWIZZLE[5:4] (RW)
 *
 * Specifies how to swap the bytes for the LUT data before store to LUTRAM.
 * Supported configurations:
 *
 * Values:
 * - 0 - No byte swapping.(Little endian)
 * - 1 - Swizzle all bytes, swap bytes 0,3 and 1,2 (aka Big Endian).
 * - 10 - Swap half-words.
 * - 11 - Swap bytes within each half-word.
 */
/*@{*/
#define BP_EPDC_CTRL_LUT_DATA_SWIZZLE (4U) /*!< Bit position for EPDC_CTRL_LUT_DATA_SWIZZLE. */
#define BM_EPDC_CTRL_LUT_DATA_SWIZZLE (0x00000030U) /*!< Bit mask for EPDC_CTRL_LUT_DATA_SWIZZLE. */
#define BS_EPDC_CTRL_LUT_DATA_SWIZZLE (2U) /*!< Bit field size in bits for EPDC_CTRL_LUT_DATA_SWIZZLE. */

#define BV_EPDC_CTRL_LUT_DATA_SWIZZLE_NO_SWAP (0U)   /*!< Bit field value for EPDC_CTRL_LUT_DATA_SWIZZLE: No byte swapping.(Little endian) */
#define BV_EPDC_CTRL_LUT_DATA_SWIZZLE_ALL_BYTES_SWAP (0x1U) /*!< Bit field value for EPDC_CTRL_LUT_DATA_SWIZZLE: Swizzle all bytes, swap bytes 0,3 and 1,2 (aka Big Endian). */
#define BV_EPDC_CTRL_LUT_DATA_SWIZZLE_HWD_SWAP (0x2U) /*!< Bit field value for EPDC_CTRL_LUT_DATA_SWIZZLE: Swap half-words. */
#define BV_EPDC_CTRL_LUT_DATA_SWIZZLE_HWD_BYTE_SWAP (0x3U) /*!< Bit field value for EPDC_CTRL_LUT_DATA_SWIZZLE: Swap bytes within each half-word. */

/*! @brief Read current value of the EPDC_CTRL_LUT_DATA_SWIZZLE field. */
#define BR_EPDC_CTRL_LUT_DATA_SWIZZLE(x) (HW_EPDC_CTRL(x).B.LUT_DATA_SWIZZLE)

/*! @brief Format value for bitfield EPDC_CTRL_LUT_DATA_SWIZZLE. */
#define BF_EPDC_CTRL_LUT_DATA_SWIZZLE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_CTRL_LUT_DATA_SWIZZLE) & BM_EPDC_CTRL_LUT_DATA_SWIZZLE)

/*! @brief Set the LUT_DATA_SWIZZLE field to a new value. */
#define BW_EPDC_CTRL_LUT_DATA_SWIZZLE(x, v) (HW_EPDC_CTRL_WR(x, (HW_EPDC_CTRL_RD(x) & ~BM_EPDC_CTRL_LUT_DATA_SWIZZLE) | BF_EPDC_CTRL_LUT_DATA_SWIZZLE(v)))
/*@}*/

/*!
 * @name Register EPDC_CTRL, field UPD_DATA_SWIZZLE[7:6] (RW)
 *
 * Specifies how to swap the bytes for the UPD data before the WB construction.
 * Plesae note this swizzle operate right after data fetch from bus, no matter
 * it's aligned access or not. Supported configurations:
 *
 * Values:
 * - 0 - No byte swapping.(Little endian)
 * - 1 - Swizzle all bytes, swap bytes 0,3 and 1,2 (aka Big Endian).
 * - 10 - Swap half-words.
 * - 11 - Swap bytes within each half-word.
 */
/*@{*/
#define BP_EPDC_CTRL_UPD_DATA_SWIZZLE (6U) /*!< Bit position for EPDC_CTRL_UPD_DATA_SWIZZLE. */
#define BM_EPDC_CTRL_UPD_DATA_SWIZZLE (0x000000C0U) /*!< Bit mask for EPDC_CTRL_UPD_DATA_SWIZZLE. */
#define BS_EPDC_CTRL_UPD_DATA_SWIZZLE (2U) /*!< Bit field size in bits for EPDC_CTRL_UPD_DATA_SWIZZLE. */

#define BV_EPDC_CTRL_UPD_DATA_SWIZZLE_NO_SWAP (0U)   /*!< Bit field value for EPDC_CTRL_UPD_DATA_SWIZZLE: No byte swapping.(Little endian) */
#define BV_EPDC_CTRL_UPD_DATA_SWIZZLE_ALL_BYTES_SWAP (0x1U) /*!< Bit field value for EPDC_CTRL_UPD_DATA_SWIZZLE: Swizzle all bytes, swap bytes 0,3 and 1,2 (aka Big Endian). */
#define BV_EPDC_CTRL_UPD_DATA_SWIZZLE_HWD_SWAP (0x2U) /*!< Bit field value for EPDC_CTRL_UPD_DATA_SWIZZLE: Swap half-words. */
#define BV_EPDC_CTRL_UPD_DATA_SWIZZLE_HWD_BYTE_SWAP (0x3U) /*!< Bit field value for EPDC_CTRL_UPD_DATA_SWIZZLE: Swap bytes within each half-word. */

/*! @brief Read current value of the EPDC_CTRL_UPD_DATA_SWIZZLE field. */
#define BR_EPDC_CTRL_UPD_DATA_SWIZZLE(x) (HW_EPDC_CTRL(x).B.UPD_DATA_SWIZZLE)

/*! @brief Format value for bitfield EPDC_CTRL_UPD_DATA_SWIZZLE. */
#define BF_EPDC_CTRL_UPD_DATA_SWIZZLE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_CTRL_UPD_DATA_SWIZZLE) & BM_EPDC_CTRL_UPD_DATA_SWIZZLE)

/*! @brief Set the UPD_DATA_SWIZZLE field to a new value. */
#define BW_EPDC_CTRL_UPD_DATA_SWIZZLE(x, v) (HW_EPDC_CTRL_WR(x, (HW_EPDC_CTRL_RD(x) & ~BM_EPDC_CTRL_UPD_DATA_SWIZZLE) | BF_EPDC_CTRL_UPD_DATA_SWIZZLE(v)))
/*@}*/

/*!
 * @name Register EPDC_CTRL, field CLKGATE[30] (RW)
 *
 * This bit must be set to zero for normal operation. When set to one it gates
 * off the clocks to the block.
 */
/*@{*/
#define BP_EPDC_CTRL_CLKGATE (30U)         /*!< Bit position for EPDC_CTRL_CLKGATE. */
#define BM_EPDC_CTRL_CLKGATE (0x40000000U) /*!< Bit mask for EPDC_CTRL_CLKGATE. */
#define BS_EPDC_CTRL_CLKGATE (1U)          /*!< Bit field size in bits for EPDC_CTRL_CLKGATE. */

/*! @brief Read current value of the EPDC_CTRL_CLKGATE field. */
#define BR_EPDC_CTRL_CLKGATE(x) (HW_EPDC_CTRL(x).B.CLKGATE)

/*! @brief Format value for bitfield EPDC_CTRL_CLKGATE. */
#define BF_EPDC_CTRL_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_CTRL_CLKGATE) & BM_EPDC_CTRL_CLKGATE)

/*! @brief Set the CLKGATE field to a new value. */
#define BW_EPDC_CTRL_CLKGATE(x, v) (HW_EPDC_CTRL_WR(x, (HW_EPDC_CTRL_RD(x) & ~BM_EPDC_CTRL_CLKGATE) | BF_EPDC_CTRL_CLKGATE(v)))
/*@}*/

/*!
 * @name Register EPDC_CTRL, field SFTRST[31] (RW)
 *
 * Set this bit to zero to enable normal EPDC operation. Set this bit to one
 * (default) to disable clocking with the EPDC and hold it in its reset (lowest
 * power) state. This bit can be turned on and then off to reset the EPDC block to
 * its default state.
 */
/*@{*/
#define BP_EPDC_CTRL_SFTRST  (31U)         /*!< Bit position for EPDC_CTRL_SFTRST. */
#define BM_EPDC_CTRL_SFTRST  (0x80000000U) /*!< Bit mask for EPDC_CTRL_SFTRST. */
#define BS_EPDC_CTRL_SFTRST  (1U)          /*!< Bit field size in bits for EPDC_CTRL_SFTRST. */

/*! @brief Read current value of the EPDC_CTRL_SFTRST field. */
#define BR_EPDC_CTRL_SFTRST(x) (HW_EPDC_CTRL(x).B.SFTRST)

/*! @brief Format value for bitfield EPDC_CTRL_SFTRST. */
#define BF_EPDC_CTRL_SFTRST(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_CTRL_SFTRST) & BM_EPDC_CTRL_SFTRST)

/*! @brief Set the SFTRST field to a new value. */
#define BW_EPDC_CTRL_SFTRST(x, v) (HW_EPDC_CTRL_WR(x, (HW_EPDC_CTRL_RD(x) & ~BM_EPDC_CTRL_SFTRST) | BF_EPDC_CTRL_SFTRST(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_WB_ADDR_TCE - EPDC Working Buffer Address for TCE
 ******************************************************************************/

/*!
 * @brief HW_EPDC_WB_ADDR_TCE - EPDC Working Buffer Address for TCE (RW)
 *
 * Reset value: 0x00000000U
 *
 * EPDC Working Buffer Address for TCE
 */
typedef union _hw_epdc_wb_addr_tce
{
    uint32_t U;
    struct _hw_epdc_wb_addr_tce_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_epdc_wb_addr_tce_t;

/*!
 * @name Constants and macros for entire EPDC_WB_ADDR_TCE register
 */
/*@{*/
#define HW_EPDC_WB_ADDR_TCE_ADDR(x) ((uintptr_t)(x) + 0x10U)

#define HW_EPDC_WB_ADDR_TCE(x)   (*(__IO hw_epdc_wb_addr_tce_t *) HW_EPDC_WB_ADDR_TCE_ADDR(x))
#define HW_EPDC_WB_ADDR_TCE_RD(x) (HW_EPDC_WB_ADDR_TCE(x).U)
#define HW_EPDC_WB_ADDR_TCE_WR(x, v) (HW_EPDC_WB_ADDR_TCE(x).U = (v))
#define HW_EPDC_WB_ADDR_TCE_SET(x, v) (HW_EPDC_WB_ADDR_TCE_WR(x, HW_EPDC_WB_ADDR_TCE_RD(x) |  (v)))
#define HW_EPDC_WB_ADDR_TCE_CLR(x, v) (HW_EPDC_WB_ADDR_TCE_WR(x, HW_EPDC_WB_ADDR_TCE_RD(x) & ~(v)))
#define HW_EPDC_WB_ADDR_TCE_TOG(x, v) (HW_EPDC_WB_ADDR_TCE_WR(x, HW_EPDC_WB_ADDR_TCE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_WB_ADDR_TCE bitfields
 */

/*!
 * @name Register EPDC_WB_ADDR_TCE, field ADDR[31:0] (RW)
 *
 * Address for EPDC working buffer. This address must be a aligned to a 64-bit
 * double-word boundary.
 */
/*@{*/
#define BP_EPDC_WB_ADDR_TCE_ADDR (0U)      /*!< Bit position for EPDC_WB_ADDR_TCE_ADDR. */
#define BM_EPDC_WB_ADDR_TCE_ADDR (0xFFFFFFFFU) /*!< Bit mask for EPDC_WB_ADDR_TCE_ADDR. */
#define BS_EPDC_WB_ADDR_TCE_ADDR (32U)     /*!< Bit field size in bits for EPDC_WB_ADDR_TCE_ADDR. */

/*! @brief Read current value of the EPDC_WB_ADDR_TCE_ADDR field. */
#define BR_EPDC_WB_ADDR_TCE_ADDR(x) (HW_EPDC_WB_ADDR_TCE(x).U)

/*! @brief Format value for bitfield EPDC_WB_ADDR_TCE_ADDR. */
#define BF_EPDC_WB_ADDR_TCE_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_ADDR_TCE_ADDR) & BM_EPDC_WB_ADDR_TCE_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_EPDC_WB_ADDR_TCE_ADDR(x, v) (HW_EPDC_WB_ADDR_TCE_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_EPDC_WVADDR - EPDC Waveform Address Pointer
 ******************************************************************************/

/*!
 * @brief HW_EPDC_WVADDR - EPDC Waveform Address Pointer (RW)
 *
 * Reset value: 0x00000000U
 *
 * EPDC Waveform Address Pointer EXAMPLE /- Reset -/
 * __raw_writel(EPDC_CTRL_SFTRST, EPDC_CTRL_SET); while (!(__raw_readl(EPDC_CTRL) & EPDC_CTRL_CLKGATE)) ;
 * __raw_writel(EPDC_CTRL_SFTRST, EPDC_CTRL_CLEAR); /- Enable clock gating (clear
 * to enable) -/ __raw_writel(EPDC_CTRL_CLKGATE, EPDC_CTRL_CLEAR); while
 * (__raw_readl(EPDC_CTRL) & (EPDC_CTRL_SFTRST | EPDC_CTRL_CLKGATE)) ; /- EPDC_CTRL -/
 * reg_val = __raw_readl(EPDC_CTRL); reg_val &= ~EPDC_CTRL_UPD_DATA_SWIZZLE_MASK;
 * reg_val |= EPDC_CTRL_UPD_DATA_SWIZZLE_NO_SWAP; reg_val &=
 * ~EPDC_CTRL_LUT_DATA_SWIZZLE_MASK; reg_val |= EPDC_CTRL_LUT_DATA_SWIZZLE_NO_SWAP;
 * __raw_writel(reg_val, EPDC_CTRL_SET);
 */
typedef union _hw_epdc_wvaddr
{
    uint32_t U;
    struct _hw_epdc_wvaddr_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_epdc_wvaddr_t;

/*!
 * @name Constants and macros for entire EPDC_WVADDR register
 */
/*@{*/
#define HW_EPDC_WVADDR_ADDR(x)   ((uintptr_t)(x) + 0x20U)

#define HW_EPDC_WVADDR(x)        (*(__IO hw_epdc_wvaddr_t *) HW_EPDC_WVADDR_ADDR(x))
#define HW_EPDC_WVADDR_RD(x)     (HW_EPDC_WVADDR(x).U)
#define HW_EPDC_WVADDR_WR(x, v)  (HW_EPDC_WVADDR(x).U = (v))
#define HW_EPDC_WVADDR_SET(x, v) (HW_EPDC_WVADDR_WR(x, HW_EPDC_WVADDR_RD(x) |  (v)))
#define HW_EPDC_WVADDR_CLR(x, v) (HW_EPDC_WVADDR_WR(x, HW_EPDC_WVADDR_RD(x) & ~(v)))
#define HW_EPDC_WVADDR_TOG(x, v) (HW_EPDC_WVADDR_WR(x, HW_EPDC_WVADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_WVADDR bitfields
 */

/*!
 * @name Register EPDC_WVADDR, field ADDR[31:0] (RW)
 *
 * Start address of waveform tables. This address needs to be aligned to a
 * 64-bit word boundary.
 */
/*@{*/
#define BP_EPDC_WVADDR_ADDR  (0U)          /*!< Bit position for EPDC_WVADDR_ADDR. */
#define BM_EPDC_WVADDR_ADDR  (0xFFFFFFFFU) /*!< Bit mask for EPDC_WVADDR_ADDR. */
#define BS_EPDC_WVADDR_ADDR  (32U)         /*!< Bit field size in bits for EPDC_WVADDR_ADDR. */

/*! @brief Read current value of the EPDC_WVADDR_ADDR field. */
#define BR_EPDC_WVADDR_ADDR(x) (HW_EPDC_WVADDR(x).U)

/*! @brief Format value for bitfield EPDC_WVADDR_ADDR. */
#define BF_EPDC_WVADDR_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WVADDR_ADDR) & BM_EPDC_WVADDR_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_EPDC_WVADDR_ADDR(x, v) (HW_EPDC_WVADDR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_EPDC_WB_ADDR - EPDC Working Buffer Address
 ******************************************************************************/

/*!
 * @brief HW_EPDC_WB_ADDR - EPDC Working Buffer Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * EPDC Working Buffer Address This register points to the address of current
 * working buffer.
 */
typedef union _hw_epdc_wb_addr
{
    uint32_t U;
    struct _hw_epdc_wb_addr_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_epdc_wb_addr_t;

/*!
 * @name Constants and macros for entire EPDC_WB_ADDR register
 */
/*@{*/
#define HW_EPDC_WB_ADDR_ADDR(x)  ((uintptr_t)(x) + 0x30U)

#define HW_EPDC_WB_ADDR(x)       (*(__IO hw_epdc_wb_addr_t *) HW_EPDC_WB_ADDR_ADDR(x))
#define HW_EPDC_WB_ADDR_RD(x)    (HW_EPDC_WB_ADDR(x).U)
#define HW_EPDC_WB_ADDR_WR(x, v) (HW_EPDC_WB_ADDR(x).U = (v))
#define HW_EPDC_WB_ADDR_SET(x, v) (HW_EPDC_WB_ADDR_WR(x, HW_EPDC_WB_ADDR_RD(x) |  (v)))
#define HW_EPDC_WB_ADDR_CLR(x, v) (HW_EPDC_WB_ADDR_WR(x, HW_EPDC_WB_ADDR_RD(x) & ~(v)))
#define HW_EPDC_WB_ADDR_TOG(x, v) (HW_EPDC_WB_ADDR_WR(x, HW_EPDC_WB_ADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_WB_ADDR bitfields
 */

/*!
 * @name Register EPDC_WB_ADDR, field ADDR[31:0] (RW)
 *
 * Address for EPDC working buffer. This address must be a aligned to a 64-bit
 * double-word boundary.
 */
/*@{*/
#define BP_EPDC_WB_ADDR_ADDR (0U)          /*!< Bit position for EPDC_WB_ADDR_ADDR. */
#define BM_EPDC_WB_ADDR_ADDR (0xFFFFFFFFU) /*!< Bit mask for EPDC_WB_ADDR_ADDR. */
#define BS_EPDC_WB_ADDR_ADDR (32U)         /*!< Bit field size in bits for EPDC_WB_ADDR_ADDR. */

/*! @brief Read current value of the EPDC_WB_ADDR_ADDR field. */
#define BR_EPDC_WB_ADDR_ADDR(x) (HW_EPDC_WB_ADDR(x).U)

/*! @brief Format value for bitfield EPDC_WB_ADDR_ADDR. */
#define BF_EPDC_WB_ADDR_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_ADDR_ADDR) & BM_EPDC_WB_ADDR_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_EPDC_WB_ADDR_ADDR(x, v) (HW_EPDC_WB_ADDR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_EPDC_RES - EPDC Screen Resolution
 ******************************************************************************/

/*!
 * @brief HW_EPDC_RES - EPDC Screen Resolution (RW)
 *
 * Reset value: 0x00000000U
 *
 * EPDC Screen Resolution. This register defines the horizontal and vertical
 * resolution of the target display panel
 */
typedef union _hw_epdc_res
{
    uint32_t U;
    struct _hw_epdc_res_bitfields
    {
        uint32_t HORIZONTAL : 13;      /*!< [12:0]  */
        uint32_t RESERVED0 : 3;        /*!< [15:13]  */
        uint32_t VERTICAL : 13;        /*!< [28:16]  */
        uint32_t RESERVED1 : 3;        /*!< [31:29]  */
    } B;
} hw_epdc_res_t;

/*!
 * @name Constants and macros for entire EPDC_RES register
 */
/*@{*/
#define HW_EPDC_RES_ADDR(x)      ((uintptr_t)(x) + 0x40U)

#define HW_EPDC_RES(x)           (*(__IO hw_epdc_res_t *) HW_EPDC_RES_ADDR(x))
#define HW_EPDC_RES_RD(x)        (HW_EPDC_RES(x).U)
#define HW_EPDC_RES_WR(x, v)     (HW_EPDC_RES(x).U = (v))
#define HW_EPDC_RES_SET(x, v)    (HW_EPDC_RES_WR(x, HW_EPDC_RES_RD(x) |  (v)))
#define HW_EPDC_RES_CLR(x, v)    (HW_EPDC_RES_WR(x, HW_EPDC_RES_RD(x) & ~(v)))
#define HW_EPDC_RES_TOG(x, v)    (HW_EPDC_RES_WR(x, HW_EPDC_RES_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_RES bitfields
 */

/*!
 * @name Register EPDC_RES, field HORIZONTAL[12:0] (RW)
 *
 * Horizontal Resolution (in pixels)
 */
/*@{*/
#define BP_EPDC_RES_HORIZONTAL (0U)        /*!< Bit position for EPDC_RES_HORIZONTAL. */
#define BM_EPDC_RES_HORIZONTAL (0x00001FFFU) /*!< Bit mask for EPDC_RES_HORIZONTAL. */
#define BS_EPDC_RES_HORIZONTAL (13U)       /*!< Bit field size in bits for EPDC_RES_HORIZONTAL. */

/*! @brief Read current value of the EPDC_RES_HORIZONTAL field. */
#define BR_EPDC_RES_HORIZONTAL(x) (HW_EPDC_RES(x).B.HORIZONTAL)

/*! @brief Format value for bitfield EPDC_RES_HORIZONTAL. */
#define BF_EPDC_RES_HORIZONTAL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_RES_HORIZONTAL) & BM_EPDC_RES_HORIZONTAL)

/*! @brief Set the HORIZONTAL field to a new value. */
#define BW_EPDC_RES_HORIZONTAL(x, v) (HW_EPDC_RES_WR(x, (HW_EPDC_RES_RD(x) & ~BM_EPDC_RES_HORIZONTAL) | BF_EPDC_RES_HORIZONTAL(v)))
/*@}*/

/*!
 * @name Register EPDC_RES, field VERTICAL[28:16] (RW)
 *
 * Vertical Resoltion (in pixels)
 */
/*@{*/
#define BP_EPDC_RES_VERTICAL (16U)         /*!< Bit position for EPDC_RES_VERTICAL. */
#define BM_EPDC_RES_VERTICAL (0x1FFF0000U) /*!< Bit mask for EPDC_RES_VERTICAL. */
#define BS_EPDC_RES_VERTICAL (13U)         /*!< Bit field size in bits for EPDC_RES_VERTICAL. */

/*! @brief Read current value of the EPDC_RES_VERTICAL field. */
#define BR_EPDC_RES_VERTICAL(x) (HW_EPDC_RES(x).B.VERTICAL)

/*! @brief Format value for bitfield EPDC_RES_VERTICAL. */
#define BF_EPDC_RES_VERTICAL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_RES_VERTICAL) & BM_EPDC_RES_VERTICAL)

/*! @brief Set the VERTICAL field to a new value. */
#define BW_EPDC_RES_VERTICAL(x, v) (HW_EPDC_RES_WR(x, (HW_EPDC_RES_RD(x) & ~BM_EPDC_RES_VERTICAL) | BF_EPDC_RES_VERTICAL(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_FORMAT - EPDC Format Control Register
 ******************************************************************************/

/*!
 * @brief HW_EPDC_FORMAT - EPDC Format Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * EPDC Pixel format control register. Defines formats for buffer and TFT
 * pixels. This register controls various functions throughout the digital portion of
 * the chip. EXAMPLE /- EPDC_FORMAT - 2bit TFT and 4bit Buf pixel format -/
 * reg_val = EPDC_FORMAT_TFT_PIXEL_FORMAT_2BIT | EPDC_FORMAT_BUF_PIXEL_FORMAT_P4N |
 * ((0x0 << EPDC_FORMAT_DEFAULT_TFT_PIXEL_OFFSET) &
 * EPDC_FORMAT_DEFAULT_TFT_PIXEL_MASK); __raw_writel(reg_val, EPDC_FORMAT);
 */
typedef union _hw_epdc_format
{
    uint32_t U;
    struct _hw_epdc_format_bitfields
    {
        uint32_t TFT_PIXEL_FORMAT : 2; /*!< [1:0]  */
        uint32_t RESERVED0 : 6;        /*!< [7:2]  */
        uint32_t BUF_PIXEL_FORMAT : 3; /*!< [10:8] this field is deprecated
                                        * in EPDCv3, replaced by WB_FIELDx where we can specify width for each
                                        * field */
        uint32_t WB_COMPRESS : 1;      /*!< [11]  */
        uint32_t WB_TYPE : 2;          /*!< [13:12]  */
        uint32_t WB_ADDR_NO_COPY : 1;  /*!< [14]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t DEFAULT_TFT_PIXEL : 8; /*!< [23:16]  */
        uint32_t BUF_PIXEL_SCALE : 1;  /*!< [24]  */
        uint32_t RESERVED2 : 7;        /*!< [31:25]  */
    } B;
} hw_epdc_format_t;

/*!
 * @name Constants and macros for entire EPDC_FORMAT register
 */
/*@{*/
#define HW_EPDC_FORMAT_ADDR(x)   ((uintptr_t)(x) + 0x50U)
#define HW_EPDC_FORMAT_SET_ADDR(x) (HW_EPDC_FORMAT_ADDR(x) + 0x4U)
#define HW_EPDC_FORMAT_CLR_ADDR(x) (HW_EPDC_FORMAT_ADDR(x) + 0x8U)
#define HW_EPDC_FORMAT_TOG_ADDR(x) (HW_EPDC_FORMAT_ADDR(x) + 0xCU)

#define HW_EPDC_FORMAT(x)        (*(__IO hw_epdc_format_t *) HW_EPDC_FORMAT_ADDR(x))
#define HW_EPDC_FORMAT_RD(x)     (HW_EPDC_FORMAT(x).U)
#define HW_EPDC_FORMAT_WR(x, v)  (HW_EPDC_FORMAT(x).U = (v))
#define HW_EPDC_FORMAT_SET(x, v) ((*(uint32_t *) HW_EPDC_FORMAT_SET_ADDR(x)) = (v))
#define HW_EPDC_FORMAT_CLR(x, v) ((*(uint32_t *) HW_EPDC_FORMAT_CLR_ADDR(x)) = (v))
#define HW_EPDC_FORMAT_TOG(x, v) ((*(uint32_t *) HW_EPDC_FORMAT_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_FORMAT bitfields
 */

/*!
 * @name Register EPDC_FORMAT, field TFT_PIXEL_FORMAT[1:0] (RW)
 *
 * EPDC TFT Pixel Format. This defines how many bits of the SDDO bus are
 * required per pixel. This field must be consistent with the waveform and panel
 * architecture.
 *
 * Values:
 * - 0 - 2-bit
 * - 1 - 2-bit and VCOM
 * - 10 - 4-bit
 * - 11 - 4-bit and VCOM
 */
/*@{*/
#define BP_EPDC_FORMAT_TFT_PIXEL_FORMAT (0U) /*!< Bit position for EPDC_FORMAT_TFT_PIXEL_FORMAT. */
#define BM_EPDC_FORMAT_TFT_PIXEL_FORMAT (0x00000003U) /*!< Bit mask for EPDC_FORMAT_TFT_PIXEL_FORMAT. */
#define BS_EPDC_FORMAT_TFT_PIXEL_FORMAT (2U) /*!< Bit field size in bits for EPDC_FORMAT_TFT_PIXEL_FORMAT. */

#define BV_EPDC_FORMAT_TFT_PIXEL_FORMAT_2B (0U)      /*!< Bit field value for EPDC_FORMAT_TFT_PIXEL_FORMAT: 2-bit */
#define BV_EPDC_FORMAT_TFT_PIXEL_FORMAT_2BV (0x1U)   /*!< Bit field value for EPDC_FORMAT_TFT_PIXEL_FORMAT: 2-bit and VCOM */
#define BV_EPDC_FORMAT_TFT_PIXEL_FORMAT_4B (0x2U)    /*!< Bit field value for EPDC_FORMAT_TFT_PIXEL_FORMAT: 4-bit */
#define BV_EPDC_FORMAT_TFT_PIXEL_FORMAT_4BV (0x3U)   /*!< Bit field value for EPDC_FORMAT_TFT_PIXEL_FORMAT: 4-bit and VCOM */

/*! @brief Read current value of the EPDC_FORMAT_TFT_PIXEL_FORMAT field. */
#define BR_EPDC_FORMAT_TFT_PIXEL_FORMAT(x) (HW_EPDC_FORMAT(x).B.TFT_PIXEL_FORMAT)

/*! @brief Format value for bitfield EPDC_FORMAT_TFT_PIXEL_FORMAT. */
#define BF_EPDC_FORMAT_TFT_PIXEL_FORMAT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_FORMAT_TFT_PIXEL_FORMAT) & BM_EPDC_FORMAT_TFT_PIXEL_FORMAT)

/*! @brief Set the TFT_PIXEL_FORMAT field to a new value. */
#define BW_EPDC_FORMAT_TFT_PIXEL_FORMAT(x, v) (HW_EPDC_FORMAT_WR(x, (HW_EPDC_FORMAT_RD(x) & ~BM_EPDC_FORMAT_TFT_PIXEL_FORMAT) | BF_EPDC_FORMAT_TFT_PIXEL_FORMAT(v)))
/*@}*/

/*!
 * @name Register EPDC_FORMAT, field BUF_PIXEL_FORMAT[10:8] (RW)
 *
 * EPDC Input Buffer Pixel format. All update buffers are expected to have 8-bit
 * grayscale pixels. This register defines which MSB's of those pixels are used.
 * It must be noted that this format must match the waveform (e.g. P4N is not
 * compatible with 3-bit waveforms)
 *
 * Values:
 * - 10 - 2-bit pixel
 * - 11 - 3-bit pixel
 * - 100 - 4-bit pixel
 * - 101 - 5-bit pixel
 */
/*@{*/
#define BP_EPDC_FORMAT_BUF_PIXEL_FORMAT (8U) /*!< Bit position for EPDC_FORMAT_BUF_PIXEL_FORMAT. */
#define BM_EPDC_FORMAT_BUF_PIXEL_FORMAT (0x00000700U) /*!< Bit mask for EPDC_FORMAT_BUF_PIXEL_FORMAT. */
#define BS_EPDC_FORMAT_BUF_PIXEL_FORMAT (3U) /*!< Bit field size in bits for EPDC_FORMAT_BUF_PIXEL_FORMAT. */

#define BV_EPDC_FORMAT_BUF_PIXEL_FORMAT_P2N (0x2U)   /*!< Bit field value for EPDC_FORMAT_BUF_PIXEL_FORMAT: 2-bit pixel */
#define BV_EPDC_FORMAT_BUF_PIXEL_FORMAT_P3N (0x3U)   /*!< Bit field value for EPDC_FORMAT_BUF_PIXEL_FORMAT: 3-bit pixel */
#define BV_EPDC_FORMAT_BUF_PIXEL_FORMAT_P4N (0x4U)   /*!< Bit field value for EPDC_FORMAT_BUF_PIXEL_FORMAT: 4-bit pixel */
#define BV_EPDC_FORMAT_BUF_PIXEL_FORMAT_P5N (0x5U)   /*!< Bit field value for EPDC_FORMAT_BUF_PIXEL_FORMAT: 5-bit pixel */

/*! @brief Read current value of the EPDC_FORMAT_BUF_PIXEL_FORMAT field. */
#define BR_EPDC_FORMAT_BUF_PIXEL_FORMAT(x) (HW_EPDC_FORMAT(x).B.BUF_PIXEL_FORMAT)

/*! @brief Format value for bitfield EPDC_FORMAT_BUF_PIXEL_FORMAT. */
#define BF_EPDC_FORMAT_BUF_PIXEL_FORMAT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_FORMAT_BUF_PIXEL_FORMAT) & BM_EPDC_FORMAT_BUF_PIXEL_FORMAT)

/*! @brief Set the BUF_PIXEL_FORMAT field to a new value. */
#define BW_EPDC_FORMAT_BUF_PIXEL_FORMAT(x, v) (HW_EPDC_FORMAT_WR(x, (HW_EPDC_FORMAT_RD(x) & ~BM_EPDC_FORMAT_BUF_PIXEL_FORMAT) | BF_EPDC_FORMAT_BUF_PIXEL_FORMAT(v)))
/*@}*/

/*!
 * @name Register EPDC_FORMAT, field WB_COMPRESS[11] (RW)
 *
 * whether the working buffer is compressed, only avilable on
 * WB_FORMAT=EXTERNAL16/32 mode
 */
/*@{*/
#define BP_EPDC_FORMAT_WB_COMPRESS (11U)   /*!< Bit position for EPDC_FORMAT_WB_COMPRESS. */
#define BM_EPDC_FORMAT_WB_COMPRESS (0x00000800U) /*!< Bit mask for EPDC_FORMAT_WB_COMPRESS. */
#define BS_EPDC_FORMAT_WB_COMPRESS (1U)    /*!< Bit field size in bits for EPDC_FORMAT_WB_COMPRESS. */

/*! @brief Read current value of the EPDC_FORMAT_WB_COMPRESS field. */
#define BR_EPDC_FORMAT_WB_COMPRESS(x) (HW_EPDC_FORMAT(x).B.WB_COMPRESS)

/*! @brief Format value for bitfield EPDC_FORMAT_WB_COMPRESS. */
#define BF_EPDC_FORMAT_WB_COMPRESS(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_FORMAT_WB_COMPRESS) & BM_EPDC_FORMAT_WB_COMPRESS)

/*! @brief Set the WB_COMPRESS field to a new value. */
#define BW_EPDC_FORMAT_WB_COMPRESS(x, v) (HW_EPDC_FORMAT_WR(x, (HW_EPDC_FORMAT_RD(x) & ~BM_EPDC_FORMAT_WB_COMPRESS) | BF_EPDC_FORMAT_WB_COMPRESS(v)))
/*@}*/

/*!
 * @name Register EPDC_FORMAT, field WB_TYPE[13:12] (RW)
 *
 * Values:
 * - 00 - internal Working Buffer written by EPDC itself
 * - 01 - working buffer is actually holding waveform
 * - 10 - 16bit working buffer written by PXP or CPU
 * - 11 - 32bit working buffer written by PXP or CPU
 */
/*@{*/
#define BP_EPDC_FORMAT_WB_TYPE (12U)       /*!< Bit position for EPDC_FORMAT_WB_TYPE. */
#define BM_EPDC_FORMAT_WB_TYPE (0x00003000U) /*!< Bit mask for EPDC_FORMAT_WB_TYPE. */
#define BS_EPDC_FORMAT_WB_TYPE (2U)        /*!< Bit field size in bits for EPDC_FORMAT_WB_TYPE. */

#define BV_EPDC_FORMAT_WB_TYPE_WB_INTERNAL (0U)      /*!< Bit field value for EPDC_FORMAT_WB_TYPE: internal Working Buffer written by EPDC itself */
#define BV_EPDC_FORMAT_WB_TYPE_WB_WAVEFORM (0x1U)    /*!< Bit field value for EPDC_FORMAT_WB_TYPE: working buffer is actually holding waveform */
#define BV_EPDC_FORMAT_WB_TYPE_WB_EXTERNAL16 (0x2U)  /*!< Bit field value for EPDC_FORMAT_WB_TYPE: 16bit working buffer written by PXP or CPU */
#define BV_EPDC_FORMAT_WB_TYPE_WB_EXTERNAL32 (0x3U)  /*!< Bit field value for EPDC_FORMAT_WB_TYPE: 32bit working buffer written by PXP or CPU */

/*! @brief Read current value of the EPDC_FORMAT_WB_TYPE field. */
#define BR_EPDC_FORMAT_WB_TYPE(x) (HW_EPDC_FORMAT(x).B.WB_TYPE)

/*! @brief Format value for bitfield EPDC_FORMAT_WB_TYPE. */
#define BF_EPDC_FORMAT_WB_TYPE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_FORMAT_WB_TYPE) & BM_EPDC_FORMAT_WB_TYPE)

/*! @brief Set the WB_TYPE field to a new value. */
#define BW_EPDC_FORMAT_WB_TYPE(x, v) (HW_EPDC_FORMAT_WR(x, (HW_EPDC_FORMAT_RD(x) & ~BM_EPDC_FORMAT_WB_TYPE) | BF_EPDC_FORMAT_WB_TYPE(v)))
/*@}*/

/*!
 * @name Register EPDC_FORMAT, field WB_ADDR_NO_COPY[14] (RW)
 *
 * 1 means do not automatically copy WB_ADDR to WB_ADDR_TCE before starting
 * every frame
 */
/*@{*/
#define BP_EPDC_FORMAT_WB_ADDR_NO_COPY (14U) /*!< Bit position for EPDC_FORMAT_WB_ADDR_NO_COPY. */
#define BM_EPDC_FORMAT_WB_ADDR_NO_COPY (0x00004000U) /*!< Bit mask for EPDC_FORMAT_WB_ADDR_NO_COPY. */
#define BS_EPDC_FORMAT_WB_ADDR_NO_COPY (1U) /*!< Bit field size in bits for EPDC_FORMAT_WB_ADDR_NO_COPY. */

/*! @brief Read current value of the EPDC_FORMAT_WB_ADDR_NO_COPY field. */
#define BR_EPDC_FORMAT_WB_ADDR_NO_COPY(x) (HW_EPDC_FORMAT(x).B.WB_ADDR_NO_COPY)

/*! @brief Format value for bitfield EPDC_FORMAT_WB_ADDR_NO_COPY. */
#define BF_EPDC_FORMAT_WB_ADDR_NO_COPY(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_FORMAT_WB_ADDR_NO_COPY) & BM_EPDC_FORMAT_WB_ADDR_NO_COPY)

/*! @brief Set the WB_ADDR_NO_COPY field to a new value. */
#define BW_EPDC_FORMAT_WB_ADDR_NO_COPY(x, v) (HW_EPDC_FORMAT_WR(x, (HW_EPDC_FORMAT_RD(x) & ~BM_EPDC_FORMAT_WB_ADDR_NO_COPY) | BF_EPDC_FORMAT_WB_ADDR_NO_COPY(v)))
/*@}*/

/*!
 * @name Register EPDC_FORMAT, field DEFAULT_TFT_PIXEL[23:16] (RW)
 *
 * Default TFT pixel value. This value is used as the source-driver voltage
 * value (TFT-pixel) for either partial-updates where a pixel has not changed or for
 * any part of the screen which is not being updated during active frame scans.
 */
/*@{*/
#define BP_EPDC_FORMAT_DEFAULT_TFT_PIXEL (16U) /*!< Bit position for EPDC_FORMAT_DEFAULT_TFT_PIXEL. */
#define BM_EPDC_FORMAT_DEFAULT_TFT_PIXEL (0x00FF0000U) /*!< Bit mask for EPDC_FORMAT_DEFAULT_TFT_PIXEL. */
#define BS_EPDC_FORMAT_DEFAULT_TFT_PIXEL (8U) /*!< Bit field size in bits for EPDC_FORMAT_DEFAULT_TFT_PIXEL. */

/*! @brief Read current value of the EPDC_FORMAT_DEFAULT_TFT_PIXEL field. */
#define BR_EPDC_FORMAT_DEFAULT_TFT_PIXEL(x) (HW_EPDC_FORMAT(x).B.DEFAULT_TFT_PIXEL)

/*! @brief Format value for bitfield EPDC_FORMAT_DEFAULT_TFT_PIXEL. */
#define BF_EPDC_FORMAT_DEFAULT_TFT_PIXEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_FORMAT_DEFAULT_TFT_PIXEL) & BM_EPDC_FORMAT_DEFAULT_TFT_PIXEL)

/*! @brief Set the DEFAULT_TFT_PIXEL field to a new value. */
#define BW_EPDC_FORMAT_DEFAULT_TFT_PIXEL(x, v) (HW_EPDC_FORMAT_WR(x, (HW_EPDC_FORMAT_RD(x) & ~BM_EPDC_FORMAT_DEFAULT_TFT_PIXEL) | BF_EPDC_FORMAT_DEFAULT_TFT_PIXEL(v)))
/*@}*/

/*!
 * @name Register EPDC_FORMAT, field BUF_PIXEL_SCALE[24] (RW)
 *
 * Selects method of conversion from 8-bit input
 *
 * Values:
 * - 0 - Use Truncate method (LSB)
 * - 1 - Use rounding method (with saturation)
 */
/*@{*/
#define BP_EPDC_FORMAT_BUF_PIXEL_SCALE (24U) /*!< Bit position for EPDC_FORMAT_BUF_PIXEL_SCALE. */
#define BM_EPDC_FORMAT_BUF_PIXEL_SCALE (0x01000000U) /*!< Bit mask for EPDC_FORMAT_BUF_PIXEL_SCALE. */
#define BS_EPDC_FORMAT_BUF_PIXEL_SCALE (1U) /*!< Bit field size in bits for EPDC_FORMAT_BUF_PIXEL_SCALE. */

#define BV_EPDC_FORMAT_BUF_PIXEL_SCALE_TRUNCATE (0U) /*!< Bit field value for EPDC_FORMAT_BUF_PIXEL_SCALE: Use Truncate method (LSB) */
#define BV_EPDC_FORMAT_BUF_PIXEL_SCALE_ROUND (0x1U)  /*!< Bit field value for EPDC_FORMAT_BUF_PIXEL_SCALE: Use rounding method (with saturation) */

/*! @brief Read current value of the EPDC_FORMAT_BUF_PIXEL_SCALE field. */
#define BR_EPDC_FORMAT_BUF_PIXEL_SCALE(x) (HW_EPDC_FORMAT(x).B.BUF_PIXEL_SCALE)

/*! @brief Format value for bitfield EPDC_FORMAT_BUF_PIXEL_SCALE. */
#define BF_EPDC_FORMAT_BUF_PIXEL_SCALE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_FORMAT_BUF_PIXEL_SCALE) & BM_EPDC_FORMAT_BUF_PIXEL_SCALE)

/*! @brief Set the BUF_PIXEL_SCALE field to a new value. */
#define BW_EPDC_FORMAT_BUF_PIXEL_SCALE(x, v) (HW_EPDC_FORMAT_WR(x, (HW_EPDC_FORMAT_RD(x) & ~BM_EPDC_FORMAT_BUF_PIXEL_SCALE) | BF_EPDC_FORMAT_BUF_PIXEL_SCALE(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_WB_FIELD0 - Working Buffer Field Setting
 ******************************************************************************/

/*!
 * @brief HW_EPDC_WB_FIELD0 - Working Buffer Field Setting (RW)
 *
 * Reset value: 0x00008AA5U
 *
 * specify the pixel fields mapping from working buffer to lut index :
 * WB[FROM+LEN:FROM] =>LUT [TO+LEN:TO]
 */
typedef union _hw_epdc_wb_field0
{
    uint32_t U;
    struct _hw_epdc_wb_field0_bitfields
    {
        uint32_t LEN : 4;              /*!< [3:0]  */
        uint32_t TO : 4;               /*!< [7:4]  */
        uint32_t FROM : 5;             /*!< [12:8]  */
        uint32_t USAGE : 3;            /*!< [15:13]  */
        uint32_t USE_FIXED : 2;        /*!< [17:16]  */
        uint32_t RESERVED0 : 6;        /*!< [23:18]  */
        uint32_t FIXED : 8;            /*!< [31:24]  */
    } B;
} hw_epdc_wb_field0_t;

/*!
 * @name Constants and macros for entire EPDC_WB_FIELD0 register
 */
/*@{*/
#define HW_EPDC_WB_FIELD0_ADDR(x) ((uintptr_t)(x) + 0x60U)

#define HW_EPDC_WB_FIELD0(x)     (*(__IO hw_epdc_wb_field0_t *) HW_EPDC_WB_FIELD0_ADDR(x))
#define HW_EPDC_WB_FIELD0_RD(x)  (HW_EPDC_WB_FIELD0(x).U)
#define HW_EPDC_WB_FIELD0_WR(x, v) (HW_EPDC_WB_FIELD0(x).U = (v))
#define HW_EPDC_WB_FIELD0_SET(x, v) (HW_EPDC_WB_FIELD0_WR(x, HW_EPDC_WB_FIELD0_RD(x) |  (v)))
#define HW_EPDC_WB_FIELD0_CLR(x, v) (HW_EPDC_WB_FIELD0_WR(x, HW_EPDC_WB_FIELD0_RD(x) & ~(v)))
#define HW_EPDC_WB_FIELD0_TOG(x, v) (HW_EPDC_WB_FIELD0_WR(x, HW_EPDC_WB_FIELD0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_WB_FIELD0 bitfields
 */

/*!
 * @name Register EPDC_WB_FIELD0, field LEN[3:0] (RW)
 *
 * Field length minus 1 (0x0 means length=1, 0xf means length=16)
 */
/*@{*/
#define BP_EPDC_WB_FIELD0_LEN (0U)         /*!< Bit position for EPDC_WB_FIELD0_LEN. */
#define BM_EPDC_WB_FIELD0_LEN (0x0000000FU) /*!< Bit mask for EPDC_WB_FIELD0_LEN. */
#define BS_EPDC_WB_FIELD0_LEN (4U)         /*!< Bit field size in bits for EPDC_WB_FIELD0_LEN. */

/*! @brief Read current value of the EPDC_WB_FIELD0_LEN field. */
#define BR_EPDC_WB_FIELD0_LEN(x) (HW_EPDC_WB_FIELD0(x).B.LEN)

/*! @brief Format value for bitfield EPDC_WB_FIELD0_LEN. */
#define BF_EPDC_WB_FIELD0_LEN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD0_LEN) & BM_EPDC_WB_FIELD0_LEN)

/*! @brief Set the LEN field to a new value. */
#define BW_EPDC_WB_FIELD0_LEN(x, v) (HW_EPDC_WB_FIELD0_WR(x, (HW_EPDC_WB_FIELD0_RD(x) & ~BM_EPDC_WB_FIELD0_LEN) | BF_EPDC_WB_FIELD0_LEN(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD0, field TO[7:4] (RW)
 *
 * Target Field's LSB
 */
/*@{*/
#define BP_EPDC_WB_FIELD0_TO (4U)          /*!< Bit position for EPDC_WB_FIELD0_TO. */
#define BM_EPDC_WB_FIELD0_TO (0x000000F0U) /*!< Bit mask for EPDC_WB_FIELD0_TO. */
#define BS_EPDC_WB_FIELD0_TO (4U)          /*!< Bit field size in bits for EPDC_WB_FIELD0_TO. */

/*! @brief Read current value of the EPDC_WB_FIELD0_TO field. */
#define BR_EPDC_WB_FIELD0_TO(x) (HW_EPDC_WB_FIELD0(x).B.TO)

/*! @brief Format value for bitfield EPDC_WB_FIELD0_TO. */
#define BF_EPDC_WB_FIELD0_TO(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD0_TO) & BM_EPDC_WB_FIELD0_TO)

/*! @brief Set the TO field to a new value. */
#define BW_EPDC_WB_FIELD0_TO(x, v) (HW_EPDC_WB_FIELD0_WR(x, (HW_EPDC_WB_FIELD0_RD(x) & ~BM_EPDC_WB_FIELD0_TO) | BF_EPDC_WB_FIELD0_TO(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD0, field FROM[12:8] (RW)
 *
 * Source Field's LSB
 */
/*@{*/
#define BP_EPDC_WB_FIELD0_FROM (8U)        /*!< Bit position for EPDC_WB_FIELD0_FROM. */
#define BM_EPDC_WB_FIELD0_FROM (0x00001F00U) /*!< Bit mask for EPDC_WB_FIELD0_FROM. */
#define BS_EPDC_WB_FIELD0_FROM (5U)        /*!< Bit field size in bits for EPDC_WB_FIELD0_FROM. */

/*! @brief Read current value of the EPDC_WB_FIELD0_FROM field. */
#define BR_EPDC_WB_FIELD0_FROM(x) (HW_EPDC_WB_FIELD0(x).B.FROM)

/*! @brief Format value for bitfield EPDC_WB_FIELD0_FROM. */
#define BF_EPDC_WB_FIELD0_FROM(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD0_FROM) & BM_EPDC_WB_FIELD0_FROM)

/*! @brief Set the FROM field to a new value. */
#define BW_EPDC_WB_FIELD0_FROM(x, v) (HW_EPDC_WB_FIELD0_WR(x, (HW_EPDC_WB_FIELD0_RD(x) & ~BM_EPDC_WB_FIELD0_FROM) | BF_EPDC_WB_FIELD0_FROM(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD0, field USAGE[15:13] (RW)
 *
 * Values:
 * - 000 - NOT USED
 * - 011 - PARTIAL (won't contribute to lut lookup index)
 * - 100 - LUT
 * - 101 - CP
 * - 110 - NP
 * - 111 - PTS
 */
/*@{*/
#define BP_EPDC_WB_FIELD0_USAGE (13U)      /*!< Bit position for EPDC_WB_FIELD0_USAGE. */
#define BM_EPDC_WB_FIELD0_USAGE (0x0000E000U) /*!< Bit mask for EPDC_WB_FIELD0_USAGE. */
#define BS_EPDC_WB_FIELD0_USAGE (3U)       /*!< Bit field size in bits for EPDC_WB_FIELD0_USAGE. */

#define BV_EPDC_WB_FIELD0_USAGE_NOT_USED (0U)        /*!< Bit field value for EPDC_WB_FIELD0_USAGE: NOT USED */
#define BV_EPDC_WB_FIELD0_USAGE_PARTIAL (0x3U)       /*!< Bit field value for EPDC_WB_FIELD0_USAGE: PARTIAL (won't contribute to lut lookup index) */
#define BV_EPDC_WB_FIELD0_USAGE_LUT    (0x4U)        /*!< Bit field value for EPDC_WB_FIELD0_USAGE: LUT */
#define BV_EPDC_WB_FIELD0_USAGE_CP     (0x5U)        /*!< Bit field value for EPDC_WB_FIELD0_USAGE: CP */
#define BV_EPDC_WB_FIELD0_USAGE_NP     (0x6U)        /*!< Bit field value for EPDC_WB_FIELD0_USAGE: NP */
#define BV_EPDC_WB_FIELD0_USAGE_PTS    (0x7U)        /*!< Bit field value for EPDC_WB_FIELD0_USAGE: PTS */

/*! @brief Read current value of the EPDC_WB_FIELD0_USAGE field. */
#define BR_EPDC_WB_FIELD0_USAGE(x) (HW_EPDC_WB_FIELD0(x).B.USAGE)

/*! @brief Format value for bitfield EPDC_WB_FIELD0_USAGE. */
#define BF_EPDC_WB_FIELD0_USAGE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD0_USAGE) & BM_EPDC_WB_FIELD0_USAGE)

/*! @brief Set the USAGE field to a new value. */
#define BW_EPDC_WB_FIELD0_USAGE(x, v) (HW_EPDC_WB_FIELD0_WR(x, (HW_EPDC_WB_FIELD0_RD(x) & ~BM_EPDC_WB_FIELD0_USAGE) | BF_EPDC_WB_FIELD0_USAGE(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD0, field USE_FIXED[17:16] (RW)
 *
 * usage of the FIXED value
 *
 * Values:
 * - 00 - not using FIXED field
 * - 01 - set this field to a FIXED value which specified by FIXED[31:24]
 * - 10 - mask off this pixel if this field is non equal to FIXED[31:24]
 * - 11 - mask off this pixel if this field is equal to FIXED[31:24]
 */
/*@{*/
#define BP_EPDC_WB_FIELD0_USE_FIXED (16U)  /*!< Bit position for EPDC_WB_FIELD0_USE_FIXED. */
#define BM_EPDC_WB_FIELD0_USE_FIXED (0x00030000U) /*!< Bit mask for EPDC_WB_FIELD0_USE_FIXED. */
#define BS_EPDC_WB_FIELD0_USE_FIXED (2U)   /*!< Bit field size in bits for EPDC_WB_FIELD0_USE_FIXED. */

#define BV_EPDC_WB_FIELD0_USE_FIXED_NO_FIXED (0U)    /*!< Bit field value for EPDC_WB_FIELD0_USE_FIXED: not using FIXED field */
#define BV_EPDC_WB_FIELD0_USE_FIXED_USE_FIXED (0x1U) /*!< Bit field value for EPDC_WB_FIELD0_USE_FIXED: set this field to a FIXED value which specified by FIXED[31:24] */
#define BV_EPDC_WB_FIELD0_USE_FIXED_NE_FIXED (0x2U)  /*!< Bit field value for EPDC_WB_FIELD0_USE_FIXED: mask off this pixel if this field is non equal to FIXED[31:24] */
#define BV_EPDC_WB_FIELD0_USE_FIXED_EQ_FIXED (0x3U)  /*!< Bit field value for EPDC_WB_FIELD0_USE_FIXED: mask off this pixel if this field is equal to FIXED[31:24] */

/*! @brief Read current value of the EPDC_WB_FIELD0_USE_FIXED field. */
#define BR_EPDC_WB_FIELD0_USE_FIXED(x) (HW_EPDC_WB_FIELD0(x).B.USE_FIXED)

/*! @brief Format value for bitfield EPDC_WB_FIELD0_USE_FIXED. */
#define BF_EPDC_WB_FIELD0_USE_FIXED(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD0_USE_FIXED) & BM_EPDC_WB_FIELD0_USE_FIXED)

/*! @brief Set the USE_FIXED field to a new value. */
#define BW_EPDC_WB_FIELD0_USE_FIXED(x, v) (HW_EPDC_WB_FIELD0_WR(x, (HW_EPDC_WB_FIELD0_RD(x) & ~BM_EPDC_WB_FIELD0_USE_FIXED) | BF_EPDC_WB_FIELD0_USE_FIXED(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD0, field FIXED[31:24] (RW)
 *
 * used to either force field into a fixed value, or compare to wb field to mask
 * off the pixel
 */
/*@{*/
#define BP_EPDC_WB_FIELD0_FIXED (24U)      /*!< Bit position for EPDC_WB_FIELD0_FIXED. */
#define BM_EPDC_WB_FIELD0_FIXED (0xFF000000U) /*!< Bit mask for EPDC_WB_FIELD0_FIXED. */
#define BS_EPDC_WB_FIELD0_FIXED (8U)       /*!< Bit field size in bits for EPDC_WB_FIELD0_FIXED. */

/*! @brief Read current value of the EPDC_WB_FIELD0_FIXED field. */
#define BR_EPDC_WB_FIELD0_FIXED(x) (HW_EPDC_WB_FIELD0(x).B.FIXED)

/*! @brief Format value for bitfield EPDC_WB_FIELD0_FIXED. */
#define BF_EPDC_WB_FIELD0_FIXED(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD0_FIXED) & BM_EPDC_WB_FIELD0_FIXED)

/*! @brief Set the FIXED field to a new value. */
#define BW_EPDC_WB_FIELD0_FIXED(x, v) (HW_EPDC_WB_FIELD0_WR(x, (HW_EPDC_WB_FIELD0_RD(x) & ~BM_EPDC_WB_FIELD0_FIXED) | BF_EPDC_WB_FIELD0_FIXED(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_WB_FIELD1 - Working Buffer Field Setting
 ******************************************************************************/

/*!
 * @brief HW_EPDC_WB_FIELD1 - Working Buffer Field Setting (RW)
 *
 * Reset value: 0x0000A003U
 *
 * specify the pixel fields mapping from working buffer to lut index :
 * WB[FROM+LEN:FROM] =>LUT [TO+LEN:TO]
 */
typedef union _hw_epdc_wb_field1
{
    uint32_t U;
    struct _hw_epdc_wb_field1_bitfields
    {
        uint32_t LEN : 4;              /*!< [3:0]  */
        uint32_t TO : 4;               /*!< [7:4]  */
        uint32_t FROM : 5;             /*!< [12:8]  */
        uint32_t USAGE : 3;            /*!< [15:13]  */
        uint32_t USE_FIXED : 2;        /*!< [17:16]  */
        uint32_t RESERVED0 : 6;        /*!< [23:18]  */
        uint32_t FIXED : 8;            /*!< [31:24]  */
    } B;
} hw_epdc_wb_field1_t;

/*!
 * @name Constants and macros for entire EPDC_WB_FIELD1 register
 */
/*@{*/
#define HW_EPDC_WB_FIELD1_ADDR(x) ((uintptr_t)(x) + 0x70U)

#define HW_EPDC_WB_FIELD1(x)     (*(__IO hw_epdc_wb_field1_t *) HW_EPDC_WB_FIELD1_ADDR(x))
#define HW_EPDC_WB_FIELD1_RD(x)  (HW_EPDC_WB_FIELD1(x).U)
#define HW_EPDC_WB_FIELD1_WR(x, v) (HW_EPDC_WB_FIELD1(x).U = (v))
#define HW_EPDC_WB_FIELD1_SET(x, v) (HW_EPDC_WB_FIELD1_WR(x, HW_EPDC_WB_FIELD1_RD(x) |  (v)))
#define HW_EPDC_WB_FIELD1_CLR(x, v) (HW_EPDC_WB_FIELD1_WR(x, HW_EPDC_WB_FIELD1_RD(x) & ~(v)))
#define HW_EPDC_WB_FIELD1_TOG(x, v) (HW_EPDC_WB_FIELD1_WR(x, HW_EPDC_WB_FIELD1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_WB_FIELD1 bitfields
 */

/*!
 * @name Register EPDC_WB_FIELD1, field LEN[3:0] (RW)
 *
 * Field length minus 1 (0x0 means length=1, 0xf means length=16)
 */
/*@{*/
#define BP_EPDC_WB_FIELD1_LEN (0U)         /*!< Bit position for EPDC_WB_FIELD1_LEN. */
#define BM_EPDC_WB_FIELD1_LEN (0x0000000FU) /*!< Bit mask for EPDC_WB_FIELD1_LEN. */
#define BS_EPDC_WB_FIELD1_LEN (4U)         /*!< Bit field size in bits for EPDC_WB_FIELD1_LEN. */

/*! @brief Read current value of the EPDC_WB_FIELD1_LEN field. */
#define BR_EPDC_WB_FIELD1_LEN(x) (HW_EPDC_WB_FIELD1(x).B.LEN)

/*! @brief Format value for bitfield EPDC_WB_FIELD1_LEN. */
#define BF_EPDC_WB_FIELD1_LEN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD1_LEN) & BM_EPDC_WB_FIELD1_LEN)

/*! @brief Set the LEN field to a new value. */
#define BW_EPDC_WB_FIELD1_LEN(x, v) (HW_EPDC_WB_FIELD1_WR(x, (HW_EPDC_WB_FIELD1_RD(x) & ~BM_EPDC_WB_FIELD1_LEN) | BF_EPDC_WB_FIELD1_LEN(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD1, field TO[7:4] (RW)
 *
 * Target Field's LSB
 */
/*@{*/
#define BP_EPDC_WB_FIELD1_TO (4U)          /*!< Bit position for EPDC_WB_FIELD1_TO. */
#define BM_EPDC_WB_FIELD1_TO (0x000000F0U) /*!< Bit mask for EPDC_WB_FIELD1_TO. */
#define BS_EPDC_WB_FIELD1_TO (4U)          /*!< Bit field size in bits for EPDC_WB_FIELD1_TO. */

/*! @brief Read current value of the EPDC_WB_FIELD1_TO field. */
#define BR_EPDC_WB_FIELD1_TO(x) (HW_EPDC_WB_FIELD1(x).B.TO)

/*! @brief Format value for bitfield EPDC_WB_FIELD1_TO. */
#define BF_EPDC_WB_FIELD1_TO(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD1_TO) & BM_EPDC_WB_FIELD1_TO)

/*! @brief Set the TO field to a new value. */
#define BW_EPDC_WB_FIELD1_TO(x, v) (HW_EPDC_WB_FIELD1_WR(x, (HW_EPDC_WB_FIELD1_RD(x) & ~BM_EPDC_WB_FIELD1_TO) | BF_EPDC_WB_FIELD1_TO(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD1, field FROM[12:8] (RW)
 *
 * Source Field's LSB
 */
/*@{*/
#define BP_EPDC_WB_FIELD1_FROM (8U)        /*!< Bit position for EPDC_WB_FIELD1_FROM. */
#define BM_EPDC_WB_FIELD1_FROM (0x00001F00U) /*!< Bit mask for EPDC_WB_FIELD1_FROM. */
#define BS_EPDC_WB_FIELD1_FROM (5U)        /*!< Bit field size in bits for EPDC_WB_FIELD1_FROM. */

/*! @brief Read current value of the EPDC_WB_FIELD1_FROM field. */
#define BR_EPDC_WB_FIELD1_FROM(x) (HW_EPDC_WB_FIELD1(x).B.FROM)

/*! @brief Format value for bitfield EPDC_WB_FIELD1_FROM. */
#define BF_EPDC_WB_FIELD1_FROM(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD1_FROM) & BM_EPDC_WB_FIELD1_FROM)

/*! @brief Set the FROM field to a new value. */
#define BW_EPDC_WB_FIELD1_FROM(x, v) (HW_EPDC_WB_FIELD1_WR(x, (HW_EPDC_WB_FIELD1_RD(x) & ~BM_EPDC_WB_FIELD1_FROM) | BF_EPDC_WB_FIELD1_FROM(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD1, field USAGE[15:13] (RW)
 *
 * Values:
 * - 000 - NOT USED
 * - 011 - PARTIAL
 * - 100 - LUT
 * - 101 - CP
 * - 110 - NP
 * - 111 - PTS
 */
/*@{*/
#define BP_EPDC_WB_FIELD1_USAGE (13U)      /*!< Bit position for EPDC_WB_FIELD1_USAGE. */
#define BM_EPDC_WB_FIELD1_USAGE (0x0000E000U) /*!< Bit mask for EPDC_WB_FIELD1_USAGE. */
#define BS_EPDC_WB_FIELD1_USAGE (3U)       /*!< Bit field size in bits for EPDC_WB_FIELD1_USAGE. */

#define BV_EPDC_WB_FIELD1_USAGE_NOT_USED (0U)        /*!< Bit field value for EPDC_WB_FIELD1_USAGE: NOT USED */
#define BV_EPDC_WB_FIELD1_USAGE_PARTIAL (0x3U)       /*!< Bit field value for EPDC_WB_FIELD1_USAGE: PARTIAL */
#define BV_EPDC_WB_FIELD1_USAGE_LUT    (0x4U)        /*!< Bit field value for EPDC_WB_FIELD1_USAGE: LUT */
#define BV_EPDC_WB_FIELD1_USAGE_CP     (0x5U)        /*!< Bit field value for EPDC_WB_FIELD1_USAGE: CP */
#define BV_EPDC_WB_FIELD1_USAGE_NP     (0x6U)        /*!< Bit field value for EPDC_WB_FIELD1_USAGE: NP */
#define BV_EPDC_WB_FIELD1_USAGE_PTS    (0x7U)        /*!< Bit field value for EPDC_WB_FIELD1_USAGE: PTS */

/*! @brief Read current value of the EPDC_WB_FIELD1_USAGE field. */
#define BR_EPDC_WB_FIELD1_USAGE(x) (HW_EPDC_WB_FIELD1(x).B.USAGE)

/*! @brief Format value for bitfield EPDC_WB_FIELD1_USAGE. */
#define BF_EPDC_WB_FIELD1_USAGE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD1_USAGE) & BM_EPDC_WB_FIELD1_USAGE)

/*! @brief Set the USAGE field to a new value. */
#define BW_EPDC_WB_FIELD1_USAGE(x, v) (HW_EPDC_WB_FIELD1_WR(x, (HW_EPDC_WB_FIELD1_RD(x) & ~BM_EPDC_WB_FIELD1_USAGE) | BF_EPDC_WB_FIELD1_USAGE(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD1, field USE_FIXED[17:16] (RW)
 *
 * usage of the FIXED value
 *
 * Values:
 * - 00 - not using FIXED field
 * - 01 - set this field to a FIXED value which specified by FIXED[31:24]
 * - 10 - mask off this pixel if this field is non equal to FIXED[31:24]
 * - 11 - mask off this pixel if this field is equal to FIXED[31:24]
 */
/*@{*/
#define BP_EPDC_WB_FIELD1_USE_FIXED (16U)  /*!< Bit position for EPDC_WB_FIELD1_USE_FIXED. */
#define BM_EPDC_WB_FIELD1_USE_FIXED (0x00030000U) /*!< Bit mask for EPDC_WB_FIELD1_USE_FIXED. */
#define BS_EPDC_WB_FIELD1_USE_FIXED (2U)   /*!< Bit field size in bits for EPDC_WB_FIELD1_USE_FIXED. */

#define BV_EPDC_WB_FIELD1_USE_FIXED_NO_FIXED (0U)    /*!< Bit field value for EPDC_WB_FIELD1_USE_FIXED: not using FIXED field */
#define BV_EPDC_WB_FIELD1_USE_FIXED_USE_FIXED (0x1U) /*!< Bit field value for EPDC_WB_FIELD1_USE_FIXED: set this field to a FIXED value which specified by FIXED[31:24] */
#define BV_EPDC_WB_FIELD1_USE_FIXED_NE_FIXED (0x2U)  /*!< Bit field value for EPDC_WB_FIELD1_USE_FIXED: mask off this pixel if this field is non equal to FIXED[31:24] */
#define BV_EPDC_WB_FIELD1_USE_FIXED_EQ_FIXED (0x3U)  /*!< Bit field value for EPDC_WB_FIELD1_USE_FIXED: mask off this pixel if this field is equal to FIXED[31:24] */

/*! @brief Read current value of the EPDC_WB_FIELD1_USE_FIXED field. */
#define BR_EPDC_WB_FIELD1_USE_FIXED(x) (HW_EPDC_WB_FIELD1(x).B.USE_FIXED)

/*! @brief Format value for bitfield EPDC_WB_FIELD1_USE_FIXED. */
#define BF_EPDC_WB_FIELD1_USE_FIXED(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD1_USE_FIXED) & BM_EPDC_WB_FIELD1_USE_FIXED)

/*! @brief Set the USE_FIXED field to a new value. */
#define BW_EPDC_WB_FIELD1_USE_FIXED(x, v) (HW_EPDC_WB_FIELD1_WR(x, (HW_EPDC_WB_FIELD1_RD(x) & ~BM_EPDC_WB_FIELD1_USE_FIXED) | BF_EPDC_WB_FIELD1_USE_FIXED(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD1, field FIXED[31:24] (RW)
 *
 * used to either force field into a fixed value, or compare to wb field to mask
 * off the pixel
 */
/*@{*/
#define BP_EPDC_WB_FIELD1_FIXED (24U)      /*!< Bit position for EPDC_WB_FIELD1_FIXED. */
#define BM_EPDC_WB_FIELD1_FIXED (0xFF000000U) /*!< Bit mask for EPDC_WB_FIELD1_FIXED. */
#define BS_EPDC_WB_FIELD1_FIXED (8U)       /*!< Bit field size in bits for EPDC_WB_FIELD1_FIXED. */

/*! @brief Read current value of the EPDC_WB_FIELD1_FIXED field. */
#define BR_EPDC_WB_FIELD1_FIXED(x) (HW_EPDC_WB_FIELD1(x).B.FIXED)

/*! @brief Format value for bitfield EPDC_WB_FIELD1_FIXED. */
#define BF_EPDC_WB_FIELD1_FIXED(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD1_FIXED) & BM_EPDC_WB_FIELD1_FIXED)

/*! @brief Set the FIXED field to a new value. */
#define BW_EPDC_WB_FIELD1_FIXED(x, v) (HW_EPDC_WB_FIELD1_WR(x, (HW_EPDC_WB_FIELD1_RD(x) & ~BM_EPDC_WB_FIELD1_FIXED) | BF_EPDC_WB_FIELD1_FIXED(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_WB_FIELD2 - Working Buffer Field Setting
 ******************************************************************************/

/*!
 * @brief HW_EPDC_WB_FIELD2 - Working Buffer Field Setting (RW)
 *
 * Reset value: 0x0000C443U
 *
 * specify the pixel fields mapping from working buffer to lut index :
 * WB[FROM+LEN:FROM] =>LUT [TO+LEN:TO]
 */
typedef union _hw_epdc_wb_field2
{
    uint32_t U;
    struct _hw_epdc_wb_field2_bitfields
    {
        uint32_t LEN : 4;              /*!< [3:0]  */
        uint32_t TO : 4;               /*!< [7:4]  */
        uint32_t FROM : 5;             /*!< [12:8]  */
        uint32_t USAGE : 3;            /*!< [15:13]  */
        uint32_t USE_FIXED : 2;        /*!< [17:16]  */
        uint32_t RESERVED0 : 6;        /*!< [23:18]  */
        uint32_t FIXED : 8;            /*!< [31:24]  */
    } B;
} hw_epdc_wb_field2_t;

/*!
 * @name Constants and macros for entire EPDC_WB_FIELD2 register
 */
/*@{*/
#define HW_EPDC_WB_FIELD2_ADDR(x) ((uintptr_t)(x) + 0x80U)

#define HW_EPDC_WB_FIELD2(x)     (*(__IO hw_epdc_wb_field2_t *) HW_EPDC_WB_FIELD2_ADDR(x))
#define HW_EPDC_WB_FIELD2_RD(x)  (HW_EPDC_WB_FIELD2(x).U)
#define HW_EPDC_WB_FIELD2_WR(x, v) (HW_EPDC_WB_FIELD2(x).U = (v))
#define HW_EPDC_WB_FIELD2_SET(x, v) (HW_EPDC_WB_FIELD2_WR(x, HW_EPDC_WB_FIELD2_RD(x) |  (v)))
#define HW_EPDC_WB_FIELD2_CLR(x, v) (HW_EPDC_WB_FIELD2_WR(x, HW_EPDC_WB_FIELD2_RD(x) & ~(v)))
#define HW_EPDC_WB_FIELD2_TOG(x, v) (HW_EPDC_WB_FIELD2_WR(x, HW_EPDC_WB_FIELD2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_WB_FIELD2 bitfields
 */

/*!
 * @name Register EPDC_WB_FIELD2, field LEN[3:0] (RW)
 *
 * Field length minus 1 (0x0 means length=1, 0xf means length=16)
 */
/*@{*/
#define BP_EPDC_WB_FIELD2_LEN (0U)         /*!< Bit position for EPDC_WB_FIELD2_LEN. */
#define BM_EPDC_WB_FIELD2_LEN (0x0000000FU) /*!< Bit mask for EPDC_WB_FIELD2_LEN. */
#define BS_EPDC_WB_FIELD2_LEN (4U)         /*!< Bit field size in bits for EPDC_WB_FIELD2_LEN. */

/*! @brief Read current value of the EPDC_WB_FIELD2_LEN field. */
#define BR_EPDC_WB_FIELD2_LEN(x) (HW_EPDC_WB_FIELD2(x).B.LEN)

/*! @brief Format value for bitfield EPDC_WB_FIELD2_LEN. */
#define BF_EPDC_WB_FIELD2_LEN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD2_LEN) & BM_EPDC_WB_FIELD2_LEN)

/*! @brief Set the LEN field to a new value. */
#define BW_EPDC_WB_FIELD2_LEN(x, v) (HW_EPDC_WB_FIELD2_WR(x, (HW_EPDC_WB_FIELD2_RD(x) & ~BM_EPDC_WB_FIELD2_LEN) | BF_EPDC_WB_FIELD2_LEN(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD2, field TO[7:4] (RW)
 *
 * Target Field's LSB
 */
/*@{*/
#define BP_EPDC_WB_FIELD2_TO (4U)          /*!< Bit position for EPDC_WB_FIELD2_TO. */
#define BM_EPDC_WB_FIELD2_TO (0x000000F0U) /*!< Bit mask for EPDC_WB_FIELD2_TO. */
#define BS_EPDC_WB_FIELD2_TO (4U)          /*!< Bit field size in bits for EPDC_WB_FIELD2_TO. */

/*! @brief Read current value of the EPDC_WB_FIELD2_TO field. */
#define BR_EPDC_WB_FIELD2_TO(x) (HW_EPDC_WB_FIELD2(x).B.TO)

/*! @brief Format value for bitfield EPDC_WB_FIELD2_TO. */
#define BF_EPDC_WB_FIELD2_TO(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD2_TO) & BM_EPDC_WB_FIELD2_TO)

/*! @brief Set the TO field to a new value. */
#define BW_EPDC_WB_FIELD2_TO(x, v) (HW_EPDC_WB_FIELD2_WR(x, (HW_EPDC_WB_FIELD2_RD(x) & ~BM_EPDC_WB_FIELD2_TO) | BF_EPDC_WB_FIELD2_TO(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD2, field FROM[12:8] (RW)
 *
 * Source Field's LSB
 */
/*@{*/
#define BP_EPDC_WB_FIELD2_FROM (8U)        /*!< Bit position for EPDC_WB_FIELD2_FROM. */
#define BM_EPDC_WB_FIELD2_FROM (0x00001F00U) /*!< Bit mask for EPDC_WB_FIELD2_FROM. */
#define BS_EPDC_WB_FIELD2_FROM (5U)        /*!< Bit field size in bits for EPDC_WB_FIELD2_FROM. */

/*! @brief Read current value of the EPDC_WB_FIELD2_FROM field. */
#define BR_EPDC_WB_FIELD2_FROM(x) (HW_EPDC_WB_FIELD2(x).B.FROM)

/*! @brief Format value for bitfield EPDC_WB_FIELD2_FROM. */
#define BF_EPDC_WB_FIELD2_FROM(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD2_FROM) & BM_EPDC_WB_FIELD2_FROM)

/*! @brief Set the FROM field to a new value. */
#define BW_EPDC_WB_FIELD2_FROM(x, v) (HW_EPDC_WB_FIELD2_WR(x, (HW_EPDC_WB_FIELD2_RD(x) & ~BM_EPDC_WB_FIELD2_FROM) | BF_EPDC_WB_FIELD2_FROM(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD2, field USAGE[15:13] (RW)
 *
 * Values:
 * - 000 - NOT USED
 * - 011 - PARTIAL
 * - 100 - LUT
 * - 101 - CP
 * - 110 - NP
 * - 111 - PTS
 */
/*@{*/
#define BP_EPDC_WB_FIELD2_USAGE (13U)      /*!< Bit position for EPDC_WB_FIELD2_USAGE. */
#define BM_EPDC_WB_FIELD2_USAGE (0x0000E000U) /*!< Bit mask for EPDC_WB_FIELD2_USAGE. */
#define BS_EPDC_WB_FIELD2_USAGE (3U)       /*!< Bit field size in bits for EPDC_WB_FIELD2_USAGE. */

#define BV_EPDC_WB_FIELD2_USAGE_NOT_USED (0U)        /*!< Bit field value for EPDC_WB_FIELD2_USAGE: NOT USED */
#define BV_EPDC_WB_FIELD2_USAGE_PARTIAL (0x3U)       /*!< Bit field value for EPDC_WB_FIELD2_USAGE: PARTIAL */
#define BV_EPDC_WB_FIELD2_USAGE_LUT    (0x4U)        /*!< Bit field value for EPDC_WB_FIELD2_USAGE: LUT */
#define BV_EPDC_WB_FIELD2_USAGE_CP     (0x5U)        /*!< Bit field value for EPDC_WB_FIELD2_USAGE: CP */
#define BV_EPDC_WB_FIELD2_USAGE_NP     (0x6U)        /*!< Bit field value for EPDC_WB_FIELD2_USAGE: NP */
#define BV_EPDC_WB_FIELD2_USAGE_PTS    (0x7U)        /*!< Bit field value for EPDC_WB_FIELD2_USAGE: PTS */

/*! @brief Read current value of the EPDC_WB_FIELD2_USAGE field. */
#define BR_EPDC_WB_FIELD2_USAGE(x) (HW_EPDC_WB_FIELD2(x).B.USAGE)

/*! @brief Format value for bitfield EPDC_WB_FIELD2_USAGE. */
#define BF_EPDC_WB_FIELD2_USAGE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD2_USAGE) & BM_EPDC_WB_FIELD2_USAGE)

/*! @brief Set the USAGE field to a new value. */
#define BW_EPDC_WB_FIELD2_USAGE(x, v) (HW_EPDC_WB_FIELD2_WR(x, (HW_EPDC_WB_FIELD2_RD(x) & ~BM_EPDC_WB_FIELD2_USAGE) | BF_EPDC_WB_FIELD2_USAGE(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD2, field USE_FIXED[17:16] (RW)
 *
 * usage of the FIXED value
 *
 * Values:
 * - 00 - not using FIXED field
 * - 01 - set this field to a FIXED value which specified by FIXED[31:24]
 * - 10 - mask off this pixel if this field is non equal to FIXED[31:24]
 * - 11 - mask off this pixel if this field is equal to FIXED[31:24]
 */
/*@{*/
#define BP_EPDC_WB_FIELD2_USE_FIXED (16U)  /*!< Bit position for EPDC_WB_FIELD2_USE_FIXED. */
#define BM_EPDC_WB_FIELD2_USE_FIXED (0x00030000U) /*!< Bit mask for EPDC_WB_FIELD2_USE_FIXED. */
#define BS_EPDC_WB_FIELD2_USE_FIXED (2U)   /*!< Bit field size in bits for EPDC_WB_FIELD2_USE_FIXED. */

#define BV_EPDC_WB_FIELD2_USE_FIXED_NO_FIXED (0U)    /*!< Bit field value for EPDC_WB_FIELD2_USE_FIXED: not using FIXED field */
#define BV_EPDC_WB_FIELD2_USE_FIXED_USE_FIXED (0x1U) /*!< Bit field value for EPDC_WB_FIELD2_USE_FIXED: set this field to a FIXED value which specified by FIXED[31:24] */
#define BV_EPDC_WB_FIELD2_USE_FIXED_NE_FIXED (0x2U)  /*!< Bit field value for EPDC_WB_FIELD2_USE_FIXED: mask off this pixel if this field is non equal to FIXED[31:24] */
#define BV_EPDC_WB_FIELD2_USE_FIXED_EQ_FIXED (0x3U)  /*!< Bit field value for EPDC_WB_FIELD2_USE_FIXED: mask off this pixel if this field is equal to FIXED[31:24] */

/*! @brief Read current value of the EPDC_WB_FIELD2_USE_FIXED field. */
#define BR_EPDC_WB_FIELD2_USE_FIXED(x) (HW_EPDC_WB_FIELD2(x).B.USE_FIXED)

/*! @brief Format value for bitfield EPDC_WB_FIELD2_USE_FIXED. */
#define BF_EPDC_WB_FIELD2_USE_FIXED(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD2_USE_FIXED) & BM_EPDC_WB_FIELD2_USE_FIXED)

/*! @brief Set the USE_FIXED field to a new value. */
#define BW_EPDC_WB_FIELD2_USE_FIXED(x, v) (HW_EPDC_WB_FIELD2_WR(x, (HW_EPDC_WB_FIELD2_RD(x) & ~BM_EPDC_WB_FIELD2_USE_FIXED) | BF_EPDC_WB_FIELD2_USE_FIXED(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD2, field FIXED[31:24] (RW)
 *
 * used to either force field into a fixed value, or compare to wb field to mask
 * off the pixel
 */
/*@{*/
#define BP_EPDC_WB_FIELD2_FIXED (24U)      /*!< Bit position for EPDC_WB_FIELD2_FIXED. */
#define BM_EPDC_WB_FIELD2_FIXED (0xFF000000U) /*!< Bit mask for EPDC_WB_FIELD2_FIXED. */
#define BS_EPDC_WB_FIELD2_FIXED (8U)       /*!< Bit field size in bits for EPDC_WB_FIELD2_FIXED. */

/*! @brief Read current value of the EPDC_WB_FIELD2_FIXED field. */
#define BR_EPDC_WB_FIELD2_FIXED(x) (HW_EPDC_WB_FIELD2(x).B.FIXED)

/*! @brief Format value for bitfield EPDC_WB_FIELD2_FIXED. */
#define BF_EPDC_WB_FIELD2_FIXED(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD2_FIXED) & BM_EPDC_WB_FIELD2_FIXED)

/*! @brief Set the FIXED field to a new value. */
#define BW_EPDC_WB_FIELD2_FIXED(x, v) (HW_EPDC_WB_FIELD2_WR(x, (HW_EPDC_WB_FIELD2_RD(x) & ~BM_EPDC_WB_FIELD2_FIXED) | BF_EPDC_WB_FIELD2_FIXED(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_WB_FIELD3 - Working Buffer Field Setting
 ******************************************************************************/

/*!
 * @brief HW_EPDC_WB_FIELD3 - Working Buffer Field Setting (RW)
 *
 * Reset value: 0x00006880U
 *
 * specify the pixel fields mapping from working buffer to lut index :
 * WB[FROM+LEN:FROM] =>LUT [TO+LEN:TO]
 */
typedef union _hw_epdc_wb_field3
{
    uint32_t U;
    struct _hw_epdc_wb_field3_bitfields
    {
        uint32_t LEN : 4;              /*!< [3:0]  */
        uint32_t TO : 4;               /*!< [7:4]  */
        uint32_t FROM : 5;             /*!< [12:8]  */
        uint32_t USAGE : 3;            /*!< [15:13]  */
        uint32_t USE_FIXED : 2;        /*!< [17:16]  */
        uint32_t RESERVED0 : 6;        /*!< [23:18]  */
        uint32_t FIXED : 8;            /*!< [31:24]  */
    } B;
} hw_epdc_wb_field3_t;

/*!
 * @name Constants and macros for entire EPDC_WB_FIELD3 register
 */
/*@{*/
#define HW_EPDC_WB_FIELD3_ADDR(x) ((uintptr_t)(x) + 0x90U)

#define HW_EPDC_WB_FIELD3(x)     (*(__IO hw_epdc_wb_field3_t *) HW_EPDC_WB_FIELD3_ADDR(x))
#define HW_EPDC_WB_FIELD3_RD(x)  (HW_EPDC_WB_FIELD3(x).U)
#define HW_EPDC_WB_FIELD3_WR(x, v) (HW_EPDC_WB_FIELD3(x).U = (v))
#define HW_EPDC_WB_FIELD3_SET(x, v) (HW_EPDC_WB_FIELD3_WR(x, HW_EPDC_WB_FIELD3_RD(x) |  (v)))
#define HW_EPDC_WB_FIELD3_CLR(x, v) (HW_EPDC_WB_FIELD3_WR(x, HW_EPDC_WB_FIELD3_RD(x) & ~(v)))
#define HW_EPDC_WB_FIELD3_TOG(x, v) (HW_EPDC_WB_FIELD3_WR(x, HW_EPDC_WB_FIELD3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_WB_FIELD3 bitfields
 */

/*!
 * @name Register EPDC_WB_FIELD3, field LEN[3:0] (RW)
 *
 * Field length minus 1 (0x0 means length=1, 0xf means length=16)
 */
/*@{*/
#define BP_EPDC_WB_FIELD3_LEN (0U)         /*!< Bit position for EPDC_WB_FIELD3_LEN. */
#define BM_EPDC_WB_FIELD3_LEN (0x0000000FU) /*!< Bit mask for EPDC_WB_FIELD3_LEN. */
#define BS_EPDC_WB_FIELD3_LEN (4U)         /*!< Bit field size in bits for EPDC_WB_FIELD3_LEN. */

/*! @brief Read current value of the EPDC_WB_FIELD3_LEN field. */
#define BR_EPDC_WB_FIELD3_LEN(x) (HW_EPDC_WB_FIELD3(x).B.LEN)

/*! @brief Format value for bitfield EPDC_WB_FIELD3_LEN. */
#define BF_EPDC_WB_FIELD3_LEN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD3_LEN) & BM_EPDC_WB_FIELD3_LEN)

/*! @brief Set the LEN field to a new value. */
#define BW_EPDC_WB_FIELD3_LEN(x, v) (HW_EPDC_WB_FIELD3_WR(x, (HW_EPDC_WB_FIELD3_RD(x) & ~BM_EPDC_WB_FIELD3_LEN) | BF_EPDC_WB_FIELD3_LEN(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD3, field TO[7:4] (RW)
 *
 * Target Field's LSB
 */
/*@{*/
#define BP_EPDC_WB_FIELD3_TO (4U)          /*!< Bit position for EPDC_WB_FIELD3_TO. */
#define BM_EPDC_WB_FIELD3_TO (0x000000F0U) /*!< Bit mask for EPDC_WB_FIELD3_TO. */
#define BS_EPDC_WB_FIELD3_TO (4U)          /*!< Bit field size in bits for EPDC_WB_FIELD3_TO. */

/*! @brief Read current value of the EPDC_WB_FIELD3_TO field. */
#define BR_EPDC_WB_FIELD3_TO(x) (HW_EPDC_WB_FIELD3(x).B.TO)

/*! @brief Format value for bitfield EPDC_WB_FIELD3_TO. */
#define BF_EPDC_WB_FIELD3_TO(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD3_TO) & BM_EPDC_WB_FIELD3_TO)

/*! @brief Set the TO field to a new value. */
#define BW_EPDC_WB_FIELD3_TO(x, v) (HW_EPDC_WB_FIELD3_WR(x, (HW_EPDC_WB_FIELD3_RD(x) & ~BM_EPDC_WB_FIELD3_TO) | BF_EPDC_WB_FIELD3_TO(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD3, field FROM[12:8] (RW)
 *
 * Source Field's LSB
 */
/*@{*/
#define BP_EPDC_WB_FIELD3_FROM (8U)        /*!< Bit position for EPDC_WB_FIELD3_FROM. */
#define BM_EPDC_WB_FIELD3_FROM (0x00001F00U) /*!< Bit mask for EPDC_WB_FIELD3_FROM. */
#define BS_EPDC_WB_FIELD3_FROM (5U)        /*!< Bit field size in bits for EPDC_WB_FIELD3_FROM. */

/*! @brief Read current value of the EPDC_WB_FIELD3_FROM field. */
#define BR_EPDC_WB_FIELD3_FROM(x) (HW_EPDC_WB_FIELD3(x).B.FROM)

/*! @brief Format value for bitfield EPDC_WB_FIELD3_FROM. */
#define BF_EPDC_WB_FIELD3_FROM(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD3_FROM) & BM_EPDC_WB_FIELD3_FROM)

/*! @brief Set the FROM field to a new value. */
#define BW_EPDC_WB_FIELD3_FROM(x, v) (HW_EPDC_WB_FIELD3_WR(x, (HW_EPDC_WB_FIELD3_RD(x) & ~BM_EPDC_WB_FIELD3_FROM) | BF_EPDC_WB_FIELD3_FROM(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD3, field USAGE[15:13] (RW)
 *
 * Values:
 * - 000 - NOT USED
 * - 011 - PARTIAL
 * - 100 - LUT
 * - 101 - CP
 * - 110 - NP
 * - 111 - PTS
 */
/*@{*/
#define BP_EPDC_WB_FIELD3_USAGE (13U)      /*!< Bit position for EPDC_WB_FIELD3_USAGE. */
#define BM_EPDC_WB_FIELD3_USAGE (0x0000E000U) /*!< Bit mask for EPDC_WB_FIELD3_USAGE. */
#define BS_EPDC_WB_FIELD3_USAGE (3U)       /*!< Bit field size in bits for EPDC_WB_FIELD3_USAGE. */

#define BV_EPDC_WB_FIELD3_USAGE_NOT_USED (0U)        /*!< Bit field value for EPDC_WB_FIELD3_USAGE: NOT USED */
#define BV_EPDC_WB_FIELD3_USAGE_PARTIAL (0x3U)       /*!< Bit field value for EPDC_WB_FIELD3_USAGE: PARTIAL */
#define BV_EPDC_WB_FIELD3_USAGE_LUT    (0x4U)        /*!< Bit field value for EPDC_WB_FIELD3_USAGE: LUT */
#define BV_EPDC_WB_FIELD3_USAGE_CP     (0x5U)        /*!< Bit field value for EPDC_WB_FIELD3_USAGE: CP */
#define BV_EPDC_WB_FIELD3_USAGE_NP     (0x6U)        /*!< Bit field value for EPDC_WB_FIELD3_USAGE: NP */
#define BV_EPDC_WB_FIELD3_USAGE_PTS    (0x7U)        /*!< Bit field value for EPDC_WB_FIELD3_USAGE: PTS */

/*! @brief Read current value of the EPDC_WB_FIELD3_USAGE field. */
#define BR_EPDC_WB_FIELD3_USAGE(x) (HW_EPDC_WB_FIELD3(x).B.USAGE)

/*! @brief Format value for bitfield EPDC_WB_FIELD3_USAGE. */
#define BF_EPDC_WB_FIELD3_USAGE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD3_USAGE) & BM_EPDC_WB_FIELD3_USAGE)

/*! @brief Set the USAGE field to a new value. */
#define BW_EPDC_WB_FIELD3_USAGE(x, v) (HW_EPDC_WB_FIELD3_WR(x, (HW_EPDC_WB_FIELD3_RD(x) & ~BM_EPDC_WB_FIELD3_USAGE) | BF_EPDC_WB_FIELD3_USAGE(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD3, field USE_FIXED[17:16] (RW)
 *
 * usage of the FIXED value
 *
 * Values:
 * - 00 - not using FIXED field
 * - 01 - set this field to a FIXED value which specified by FIXED[31:24]
 * - 10 - mask off this pixel if this field is non equal to FIXED[31:24]
 * - 11 - mask off this pixel if this field is equal to FIXED[31:24]
 */
/*@{*/
#define BP_EPDC_WB_FIELD3_USE_FIXED (16U)  /*!< Bit position for EPDC_WB_FIELD3_USE_FIXED. */
#define BM_EPDC_WB_FIELD3_USE_FIXED (0x00030000U) /*!< Bit mask for EPDC_WB_FIELD3_USE_FIXED. */
#define BS_EPDC_WB_FIELD3_USE_FIXED (2U)   /*!< Bit field size in bits for EPDC_WB_FIELD3_USE_FIXED. */

#define BV_EPDC_WB_FIELD3_USE_FIXED_NO_FIXED (0U)    /*!< Bit field value for EPDC_WB_FIELD3_USE_FIXED: not using FIXED field */
#define BV_EPDC_WB_FIELD3_USE_FIXED_USE_FIXED (0x1U) /*!< Bit field value for EPDC_WB_FIELD3_USE_FIXED: set this field to a FIXED value which specified by FIXED[31:24] */
#define BV_EPDC_WB_FIELD3_USE_FIXED_NE_FIXED (0x2U)  /*!< Bit field value for EPDC_WB_FIELD3_USE_FIXED: mask off this pixel if this field is non equal to FIXED[31:24] */
#define BV_EPDC_WB_FIELD3_USE_FIXED_EQ_FIXED (0x3U)  /*!< Bit field value for EPDC_WB_FIELD3_USE_FIXED: mask off this pixel if this field is equal to FIXED[31:24] */

/*! @brief Read current value of the EPDC_WB_FIELD3_USE_FIXED field. */
#define BR_EPDC_WB_FIELD3_USE_FIXED(x) (HW_EPDC_WB_FIELD3(x).B.USE_FIXED)

/*! @brief Format value for bitfield EPDC_WB_FIELD3_USE_FIXED. */
#define BF_EPDC_WB_FIELD3_USE_FIXED(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD3_USE_FIXED) & BM_EPDC_WB_FIELD3_USE_FIXED)

/*! @brief Set the USE_FIXED field to a new value. */
#define BW_EPDC_WB_FIELD3_USE_FIXED(x, v) (HW_EPDC_WB_FIELD3_WR(x, (HW_EPDC_WB_FIELD3_RD(x) & ~BM_EPDC_WB_FIELD3_USE_FIXED) | BF_EPDC_WB_FIELD3_USE_FIXED(v)))
/*@}*/

/*!
 * @name Register EPDC_WB_FIELD3, field FIXED[31:24] (RW)
 *
 * used to either force field into a fixed value, or compare to wb field to mask
 * off the pixel
 */
/*@{*/
#define BP_EPDC_WB_FIELD3_FIXED (24U)      /*!< Bit position for EPDC_WB_FIELD3_FIXED. */
#define BM_EPDC_WB_FIELD3_FIXED (0xFF000000U) /*!< Bit mask for EPDC_WB_FIELD3_FIXED. */
#define BS_EPDC_WB_FIELD3_FIXED (8U)       /*!< Bit field size in bits for EPDC_WB_FIELD3_FIXED. */

/*! @brief Read current value of the EPDC_WB_FIELD3_FIXED field. */
#define BR_EPDC_WB_FIELD3_FIXED(x) (HW_EPDC_WB_FIELD3(x).B.FIXED)

/*! @brief Format value for bitfield EPDC_WB_FIELD3_FIXED. */
#define BF_EPDC_WB_FIELD3_FIXED(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_WB_FIELD3_FIXED) & BM_EPDC_WB_FIELD3_FIXED)

/*! @brief Set the FIXED field to a new value. */
#define BW_EPDC_WB_FIELD3_FIXED(x, v) (HW_EPDC_WB_FIELD3_WR(x, (HW_EPDC_WB_FIELD3_RD(x) & ~BM_EPDC_WB_FIELD3_FIXED) | BF_EPDC_WB_FIELD3_FIXED(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_FIFOCTRL - EPDC FIFO control register
 ******************************************************************************/

/*!
 * @brief HW_EPDC_FIFOCTRL - EPDC FIFO control register (RW)
 *
 * Reset value: 0x00800000U
 *
 * Allows for programmability of pixel FIFO watermarks used in conjunction with
 * system arbitration hardware This register houses FIFO control bits EXAMPLE /-
 * EPDC_FIFOCTRL (disabled) -/ reg_val = ((100 <<
 * EPDC_FIFOCTRL_FIFO_INIT_LEVEL_OFFSET) & EPDC_FIFOCTRL_FIFO_INIT_LEVEL_MASK) | ((200 <<
 * EPDC_FIFOCTRL_FIFO_H_LEVEL_OFFSET) & EPDC_FIFOCTRL_FIFO_H_LEVEL_MASK) | ((100 <<
 * EPDC_FIFOCTRL_FIFO_L_LEVEL_OFFSET) & EPDC_FIFOCTRL_FIFO_L_LEVEL_MASK); __raw_writel(reg_val,
 * EPDC_FIFOCTRL);
 */
typedef union _hw_epdc_fifoctrl
{
    uint32_t U;
    struct _hw_epdc_fifoctrl_bitfields
    {
        uint32_t FIFO_L_LEVEL : 8;     /*!< [7:0]  */
        uint32_t FIFO_H_LEVEL : 8;     /*!< [15:8]  */
        uint32_t FIFO_INIT_LEVEL : 8;  /*!< [23:16]  */
        uint32_t RESERVED0 : 7;        /*!< [30:24]  */
        uint32_t ENABLE_PRIORITY : 1;  /*!< [31]  */
    } B;
} hw_epdc_fifoctrl_t;

/*!
 * @name Constants and macros for entire EPDC_FIFOCTRL register
 */
/*@{*/
#define HW_EPDC_FIFOCTRL_ADDR(x) ((uintptr_t)(x) + 0xA0U)
#define HW_EPDC_FIFOCTRL_SET_ADDR(x) (HW_EPDC_FIFOCTRL_ADDR(x) + 0x4U)
#define HW_EPDC_FIFOCTRL_CLR_ADDR(x) (HW_EPDC_FIFOCTRL_ADDR(x) + 0x8U)
#define HW_EPDC_FIFOCTRL_TOG_ADDR(x) (HW_EPDC_FIFOCTRL_ADDR(x) + 0xCU)

#define HW_EPDC_FIFOCTRL(x)      (*(__IO hw_epdc_fifoctrl_t *) HW_EPDC_FIFOCTRL_ADDR(x))
#define HW_EPDC_FIFOCTRL_RD(x)   (HW_EPDC_FIFOCTRL(x).U)
#define HW_EPDC_FIFOCTRL_WR(x, v) (HW_EPDC_FIFOCTRL(x).U = (v))
#define HW_EPDC_FIFOCTRL_SET(x, v) ((*(uint32_t *) HW_EPDC_FIFOCTRL_SET_ADDR(x)) = (v))
#define HW_EPDC_FIFOCTRL_CLR(x, v) ((*(uint32_t *) HW_EPDC_FIFOCTRL_CLR_ADDR(x)) = (v))
#define HW_EPDC_FIFOCTRL_TOG(x, v) ((*(uint32_t *) HW_EPDC_FIFOCTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_FIFOCTRL bitfields
 */

/*!
 * @name Register EPDC_FIFOCTRL, field FIFO_L_LEVEL[7:0] (RW)
 *
 * Lower level value of FIFO watermark. When the pixel FIFO reaches this level
 * or below, the priority elevation request is asserted.
 */
/*@{*/
#define BP_EPDC_FIFOCTRL_FIFO_L_LEVEL (0U) /*!< Bit position for EPDC_FIFOCTRL_FIFO_L_LEVEL. */
#define BM_EPDC_FIFOCTRL_FIFO_L_LEVEL (0x000000FFU) /*!< Bit mask for EPDC_FIFOCTRL_FIFO_L_LEVEL. */
#define BS_EPDC_FIFOCTRL_FIFO_L_LEVEL (8U) /*!< Bit field size in bits for EPDC_FIFOCTRL_FIFO_L_LEVEL. */

/*! @brief Read current value of the EPDC_FIFOCTRL_FIFO_L_LEVEL field. */
#define BR_EPDC_FIFOCTRL_FIFO_L_LEVEL(x) (HW_EPDC_FIFOCTRL(x).B.FIFO_L_LEVEL)

/*! @brief Format value for bitfield EPDC_FIFOCTRL_FIFO_L_LEVEL. */
#define BF_EPDC_FIFOCTRL_FIFO_L_LEVEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_FIFOCTRL_FIFO_L_LEVEL) & BM_EPDC_FIFOCTRL_FIFO_L_LEVEL)

/*! @brief Set the FIFO_L_LEVEL field to a new value. */
#define BW_EPDC_FIFOCTRL_FIFO_L_LEVEL(x, v) (HW_EPDC_FIFOCTRL_WR(x, (HW_EPDC_FIFOCTRL_RD(x) & ~BM_EPDC_FIFOCTRL_FIFO_L_LEVEL) | BF_EPDC_FIFOCTRL_FIFO_L_LEVEL(v)))
/*@}*/

/*!
 * @name Register EPDC_FIFOCTRL, field FIFO_H_LEVEL[15:8] (RW)
 *
 * Upper level value of FIFO watermark. Must be greater than FIFO_L_LEVEL. When
 * the pixel FIFO reaches this level or above, the priority elevation request is
 * negated
 */
/*@{*/
#define BP_EPDC_FIFOCTRL_FIFO_H_LEVEL (8U) /*!< Bit position for EPDC_FIFOCTRL_FIFO_H_LEVEL. */
#define BM_EPDC_FIFOCTRL_FIFO_H_LEVEL (0x0000FF00U) /*!< Bit mask for EPDC_FIFOCTRL_FIFO_H_LEVEL. */
#define BS_EPDC_FIFOCTRL_FIFO_H_LEVEL (8U) /*!< Bit field size in bits for EPDC_FIFOCTRL_FIFO_H_LEVEL. */

/*! @brief Read current value of the EPDC_FIFOCTRL_FIFO_H_LEVEL field. */
#define BR_EPDC_FIFOCTRL_FIFO_H_LEVEL(x) (HW_EPDC_FIFOCTRL(x).B.FIFO_H_LEVEL)

/*! @brief Format value for bitfield EPDC_FIFOCTRL_FIFO_H_LEVEL. */
#define BF_EPDC_FIFOCTRL_FIFO_H_LEVEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_FIFOCTRL_FIFO_H_LEVEL) & BM_EPDC_FIFOCTRL_FIFO_H_LEVEL)

/*! @brief Set the FIFO_H_LEVEL field to a new value. */
#define BW_EPDC_FIFOCTRL_FIFO_H_LEVEL(x, v) (HW_EPDC_FIFOCTRL_WR(x, (HW_EPDC_FIFOCTRL_RD(x) & ~BM_EPDC_FIFOCTRL_FIFO_H_LEVEL) | BF_EPDC_FIFOCTRL_FIFO_H_LEVEL(v)))
/*@}*/

/*!
 * @name Register EPDC_FIFOCTRL, field FIFO_INIT_LEVEL[23:16] (RW)
 *
 * This register sets the watermark for the pixel-fifo.
 */
/*@{*/
#define BP_EPDC_FIFOCTRL_FIFO_INIT_LEVEL (16U) /*!< Bit position for EPDC_FIFOCTRL_FIFO_INIT_LEVEL. */
#define BM_EPDC_FIFOCTRL_FIFO_INIT_LEVEL (0x00FF0000U) /*!< Bit mask for EPDC_FIFOCTRL_FIFO_INIT_LEVEL. */
#define BS_EPDC_FIFOCTRL_FIFO_INIT_LEVEL (8U) /*!< Bit field size in bits for EPDC_FIFOCTRL_FIFO_INIT_LEVEL. */

/*! @brief Read current value of the EPDC_FIFOCTRL_FIFO_INIT_LEVEL field. */
#define BR_EPDC_FIFOCTRL_FIFO_INIT_LEVEL(x) (HW_EPDC_FIFOCTRL(x).B.FIFO_INIT_LEVEL)

/*! @brief Format value for bitfield EPDC_FIFOCTRL_FIFO_INIT_LEVEL. */
#define BF_EPDC_FIFOCTRL_FIFO_INIT_LEVEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_FIFOCTRL_FIFO_INIT_LEVEL) & BM_EPDC_FIFOCTRL_FIFO_INIT_LEVEL)

/*! @brief Set the FIFO_INIT_LEVEL field to a new value. */
#define BW_EPDC_FIFOCTRL_FIFO_INIT_LEVEL(x, v) (HW_EPDC_FIFOCTRL_WR(x, (HW_EPDC_FIFOCTRL_RD(x) & ~BM_EPDC_FIFOCTRL_FIFO_INIT_LEVEL) | BF_EPDC_FIFOCTRL_FIFO_INIT_LEVEL(v)))
/*@}*/

/*!
 * @name Register EPDC_FIFOCTRL, field ENABLE_PRIORITY[31] (RW)
 *
 * Enable watermark-based priority elevation mechanism. 1=Enabled, 0=Disabled.
 * (Only applies to FIFO_H_LEVEL and FIFO_L_LEVEL)
 */
/*@{*/
#define BP_EPDC_FIFOCTRL_ENABLE_PRIORITY (31U) /*!< Bit position for EPDC_FIFOCTRL_ENABLE_PRIORITY. */
#define BM_EPDC_FIFOCTRL_ENABLE_PRIORITY (0x80000000U) /*!< Bit mask for EPDC_FIFOCTRL_ENABLE_PRIORITY. */
#define BS_EPDC_FIFOCTRL_ENABLE_PRIORITY (1U) /*!< Bit field size in bits for EPDC_FIFOCTRL_ENABLE_PRIORITY. */

/*! @brief Read current value of the EPDC_FIFOCTRL_ENABLE_PRIORITY field. */
#define BR_EPDC_FIFOCTRL_ENABLE_PRIORITY(x) (HW_EPDC_FIFOCTRL(x).B.ENABLE_PRIORITY)

/*! @brief Format value for bitfield EPDC_FIFOCTRL_ENABLE_PRIORITY. */
#define BF_EPDC_FIFOCTRL_ENABLE_PRIORITY(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_FIFOCTRL_ENABLE_PRIORITY) & BM_EPDC_FIFOCTRL_ENABLE_PRIORITY)

/*! @brief Set the ENABLE_PRIORITY field to a new value. */
#define BW_EPDC_FIFOCTRL_ENABLE_PRIORITY(x, v) (HW_EPDC_FIFOCTRL_WR(x, (HW_EPDC_FIFOCTRL_RD(x) & ~BM_EPDC_FIFOCTRL_ENABLE_PRIORITY) | BF_EPDC_FIFOCTRL_ENABLE_PRIORITY(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_UPD_ADDR - EPDC Update Region Address
 ******************************************************************************/

/*!
 * @brief HW_EPDC_UPD_ADDR - EPDC Update Region Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * EPDC Update Region Address The address alignment depends on whether the
 * update region stride register (EPDC_UPD_STRIDE) is set or not. If EPDC_UPD_STRIDE
 * is zero, the update region address must start and end on the 8-byte aligned
 * addresses. If EPDC_UPD_STRIDE is non-zero, the update region address can start
 * and/or end on any byte addressing. But aligned address still recomended be get
 * best bus performance. EXAMPLE1 /- no update stride case -/ u32 stride = 0; u32
 * addr = 0x100; /- 8-byte aligned -/ __raw_writel(stride, EPDC_UPD_STRIDE);
 * __raw_writel(addr, EPDC_UPD_ADDR); EXAMPLE2 /- update stride = 345 -/ u32 stride =
 * 345; u32 addr = 0x123; /- 8-byte unaligned is OK -/ __raw_writel(stride,
 * EPDC_UPD_STRIDE); __raw_writel(addr, EPDC_UPD_ADDR);
 */
typedef union _hw_epdc_upd_addr
{
    uint32_t U;
    struct _hw_epdc_upd_addr_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_epdc_upd_addr_t;

/*!
 * @name Constants and macros for entire EPDC_UPD_ADDR register
 */
/*@{*/
#define HW_EPDC_UPD_ADDR_ADDR(x) ((uintptr_t)(x) + 0x100U)

#define HW_EPDC_UPD_ADDR(x)      (*(__IO hw_epdc_upd_addr_t *) HW_EPDC_UPD_ADDR_ADDR(x))
#define HW_EPDC_UPD_ADDR_RD(x)   (HW_EPDC_UPD_ADDR(x).U)
#define HW_EPDC_UPD_ADDR_WR(x, v) (HW_EPDC_UPD_ADDR(x).U = (v))
#define HW_EPDC_UPD_ADDR_SET(x, v) (HW_EPDC_UPD_ADDR_WR(x, HW_EPDC_UPD_ADDR_RD(x) |  (v)))
#define HW_EPDC_UPD_ADDR_CLR(x, v) (HW_EPDC_UPD_ADDR_WR(x, HW_EPDC_UPD_ADDR_RD(x) & ~(v)))
#define HW_EPDC_UPD_ADDR_TOG(x, v) (HW_EPDC_UPD_ADDR_WR(x, HW_EPDC_UPD_ADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_UPD_ADDR bitfields
 */

/*!
 * @name Register EPDC_UPD_ADDR, field ADDR[31:0] (RW)
 *
 * Address for incoming region update. This address points to update region
 * which will be processed into the working buffer.
 */
/*@{*/
#define BP_EPDC_UPD_ADDR_ADDR (0U)         /*!< Bit position for EPDC_UPD_ADDR_ADDR. */
#define BM_EPDC_UPD_ADDR_ADDR (0xFFFFFFFFU) /*!< Bit mask for EPDC_UPD_ADDR_ADDR. */
#define BS_EPDC_UPD_ADDR_ADDR (32U)        /*!< Bit field size in bits for EPDC_UPD_ADDR_ADDR. */

/*! @brief Read current value of the EPDC_UPD_ADDR_ADDR field. */
#define BR_EPDC_UPD_ADDR_ADDR(x) (HW_EPDC_UPD_ADDR(x).U)

/*! @brief Format value for bitfield EPDC_UPD_ADDR_ADDR. */
#define BF_EPDC_UPD_ADDR_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_UPD_ADDR_ADDR) & BM_EPDC_UPD_ADDR_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_EPDC_UPD_ADDR_ADDR(x, v) (HW_EPDC_UPD_ADDR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_EPDC_UPD_STRIDE - EPDC Update Region Stride
 ******************************************************************************/

/*!
 * @brief HW_EPDC_UPD_STRIDE - EPDC Update Region Stride (RW)
 *
 * Reset value: 0x00000000U
 *
 * EPDC Update Region Stride When UPD_STRIDE==0 (stride feature disabled), UPD
 * buffer line must start from 64-bit boundary and end on 64-bit boundary(padding
 * if not). When UPD_STRIDE!=0 (stride feature enabled), UPD buffer line can
 * start or end on any byte address, UPD_WIDTH should be set to real line bytes count
 * as normal, while UPD_STRIDE set to byte distance between two lines' start.
 * EXAMPLE see details on stride feature introduction
 */
typedef union _hw_epdc_upd_stride
{
    uint32_t U;
    struct _hw_epdc_upd_stride_bitfields
    {
        uint32_t STRIDE : 32;          /*!< [31:0]  */
    } B;
} hw_epdc_upd_stride_t;

/*!
 * @name Constants and macros for entire EPDC_UPD_STRIDE register
 */
/*@{*/
#define HW_EPDC_UPD_STRIDE_ADDR(x) ((uintptr_t)(x) + 0x110U)

#define HW_EPDC_UPD_STRIDE(x)    (*(__IO hw_epdc_upd_stride_t *) HW_EPDC_UPD_STRIDE_ADDR(x))
#define HW_EPDC_UPD_STRIDE_RD(x) (HW_EPDC_UPD_STRIDE(x).U)
#define HW_EPDC_UPD_STRIDE_WR(x, v) (HW_EPDC_UPD_STRIDE(x).U = (v))
#define HW_EPDC_UPD_STRIDE_SET(x, v) (HW_EPDC_UPD_STRIDE_WR(x, HW_EPDC_UPD_STRIDE_RD(x) |  (v)))
#define HW_EPDC_UPD_STRIDE_CLR(x, v) (HW_EPDC_UPD_STRIDE_WR(x, HW_EPDC_UPD_STRIDE_RD(x) & ~(v)))
#define HW_EPDC_UPD_STRIDE_TOG(x, v) (HW_EPDC_UPD_STRIDE_WR(x, HW_EPDC_UPD_STRIDE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_UPD_STRIDE bitfields
 */

/*!
 * @name Register EPDC_UPD_STRIDE, field STRIDE[31:0] (RW)
 *
 * line stride for incoming region update
 */
/*@{*/
#define BP_EPDC_UPD_STRIDE_STRIDE (0U)     /*!< Bit position for EPDC_UPD_STRIDE_STRIDE. */
#define BM_EPDC_UPD_STRIDE_STRIDE (0xFFFFFFFFU) /*!< Bit mask for EPDC_UPD_STRIDE_STRIDE. */
#define BS_EPDC_UPD_STRIDE_STRIDE (32U)    /*!< Bit field size in bits for EPDC_UPD_STRIDE_STRIDE. */

/*! @brief Read current value of the EPDC_UPD_STRIDE_STRIDE field. */
#define BR_EPDC_UPD_STRIDE_STRIDE(x) (HW_EPDC_UPD_STRIDE(x).U)

/*! @brief Format value for bitfield EPDC_UPD_STRIDE_STRIDE. */
#define BF_EPDC_UPD_STRIDE_STRIDE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_UPD_STRIDE_STRIDE) & BM_EPDC_UPD_STRIDE_STRIDE)

/*! @brief Set the STRIDE field to a new value. */
#define BW_EPDC_UPD_STRIDE_STRIDE(x, v) (HW_EPDC_UPD_STRIDE_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_EPDC_UPD_CORD - EPDC Update Command Co-ordinate
 ******************************************************************************/

/*!
 * @brief HW_EPDC_UPD_CORD - EPDC Update Command Co-ordinate (RW)
 *
 * Reset value: 0x00000000U
 *
 * EPDC Update Command Co-ordinate This register is used for setting up the
 * coordinate of a new update region.
 */
typedef union _hw_epdc_upd_cord
{
    uint32_t U;
    struct _hw_epdc_upd_cord_bitfields
    {
        uint32_t XCORD : 13;           /*!< [12:0]  */
        uint32_t RESERVED0 : 3;        /*!< [15:13]  */
        uint32_t YCORD : 13;           /*!< [28:16]  */
        uint32_t RESERVED1 : 3;        /*!< [31:29]  */
    } B;
} hw_epdc_upd_cord_t;

/*!
 * @name Constants and macros for entire EPDC_UPD_CORD register
 */
/*@{*/
#define HW_EPDC_UPD_CORD_ADDR(x) ((uintptr_t)(x) + 0x120U)

#define HW_EPDC_UPD_CORD(x)      (*(__IO hw_epdc_upd_cord_t *) HW_EPDC_UPD_CORD_ADDR(x))
#define HW_EPDC_UPD_CORD_RD(x)   (HW_EPDC_UPD_CORD(x).U)
#define HW_EPDC_UPD_CORD_WR(x, v) (HW_EPDC_UPD_CORD(x).U = (v))
#define HW_EPDC_UPD_CORD_SET(x, v) (HW_EPDC_UPD_CORD_WR(x, HW_EPDC_UPD_CORD_RD(x) |  (v)))
#define HW_EPDC_UPD_CORD_CLR(x, v) (HW_EPDC_UPD_CORD_WR(x, HW_EPDC_UPD_CORD_RD(x) & ~(v)))
#define HW_EPDC_UPD_CORD_TOG(x, v) (HW_EPDC_UPD_CORD_WR(x, HW_EPDC_UPD_CORD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_UPD_CORD bitfields
 */

/*!
 * @name Register EPDC_UPD_CORD, field XCORD[12:0] (RW)
 *
 * X co-ordinate for incoming region update
 */
/*@{*/
#define BP_EPDC_UPD_CORD_XCORD (0U)        /*!< Bit position for EPDC_UPD_CORD_XCORD. */
#define BM_EPDC_UPD_CORD_XCORD (0x00001FFFU) /*!< Bit mask for EPDC_UPD_CORD_XCORD. */
#define BS_EPDC_UPD_CORD_XCORD (13U)       /*!< Bit field size in bits for EPDC_UPD_CORD_XCORD. */

/*! @brief Read current value of the EPDC_UPD_CORD_XCORD field. */
#define BR_EPDC_UPD_CORD_XCORD(x) (HW_EPDC_UPD_CORD(x).B.XCORD)

/*! @brief Format value for bitfield EPDC_UPD_CORD_XCORD. */
#define BF_EPDC_UPD_CORD_XCORD(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_UPD_CORD_XCORD) & BM_EPDC_UPD_CORD_XCORD)

/*! @brief Set the XCORD field to a new value. */
#define BW_EPDC_UPD_CORD_XCORD(x, v) (HW_EPDC_UPD_CORD_WR(x, (HW_EPDC_UPD_CORD_RD(x) & ~BM_EPDC_UPD_CORD_XCORD) | BF_EPDC_UPD_CORD_XCORD(v)))
/*@}*/

/*!
 * @name Register EPDC_UPD_CORD, field YCORD[28:16] (RW)
 *
 * Y co-ordinate for incoming region update
 */
/*@{*/
#define BP_EPDC_UPD_CORD_YCORD (16U)       /*!< Bit position for EPDC_UPD_CORD_YCORD. */
#define BM_EPDC_UPD_CORD_YCORD (0x1FFF0000U) /*!< Bit mask for EPDC_UPD_CORD_YCORD. */
#define BS_EPDC_UPD_CORD_YCORD (13U)       /*!< Bit field size in bits for EPDC_UPD_CORD_YCORD. */

/*! @brief Read current value of the EPDC_UPD_CORD_YCORD field. */
#define BR_EPDC_UPD_CORD_YCORD(x) (HW_EPDC_UPD_CORD(x).B.YCORD)

/*! @brief Format value for bitfield EPDC_UPD_CORD_YCORD. */
#define BF_EPDC_UPD_CORD_YCORD(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_UPD_CORD_YCORD) & BM_EPDC_UPD_CORD_YCORD)

/*! @brief Set the YCORD field to a new value. */
#define BW_EPDC_UPD_CORD_YCORD(x, v) (HW_EPDC_UPD_CORD_WR(x, (HW_EPDC_UPD_CORD_RD(x) & ~BM_EPDC_UPD_CORD_YCORD) | BF_EPDC_UPD_CORD_YCORD(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_UPD_SIZE - EPDC Update Command Size
 ******************************************************************************/

/*!
 * @brief HW_EPDC_UPD_SIZE - EPDC Update Command Size (RW)
 *
 * Reset value: 0x00000000U
 *
 * EPDC Update Command Size This register sets up the size of an update region.
 */
typedef union _hw_epdc_upd_size
{
    uint32_t U;
    struct _hw_epdc_upd_size_bitfields
    {
        uint32_t WIDTH : 13;           /*!< [12:0]  */
        uint32_t RESERVED0 : 3;        /*!< [15:13]  */
        uint32_t HEIGHT : 13;          /*!< [28:16]  */
        uint32_t RESERVED1 : 3;        /*!< [31:29]  */
    } B;
} hw_epdc_upd_size_t;

/*!
 * @name Constants and macros for entire EPDC_UPD_SIZE register
 */
/*@{*/
#define HW_EPDC_UPD_SIZE_ADDR(x) ((uintptr_t)(x) + 0x140U)

#define HW_EPDC_UPD_SIZE(x)      (*(__IO hw_epdc_upd_size_t *) HW_EPDC_UPD_SIZE_ADDR(x))
#define HW_EPDC_UPD_SIZE_RD(x)   (HW_EPDC_UPD_SIZE(x).U)
#define HW_EPDC_UPD_SIZE_WR(x, v) (HW_EPDC_UPD_SIZE(x).U = (v))
#define HW_EPDC_UPD_SIZE_SET(x, v) (HW_EPDC_UPD_SIZE_WR(x, HW_EPDC_UPD_SIZE_RD(x) |  (v)))
#define HW_EPDC_UPD_SIZE_CLR(x, v) (HW_EPDC_UPD_SIZE_WR(x, HW_EPDC_UPD_SIZE_RD(x) & ~(v)))
#define HW_EPDC_UPD_SIZE_TOG(x, v) (HW_EPDC_UPD_SIZE_WR(x, HW_EPDC_UPD_SIZE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_UPD_SIZE bitfields
 */

/*!
 * @name Register EPDC_UPD_SIZE, field WIDTH[12:0] (RW)
 *
 * Width (in pixels)
 */
/*@{*/
#define BP_EPDC_UPD_SIZE_WIDTH (0U)        /*!< Bit position for EPDC_UPD_SIZE_WIDTH. */
#define BM_EPDC_UPD_SIZE_WIDTH (0x00001FFFU) /*!< Bit mask for EPDC_UPD_SIZE_WIDTH. */
#define BS_EPDC_UPD_SIZE_WIDTH (13U)       /*!< Bit field size in bits for EPDC_UPD_SIZE_WIDTH. */

/*! @brief Read current value of the EPDC_UPD_SIZE_WIDTH field. */
#define BR_EPDC_UPD_SIZE_WIDTH(x) (HW_EPDC_UPD_SIZE(x).B.WIDTH)

/*! @brief Format value for bitfield EPDC_UPD_SIZE_WIDTH. */
#define BF_EPDC_UPD_SIZE_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_UPD_SIZE_WIDTH) & BM_EPDC_UPD_SIZE_WIDTH)

/*! @brief Set the WIDTH field to a new value. */
#define BW_EPDC_UPD_SIZE_WIDTH(x, v) (HW_EPDC_UPD_SIZE_WR(x, (HW_EPDC_UPD_SIZE_RD(x) & ~BM_EPDC_UPD_SIZE_WIDTH) | BF_EPDC_UPD_SIZE_WIDTH(v)))
/*@}*/

/*!
 * @name Register EPDC_UPD_SIZE, field HEIGHT[28:16] (RW)
 *
 * Height (in pixels)
 */
/*@{*/
#define BP_EPDC_UPD_SIZE_HEIGHT (16U)      /*!< Bit position for EPDC_UPD_SIZE_HEIGHT. */
#define BM_EPDC_UPD_SIZE_HEIGHT (0x1FFF0000U) /*!< Bit mask for EPDC_UPD_SIZE_HEIGHT. */
#define BS_EPDC_UPD_SIZE_HEIGHT (13U)      /*!< Bit field size in bits for EPDC_UPD_SIZE_HEIGHT. */

/*! @brief Read current value of the EPDC_UPD_SIZE_HEIGHT field. */
#define BR_EPDC_UPD_SIZE_HEIGHT(x) (HW_EPDC_UPD_SIZE(x).B.HEIGHT)

/*! @brief Format value for bitfield EPDC_UPD_SIZE_HEIGHT. */
#define BF_EPDC_UPD_SIZE_HEIGHT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_UPD_SIZE_HEIGHT) & BM_EPDC_UPD_SIZE_HEIGHT)

/*! @brief Set the HEIGHT field to a new value. */
#define BW_EPDC_UPD_SIZE_HEIGHT(x, v) (HW_EPDC_UPD_SIZE_WR(x, (HW_EPDC_UPD_SIZE_RD(x) & ~BM_EPDC_UPD_SIZE_HEIGHT) | BF_EPDC_UPD_SIZE_HEIGHT(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_UPD_CTRL - EPDC Update Command Control
 ******************************************************************************/

/*!
 * @brief HW_EPDC_UPD_CTRL - EPDC Update Command Control (RW)
 *
 * Reset value: 0x00000000U
 *
 * EPDC Update Command Control. Writing to this registers triggers and update
 * request operation.
 */
typedef union _hw_epdc_upd_ctrl
{
    uint32_t U;
    struct _hw_epdc_upd_ctrl_bitfields
    {
        uint32_t UPDATE_MODE : 1;      /*!< [0]  */
        uint32_t DRY_RUN : 1;          /*!< [1]  */
        uint32_t AUTOWV : 1;           /*!< [2]  */
        uint32_t PAUSE : 1;            /*!< [3]  */
        uint32_t NO_LUT_CANCEL : 1;    /*!< [4]  */
        uint32_t STANDBY : 1;          /*!< [5]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t WAVEFORM_MODE : 8;    /*!< [15:8]  */
        uint32_t LUT_SEL : 6;          /*!< [21:16]  */
        uint32_t RESERVED1 : 9;        /*!< [30:22]  */
        uint32_t USE_FIXED : 1;        /*!< [31]  */
    } B;
} hw_epdc_upd_ctrl_t;

/*!
 * @name Constants and macros for entire EPDC_UPD_CTRL register
 */
/*@{*/
#define HW_EPDC_UPD_CTRL_ADDR(x) ((uintptr_t)(x) + 0x160U)
#define HW_EPDC_UPD_CTRL_SET_ADDR(x) (HW_EPDC_UPD_CTRL_ADDR(x) + 0x4U)
#define HW_EPDC_UPD_CTRL_CLR_ADDR(x) (HW_EPDC_UPD_CTRL_ADDR(x) + 0x8U)
#define HW_EPDC_UPD_CTRL_TOG_ADDR(x) (HW_EPDC_UPD_CTRL_ADDR(x) + 0xCU)

#define HW_EPDC_UPD_CTRL(x)      (*(__IO hw_epdc_upd_ctrl_t *) HW_EPDC_UPD_CTRL_ADDR(x))
#define HW_EPDC_UPD_CTRL_RD(x)   (HW_EPDC_UPD_CTRL(x).U)
#define HW_EPDC_UPD_CTRL_WR(x, v) (HW_EPDC_UPD_CTRL(x).U = (v))
#define HW_EPDC_UPD_CTRL_SET(x, v) ((*(uint32_t *) HW_EPDC_UPD_CTRL_SET_ADDR(x)) = (v))
#define HW_EPDC_UPD_CTRL_CLR(x, v) ((*(uint32_t *) HW_EPDC_UPD_CTRL_CLR_ADDR(x)) = (v))
#define HW_EPDC_UPD_CTRL_TOG(x, v) ((*(uint32_t *) HW_EPDC_UPD_CTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_UPD_CTRL bitfields
 */

/*!
 * @name Register EPDC_UPD_CTRL, field UPDATE_MODE[0] (RW)
 *
 * Update Mode
 *
 * Values:
 * - 0 - Partial Update : only process changed pixels in region
 * - 1 - Full Update : process all pixels in region
 */
/*@{*/
#define BP_EPDC_UPD_CTRL_UPDATE_MODE (0U)  /*!< Bit position for EPDC_UPD_CTRL_UPDATE_MODE. */
#define BM_EPDC_UPD_CTRL_UPDATE_MODE (0x00000001U) /*!< Bit mask for EPDC_UPD_CTRL_UPDATE_MODE. */
#define BS_EPDC_UPD_CTRL_UPDATE_MODE (1U)  /*!< Bit field size in bits for EPDC_UPD_CTRL_UPDATE_MODE. */

#define BV_EPDC_UPD_CTRL_UPDATE_MODE_PARTIAL (0U)    /*!< Bit field value for EPDC_UPD_CTRL_UPDATE_MODE: Partial Update : only process changed pixels in region */
#define BV_EPDC_UPD_CTRL_UPDATE_MODE_FULL (0x1U)     /*!< Bit field value for EPDC_UPD_CTRL_UPDATE_MODE: Full Update : process all pixels in region */

/*! @brief Read current value of the EPDC_UPD_CTRL_UPDATE_MODE field. */
#define BR_EPDC_UPD_CTRL_UPDATE_MODE(x) (HW_EPDC_UPD_CTRL(x).B.UPDATE_MODE)

/*! @brief Format value for bitfield EPDC_UPD_CTRL_UPDATE_MODE. */
#define BF_EPDC_UPD_CTRL_UPDATE_MODE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_UPD_CTRL_UPDATE_MODE) & BM_EPDC_UPD_CTRL_UPDATE_MODE)

/*! @brief Set the UPDATE_MODE field to a new value. */
#define BW_EPDC_UPD_CTRL_UPDATE_MODE(x, v) (HW_EPDC_UPD_CTRL_WR(x, (HW_EPDC_UPD_CTRL_RD(x) & ~BM_EPDC_UPD_CTRL_UPDATE_MODE) | BF_EPDC_UPD_CTRL_UPDATE_MODE(v)))
/*@}*/

/*!
 * @name Register EPDC_UPD_CTRL, field DRY_RUN[1] (RW)
 *
 * Enable Dry Run mode(set to 1). WB won't be updated in this mode, and lut_sel
 * will be ignored, so actually you don't need to wait for LUT available to use
 * this feature
 */
/*@{*/
#define BP_EPDC_UPD_CTRL_DRY_RUN (1U)      /*!< Bit position for EPDC_UPD_CTRL_DRY_RUN. */
#define BM_EPDC_UPD_CTRL_DRY_RUN (0x00000002U) /*!< Bit mask for EPDC_UPD_CTRL_DRY_RUN. */
#define BS_EPDC_UPD_CTRL_DRY_RUN (1U)      /*!< Bit field size in bits for EPDC_UPD_CTRL_DRY_RUN. */

/*! @brief Read current value of the EPDC_UPD_CTRL_DRY_RUN field. */
#define BR_EPDC_UPD_CTRL_DRY_RUN(x) (HW_EPDC_UPD_CTRL(x).B.DRY_RUN)

/*! @brief Format value for bitfield EPDC_UPD_CTRL_DRY_RUN. */
#define BF_EPDC_UPD_CTRL_DRY_RUN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_UPD_CTRL_DRY_RUN) & BM_EPDC_UPD_CTRL_DRY_RUN)

/*! @brief Set the DRY_RUN field to a new value. */
#define BW_EPDC_UPD_CTRL_DRY_RUN(x, v) (HW_EPDC_UPD_CTRL_WR(x, (HW_EPDC_UPD_CTRL_RD(x) & ~BM_EPDC_UPD_CTRL_DRY_RUN) | BF_EPDC_UPD_CTRL_DRY_RUN(v)))
/*@}*/

/*!
 * @name Register EPDC_UPD_CTRL, field AUTOWV[2] (RW)
 *
 * enable automatical waveform mode selection
 */
/*@{*/
#define BP_EPDC_UPD_CTRL_AUTOWV (2U)       /*!< Bit position for EPDC_UPD_CTRL_AUTOWV. */
#define BM_EPDC_UPD_CTRL_AUTOWV (0x00000004U) /*!< Bit mask for EPDC_UPD_CTRL_AUTOWV. */
#define BS_EPDC_UPD_CTRL_AUTOWV (1U)       /*!< Bit field size in bits for EPDC_UPD_CTRL_AUTOWV. */

/*! @brief Read current value of the EPDC_UPD_CTRL_AUTOWV field. */
#define BR_EPDC_UPD_CTRL_AUTOWV(x) (HW_EPDC_UPD_CTRL(x).B.AUTOWV)

/*! @brief Format value for bitfield EPDC_UPD_CTRL_AUTOWV. */
#define BF_EPDC_UPD_CTRL_AUTOWV(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_UPD_CTRL_AUTOWV) & BM_EPDC_UPD_CTRL_AUTOWV)

/*! @brief Set the AUTOWV field to a new value. */
#define BW_EPDC_UPD_CTRL_AUTOWV(x, v) (HW_EPDC_UPD_CTRL_WR(x, (HW_EPDC_UPD_CTRL_RD(x) & ~BM_EPDC_UPD_CTRL_AUTOWV) | BF_EPDC_UPD_CTRL_AUTOWV(v)))
/*@}*/

/*!
 * @name Register EPDC_UPD_CTRL, field PAUSE[3] (RW)
 *
 * Values:
 * - 0 - epdc will analyze update buffer, report histogram, then update waveform
 *     mode using the programmed mode mapping in AUTOWV_LUT and start LUT loading
 * - 1 - epdc will analyze update buffer, report histogram, then pause and
 *     waiting software to write again with selected waveform mode to start lut loading
 */
/*@{*/
#define BP_EPDC_UPD_CTRL_PAUSE (3U)        /*!< Bit position for EPDC_UPD_CTRL_PAUSE. */
#define BM_EPDC_UPD_CTRL_PAUSE (0x00000008U) /*!< Bit mask for EPDC_UPD_CTRL_PAUSE. */
#define BS_EPDC_UPD_CTRL_PAUSE (1U)        /*!< Bit field size in bits for EPDC_UPD_CTRL_PAUSE. */

#define BV_EPDC_UPD_CTRL_PAUSE_AUTO    (0U)          /*!< Bit field value for EPDC_UPD_CTRL_PAUSE: epdc will analyze update buffer, report histogram, then update waveform mode using the programmed mode mapping in AUTOWV_LUT and start LUT loading */
#define BV_EPDC_UPD_CTRL_PAUSE_MANUAL  (0x1U)        /*!< Bit field value for EPDC_UPD_CTRL_PAUSE: epdc will analyze update buffer, report histogram, then pause and waiting software to write again with selected waveform mode to start lut loading */

/*! @brief Read current value of the EPDC_UPD_CTRL_PAUSE field. */
#define BR_EPDC_UPD_CTRL_PAUSE(x) (HW_EPDC_UPD_CTRL(x).B.PAUSE)

/*! @brief Format value for bitfield EPDC_UPD_CTRL_PAUSE. */
#define BF_EPDC_UPD_CTRL_PAUSE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_UPD_CTRL_PAUSE) & BM_EPDC_UPD_CTRL_PAUSE)

/*! @brief Set the PAUSE field to a new value. */
#define BW_EPDC_UPD_CTRL_PAUSE(x, v) (HW_EPDC_UPD_CTRL_WR(x, (HW_EPDC_UPD_CTRL_RD(x) & ~BM_EPDC_UPD_CTRL_PAUSE) | BF_EPDC_UPD_CTRL_PAUSE(v)))
/*@}*/

/*!
 * @name Register EPDC_UPD_CTRL, field NO_LUT_CANCEL[4] (RW)
 *
 * EPDC will cancel LUT loading for void update (no real update needed because
 * of partial or collision), set this bit to 1 to disable this feature
 */
/*@{*/
#define BP_EPDC_UPD_CTRL_NO_LUT_CANCEL (4U) /*!< Bit position for EPDC_UPD_CTRL_NO_LUT_CANCEL. */
#define BM_EPDC_UPD_CTRL_NO_LUT_CANCEL (0x00000010U) /*!< Bit mask for EPDC_UPD_CTRL_NO_LUT_CANCEL. */
#define BS_EPDC_UPD_CTRL_NO_LUT_CANCEL (1U) /*!< Bit field size in bits for EPDC_UPD_CTRL_NO_LUT_CANCEL. */

/*! @brief Read current value of the EPDC_UPD_CTRL_NO_LUT_CANCEL field. */
#define BR_EPDC_UPD_CTRL_NO_LUT_CANCEL(x) (HW_EPDC_UPD_CTRL(x).B.NO_LUT_CANCEL)

/*! @brief Format value for bitfield EPDC_UPD_CTRL_NO_LUT_CANCEL. */
#define BF_EPDC_UPD_CTRL_NO_LUT_CANCEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_UPD_CTRL_NO_LUT_CANCEL) & BM_EPDC_UPD_CTRL_NO_LUT_CANCEL)

/*! @brief Set the NO_LUT_CANCEL field to a new value. */
#define BW_EPDC_UPD_CTRL_NO_LUT_CANCEL(x, v) (HW_EPDC_UPD_CTRL_WR(x, (HW_EPDC_UPD_CTRL_RD(x) & ~BM_EPDC_UPD_CTRL_NO_LUT_CANCEL) | BF_EPDC_UPD_CTRL_NO_LUT_CANCEL(v)))
/*@}*/

/*!
 * @name Register EPDC_UPD_CTRL, field STANDBY[5] (RW)
 */
/*@{*/
#define BP_EPDC_UPD_CTRL_STANDBY (5U)      /*!< Bit position for EPDC_UPD_CTRL_STANDBY. */
#define BM_EPDC_UPD_CTRL_STANDBY (0x00000020U) /*!< Bit mask for EPDC_UPD_CTRL_STANDBY. */
#define BS_EPDC_UPD_CTRL_STANDBY (1U)      /*!< Bit field size in bits for EPDC_UPD_CTRL_STANDBY. */

/*! @brief Read current value of the EPDC_UPD_CTRL_STANDBY field. */
#define BR_EPDC_UPD_CTRL_STANDBY(x) (HW_EPDC_UPD_CTRL(x).B.STANDBY)

/*! @brief Format value for bitfield EPDC_UPD_CTRL_STANDBY. */
#define BF_EPDC_UPD_CTRL_STANDBY(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_UPD_CTRL_STANDBY) & BM_EPDC_UPD_CTRL_STANDBY)

/*! @brief Set the STANDBY field to a new value. */
#define BW_EPDC_UPD_CTRL_STANDBY(x, v) (HW_EPDC_UPD_CTRL_WR(x, (HW_EPDC_UPD_CTRL_RD(x) & ~BM_EPDC_UPD_CTRL_STANDBY) | BF_EPDC_UPD_CTRL_STANDBY(v)))
/*@}*/

/*!
 * @name Register EPDC_UPD_CTRL, field WAVEFORM_MODE[15:8] (RW)
 *
 * Waveform Mode 0-255
 */
/*@{*/
#define BP_EPDC_UPD_CTRL_WAVEFORM_MODE (8U) /*!< Bit position for EPDC_UPD_CTRL_WAVEFORM_MODE. */
#define BM_EPDC_UPD_CTRL_WAVEFORM_MODE (0x0000FF00U) /*!< Bit mask for EPDC_UPD_CTRL_WAVEFORM_MODE. */
#define BS_EPDC_UPD_CTRL_WAVEFORM_MODE (8U) /*!< Bit field size in bits for EPDC_UPD_CTRL_WAVEFORM_MODE. */

/*! @brief Read current value of the EPDC_UPD_CTRL_WAVEFORM_MODE field. */
#define BR_EPDC_UPD_CTRL_WAVEFORM_MODE(x) (HW_EPDC_UPD_CTRL(x).B.WAVEFORM_MODE)

/*! @brief Format value for bitfield EPDC_UPD_CTRL_WAVEFORM_MODE. */
#define BF_EPDC_UPD_CTRL_WAVEFORM_MODE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_UPD_CTRL_WAVEFORM_MODE) & BM_EPDC_UPD_CTRL_WAVEFORM_MODE)

/*! @brief Set the WAVEFORM_MODE field to a new value. */
#define BW_EPDC_UPD_CTRL_WAVEFORM_MODE(x, v) (HW_EPDC_UPD_CTRL_WR(x, (HW_EPDC_UPD_CTRL_RD(x) & ~BM_EPDC_UPD_CTRL_WAVEFORM_MODE) | BF_EPDC_UPD_CTRL_WAVEFORM_MODE(v)))
/*@}*/

/*!
 * @name Register EPDC_UPD_CTRL, field LUT_SEL[21:16] (RW)
 *
 * LUT select 0-63
 */
/*@{*/
#define BP_EPDC_UPD_CTRL_LUT_SEL (16U)     /*!< Bit position for EPDC_UPD_CTRL_LUT_SEL. */
#define BM_EPDC_UPD_CTRL_LUT_SEL (0x003F0000U) /*!< Bit mask for EPDC_UPD_CTRL_LUT_SEL. */
#define BS_EPDC_UPD_CTRL_LUT_SEL (6U)      /*!< Bit field size in bits for EPDC_UPD_CTRL_LUT_SEL. */

/*! @brief Read current value of the EPDC_UPD_CTRL_LUT_SEL field. */
#define BR_EPDC_UPD_CTRL_LUT_SEL(x) (HW_EPDC_UPD_CTRL(x).B.LUT_SEL)

/*! @brief Format value for bitfield EPDC_UPD_CTRL_LUT_SEL. */
#define BF_EPDC_UPD_CTRL_LUT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_UPD_CTRL_LUT_SEL) & BM_EPDC_UPD_CTRL_LUT_SEL)

/*! @brief Set the LUT_SEL field to a new value. */
#define BW_EPDC_UPD_CTRL_LUT_SEL(x, v) (HW_EPDC_UPD_CTRL_WR(x, (HW_EPDC_UPD_CTRL_RD(x) & ~BM_EPDC_UPD_CTRL_LUT_SEL) | BF_EPDC_UPD_CTRL_LUT_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_UPD_CTRL, field USE_FIXED[31] (RW)
 *
 * Use fixed pixel values (requires programming of EPDC_UPD_FIXED)
 */
/*@{*/
#define BP_EPDC_UPD_CTRL_USE_FIXED (31U)   /*!< Bit position for EPDC_UPD_CTRL_USE_FIXED. */
#define BM_EPDC_UPD_CTRL_USE_FIXED (0x80000000U) /*!< Bit mask for EPDC_UPD_CTRL_USE_FIXED. */
#define BS_EPDC_UPD_CTRL_USE_FIXED (1U)    /*!< Bit field size in bits for EPDC_UPD_CTRL_USE_FIXED. */

/*! @brief Read current value of the EPDC_UPD_CTRL_USE_FIXED field. */
#define BR_EPDC_UPD_CTRL_USE_FIXED(x) (HW_EPDC_UPD_CTRL(x).B.USE_FIXED)

/*! @brief Format value for bitfield EPDC_UPD_CTRL_USE_FIXED. */
#define BF_EPDC_UPD_CTRL_USE_FIXED(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_UPD_CTRL_USE_FIXED) & BM_EPDC_UPD_CTRL_USE_FIXED)

/*! @brief Set the USE_FIXED field to a new value. */
#define BW_EPDC_UPD_CTRL_USE_FIXED(x, v) (HW_EPDC_UPD_CTRL_WR(x, (HW_EPDC_UPD_CTRL_RD(x) & ~BM_EPDC_UPD_CTRL_USE_FIXED) | BF_EPDC_UPD_CTRL_USE_FIXED(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_UPD_FIXED - EPDC Update Fixed Pixel Control
 ******************************************************************************/

/*!
 * @brief HW_EPDC_UPD_FIXED - EPDC Update Fixed Pixel Control (RW)
 *
 * Reset value: 0x00000000U
 *
 * EPDC Update Control register for fixed-pixel updates (enabled via
 * EPDC_UPD_CTRL[USE_FIXED])
 */
typedef union _hw_epdc_upd_fixed
{
    uint32_t U;
    struct _hw_epdc_upd_fixed_bitfields
    {
        uint32_t FIXCP : 8;            /*!< [7:0]  */
        uint32_t FIXNP : 8;            /*!< [15:8]  */
        uint32_t RESERVED0 : 14;       /*!< [29:16]  */
        uint32_t FIXCP_EN : 1;         /*!< [30]  */
        uint32_t FIXNP_EN : 1;         /*!< [31]  */
    } B;
} hw_epdc_upd_fixed_t;

/*!
 * @name Constants and macros for entire EPDC_UPD_FIXED register
 */
/*@{*/
#define HW_EPDC_UPD_FIXED_ADDR(x) ((uintptr_t)(x) + 0x180U)
#define HW_EPDC_UPD_FIXED_SET_ADDR(x) (HW_EPDC_UPD_FIXED_ADDR(x) + 0x4U)
#define HW_EPDC_UPD_FIXED_CLR_ADDR(x) (HW_EPDC_UPD_FIXED_ADDR(x) + 0x8U)
#define HW_EPDC_UPD_FIXED_TOG_ADDR(x) (HW_EPDC_UPD_FIXED_ADDR(x) + 0xCU)

#define HW_EPDC_UPD_FIXED(x)     (*(__IO hw_epdc_upd_fixed_t *) HW_EPDC_UPD_FIXED_ADDR(x))
#define HW_EPDC_UPD_FIXED_RD(x)  (HW_EPDC_UPD_FIXED(x).U)
#define HW_EPDC_UPD_FIXED_WR(x, v) (HW_EPDC_UPD_FIXED(x).U = (v))
#define HW_EPDC_UPD_FIXED_SET(x, v) ((*(uint32_t *) HW_EPDC_UPD_FIXED_SET_ADDR(x)) = (v))
#define HW_EPDC_UPD_FIXED_CLR(x, v) ((*(uint32_t *) HW_EPDC_UPD_FIXED_CLR_ADDR(x)) = (v))
#define HW_EPDC_UPD_FIXED_TOG(x, v) ((*(uint32_t *) HW_EPDC_UPD_FIXED_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_UPD_FIXED bitfields
 */

/*!
 * @name Register EPDC_UPD_FIXED, field FIXCP[7:0] (RW)
 *
 * CP value if fixecp_en is set to 1. Data in Y8 format.
 */
/*@{*/
#define BP_EPDC_UPD_FIXED_FIXCP (0U)       /*!< Bit position for EPDC_UPD_FIXED_FIXCP. */
#define BM_EPDC_UPD_FIXED_FIXCP (0x000000FFU) /*!< Bit mask for EPDC_UPD_FIXED_FIXCP. */
#define BS_EPDC_UPD_FIXED_FIXCP (8U)       /*!< Bit field size in bits for EPDC_UPD_FIXED_FIXCP. */

/*! @brief Read current value of the EPDC_UPD_FIXED_FIXCP field. */
#define BR_EPDC_UPD_FIXED_FIXCP(x) (HW_EPDC_UPD_FIXED(x).B.FIXCP)

/*! @brief Format value for bitfield EPDC_UPD_FIXED_FIXCP. */
#define BF_EPDC_UPD_FIXED_FIXCP(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_UPD_FIXED_FIXCP) & BM_EPDC_UPD_FIXED_FIXCP)

/*! @brief Set the FIXCP field to a new value. */
#define BW_EPDC_UPD_FIXED_FIXCP(x, v) (HW_EPDC_UPD_FIXED_WR(x, (HW_EPDC_UPD_FIXED_RD(x) & ~BM_EPDC_UPD_FIXED_FIXCP) | BF_EPDC_UPD_FIXED_FIXCP(v)))
/*@}*/

/*!
 * @name Register EPDC_UPD_FIXED, field FIXNP[15:8] (RW)
 *
 * NP value if fixenp_en is set to 1. Data in Y8 format.
 */
/*@{*/
#define BP_EPDC_UPD_FIXED_FIXNP (8U)       /*!< Bit position for EPDC_UPD_FIXED_FIXNP. */
#define BM_EPDC_UPD_FIXED_FIXNP (0x0000FF00U) /*!< Bit mask for EPDC_UPD_FIXED_FIXNP. */
#define BS_EPDC_UPD_FIXED_FIXNP (8U)       /*!< Bit field size in bits for EPDC_UPD_FIXED_FIXNP. */

/*! @brief Read current value of the EPDC_UPD_FIXED_FIXNP field. */
#define BR_EPDC_UPD_FIXED_FIXNP(x) (HW_EPDC_UPD_FIXED(x).B.FIXNP)

/*! @brief Format value for bitfield EPDC_UPD_FIXED_FIXNP. */
#define BF_EPDC_UPD_FIXED_FIXNP(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_UPD_FIXED_FIXNP) & BM_EPDC_UPD_FIXED_FIXNP)

/*! @brief Set the FIXNP field to a new value. */
#define BW_EPDC_UPD_FIXED_FIXNP(x, v) (HW_EPDC_UPD_FIXED_WR(x, (HW_EPDC_UPD_FIXED_RD(x) & ~BM_EPDC_UPD_FIXED_FIXNP) | BF_EPDC_UPD_FIXED_FIXNP(v)))
/*@}*/

/*!
 * @name Register EPDC_UPD_FIXED, field FIXCP_EN[30] (RW)
 *
 * If set to 1, current updated region has the CP value defined by FIXCP
 */
/*@{*/
#define BP_EPDC_UPD_FIXED_FIXCP_EN (30U)   /*!< Bit position for EPDC_UPD_FIXED_FIXCP_EN. */
#define BM_EPDC_UPD_FIXED_FIXCP_EN (0x40000000U) /*!< Bit mask for EPDC_UPD_FIXED_FIXCP_EN. */
#define BS_EPDC_UPD_FIXED_FIXCP_EN (1U)    /*!< Bit field size in bits for EPDC_UPD_FIXED_FIXCP_EN. */

/*! @brief Read current value of the EPDC_UPD_FIXED_FIXCP_EN field. */
#define BR_EPDC_UPD_FIXED_FIXCP_EN(x) (HW_EPDC_UPD_FIXED(x).B.FIXCP_EN)

/*! @brief Format value for bitfield EPDC_UPD_FIXED_FIXCP_EN. */
#define BF_EPDC_UPD_FIXED_FIXCP_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_UPD_FIXED_FIXCP_EN) & BM_EPDC_UPD_FIXED_FIXCP_EN)

/*! @brief Set the FIXCP_EN field to a new value. */
#define BW_EPDC_UPD_FIXED_FIXCP_EN(x, v) (HW_EPDC_UPD_FIXED_WR(x, (HW_EPDC_UPD_FIXED_RD(x) & ~BM_EPDC_UPD_FIXED_FIXCP_EN) | BF_EPDC_UPD_FIXED_FIXCP_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_UPD_FIXED, field FIXNP_EN[31] (RW)
 *
 * If set to 1, current updated region has the NP value defined by FIXNP
 */
/*@{*/
#define BP_EPDC_UPD_FIXED_FIXNP_EN (31U)   /*!< Bit position for EPDC_UPD_FIXED_FIXNP_EN. */
#define BM_EPDC_UPD_FIXED_FIXNP_EN (0x80000000U) /*!< Bit mask for EPDC_UPD_FIXED_FIXNP_EN. */
#define BS_EPDC_UPD_FIXED_FIXNP_EN (1U)    /*!< Bit field size in bits for EPDC_UPD_FIXED_FIXNP_EN. */

/*! @brief Read current value of the EPDC_UPD_FIXED_FIXNP_EN field. */
#define BR_EPDC_UPD_FIXED_FIXNP_EN(x) (HW_EPDC_UPD_FIXED(x).B.FIXNP_EN)

/*! @brief Format value for bitfield EPDC_UPD_FIXED_FIXNP_EN. */
#define BF_EPDC_UPD_FIXED_FIXNP_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_UPD_FIXED_FIXNP_EN) & BM_EPDC_UPD_FIXED_FIXNP_EN)

/*! @brief Set the FIXNP_EN field to a new value. */
#define BW_EPDC_UPD_FIXED_FIXNP_EN(x, v) (HW_EPDC_UPD_FIXED_WR(x, (HW_EPDC_UPD_FIXED_RD(x) & ~BM_EPDC_UPD_FIXED_FIXNP_EN) | BF_EPDC_UPD_FIXED_FIXNP_EN(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_TEMP - EPDC Temperature Register
 ******************************************************************************/

/*!
 * @brief HW_EPDC_TEMP - EPDC Temperature Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * EPDC Temperature Compensation Register
 */
typedef union _hw_epdc_temp
{
    uint32_t U;
    struct _hw_epdc_temp_bitfields
    {
        uint32_t TEMPERATURE : 32;     /*!< [31:0]  */
    } B;
} hw_epdc_temp_t;

/*!
 * @name Constants and macros for entire EPDC_TEMP register
 */
/*@{*/
#define HW_EPDC_TEMP_ADDR(x)     ((uintptr_t)(x) + 0x1A0U)

#define HW_EPDC_TEMP(x)          (*(__IO hw_epdc_temp_t *) HW_EPDC_TEMP_ADDR(x))
#define HW_EPDC_TEMP_RD(x)       (HW_EPDC_TEMP(x).U)
#define HW_EPDC_TEMP_WR(x, v)    (HW_EPDC_TEMP(x).U = (v))
#define HW_EPDC_TEMP_SET(x, v)   (HW_EPDC_TEMP_WR(x, HW_EPDC_TEMP_RD(x) |  (v)))
#define HW_EPDC_TEMP_CLR(x, v)   (HW_EPDC_TEMP_WR(x, HW_EPDC_TEMP_RD(x) & ~(v)))
#define HW_EPDC_TEMP_TOG(x, v)   (HW_EPDC_TEMP_WR(x, HW_EPDC_TEMP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_TEMP bitfields
 */

/*!
 * @name Register EPDC_TEMP, field TEMPERATURE[31:0] (RW)
 *
 * Temperature Value. This value is simply an index (not a temperature value).
 * The index is used by the EPDC to access the correct temperature compensated
 * waveform.
 */
/*@{*/
#define BP_EPDC_TEMP_TEMPERATURE (0U)      /*!< Bit position for EPDC_TEMP_TEMPERATURE. */
#define BM_EPDC_TEMP_TEMPERATURE (0xFFFFFFFFU) /*!< Bit mask for EPDC_TEMP_TEMPERATURE. */
#define BS_EPDC_TEMP_TEMPERATURE (32U)     /*!< Bit field size in bits for EPDC_TEMP_TEMPERATURE. */

/*! @brief Read current value of the EPDC_TEMP_TEMPERATURE field. */
#define BR_EPDC_TEMP_TEMPERATURE(x) (HW_EPDC_TEMP(x).U)

/*! @brief Format value for bitfield EPDC_TEMP_TEMPERATURE. */
#define BF_EPDC_TEMP_TEMPERATURE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TEMP_TEMPERATURE) & BM_EPDC_TEMP_TEMPERATURE)

/*! @brief Set the TEMPERATURE field to a new value. */
#define BW_EPDC_TEMP_TEMPERATURE(x, v) (HW_EPDC_TEMP_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_EPDC_AUTOWV_LUT - Waveform Mode Lookup Table Control Register.
 ******************************************************************************/

/*!
 * @brief HW_EPDC_AUTOWV_LUT - Waveform Mode Lookup Table Control Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to access the waveform mode lookup table. DATA ->
 * AUTOWV_LUT[ADDR] : Writing this reg with 'ADDR' and 'DATA' info will get 'DATA'
 * written to AUTOWV_LUT mem indexed with 'ADDR'
 */
typedef union _hw_epdc_autowv_lut
{
    uint32_t U;
    struct _hw_epdc_autowv_lut_bitfields
    {
        uint32_t ADDR : 3;             /*!< [2:0]  */
        uint32_t RESERVED0 : 13;       /*!< [15:3]  */
        uint32_t DATA : 8;             /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_epdc_autowv_lut_t;

/*!
 * @name Constants and macros for entire EPDC_AUTOWV_LUT register
 */
/*@{*/
#define HW_EPDC_AUTOWV_LUT_ADDR(x) ((uintptr_t)(x) + 0x1C0U)

#define HW_EPDC_AUTOWV_LUT(x)    (*(__IO hw_epdc_autowv_lut_t *) HW_EPDC_AUTOWV_LUT_ADDR(x))
#define HW_EPDC_AUTOWV_LUT_RD(x) (HW_EPDC_AUTOWV_LUT(x).U)
#define HW_EPDC_AUTOWV_LUT_WR(x, v) (HW_EPDC_AUTOWV_LUT(x).U = (v))
#define HW_EPDC_AUTOWV_LUT_SET(x, v) (HW_EPDC_AUTOWV_LUT_WR(x, HW_EPDC_AUTOWV_LUT_RD(x) |  (v)))
#define HW_EPDC_AUTOWV_LUT_CLR(x, v) (HW_EPDC_AUTOWV_LUT_WR(x, HW_EPDC_AUTOWV_LUT_RD(x) & ~(v)))
#define HW_EPDC_AUTOWV_LUT_TOG(x, v) (HW_EPDC_AUTOWV_LUT_WR(x, HW_EPDC_AUTOWV_LUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_AUTOWV_LUT bitfields
 */

/*!
 * @name Register EPDC_AUTOWV_LUT, field ADDR[2:0] (RW)
 *
 * ADDR
 */
/*@{*/
#define BP_EPDC_AUTOWV_LUT_ADDR (0U)       /*!< Bit position for EPDC_AUTOWV_LUT_ADDR. */
#define BM_EPDC_AUTOWV_LUT_ADDR (0x00000007U) /*!< Bit mask for EPDC_AUTOWV_LUT_ADDR. */
#define BS_EPDC_AUTOWV_LUT_ADDR (3U)       /*!< Bit field size in bits for EPDC_AUTOWV_LUT_ADDR. */

/*! @brief Read current value of the EPDC_AUTOWV_LUT_ADDR field. */
#define BR_EPDC_AUTOWV_LUT_ADDR(x) (HW_EPDC_AUTOWV_LUT(x).B.ADDR)

/*! @brief Format value for bitfield EPDC_AUTOWV_LUT_ADDR. */
#define BF_EPDC_AUTOWV_LUT_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_AUTOWV_LUT_ADDR) & BM_EPDC_AUTOWV_LUT_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_EPDC_AUTOWV_LUT_ADDR(x, v) (HW_EPDC_AUTOWV_LUT_WR(x, (HW_EPDC_AUTOWV_LUT_RD(x) & ~BM_EPDC_AUTOWV_LUT_ADDR) | BF_EPDC_AUTOWV_LUT_ADDR(v)))
/*@}*/

/*!
 * @name Register EPDC_AUTOWV_LUT, field DATA[23:16] (RW)
 *
 * DATA
 */
/*@{*/
#define BP_EPDC_AUTOWV_LUT_DATA (16U)      /*!< Bit position for EPDC_AUTOWV_LUT_DATA. */
#define BM_EPDC_AUTOWV_LUT_DATA (0x00FF0000U) /*!< Bit mask for EPDC_AUTOWV_LUT_DATA. */
#define BS_EPDC_AUTOWV_LUT_DATA (8U)       /*!< Bit field size in bits for EPDC_AUTOWV_LUT_DATA. */

/*! @brief Read current value of the EPDC_AUTOWV_LUT_DATA field. */
#define BR_EPDC_AUTOWV_LUT_DATA(x) (HW_EPDC_AUTOWV_LUT(x).B.DATA)

/*! @brief Format value for bitfield EPDC_AUTOWV_LUT_DATA. */
#define BF_EPDC_AUTOWV_LUT_DATA(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_AUTOWV_LUT_DATA) & BM_EPDC_AUTOWV_LUT_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_EPDC_AUTOWV_LUT_DATA(x, v) (HW_EPDC_AUTOWV_LUT_WR(x, (HW_EPDC_AUTOWV_LUT_RD(x) & ~BM_EPDC_AUTOWV_LUT_DATA) | BF_EPDC_AUTOWV_LUT_DATA(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_LUT_STANDBY1 - EPDC LUT Standby Register for LUT 31~0
 ******************************************************************************/

/*!
 * @brief HW_EPDC_LUT_STANDBY1 - EPDC LUT Standby Register for LUT 31~0 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_epdc_lut_standby1
{
    uint32_t U;
    struct _hw_epdc_lut_standby1_bitfields
    {
        uint32_t LUTN : 32;            /*!< [31:0]  */
    } B;
} hw_epdc_lut_standby1_t;

/*!
 * @name Constants and macros for entire EPDC_LUT_STANDBY1 register
 */
/*@{*/
#define HW_EPDC_LUT_STANDBY1_ADDR(x) ((uintptr_t)(x) + 0x1E0U)
#define HW_EPDC_LUT_STANDBY1_SET_ADDR(x) (HW_EPDC_LUT_STANDBY1_ADDR(x) + 0x4U)
#define HW_EPDC_LUT_STANDBY1_CLR_ADDR(x) (HW_EPDC_LUT_STANDBY1_ADDR(x) + 0x8U)
#define HW_EPDC_LUT_STANDBY1_TOG_ADDR(x) (HW_EPDC_LUT_STANDBY1_ADDR(x) + 0xCU)

#define HW_EPDC_LUT_STANDBY1(x)  (*(__IO hw_epdc_lut_standby1_t *) HW_EPDC_LUT_STANDBY1_ADDR(x))
#define HW_EPDC_LUT_STANDBY1_RD(x) (HW_EPDC_LUT_STANDBY1(x).U)
#define HW_EPDC_LUT_STANDBY1_WR(x, v) (HW_EPDC_LUT_STANDBY1(x).U = (v))
#define HW_EPDC_LUT_STANDBY1_SET(x, v) ((*(uint32_t *) HW_EPDC_LUT_STANDBY1_SET_ADDR(x)) = (v))
#define HW_EPDC_LUT_STANDBY1_CLR(x, v) ((*(uint32_t *) HW_EPDC_LUT_STANDBY1_CLR_ADDR(x)) = (v))
#define HW_EPDC_LUT_STANDBY1_TOG(x, v) ((*(uint32_t *) HW_EPDC_LUT_STANDBY1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_LUT_STANDBY1 bitfields
 */

/*!
 * @name Register EPDC_LUT_STANDBY1, field LUTN[31:0] (RW)
 *
 * LUT 0~31 standby control
 */
/*@{*/
#define BP_EPDC_LUT_STANDBY1_LUTN (0U)     /*!< Bit position for EPDC_LUT_STANDBY1_LUTN. */
#define BM_EPDC_LUT_STANDBY1_LUTN (0xFFFFFFFFU) /*!< Bit mask for EPDC_LUT_STANDBY1_LUTN. */
#define BS_EPDC_LUT_STANDBY1_LUTN (32U)    /*!< Bit field size in bits for EPDC_LUT_STANDBY1_LUTN. */

/*! @brief Read current value of the EPDC_LUT_STANDBY1_LUTN field. */
#define BR_EPDC_LUT_STANDBY1_LUTN(x) (HW_EPDC_LUT_STANDBY1(x).U)

/*! @brief Format value for bitfield EPDC_LUT_STANDBY1_LUTN. */
#define BF_EPDC_LUT_STANDBY1_LUTN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_LUT_STANDBY1_LUTN) & BM_EPDC_LUT_STANDBY1_LUTN)

/*! @brief Set the LUTN field to a new value. */
#define BW_EPDC_LUT_STANDBY1_LUTN(x, v) (HW_EPDC_LUT_STANDBY1_WR(x, v))
/*@}*/




/*******************************************************************************
 * HW_EPDC_LUT_STANDBY2 - EPDC LUT Standby Registerr for LUT 63~32
 ******************************************************************************/

/*!
 * @brief HW_EPDC_LUT_STANDBY2 - EPDC LUT Standby Registerr for LUT 63~32 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_epdc_lut_standby2
{
    uint32_t U;
    struct _hw_epdc_lut_standby2_bitfields
    {
        uint32_t LUTN : 32;            /*!< [31:0]  */
    } B;
} hw_epdc_lut_standby2_t;

/*!
 * @name Constants and macros for entire EPDC_LUT_STANDBY2 register
 */
/*@{*/
#define HW_EPDC_LUT_STANDBY2_ADDR(x) ((uintptr_t)(x) + 0x1F0U)
#define HW_EPDC_LUT_STANDBY2_SET_ADDR(x) (HW_EPDC_LUT_STANDBY2_ADDR(x) + 0x4U)
#define HW_EPDC_LUT_STANDBY2_CLR_ADDR(x) (HW_EPDC_LUT_STANDBY2_ADDR(x) + 0x8U)
#define HW_EPDC_LUT_STANDBY2_TOG_ADDR(x) (HW_EPDC_LUT_STANDBY2_ADDR(x) + 0xCU)

#define HW_EPDC_LUT_STANDBY2(x)  (*(__IO hw_epdc_lut_standby2_t *) HW_EPDC_LUT_STANDBY2_ADDR(x))
#define HW_EPDC_LUT_STANDBY2_RD(x) (HW_EPDC_LUT_STANDBY2(x).U)
#define HW_EPDC_LUT_STANDBY2_WR(x, v) (HW_EPDC_LUT_STANDBY2(x).U = (v))
#define HW_EPDC_LUT_STANDBY2_SET(x, v) ((*(uint32_t *) HW_EPDC_LUT_STANDBY2_SET_ADDR(x)) = (v))
#define HW_EPDC_LUT_STANDBY2_CLR(x, v) ((*(uint32_t *) HW_EPDC_LUT_STANDBY2_CLR_ADDR(x)) = (v))
#define HW_EPDC_LUT_STANDBY2_TOG(x, v) ((*(uint32_t *) HW_EPDC_LUT_STANDBY2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_LUT_STANDBY2 bitfields
 */

/*!
 * @name Register EPDC_LUT_STANDBY2, field LUTN[31:0] (RW)
 *
 * LUT 32~64 Standby Control
 */
/*@{*/
#define BP_EPDC_LUT_STANDBY2_LUTN (0U)     /*!< Bit position for EPDC_LUT_STANDBY2_LUTN. */
#define BM_EPDC_LUT_STANDBY2_LUTN (0xFFFFFFFFU) /*!< Bit mask for EPDC_LUT_STANDBY2_LUTN. */
#define BS_EPDC_LUT_STANDBY2_LUTN (32U)    /*!< Bit field size in bits for EPDC_LUT_STANDBY2_LUTN. */

/*! @brief Read current value of the EPDC_LUT_STANDBY2_LUTN field. */
#define BR_EPDC_LUT_STANDBY2_LUTN(x) (HW_EPDC_LUT_STANDBY2(x).U)

/*! @brief Format value for bitfield EPDC_LUT_STANDBY2_LUTN. */
#define BF_EPDC_LUT_STANDBY2_LUTN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_LUT_STANDBY2_LUTN) & BM_EPDC_LUT_STANDBY2_LUTN)

/*! @brief Set the LUTN field to a new value. */
#define BW_EPDC_LUT_STANDBY2_LUTN(x, v) (HW_EPDC_LUT_STANDBY2_WR(x, v))
/*@}*/




/*******************************************************************************
 * HW_EPDC_TCE_CTRL - EPDC Timing Control Engine Control Register
 ******************************************************************************/

/*!
 * @brief HW_EPDC_TCE_CTRL - EPDC Timing Control Engine Control Register (RW)
 *
 * Reset value: 0x00000010U
 *
 * TCE general control register This register houses Horizontal scan timing.
 * Note that line data length is derived from EPDC_RES.
 */
typedef union _hw_epdc_tce_ctrl
{
    uint32_t U;
    struct _hw_epdc_tce_ctrl_bitfields
    {
        uint32_t PIXELS_PER_SDCLK : 2; /*!< [1:0]  */
        uint32_t SDDO_WIDTH : 1;       /*!< [2]  */
        uint32_t DUAL_SCAN : 1;        /*!< [3]  */
        uint32_t SCAN_DIR_0 : 1;       /*!< [4]  */
        uint32_t SCAN_DIR_1 : 1;       /*!< [5]  */
        uint32_t LVDS_MODE : 1;        /*!< [6]  */
        uint32_t LVDS_MODE_CE : 1;     /*!< [7]  */
        uint32_t DDR_MODE : 1;         /*!< [8]  */
        uint32_t VCOM_MODE : 1;        /*!< [9]  */
        uint32_t VCOM_VAL : 2;         /*!< [11:10]  */
        uint32_t RESERVED0 : 4;        /*!< [15:12]  */
        uint32_t VSCAN_HOLDOFF : 9;    /*!< [24:16]  */
        uint32_t RESERVED1 : 7;        /*!< [31:25]  */
    } B;
} hw_epdc_tce_ctrl_t;

/*!
 * @name Constants and macros for entire EPDC_TCE_CTRL register
 */
/*@{*/
#define HW_EPDC_TCE_CTRL_ADDR(x) ((uintptr_t)(x) + 0x200U)
#define HW_EPDC_TCE_CTRL_SET_ADDR(x) (HW_EPDC_TCE_CTRL_ADDR(x) + 0x4U)
#define HW_EPDC_TCE_CTRL_CLR_ADDR(x) (HW_EPDC_TCE_CTRL_ADDR(x) + 0x8U)
#define HW_EPDC_TCE_CTRL_TOG_ADDR(x) (HW_EPDC_TCE_CTRL_ADDR(x) + 0xCU)

#define HW_EPDC_TCE_CTRL(x)      (*(__IO hw_epdc_tce_ctrl_t *) HW_EPDC_TCE_CTRL_ADDR(x))
#define HW_EPDC_TCE_CTRL_RD(x)   (HW_EPDC_TCE_CTRL(x).U)
#define HW_EPDC_TCE_CTRL_WR(x, v) (HW_EPDC_TCE_CTRL(x).U = (v))
#define HW_EPDC_TCE_CTRL_SET(x, v) ((*(uint32_t *) HW_EPDC_TCE_CTRL_SET_ADDR(x)) = (v))
#define HW_EPDC_TCE_CTRL_CLR(x, v) ((*(uint32_t *) HW_EPDC_TCE_CTRL_CLR_ADDR(x)) = (v))
#define HW_EPDC_TCE_CTRL_TOG(x, v) ((*(uint32_t *) HW_EPDC_TCE_CTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_TCE_CTRL bitfields
 */

/*!
 * @name Register EPDC_TCE_CTRL, field PIXELS_PER_SDCLK[1:0] (RW)
 *
 * Number of TFT pixels per SDCLK period. Note that this value forms the
 * division of the PIXLK to generate the SDCLK such that SDCLK =
 * PIXCLK/PIXELS_PER_SDCLK. For dual-scan mode (DUAL_SCAN=1), this applies to 8-bit half of the 16-bit
 * SDDO. It should be noted that when DDR_MODE is enabled, both edges of the clock
 * have to be accounted for in this value, so for example with an 8-bit SDDO,
 * 2-bit TFT pixel, this field should be set to EIGHT (four pixels on the pos-edge
 * and 4-pixels on the neg-edge)
 *
 * Values:
 * - 0 - Reserved
 * - 1 - Two TFT-pixels per SDCLK
 * - 10 - Four TFT-pixels per SDCLK
 * - 11 - Eight TFT-pixels per SDCLK
 */
/*@{*/
#define BP_EPDC_TCE_CTRL_PIXELS_PER_SDCLK (0U) /*!< Bit position for EPDC_TCE_CTRL_PIXELS_PER_SDCLK. */
#define BM_EPDC_TCE_CTRL_PIXELS_PER_SDCLK (0x00000003U) /*!< Bit mask for EPDC_TCE_CTRL_PIXELS_PER_SDCLK. */
#define BS_EPDC_TCE_CTRL_PIXELS_PER_SDCLK (2U) /*!< Bit field size in bits for EPDC_TCE_CTRL_PIXELS_PER_SDCLK. */

#define BV_EPDC_TCE_CTRL_PIXELS_PER_SDCLK_RESERVED (0U) /*!< Bit field value for EPDC_TCE_CTRL_PIXELS_PER_SDCLK: Reserved */
#define BV_EPDC_TCE_CTRL_PIXELS_PER_SDCLK_TWO (0x1U) /*!< Bit field value for EPDC_TCE_CTRL_PIXELS_PER_SDCLK: Two TFT-pixels per SDCLK */
#define BV_EPDC_TCE_CTRL_PIXELS_PER_SDCLK_FOUR (0x2U) /*!< Bit field value for EPDC_TCE_CTRL_PIXELS_PER_SDCLK: Four TFT-pixels per SDCLK */
#define BV_EPDC_TCE_CTRL_PIXELS_PER_SDCLK_EIGHT (0x3U) /*!< Bit field value for EPDC_TCE_CTRL_PIXELS_PER_SDCLK: Eight TFT-pixels per SDCLK */

/*! @brief Read current value of the EPDC_TCE_CTRL_PIXELS_PER_SDCLK field. */
#define BR_EPDC_TCE_CTRL_PIXELS_PER_SDCLK(x) (HW_EPDC_TCE_CTRL(x).B.PIXELS_PER_SDCLK)

/*! @brief Format value for bitfield EPDC_TCE_CTRL_PIXELS_PER_SDCLK. */
#define BF_EPDC_TCE_CTRL_PIXELS_PER_SDCLK(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_CTRL_PIXELS_PER_SDCLK) & BM_EPDC_TCE_CTRL_PIXELS_PER_SDCLK)

/*! @brief Set the PIXELS_PER_SDCLK field to a new value. */
#define BW_EPDC_TCE_CTRL_PIXELS_PER_SDCLK(x, v) (HW_EPDC_TCE_CTRL_WR(x, (HW_EPDC_TCE_CTRL_RD(x) & ~BM_EPDC_TCE_CTRL_PIXELS_PER_SDCLK) | BF_EPDC_TCE_CTRL_PIXELS_PER_SDCLK(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_CTRL, field SDDO_WIDTH[2] (RW)
 *
 * Selects either 8 or 16 bit SDDO bus format
 *
 * Values:
 * - 0 - Connect to 8-bit source driver
 * - 1 - Connct to 16-bit source driver
 */
/*@{*/
#define BP_EPDC_TCE_CTRL_SDDO_WIDTH (2U)   /*!< Bit position for EPDC_TCE_CTRL_SDDO_WIDTH. */
#define BM_EPDC_TCE_CTRL_SDDO_WIDTH (0x00000004U) /*!< Bit mask for EPDC_TCE_CTRL_SDDO_WIDTH. */
#define BS_EPDC_TCE_CTRL_SDDO_WIDTH (1U)   /*!< Bit field size in bits for EPDC_TCE_CTRL_SDDO_WIDTH. */

#define BV_EPDC_TCE_CTRL_SDDO_WIDTH_8BIT (0U)        /*!< Bit field value for EPDC_TCE_CTRL_SDDO_WIDTH: Connect to 8-bit source driver */
#define BV_EPDC_TCE_CTRL_SDDO_WIDTH_16BIT (0x1U)     /*!< Bit field value for EPDC_TCE_CTRL_SDDO_WIDTH: Connct to 16-bit source driver */

/*! @brief Read current value of the EPDC_TCE_CTRL_SDDO_WIDTH field. */
#define BR_EPDC_TCE_CTRL_SDDO_WIDTH(x) (HW_EPDC_TCE_CTRL(x).B.SDDO_WIDTH)

/*! @brief Format value for bitfield EPDC_TCE_CTRL_SDDO_WIDTH. */
#define BF_EPDC_TCE_CTRL_SDDO_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_CTRL_SDDO_WIDTH) & BM_EPDC_TCE_CTRL_SDDO_WIDTH)

/*! @brief Set the SDDO_WIDTH field to a new value. */
#define BW_EPDC_TCE_CTRL_SDDO_WIDTH(x, v) (HW_EPDC_TCE_CTRL_WR(x, (HW_EPDC_TCE_CTRL_RD(x) & ~BM_EPDC_TCE_CTRL_SDDO_WIDTH) | BF_EPDC_TCE_CTRL_SDDO_WIDTH(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_CTRL, field DUAL_SCAN[3] (RW)
 *
 * Enables dual scan-mode. Note in this mode, SDDO_BUS_FORMAT=16BIT must be
 * selected. and PIXELS_PER_CLK applies to each 8-bit segment of the SDDO bus.
 */
/*@{*/
#define BP_EPDC_TCE_CTRL_DUAL_SCAN (3U)    /*!< Bit position for EPDC_TCE_CTRL_DUAL_SCAN. */
#define BM_EPDC_TCE_CTRL_DUAL_SCAN (0x00000008U) /*!< Bit mask for EPDC_TCE_CTRL_DUAL_SCAN. */
#define BS_EPDC_TCE_CTRL_DUAL_SCAN (1U)    /*!< Bit field size in bits for EPDC_TCE_CTRL_DUAL_SCAN. */

/*! @brief Read current value of the EPDC_TCE_CTRL_DUAL_SCAN field. */
#define BR_EPDC_TCE_CTRL_DUAL_SCAN(x) (HW_EPDC_TCE_CTRL(x).B.DUAL_SCAN)

/*! @brief Format value for bitfield EPDC_TCE_CTRL_DUAL_SCAN. */
#define BF_EPDC_TCE_CTRL_DUAL_SCAN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_CTRL_DUAL_SCAN) & BM_EPDC_TCE_CTRL_DUAL_SCAN)

/*! @brief Set the DUAL_SCAN field to a new value. */
#define BW_EPDC_TCE_CTRL_DUAL_SCAN(x, v) (HW_EPDC_TCE_CTRL_WR(x, (HW_EPDC_TCE_CTRL_RD(x) & ~BM_EPDC_TCE_CTRL_DUAL_SCAN) | BF_EPDC_TCE_CTRL_DUAL_SCAN(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_CTRL, field SCAN_DIR_0[4] (RW)
 *
 * Determines scan direction for each half of the TFT panel
 *
 * Values:
 * - 1 - Scan this region from bottom to top
 * - 0 - Scan this region from top to bottom
 */
/*@{*/
#define BP_EPDC_TCE_CTRL_SCAN_DIR_0 (4U)   /*!< Bit position for EPDC_TCE_CTRL_SCAN_DIR_0. */
#define BM_EPDC_TCE_CTRL_SCAN_DIR_0 (0x00000010U) /*!< Bit mask for EPDC_TCE_CTRL_SCAN_DIR_0. */
#define BS_EPDC_TCE_CTRL_SCAN_DIR_0 (1U)   /*!< Bit field size in bits for EPDC_TCE_CTRL_SCAN_DIR_0. */

#define BV_EPDC_TCE_CTRL_SCAN_DIR_0_UP (0x1U)        /*!< Bit field value for EPDC_TCE_CTRL_SCAN_DIR_0: Scan this region from bottom to top */
#define BV_EPDC_TCE_CTRL_SCAN_DIR_0_DOWN (0U)        /*!< Bit field value for EPDC_TCE_CTRL_SCAN_DIR_0: Scan this region from top to bottom */

/*! @brief Read current value of the EPDC_TCE_CTRL_SCAN_DIR_0 field. */
#define BR_EPDC_TCE_CTRL_SCAN_DIR_0(x) (HW_EPDC_TCE_CTRL(x).B.SCAN_DIR_0)

/*! @brief Format value for bitfield EPDC_TCE_CTRL_SCAN_DIR_0. */
#define BF_EPDC_TCE_CTRL_SCAN_DIR_0(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_CTRL_SCAN_DIR_0) & BM_EPDC_TCE_CTRL_SCAN_DIR_0)

/*! @brief Set the SCAN_DIR_0 field to a new value. */
#define BW_EPDC_TCE_CTRL_SCAN_DIR_0(x, v) (HW_EPDC_TCE_CTRL_WR(x, (HW_EPDC_TCE_CTRL_RD(x) & ~BM_EPDC_TCE_CTRL_SCAN_DIR_0) | BF_EPDC_TCE_CTRL_SCAN_DIR_0(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_CTRL, field SCAN_DIR_1[5] (RW)
 *
 * Determines scan direction for each half of the TFT panel
 *
 * Values:
 * - 1 - Scan this region from bottom to top
 * - 0 - Scan this region from top to bottom
 */
/*@{*/
#define BP_EPDC_TCE_CTRL_SCAN_DIR_1 (5U)   /*!< Bit position for EPDC_TCE_CTRL_SCAN_DIR_1. */
#define BM_EPDC_TCE_CTRL_SCAN_DIR_1 (0x00000020U) /*!< Bit mask for EPDC_TCE_CTRL_SCAN_DIR_1. */
#define BS_EPDC_TCE_CTRL_SCAN_DIR_1 (1U)   /*!< Bit field size in bits for EPDC_TCE_CTRL_SCAN_DIR_1. */

#define BV_EPDC_TCE_CTRL_SCAN_DIR_1_UP (0x1U)        /*!< Bit field value for EPDC_TCE_CTRL_SCAN_DIR_1: Scan this region from bottom to top */
#define BV_EPDC_TCE_CTRL_SCAN_DIR_1_DOWN (0U)        /*!< Bit field value for EPDC_TCE_CTRL_SCAN_DIR_1: Scan this region from top to bottom */

/*! @brief Read current value of the EPDC_TCE_CTRL_SCAN_DIR_1 field. */
#define BR_EPDC_TCE_CTRL_SCAN_DIR_1(x) (HW_EPDC_TCE_CTRL(x).B.SCAN_DIR_1)

/*! @brief Format value for bitfield EPDC_TCE_CTRL_SCAN_DIR_1. */
#define BF_EPDC_TCE_CTRL_SCAN_DIR_1(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_CTRL_SCAN_DIR_1) & BM_EPDC_TCE_CTRL_SCAN_DIR_1)

/*! @brief Set the SCAN_DIR_1 field to a new value. */
#define BW_EPDC_TCE_CTRL_SCAN_DIR_1(x, v) (HW_EPDC_TCE_CTRL_WR(x, (HW_EPDC_TCE_CTRL_RD(x) & ~BM_EPDC_TCE_CTRL_SCAN_DIR_1) | BF_EPDC_TCE_CTRL_SCAN_DIR_1(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_CTRL, field LVDS_MODE[6] (RW)
 *
 * If set, the upper 8-bit of the SDDO bus are used for LVDS differential
 * signalling. Note that this can only be used when SDDO_BUS_FORMAT is set to 16BIT,
 * i.e. LVDS signaling is not supported with an 8-bit SDDO interface. Note that for
 * LVDS_MODE, DDR_MODE must also be set.
 */
/*@{*/
#define BP_EPDC_TCE_CTRL_LVDS_MODE (6U)    /*!< Bit position for EPDC_TCE_CTRL_LVDS_MODE. */
#define BM_EPDC_TCE_CTRL_LVDS_MODE (0x00000040U) /*!< Bit mask for EPDC_TCE_CTRL_LVDS_MODE. */
#define BS_EPDC_TCE_CTRL_LVDS_MODE (1U)    /*!< Bit field size in bits for EPDC_TCE_CTRL_LVDS_MODE. */

/*! @brief Read current value of the EPDC_TCE_CTRL_LVDS_MODE field. */
#define BR_EPDC_TCE_CTRL_LVDS_MODE(x) (HW_EPDC_TCE_CTRL(x).B.LVDS_MODE)

/*! @brief Format value for bitfield EPDC_TCE_CTRL_LVDS_MODE. */
#define BF_EPDC_TCE_CTRL_LVDS_MODE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_CTRL_LVDS_MODE) & BM_EPDC_TCE_CTRL_LVDS_MODE)

/*! @brief Set the LVDS_MODE field to a new value. */
#define BW_EPDC_TCE_CTRL_LVDS_MODE(x, v) (HW_EPDC_TCE_CTRL_WR(x, (HW_EPDC_TCE_CTRL_RD(x) & ~BM_EPDC_TCE_CTRL_LVDS_MODE) | BF_EPDC_TCE_CTRL_LVDS_MODE(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_CTRL, field LVDS_MODE_CE[7] (RW)
 *
 * If set (together with LVDS_MODE=1), SDCE[9:5] shall be driven as the
 * differential inverse of SDCE[4:0]. In this mode the EPDC only supports 5 CE lines.
 */
/*@{*/
#define BP_EPDC_TCE_CTRL_LVDS_MODE_CE (7U) /*!< Bit position for EPDC_TCE_CTRL_LVDS_MODE_CE. */
#define BM_EPDC_TCE_CTRL_LVDS_MODE_CE (0x00000080U) /*!< Bit mask for EPDC_TCE_CTRL_LVDS_MODE_CE. */
#define BS_EPDC_TCE_CTRL_LVDS_MODE_CE (1U) /*!< Bit field size in bits for EPDC_TCE_CTRL_LVDS_MODE_CE. */

/*! @brief Read current value of the EPDC_TCE_CTRL_LVDS_MODE_CE field. */
#define BR_EPDC_TCE_CTRL_LVDS_MODE_CE(x) (HW_EPDC_TCE_CTRL(x).B.LVDS_MODE_CE)

/*! @brief Format value for bitfield EPDC_TCE_CTRL_LVDS_MODE_CE. */
#define BF_EPDC_TCE_CTRL_LVDS_MODE_CE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_CTRL_LVDS_MODE_CE) & BM_EPDC_TCE_CTRL_LVDS_MODE_CE)

/*! @brief Set the LVDS_MODE_CE field to a new value. */
#define BW_EPDC_TCE_CTRL_LVDS_MODE_CE(x, v) (HW_EPDC_TCE_CTRL_WR(x, (HW_EPDC_TCE_CTRL_RD(x) & ~BM_EPDC_TCE_CTRL_LVDS_MODE_CE) | BF_EPDC_TCE_CTRL_LVDS_MODE_CE(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_CTRL, field DDR_MODE[8] (RW)
 *
 * If set, SDDO data is driven on both positive and negative edges of SDCLK.
 * Note that this mode is not supported when SDDO_BUS_FORMAT=16BIT and LVDS is not
 * used. This must always be set when LVDS_MODE is set.
 */
/*@{*/
#define BP_EPDC_TCE_CTRL_DDR_MODE (8U)     /*!< Bit position for EPDC_TCE_CTRL_DDR_MODE. */
#define BM_EPDC_TCE_CTRL_DDR_MODE (0x00000100U) /*!< Bit mask for EPDC_TCE_CTRL_DDR_MODE. */
#define BS_EPDC_TCE_CTRL_DDR_MODE (1U)     /*!< Bit field size in bits for EPDC_TCE_CTRL_DDR_MODE. */

/*! @brief Read current value of the EPDC_TCE_CTRL_DDR_MODE field. */
#define BR_EPDC_TCE_CTRL_DDR_MODE(x) (HW_EPDC_TCE_CTRL(x).B.DDR_MODE)

/*! @brief Format value for bitfield EPDC_TCE_CTRL_DDR_MODE. */
#define BF_EPDC_TCE_CTRL_DDR_MODE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_CTRL_DDR_MODE) & BM_EPDC_TCE_CTRL_DDR_MODE)

/*! @brief Set the DDR_MODE field to a new value. */
#define BW_EPDC_TCE_CTRL_DDR_MODE(x, v) (HW_EPDC_TCE_CTRL_WR(x, (HW_EPDC_TCE_CTRL_RD(x) & ~BM_EPDC_TCE_CTRL_DDR_MODE) | BF_EPDC_TCE_CTRL_DDR_MODE(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_CTRL, field VCOM_MODE[9] (RW)
 *
 * This field determines the method used to drive the VCOM signal.
 *
 * Values:
 * - 0 - VCOM Value is set manually using VCOM_VAL field
 * - 1 - VCOM Value is used from waveform
 */
/*@{*/
#define BP_EPDC_TCE_CTRL_VCOM_MODE (9U)    /*!< Bit position for EPDC_TCE_CTRL_VCOM_MODE. */
#define BM_EPDC_TCE_CTRL_VCOM_MODE (0x00000200U) /*!< Bit mask for EPDC_TCE_CTRL_VCOM_MODE. */
#define BS_EPDC_TCE_CTRL_VCOM_MODE (1U)    /*!< Bit field size in bits for EPDC_TCE_CTRL_VCOM_MODE. */

#define BV_EPDC_TCE_CTRL_VCOM_MODE_MANUAL (0U)       /*!< Bit field value for EPDC_TCE_CTRL_VCOM_MODE: VCOM Value is set manually using VCOM_VAL field */
#define BV_EPDC_TCE_CTRL_VCOM_MODE_AUTO (0x1U)       /*!< Bit field value for EPDC_TCE_CTRL_VCOM_MODE: VCOM Value is used from waveform */

/*! @brief Read current value of the EPDC_TCE_CTRL_VCOM_MODE field. */
#define BR_EPDC_TCE_CTRL_VCOM_MODE(x) (HW_EPDC_TCE_CTRL(x).B.VCOM_MODE)

/*! @brief Format value for bitfield EPDC_TCE_CTRL_VCOM_MODE. */
#define BF_EPDC_TCE_CTRL_VCOM_MODE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_CTRL_VCOM_MODE) & BM_EPDC_TCE_CTRL_VCOM_MODE)

/*! @brief Set the VCOM_MODE field to a new value. */
#define BW_EPDC_TCE_CTRL_VCOM_MODE(x, v) (HW_EPDC_TCE_CTRL_WR(x, (HW_EPDC_TCE_CTRL_RD(x) & ~BM_EPDC_TCE_CTRL_VCOM_MODE) | BF_EPDC_TCE_CTRL_VCOM_MODE(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_CTRL, field VCOM_VAL[11:10] (RW)
 *
 * When VCOM_MODE = MANUAL, this value is used to manually set the VCOM value
 * for the VCOM[1:0] pins
 */
/*@{*/
#define BP_EPDC_TCE_CTRL_VCOM_VAL (10U)    /*!< Bit position for EPDC_TCE_CTRL_VCOM_VAL. */
#define BM_EPDC_TCE_CTRL_VCOM_VAL (0x00000C00U) /*!< Bit mask for EPDC_TCE_CTRL_VCOM_VAL. */
#define BS_EPDC_TCE_CTRL_VCOM_VAL (2U)     /*!< Bit field size in bits for EPDC_TCE_CTRL_VCOM_VAL. */

/*! @brief Read current value of the EPDC_TCE_CTRL_VCOM_VAL field. */
#define BR_EPDC_TCE_CTRL_VCOM_VAL(x) (HW_EPDC_TCE_CTRL(x).B.VCOM_VAL)

/*! @brief Format value for bitfield EPDC_TCE_CTRL_VCOM_VAL. */
#define BF_EPDC_TCE_CTRL_VCOM_VAL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_CTRL_VCOM_VAL) & BM_EPDC_TCE_CTRL_VCOM_VAL)

/*! @brief Set the VCOM_VAL field to a new value. */
#define BW_EPDC_TCE_CTRL_VCOM_VAL(x, v) (HW_EPDC_TCE_CTRL_WR(x, (HW_EPDC_TCE_CTRL_RD(x) & ~BM_EPDC_TCE_CTRL_VCOM_VAL) | BF_EPDC_TCE_CTRL_VCOM_VAL(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_CTRL, field VSCAN_HOLDOFF[24:16] (RW)
 *
 * This period (expressed in vertical lines), sets the portion of the vertical
 * blanking available for new LUTs to be activated. The remainder of the blanking
 * period is reserved for pre-filling the TCE pixel FIFOs. Increasing this value
 * allows for multiple smaller updates to be intercepted by the current frame
 * scan. This number should not exceed FRAME_END+FRAME_SYNC+FRAME_BEGIN. Increasing
 * this value can improve the ability for any given update to intercept the next
 * available frame-scan. Excessive values can result in TCE FIFO under-runs.
 */
/*@{*/
#define BP_EPDC_TCE_CTRL_VSCAN_HOLDOFF (16U) /*!< Bit position for EPDC_TCE_CTRL_VSCAN_HOLDOFF. */
#define BM_EPDC_TCE_CTRL_VSCAN_HOLDOFF (0x01FF0000U) /*!< Bit mask for EPDC_TCE_CTRL_VSCAN_HOLDOFF. */
#define BS_EPDC_TCE_CTRL_VSCAN_HOLDOFF (9U) /*!< Bit field size in bits for EPDC_TCE_CTRL_VSCAN_HOLDOFF. */

/*! @brief Read current value of the EPDC_TCE_CTRL_VSCAN_HOLDOFF field. */
#define BR_EPDC_TCE_CTRL_VSCAN_HOLDOFF(x) (HW_EPDC_TCE_CTRL(x).B.VSCAN_HOLDOFF)

/*! @brief Format value for bitfield EPDC_TCE_CTRL_VSCAN_HOLDOFF. */
#define BF_EPDC_TCE_CTRL_VSCAN_HOLDOFF(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_CTRL_VSCAN_HOLDOFF) & BM_EPDC_TCE_CTRL_VSCAN_HOLDOFF)

/*! @brief Set the VSCAN_HOLDOFF field to a new value. */
#define BW_EPDC_TCE_CTRL_VSCAN_HOLDOFF(x, v) (HW_EPDC_TCE_CTRL_WR(x, (HW_EPDC_TCE_CTRL_RD(x) & ~BM_EPDC_TCE_CTRL_VSCAN_HOLDOFF) | BF_EPDC_TCE_CTRL_VSCAN_HOLDOFF(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_TCE_SDCFG - EPDC Timing Control Engine Source-Driver Config Register
 ******************************************************************************/

/*!
 * @brief HW_EPDC_TCE_SDCFG - EPDC Timing Control Engine Source-Driver Config Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Source-driver configuration register
 */
typedef union _hw_epdc_tce_sdcfg
{
    uint32_t U;
    struct _hw_epdc_tce_sdcfg_bitfields
    {
        uint32_t PIXELS_PER_CE : 13;   /*!< [12:0]  */
        uint32_t SDDO_INVERT : 1;      /*!< [13]  */
        uint32_t SDDO_REFORMAT : 2;    /*!< [15:14]  */
        uint32_t NUM_CE : 4;           /*!< [19:16]  */
        uint32_t SDSHR : 1;            /*!< [20]  */
        uint32_t SDCLK_HOLD : 1;       /*!< [21]  */
        uint32_t RESERVED0 : 10;       /*!< [31:22]  */
    } B;
} hw_epdc_tce_sdcfg_t;

/*!
 * @name Constants and macros for entire EPDC_TCE_SDCFG register
 */
/*@{*/
#define HW_EPDC_TCE_SDCFG_ADDR(x) ((uintptr_t)(x) + 0x220U)
#define HW_EPDC_TCE_SDCFG_SET_ADDR(x) (HW_EPDC_TCE_SDCFG_ADDR(x) + 0x4U)
#define HW_EPDC_TCE_SDCFG_CLR_ADDR(x) (HW_EPDC_TCE_SDCFG_ADDR(x) + 0x8U)
#define HW_EPDC_TCE_SDCFG_TOG_ADDR(x) (HW_EPDC_TCE_SDCFG_ADDR(x) + 0xCU)

#define HW_EPDC_TCE_SDCFG(x)     (*(__IO hw_epdc_tce_sdcfg_t *) HW_EPDC_TCE_SDCFG_ADDR(x))
#define HW_EPDC_TCE_SDCFG_RD(x)  (HW_EPDC_TCE_SDCFG(x).U)
#define HW_EPDC_TCE_SDCFG_WR(x, v) (HW_EPDC_TCE_SDCFG(x).U = (v))
#define HW_EPDC_TCE_SDCFG_SET(x, v) ((*(uint32_t *) HW_EPDC_TCE_SDCFG_SET_ADDR(x)) = (v))
#define HW_EPDC_TCE_SDCFG_CLR(x, v) ((*(uint32_t *) HW_EPDC_TCE_SDCFG_CLR_ADDR(x)) = (v))
#define HW_EPDC_TCE_SDCFG_TOG(x, v) ((*(uint32_t *) HW_EPDC_TCE_SDCFG_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_TCE_SDCFG bitfields
 */

/*!
 * @name Register EPDC_TCE_SDCFG, field PIXELS_PER_CE[12:0] (RW)
 *
 * Number of pixels (outputs) per source-driver IC. Please note that
 * EPDC_RES[HORIZONTAL] must be an integer multiple of PINS_PER_CE.
 */
/*@{*/
#define BP_EPDC_TCE_SDCFG_PIXELS_PER_CE (0U) /*!< Bit position for EPDC_TCE_SDCFG_PIXELS_PER_CE. */
#define BM_EPDC_TCE_SDCFG_PIXELS_PER_CE (0x00001FFFU) /*!< Bit mask for EPDC_TCE_SDCFG_PIXELS_PER_CE. */
#define BS_EPDC_TCE_SDCFG_PIXELS_PER_CE (13U) /*!< Bit field size in bits for EPDC_TCE_SDCFG_PIXELS_PER_CE. */

/*! @brief Read current value of the EPDC_TCE_SDCFG_PIXELS_PER_CE field. */
#define BR_EPDC_TCE_SDCFG_PIXELS_PER_CE(x) (HW_EPDC_TCE_SDCFG(x).B.PIXELS_PER_CE)

/*! @brief Format value for bitfield EPDC_TCE_SDCFG_PIXELS_PER_CE. */
#define BF_EPDC_TCE_SDCFG_PIXELS_PER_CE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_SDCFG_PIXELS_PER_CE) & BM_EPDC_TCE_SDCFG_PIXELS_PER_CE)

/*! @brief Set the PIXELS_PER_CE field to a new value. */
#define BW_EPDC_TCE_SDCFG_PIXELS_PER_CE(x, v) (HW_EPDC_TCE_SDCFG_WR(x, (HW_EPDC_TCE_SDCFG_RD(x) & ~BM_EPDC_TCE_SDCFG_PIXELS_PER_CE) | BF_EPDC_TCE_SDCFG_PIXELS_PER_CE(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_SDCFG, field SDDO_INVERT[13] (RW)
 *
 * Setting this bit to 1 reverses the polarity of each SDDO bit so 0xAAAA in
 * 16-bit mode for example becomes 0x5555. This setting can be made in addition to
 * the SDDO_REFORMAT register setting.
 */
/*@{*/
#define BP_EPDC_TCE_SDCFG_SDDO_INVERT (13U) /*!< Bit position for EPDC_TCE_SDCFG_SDDO_INVERT. */
#define BM_EPDC_TCE_SDCFG_SDDO_INVERT (0x00002000U) /*!< Bit mask for EPDC_TCE_SDCFG_SDDO_INVERT. */
#define BS_EPDC_TCE_SDCFG_SDDO_INVERT (1U) /*!< Bit field size in bits for EPDC_TCE_SDCFG_SDDO_INVERT. */

/*! @brief Read current value of the EPDC_TCE_SDCFG_SDDO_INVERT field. */
#define BR_EPDC_TCE_SDCFG_SDDO_INVERT(x) (HW_EPDC_TCE_SDCFG(x).B.SDDO_INVERT)

/*! @brief Format value for bitfield EPDC_TCE_SDCFG_SDDO_INVERT. */
#define BF_EPDC_TCE_SDCFG_SDDO_INVERT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_SDCFG_SDDO_INVERT) & BM_EPDC_TCE_SDCFG_SDDO_INVERT)

/*! @brief Set the SDDO_INVERT field to a new value. */
#define BW_EPDC_TCE_SDCFG_SDDO_INVERT(x, v) (HW_EPDC_TCE_SDCFG_WR(x, (HW_EPDC_TCE_SDCFG_RD(x) & ~BM_EPDC_TCE_SDCFG_SDDO_INVERT) | BF_EPDC_TCE_SDCFG_SDDO_INVERT(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_SDCFG, field SDDO_REFORMAT[15:14] (RW)
 *
 * This register defines the various re-formatting options to enable more
 * flexibility in the source-driver interface:
 *
 * Values:
 * - 0 - No change.
 * - 1 - Reverses the order of the pixels on SDDO. This register setting is
 *     sensitive to the TFT pixel width (TFT_PIXEL_FORMAT), e.g. for
 *     TFT_PIXEL_FORMAT=2B on an 8-bit bus P3,P2,P1,P0 becomes P0,P1,P2,P3, whereas with
 *     TFT_PIXEL_FORMAT=4B, on an 8-bit bus, P1,P0 becomes P0,P1
 */
/*@{*/
#define BP_EPDC_TCE_SDCFG_SDDO_REFORMAT (14U) /*!< Bit position for EPDC_TCE_SDCFG_SDDO_REFORMAT. */
#define BM_EPDC_TCE_SDCFG_SDDO_REFORMAT (0x0000C000U) /*!< Bit mask for EPDC_TCE_SDCFG_SDDO_REFORMAT. */
#define BS_EPDC_TCE_SDCFG_SDDO_REFORMAT (2U) /*!< Bit field size in bits for EPDC_TCE_SDCFG_SDDO_REFORMAT. */

#define BV_EPDC_TCE_SDCFG_SDDO_REFORMAT_STANDARD (0U) /*!< Bit field value for EPDC_TCE_SDCFG_SDDO_REFORMAT: No change. */
#define BV_EPDC_TCE_SDCFG_SDDO_REFORMAT_FLIP_PIXELS (0x1U) /*!< Bit field value for EPDC_TCE_SDCFG_SDDO_REFORMAT: Reverses the order of the pixels on SDDO. This register setting is sensitive to the TFT pixel width (TFT_PIXEL_FORMAT), e.g. for TFT_PIXEL_FORMAT=2B on an 8-bit bus P3,P2,P1,P0 becomes P0,P1,P2,P3, whereas with TFT_PIXEL_FORMAT=4B, on an 8-bit bus, P1,P0 becomes P0,P1 */

/*! @brief Read current value of the EPDC_TCE_SDCFG_SDDO_REFORMAT field. */
#define BR_EPDC_TCE_SDCFG_SDDO_REFORMAT(x) (HW_EPDC_TCE_SDCFG(x).B.SDDO_REFORMAT)

/*! @brief Format value for bitfield EPDC_TCE_SDCFG_SDDO_REFORMAT. */
#define BF_EPDC_TCE_SDCFG_SDDO_REFORMAT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_SDCFG_SDDO_REFORMAT) & BM_EPDC_TCE_SDCFG_SDDO_REFORMAT)

/*! @brief Set the SDDO_REFORMAT field to a new value. */
#define BW_EPDC_TCE_SDCFG_SDDO_REFORMAT(x, v) (HW_EPDC_TCE_SDCFG_WR(x, (HW_EPDC_TCE_SDCFG_RD(x) & ~BM_EPDC_TCE_SDCFG_SDDO_REFORMAT) | BF_EPDC_TCE_SDCFG_SDDO_REFORMAT(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_SDCFG, field NUM_CE[19:16] (RW)
 *
 * Number of source driver IC chip-enables. Must be 1-10
 */
/*@{*/
#define BP_EPDC_TCE_SDCFG_NUM_CE (16U)     /*!< Bit position for EPDC_TCE_SDCFG_NUM_CE. */
#define BM_EPDC_TCE_SDCFG_NUM_CE (0x000F0000U) /*!< Bit mask for EPDC_TCE_SDCFG_NUM_CE. */
#define BS_EPDC_TCE_SDCFG_NUM_CE (4U)      /*!< Bit field size in bits for EPDC_TCE_SDCFG_NUM_CE. */

/*! @brief Read current value of the EPDC_TCE_SDCFG_NUM_CE field. */
#define BR_EPDC_TCE_SDCFG_NUM_CE(x) (HW_EPDC_TCE_SDCFG(x).B.NUM_CE)

/*! @brief Format value for bitfield EPDC_TCE_SDCFG_NUM_CE. */
#define BF_EPDC_TCE_SDCFG_NUM_CE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_SDCFG_NUM_CE) & BM_EPDC_TCE_SDCFG_NUM_CE)

/*! @brief Set the NUM_CE field to a new value. */
#define BW_EPDC_TCE_SDCFG_NUM_CE(x, v) (HW_EPDC_TCE_SDCFG_WR(x, (HW_EPDC_TCE_SDCFG_RD(x) & ~BM_EPDC_TCE_SDCFG_NUM_CE) | BF_EPDC_TCE_SDCFG_NUM_CE(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_SDCFG, field SDSHR[20] (RW)
 *
 * Value for source-driver shift direction output port
 */
/*@{*/
#define BP_EPDC_TCE_SDCFG_SDSHR (20U)      /*!< Bit position for EPDC_TCE_SDCFG_SDSHR. */
#define BM_EPDC_TCE_SDCFG_SDSHR (0x00100000U) /*!< Bit mask for EPDC_TCE_SDCFG_SDSHR. */
#define BS_EPDC_TCE_SDCFG_SDSHR (1U)       /*!< Bit field size in bits for EPDC_TCE_SDCFG_SDSHR. */

/*! @brief Read current value of the EPDC_TCE_SDCFG_SDSHR field. */
#define BR_EPDC_TCE_SDCFG_SDSHR(x) (HW_EPDC_TCE_SDCFG(x).B.SDSHR)

/*! @brief Format value for bitfield EPDC_TCE_SDCFG_SDSHR. */
#define BF_EPDC_TCE_SDCFG_SDSHR(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_SDCFG_SDSHR) & BM_EPDC_TCE_SDCFG_SDSHR)

/*! @brief Set the SDSHR field to a new value. */
#define BW_EPDC_TCE_SDCFG_SDSHR(x, v) (HW_EPDC_TCE_SDCFG_WR(x, (HW_EPDC_TCE_SDCFG_RD(x) & ~BM_EPDC_TCE_SDCFG_SDSHR) | BF_EPDC_TCE_SDCFG_SDSHR(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_SDCFG, field SDCLK_HOLD[21] (RW)
 *
 * Setting this bit to 1 holds the SDCLK low during LINE_BEGIN
 */
/*@{*/
#define BP_EPDC_TCE_SDCFG_SDCLK_HOLD (21U) /*!< Bit position for EPDC_TCE_SDCFG_SDCLK_HOLD. */
#define BM_EPDC_TCE_SDCFG_SDCLK_HOLD (0x00200000U) /*!< Bit mask for EPDC_TCE_SDCFG_SDCLK_HOLD. */
#define BS_EPDC_TCE_SDCFG_SDCLK_HOLD (1U)  /*!< Bit field size in bits for EPDC_TCE_SDCFG_SDCLK_HOLD. */

/*! @brief Read current value of the EPDC_TCE_SDCFG_SDCLK_HOLD field. */
#define BR_EPDC_TCE_SDCFG_SDCLK_HOLD(x) (HW_EPDC_TCE_SDCFG(x).B.SDCLK_HOLD)

/*! @brief Format value for bitfield EPDC_TCE_SDCFG_SDCLK_HOLD. */
#define BF_EPDC_TCE_SDCFG_SDCLK_HOLD(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_SDCFG_SDCLK_HOLD) & BM_EPDC_TCE_SDCFG_SDCLK_HOLD)

/*! @brief Set the SDCLK_HOLD field to a new value. */
#define BW_EPDC_TCE_SDCFG_SDCLK_HOLD(x, v) (HW_EPDC_TCE_SDCFG_WR(x, (HW_EPDC_TCE_SDCFG_RD(x) & ~BM_EPDC_TCE_SDCFG_SDCLK_HOLD) | BF_EPDC_TCE_SDCFG_SDCLK_HOLD(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_TCE_GDCFG - EPDC Timing Control Engine Gate-Driver Config Register
 ******************************************************************************/

/*!
 * @brief HW_EPDC_TCE_GDCFG - EPDC Timing Control Engine Gate-Driver Config Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register houses gate-driver configuration.
 */
typedef union _hw_epdc_tce_gdcfg
{
    uint32_t U;
    struct _hw_epdc_tce_gdcfg_bitfields
    {
        uint32_t GDSP_MODE : 1;        /*!< [0]  */
        uint32_t GDOE_MODE : 1;        /*!< [1]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t GDRL : 1;             /*!< [4]  */
        uint32_t RESERVED1 : 11;       /*!< [15:5]  */
        uint32_t PERIOD_VSCAN : 16;    /*!< [31:16]  */
    } B;
} hw_epdc_tce_gdcfg_t;

/*!
 * @name Constants and macros for entire EPDC_TCE_GDCFG register
 */
/*@{*/
#define HW_EPDC_TCE_GDCFG_ADDR(x) ((uintptr_t)(x) + 0x240U)
#define HW_EPDC_TCE_GDCFG_SET_ADDR(x) (HW_EPDC_TCE_GDCFG_ADDR(x) + 0x4U)
#define HW_EPDC_TCE_GDCFG_CLR_ADDR(x) (HW_EPDC_TCE_GDCFG_ADDR(x) + 0x8U)
#define HW_EPDC_TCE_GDCFG_TOG_ADDR(x) (HW_EPDC_TCE_GDCFG_ADDR(x) + 0xCU)

#define HW_EPDC_TCE_GDCFG(x)     (*(__IO hw_epdc_tce_gdcfg_t *) HW_EPDC_TCE_GDCFG_ADDR(x))
#define HW_EPDC_TCE_GDCFG_RD(x)  (HW_EPDC_TCE_GDCFG(x).U)
#define HW_EPDC_TCE_GDCFG_WR(x, v) (HW_EPDC_TCE_GDCFG(x).U = (v))
#define HW_EPDC_TCE_GDCFG_SET(x, v) ((*(uint32_t *) HW_EPDC_TCE_GDCFG_SET_ADDR(x)) = (v))
#define HW_EPDC_TCE_GDCFG_CLR(x, v) ((*(uint32_t *) HW_EPDC_TCE_GDCFG_CLR_ADDR(x)) = (v))
#define HW_EPDC_TCE_GDCFG_TOG(x, v) ((*(uint32_t *) HW_EPDC_TCE_GDCFG_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_TCE_GDCFG bitfields
 */

/*!
 * @name Register EPDC_TCE_GDCFG, field GDSP_MODE[0] (RW)
 *
 * Selects method for driving GDSP pulse. When set to 0, GDSP is is always fixed
 * to have a pulse width of one line-time. When set to 1, GDSP has a pulse-width
 * determined by the FRAME_SYNC setting. Note that GDSP_MODE=1 is not compatible
 * with the GDSP_OFFSET function
 */
/*@{*/
#define BP_EPDC_TCE_GDCFG_GDSP_MODE (0U)   /*!< Bit position for EPDC_TCE_GDCFG_GDSP_MODE. */
#define BM_EPDC_TCE_GDCFG_GDSP_MODE (0x00000001U) /*!< Bit mask for EPDC_TCE_GDCFG_GDSP_MODE. */
#define BS_EPDC_TCE_GDCFG_GDSP_MODE (1U)   /*!< Bit field size in bits for EPDC_TCE_GDCFG_GDSP_MODE. */

/*! @brief Read current value of the EPDC_TCE_GDCFG_GDSP_MODE field. */
#define BR_EPDC_TCE_GDCFG_GDSP_MODE(x) (HW_EPDC_TCE_GDCFG(x).B.GDSP_MODE)

/*! @brief Format value for bitfield EPDC_TCE_GDCFG_GDSP_MODE. */
#define BF_EPDC_TCE_GDCFG_GDSP_MODE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_GDCFG_GDSP_MODE) & BM_EPDC_TCE_GDCFG_GDSP_MODE)

/*! @brief Set the GDSP_MODE field to a new value. */
#define BW_EPDC_TCE_GDCFG_GDSP_MODE(x, v) (HW_EPDC_TCE_GDCFG_WR(x, (HW_EPDC_TCE_GDCFG_RD(x) & ~BM_EPDC_TCE_GDCFG_GDSP_MODE) | BF_EPDC_TCE_GDCFG_GDSP_MODE(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_GDCFG, field GDOE_MODE[1] (RW)
 *
 * Selects method for driving GDOE signal. When set to 0, GDOE is driven at all
 * times during the frame-scan except FRAME_SYNC. When set to 1, GDOE is driven
 * as a delayed version of GDCLK delayed by EPDC_TCE_TIMING3[GDOE_OFFSET].
 */
/*@{*/
#define BP_EPDC_TCE_GDCFG_GDOE_MODE (1U)   /*!< Bit position for EPDC_TCE_GDCFG_GDOE_MODE. */
#define BM_EPDC_TCE_GDCFG_GDOE_MODE (0x00000002U) /*!< Bit mask for EPDC_TCE_GDCFG_GDOE_MODE. */
#define BS_EPDC_TCE_GDCFG_GDOE_MODE (1U)   /*!< Bit field size in bits for EPDC_TCE_GDCFG_GDOE_MODE. */

/*! @brief Read current value of the EPDC_TCE_GDCFG_GDOE_MODE field. */
#define BR_EPDC_TCE_GDCFG_GDOE_MODE(x) (HW_EPDC_TCE_GDCFG(x).B.GDOE_MODE)

/*! @brief Format value for bitfield EPDC_TCE_GDCFG_GDOE_MODE. */
#define BF_EPDC_TCE_GDCFG_GDOE_MODE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_GDCFG_GDOE_MODE) & BM_EPDC_TCE_GDCFG_GDOE_MODE)

/*! @brief Set the GDOE_MODE field to a new value. */
#define BW_EPDC_TCE_GDCFG_GDOE_MODE(x, v) (HW_EPDC_TCE_GDCFG_WR(x, (HW_EPDC_TCE_GDCFG_RD(x) & ~BM_EPDC_TCE_GDCFG_GDOE_MODE) | BF_EPDC_TCE_GDCFG_GDOE_MODE(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_GDCFG, field GDRL[4] (RW)
 *
 * Value for gate-driver right/left shift output port
 */
/*@{*/
#define BP_EPDC_TCE_GDCFG_GDRL (4U)        /*!< Bit position for EPDC_TCE_GDCFG_GDRL. */
#define BM_EPDC_TCE_GDCFG_GDRL (0x00000010U) /*!< Bit mask for EPDC_TCE_GDCFG_GDRL. */
#define BS_EPDC_TCE_GDCFG_GDRL (1U)        /*!< Bit field size in bits for EPDC_TCE_GDCFG_GDRL. */

/*! @brief Read current value of the EPDC_TCE_GDCFG_GDRL field. */
#define BR_EPDC_TCE_GDCFG_GDRL(x) (HW_EPDC_TCE_GDCFG(x).B.GDRL)

/*! @brief Format value for bitfield EPDC_TCE_GDCFG_GDRL. */
#define BF_EPDC_TCE_GDCFG_GDRL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_GDCFG_GDRL) & BM_EPDC_TCE_GDCFG_GDRL)

/*! @brief Set the GDRL field to a new value. */
#define BW_EPDC_TCE_GDCFG_GDRL(x, v) (HW_EPDC_TCE_GDCFG_WR(x, (HW_EPDC_TCE_GDCFG_RD(x) & ~BM_EPDC_TCE_GDCFG_GDRL) | BF_EPDC_TCE_GDCFG_GDRL(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_GDCFG, field PERIOD_VSCAN[31:16] (RW)
 *
 * when vscan state is splited, this reg defines the counter period
 */
/*@{*/
#define BP_EPDC_TCE_GDCFG_PERIOD_VSCAN (16U) /*!< Bit position for EPDC_TCE_GDCFG_PERIOD_VSCAN. */
#define BM_EPDC_TCE_GDCFG_PERIOD_VSCAN (0xFFFF0000U) /*!< Bit mask for EPDC_TCE_GDCFG_PERIOD_VSCAN. */
#define BS_EPDC_TCE_GDCFG_PERIOD_VSCAN (16U) /*!< Bit field size in bits for EPDC_TCE_GDCFG_PERIOD_VSCAN. */

/*! @brief Read current value of the EPDC_TCE_GDCFG_PERIOD_VSCAN field. */
#define BR_EPDC_TCE_GDCFG_PERIOD_VSCAN(x) (HW_EPDC_TCE_GDCFG(x).B.PERIOD_VSCAN)

/*! @brief Format value for bitfield EPDC_TCE_GDCFG_PERIOD_VSCAN. */
#define BF_EPDC_TCE_GDCFG_PERIOD_VSCAN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_GDCFG_PERIOD_VSCAN) & BM_EPDC_TCE_GDCFG_PERIOD_VSCAN)

/*! @brief Set the PERIOD_VSCAN field to a new value. */
#define BW_EPDC_TCE_GDCFG_PERIOD_VSCAN(x, v) (HW_EPDC_TCE_GDCFG_WR(x, (HW_EPDC_TCE_GDCFG_RD(x) & ~BM_EPDC_TCE_GDCFG_PERIOD_VSCAN) | BF_EPDC_TCE_GDCFG_PERIOD_VSCAN(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_TCE_HSCAN1 - EPDC Timing Control Engine Horizontal Timing Register 1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_TCE_HSCAN1 - EPDC Timing Control Engine Horizontal Timing Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Horizontal scan timing registers. Note that all timing values are expressed
 * in terms of the EPDC's internal PIXCLK, which depending on the PIXELS_PER_SDCLK
 * register setting is either 2:1 or 4:1 This register houses Horizontal scan
 * timing. Note that line data length is derived from EPDC_RES.
 */
typedef union _hw_epdc_tce_hscan1
{
    uint32_t U;
    struct _hw_epdc_tce_hscan1_bitfields
    {
        uint32_t LINE_SYNC : 12;       /*!< [11:0]  */
        uint32_t RESERVED0 : 4;        /*!< [15:12]  */
        uint32_t LINE_SYNC_WIDTH : 12; /*!< [27:16]  */
        uint32_t RESERVED1 : 4;        /*!< [31:28]  */
    } B;
} hw_epdc_tce_hscan1_t;

/*!
 * @name Constants and macros for entire EPDC_TCE_HSCAN1 register
 */
/*@{*/
#define HW_EPDC_TCE_HSCAN1_ADDR(x) ((uintptr_t)(x) + 0x260U)
#define HW_EPDC_TCE_HSCAN1_SET_ADDR(x) (HW_EPDC_TCE_HSCAN1_ADDR(x) + 0x4U)
#define HW_EPDC_TCE_HSCAN1_CLR_ADDR(x) (HW_EPDC_TCE_HSCAN1_ADDR(x) + 0x8U)
#define HW_EPDC_TCE_HSCAN1_TOG_ADDR(x) (HW_EPDC_TCE_HSCAN1_ADDR(x) + 0xCU)

#define HW_EPDC_TCE_HSCAN1(x)    (*(__IO hw_epdc_tce_hscan1_t *) HW_EPDC_TCE_HSCAN1_ADDR(x))
#define HW_EPDC_TCE_HSCAN1_RD(x) (HW_EPDC_TCE_HSCAN1(x).U)
#define HW_EPDC_TCE_HSCAN1_WR(x, v) (HW_EPDC_TCE_HSCAN1(x).U = (v))
#define HW_EPDC_TCE_HSCAN1_SET(x, v) ((*(uint32_t *) HW_EPDC_TCE_HSCAN1_SET_ADDR(x)) = (v))
#define HW_EPDC_TCE_HSCAN1_CLR(x, v) ((*(uint32_t *) HW_EPDC_TCE_HSCAN1_CLR_ADDR(x)) = (v))
#define HW_EPDC_TCE_HSCAN1_TOG(x, v) ((*(uint32_t *) HW_EPDC_TCE_HSCAN1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_TCE_HSCAN1 bitfields
 */

/*!
 * @name Register EPDC_TCE_HSCAN1, field LINE_SYNC[11:0] (RW)
 *
 * Number of PIXCLK cycles for line sync duration. Note that this value
 * encompasses the LINE_SYNC_WIDTH duration. This value must be programmed to a multiple
 * of SDCLK cycles
 */
/*@{*/
#define BP_EPDC_TCE_HSCAN1_LINE_SYNC (0U)  /*!< Bit position for EPDC_TCE_HSCAN1_LINE_SYNC. */
#define BM_EPDC_TCE_HSCAN1_LINE_SYNC (0x00000FFFU) /*!< Bit mask for EPDC_TCE_HSCAN1_LINE_SYNC. */
#define BS_EPDC_TCE_HSCAN1_LINE_SYNC (12U) /*!< Bit field size in bits for EPDC_TCE_HSCAN1_LINE_SYNC. */

/*! @brief Read current value of the EPDC_TCE_HSCAN1_LINE_SYNC field. */
#define BR_EPDC_TCE_HSCAN1_LINE_SYNC(x) (HW_EPDC_TCE_HSCAN1(x).B.LINE_SYNC)

/*! @brief Format value for bitfield EPDC_TCE_HSCAN1_LINE_SYNC. */
#define BF_EPDC_TCE_HSCAN1_LINE_SYNC(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_HSCAN1_LINE_SYNC) & BM_EPDC_TCE_HSCAN1_LINE_SYNC)

/*! @brief Set the LINE_SYNC field to a new value. */
#define BW_EPDC_TCE_HSCAN1_LINE_SYNC(x, v) (HW_EPDC_TCE_HSCAN1_WR(x, (HW_EPDC_TCE_HSCAN1_RD(x) & ~BM_EPDC_TCE_HSCAN1_LINE_SYNC) | BF_EPDC_TCE_HSCAN1_LINE_SYNC(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_HSCAN1, field LINE_SYNC_WIDTH[27:16] (RW)
 *
 * Number of PIXCLK cycles for the SDLE active time. Note that this value cannot
 * be larger than LINE_SYNC and must be greater than 0. Typically it is
 * recommended to set this value to be the same as LINE_SYNC
 */
/*@{*/
#define BP_EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH (16U) /*!< Bit position for EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH. */
#define BM_EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH (0x0FFF0000U) /*!< Bit mask for EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH. */
#define BS_EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH (12U) /*!< Bit field size in bits for EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH. */

/*! @brief Read current value of the EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH field. */
#define BR_EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH(x) (HW_EPDC_TCE_HSCAN1(x).B.LINE_SYNC_WIDTH)

/*! @brief Format value for bitfield EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH. */
#define BF_EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH) & BM_EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH)

/*! @brief Set the LINE_SYNC_WIDTH field to a new value. */
#define BW_EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH(x, v) (HW_EPDC_TCE_HSCAN1_WR(x, (HW_EPDC_TCE_HSCAN1_RD(x) & ~BM_EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH) | BF_EPDC_TCE_HSCAN1_LINE_SYNC_WIDTH(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_TCE_HSCAN2 - EPDC Timing Control Engine Horizontal Timing Register 2
 ******************************************************************************/

/*!
 * @brief HW_EPDC_TCE_HSCAN2 - EPDC Timing Control Engine Horizontal Timing Register 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Horizontal scan timing registers. Note that all timing values are expressed
 * in terms of the EPDC's internal PIXCLK, which depending on the PIXELS_PER_SDCLK
 * register setting is either 2:1 or 4:1 This register houses Horizontal scan
 * timing. Note that line data length is derived from EPDC_RES.
 */
typedef union _hw_epdc_tce_hscan2
{
    uint32_t U;
    struct _hw_epdc_tce_hscan2_bitfields
    {
        uint32_t LINE_BEGIN : 12;      /*!< [11:0]  */
        uint32_t RESERVED0 : 4;        /*!< [15:12]  */
        uint32_t LINE_END : 12;        /*!< [27:16]  */
        uint32_t RESERVED1 : 4;        /*!< [31:28]  */
    } B;
} hw_epdc_tce_hscan2_t;

/*!
 * @name Constants and macros for entire EPDC_TCE_HSCAN2 register
 */
/*@{*/
#define HW_EPDC_TCE_HSCAN2_ADDR(x) ((uintptr_t)(x) + 0x280U)
#define HW_EPDC_TCE_HSCAN2_SET_ADDR(x) (HW_EPDC_TCE_HSCAN2_ADDR(x) + 0x4U)
#define HW_EPDC_TCE_HSCAN2_CLR_ADDR(x) (HW_EPDC_TCE_HSCAN2_ADDR(x) + 0x8U)
#define HW_EPDC_TCE_HSCAN2_TOG_ADDR(x) (HW_EPDC_TCE_HSCAN2_ADDR(x) + 0xCU)

#define HW_EPDC_TCE_HSCAN2(x)    (*(__IO hw_epdc_tce_hscan2_t *) HW_EPDC_TCE_HSCAN2_ADDR(x))
#define HW_EPDC_TCE_HSCAN2_RD(x) (HW_EPDC_TCE_HSCAN2(x).U)
#define HW_EPDC_TCE_HSCAN2_WR(x, v) (HW_EPDC_TCE_HSCAN2(x).U = (v))
#define HW_EPDC_TCE_HSCAN2_SET(x, v) ((*(uint32_t *) HW_EPDC_TCE_HSCAN2_SET_ADDR(x)) = (v))
#define HW_EPDC_TCE_HSCAN2_CLR(x, v) ((*(uint32_t *) HW_EPDC_TCE_HSCAN2_CLR_ADDR(x)) = (v))
#define HW_EPDC_TCE_HSCAN2_TOG(x, v) ((*(uint32_t *) HW_EPDC_TCE_HSCAN2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_TCE_HSCAN2 bitfields
 */

/*!
 * @name Register EPDC_TCE_HSCAN2, field LINE_BEGIN[11:0] (RW)
 *
 * Number of PIXCLK cycles for line begin duration. This defines the interval
 * between de-assertion of SDLE and assertion of the SDCE signals. This value must
 * be programmed to a multiple of SDCLK cycles
 */
/*@{*/
#define BP_EPDC_TCE_HSCAN2_LINE_BEGIN (0U) /*!< Bit position for EPDC_TCE_HSCAN2_LINE_BEGIN. */
#define BM_EPDC_TCE_HSCAN2_LINE_BEGIN (0x00000FFFU) /*!< Bit mask for EPDC_TCE_HSCAN2_LINE_BEGIN. */
#define BS_EPDC_TCE_HSCAN2_LINE_BEGIN (12U) /*!< Bit field size in bits for EPDC_TCE_HSCAN2_LINE_BEGIN. */

/*! @brief Read current value of the EPDC_TCE_HSCAN2_LINE_BEGIN field. */
#define BR_EPDC_TCE_HSCAN2_LINE_BEGIN(x) (HW_EPDC_TCE_HSCAN2(x).B.LINE_BEGIN)

/*! @brief Format value for bitfield EPDC_TCE_HSCAN2_LINE_BEGIN. */
#define BF_EPDC_TCE_HSCAN2_LINE_BEGIN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_HSCAN2_LINE_BEGIN) & BM_EPDC_TCE_HSCAN2_LINE_BEGIN)

/*! @brief Set the LINE_BEGIN field to a new value. */
#define BW_EPDC_TCE_HSCAN2_LINE_BEGIN(x, v) (HW_EPDC_TCE_HSCAN2_WR(x, (HW_EPDC_TCE_HSCAN2_RD(x) & ~BM_EPDC_TCE_HSCAN2_LINE_BEGIN) | BF_EPDC_TCE_HSCAN2_LINE_BEGIN(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_HSCAN2, field LINE_END[27:16] (RW)
 *
 * Number of PIXCLK cycles for line end duration. This defines the duration from
 * the de-assertion of SDCE and assertion of the next SDLE.
 */
/*@{*/
#define BP_EPDC_TCE_HSCAN2_LINE_END (16U)  /*!< Bit position for EPDC_TCE_HSCAN2_LINE_END. */
#define BM_EPDC_TCE_HSCAN2_LINE_END (0x0FFF0000U) /*!< Bit mask for EPDC_TCE_HSCAN2_LINE_END. */
#define BS_EPDC_TCE_HSCAN2_LINE_END (12U)  /*!< Bit field size in bits for EPDC_TCE_HSCAN2_LINE_END. */

/*! @brief Read current value of the EPDC_TCE_HSCAN2_LINE_END field. */
#define BR_EPDC_TCE_HSCAN2_LINE_END(x) (HW_EPDC_TCE_HSCAN2(x).B.LINE_END)

/*! @brief Format value for bitfield EPDC_TCE_HSCAN2_LINE_END. */
#define BF_EPDC_TCE_HSCAN2_LINE_END(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_HSCAN2_LINE_END) & BM_EPDC_TCE_HSCAN2_LINE_END)

/*! @brief Set the LINE_END field to a new value. */
#define BW_EPDC_TCE_HSCAN2_LINE_END(x, v) (HW_EPDC_TCE_HSCAN2_WR(x, (HW_EPDC_TCE_HSCAN2_RD(x) & ~BM_EPDC_TCE_HSCAN2_LINE_END) | BF_EPDC_TCE_HSCAN2_LINE_END(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_TCE_VSCAN - EPDC Timing Control Engine Vertical Timing Register
 ******************************************************************************/

/*!
 * @brief HW_EPDC_TCE_VSCAN - EPDC Timing Control Engine Vertical Timing Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Vertical scan timing registers This register houses vertical scan timing.
 * Note that frame data length is derived from EPDC_RES.
 */
typedef union _hw_epdc_tce_vscan
{
    uint32_t U;
    struct _hw_epdc_tce_vscan_bitfields
    {
        uint32_t FRAME_SYNC : 8;       /*!< [7:0]  */
        uint32_t FRAME_BEGIN : 8;      /*!< [15:8]  */
        uint32_t FRAME_END : 8;        /*!< [23:16]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_epdc_tce_vscan_t;

/*!
 * @name Constants and macros for entire EPDC_TCE_VSCAN register
 */
/*@{*/
#define HW_EPDC_TCE_VSCAN_ADDR(x) ((uintptr_t)(x) + 0x2A0U)
#define HW_EPDC_TCE_VSCAN_SET_ADDR(x) (HW_EPDC_TCE_VSCAN_ADDR(x) + 0x4U)
#define HW_EPDC_TCE_VSCAN_CLR_ADDR(x) (HW_EPDC_TCE_VSCAN_ADDR(x) + 0x8U)
#define HW_EPDC_TCE_VSCAN_TOG_ADDR(x) (HW_EPDC_TCE_VSCAN_ADDR(x) + 0xCU)

#define HW_EPDC_TCE_VSCAN(x)     (*(__IO hw_epdc_tce_vscan_t *) HW_EPDC_TCE_VSCAN_ADDR(x))
#define HW_EPDC_TCE_VSCAN_RD(x)  (HW_EPDC_TCE_VSCAN(x).U)
#define HW_EPDC_TCE_VSCAN_WR(x, v) (HW_EPDC_TCE_VSCAN(x).U = (v))
#define HW_EPDC_TCE_VSCAN_SET(x, v) ((*(uint32_t *) HW_EPDC_TCE_VSCAN_SET_ADDR(x)) = (v))
#define HW_EPDC_TCE_VSCAN_CLR(x, v) ((*(uint32_t *) HW_EPDC_TCE_VSCAN_CLR_ADDR(x)) = (v))
#define HW_EPDC_TCE_VSCAN_TOG(x, v) ((*(uint32_t *) HW_EPDC_TCE_VSCAN_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_TCE_VSCAN bitfields
 */

/*!
 * @name Register EPDC_TCE_VSCAN, field FRAME_SYNC[7:0] (RW)
 *
 * Number of lines for frame sync duration.
 */
/*@{*/
#define BP_EPDC_TCE_VSCAN_FRAME_SYNC (0U)  /*!< Bit position for EPDC_TCE_VSCAN_FRAME_SYNC. */
#define BM_EPDC_TCE_VSCAN_FRAME_SYNC (0x000000FFU) /*!< Bit mask for EPDC_TCE_VSCAN_FRAME_SYNC. */
#define BS_EPDC_TCE_VSCAN_FRAME_SYNC (8U)  /*!< Bit field size in bits for EPDC_TCE_VSCAN_FRAME_SYNC. */

/*! @brief Read current value of the EPDC_TCE_VSCAN_FRAME_SYNC field. */
#define BR_EPDC_TCE_VSCAN_FRAME_SYNC(x) (HW_EPDC_TCE_VSCAN(x).B.FRAME_SYNC)

/*! @brief Format value for bitfield EPDC_TCE_VSCAN_FRAME_SYNC. */
#define BF_EPDC_TCE_VSCAN_FRAME_SYNC(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_VSCAN_FRAME_SYNC) & BM_EPDC_TCE_VSCAN_FRAME_SYNC)

/*! @brief Set the FRAME_SYNC field to a new value. */
#define BW_EPDC_TCE_VSCAN_FRAME_SYNC(x, v) (HW_EPDC_TCE_VSCAN_WR(x, (HW_EPDC_TCE_VSCAN_RD(x) & ~BM_EPDC_TCE_VSCAN_FRAME_SYNC) | BF_EPDC_TCE_VSCAN_FRAME_SYNC(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_VSCAN, field FRAME_BEGIN[15:8] (RW)
 *
 * Number of lines for frame begin duration.
 */
/*@{*/
#define BP_EPDC_TCE_VSCAN_FRAME_BEGIN (8U) /*!< Bit position for EPDC_TCE_VSCAN_FRAME_BEGIN. */
#define BM_EPDC_TCE_VSCAN_FRAME_BEGIN (0x0000FF00U) /*!< Bit mask for EPDC_TCE_VSCAN_FRAME_BEGIN. */
#define BS_EPDC_TCE_VSCAN_FRAME_BEGIN (8U) /*!< Bit field size in bits for EPDC_TCE_VSCAN_FRAME_BEGIN. */

/*! @brief Read current value of the EPDC_TCE_VSCAN_FRAME_BEGIN field. */
#define BR_EPDC_TCE_VSCAN_FRAME_BEGIN(x) (HW_EPDC_TCE_VSCAN(x).B.FRAME_BEGIN)

/*! @brief Format value for bitfield EPDC_TCE_VSCAN_FRAME_BEGIN. */
#define BF_EPDC_TCE_VSCAN_FRAME_BEGIN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_VSCAN_FRAME_BEGIN) & BM_EPDC_TCE_VSCAN_FRAME_BEGIN)

/*! @brief Set the FRAME_BEGIN field to a new value. */
#define BW_EPDC_TCE_VSCAN_FRAME_BEGIN(x, v) (HW_EPDC_TCE_VSCAN_WR(x, (HW_EPDC_TCE_VSCAN_RD(x) & ~BM_EPDC_TCE_VSCAN_FRAME_BEGIN) | BF_EPDC_TCE_VSCAN_FRAME_BEGIN(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_VSCAN, field FRAME_END[23:16] (RW)
 *
 * Number of lines for frame end duration.
 */
/*@{*/
#define BP_EPDC_TCE_VSCAN_FRAME_END (16U)  /*!< Bit position for EPDC_TCE_VSCAN_FRAME_END. */
#define BM_EPDC_TCE_VSCAN_FRAME_END (0x00FF0000U) /*!< Bit mask for EPDC_TCE_VSCAN_FRAME_END. */
#define BS_EPDC_TCE_VSCAN_FRAME_END (8U)   /*!< Bit field size in bits for EPDC_TCE_VSCAN_FRAME_END. */

/*! @brief Read current value of the EPDC_TCE_VSCAN_FRAME_END field. */
#define BR_EPDC_TCE_VSCAN_FRAME_END(x) (HW_EPDC_TCE_VSCAN(x).B.FRAME_END)

/*! @brief Format value for bitfield EPDC_TCE_VSCAN_FRAME_END. */
#define BF_EPDC_TCE_VSCAN_FRAME_END(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_VSCAN_FRAME_END) & BM_EPDC_TCE_VSCAN_FRAME_END)

/*! @brief Set the FRAME_END field to a new value. */
#define BW_EPDC_TCE_VSCAN_FRAME_END(x, v) (HW_EPDC_TCE_VSCAN_WR(x, (HW_EPDC_TCE_VSCAN_RD(x) & ~BM_EPDC_TCE_VSCAN_FRAME_END) | BF_EPDC_TCE_VSCAN_FRAME_END(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_TCE_OE - EPDC Timing Control Engine OE timing control Register
 ******************************************************************************/

/*!
 * @brief HW_EPDC_TCE_OE - EPDC Timing Control Engine OE timing control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contain delay programming values for the SDOEZ and SDOED source
 * driver control signals This register contain delay programming values for the
 * SDOZ and SDOE source driver control signals
 */
typedef union _hw_epdc_tce_oe
{
    uint32_t U;
    struct _hw_epdc_tce_oe_bitfields
    {
        uint32_t SDOEZ_DLY : 8;        /*!< [7:0]  */
        uint32_t SDOEZ_WIDTH : 8;      /*!< [15:8]  */
        uint32_t SDOED_DLY : 8;        /*!< [23:16]  */
        uint32_t SDOED_WIDTH : 8;      /*!< [31:24]  */
    } B;
} hw_epdc_tce_oe_t;

/*!
 * @name Constants and macros for entire EPDC_TCE_OE register
 */
/*@{*/
#define HW_EPDC_TCE_OE_ADDR(x)   ((uintptr_t)(x) + 0x2C0U)
#define HW_EPDC_TCE_OE_SET_ADDR(x) (HW_EPDC_TCE_OE_ADDR(x) + 0x4U)
#define HW_EPDC_TCE_OE_CLR_ADDR(x) (HW_EPDC_TCE_OE_ADDR(x) + 0x8U)
#define HW_EPDC_TCE_OE_TOG_ADDR(x) (HW_EPDC_TCE_OE_ADDR(x) + 0xCU)

#define HW_EPDC_TCE_OE(x)        (*(__IO hw_epdc_tce_oe_t *) HW_EPDC_TCE_OE_ADDR(x))
#define HW_EPDC_TCE_OE_RD(x)     (HW_EPDC_TCE_OE(x).U)
#define HW_EPDC_TCE_OE_WR(x, v)  (HW_EPDC_TCE_OE(x).U = (v))
#define HW_EPDC_TCE_OE_SET(x, v) ((*(uint32_t *) HW_EPDC_TCE_OE_SET_ADDR(x)) = (v))
#define HW_EPDC_TCE_OE_CLR(x, v) ((*(uint32_t *) HW_EPDC_TCE_OE_CLR_ADDR(x)) = (v))
#define HW_EPDC_TCE_OE_TOG(x, v) ((*(uint32_t *) HW_EPDC_TCE_OE_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_TCE_OE bitfields
 */

/*!
 * @name Register EPDC_TCE_OE, field SDOEZ_DLY[7:0] (RW)
 *
 * Number of PIXCLK cycles from SDLE falling edge to SDOEZ rising (Must be
 * greater than 0)
 */
/*@{*/
#define BP_EPDC_TCE_OE_SDOEZ_DLY (0U)      /*!< Bit position for EPDC_TCE_OE_SDOEZ_DLY. */
#define BM_EPDC_TCE_OE_SDOEZ_DLY (0x000000FFU) /*!< Bit mask for EPDC_TCE_OE_SDOEZ_DLY. */
#define BS_EPDC_TCE_OE_SDOEZ_DLY (8U)      /*!< Bit field size in bits for EPDC_TCE_OE_SDOEZ_DLY. */

/*! @brief Read current value of the EPDC_TCE_OE_SDOEZ_DLY field. */
#define BR_EPDC_TCE_OE_SDOEZ_DLY(x) (HW_EPDC_TCE_OE(x).B.SDOEZ_DLY)

/*! @brief Format value for bitfield EPDC_TCE_OE_SDOEZ_DLY. */
#define BF_EPDC_TCE_OE_SDOEZ_DLY(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_OE_SDOEZ_DLY) & BM_EPDC_TCE_OE_SDOEZ_DLY)

/*! @brief Set the SDOEZ_DLY field to a new value. */
#define BW_EPDC_TCE_OE_SDOEZ_DLY(x, v) (HW_EPDC_TCE_OE_WR(x, (HW_EPDC_TCE_OE_RD(x) & ~BM_EPDC_TCE_OE_SDOEZ_DLY) | BF_EPDC_TCE_OE_SDOEZ_DLY(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_OE, field SDOEZ_WIDTH[15:8] (RW)
 *
 * Number of PIXCLK cycles from SDOEZ high to SDOEZ falling (Must be greater
 * than 0)
 */
/*@{*/
#define BP_EPDC_TCE_OE_SDOEZ_WIDTH (8U)    /*!< Bit position for EPDC_TCE_OE_SDOEZ_WIDTH. */
#define BM_EPDC_TCE_OE_SDOEZ_WIDTH (0x0000FF00U) /*!< Bit mask for EPDC_TCE_OE_SDOEZ_WIDTH. */
#define BS_EPDC_TCE_OE_SDOEZ_WIDTH (8U)    /*!< Bit field size in bits for EPDC_TCE_OE_SDOEZ_WIDTH. */

/*! @brief Read current value of the EPDC_TCE_OE_SDOEZ_WIDTH field. */
#define BR_EPDC_TCE_OE_SDOEZ_WIDTH(x) (HW_EPDC_TCE_OE(x).B.SDOEZ_WIDTH)

/*! @brief Format value for bitfield EPDC_TCE_OE_SDOEZ_WIDTH. */
#define BF_EPDC_TCE_OE_SDOEZ_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_OE_SDOEZ_WIDTH) & BM_EPDC_TCE_OE_SDOEZ_WIDTH)

/*! @brief Set the SDOEZ_WIDTH field to a new value. */
#define BW_EPDC_TCE_OE_SDOEZ_WIDTH(x, v) (HW_EPDC_TCE_OE_WR(x, (HW_EPDC_TCE_OE_RD(x) & ~BM_EPDC_TCE_OE_SDOEZ_WIDTH) | BF_EPDC_TCE_OE_SDOEZ_WIDTH(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_OE, field SDOED_DLY[23:16] (RW)
 *
 * Number of PIXCLK cycles from SDOEZ low to SDOED rising (Must be greater than
 * 0)
 */
/*@{*/
#define BP_EPDC_TCE_OE_SDOED_DLY (16U)     /*!< Bit position for EPDC_TCE_OE_SDOED_DLY. */
#define BM_EPDC_TCE_OE_SDOED_DLY (0x00FF0000U) /*!< Bit mask for EPDC_TCE_OE_SDOED_DLY. */
#define BS_EPDC_TCE_OE_SDOED_DLY (8U)      /*!< Bit field size in bits for EPDC_TCE_OE_SDOED_DLY. */

/*! @brief Read current value of the EPDC_TCE_OE_SDOED_DLY field. */
#define BR_EPDC_TCE_OE_SDOED_DLY(x) (HW_EPDC_TCE_OE(x).B.SDOED_DLY)

/*! @brief Format value for bitfield EPDC_TCE_OE_SDOED_DLY. */
#define BF_EPDC_TCE_OE_SDOED_DLY(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_OE_SDOED_DLY) & BM_EPDC_TCE_OE_SDOED_DLY)

/*! @brief Set the SDOED_DLY field to a new value. */
#define BW_EPDC_TCE_OE_SDOED_DLY(x, v) (HW_EPDC_TCE_OE_WR(x, (HW_EPDC_TCE_OE_RD(x) & ~BM_EPDC_TCE_OE_SDOED_DLY) | BF_EPDC_TCE_OE_SDOED_DLY(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_OE, field SDOED_WIDTH[31:24] (RW)
 *
 * Number of PIXCLK cycles from SDOED high to SDOED falling (Must be greater
 * than 0)
 */
/*@{*/
#define BP_EPDC_TCE_OE_SDOED_WIDTH (24U)   /*!< Bit position for EPDC_TCE_OE_SDOED_WIDTH. */
#define BM_EPDC_TCE_OE_SDOED_WIDTH (0xFF000000U) /*!< Bit mask for EPDC_TCE_OE_SDOED_WIDTH. */
#define BS_EPDC_TCE_OE_SDOED_WIDTH (8U)    /*!< Bit field size in bits for EPDC_TCE_OE_SDOED_WIDTH. */

/*! @brief Read current value of the EPDC_TCE_OE_SDOED_WIDTH field. */
#define BR_EPDC_TCE_OE_SDOED_WIDTH(x) (HW_EPDC_TCE_OE(x).B.SDOED_WIDTH)

/*! @brief Format value for bitfield EPDC_TCE_OE_SDOED_WIDTH. */
#define BF_EPDC_TCE_OE_SDOED_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_OE_SDOED_WIDTH) & BM_EPDC_TCE_OE_SDOED_WIDTH)

/*! @brief Set the SDOED_WIDTH field to a new value. */
#define BW_EPDC_TCE_OE_SDOED_WIDTH(x, v) (HW_EPDC_TCE_OE_WR(x, (HW_EPDC_TCE_OE_RD(x) & ~BM_EPDC_TCE_OE_SDOED_WIDTH) | BF_EPDC_TCE_OE_SDOED_WIDTH(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_TCE_POLARITY - EPDC Timing Control Engine Driver Polarity Register
 ******************************************************************************/

/*!
 * @brief HW_EPDC_TCE_POLARITY - EPDC Timing Control Engine Driver Polarity Register (RW)
 *
 * Reset value: 0x0000001EU
 *
 * This registers allows for programming the polarity of source/gate driver
 * control signals This register houses FIFO control bits
 */
typedef union _hw_epdc_tce_polarity
{
    uint32_t U;
    struct _hw_epdc_tce_polarity_bitfields
    {
        uint32_t SDCE_POL : 1;         /*!< [0]  */
        uint32_t SDLE_POL : 1;         /*!< [1]  */
        uint32_t SDOE_POL : 1;         /*!< [2]  */
        uint32_t GDOE_POL : 1;         /*!< [3]  */
        uint32_t GDSP_POL : 1;         /*!< [4]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_epdc_tce_polarity_t;

/*!
 * @name Constants and macros for entire EPDC_TCE_POLARITY register
 */
/*@{*/
#define HW_EPDC_TCE_POLARITY_ADDR(x) ((uintptr_t)(x) + 0x2E0U)
#define HW_EPDC_TCE_POLARITY_SET_ADDR(x) (HW_EPDC_TCE_POLARITY_ADDR(x) + 0x4U)
#define HW_EPDC_TCE_POLARITY_CLR_ADDR(x) (HW_EPDC_TCE_POLARITY_ADDR(x) + 0x8U)
#define HW_EPDC_TCE_POLARITY_TOG_ADDR(x) (HW_EPDC_TCE_POLARITY_ADDR(x) + 0xCU)

#define HW_EPDC_TCE_POLARITY(x)  (*(__IO hw_epdc_tce_polarity_t *) HW_EPDC_TCE_POLARITY_ADDR(x))
#define HW_EPDC_TCE_POLARITY_RD(x) (HW_EPDC_TCE_POLARITY(x).U)
#define HW_EPDC_TCE_POLARITY_WR(x, v) (HW_EPDC_TCE_POLARITY(x).U = (v))
#define HW_EPDC_TCE_POLARITY_SET(x, v) ((*(uint32_t *) HW_EPDC_TCE_POLARITY_SET_ADDR(x)) = (v))
#define HW_EPDC_TCE_POLARITY_CLR(x, v) ((*(uint32_t *) HW_EPDC_TCE_POLARITY_CLR_ADDR(x)) = (v))
#define HW_EPDC_TCE_POLARITY_TOG(x, v) ((*(uint32_t *) HW_EPDC_TCE_POLARITY_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_TCE_POLARITY bitfields
 */

/*!
 * @name Register EPDC_TCE_POLARITY, field SDCE_POL[0] (RW)
 *
 * 0 = Active Low, 1 = Active High. Applies to all 10 SDCE outputs
 */
/*@{*/
#define BP_EPDC_TCE_POLARITY_SDCE_POL (0U) /*!< Bit position for EPDC_TCE_POLARITY_SDCE_POL. */
#define BM_EPDC_TCE_POLARITY_SDCE_POL (0x00000001U) /*!< Bit mask for EPDC_TCE_POLARITY_SDCE_POL. */
#define BS_EPDC_TCE_POLARITY_SDCE_POL (1U) /*!< Bit field size in bits for EPDC_TCE_POLARITY_SDCE_POL. */

/*! @brief Read current value of the EPDC_TCE_POLARITY_SDCE_POL field. */
#define BR_EPDC_TCE_POLARITY_SDCE_POL(x) (HW_EPDC_TCE_POLARITY(x).B.SDCE_POL)

/*! @brief Format value for bitfield EPDC_TCE_POLARITY_SDCE_POL. */
#define BF_EPDC_TCE_POLARITY_SDCE_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_POLARITY_SDCE_POL) & BM_EPDC_TCE_POLARITY_SDCE_POL)

/*! @brief Set the SDCE_POL field to a new value. */
#define BW_EPDC_TCE_POLARITY_SDCE_POL(x, v) (HW_EPDC_TCE_POLARITY_WR(x, (HW_EPDC_TCE_POLARITY_RD(x) & ~BM_EPDC_TCE_POLARITY_SDCE_POL) | BF_EPDC_TCE_POLARITY_SDCE_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_POLARITY, field SDLE_POL[1] (RW)
 *
 * 0 = Active Low, 1 = Active High. Applies to the SDLE output
 */
/*@{*/
#define BP_EPDC_TCE_POLARITY_SDLE_POL (1U) /*!< Bit position for EPDC_TCE_POLARITY_SDLE_POL. */
#define BM_EPDC_TCE_POLARITY_SDLE_POL (0x00000002U) /*!< Bit mask for EPDC_TCE_POLARITY_SDLE_POL. */
#define BS_EPDC_TCE_POLARITY_SDLE_POL (1U) /*!< Bit field size in bits for EPDC_TCE_POLARITY_SDLE_POL. */

/*! @brief Read current value of the EPDC_TCE_POLARITY_SDLE_POL field. */
#define BR_EPDC_TCE_POLARITY_SDLE_POL(x) (HW_EPDC_TCE_POLARITY(x).B.SDLE_POL)

/*! @brief Format value for bitfield EPDC_TCE_POLARITY_SDLE_POL. */
#define BF_EPDC_TCE_POLARITY_SDLE_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_POLARITY_SDLE_POL) & BM_EPDC_TCE_POLARITY_SDLE_POL)

/*! @brief Set the SDLE_POL field to a new value. */
#define BW_EPDC_TCE_POLARITY_SDLE_POL(x, v) (HW_EPDC_TCE_POLARITY_WR(x, (HW_EPDC_TCE_POLARITY_RD(x) & ~BM_EPDC_TCE_POLARITY_SDLE_POL) | BF_EPDC_TCE_POLARITY_SDLE_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_POLARITY, field SDOE_POL[2] (RW)
 *
 * 0 = Active Low, 1 = Active High. Applies to the SDOE. Does not apply to SDOEZ
 * and SDOED outputs
 */
/*@{*/
#define BP_EPDC_TCE_POLARITY_SDOE_POL (2U) /*!< Bit position for EPDC_TCE_POLARITY_SDOE_POL. */
#define BM_EPDC_TCE_POLARITY_SDOE_POL (0x00000004U) /*!< Bit mask for EPDC_TCE_POLARITY_SDOE_POL. */
#define BS_EPDC_TCE_POLARITY_SDOE_POL (1U) /*!< Bit field size in bits for EPDC_TCE_POLARITY_SDOE_POL. */

/*! @brief Read current value of the EPDC_TCE_POLARITY_SDOE_POL field. */
#define BR_EPDC_TCE_POLARITY_SDOE_POL(x) (HW_EPDC_TCE_POLARITY(x).B.SDOE_POL)

/*! @brief Format value for bitfield EPDC_TCE_POLARITY_SDOE_POL. */
#define BF_EPDC_TCE_POLARITY_SDOE_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_POLARITY_SDOE_POL) & BM_EPDC_TCE_POLARITY_SDOE_POL)

/*! @brief Set the SDOE_POL field to a new value. */
#define BW_EPDC_TCE_POLARITY_SDOE_POL(x, v) (HW_EPDC_TCE_POLARITY_WR(x, (HW_EPDC_TCE_POLARITY_RD(x) & ~BM_EPDC_TCE_POLARITY_SDOE_POL) | BF_EPDC_TCE_POLARITY_SDOE_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_POLARITY, field GDOE_POL[3] (RW)
 *
 * 0 = Active Low, 1 = Active High. Applies to the GDOE output
 */
/*@{*/
#define BP_EPDC_TCE_POLARITY_GDOE_POL (3U) /*!< Bit position for EPDC_TCE_POLARITY_GDOE_POL. */
#define BM_EPDC_TCE_POLARITY_GDOE_POL (0x00000008U) /*!< Bit mask for EPDC_TCE_POLARITY_GDOE_POL. */
#define BS_EPDC_TCE_POLARITY_GDOE_POL (1U) /*!< Bit field size in bits for EPDC_TCE_POLARITY_GDOE_POL. */

/*! @brief Read current value of the EPDC_TCE_POLARITY_GDOE_POL field. */
#define BR_EPDC_TCE_POLARITY_GDOE_POL(x) (HW_EPDC_TCE_POLARITY(x).B.GDOE_POL)

/*! @brief Format value for bitfield EPDC_TCE_POLARITY_GDOE_POL. */
#define BF_EPDC_TCE_POLARITY_GDOE_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_POLARITY_GDOE_POL) & BM_EPDC_TCE_POLARITY_GDOE_POL)

/*! @brief Set the GDOE_POL field to a new value. */
#define BW_EPDC_TCE_POLARITY_GDOE_POL(x, v) (HW_EPDC_TCE_POLARITY_WR(x, (HW_EPDC_TCE_POLARITY_RD(x) & ~BM_EPDC_TCE_POLARITY_GDOE_POL) | BF_EPDC_TCE_POLARITY_GDOE_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_POLARITY, field GDSP_POL[4] (RW)
 *
 * 0 = Active Low, 1 = Active High. Applies to the GDSP output
 */
/*@{*/
#define BP_EPDC_TCE_POLARITY_GDSP_POL (4U) /*!< Bit position for EPDC_TCE_POLARITY_GDSP_POL. */
#define BM_EPDC_TCE_POLARITY_GDSP_POL (0x00000010U) /*!< Bit mask for EPDC_TCE_POLARITY_GDSP_POL. */
#define BS_EPDC_TCE_POLARITY_GDSP_POL (1U) /*!< Bit field size in bits for EPDC_TCE_POLARITY_GDSP_POL. */

/*! @brief Read current value of the EPDC_TCE_POLARITY_GDSP_POL field. */
#define BR_EPDC_TCE_POLARITY_GDSP_POL(x) (HW_EPDC_TCE_POLARITY(x).B.GDSP_POL)

/*! @brief Format value for bitfield EPDC_TCE_POLARITY_GDSP_POL. */
#define BF_EPDC_TCE_POLARITY_GDSP_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_POLARITY_GDSP_POL) & BM_EPDC_TCE_POLARITY_GDSP_POL)

/*! @brief Set the GDSP_POL field to a new value. */
#define BW_EPDC_TCE_POLARITY_GDSP_POL(x, v) (HW_EPDC_TCE_POLARITY_WR(x, (HW_EPDC_TCE_POLARITY_RD(x) & ~BM_EPDC_TCE_POLARITY_GDSP_POL) | BF_EPDC_TCE_POLARITY_GDSP_POL(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_TCE_TIMING1 - EPDC Timing Control Engine Timing Register 1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_TCE_TIMING1 - EPDC Timing Control Engine Timing Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains various timing adjustment controls This register
 * houses general purpose timing adjustment registers
 */
typedef union _hw_epdc_tce_timing1
{
    uint32_t U;
    struct _hw_epdc_tce_timing1_bitfields
    {
        uint32_t SDCLK_SHIFT : 2;      /*!< [1:0]  */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t SDCLK_INVERT : 1;     /*!< [3]  */
        uint32_t SDLE_SHIFT : 2;       /*!< [5:4]  */
        uint32_t RESERVED1 : 26;       /*!< [31:6]  */
    } B;
} hw_epdc_tce_timing1_t;

/*!
 * @name Constants and macros for entire EPDC_TCE_TIMING1 register
 */
/*@{*/
#define HW_EPDC_TCE_TIMING1_ADDR(x) ((uintptr_t)(x) + 0x300U)
#define HW_EPDC_TCE_TIMING1_SET_ADDR(x) (HW_EPDC_TCE_TIMING1_ADDR(x) + 0x4U)
#define HW_EPDC_TCE_TIMING1_CLR_ADDR(x) (HW_EPDC_TCE_TIMING1_ADDR(x) + 0x8U)
#define HW_EPDC_TCE_TIMING1_TOG_ADDR(x) (HW_EPDC_TCE_TIMING1_ADDR(x) + 0xCU)

#define HW_EPDC_TCE_TIMING1(x)   (*(__IO hw_epdc_tce_timing1_t *) HW_EPDC_TCE_TIMING1_ADDR(x))
#define HW_EPDC_TCE_TIMING1_RD(x) (HW_EPDC_TCE_TIMING1(x).U)
#define HW_EPDC_TCE_TIMING1_WR(x, v) (HW_EPDC_TCE_TIMING1(x).U = (v))
#define HW_EPDC_TCE_TIMING1_SET(x, v) ((*(uint32_t *) HW_EPDC_TCE_TIMING1_SET_ADDR(x)) = (v))
#define HW_EPDC_TCE_TIMING1_CLR(x, v) ((*(uint32_t *) HW_EPDC_TCE_TIMING1_CLR_ADDR(x)) = (v))
#define HW_EPDC_TCE_TIMING1_TOG(x, v) ((*(uint32_t *) HW_EPDC_TCE_TIMING1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_TCE_TIMING1 bitfields
 */

/*!
 * @name Register EPDC_TCE_TIMING1, field SDCLK_SHIFT[1:0] (RW)
 *
 * This register can be used to implement additional timing setup/hold
 * adjustment of source driver signals by adjusting the SDCLK up to 4 cycles
 *
 * Values:
 * - 0 - No shift of SDCLK
 * - 1 - Shift SDCLK 1 pixclk cycle
 * - 10 - Shift SDCLK 2 pixclk cycles
 * - 11 - Shift SDCLK 3 pixclk cycles
 */
/*@{*/
#define BP_EPDC_TCE_TIMING1_SDCLK_SHIFT (0U) /*!< Bit position for EPDC_TCE_TIMING1_SDCLK_SHIFT. */
#define BM_EPDC_TCE_TIMING1_SDCLK_SHIFT (0x00000003U) /*!< Bit mask for EPDC_TCE_TIMING1_SDCLK_SHIFT. */
#define BS_EPDC_TCE_TIMING1_SDCLK_SHIFT (2U) /*!< Bit field size in bits for EPDC_TCE_TIMING1_SDCLK_SHIFT. */

#define BV_EPDC_TCE_TIMING1_SDCLK_SHIFT_NONE (0U)    /*!< Bit field value for EPDC_TCE_TIMING1_SDCLK_SHIFT: No shift of SDCLK */
#define BV_EPDC_TCE_TIMING1_SDCLK_SHIFT_ONE (0x1U)   /*!< Bit field value for EPDC_TCE_TIMING1_SDCLK_SHIFT: Shift SDCLK 1 pixclk cycle */
#define BV_EPDC_TCE_TIMING1_SDCLK_SHIFT_TWO (0x2U)   /*!< Bit field value for EPDC_TCE_TIMING1_SDCLK_SHIFT: Shift SDCLK 2 pixclk cycles */
#define BV_EPDC_TCE_TIMING1_SDCLK_SHIFT_THREE (0x3U) /*!< Bit field value for EPDC_TCE_TIMING1_SDCLK_SHIFT: Shift SDCLK 3 pixclk cycles */

/*! @brief Read current value of the EPDC_TCE_TIMING1_SDCLK_SHIFT field. */
#define BR_EPDC_TCE_TIMING1_SDCLK_SHIFT(x) (HW_EPDC_TCE_TIMING1(x).B.SDCLK_SHIFT)

/*! @brief Format value for bitfield EPDC_TCE_TIMING1_SDCLK_SHIFT. */
#define BF_EPDC_TCE_TIMING1_SDCLK_SHIFT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_TIMING1_SDCLK_SHIFT) & BM_EPDC_TCE_TIMING1_SDCLK_SHIFT)

/*! @brief Set the SDCLK_SHIFT field to a new value. */
#define BW_EPDC_TCE_TIMING1_SDCLK_SHIFT(x, v) (HW_EPDC_TCE_TIMING1_WR(x, (HW_EPDC_TCE_TIMING1_RD(x) & ~BM_EPDC_TCE_TIMING1_SDCLK_SHIFT) | BF_EPDC_TCE_TIMING1_SDCLK_SHIFT(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_TIMING1, field SDCLK_INVERT[3] (RW)
 *
 * Invert phase of SDCLK
 */
/*@{*/
#define BP_EPDC_TCE_TIMING1_SDCLK_INVERT (3U) /*!< Bit position for EPDC_TCE_TIMING1_SDCLK_INVERT. */
#define BM_EPDC_TCE_TIMING1_SDCLK_INVERT (0x00000008U) /*!< Bit mask for EPDC_TCE_TIMING1_SDCLK_INVERT. */
#define BS_EPDC_TCE_TIMING1_SDCLK_INVERT (1U) /*!< Bit field size in bits for EPDC_TCE_TIMING1_SDCLK_INVERT. */

/*! @brief Read current value of the EPDC_TCE_TIMING1_SDCLK_INVERT field. */
#define BR_EPDC_TCE_TIMING1_SDCLK_INVERT(x) (HW_EPDC_TCE_TIMING1(x).B.SDCLK_INVERT)

/*! @brief Format value for bitfield EPDC_TCE_TIMING1_SDCLK_INVERT. */
#define BF_EPDC_TCE_TIMING1_SDCLK_INVERT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_TIMING1_SDCLK_INVERT) & BM_EPDC_TCE_TIMING1_SDCLK_INVERT)

/*! @brief Set the SDCLK_INVERT field to a new value. */
#define BW_EPDC_TCE_TIMING1_SDCLK_INVERT(x, v) (HW_EPDC_TCE_TIMING1_WR(x, (HW_EPDC_TCE_TIMING1_RD(x) & ~BM_EPDC_TCE_TIMING1_SDCLK_INVERT) | BF_EPDC_TCE_TIMING1_SDCLK_INVERT(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_TIMING1, field SDLE_SHIFT[5:4] (RW)
 *
 * This register can be used to implement additional timing setup/hold
 * adjustment of source driver signals by adjusting the SDCLK up to 3 PIXCLK cycles
 *
 * Values:
 * - 0 - No shift of SDLE
 * - 1 - Shift SDLE 1 pixclk cycle
 * - 10 - Shift SDLE 2 pixclk cycles
 * - 11 - Shift SDLE 3 pixclk cycles
 */
/*@{*/
#define BP_EPDC_TCE_TIMING1_SDLE_SHIFT (4U) /*!< Bit position for EPDC_TCE_TIMING1_SDLE_SHIFT. */
#define BM_EPDC_TCE_TIMING1_SDLE_SHIFT (0x00000030U) /*!< Bit mask for EPDC_TCE_TIMING1_SDLE_SHIFT. */
#define BS_EPDC_TCE_TIMING1_SDLE_SHIFT (2U) /*!< Bit field size in bits for EPDC_TCE_TIMING1_SDLE_SHIFT. */

#define BV_EPDC_TCE_TIMING1_SDLE_SHIFT_NONE (0U)     /*!< Bit field value for EPDC_TCE_TIMING1_SDLE_SHIFT: No shift of SDLE */
#define BV_EPDC_TCE_TIMING1_SDLE_SHIFT_ONE (0x1U)    /*!< Bit field value for EPDC_TCE_TIMING1_SDLE_SHIFT: Shift SDLE 1 pixclk cycle */
#define BV_EPDC_TCE_TIMING1_SDLE_SHIFT_TWO (0x2U)    /*!< Bit field value for EPDC_TCE_TIMING1_SDLE_SHIFT: Shift SDLE 2 pixclk cycles */
#define BV_EPDC_TCE_TIMING1_SDLE_SHIFT_THREE (0x3U)  /*!< Bit field value for EPDC_TCE_TIMING1_SDLE_SHIFT: Shift SDLE 3 pixclk cycles */

/*! @brief Read current value of the EPDC_TCE_TIMING1_SDLE_SHIFT field. */
#define BR_EPDC_TCE_TIMING1_SDLE_SHIFT(x) (HW_EPDC_TCE_TIMING1(x).B.SDLE_SHIFT)

/*! @brief Format value for bitfield EPDC_TCE_TIMING1_SDLE_SHIFT. */
#define BF_EPDC_TCE_TIMING1_SDLE_SHIFT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_TIMING1_SDLE_SHIFT) & BM_EPDC_TCE_TIMING1_SDLE_SHIFT)

/*! @brief Set the SDLE_SHIFT field to a new value. */
#define BW_EPDC_TCE_TIMING1_SDLE_SHIFT(x, v) (HW_EPDC_TCE_TIMING1_WR(x, (HW_EPDC_TCE_TIMING1_RD(x) & ~BM_EPDC_TCE_TIMING1_SDLE_SHIFT) | BF_EPDC_TCE_TIMING1_SDLE_SHIFT(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_TCE_TIMING2 - EPDC Timing Control Engine Timing Register 2
 ******************************************************************************/

/*!
 * @brief HW_EPDC_TCE_TIMING2 - EPDC Timing Control Engine Timing Register 2 (RW)
 *
 * Reset value: 0x00000001U
 *
 * This register contains various timing adjustment controls This register
 * houses general purpose timing adjustment registers
 */
typedef union _hw_epdc_tce_timing2
{
    uint32_t U;
    struct _hw_epdc_tce_timing2_bitfields
    {
        uint32_t GDSP_OFFSET : 16;     /*!< [15:0]  */
        uint32_t GDCLK_HP : 16;        /*!< [31:16]  */
    } B;
} hw_epdc_tce_timing2_t;

/*!
 * @name Constants and macros for entire EPDC_TCE_TIMING2 register
 */
/*@{*/
#define HW_EPDC_TCE_TIMING2_ADDR(x) ((uintptr_t)(x) + 0x310U)
#define HW_EPDC_TCE_TIMING2_SET_ADDR(x) (HW_EPDC_TCE_TIMING2_ADDR(x) + 0x4U)
#define HW_EPDC_TCE_TIMING2_CLR_ADDR(x) (HW_EPDC_TCE_TIMING2_ADDR(x) + 0x8U)
#define HW_EPDC_TCE_TIMING2_TOG_ADDR(x) (HW_EPDC_TCE_TIMING2_ADDR(x) + 0xCU)

#define HW_EPDC_TCE_TIMING2(x)   (*(__IO hw_epdc_tce_timing2_t *) HW_EPDC_TCE_TIMING2_ADDR(x))
#define HW_EPDC_TCE_TIMING2_RD(x) (HW_EPDC_TCE_TIMING2(x).U)
#define HW_EPDC_TCE_TIMING2_WR(x, v) (HW_EPDC_TCE_TIMING2(x).U = (v))
#define HW_EPDC_TCE_TIMING2_SET(x, v) ((*(uint32_t *) HW_EPDC_TCE_TIMING2_SET_ADDR(x)) = (v))
#define HW_EPDC_TCE_TIMING2_CLR(x, v) ((*(uint32_t *) HW_EPDC_TCE_TIMING2_CLR_ADDR(x)) = (v))
#define HW_EPDC_TCE_TIMING2_TOG(x, v) ((*(uint32_t *) HW_EPDC_TCE_TIMING2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_TCE_TIMING2 bitfields
 */

/*!
 * @name Register EPDC_TCE_TIMING2, field GDSP_OFFSET[15:0] (RW)
 *
 * This register allows the user to shift the GDSP pulse by N PIXCLKs where N=1
 * to 65535. Note that GDSP will always have a pulse width equivalent to the
 * line-clock timing. A value of 0 is not supported.
 */
/*@{*/
#define BP_EPDC_TCE_TIMING2_GDSP_OFFSET (0U) /*!< Bit position for EPDC_TCE_TIMING2_GDSP_OFFSET. */
#define BM_EPDC_TCE_TIMING2_GDSP_OFFSET (0x0000FFFFU) /*!< Bit mask for EPDC_TCE_TIMING2_GDSP_OFFSET. */
#define BS_EPDC_TCE_TIMING2_GDSP_OFFSET (16U) /*!< Bit field size in bits for EPDC_TCE_TIMING2_GDSP_OFFSET. */

/*! @brief Read current value of the EPDC_TCE_TIMING2_GDSP_OFFSET field. */
#define BR_EPDC_TCE_TIMING2_GDSP_OFFSET(x) (HW_EPDC_TCE_TIMING2(x).B.GDSP_OFFSET)

/*! @brief Format value for bitfield EPDC_TCE_TIMING2_GDSP_OFFSET. */
#define BF_EPDC_TCE_TIMING2_GDSP_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_TIMING2_GDSP_OFFSET) & BM_EPDC_TCE_TIMING2_GDSP_OFFSET)

/*! @brief Set the GDSP_OFFSET field to a new value. */
#define BW_EPDC_TCE_TIMING2_GDSP_OFFSET(x, v) (HW_EPDC_TCE_TIMING2_WR(x, (HW_EPDC_TCE_TIMING2_RD(x) & ~BM_EPDC_TCE_TIMING2_GDSP_OFFSET) | BF_EPDC_TCE_TIMING2_GDSP_OFFSET(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_TIMING2, field GDCLK_HP[31:16] (RW)
 *
 * This register controls the GDCLK high-pulse width. It is expressed by N
 * PIXCLKs where N=1 to 65535. Note that GDCLK will always have a period equal to the
 * line-clock timing. A value of 0 is not supported. It is recommended that this
 * value be set to at least a half line-clock time. For panels which use GDCLK to
 * drive GDOE, this high-pulse width should be set to cover tha majority of the
 * line timing
 */
/*@{*/
#define BP_EPDC_TCE_TIMING2_GDCLK_HP (16U) /*!< Bit position for EPDC_TCE_TIMING2_GDCLK_HP. */
#define BM_EPDC_TCE_TIMING2_GDCLK_HP (0xFFFF0000U) /*!< Bit mask for EPDC_TCE_TIMING2_GDCLK_HP. */
#define BS_EPDC_TCE_TIMING2_GDCLK_HP (16U) /*!< Bit field size in bits for EPDC_TCE_TIMING2_GDCLK_HP. */

/*! @brief Read current value of the EPDC_TCE_TIMING2_GDCLK_HP field. */
#define BR_EPDC_TCE_TIMING2_GDCLK_HP(x) (HW_EPDC_TCE_TIMING2(x).B.GDCLK_HP)

/*! @brief Format value for bitfield EPDC_TCE_TIMING2_GDCLK_HP. */
#define BF_EPDC_TCE_TIMING2_GDCLK_HP(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_TIMING2_GDCLK_HP) & BM_EPDC_TCE_TIMING2_GDCLK_HP)

/*! @brief Set the GDCLK_HP field to a new value. */
#define BW_EPDC_TCE_TIMING2_GDCLK_HP(x, v) (HW_EPDC_TCE_TIMING2_WR(x, (HW_EPDC_TCE_TIMING2_RD(x) & ~BM_EPDC_TCE_TIMING2_GDCLK_HP) | BF_EPDC_TCE_TIMING2_GDCLK_HP(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_TCE_TIMING3 - EPDC Timing Control Engine Timing Register 3
 ******************************************************************************/

/*!
 * @brief HW_EPDC_TCE_TIMING3 - EPDC Timing Control Engine Timing Register 3 (RW)
 *
 * Reset value: 0x00000001U
 *
 * This register contains various timing adjustment controls This register
 * houses general purpose timing adjustment registers
 */
typedef union _hw_epdc_tce_timing3
{
    uint32_t U;
    struct _hw_epdc_tce_timing3_bitfields
    {
        uint32_t GDCLK_OFFSET : 16;    /*!< [15:0]  */
        uint32_t GDOE_OFFSET : 16;     /*!< [31:16]  */
    } B;
} hw_epdc_tce_timing3_t;

/*!
 * @name Constants and macros for entire EPDC_TCE_TIMING3 register
 */
/*@{*/
#define HW_EPDC_TCE_TIMING3_ADDR(x) ((uintptr_t)(x) + 0x320U)
#define HW_EPDC_TCE_TIMING3_SET_ADDR(x) (HW_EPDC_TCE_TIMING3_ADDR(x) + 0x4U)
#define HW_EPDC_TCE_TIMING3_CLR_ADDR(x) (HW_EPDC_TCE_TIMING3_ADDR(x) + 0x8U)
#define HW_EPDC_TCE_TIMING3_TOG_ADDR(x) (HW_EPDC_TCE_TIMING3_ADDR(x) + 0xCU)

#define HW_EPDC_TCE_TIMING3(x)   (*(__IO hw_epdc_tce_timing3_t *) HW_EPDC_TCE_TIMING3_ADDR(x))
#define HW_EPDC_TCE_TIMING3_RD(x) (HW_EPDC_TCE_TIMING3(x).U)
#define HW_EPDC_TCE_TIMING3_WR(x, v) (HW_EPDC_TCE_TIMING3(x).U = (v))
#define HW_EPDC_TCE_TIMING3_SET(x, v) ((*(uint32_t *) HW_EPDC_TCE_TIMING3_SET_ADDR(x)) = (v))
#define HW_EPDC_TCE_TIMING3_CLR(x, v) ((*(uint32_t *) HW_EPDC_TCE_TIMING3_CLR_ADDR(x)) = (v))
#define HW_EPDC_TCE_TIMING3_TOG(x, v) ((*(uint32_t *) HW_EPDC_TCE_TIMING3_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_TCE_TIMING3 bitfields
 */

/*!
 * @name Register EPDC_TCE_TIMING3, field GDCLK_OFFSET[15:0] (RW)
 *
 * This register allows the user to shift the GDCLK from the line time by N
 * PIXCLK cycles.
 */
/*@{*/
#define BP_EPDC_TCE_TIMING3_GDCLK_OFFSET (0U) /*!< Bit position for EPDC_TCE_TIMING3_GDCLK_OFFSET. */
#define BM_EPDC_TCE_TIMING3_GDCLK_OFFSET (0x0000FFFFU) /*!< Bit mask for EPDC_TCE_TIMING3_GDCLK_OFFSET. */
#define BS_EPDC_TCE_TIMING3_GDCLK_OFFSET (16U) /*!< Bit field size in bits for EPDC_TCE_TIMING3_GDCLK_OFFSET. */

/*! @brief Read current value of the EPDC_TCE_TIMING3_GDCLK_OFFSET field. */
#define BR_EPDC_TCE_TIMING3_GDCLK_OFFSET(x) (HW_EPDC_TCE_TIMING3(x).B.GDCLK_OFFSET)

/*! @brief Format value for bitfield EPDC_TCE_TIMING3_GDCLK_OFFSET. */
#define BF_EPDC_TCE_TIMING3_GDCLK_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_TIMING3_GDCLK_OFFSET) & BM_EPDC_TCE_TIMING3_GDCLK_OFFSET)

/*! @brief Set the GDCLK_OFFSET field to a new value. */
#define BW_EPDC_TCE_TIMING3_GDCLK_OFFSET(x, v) (HW_EPDC_TCE_TIMING3_WR(x, (HW_EPDC_TCE_TIMING3_RD(x) & ~BM_EPDC_TCE_TIMING3_GDCLK_OFFSET) | BF_EPDC_TCE_TIMING3_GDCLK_OFFSET(v)))
/*@}*/

/*!
 * @name Register EPDC_TCE_TIMING3, field GDOE_OFFSET[31:16] (RW)
 *
 * When using GDOE_MODE=1, this register sets the delay from GDCLK to the GDOE
 * in terms of N PIXCLK cycles
 */
/*@{*/
#define BP_EPDC_TCE_TIMING3_GDOE_OFFSET (16U) /*!< Bit position for EPDC_TCE_TIMING3_GDOE_OFFSET. */
#define BM_EPDC_TCE_TIMING3_GDOE_OFFSET (0xFFFF0000U) /*!< Bit mask for EPDC_TCE_TIMING3_GDOE_OFFSET. */
#define BS_EPDC_TCE_TIMING3_GDOE_OFFSET (16U) /*!< Bit field size in bits for EPDC_TCE_TIMING3_GDOE_OFFSET. */

/*! @brief Read current value of the EPDC_TCE_TIMING3_GDOE_OFFSET field. */
#define BR_EPDC_TCE_TIMING3_GDOE_OFFSET(x) (HW_EPDC_TCE_TIMING3(x).B.GDOE_OFFSET)

/*! @brief Format value for bitfield EPDC_TCE_TIMING3_GDOE_OFFSET. */
#define BF_EPDC_TCE_TIMING3_GDOE_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_TCE_TIMING3_GDOE_OFFSET) & BM_EPDC_TCE_TIMING3_GDOE_OFFSET)

/*! @brief Set the GDOE_OFFSET field to a new value. */
#define BW_EPDC_TCE_TIMING3_GDOE_OFFSET(x, v) (HW_EPDC_TCE_TIMING3_WR(x, (HW_EPDC_TCE_TIMING3_RD(x) & ~BM_EPDC_TCE_TIMING3_GDOE_OFFSET) | BF_EPDC_TCE_TIMING3_GDOE_OFFSET(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_PIGEON_CTRL0 - EPDC Pigeon Mode Control Register 0
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_CTRL0 - EPDC Pigeon Mode Control Register 0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains global counter settings for Pigeon Mode This register
 * houses general purpose timing adjustment registers
 */
typedef union _hw_epdc_pigeon_ctrl0
{
    uint32_t U;
    struct _hw_epdc_pigeon_ctrl0_bitfields
    {
        uint32_t FD_PERIOD : 12;       /*!< [11:0]  */
        uint32_t RESERVED0 : 4;        /*!< [15:12]  */
        uint32_t LD_PERIOD : 12;       /*!< [27:16]  */
        uint32_t RESERVED1 : 4;        /*!< [31:28]  */
    } B;
} hw_epdc_pigeon_ctrl0_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_CTRL0 register
 */
/*@{*/
#define HW_EPDC_PIGEON_CTRL0_ADDR(x) ((uintptr_t)(x) + 0x380U)
#define HW_EPDC_PIGEON_CTRL0_SET_ADDR(x) (HW_EPDC_PIGEON_CTRL0_ADDR(x) + 0x4U)
#define HW_EPDC_PIGEON_CTRL0_CLR_ADDR(x) (HW_EPDC_PIGEON_CTRL0_ADDR(x) + 0x8U)
#define HW_EPDC_PIGEON_CTRL0_TOG_ADDR(x) (HW_EPDC_PIGEON_CTRL0_ADDR(x) + 0xCU)

#define HW_EPDC_PIGEON_CTRL0(x)  (*(__IO hw_epdc_pigeon_ctrl0_t *) HW_EPDC_PIGEON_CTRL0_ADDR(x))
#define HW_EPDC_PIGEON_CTRL0_RD(x) (HW_EPDC_PIGEON_CTRL0(x).U)
#define HW_EPDC_PIGEON_CTRL0_WR(x, v) (HW_EPDC_PIGEON_CTRL0(x).U = (v))
#define HW_EPDC_PIGEON_CTRL0_SET(x, v) ((*(uint32_t *) HW_EPDC_PIGEON_CTRL0_SET_ADDR(x)) = (v))
#define HW_EPDC_PIGEON_CTRL0_CLR(x, v) ((*(uint32_t *) HW_EPDC_PIGEON_CTRL0_CLR_ADDR(x)) = (v))
#define HW_EPDC_PIGEON_CTRL0_TOG(x, v) ((*(uint32_t *) HW_EPDC_PIGEON_CTRL0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_CTRL0 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_CTRL0, field FD_PERIOD[11:0] (RW)
 *
 * period of line counter during FD phase
 */
/*@{*/
#define BP_EPDC_PIGEON_CTRL0_FD_PERIOD (0U) /*!< Bit position for EPDC_PIGEON_CTRL0_FD_PERIOD. */
#define BM_EPDC_PIGEON_CTRL0_FD_PERIOD (0x00000FFFU) /*!< Bit mask for EPDC_PIGEON_CTRL0_FD_PERIOD. */
#define BS_EPDC_PIGEON_CTRL0_FD_PERIOD (12U) /*!< Bit field size in bits for EPDC_PIGEON_CTRL0_FD_PERIOD. */

/*! @brief Read current value of the EPDC_PIGEON_CTRL0_FD_PERIOD field. */
#define BR_EPDC_PIGEON_CTRL0_FD_PERIOD(x) (HW_EPDC_PIGEON_CTRL0(x).B.FD_PERIOD)

/*! @brief Format value for bitfield EPDC_PIGEON_CTRL0_FD_PERIOD. */
#define BF_EPDC_PIGEON_CTRL0_FD_PERIOD(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_CTRL0_FD_PERIOD) & BM_EPDC_PIGEON_CTRL0_FD_PERIOD)

/*! @brief Set the FD_PERIOD field to a new value. */
#define BW_EPDC_PIGEON_CTRL0_FD_PERIOD(x, v) (HW_EPDC_PIGEON_CTRL0_WR(x, (HW_EPDC_PIGEON_CTRL0_RD(x) & ~BM_EPDC_PIGEON_CTRL0_FD_PERIOD) | BF_EPDC_PIGEON_CTRL0_FD_PERIOD(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_CTRL0, field LD_PERIOD[27:16] (RW)
 *
 * period of pclk counter during LD phase
 */
/*@{*/
#define BP_EPDC_PIGEON_CTRL0_LD_PERIOD (16U) /*!< Bit position for EPDC_PIGEON_CTRL0_LD_PERIOD. */
#define BM_EPDC_PIGEON_CTRL0_LD_PERIOD (0x0FFF0000U) /*!< Bit mask for EPDC_PIGEON_CTRL0_LD_PERIOD. */
#define BS_EPDC_PIGEON_CTRL0_LD_PERIOD (12U) /*!< Bit field size in bits for EPDC_PIGEON_CTRL0_LD_PERIOD. */

/*! @brief Read current value of the EPDC_PIGEON_CTRL0_LD_PERIOD field. */
#define BR_EPDC_PIGEON_CTRL0_LD_PERIOD(x) (HW_EPDC_PIGEON_CTRL0(x).B.LD_PERIOD)

/*! @brief Format value for bitfield EPDC_PIGEON_CTRL0_LD_PERIOD. */
#define BF_EPDC_PIGEON_CTRL0_LD_PERIOD(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_CTRL0_LD_PERIOD) & BM_EPDC_PIGEON_CTRL0_LD_PERIOD)

/*! @brief Set the LD_PERIOD field to a new value. */
#define BW_EPDC_PIGEON_CTRL0_LD_PERIOD(x, v) (HW_EPDC_PIGEON_CTRL0_WR(x, (HW_EPDC_PIGEON_CTRL0_RD(x) & ~BM_EPDC_PIGEON_CTRL0_LD_PERIOD) | BF_EPDC_PIGEON_CTRL0_LD_PERIOD(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_PIGEON_CTRL1 - EPDC Pigeon Mode Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_CTRL1 - EPDC Pigeon Mode Control Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains global counter setting for pigeon mode This register
 * houses general purpose timing adjustment registers
 */
typedef union _hw_epdc_pigeon_ctrl1
{
    uint32_t U;
    struct _hw_epdc_pigeon_ctrl1_bitfields
    {
        uint32_t FRAME_CNT_PERIOD : 12; /*!< [11:0]  */
        uint32_t RESERVED0 : 4;        /*!< [15:12]  */
        uint32_t FRAME_CNT_CYCLES : 12; /*!< [27:16]  */
        uint32_t RESERVED1 : 4;        /*!< [31:28]  */
    } B;
} hw_epdc_pigeon_ctrl1_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_CTRL1 register
 */
/*@{*/
#define HW_EPDC_PIGEON_CTRL1_ADDR(x) ((uintptr_t)(x) + 0x390U)
#define HW_EPDC_PIGEON_CTRL1_SET_ADDR(x) (HW_EPDC_PIGEON_CTRL1_ADDR(x) + 0x4U)
#define HW_EPDC_PIGEON_CTRL1_CLR_ADDR(x) (HW_EPDC_PIGEON_CTRL1_ADDR(x) + 0x8U)
#define HW_EPDC_PIGEON_CTRL1_TOG_ADDR(x) (HW_EPDC_PIGEON_CTRL1_ADDR(x) + 0xCU)

#define HW_EPDC_PIGEON_CTRL1(x)  (*(__IO hw_epdc_pigeon_ctrl1_t *) HW_EPDC_PIGEON_CTRL1_ADDR(x))
#define HW_EPDC_PIGEON_CTRL1_RD(x) (HW_EPDC_PIGEON_CTRL1(x).U)
#define HW_EPDC_PIGEON_CTRL1_WR(x, v) (HW_EPDC_PIGEON_CTRL1(x).U = (v))
#define HW_EPDC_PIGEON_CTRL1_SET(x, v) ((*(uint32_t *) HW_EPDC_PIGEON_CTRL1_SET_ADDR(x)) = (v))
#define HW_EPDC_PIGEON_CTRL1_CLR(x, v) ((*(uint32_t *) HW_EPDC_PIGEON_CTRL1_CLR_ADDR(x)) = (v))
#define HW_EPDC_PIGEON_CTRL1_TOG(x, v) ((*(uint32_t *) HW_EPDC_PIGEON_CTRL1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_CTRL1 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_CTRL1, field FRAME_CNT_PERIOD[11:0] (RW)
 *
 * period of frame counter
 */
/*@{*/
#define BP_EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD (0U) /*!< Bit position for EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD. */
#define BM_EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD (0x00000FFFU) /*!< Bit mask for EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD. */
#define BS_EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD (12U) /*!< Bit field size in bits for EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD. */

/*! @brief Read current value of the EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD field. */
#define BR_EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD(x) (HW_EPDC_PIGEON_CTRL1(x).B.FRAME_CNT_PERIOD)

/*! @brief Format value for bitfield EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD. */
#define BF_EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD) & BM_EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD)

/*! @brief Set the FRAME_CNT_PERIOD field to a new value. */
#define BW_EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD(x, v) (HW_EPDC_PIGEON_CTRL1_WR(x, (HW_EPDC_PIGEON_CTRL1_RD(x) & ~BM_EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD) | BF_EPDC_PIGEON_CTRL1_FRAME_CNT_PERIOD(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_CTRL1, field FRAME_CNT_CYCLES[27:16] (RW)
 *
 * max cycles of frame counter
 */
/*@{*/
#define BP_EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES (16U) /*!< Bit position for EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES. */
#define BM_EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES (0x0FFF0000U) /*!< Bit mask for EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES. */
#define BS_EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES (12U) /*!< Bit field size in bits for EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES. */

/*! @brief Read current value of the EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES field. */
#define BR_EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES(x) (HW_EPDC_PIGEON_CTRL1(x).B.FRAME_CNT_CYCLES)

/*! @brief Format value for bitfield EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES. */
#define BF_EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES) & BM_EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES)

/*! @brief Set the FRAME_CNT_CYCLES field to a new value. */
#define BW_EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES(x, v) (HW_EPDC_PIGEON_CTRL1_WR(x, (HW_EPDC_PIGEON_CTRL1_RD(x) & ~BM_EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES) | BF_EPDC_PIGEON_CTRL1_FRAME_CNT_CYCLES(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_IRQ_MASK1 - EPDC IRQ Mask Register for LUT 0~31
 ******************************************************************************/

/*!
 * @brief HW_EPDC_IRQ_MASK1 - EPDC IRQ Mask Register for LUT 0~31 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Controls masking EPDC LUT complete interrupts This register controls LUT0~31
 * IRQ masks for EPDC interrupts
 */
typedef union _hw_epdc_irq_mask1
{
    uint32_t U;
    struct _hw_epdc_irq_mask1_bitfields
    {
        uint32_t LUTN_CMPLT_IRQ_EN : 32; /*!< [31:0]  */
    } B;
} hw_epdc_irq_mask1_t;

/*!
 * @name Constants and macros for entire EPDC_IRQ_MASK1 register
 */
/*@{*/
#define HW_EPDC_IRQ_MASK1_ADDR(x) ((uintptr_t)(x) + 0x3C0U)
#define HW_EPDC_IRQ_MASK1_SET_ADDR(x) (HW_EPDC_IRQ_MASK1_ADDR(x) + 0x4U)
#define HW_EPDC_IRQ_MASK1_CLR_ADDR(x) (HW_EPDC_IRQ_MASK1_ADDR(x) + 0x8U)
#define HW_EPDC_IRQ_MASK1_TOG_ADDR(x) (HW_EPDC_IRQ_MASK1_ADDR(x) + 0xCU)

#define HW_EPDC_IRQ_MASK1(x)     (*(__IO hw_epdc_irq_mask1_t *) HW_EPDC_IRQ_MASK1_ADDR(x))
#define HW_EPDC_IRQ_MASK1_RD(x)  (HW_EPDC_IRQ_MASK1(x).U)
#define HW_EPDC_IRQ_MASK1_WR(x, v) (HW_EPDC_IRQ_MASK1(x).U = (v))
#define HW_EPDC_IRQ_MASK1_SET(x, v) ((*(uint32_t *) HW_EPDC_IRQ_MASK1_SET_ADDR(x)) = (v))
#define HW_EPDC_IRQ_MASK1_CLR(x, v) ((*(uint32_t *) HW_EPDC_IRQ_MASK1_CLR_ADDR(x)) = (v))
#define HW_EPDC_IRQ_MASK1_TOG(x, v) ((*(uint32_t *) HW_EPDC_IRQ_MASK1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_IRQ_MASK1 bitfields
 */

/*!
 * @name Register EPDC_IRQ_MASK1, field LUTN_CMPLT_IRQ_EN[31:0] (RW)
 *
 * LUT0~31 Complete Interrupt Enable
 */
/*@{*/
#define BP_EPDC_IRQ_MASK1_LUTN_CMPLT_IRQ_EN (0U) /*!< Bit position for EPDC_IRQ_MASK1_LUTN_CMPLT_IRQ_EN. */
#define BM_EPDC_IRQ_MASK1_LUTN_CMPLT_IRQ_EN (0xFFFFFFFFU) /*!< Bit mask for EPDC_IRQ_MASK1_LUTN_CMPLT_IRQ_EN. */
#define BS_EPDC_IRQ_MASK1_LUTN_CMPLT_IRQ_EN (32U) /*!< Bit field size in bits for EPDC_IRQ_MASK1_LUTN_CMPLT_IRQ_EN. */

/*! @brief Read current value of the EPDC_IRQ_MASK1_LUTN_CMPLT_IRQ_EN field. */
#define BR_EPDC_IRQ_MASK1_LUTN_CMPLT_IRQ_EN(x) (HW_EPDC_IRQ_MASK1(x).U)

/*! @brief Format value for bitfield EPDC_IRQ_MASK1_LUTN_CMPLT_IRQ_EN. */
#define BF_EPDC_IRQ_MASK1_LUTN_CMPLT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ_MASK1_LUTN_CMPLT_IRQ_EN) & BM_EPDC_IRQ_MASK1_LUTN_CMPLT_IRQ_EN)

/*! @brief Set the LUTN_CMPLT_IRQ_EN field to a new value. */
#define BW_EPDC_IRQ_MASK1_LUTN_CMPLT_IRQ_EN(x, v) (HW_EPDC_IRQ_MASK1_WR(x, v))
/*@}*/




/*******************************************************************************
 * HW_EPDC_IRQ_MASK2 - EPDC IRQ Mask Register for LUT 32~63
 ******************************************************************************/

/*!
 * @brief HW_EPDC_IRQ_MASK2 - EPDC IRQ Mask Register for LUT 32~63 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Controls masking EPDC LUT complete interrupts This register controls LUT0~31
 * IRQ masks for EPDC interrupts
 */
typedef union _hw_epdc_irq_mask2
{
    uint32_t U;
    struct _hw_epdc_irq_mask2_bitfields
    {
        uint32_t LUTN_CMPLT_IRQ_EN : 32; /*!< [31:0]  */
    } B;
} hw_epdc_irq_mask2_t;

/*!
 * @name Constants and macros for entire EPDC_IRQ_MASK2 register
 */
/*@{*/
#define HW_EPDC_IRQ_MASK2_ADDR(x) ((uintptr_t)(x) + 0x3D0U)
#define HW_EPDC_IRQ_MASK2_SET_ADDR(x) (HW_EPDC_IRQ_MASK2_ADDR(x) + 0x4U)
#define HW_EPDC_IRQ_MASK2_CLR_ADDR(x) (HW_EPDC_IRQ_MASK2_ADDR(x) + 0x8U)
#define HW_EPDC_IRQ_MASK2_TOG_ADDR(x) (HW_EPDC_IRQ_MASK2_ADDR(x) + 0xCU)

#define HW_EPDC_IRQ_MASK2(x)     (*(__IO hw_epdc_irq_mask2_t *) HW_EPDC_IRQ_MASK2_ADDR(x))
#define HW_EPDC_IRQ_MASK2_RD(x)  (HW_EPDC_IRQ_MASK2(x).U)
#define HW_EPDC_IRQ_MASK2_WR(x, v) (HW_EPDC_IRQ_MASK2(x).U = (v))
#define HW_EPDC_IRQ_MASK2_SET(x, v) ((*(uint32_t *) HW_EPDC_IRQ_MASK2_SET_ADDR(x)) = (v))
#define HW_EPDC_IRQ_MASK2_CLR(x, v) ((*(uint32_t *) HW_EPDC_IRQ_MASK2_CLR_ADDR(x)) = (v))
#define HW_EPDC_IRQ_MASK2_TOG(x, v) ((*(uint32_t *) HW_EPDC_IRQ_MASK2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_IRQ_MASK2 bitfields
 */

/*!
 * @name Register EPDC_IRQ_MASK2, field LUTN_CMPLT_IRQ_EN[31:0] (RW)
 *
 * LUT32~64 Complete Interrupt Enable
 */
/*@{*/
#define BP_EPDC_IRQ_MASK2_LUTN_CMPLT_IRQ_EN (0U) /*!< Bit position for EPDC_IRQ_MASK2_LUTN_CMPLT_IRQ_EN. */
#define BM_EPDC_IRQ_MASK2_LUTN_CMPLT_IRQ_EN (0xFFFFFFFFU) /*!< Bit mask for EPDC_IRQ_MASK2_LUTN_CMPLT_IRQ_EN. */
#define BS_EPDC_IRQ_MASK2_LUTN_CMPLT_IRQ_EN (32U) /*!< Bit field size in bits for EPDC_IRQ_MASK2_LUTN_CMPLT_IRQ_EN. */

/*! @brief Read current value of the EPDC_IRQ_MASK2_LUTN_CMPLT_IRQ_EN field. */
#define BR_EPDC_IRQ_MASK2_LUTN_CMPLT_IRQ_EN(x) (HW_EPDC_IRQ_MASK2(x).U)

/*! @brief Format value for bitfield EPDC_IRQ_MASK2_LUTN_CMPLT_IRQ_EN. */
#define BF_EPDC_IRQ_MASK2_LUTN_CMPLT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ_MASK2_LUTN_CMPLT_IRQ_EN) & BM_EPDC_IRQ_MASK2_LUTN_CMPLT_IRQ_EN)

/*! @brief Set the LUTN_CMPLT_IRQ_EN field to a new value. */
#define BW_EPDC_IRQ_MASK2_LUTN_CMPLT_IRQ_EN(x, v) (HW_EPDC_IRQ_MASK2_WR(x, v))
/*@}*/




/*******************************************************************************
 * HW_EPDC_IRQ1 - EPDC Interrupt Register for LUT 0~31
 ******************************************************************************/

/*!
 * @brief HW_EPDC_IRQ1 - EPDC Interrupt Register for LUT 0~31 (RW)
 *
 * Reset value: 0x00000000U
 *
 * EPDC LUT Completion IRQs. The IRQ for a specific LUT is triggered when it's
 * corrrsponding physical update is competed on the screen. Each interrupt has a
 * corresponding mask register in EPDC_IRQ_MASK This register houses the interrupt
 * bits for the LUT Completions
 */
typedef union _hw_epdc_irq1
{
    uint32_t U;
    struct _hw_epdc_irq1_bitfields
    {
        uint32_t LUTN_CMPLT_IRQ : 32;  /*!< [31:0]  */
    } B;
} hw_epdc_irq1_t;

/*!
 * @name Constants and macros for entire EPDC_IRQ1 register
 */
/*@{*/
#define HW_EPDC_IRQ1_ADDR(x)     ((uintptr_t)(x) + 0x3E0U)
#define HW_EPDC_IRQ1_SET_ADDR(x) (HW_EPDC_IRQ1_ADDR(x) + 0x4U)
#define HW_EPDC_IRQ1_CLR_ADDR(x) (HW_EPDC_IRQ1_ADDR(x) + 0x8U)
#define HW_EPDC_IRQ1_TOG_ADDR(x) (HW_EPDC_IRQ1_ADDR(x) + 0xCU)

#define HW_EPDC_IRQ1(x)          (*(__IO hw_epdc_irq1_t *) HW_EPDC_IRQ1_ADDR(x))
#define HW_EPDC_IRQ1_RD(x)       (HW_EPDC_IRQ1(x).U)
#define HW_EPDC_IRQ1_WR(x, v)    (HW_EPDC_IRQ1(x).U = (v))
#define HW_EPDC_IRQ1_SET(x, v)   ((*(uint32_t *) HW_EPDC_IRQ1_SET_ADDR(x)) = (v))
#define HW_EPDC_IRQ1_CLR(x, v)   ((*(uint32_t *) HW_EPDC_IRQ1_CLR_ADDR(x)) = (v))
#define HW_EPDC_IRQ1_TOG(x, v)   ((*(uint32_t *) HW_EPDC_IRQ1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_IRQ1 bitfields
 */

/*!
 * @name Register EPDC_IRQ1, field LUTN_CMPLT_IRQ[31:0] (RW)
 *
 * LUT 0~31 Complete Interrupt
 */
/*@{*/
#define BP_EPDC_IRQ1_LUTN_CMPLT_IRQ (0U)   /*!< Bit position for EPDC_IRQ1_LUTN_CMPLT_IRQ. */
#define BM_EPDC_IRQ1_LUTN_CMPLT_IRQ (0xFFFFFFFFU) /*!< Bit mask for EPDC_IRQ1_LUTN_CMPLT_IRQ. */
#define BS_EPDC_IRQ1_LUTN_CMPLT_IRQ (32U)  /*!< Bit field size in bits for EPDC_IRQ1_LUTN_CMPLT_IRQ. */

/*! @brief Read current value of the EPDC_IRQ1_LUTN_CMPLT_IRQ field. */
#define BR_EPDC_IRQ1_LUTN_CMPLT_IRQ(x) (HW_EPDC_IRQ1(x).U)

/*! @brief Format value for bitfield EPDC_IRQ1_LUTN_CMPLT_IRQ. */
#define BF_EPDC_IRQ1_LUTN_CMPLT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ1_LUTN_CMPLT_IRQ) & BM_EPDC_IRQ1_LUTN_CMPLT_IRQ)

/*! @brief Set the LUTN_CMPLT_IRQ field to a new value. */
#define BW_EPDC_IRQ1_LUTN_CMPLT_IRQ(x, v) (HW_EPDC_IRQ1_WR(x, v))
/*@}*/




/*******************************************************************************
 * HW_EPDC_IRQ2 - EPDC Interrupt Registerr for LUT 32~63
 ******************************************************************************/

/*!
 * @brief HW_EPDC_IRQ2 - EPDC Interrupt Registerr for LUT 32~63 (RW)
 *
 * Reset value: 0x00000000U
 *
 * EPDC LUT Completion IRQs. The IRQ for a specific LUT is triggered when it's
 * corrrsponding physical update is competed on the screen. Each interrupt has a
 * corresponding mask register in EPDC_IRQ_MASK This register houses the interrupt
 * bits for the LUT Completions
 */
typedef union _hw_epdc_irq2
{
    uint32_t U;
    struct _hw_epdc_irq2_bitfields
    {
        uint32_t LUTN_CMPLT_IRQ : 32;  /*!< [31:0]  */
    } B;
} hw_epdc_irq2_t;

/*!
 * @name Constants and macros for entire EPDC_IRQ2 register
 */
/*@{*/
#define HW_EPDC_IRQ2_ADDR(x)     ((uintptr_t)(x) + 0x3F0U)
#define HW_EPDC_IRQ2_SET_ADDR(x) (HW_EPDC_IRQ2_ADDR(x) + 0x4U)
#define HW_EPDC_IRQ2_CLR_ADDR(x) (HW_EPDC_IRQ2_ADDR(x) + 0x8U)
#define HW_EPDC_IRQ2_TOG_ADDR(x) (HW_EPDC_IRQ2_ADDR(x) + 0xCU)

#define HW_EPDC_IRQ2(x)          (*(__IO hw_epdc_irq2_t *) HW_EPDC_IRQ2_ADDR(x))
#define HW_EPDC_IRQ2_RD(x)       (HW_EPDC_IRQ2(x).U)
#define HW_EPDC_IRQ2_WR(x, v)    (HW_EPDC_IRQ2(x).U = (v))
#define HW_EPDC_IRQ2_SET(x, v)   ((*(uint32_t *) HW_EPDC_IRQ2_SET_ADDR(x)) = (v))
#define HW_EPDC_IRQ2_CLR(x, v)   ((*(uint32_t *) HW_EPDC_IRQ2_CLR_ADDR(x)) = (v))
#define HW_EPDC_IRQ2_TOG(x, v)   ((*(uint32_t *) HW_EPDC_IRQ2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_IRQ2 bitfields
 */

/*!
 * @name Register EPDC_IRQ2, field LUTN_CMPLT_IRQ[31:0] (RW)
 *
 * LUT 32~64 Complete Interrupt
 */
/*@{*/
#define BP_EPDC_IRQ2_LUTN_CMPLT_IRQ (0U)   /*!< Bit position for EPDC_IRQ2_LUTN_CMPLT_IRQ. */
#define BM_EPDC_IRQ2_LUTN_CMPLT_IRQ (0xFFFFFFFFU) /*!< Bit mask for EPDC_IRQ2_LUTN_CMPLT_IRQ. */
#define BS_EPDC_IRQ2_LUTN_CMPLT_IRQ (32U)  /*!< Bit field size in bits for EPDC_IRQ2_LUTN_CMPLT_IRQ. */

/*! @brief Read current value of the EPDC_IRQ2_LUTN_CMPLT_IRQ field. */
#define BR_EPDC_IRQ2_LUTN_CMPLT_IRQ(x) (HW_EPDC_IRQ2(x).U)

/*! @brief Format value for bitfield EPDC_IRQ2_LUTN_CMPLT_IRQ. */
#define BF_EPDC_IRQ2_LUTN_CMPLT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ2_LUTN_CMPLT_IRQ) & BM_EPDC_IRQ2_LUTN_CMPLT_IRQ)

/*! @brief Set the LUTN_CMPLT_IRQ field to a new value. */
#define BW_EPDC_IRQ2_LUTN_CMPLT_IRQ(x, v) (HW_EPDC_IRQ2_WR(x, v))
/*@}*/




/*******************************************************************************
 * HW_EPDC_IRQ_MASK - EPDC IRQ Mask Register
 ******************************************************************************/

/*!
 * @brief HW_EPDC_IRQ_MASK - EPDC IRQ Mask Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Controls masking for all EPDC interrupts This register controls IRQ masks for
 * all EPDC interrupts
 */
typedef union _hw_epdc_irq_mask
{
    uint32_t U;
    struct _hw_epdc_irq_mask_bitfields
    {
        uint32_t RESERVED0 : 16;       /*!< [15:0]  */
        uint32_t WB_CMPLT_IRQ_EN : 1;  /*!< [16]  */
        uint32_t COL_IRQ_EN : 1;       /*!< [17]  */
        uint32_t TCE_UNDERRUN_IRQ_EN : 1; /*!< [18]  */
        uint32_t FRAME_END_IRQ_EN : 1; /*!< [19]  */
        uint32_t BUS_ERROR_IRQ_EN : 1; /*!< [20]  */
        uint32_t TCE_IDLE_IRQ_EN : 1;  /*!< [21]  */
        uint32_t UPD_DONE_IRQ_EN : 1;  /*!< [22]  */
        uint32_t PWR_IRQ_EN : 1;       /*!< [23]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_epdc_irq_mask_t;

/*!
 * @name Constants and macros for entire EPDC_IRQ_MASK register
 */
/*@{*/
#define HW_EPDC_IRQ_MASK_ADDR(x) ((uintptr_t)(x) + 0x400U)
#define HW_EPDC_IRQ_MASK_SET_ADDR(x) (HW_EPDC_IRQ_MASK_ADDR(x) + 0x4U)
#define HW_EPDC_IRQ_MASK_CLR_ADDR(x) (HW_EPDC_IRQ_MASK_ADDR(x) + 0x8U)
#define HW_EPDC_IRQ_MASK_TOG_ADDR(x) (HW_EPDC_IRQ_MASK_ADDR(x) + 0xCU)

#define HW_EPDC_IRQ_MASK(x)      (*(__IO hw_epdc_irq_mask_t *) HW_EPDC_IRQ_MASK_ADDR(x))
#define HW_EPDC_IRQ_MASK_RD(x)   (HW_EPDC_IRQ_MASK(x).U)
#define HW_EPDC_IRQ_MASK_WR(x, v) (HW_EPDC_IRQ_MASK(x).U = (v))
#define HW_EPDC_IRQ_MASK_SET(x, v) ((*(uint32_t *) HW_EPDC_IRQ_MASK_SET_ADDR(x)) = (v))
#define HW_EPDC_IRQ_MASK_CLR(x, v) ((*(uint32_t *) HW_EPDC_IRQ_MASK_CLR_ADDR(x)) = (v))
#define HW_EPDC_IRQ_MASK_TOG(x, v) ((*(uint32_t *) HW_EPDC_IRQ_MASK_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_IRQ_MASK bitfields
 */

/*!
 * @name Register EPDC_IRQ_MASK, field WB_CMPLT_IRQ_EN[16] (RW)
 *
 * Enable WB complete interrupt
 */
/*@{*/
#define BP_EPDC_IRQ_MASK_WB_CMPLT_IRQ_EN (16U) /*!< Bit position for EPDC_IRQ_MASK_WB_CMPLT_IRQ_EN. */
#define BM_EPDC_IRQ_MASK_WB_CMPLT_IRQ_EN (0x00010000U) /*!< Bit mask for EPDC_IRQ_MASK_WB_CMPLT_IRQ_EN. */
#define BS_EPDC_IRQ_MASK_WB_CMPLT_IRQ_EN (1U) /*!< Bit field size in bits for EPDC_IRQ_MASK_WB_CMPLT_IRQ_EN. */

/*! @brief Read current value of the EPDC_IRQ_MASK_WB_CMPLT_IRQ_EN field. */
#define BR_EPDC_IRQ_MASK_WB_CMPLT_IRQ_EN(x) (HW_EPDC_IRQ_MASK(x).B.WB_CMPLT_IRQ_EN)

/*! @brief Format value for bitfield EPDC_IRQ_MASK_WB_CMPLT_IRQ_EN. */
#define BF_EPDC_IRQ_MASK_WB_CMPLT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ_MASK_WB_CMPLT_IRQ_EN) & BM_EPDC_IRQ_MASK_WB_CMPLT_IRQ_EN)

/*! @brief Set the WB_CMPLT_IRQ_EN field to a new value. */
#define BW_EPDC_IRQ_MASK_WB_CMPLT_IRQ_EN(x, v) (HW_EPDC_IRQ_MASK_WR(x, (HW_EPDC_IRQ_MASK_RD(x) & ~BM_EPDC_IRQ_MASK_WB_CMPLT_IRQ_EN) | BF_EPDC_IRQ_MASK_WB_CMPLT_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_IRQ_MASK, field COL_IRQ_EN[17] (RW)
 *
 * Enable collision detection interrupts for all LUTs
 */
/*@{*/
#define BP_EPDC_IRQ_MASK_COL_IRQ_EN (17U)  /*!< Bit position for EPDC_IRQ_MASK_COL_IRQ_EN. */
#define BM_EPDC_IRQ_MASK_COL_IRQ_EN (0x00020000U) /*!< Bit mask for EPDC_IRQ_MASK_COL_IRQ_EN. */
#define BS_EPDC_IRQ_MASK_COL_IRQ_EN (1U)   /*!< Bit field size in bits for EPDC_IRQ_MASK_COL_IRQ_EN. */

/*! @brief Read current value of the EPDC_IRQ_MASK_COL_IRQ_EN field. */
#define BR_EPDC_IRQ_MASK_COL_IRQ_EN(x) (HW_EPDC_IRQ_MASK(x).B.COL_IRQ_EN)

/*! @brief Format value for bitfield EPDC_IRQ_MASK_COL_IRQ_EN. */
#define BF_EPDC_IRQ_MASK_COL_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ_MASK_COL_IRQ_EN) & BM_EPDC_IRQ_MASK_COL_IRQ_EN)

/*! @brief Set the COL_IRQ_EN field to a new value. */
#define BW_EPDC_IRQ_MASK_COL_IRQ_EN(x, v) (HW_EPDC_IRQ_MASK_WR(x, (HW_EPDC_IRQ_MASK_RD(x) & ~BM_EPDC_IRQ_MASK_COL_IRQ_EN) | BF_EPDC_IRQ_MASK_COL_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_IRQ_MASK, field TCE_UNDERRUN_IRQ_EN[18] (RW)
 *
 * Enable pixel FIFO under-run condition detection.
 */
/*@{*/
#define BP_EPDC_IRQ_MASK_TCE_UNDERRUN_IRQ_EN (18U) /*!< Bit position for EPDC_IRQ_MASK_TCE_UNDERRUN_IRQ_EN. */
#define BM_EPDC_IRQ_MASK_TCE_UNDERRUN_IRQ_EN (0x00040000U) /*!< Bit mask for EPDC_IRQ_MASK_TCE_UNDERRUN_IRQ_EN. */
#define BS_EPDC_IRQ_MASK_TCE_UNDERRUN_IRQ_EN (1U) /*!< Bit field size in bits for EPDC_IRQ_MASK_TCE_UNDERRUN_IRQ_EN. */

/*! @brief Read current value of the EPDC_IRQ_MASK_TCE_UNDERRUN_IRQ_EN field. */
#define BR_EPDC_IRQ_MASK_TCE_UNDERRUN_IRQ_EN(x) (HW_EPDC_IRQ_MASK(x).B.TCE_UNDERRUN_IRQ_EN)

/*! @brief Format value for bitfield EPDC_IRQ_MASK_TCE_UNDERRUN_IRQ_EN. */
#define BF_EPDC_IRQ_MASK_TCE_UNDERRUN_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ_MASK_TCE_UNDERRUN_IRQ_EN) & BM_EPDC_IRQ_MASK_TCE_UNDERRUN_IRQ_EN)

/*! @brief Set the TCE_UNDERRUN_IRQ_EN field to a new value. */
#define BW_EPDC_IRQ_MASK_TCE_UNDERRUN_IRQ_EN(x, v) (HW_EPDC_IRQ_MASK_WR(x, (HW_EPDC_IRQ_MASK_RD(x) & ~BM_EPDC_IRQ_MASK_TCE_UNDERRUN_IRQ_EN) | BF_EPDC_IRQ_MASK_TCE_UNDERRUN_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_IRQ_MASK, field FRAME_END_IRQ_EN[19] (RW)
 *
 * If this bit is set, EPDC will assert the current frame end interrupt. This
 * irq is only available during updating period.
 */
/*@{*/
#define BP_EPDC_IRQ_MASK_FRAME_END_IRQ_EN (19U) /*!< Bit position for EPDC_IRQ_MASK_FRAME_END_IRQ_EN. */
#define BM_EPDC_IRQ_MASK_FRAME_END_IRQ_EN (0x00080000U) /*!< Bit mask for EPDC_IRQ_MASK_FRAME_END_IRQ_EN. */
#define BS_EPDC_IRQ_MASK_FRAME_END_IRQ_EN (1U) /*!< Bit field size in bits for EPDC_IRQ_MASK_FRAME_END_IRQ_EN. */

/*! @brief Read current value of the EPDC_IRQ_MASK_FRAME_END_IRQ_EN field. */
#define BR_EPDC_IRQ_MASK_FRAME_END_IRQ_EN(x) (HW_EPDC_IRQ_MASK(x).B.FRAME_END_IRQ_EN)

/*! @brief Format value for bitfield EPDC_IRQ_MASK_FRAME_END_IRQ_EN. */
#define BF_EPDC_IRQ_MASK_FRAME_END_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ_MASK_FRAME_END_IRQ_EN) & BM_EPDC_IRQ_MASK_FRAME_END_IRQ_EN)

/*! @brief Set the FRAME_END_IRQ_EN field to a new value. */
#define BW_EPDC_IRQ_MASK_FRAME_END_IRQ_EN(x, v) (HW_EPDC_IRQ_MASK_WR(x, (HW_EPDC_IRQ_MASK_RD(x) & ~BM_EPDC_IRQ_MASK_FRAME_END_IRQ_EN) | BF_EPDC_IRQ_MASK_FRAME_END_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_IRQ_MASK, field BUS_ERROR_IRQ_EN[20] (RW)
 *
 * Enable AXI BUS ERROR interrupt detection.
 */
/*@{*/
#define BP_EPDC_IRQ_MASK_BUS_ERROR_IRQ_EN (20U) /*!< Bit position for EPDC_IRQ_MASK_BUS_ERROR_IRQ_EN. */
#define BM_EPDC_IRQ_MASK_BUS_ERROR_IRQ_EN (0x00100000U) /*!< Bit mask for EPDC_IRQ_MASK_BUS_ERROR_IRQ_EN. */
#define BS_EPDC_IRQ_MASK_BUS_ERROR_IRQ_EN (1U) /*!< Bit field size in bits for EPDC_IRQ_MASK_BUS_ERROR_IRQ_EN. */

/*! @brief Read current value of the EPDC_IRQ_MASK_BUS_ERROR_IRQ_EN field. */
#define BR_EPDC_IRQ_MASK_BUS_ERROR_IRQ_EN(x) (HW_EPDC_IRQ_MASK(x).B.BUS_ERROR_IRQ_EN)

/*! @brief Format value for bitfield EPDC_IRQ_MASK_BUS_ERROR_IRQ_EN. */
#define BF_EPDC_IRQ_MASK_BUS_ERROR_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ_MASK_BUS_ERROR_IRQ_EN) & BM_EPDC_IRQ_MASK_BUS_ERROR_IRQ_EN)

/*! @brief Set the BUS_ERROR_IRQ_EN field to a new value. */
#define BW_EPDC_IRQ_MASK_BUS_ERROR_IRQ_EN(x, v) (HW_EPDC_IRQ_MASK_WR(x, (HW_EPDC_IRQ_MASK_RD(x) & ~BM_EPDC_IRQ_MASK_BUS_ERROR_IRQ_EN) | BF_EPDC_IRQ_MASK_BUS_ERROR_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_IRQ_MASK, field TCE_IDLE_IRQ_EN[21] (RW)
 *
 * Enable TCE Idle interrupt detection.
 */
/*@{*/
#define BP_EPDC_IRQ_MASK_TCE_IDLE_IRQ_EN (21U) /*!< Bit position for EPDC_IRQ_MASK_TCE_IDLE_IRQ_EN. */
#define BM_EPDC_IRQ_MASK_TCE_IDLE_IRQ_EN (0x00200000U) /*!< Bit mask for EPDC_IRQ_MASK_TCE_IDLE_IRQ_EN. */
#define BS_EPDC_IRQ_MASK_TCE_IDLE_IRQ_EN (1U) /*!< Bit field size in bits for EPDC_IRQ_MASK_TCE_IDLE_IRQ_EN. */

/*! @brief Read current value of the EPDC_IRQ_MASK_TCE_IDLE_IRQ_EN field. */
#define BR_EPDC_IRQ_MASK_TCE_IDLE_IRQ_EN(x) (HW_EPDC_IRQ_MASK(x).B.TCE_IDLE_IRQ_EN)

/*! @brief Format value for bitfield EPDC_IRQ_MASK_TCE_IDLE_IRQ_EN. */
#define BF_EPDC_IRQ_MASK_TCE_IDLE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ_MASK_TCE_IDLE_IRQ_EN) & BM_EPDC_IRQ_MASK_TCE_IDLE_IRQ_EN)

/*! @brief Set the TCE_IDLE_IRQ_EN field to a new value. */
#define BW_EPDC_IRQ_MASK_TCE_IDLE_IRQ_EN(x, v) (HW_EPDC_IRQ_MASK_WR(x, (HW_EPDC_IRQ_MASK_RD(x) & ~BM_EPDC_IRQ_MASK_TCE_IDLE_IRQ_EN) | BF_EPDC_IRQ_MASK_TCE_IDLE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_IRQ_MASK, field UPD_DONE_IRQ_EN[22] (RW)
 *
 * Enable UPD complete interrupt
 */
/*@{*/
#define BP_EPDC_IRQ_MASK_UPD_DONE_IRQ_EN (22U) /*!< Bit position for EPDC_IRQ_MASK_UPD_DONE_IRQ_EN. */
#define BM_EPDC_IRQ_MASK_UPD_DONE_IRQ_EN (0x00400000U) /*!< Bit mask for EPDC_IRQ_MASK_UPD_DONE_IRQ_EN. */
#define BS_EPDC_IRQ_MASK_UPD_DONE_IRQ_EN (1U) /*!< Bit field size in bits for EPDC_IRQ_MASK_UPD_DONE_IRQ_EN. */

/*! @brief Read current value of the EPDC_IRQ_MASK_UPD_DONE_IRQ_EN field. */
#define BR_EPDC_IRQ_MASK_UPD_DONE_IRQ_EN(x) (HW_EPDC_IRQ_MASK(x).B.UPD_DONE_IRQ_EN)

/*! @brief Format value for bitfield EPDC_IRQ_MASK_UPD_DONE_IRQ_EN. */
#define BF_EPDC_IRQ_MASK_UPD_DONE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ_MASK_UPD_DONE_IRQ_EN) & BM_EPDC_IRQ_MASK_UPD_DONE_IRQ_EN)

/*! @brief Set the UPD_DONE_IRQ_EN field to a new value. */
#define BW_EPDC_IRQ_MASK_UPD_DONE_IRQ_EN(x, v) (HW_EPDC_IRQ_MASK_WR(x, (HW_EPDC_IRQ_MASK_RD(x) & ~BM_EPDC_IRQ_MASK_UPD_DONE_IRQ_EN) | BF_EPDC_IRQ_MASK_UPD_DONE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_IRQ_MASK, field PWR_IRQ_EN[23] (RW)
 *
 * Enable power interrupt
 */
/*@{*/
#define BP_EPDC_IRQ_MASK_PWR_IRQ_EN (23U)  /*!< Bit position for EPDC_IRQ_MASK_PWR_IRQ_EN. */
#define BM_EPDC_IRQ_MASK_PWR_IRQ_EN (0x00800000U) /*!< Bit mask for EPDC_IRQ_MASK_PWR_IRQ_EN. */
#define BS_EPDC_IRQ_MASK_PWR_IRQ_EN (1U)   /*!< Bit field size in bits for EPDC_IRQ_MASK_PWR_IRQ_EN. */

/*! @brief Read current value of the EPDC_IRQ_MASK_PWR_IRQ_EN field. */
#define BR_EPDC_IRQ_MASK_PWR_IRQ_EN(x) (HW_EPDC_IRQ_MASK(x).B.PWR_IRQ_EN)

/*! @brief Format value for bitfield EPDC_IRQ_MASK_PWR_IRQ_EN. */
#define BF_EPDC_IRQ_MASK_PWR_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ_MASK_PWR_IRQ_EN) & BM_EPDC_IRQ_MASK_PWR_IRQ_EN)

/*! @brief Set the PWR_IRQ_EN field to a new value. */
#define BW_EPDC_IRQ_MASK_PWR_IRQ_EN(x, v) (HW_EPDC_IRQ_MASK_WR(x, (HW_EPDC_IRQ_MASK_RD(x) & ~BM_EPDC_IRQ_MASK_PWR_IRQ_EN) | BF_EPDC_IRQ_MASK_PWR_IRQ_EN(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_IRQ - EPDC Interrupt Register
 ******************************************************************************/

/*!
 * @brief HW_EPDC_IRQ - EPDC Interrupt Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * EPDC LUT Completion IRQs. The IRQ for a specific LUT is triggered when it's
 * corrrsponding physical update is competed on the screen. Each interrupt has a
 * corresponding mask register in EPDC_IRQ_MASK This register houses the interrupt
 * bits for the LUT Completions
 */
typedef union _hw_epdc_irq
{
    uint32_t U;
    struct _hw_epdc_irq_bitfields
    {
        uint32_t RESERVED0 : 16;       /*!< [15:0]  */
        uint32_t WB_CMPLT_IRQ : 1;     /*!< [16]  */
        uint32_t LUT_COL_IRQ : 1;      /*!< [17]  */
        uint32_t TCE_UNDERRUN_IRQ : 1; /*!< [18]  */
        uint32_t FRAME_END_IRQ : 1;    /*!< [19]  */
        uint32_t BUS_ERROR_IRQ : 1;    /*!< [20]  */
        uint32_t TCE_IDLE_IRQ : 1;     /*!< [21]  */
        uint32_t UPD_DONE_IRQ : 1;     /*!< [22]  */
        uint32_t PWR_IRQ : 1;          /*!< [23]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_epdc_irq_t;

/*!
 * @name Constants and macros for entire EPDC_IRQ register
 */
/*@{*/
#define HW_EPDC_IRQ_ADDR(x)      ((uintptr_t)(x) + 0x420U)
#define HW_EPDC_IRQ_SET_ADDR(x)  (HW_EPDC_IRQ_ADDR(x) + 0x4U)
#define HW_EPDC_IRQ_CLR_ADDR(x)  (HW_EPDC_IRQ_ADDR(x) + 0x8U)
#define HW_EPDC_IRQ_TOG_ADDR(x)  (HW_EPDC_IRQ_ADDR(x) + 0xCU)

#define HW_EPDC_IRQ(x)           (*(__IO hw_epdc_irq_t *) HW_EPDC_IRQ_ADDR(x))
#define HW_EPDC_IRQ_RD(x)        (HW_EPDC_IRQ(x).U)
#define HW_EPDC_IRQ_WR(x, v)     (HW_EPDC_IRQ(x).U = (v))
#define HW_EPDC_IRQ_SET(x, v)    ((*(uint32_t *) HW_EPDC_IRQ_SET_ADDR(x)) = (v))
#define HW_EPDC_IRQ_CLR(x, v)    ((*(uint32_t *) HW_EPDC_IRQ_CLR_ADDR(x)) = (v))
#define HW_EPDC_IRQ_TOG(x, v)    ((*(uint32_t *) HW_EPDC_IRQ_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_IRQ bitfields
 */

/*!
 * @name Register EPDC_IRQ, field WB_CMPLT_IRQ[16] (RW)
 *
 * Working buffer process complete Interrupt
 */
/*@{*/
#define BP_EPDC_IRQ_WB_CMPLT_IRQ (16U)     /*!< Bit position for EPDC_IRQ_WB_CMPLT_IRQ. */
#define BM_EPDC_IRQ_WB_CMPLT_IRQ (0x00010000U) /*!< Bit mask for EPDC_IRQ_WB_CMPLT_IRQ. */
#define BS_EPDC_IRQ_WB_CMPLT_IRQ (1U)      /*!< Bit field size in bits for EPDC_IRQ_WB_CMPLT_IRQ. */

/*! @brief Read current value of the EPDC_IRQ_WB_CMPLT_IRQ field. */
#define BR_EPDC_IRQ_WB_CMPLT_IRQ(x) (HW_EPDC_IRQ(x).B.WB_CMPLT_IRQ)

/*! @brief Format value for bitfield EPDC_IRQ_WB_CMPLT_IRQ. */
#define BF_EPDC_IRQ_WB_CMPLT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ_WB_CMPLT_IRQ) & BM_EPDC_IRQ_WB_CMPLT_IRQ)

/*! @brief Set the WB_CMPLT_IRQ field to a new value. */
#define BW_EPDC_IRQ_WB_CMPLT_IRQ(x, v) (HW_EPDC_IRQ_WR(x, (HW_EPDC_IRQ_RD(x) & ~BM_EPDC_IRQ_WB_CMPLT_IRQ) | BF_EPDC_IRQ_WB_CMPLT_IRQ(v)))
/*@}*/

/*!
 * @name Register EPDC_IRQ, field LUT_COL_IRQ[17] (RW)
 *
 * Collision detection interrupt. Check EPDC_STATUS_COL.
 */
/*@{*/
#define BP_EPDC_IRQ_LUT_COL_IRQ (17U)      /*!< Bit position for EPDC_IRQ_LUT_COL_IRQ. */
#define BM_EPDC_IRQ_LUT_COL_IRQ (0x00020000U) /*!< Bit mask for EPDC_IRQ_LUT_COL_IRQ. */
#define BS_EPDC_IRQ_LUT_COL_IRQ (1U)       /*!< Bit field size in bits for EPDC_IRQ_LUT_COL_IRQ. */

/*! @brief Read current value of the EPDC_IRQ_LUT_COL_IRQ field. */
#define BR_EPDC_IRQ_LUT_COL_IRQ(x) (HW_EPDC_IRQ(x).B.LUT_COL_IRQ)

/*! @brief Format value for bitfield EPDC_IRQ_LUT_COL_IRQ. */
#define BF_EPDC_IRQ_LUT_COL_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ_LUT_COL_IRQ) & BM_EPDC_IRQ_LUT_COL_IRQ)

/*! @brief Set the LUT_COL_IRQ field to a new value. */
#define BW_EPDC_IRQ_LUT_COL_IRQ(x, v) (HW_EPDC_IRQ_WR(x, (HW_EPDC_IRQ_RD(x) & ~BM_EPDC_IRQ_LUT_COL_IRQ) | BF_EPDC_IRQ_LUT_COL_IRQ(v)))
/*@}*/

/*!
 * @name Register EPDC_IRQ, field TCE_UNDERRUN_IRQ[18] (RW)
 *
 * Interrupt to indicate that a pixel FIFO under-run has occured.
 */
/*@{*/
#define BP_EPDC_IRQ_TCE_UNDERRUN_IRQ (18U) /*!< Bit position for EPDC_IRQ_TCE_UNDERRUN_IRQ. */
#define BM_EPDC_IRQ_TCE_UNDERRUN_IRQ (0x00040000U) /*!< Bit mask for EPDC_IRQ_TCE_UNDERRUN_IRQ. */
#define BS_EPDC_IRQ_TCE_UNDERRUN_IRQ (1U)  /*!< Bit field size in bits for EPDC_IRQ_TCE_UNDERRUN_IRQ. */

/*! @brief Read current value of the EPDC_IRQ_TCE_UNDERRUN_IRQ field. */
#define BR_EPDC_IRQ_TCE_UNDERRUN_IRQ(x) (HW_EPDC_IRQ(x).B.TCE_UNDERRUN_IRQ)

/*! @brief Format value for bitfield EPDC_IRQ_TCE_UNDERRUN_IRQ. */
#define BF_EPDC_IRQ_TCE_UNDERRUN_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ_TCE_UNDERRUN_IRQ) & BM_EPDC_IRQ_TCE_UNDERRUN_IRQ)

/*! @brief Set the TCE_UNDERRUN_IRQ field to a new value. */
#define BW_EPDC_IRQ_TCE_UNDERRUN_IRQ(x, v) (HW_EPDC_IRQ_WR(x, (HW_EPDC_IRQ_RD(x) & ~BM_EPDC_IRQ_TCE_UNDERRUN_IRQ) | BF_EPDC_IRQ_TCE_UNDERRUN_IRQ(v)))
/*@}*/

/*!
 * @name Register EPDC_IRQ, field FRAME_END_IRQ[19] (RW)
 *
 * Interrupt to indicate EPDC has completed the current frame and is in the
 * vertical blanking period.
 */
/*@{*/
#define BP_EPDC_IRQ_FRAME_END_IRQ (19U)    /*!< Bit position for EPDC_IRQ_FRAME_END_IRQ. */
#define BM_EPDC_IRQ_FRAME_END_IRQ (0x00080000U) /*!< Bit mask for EPDC_IRQ_FRAME_END_IRQ. */
#define BS_EPDC_IRQ_FRAME_END_IRQ (1U)     /*!< Bit field size in bits for EPDC_IRQ_FRAME_END_IRQ. */

/*! @brief Read current value of the EPDC_IRQ_FRAME_END_IRQ field. */
#define BR_EPDC_IRQ_FRAME_END_IRQ(x) (HW_EPDC_IRQ(x).B.FRAME_END_IRQ)

/*! @brief Format value for bitfield EPDC_IRQ_FRAME_END_IRQ. */
#define BF_EPDC_IRQ_FRAME_END_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ_FRAME_END_IRQ) & BM_EPDC_IRQ_FRAME_END_IRQ)

/*! @brief Set the FRAME_END_IRQ field to a new value. */
#define BW_EPDC_IRQ_FRAME_END_IRQ(x, v) (HW_EPDC_IRQ_WR(x, (HW_EPDC_IRQ_RD(x) & ~BM_EPDC_IRQ_FRAME_END_IRQ) | BF_EPDC_IRQ_FRAME_END_IRQ(v)))
/*@}*/

/*!
 * @name Register EPDC_IRQ, field BUS_ERROR_IRQ[20] (RW)
 *
 * Interrupt to indicate AXI BUS error occurs.
 */
/*@{*/
#define BP_EPDC_IRQ_BUS_ERROR_IRQ (20U)    /*!< Bit position for EPDC_IRQ_BUS_ERROR_IRQ. */
#define BM_EPDC_IRQ_BUS_ERROR_IRQ (0x00100000U) /*!< Bit mask for EPDC_IRQ_BUS_ERROR_IRQ. */
#define BS_EPDC_IRQ_BUS_ERROR_IRQ (1U)     /*!< Bit field size in bits for EPDC_IRQ_BUS_ERROR_IRQ. */

/*! @brief Read current value of the EPDC_IRQ_BUS_ERROR_IRQ field. */
#define BR_EPDC_IRQ_BUS_ERROR_IRQ(x) (HW_EPDC_IRQ(x).B.BUS_ERROR_IRQ)

/*! @brief Format value for bitfield EPDC_IRQ_BUS_ERROR_IRQ. */
#define BF_EPDC_IRQ_BUS_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ_BUS_ERROR_IRQ) & BM_EPDC_IRQ_BUS_ERROR_IRQ)

/*! @brief Set the BUS_ERROR_IRQ field to a new value. */
#define BW_EPDC_IRQ_BUS_ERROR_IRQ(x, v) (HW_EPDC_IRQ_WR(x, (HW_EPDC_IRQ_RD(x) & ~BM_EPDC_IRQ_BUS_ERROR_IRQ) | BF_EPDC_IRQ_BUS_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register EPDC_IRQ, field TCE_IDLE_IRQ[21] (RW)
 *
 * Interrupt to indicate that the TCE has completed TFT frame scans and is in an
 * idle state.
 */
/*@{*/
#define BP_EPDC_IRQ_TCE_IDLE_IRQ (21U)     /*!< Bit position for EPDC_IRQ_TCE_IDLE_IRQ. */
#define BM_EPDC_IRQ_TCE_IDLE_IRQ (0x00200000U) /*!< Bit mask for EPDC_IRQ_TCE_IDLE_IRQ. */
#define BS_EPDC_IRQ_TCE_IDLE_IRQ (1U)      /*!< Bit field size in bits for EPDC_IRQ_TCE_IDLE_IRQ. */

/*! @brief Read current value of the EPDC_IRQ_TCE_IDLE_IRQ field. */
#define BR_EPDC_IRQ_TCE_IDLE_IRQ(x) (HW_EPDC_IRQ(x).B.TCE_IDLE_IRQ)

/*! @brief Format value for bitfield EPDC_IRQ_TCE_IDLE_IRQ. */
#define BF_EPDC_IRQ_TCE_IDLE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ_TCE_IDLE_IRQ) & BM_EPDC_IRQ_TCE_IDLE_IRQ)

/*! @brief Set the TCE_IDLE_IRQ field to a new value. */
#define BW_EPDC_IRQ_TCE_IDLE_IRQ(x, v) (HW_EPDC_IRQ_WR(x, (HW_EPDC_IRQ_RD(x) & ~BM_EPDC_IRQ_TCE_IDLE_IRQ) | BF_EPDC_IRQ_TCE_IDLE_IRQ(v)))
/*@}*/

/*!
 * @name Register EPDC_IRQ, field UPD_DONE_IRQ[22] (RW)
 *
 * Working buffer process complete Interrupt
 */
/*@{*/
#define BP_EPDC_IRQ_UPD_DONE_IRQ (22U)     /*!< Bit position for EPDC_IRQ_UPD_DONE_IRQ. */
#define BM_EPDC_IRQ_UPD_DONE_IRQ (0x00400000U) /*!< Bit mask for EPDC_IRQ_UPD_DONE_IRQ. */
#define BS_EPDC_IRQ_UPD_DONE_IRQ (1U)      /*!< Bit field size in bits for EPDC_IRQ_UPD_DONE_IRQ. */

/*! @brief Read current value of the EPDC_IRQ_UPD_DONE_IRQ field. */
#define BR_EPDC_IRQ_UPD_DONE_IRQ(x) (HW_EPDC_IRQ(x).B.UPD_DONE_IRQ)

/*! @brief Format value for bitfield EPDC_IRQ_UPD_DONE_IRQ. */
#define BF_EPDC_IRQ_UPD_DONE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ_UPD_DONE_IRQ) & BM_EPDC_IRQ_UPD_DONE_IRQ)

/*! @brief Set the UPD_DONE_IRQ field to a new value. */
#define BW_EPDC_IRQ_UPD_DONE_IRQ(x, v) (HW_EPDC_IRQ_WR(x, (HW_EPDC_IRQ_RD(x) & ~BM_EPDC_IRQ_UPD_DONE_IRQ) | BF_EPDC_IRQ_UPD_DONE_IRQ(v)))
/*@}*/

/*!
 * @name Register EPDC_IRQ, field PWR_IRQ[23] (RW)
 *
 * Power Interrupt
 */
/*@{*/
#define BP_EPDC_IRQ_PWR_IRQ  (23U)         /*!< Bit position for EPDC_IRQ_PWR_IRQ. */
#define BM_EPDC_IRQ_PWR_IRQ  (0x00800000U) /*!< Bit mask for EPDC_IRQ_PWR_IRQ. */
#define BS_EPDC_IRQ_PWR_IRQ  (1U)          /*!< Bit field size in bits for EPDC_IRQ_PWR_IRQ. */

/*! @brief Read current value of the EPDC_IRQ_PWR_IRQ field. */
#define BR_EPDC_IRQ_PWR_IRQ(x) (HW_EPDC_IRQ(x).B.PWR_IRQ)

/*! @brief Format value for bitfield EPDC_IRQ_PWR_IRQ. */
#define BF_EPDC_IRQ_PWR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_IRQ_PWR_IRQ) & BM_EPDC_IRQ_PWR_IRQ)

/*! @brief Set the PWR_IRQ field to a new value. */
#define BW_EPDC_IRQ_PWR_IRQ(x, v) (HW_EPDC_IRQ_WR(x, (HW_EPDC_IRQ_RD(x) & ~BM_EPDC_IRQ_PWR_IRQ) | BF_EPDC_IRQ_PWR_IRQ(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_STATUS_LUTS1 - EPDC Status Register - LUTs
 ******************************************************************************/

/*!
 * @brief HW_EPDC_STATUS_LUTS1 - EPDC Status Register - LUTs (RW)
 *
 * Reset value: 0x00000000U
 *
 * EPDC Status Register - LUTS 0~31
 */
typedef union _hw_epdc_status_luts1
{
    uint32_t U;
    struct _hw_epdc_status_luts1_bitfields
    {
        uint32_t LUTN_STS : 32;        /*!< [31:0]  */
    } B;
} hw_epdc_status_luts1_t;

/*!
 * @name Constants and macros for entire EPDC_STATUS_LUTS1 register
 */
/*@{*/
#define HW_EPDC_STATUS_LUTS1_ADDR(x) ((uintptr_t)(x) + 0x440U)
#define HW_EPDC_STATUS_LUTS1_SET_ADDR(x) (HW_EPDC_STATUS_LUTS1_ADDR(x) + 0x4U)
#define HW_EPDC_STATUS_LUTS1_CLR_ADDR(x) (HW_EPDC_STATUS_LUTS1_ADDR(x) + 0x8U)
#define HW_EPDC_STATUS_LUTS1_TOG_ADDR(x) (HW_EPDC_STATUS_LUTS1_ADDR(x) + 0xCU)

#define HW_EPDC_STATUS_LUTS1(x)  (*(__IO hw_epdc_status_luts1_t *) HW_EPDC_STATUS_LUTS1_ADDR(x))
#define HW_EPDC_STATUS_LUTS1_RD(x) (HW_EPDC_STATUS_LUTS1(x).U)
#define HW_EPDC_STATUS_LUTS1_WR(x, v) (HW_EPDC_STATUS_LUTS1(x).U = (v))
#define HW_EPDC_STATUS_LUTS1_SET(x, v) ((*(uint32_t *) HW_EPDC_STATUS_LUTS1_SET_ADDR(x)) = (v))
#define HW_EPDC_STATUS_LUTS1_CLR(x, v) ((*(uint32_t *) HW_EPDC_STATUS_LUTS1_CLR_ADDR(x)) = (v))
#define HW_EPDC_STATUS_LUTS1_TOG(x, v) ((*(uint32_t *) HW_EPDC_STATUS_LUTS1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_STATUS_LUTS1 bitfields
 */

/*!
 * @name Register EPDC_STATUS_LUTS1, field LUTN_STS[31:0] (RW)
 *
 * LUT 0~31 Status : 1=ACTIVE, 0=IDLE
 */
/*@{*/
#define BP_EPDC_STATUS_LUTS1_LUTN_STS (0U) /*!< Bit position for EPDC_STATUS_LUTS1_LUTN_STS. */
#define BM_EPDC_STATUS_LUTS1_LUTN_STS (0xFFFFFFFFU) /*!< Bit mask for EPDC_STATUS_LUTS1_LUTN_STS. */
#define BS_EPDC_STATUS_LUTS1_LUTN_STS (32U) /*!< Bit field size in bits for EPDC_STATUS_LUTS1_LUTN_STS. */

/*! @brief Read current value of the EPDC_STATUS_LUTS1_LUTN_STS field. */
#define BR_EPDC_STATUS_LUTS1_LUTN_STS(x) (HW_EPDC_STATUS_LUTS1(x).U)

/*! @brief Format value for bitfield EPDC_STATUS_LUTS1_LUTN_STS. */
#define BF_EPDC_STATUS_LUTS1_LUTN_STS(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_STATUS_LUTS1_LUTN_STS) & BM_EPDC_STATUS_LUTS1_LUTN_STS)

/*! @brief Set the LUTN_STS field to a new value. */
#define BW_EPDC_STATUS_LUTS1_LUTN_STS(x, v) (HW_EPDC_STATUS_LUTS1_WR(x, v))
/*@}*/




/*******************************************************************************
 * HW_EPDC_STATUS_LUTS2 - EPDC Status Register - LUTs
 ******************************************************************************/

/*!
 * @brief HW_EPDC_STATUS_LUTS2 - EPDC Status Register - LUTs (RW)
 *
 * Reset value: 0x00000000U
 *
 * EPDC Status Register - LUTS 0~31
 */
typedef union _hw_epdc_status_luts2
{
    uint32_t U;
    struct _hw_epdc_status_luts2_bitfields
    {
        uint32_t LUTN_STS : 32;        /*!< [31:0]  */
    } B;
} hw_epdc_status_luts2_t;

/*!
 * @name Constants and macros for entire EPDC_STATUS_LUTS2 register
 */
/*@{*/
#define HW_EPDC_STATUS_LUTS2_ADDR(x) ((uintptr_t)(x) + 0x450U)
#define HW_EPDC_STATUS_LUTS2_SET_ADDR(x) (HW_EPDC_STATUS_LUTS2_ADDR(x) + 0x4U)
#define HW_EPDC_STATUS_LUTS2_CLR_ADDR(x) (HW_EPDC_STATUS_LUTS2_ADDR(x) + 0x8U)
#define HW_EPDC_STATUS_LUTS2_TOG_ADDR(x) (HW_EPDC_STATUS_LUTS2_ADDR(x) + 0xCU)

#define HW_EPDC_STATUS_LUTS2(x)  (*(__IO hw_epdc_status_luts2_t *) HW_EPDC_STATUS_LUTS2_ADDR(x))
#define HW_EPDC_STATUS_LUTS2_RD(x) (HW_EPDC_STATUS_LUTS2(x).U)
#define HW_EPDC_STATUS_LUTS2_WR(x, v) (HW_EPDC_STATUS_LUTS2(x).U = (v))
#define HW_EPDC_STATUS_LUTS2_SET(x, v) ((*(uint32_t *) HW_EPDC_STATUS_LUTS2_SET_ADDR(x)) = (v))
#define HW_EPDC_STATUS_LUTS2_CLR(x, v) ((*(uint32_t *) HW_EPDC_STATUS_LUTS2_CLR_ADDR(x)) = (v))
#define HW_EPDC_STATUS_LUTS2_TOG(x, v) ((*(uint32_t *) HW_EPDC_STATUS_LUTS2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_STATUS_LUTS2 bitfields
 */

/*!
 * @name Register EPDC_STATUS_LUTS2, field LUTN_STS[31:0] (RW)
 *
 * LUT 32~63 Status : 1=ACTIVE, 0=IDLE
 */
/*@{*/
#define BP_EPDC_STATUS_LUTS2_LUTN_STS (0U) /*!< Bit position for EPDC_STATUS_LUTS2_LUTN_STS. */
#define BM_EPDC_STATUS_LUTS2_LUTN_STS (0xFFFFFFFFU) /*!< Bit mask for EPDC_STATUS_LUTS2_LUTN_STS. */
#define BS_EPDC_STATUS_LUTS2_LUTN_STS (32U) /*!< Bit field size in bits for EPDC_STATUS_LUTS2_LUTN_STS. */

/*! @brief Read current value of the EPDC_STATUS_LUTS2_LUTN_STS field. */
#define BR_EPDC_STATUS_LUTS2_LUTN_STS(x) (HW_EPDC_STATUS_LUTS2(x).U)

/*! @brief Format value for bitfield EPDC_STATUS_LUTS2_LUTN_STS. */
#define BF_EPDC_STATUS_LUTS2_LUTN_STS(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_STATUS_LUTS2_LUTN_STS) & BM_EPDC_STATUS_LUTS2_LUTN_STS)

/*! @brief Set the LUTN_STS field to a new value. */
#define BW_EPDC_STATUS_LUTS2_LUTN_STS(x, v) (HW_EPDC_STATUS_LUTS2_WR(x, v))
/*@}*/




/*******************************************************************************
 * HW_EPDC_STATUS_NEXTLUT - EPDC Status Register - Next Available LUT
 ******************************************************************************/

/*!
 * @brief HW_EPDC_STATUS_NEXTLUT - EPDC Status Register - Next Available LUT (RO)
 *
 * Reset value: 0x0000013FU
 *
 * Holds value of next available LUT. Can be used for fast LUT assignment. This
 * value can be read and then used in an update command as part of the
 * EPDC_UPD_CTRL register write The DIGCTL Status Register provides a read-only view to
 * various input conditions and internal states.
 */
typedef union _hw_epdc_status_nextlut
{
    uint32_t U;
    struct _hw_epdc_status_nextlut_bitfields
    {
        uint32_t NEXT_LUT : 6;         /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t NEXT_LUT_VALID : 1;   /*!< [8]  */
        uint32_t RESERVED1 : 23;       /*!< [31:9]  */
    } B;
} hw_epdc_status_nextlut_t;

/*!
 * @name Constants and macros for entire EPDC_STATUS_NEXTLUT register
 */
/*@{*/
#define HW_EPDC_STATUS_NEXTLUT_ADDR(x) ((uintptr_t)(x) + 0x460U)

#define HW_EPDC_STATUS_NEXTLUT(x) (*(__I hw_epdc_status_nextlut_t *) HW_EPDC_STATUS_NEXTLUT_ADDR(x))
#define HW_EPDC_STATUS_NEXTLUT_RD(x) (HW_EPDC_STATUS_NEXTLUT(x).U)
/*@}*/

/*
 * Constants & macros for individual EPDC_STATUS_NEXTLUT bitfields
 */

/*!
 * @name Register EPDC_STATUS_NEXTLUT, field NEXT_LUT[5:0] (RO)
 *
 * Next available LUT value
 */
/*@{*/
#define BP_EPDC_STATUS_NEXTLUT_NEXT_LUT (0U) /*!< Bit position for EPDC_STATUS_NEXTLUT_NEXT_LUT. */
#define BM_EPDC_STATUS_NEXTLUT_NEXT_LUT (0x0000003FU) /*!< Bit mask for EPDC_STATUS_NEXTLUT_NEXT_LUT. */
#define BS_EPDC_STATUS_NEXTLUT_NEXT_LUT (6U) /*!< Bit field size in bits for EPDC_STATUS_NEXTLUT_NEXT_LUT. */

/*! @brief Read current value of the EPDC_STATUS_NEXTLUT_NEXT_LUT field. */
#define BR_EPDC_STATUS_NEXTLUT_NEXT_LUT(x) (HW_EPDC_STATUS_NEXTLUT(x).B.NEXT_LUT)
/*@}*/

/*!
 * @name Register EPDC_STATUS_NEXTLUT, field NEXT_LUT_VALID[8] (RO)
 *
 * This bitfield can be used to check against a LUTs full condition
 */
/*@{*/
#define BP_EPDC_STATUS_NEXTLUT_NEXT_LUT_VALID (8U) /*!< Bit position for EPDC_STATUS_NEXTLUT_NEXT_LUT_VALID. */
#define BM_EPDC_STATUS_NEXTLUT_NEXT_LUT_VALID (0x00000100U) /*!< Bit mask for EPDC_STATUS_NEXTLUT_NEXT_LUT_VALID. */
#define BS_EPDC_STATUS_NEXTLUT_NEXT_LUT_VALID (1U) /*!< Bit field size in bits for EPDC_STATUS_NEXTLUT_NEXT_LUT_VALID. */

/*! @brief Read current value of the EPDC_STATUS_NEXTLUT_NEXT_LUT_VALID field. */
#define BR_EPDC_STATUS_NEXTLUT_NEXT_LUT_VALID(x) (HW_EPDC_STATUS_NEXTLUT(x).B.NEXT_LUT_VALID)
/*@}*/

/*******************************************************************************
 * HW_EPDC_STATUS_COL1 - EPDC LUT Collision Status
 ******************************************************************************/

/*!
 * @brief HW_EPDC_STATUS_COL1 - EPDC LUT Collision Status (RO)
 *
 * Reset value: 0x00000000U
 *
 * EPDC LUT Collision Status Register and works in conjuction with
 * EPDC_IRQ[LUT_COL_IRQ]. When a collision occurs the interrupt is set and all status bits are
 * set for LUTs which were touched by the collision. It does not set the bit for
 * the LUT which caused the collision. There is a single interrupt mask which is
 * used to control all the IRQ bits in this register (in EPDC_IRQ_MASK). Note
 * that a collision caused by a LUT which was set-up for no collision detection
 * will not trigger any collision LUT IRQ or status update. Note that clearing the
 * interrupt bit EPDC_IRQ[LUT_COL_IRQ] clears this register
 */
typedef union _hw_epdc_status_col1
{
    uint32_t U;
    struct _hw_epdc_status_col1_bitfields
    {
        uint32_t LUTN_COL_STS : 32;    /*!< [31:0]  */
    } B;
} hw_epdc_status_col1_t;

/*!
 * @name Constants and macros for entire EPDC_STATUS_COL1 register
 */
/*@{*/
#define HW_EPDC_STATUS_COL1_ADDR(x) ((uintptr_t)(x) + 0x480U)
#define HW_EPDC_STATUS_COL1_SET_ADDR(x) (HW_EPDC_STATUS_COL1_ADDR(x) + 0x4U)
#define HW_EPDC_STATUS_COL1_CLR_ADDR(x) (HW_EPDC_STATUS_COL1_ADDR(x) + 0x8U)
#define HW_EPDC_STATUS_COL1_TOG_ADDR(x) (HW_EPDC_STATUS_COL1_ADDR(x) + 0xCU)

#define HW_EPDC_STATUS_COL1(x)   (*(__I hw_epdc_status_col1_t *) HW_EPDC_STATUS_COL1_ADDR(x))
#define HW_EPDC_STATUS_COL1_RD(x) (HW_EPDC_STATUS_COL1(x).U)
/*@}*/

/*
 * Constants & macros for individual EPDC_STATUS_COL1 bitfields
 */

/*!
 * @name Register EPDC_STATUS_COL1, field LUTN_COL_STS[31:0] (RO)
 *
 * LUTn Collision Status
 */
/*@{*/
#define BP_EPDC_STATUS_COL1_LUTN_COL_STS (0U) /*!< Bit position for EPDC_STATUS_COL1_LUTN_COL_STS. */
#define BM_EPDC_STATUS_COL1_LUTN_COL_STS (0xFFFFFFFFU) /*!< Bit mask for EPDC_STATUS_COL1_LUTN_COL_STS. */
#define BS_EPDC_STATUS_COL1_LUTN_COL_STS (32U) /*!< Bit field size in bits for EPDC_STATUS_COL1_LUTN_COL_STS. */

/*! @brief Read current value of the EPDC_STATUS_COL1_LUTN_COL_STS field. */
#define BR_EPDC_STATUS_COL1_LUTN_COL_STS(x) (HW_EPDC_STATUS_COL1(x).U)
/*@}*/




/*******************************************************************************
 * HW_EPDC_STATUS_COL2 - EPDC LUT Collision Status
 ******************************************************************************/

/*!
 * @brief HW_EPDC_STATUS_COL2 - EPDC LUT Collision Status (RO)
 *
 * Reset value: 0x00000000U
 *
 * EPDC LUT Collision Status Register and works in conjuction with
 * EPDC_IRQ[LUT_COL_IRQ]. When a collision occurs the interrupt is set and all status bits are
 * set for LUTs which were touched by the collision. It does not set the bit for
 * the LUT which caused the collision. There is a single interrupt mask which is
 * used to control all the IRQ bits in this register (in EPDC_IRQ_MASK). Note
 * that a collision caused by a LUT which was set-up for no collision detection
 * will not trigger any collision LUT IRQ or status update. Note that clearing the
 * interrupt bit EPDC_IRQ[LUT_COL_IRQ] clears this register
 */
typedef union _hw_epdc_status_col2
{
    uint32_t U;
    struct _hw_epdc_status_col2_bitfields
    {
        uint32_t LUTN_COL_STS : 32;    /*!< [31:0]  */
    } B;
} hw_epdc_status_col2_t;

/*!
 * @name Constants and macros for entire EPDC_STATUS_COL2 register
 */
/*@{*/
#define HW_EPDC_STATUS_COL2_ADDR(x) ((uintptr_t)(x) + 0x490U)
#define HW_EPDC_STATUS_COL2_SET_ADDR(x) (HW_EPDC_STATUS_COL2_ADDR(x) + 0x4U)
#define HW_EPDC_STATUS_COL2_CLR_ADDR(x) (HW_EPDC_STATUS_COL2_ADDR(x) + 0x8U)
#define HW_EPDC_STATUS_COL2_TOG_ADDR(x) (HW_EPDC_STATUS_COL2_ADDR(x) + 0xCU)

#define HW_EPDC_STATUS_COL2(x)   (*(__I hw_epdc_status_col2_t *) HW_EPDC_STATUS_COL2_ADDR(x))
#define HW_EPDC_STATUS_COL2_RD(x) (HW_EPDC_STATUS_COL2(x).U)
/*@}*/

/*
 * Constants & macros for individual EPDC_STATUS_COL2 bitfields
 */

/*!
 * @name Register EPDC_STATUS_COL2, field LUTN_COL_STS[31:0] (RO)
 *
 * LUTn Collision Status
 */
/*@{*/
#define BP_EPDC_STATUS_COL2_LUTN_COL_STS (0U) /*!< Bit position for EPDC_STATUS_COL2_LUTN_COL_STS. */
#define BM_EPDC_STATUS_COL2_LUTN_COL_STS (0xFFFFFFFFU) /*!< Bit mask for EPDC_STATUS_COL2_LUTN_COL_STS. */
#define BS_EPDC_STATUS_COL2_LUTN_COL_STS (32U) /*!< Bit field size in bits for EPDC_STATUS_COL2_LUTN_COL_STS. */

/*! @brief Read current value of the EPDC_STATUS_COL2_LUTN_COL_STS field. */
#define BR_EPDC_STATUS_COL2_LUTN_COL_STS(x) (HW_EPDC_STATUS_COL2(x).U)
/*@}*/




/*******************************************************************************
 * HW_EPDC_STATUS - EPDC General Status Register
 ******************************************************************************/

/*!
 * @brief HW_EPDC_STATUS - EPDC General Status Register (RW)
 *
 * Reset value: 0x00000008U
 *
 * Register to house non LUT specific status bits This register houses general
 * status bits
 */
typedef union _hw_epdc_status
{
    uint32_t U;
    struct _hw_epdc_status_bitfields
    {
        uint32_t WB_BUSY : 1;          /*!< [0]  */
        uint32_t LUTS_BUSY : 1;        /*!< [1]  */
        uint32_t LUTS_UNDERRUN : 1;    /*!< [2]  */
        uint32_t UPD_VOID : 1;         /*!< [3]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t HISTOGRAM_NP : 5;     /*!< [12:8]  */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t HISTOGRAM_CP : 5;     /*!< [20:16]  */
        uint32_t RESERVED2 : 11;       /*!< [31:21]  */
    } B;
} hw_epdc_status_t;

/*!
 * @name Constants and macros for entire EPDC_STATUS register
 */
/*@{*/
#define HW_EPDC_STATUS_ADDR(x)   ((uintptr_t)(x) + 0x4A0U)
#define HW_EPDC_STATUS_SET_ADDR(x) (HW_EPDC_STATUS_ADDR(x) + 0x4U)
#define HW_EPDC_STATUS_CLR_ADDR(x) (HW_EPDC_STATUS_ADDR(x) + 0x8U)
#define HW_EPDC_STATUS_TOG_ADDR(x) (HW_EPDC_STATUS_ADDR(x) + 0xCU)

#define HW_EPDC_STATUS(x)        (*(__IO hw_epdc_status_t *) HW_EPDC_STATUS_ADDR(x))
#define HW_EPDC_STATUS_RD(x)     (HW_EPDC_STATUS(x).U)
#define HW_EPDC_STATUS_WR(x, v)  (HW_EPDC_STATUS(x).U = (v))
#define HW_EPDC_STATUS_SET(x, v) ((*(uint32_t *) HW_EPDC_STATUS_SET_ADDR(x)) = (v))
#define HW_EPDC_STATUS_CLR(x, v) ((*(uint32_t *) HW_EPDC_STATUS_CLR_ADDR(x)) = (v))
#define HW_EPDC_STATUS_TOG(x, v) ((*(uint32_t *) HW_EPDC_STATUS_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_STATUS bitfields
 */

/*!
 * @name Register EPDC_STATUS, field WB_BUSY[0] (RO)
 *
 * Working buffer process is busy cannot accept new update requests. When
 * WB_BUSY is 1, software should wait for the WB_CMPLT_IRQ interrupt. When this
 * interrupt occurs WB_BUSY is cleared immediately. This is a real-time status of the
 * process.
 */
/*@{*/
#define BP_EPDC_STATUS_WB_BUSY (0U)        /*!< Bit position for EPDC_STATUS_WB_BUSY. */
#define BM_EPDC_STATUS_WB_BUSY (0x00000001U) /*!< Bit mask for EPDC_STATUS_WB_BUSY. */
#define BS_EPDC_STATUS_WB_BUSY (1U)        /*!< Bit field size in bits for EPDC_STATUS_WB_BUSY. */

/*! @brief Read current value of the EPDC_STATUS_WB_BUSY field. */
#define BR_EPDC_STATUS_WB_BUSY(x) (HW_EPDC_STATUS(x).B.WB_BUSY)
/*@}*/

/*!
 * @name Register EPDC_STATUS, field LUTS_BUSY[1] (RO)
 *
 * Provides a summary status of LUTs. 1= All LUTs are busy, 0= LUTs are available
 */
/*@{*/
#define BP_EPDC_STATUS_LUTS_BUSY (1U)      /*!< Bit position for EPDC_STATUS_LUTS_BUSY. */
#define BM_EPDC_STATUS_LUTS_BUSY (0x00000002U) /*!< Bit mask for EPDC_STATUS_LUTS_BUSY. */
#define BS_EPDC_STATUS_LUTS_BUSY (1U)      /*!< Bit field size in bits for EPDC_STATUS_LUTS_BUSY. */

/*! @brief Read current value of the EPDC_STATUS_LUTS_BUSY field. */
#define BR_EPDC_STATUS_LUTS_BUSY(x) (HW_EPDC_STATUS(x).B.LUTS_BUSY)
/*@}*/

/*!
 * @name Register EPDC_STATUS, field LUTS_UNDERRUN[2] (RO)
 *
 * Provides a summary status of LUT fill. 1= not enough time for active luts
 * read during blanking period before vscan_holdoff. 0=complete all active luts fill
 * during blanking period before VSCAN_HOLDOFF.
 */
/*@{*/
#define BP_EPDC_STATUS_LUTS_UNDERRUN (2U)  /*!< Bit position for EPDC_STATUS_LUTS_UNDERRUN. */
#define BM_EPDC_STATUS_LUTS_UNDERRUN (0x00000004U) /*!< Bit mask for EPDC_STATUS_LUTS_UNDERRUN. */
#define BS_EPDC_STATUS_LUTS_UNDERRUN (1U)  /*!< Bit field size in bits for EPDC_STATUS_LUTS_UNDERRUN. */

/*! @brief Read current value of the EPDC_STATUS_LUTS_UNDERRUN field. */
#define BR_EPDC_STATUS_LUTS_UNDERRUN(x) (HW_EPDC_STATUS(x).B.LUTS_UNDERRUN)
/*@}*/

/*!
 * @name Register EPDC_STATUS, field UPD_VOID[3] (RO)
 *
 * Indicates that the update buffer is void. This means either no pixels need
 * updating or all pixels requiring updating were collided.
 */
/*@{*/
#define BP_EPDC_STATUS_UPD_VOID (3U)       /*!< Bit position for EPDC_STATUS_UPD_VOID. */
#define BM_EPDC_STATUS_UPD_VOID (0x00000008U) /*!< Bit mask for EPDC_STATUS_UPD_VOID. */
#define BS_EPDC_STATUS_UPD_VOID (1U)       /*!< Bit field size in bits for EPDC_STATUS_UPD_VOID. */

/*! @brief Read current value of the EPDC_STATUS_UPD_VOID field. */
#define BR_EPDC_STATUS_UPD_VOID(x) (HW_EPDC_STATUS(x).B.UPD_VOID)
/*@}*/

/*!
 * @name Register EPDC_STATUS, field HISTOGRAM_NP[12:8] (RW)
 *
 * Indicates which histogram matched the processed bitmap(NP). Bit[0] indicates
 * that the bitmap pixels were fully contained within the HIST1 (single color )
 * histogram. Bit[1] indicates that the bitmap pixels were fully contained within
 * the HIST2 (black / white ) histogram. Bit[2] indicates that the bitmap pixels
 * were fully contained within the HIST4 (2-bit grayscale) histogram. Bit[3]
 * indicates that the bitmap pixels were fully contained within the HIST8 (3-bit
 * grayscale) histogram. Bit[4] indicates that the bitmap pixels were fully contained
 * within the HIST16 (4-bit grayscale) histogram.
 */
/*@{*/
#define BP_EPDC_STATUS_HISTOGRAM_NP (8U)   /*!< Bit position for EPDC_STATUS_HISTOGRAM_NP. */
#define BM_EPDC_STATUS_HISTOGRAM_NP (0x00001F00U) /*!< Bit mask for EPDC_STATUS_HISTOGRAM_NP. */
#define BS_EPDC_STATUS_HISTOGRAM_NP (5U)   /*!< Bit field size in bits for EPDC_STATUS_HISTOGRAM_NP. */

/*! @brief Read current value of the EPDC_STATUS_HISTOGRAM_NP field. */
#define BR_EPDC_STATUS_HISTOGRAM_NP(x) (HW_EPDC_STATUS(x).B.HISTOGRAM_NP)

/*! @brief Format value for bitfield EPDC_STATUS_HISTOGRAM_NP. */
#define BF_EPDC_STATUS_HISTOGRAM_NP(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_STATUS_HISTOGRAM_NP) & BM_EPDC_STATUS_HISTOGRAM_NP)

/*! @brief Set the HISTOGRAM_NP field to a new value. */
#define BW_EPDC_STATUS_HISTOGRAM_NP(x, v) (HW_EPDC_STATUS_WR(x, (HW_EPDC_STATUS_RD(x) & ~BM_EPDC_STATUS_HISTOGRAM_NP) | BF_EPDC_STATUS_HISTOGRAM_NP(v)))
/*@}*/

/*!
 * @name Register EPDC_STATUS, field HISTOGRAM_CP[20:16] (RW)
 *
 * Indicates which histogram matched the existing bitmap(CP). Bit[0] indicates
 * that the bitmap pixels were fully contained within the HIST1 (single color )
 * histogram. Bit[1] indicates that the bitmap pixels were fully contained within
 * the HIST2 (black / white ) histogram. Bit[2] indicates that the bitmap pixels
 * were fully contained within the HIST4 (2-bit grayscale) histogram. Bit[3]
 * indicates that the bitmap pixels were fully contained within the HIST8 (3-bit
 * grayscale) histogram. Bit[4] indicates that the bitmap pixels were fully contained
 * within the HIST16 (4-bit grayscale) histogram.
 */
/*@{*/
#define BP_EPDC_STATUS_HISTOGRAM_CP (16U)  /*!< Bit position for EPDC_STATUS_HISTOGRAM_CP. */
#define BM_EPDC_STATUS_HISTOGRAM_CP (0x001F0000U) /*!< Bit mask for EPDC_STATUS_HISTOGRAM_CP. */
#define BS_EPDC_STATUS_HISTOGRAM_CP (5U)   /*!< Bit field size in bits for EPDC_STATUS_HISTOGRAM_CP. */

/*! @brief Read current value of the EPDC_STATUS_HISTOGRAM_CP field. */
#define BR_EPDC_STATUS_HISTOGRAM_CP(x) (HW_EPDC_STATUS(x).B.HISTOGRAM_CP)

/*! @brief Format value for bitfield EPDC_STATUS_HISTOGRAM_CP. */
#define BF_EPDC_STATUS_HISTOGRAM_CP(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_STATUS_HISTOGRAM_CP) & BM_EPDC_STATUS_HISTOGRAM_CP)

/*! @brief Set the HISTOGRAM_CP field to a new value. */
#define BW_EPDC_STATUS_HISTOGRAM_CP(x, v) (HW_EPDC_STATUS_WR(x, (HW_EPDC_STATUS_RD(x) & ~BM_EPDC_STATUS_HISTOGRAM_CP) | BF_EPDC_STATUS_HISTOGRAM_CP(v)))
/*@}*/




/*******************************************************************************
 * HW_EPDC_UPD_COL_CORD - EPDC Collision Region Co-ordinate
 ******************************************************************************/

/*!
 * @brief HW_EPDC_UPD_COL_CORD - EPDC Collision Region Co-ordinate (RO)
 *
 * Reset value: 0x00000000U
 *
 * EPDC Collision Region Co-ordinate, cleared when new update issued This
 * register only valid after WB completion and collision happens.
 */
typedef union _hw_epdc_upd_col_cord
{
    uint32_t U;
    struct _hw_epdc_upd_col_cord_bitfields
    {
        uint32_t XCORD : 13;           /*!< [12:0]  */
        uint32_t RESERVED0 : 3;        /*!< [15:13]  */
        uint32_t YCORD : 13;           /*!< [28:16]  */
        uint32_t RESERVED1 : 3;        /*!< [31:29]  */
    } B;
} hw_epdc_upd_col_cord_t;

/*!
 * @name Constants and macros for entire EPDC_UPD_COL_CORD register
 */
/*@{*/
#define HW_EPDC_UPD_COL_CORD_ADDR(x) ((uintptr_t)(x) + 0x4C0U)

#define HW_EPDC_UPD_COL_CORD(x)  (*(__I hw_epdc_upd_col_cord_t *) HW_EPDC_UPD_COL_CORD_ADDR(x))
#define HW_EPDC_UPD_COL_CORD_RD(x) (HW_EPDC_UPD_COL_CORD(x).U)
/*@}*/

/*
 * Constants & macros for individual EPDC_UPD_COL_CORD bitfields
 */

/*!
 * @name Register EPDC_UPD_COL_CORD, field XCORD[12:0] (RO)
 *
 * X co-ordinate for collision region of the latest completed update
 */
/*@{*/
#define BP_EPDC_UPD_COL_CORD_XCORD (0U)    /*!< Bit position for EPDC_UPD_COL_CORD_XCORD. */
#define BM_EPDC_UPD_COL_CORD_XCORD (0x00001FFFU) /*!< Bit mask for EPDC_UPD_COL_CORD_XCORD. */
#define BS_EPDC_UPD_COL_CORD_XCORD (13U)   /*!< Bit field size in bits for EPDC_UPD_COL_CORD_XCORD. */

/*! @brief Read current value of the EPDC_UPD_COL_CORD_XCORD field. */
#define BR_EPDC_UPD_COL_CORD_XCORD(x) (HW_EPDC_UPD_COL_CORD(x).B.XCORD)
/*@}*/

/*!
 * @name Register EPDC_UPD_COL_CORD, field YCORD[28:16] (RO)
 *
 * Y co-ordinate for collision region of the latest completed update
 */
/*@{*/
#define BP_EPDC_UPD_COL_CORD_YCORD (16U)   /*!< Bit position for EPDC_UPD_COL_CORD_YCORD. */
#define BM_EPDC_UPD_COL_CORD_YCORD (0x1FFF0000U) /*!< Bit mask for EPDC_UPD_COL_CORD_YCORD. */
#define BS_EPDC_UPD_COL_CORD_YCORD (13U)   /*!< Bit field size in bits for EPDC_UPD_COL_CORD_YCORD. */

/*! @brief Read current value of the EPDC_UPD_COL_CORD_YCORD field. */
#define BR_EPDC_UPD_COL_CORD_YCORD(x) (HW_EPDC_UPD_COL_CORD(x).B.YCORD)
/*@}*/

/*******************************************************************************
 * HW_EPDC_UPD_COL_SIZE - EPDC Collision Region Size
 ******************************************************************************/

/*!
 * @brief HW_EPDC_UPD_COL_SIZE - EPDC Collision Region Size (RO)
 *
 * Reset value: 0x00000000U
 *
 * EPDC Collision Region Size of the latest completed update cleared when new
 * update issued This register only valid after WB completion and collision happens.
 */
typedef union _hw_epdc_upd_col_size
{
    uint32_t U;
    struct _hw_epdc_upd_col_size_bitfields
    {
        uint32_t WIDTH : 13;           /*!< [12:0]  */
        uint32_t RESERVED0 : 3;        /*!< [15:13]  */
        uint32_t HEIGHT : 13;          /*!< [28:16]  */
        uint32_t RESERVED1 : 3;        /*!< [31:29]  */
    } B;
} hw_epdc_upd_col_size_t;

/*!
 * @name Constants and macros for entire EPDC_UPD_COL_SIZE register
 */
/*@{*/
#define HW_EPDC_UPD_COL_SIZE_ADDR(x) ((uintptr_t)(x) + 0x4E0U)

#define HW_EPDC_UPD_COL_SIZE(x)  (*(__I hw_epdc_upd_col_size_t *) HW_EPDC_UPD_COL_SIZE_ADDR(x))
#define HW_EPDC_UPD_COL_SIZE_RD(x) (HW_EPDC_UPD_COL_SIZE(x).U)
/*@}*/

/*
 * Constants & macros for individual EPDC_UPD_COL_SIZE bitfields
 */

/*!
 * @name Register EPDC_UPD_COL_SIZE, field WIDTH[12:0] (RO)
 *
 * Width (in pixels)
 */
/*@{*/
#define BP_EPDC_UPD_COL_SIZE_WIDTH (0U)    /*!< Bit position for EPDC_UPD_COL_SIZE_WIDTH. */
#define BM_EPDC_UPD_COL_SIZE_WIDTH (0x00001FFFU) /*!< Bit mask for EPDC_UPD_COL_SIZE_WIDTH. */
#define BS_EPDC_UPD_COL_SIZE_WIDTH (13U)   /*!< Bit field size in bits for EPDC_UPD_COL_SIZE_WIDTH. */

/*! @brief Read current value of the EPDC_UPD_COL_SIZE_WIDTH field. */
#define BR_EPDC_UPD_COL_SIZE_WIDTH(x) (HW_EPDC_UPD_COL_SIZE(x).B.WIDTH)
/*@}*/

/*!
 * @name Register EPDC_UPD_COL_SIZE, field HEIGHT[28:16] (RO)
 *
 * Height (in pixels)
 */
/*@{*/
#define BP_EPDC_UPD_COL_SIZE_HEIGHT (16U)  /*!< Bit position for EPDC_UPD_COL_SIZE_HEIGHT. */
#define BM_EPDC_UPD_COL_SIZE_HEIGHT (0x1FFF0000U) /*!< Bit mask for EPDC_UPD_COL_SIZE_HEIGHT. */
#define BS_EPDC_UPD_COL_SIZE_HEIGHT (13U)  /*!< Bit field size in bits for EPDC_UPD_COL_SIZE_HEIGHT. */

/*! @brief Read current value of the EPDC_UPD_COL_SIZE_HEIGHT field. */
#define BR_EPDC_UPD_COL_SIZE_HEIGHT(x) (HW_EPDC_UPD_COL_SIZE(x).B.HEIGHT)
/*@}*/

/*******************************************************************************
 * HW_EPDC_HIST1_PARAM - 1-level Histogram Parameter Register.
 ******************************************************************************/

/*!
 * @brief HW_EPDC_HIST1_PARAM - 1-level Histogram Parameter Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register specifies the valid values for a 1-level(single color)
 * histogram. If all pixels in a bitmap is only one color, STATUS[0] will be set at the
 * end of frame processing. All comparator values should be programmed such that
 * they are consistent with the TFT_PIXEL_FORMAT control field.
 */
typedef union _hw_epdc_hist1_param
{
    uint32_t U;
    struct _hw_epdc_hist1_param_bitfields
    {
        uint32_t VALUE0 : 5;           /*!< [4:0]  */
        uint32_t RSVD : 27;            /*!< [31:5]  */
    } B;
} hw_epdc_hist1_param_t;

/*!
 * @name Constants and macros for entire EPDC_HIST1_PARAM register
 */
/*@{*/
#define HW_EPDC_HIST1_PARAM_ADDR(x) ((uintptr_t)(x) + 0x600U)

#define HW_EPDC_HIST1_PARAM(x)   (*(__IO hw_epdc_hist1_param_t *) HW_EPDC_HIST1_PARAM_ADDR(x))
#define HW_EPDC_HIST1_PARAM_RD(x) (HW_EPDC_HIST1_PARAM(x).U)
#define HW_EPDC_HIST1_PARAM_WR(x, v) (HW_EPDC_HIST1_PARAM(x).U = (v))
#define HW_EPDC_HIST1_PARAM_SET(x, v) (HW_EPDC_HIST1_PARAM_WR(x, HW_EPDC_HIST1_PARAM_RD(x) |  (v)))
#define HW_EPDC_HIST1_PARAM_CLR(x, v) (HW_EPDC_HIST1_PARAM_WR(x, HW_EPDC_HIST1_PARAM_RD(x) & ~(v)))
#define HW_EPDC_HIST1_PARAM_TOG(x, v) (HW_EPDC_HIST1_PARAM_WR(x, HW_EPDC_HIST1_PARAM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_HIST1_PARAM bitfields
 */

/*!
 * @name Register EPDC_HIST1_PARAM, field VALUE0[4:0] (RW)
 *
 * value for 1-level histogram
 */
/*@{*/
#define BP_EPDC_HIST1_PARAM_VALUE0 (0U)    /*!< Bit position for EPDC_HIST1_PARAM_VALUE0. */
#define BM_EPDC_HIST1_PARAM_VALUE0 (0x0000001FU) /*!< Bit mask for EPDC_HIST1_PARAM_VALUE0. */
#define BS_EPDC_HIST1_PARAM_VALUE0 (5U)    /*!< Bit field size in bits for EPDC_HIST1_PARAM_VALUE0. */

/*! @brief Read current value of the EPDC_HIST1_PARAM_VALUE0 field. */
#define BR_EPDC_HIST1_PARAM_VALUE0(x) (HW_EPDC_HIST1_PARAM(x).B.VALUE0)

/*! @brief Format value for bitfield EPDC_HIST1_PARAM_VALUE0. */
#define BF_EPDC_HIST1_PARAM_VALUE0(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST1_PARAM_VALUE0) & BM_EPDC_HIST1_PARAM_VALUE0)

/*! @brief Set the VALUE0 field to a new value. */
#define BW_EPDC_HIST1_PARAM_VALUE0(x, v) (HW_EPDC_HIST1_PARAM_WR(x, (HW_EPDC_HIST1_PARAM_RD(x) & ~BM_EPDC_HIST1_PARAM_VALUE0) | BF_EPDC_HIST1_PARAM_VALUE0(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST1_PARAM, field RSVD[31:5] (RU)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_EPDC_HIST1_PARAM_RSVD (5U)      /*!< Bit position for EPDC_HIST1_PARAM_RSVD. */
#define BM_EPDC_HIST1_PARAM_RSVD (0xFFFFFFE0U) /*!< Bit mask for EPDC_HIST1_PARAM_RSVD. */
#define BS_EPDC_HIST1_PARAM_RSVD (27U)     /*!< Bit field size in bits for EPDC_HIST1_PARAM_RSVD. */
/*@}*/

/*******************************************************************************
 * HW_EPDC_HIST2_PARAM - 2-level Histogram Parameter Register.
 ******************************************************************************/

/*!
 * @brief HW_EPDC_HIST2_PARAM - 2-level Histogram Parameter Register. (RW)
 *
 * Reset value: 0x00000F00U
 *
 * This register specifies the valid values for a 2-level histogram. If all
 * pixels in a bitmap match these two values, STATUS[0] will be set at the end of
 * frame processing. All comparator values should be programmed such that they are
 * consistent with the TFT_PIXEL_FORMAT control field.
 */
typedef union _hw_epdc_hist2_param
{
    uint32_t U;
    struct _hw_epdc_hist2_param_bitfields
    {
        uint32_t VALUE0 : 5;           /*!< [4:0]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t VALUE1 : 5;           /*!< [12:8]  */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t RSVD : 16;            /*!< [31:16]  */
    } B;
} hw_epdc_hist2_param_t;

/*!
 * @name Constants and macros for entire EPDC_HIST2_PARAM register
 */
/*@{*/
#define HW_EPDC_HIST2_PARAM_ADDR(x) ((uintptr_t)(x) + 0x610U)

#define HW_EPDC_HIST2_PARAM(x)   (*(__IO hw_epdc_hist2_param_t *) HW_EPDC_HIST2_PARAM_ADDR(x))
#define HW_EPDC_HIST2_PARAM_RD(x) (HW_EPDC_HIST2_PARAM(x).U)
#define HW_EPDC_HIST2_PARAM_WR(x, v) (HW_EPDC_HIST2_PARAM(x).U = (v))
#define HW_EPDC_HIST2_PARAM_SET(x, v) (HW_EPDC_HIST2_PARAM_WR(x, HW_EPDC_HIST2_PARAM_RD(x) |  (v)))
#define HW_EPDC_HIST2_PARAM_CLR(x, v) (HW_EPDC_HIST2_PARAM_WR(x, HW_EPDC_HIST2_PARAM_RD(x) & ~(v)))
#define HW_EPDC_HIST2_PARAM_TOG(x, v) (HW_EPDC_HIST2_PARAM_WR(x, HW_EPDC_HIST2_PARAM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_HIST2_PARAM bitfields
 */

/*!
 * @name Register EPDC_HIST2_PARAM, field VALUE0[4:0] (RW)
 *
 * Black value for 2-level histogram
 */
/*@{*/
#define BP_EPDC_HIST2_PARAM_VALUE0 (0U)    /*!< Bit position for EPDC_HIST2_PARAM_VALUE0. */
#define BM_EPDC_HIST2_PARAM_VALUE0 (0x0000001FU) /*!< Bit mask for EPDC_HIST2_PARAM_VALUE0. */
#define BS_EPDC_HIST2_PARAM_VALUE0 (5U)    /*!< Bit field size in bits for EPDC_HIST2_PARAM_VALUE0. */

/*! @brief Read current value of the EPDC_HIST2_PARAM_VALUE0 field. */
#define BR_EPDC_HIST2_PARAM_VALUE0(x) (HW_EPDC_HIST2_PARAM(x).B.VALUE0)

/*! @brief Format value for bitfield EPDC_HIST2_PARAM_VALUE0. */
#define BF_EPDC_HIST2_PARAM_VALUE0(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST2_PARAM_VALUE0) & BM_EPDC_HIST2_PARAM_VALUE0)

/*! @brief Set the VALUE0 field to a new value. */
#define BW_EPDC_HIST2_PARAM_VALUE0(x, v) (HW_EPDC_HIST2_PARAM_WR(x, (HW_EPDC_HIST2_PARAM_RD(x) & ~BM_EPDC_HIST2_PARAM_VALUE0) | BF_EPDC_HIST2_PARAM_VALUE0(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST2_PARAM, field VALUE1[12:8] (RW)
 *
 * White value for 2-level histogram
 */
/*@{*/
#define BP_EPDC_HIST2_PARAM_VALUE1 (8U)    /*!< Bit position for EPDC_HIST2_PARAM_VALUE1. */
#define BM_EPDC_HIST2_PARAM_VALUE1 (0x00001F00U) /*!< Bit mask for EPDC_HIST2_PARAM_VALUE1. */
#define BS_EPDC_HIST2_PARAM_VALUE1 (5U)    /*!< Bit field size in bits for EPDC_HIST2_PARAM_VALUE1. */

/*! @brief Read current value of the EPDC_HIST2_PARAM_VALUE1 field. */
#define BR_EPDC_HIST2_PARAM_VALUE1(x) (HW_EPDC_HIST2_PARAM(x).B.VALUE1)

/*! @brief Format value for bitfield EPDC_HIST2_PARAM_VALUE1. */
#define BF_EPDC_HIST2_PARAM_VALUE1(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST2_PARAM_VALUE1) & BM_EPDC_HIST2_PARAM_VALUE1)

/*! @brief Set the VALUE1 field to a new value. */
#define BW_EPDC_HIST2_PARAM_VALUE1(x, v) (HW_EPDC_HIST2_PARAM_WR(x, (HW_EPDC_HIST2_PARAM_RD(x) & ~BM_EPDC_HIST2_PARAM_VALUE1) | BF_EPDC_HIST2_PARAM_VALUE1(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST2_PARAM, field RSVD[31:16] (RU)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_EPDC_HIST2_PARAM_RSVD (16U)     /*!< Bit position for EPDC_HIST2_PARAM_RSVD. */
#define BM_EPDC_HIST2_PARAM_RSVD (0xFFFF0000U) /*!< Bit mask for EPDC_HIST2_PARAM_RSVD. */
#define BS_EPDC_HIST2_PARAM_RSVD (16U)     /*!< Bit field size in bits for EPDC_HIST2_PARAM_RSVD. */
/*@}*/

/*******************************************************************************
 * HW_EPDC_HIST4_PARAM - 4-level Histogram Parameter Register.
 ******************************************************************************/

/*!
 * @brief HW_EPDC_HIST4_PARAM - 4-level Histogram Parameter Register. (RW)
 *
 * Reset value: 0x0F0A0500U
 *
 * This register specifies the valid values for a 4-level histogram. If all
 * pixels in a bitmap match these two values, STATUS[1] will be set at the end of
 * frame processing. All comparator values should be programmed such that they are
 * consistent with the TFT_PIXEL_FORMAT control field.
 */
typedef union _hw_epdc_hist4_param
{
    uint32_t U;
    struct _hw_epdc_hist4_param_bitfields
    {
        uint32_t VALUE0 : 5;           /*!< [4:0]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t VALUE1 : 5;           /*!< [12:8]  */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t VALUE2 : 5;           /*!< [20:16]  */
        uint32_t RESERVED2 : 3;        /*!< [23:21]  */
        uint32_t VALUE3 : 5;           /*!< [28:24]  */
        uint32_t RESERVED3 : 3;        /*!< [31:29]  */
    } B;
} hw_epdc_hist4_param_t;

/*!
 * @name Constants and macros for entire EPDC_HIST4_PARAM register
 */
/*@{*/
#define HW_EPDC_HIST4_PARAM_ADDR(x) ((uintptr_t)(x) + 0x620U)

#define HW_EPDC_HIST4_PARAM(x)   (*(__IO hw_epdc_hist4_param_t *) HW_EPDC_HIST4_PARAM_ADDR(x))
#define HW_EPDC_HIST4_PARAM_RD(x) (HW_EPDC_HIST4_PARAM(x).U)
#define HW_EPDC_HIST4_PARAM_WR(x, v) (HW_EPDC_HIST4_PARAM(x).U = (v))
#define HW_EPDC_HIST4_PARAM_SET(x, v) (HW_EPDC_HIST4_PARAM_WR(x, HW_EPDC_HIST4_PARAM_RD(x) |  (v)))
#define HW_EPDC_HIST4_PARAM_CLR(x, v) (HW_EPDC_HIST4_PARAM_WR(x, HW_EPDC_HIST4_PARAM_RD(x) & ~(v)))
#define HW_EPDC_HIST4_PARAM_TOG(x, v) (HW_EPDC_HIST4_PARAM_WR(x, HW_EPDC_HIST4_PARAM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_HIST4_PARAM bitfields
 */

/*!
 * @name Register EPDC_HIST4_PARAM, field VALUE0[4:0] (RW)
 *
 * GRAY0 (Black) value for 4-level histogram
 */
/*@{*/
#define BP_EPDC_HIST4_PARAM_VALUE0 (0U)    /*!< Bit position for EPDC_HIST4_PARAM_VALUE0. */
#define BM_EPDC_HIST4_PARAM_VALUE0 (0x0000001FU) /*!< Bit mask for EPDC_HIST4_PARAM_VALUE0. */
#define BS_EPDC_HIST4_PARAM_VALUE0 (5U)    /*!< Bit field size in bits for EPDC_HIST4_PARAM_VALUE0. */

/*! @brief Read current value of the EPDC_HIST4_PARAM_VALUE0 field. */
#define BR_EPDC_HIST4_PARAM_VALUE0(x) (HW_EPDC_HIST4_PARAM(x).B.VALUE0)

/*! @brief Format value for bitfield EPDC_HIST4_PARAM_VALUE0. */
#define BF_EPDC_HIST4_PARAM_VALUE0(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST4_PARAM_VALUE0) & BM_EPDC_HIST4_PARAM_VALUE0)

/*! @brief Set the VALUE0 field to a new value. */
#define BW_EPDC_HIST4_PARAM_VALUE0(x, v) (HW_EPDC_HIST4_PARAM_WR(x, (HW_EPDC_HIST4_PARAM_RD(x) & ~BM_EPDC_HIST4_PARAM_VALUE0) | BF_EPDC_HIST4_PARAM_VALUE0(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST4_PARAM, field VALUE1[12:8] (RW)
 *
 * GRAY1 value for 4-level histogram
 */
/*@{*/
#define BP_EPDC_HIST4_PARAM_VALUE1 (8U)    /*!< Bit position for EPDC_HIST4_PARAM_VALUE1. */
#define BM_EPDC_HIST4_PARAM_VALUE1 (0x00001F00U) /*!< Bit mask for EPDC_HIST4_PARAM_VALUE1. */
#define BS_EPDC_HIST4_PARAM_VALUE1 (5U)    /*!< Bit field size in bits for EPDC_HIST4_PARAM_VALUE1. */

/*! @brief Read current value of the EPDC_HIST4_PARAM_VALUE1 field. */
#define BR_EPDC_HIST4_PARAM_VALUE1(x) (HW_EPDC_HIST4_PARAM(x).B.VALUE1)

/*! @brief Format value for bitfield EPDC_HIST4_PARAM_VALUE1. */
#define BF_EPDC_HIST4_PARAM_VALUE1(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST4_PARAM_VALUE1) & BM_EPDC_HIST4_PARAM_VALUE1)

/*! @brief Set the VALUE1 field to a new value. */
#define BW_EPDC_HIST4_PARAM_VALUE1(x, v) (HW_EPDC_HIST4_PARAM_WR(x, (HW_EPDC_HIST4_PARAM_RD(x) & ~BM_EPDC_HIST4_PARAM_VALUE1) | BF_EPDC_HIST4_PARAM_VALUE1(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST4_PARAM, field VALUE2[20:16] (RW)
 *
 * GRAY2 value for 4-level histogram
 */
/*@{*/
#define BP_EPDC_HIST4_PARAM_VALUE2 (16U)   /*!< Bit position for EPDC_HIST4_PARAM_VALUE2. */
#define BM_EPDC_HIST4_PARAM_VALUE2 (0x001F0000U) /*!< Bit mask for EPDC_HIST4_PARAM_VALUE2. */
#define BS_EPDC_HIST4_PARAM_VALUE2 (5U)    /*!< Bit field size in bits for EPDC_HIST4_PARAM_VALUE2. */

/*! @brief Read current value of the EPDC_HIST4_PARAM_VALUE2 field. */
#define BR_EPDC_HIST4_PARAM_VALUE2(x) (HW_EPDC_HIST4_PARAM(x).B.VALUE2)

/*! @brief Format value for bitfield EPDC_HIST4_PARAM_VALUE2. */
#define BF_EPDC_HIST4_PARAM_VALUE2(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST4_PARAM_VALUE2) & BM_EPDC_HIST4_PARAM_VALUE2)

/*! @brief Set the VALUE2 field to a new value. */
#define BW_EPDC_HIST4_PARAM_VALUE2(x, v) (HW_EPDC_HIST4_PARAM_WR(x, (HW_EPDC_HIST4_PARAM_RD(x) & ~BM_EPDC_HIST4_PARAM_VALUE2) | BF_EPDC_HIST4_PARAM_VALUE2(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST4_PARAM, field VALUE3[28:24] (RW)
 *
 * GRAY3 (White) value for 4-level histogram
 */
/*@{*/
#define BP_EPDC_HIST4_PARAM_VALUE3 (24U)   /*!< Bit position for EPDC_HIST4_PARAM_VALUE3. */
#define BM_EPDC_HIST4_PARAM_VALUE3 (0x1F000000U) /*!< Bit mask for EPDC_HIST4_PARAM_VALUE3. */
#define BS_EPDC_HIST4_PARAM_VALUE3 (5U)    /*!< Bit field size in bits for EPDC_HIST4_PARAM_VALUE3. */

/*! @brief Read current value of the EPDC_HIST4_PARAM_VALUE3 field. */
#define BR_EPDC_HIST4_PARAM_VALUE3(x) (HW_EPDC_HIST4_PARAM(x).B.VALUE3)

/*! @brief Format value for bitfield EPDC_HIST4_PARAM_VALUE3. */
#define BF_EPDC_HIST4_PARAM_VALUE3(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST4_PARAM_VALUE3) & BM_EPDC_HIST4_PARAM_VALUE3)

/*! @brief Set the VALUE3 field to a new value. */
#define BW_EPDC_HIST4_PARAM_VALUE3(x, v) (HW_EPDC_HIST4_PARAM_WR(x, (HW_EPDC_HIST4_PARAM_RD(x) & ~BM_EPDC_HIST4_PARAM_VALUE3) | BF_EPDC_HIST4_PARAM_VALUE3(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_HIST8_PARAM0 - 8-level Histogram Parameter 0 Register.
 ******************************************************************************/

/*!
 * @brief HW_EPDC_HIST8_PARAM0 - 8-level Histogram Parameter 0 Register. (RW)
 *
 * Reset value: 0x06040200U
 *
 * This register specifies four of the valid values for an 8-level histogram. If
 * all pixels in a bitmap match these two values, STATUS[2] will be set at the
 * end of frame processing. All comparator values should be programmed such that
 * they are consistent with the TFT_PIXEL_FORMAT control field.
 */
typedef union _hw_epdc_hist8_param0
{
    uint32_t U;
    struct _hw_epdc_hist8_param0_bitfields
    {
        uint32_t VALUE0 : 5;           /*!< [4:0]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t VALUE1 : 5;           /*!< [12:8]  */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t VALUE2 : 5;           /*!< [20:16]  */
        uint32_t RESERVED2 : 3;        /*!< [23:21]  */
        uint32_t VALUE3 : 5;           /*!< [28:24]  */
        uint32_t RESERVED3 : 3;        /*!< [31:29]  */
    } B;
} hw_epdc_hist8_param0_t;

/*!
 * @name Constants and macros for entire EPDC_HIST8_PARAM0 register
 */
/*@{*/
#define HW_EPDC_HIST8_PARAM0_ADDR(x) ((uintptr_t)(x) + 0x630U)

#define HW_EPDC_HIST8_PARAM0(x)  (*(__IO hw_epdc_hist8_param0_t *) HW_EPDC_HIST8_PARAM0_ADDR(x))
#define HW_EPDC_HIST8_PARAM0_RD(x) (HW_EPDC_HIST8_PARAM0(x).U)
#define HW_EPDC_HIST8_PARAM0_WR(x, v) (HW_EPDC_HIST8_PARAM0(x).U = (v))
#define HW_EPDC_HIST8_PARAM0_SET(x, v) (HW_EPDC_HIST8_PARAM0_WR(x, HW_EPDC_HIST8_PARAM0_RD(x) |  (v)))
#define HW_EPDC_HIST8_PARAM0_CLR(x, v) (HW_EPDC_HIST8_PARAM0_WR(x, HW_EPDC_HIST8_PARAM0_RD(x) & ~(v)))
#define HW_EPDC_HIST8_PARAM0_TOG(x, v) (HW_EPDC_HIST8_PARAM0_WR(x, HW_EPDC_HIST8_PARAM0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_HIST8_PARAM0 bitfields
 */

/*!
 * @name Register EPDC_HIST8_PARAM0, field VALUE0[4:0] (RW)
 *
 * GRAY0 (Black) value for 8-level histogram
 */
/*@{*/
#define BP_EPDC_HIST8_PARAM0_VALUE0 (0U)   /*!< Bit position for EPDC_HIST8_PARAM0_VALUE0. */
#define BM_EPDC_HIST8_PARAM0_VALUE0 (0x0000001FU) /*!< Bit mask for EPDC_HIST8_PARAM0_VALUE0. */
#define BS_EPDC_HIST8_PARAM0_VALUE0 (5U)   /*!< Bit field size in bits for EPDC_HIST8_PARAM0_VALUE0. */

/*! @brief Read current value of the EPDC_HIST8_PARAM0_VALUE0 field. */
#define BR_EPDC_HIST8_PARAM0_VALUE0(x) (HW_EPDC_HIST8_PARAM0(x).B.VALUE0)

/*! @brief Format value for bitfield EPDC_HIST8_PARAM0_VALUE0. */
#define BF_EPDC_HIST8_PARAM0_VALUE0(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST8_PARAM0_VALUE0) & BM_EPDC_HIST8_PARAM0_VALUE0)

/*! @brief Set the VALUE0 field to a new value. */
#define BW_EPDC_HIST8_PARAM0_VALUE0(x, v) (HW_EPDC_HIST8_PARAM0_WR(x, (HW_EPDC_HIST8_PARAM0_RD(x) & ~BM_EPDC_HIST8_PARAM0_VALUE0) | BF_EPDC_HIST8_PARAM0_VALUE0(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST8_PARAM0, field VALUE1[12:8] (RW)
 *
 * GRAY1 value for 8-level histogram
 */
/*@{*/
#define BP_EPDC_HIST8_PARAM0_VALUE1 (8U)   /*!< Bit position for EPDC_HIST8_PARAM0_VALUE1. */
#define BM_EPDC_HIST8_PARAM0_VALUE1 (0x00001F00U) /*!< Bit mask for EPDC_HIST8_PARAM0_VALUE1. */
#define BS_EPDC_HIST8_PARAM0_VALUE1 (5U)   /*!< Bit field size in bits for EPDC_HIST8_PARAM0_VALUE1. */

/*! @brief Read current value of the EPDC_HIST8_PARAM0_VALUE1 field. */
#define BR_EPDC_HIST8_PARAM0_VALUE1(x) (HW_EPDC_HIST8_PARAM0(x).B.VALUE1)

/*! @brief Format value for bitfield EPDC_HIST8_PARAM0_VALUE1. */
#define BF_EPDC_HIST8_PARAM0_VALUE1(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST8_PARAM0_VALUE1) & BM_EPDC_HIST8_PARAM0_VALUE1)

/*! @brief Set the VALUE1 field to a new value. */
#define BW_EPDC_HIST8_PARAM0_VALUE1(x, v) (HW_EPDC_HIST8_PARAM0_WR(x, (HW_EPDC_HIST8_PARAM0_RD(x) & ~BM_EPDC_HIST8_PARAM0_VALUE1) | BF_EPDC_HIST8_PARAM0_VALUE1(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST8_PARAM0, field VALUE2[20:16] (RW)
 *
 * GRAY2 value for 8-level histogram
 */
/*@{*/
#define BP_EPDC_HIST8_PARAM0_VALUE2 (16U)  /*!< Bit position for EPDC_HIST8_PARAM0_VALUE2. */
#define BM_EPDC_HIST8_PARAM0_VALUE2 (0x001F0000U) /*!< Bit mask for EPDC_HIST8_PARAM0_VALUE2. */
#define BS_EPDC_HIST8_PARAM0_VALUE2 (5U)   /*!< Bit field size in bits for EPDC_HIST8_PARAM0_VALUE2. */

/*! @brief Read current value of the EPDC_HIST8_PARAM0_VALUE2 field. */
#define BR_EPDC_HIST8_PARAM0_VALUE2(x) (HW_EPDC_HIST8_PARAM0(x).B.VALUE2)

/*! @brief Format value for bitfield EPDC_HIST8_PARAM0_VALUE2. */
#define BF_EPDC_HIST8_PARAM0_VALUE2(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST8_PARAM0_VALUE2) & BM_EPDC_HIST8_PARAM0_VALUE2)

/*! @brief Set the VALUE2 field to a new value. */
#define BW_EPDC_HIST8_PARAM0_VALUE2(x, v) (HW_EPDC_HIST8_PARAM0_WR(x, (HW_EPDC_HIST8_PARAM0_RD(x) & ~BM_EPDC_HIST8_PARAM0_VALUE2) | BF_EPDC_HIST8_PARAM0_VALUE2(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST8_PARAM0, field VALUE3[28:24] (RW)
 *
 * GRAY3 value for 8-level histogram
 */
/*@{*/
#define BP_EPDC_HIST8_PARAM0_VALUE3 (24U)  /*!< Bit position for EPDC_HIST8_PARAM0_VALUE3. */
#define BM_EPDC_HIST8_PARAM0_VALUE3 (0x1F000000U) /*!< Bit mask for EPDC_HIST8_PARAM0_VALUE3. */
#define BS_EPDC_HIST8_PARAM0_VALUE3 (5U)   /*!< Bit field size in bits for EPDC_HIST8_PARAM0_VALUE3. */

/*! @brief Read current value of the EPDC_HIST8_PARAM0_VALUE3 field. */
#define BR_EPDC_HIST8_PARAM0_VALUE3(x) (HW_EPDC_HIST8_PARAM0(x).B.VALUE3)

/*! @brief Format value for bitfield EPDC_HIST8_PARAM0_VALUE3. */
#define BF_EPDC_HIST8_PARAM0_VALUE3(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST8_PARAM0_VALUE3) & BM_EPDC_HIST8_PARAM0_VALUE3)

/*! @brief Set the VALUE3 field to a new value. */
#define BW_EPDC_HIST8_PARAM0_VALUE3(x, v) (HW_EPDC_HIST8_PARAM0_WR(x, (HW_EPDC_HIST8_PARAM0_RD(x) & ~BM_EPDC_HIST8_PARAM0_VALUE3) | BF_EPDC_HIST8_PARAM0_VALUE3(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_HIST8_PARAM1 - 8-level Histogram Parameter 1 Register.
 ******************************************************************************/

/*!
 * @brief HW_EPDC_HIST8_PARAM1 - 8-level Histogram Parameter 1 Register. (RW)
 *
 * Reset value: 0x0F0D0B09U
 *
 * This register specifies four of the valid values for an 8-level histogram. If
 * all pixels in a bitmap match these two values, STATUS[2] will be set at the
 * end of frame processing. All comparator values should be programmed such that
 * they are consistent with the TFT_PIXEL_FORMAT control field.
 */
typedef union _hw_epdc_hist8_param1
{
    uint32_t U;
    struct _hw_epdc_hist8_param1_bitfields
    {
        uint32_t VALUE4 : 5;           /*!< [4:0]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t VALUE5 : 5;           /*!< [12:8]  */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t VALUE6 : 5;           /*!< [20:16]  */
        uint32_t RESERVED2 : 3;        /*!< [23:21]  */
        uint32_t VALUE7 : 5;           /*!< [28:24]  */
        uint32_t RESERVED3 : 3;        /*!< [31:29]  */
    } B;
} hw_epdc_hist8_param1_t;

/*!
 * @name Constants and macros for entire EPDC_HIST8_PARAM1 register
 */
/*@{*/
#define HW_EPDC_HIST8_PARAM1_ADDR(x) ((uintptr_t)(x) + 0x640U)

#define HW_EPDC_HIST8_PARAM1(x)  (*(__IO hw_epdc_hist8_param1_t *) HW_EPDC_HIST8_PARAM1_ADDR(x))
#define HW_EPDC_HIST8_PARAM1_RD(x) (HW_EPDC_HIST8_PARAM1(x).U)
#define HW_EPDC_HIST8_PARAM1_WR(x, v) (HW_EPDC_HIST8_PARAM1(x).U = (v))
#define HW_EPDC_HIST8_PARAM1_SET(x, v) (HW_EPDC_HIST8_PARAM1_WR(x, HW_EPDC_HIST8_PARAM1_RD(x) |  (v)))
#define HW_EPDC_HIST8_PARAM1_CLR(x, v) (HW_EPDC_HIST8_PARAM1_WR(x, HW_EPDC_HIST8_PARAM1_RD(x) & ~(v)))
#define HW_EPDC_HIST8_PARAM1_TOG(x, v) (HW_EPDC_HIST8_PARAM1_WR(x, HW_EPDC_HIST8_PARAM1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_HIST8_PARAM1 bitfields
 */

/*!
 * @name Register EPDC_HIST8_PARAM1, field VALUE4[4:0] (RW)
 *
 * GRAY4 value for 8-level histogram
 */
/*@{*/
#define BP_EPDC_HIST8_PARAM1_VALUE4 (0U)   /*!< Bit position for EPDC_HIST8_PARAM1_VALUE4. */
#define BM_EPDC_HIST8_PARAM1_VALUE4 (0x0000001FU) /*!< Bit mask for EPDC_HIST8_PARAM1_VALUE4. */
#define BS_EPDC_HIST8_PARAM1_VALUE4 (5U)   /*!< Bit field size in bits for EPDC_HIST8_PARAM1_VALUE4. */

/*! @brief Read current value of the EPDC_HIST8_PARAM1_VALUE4 field. */
#define BR_EPDC_HIST8_PARAM1_VALUE4(x) (HW_EPDC_HIST8_PARAM1(x).B.VALUE4)

/*! @brief Format value for bitfield EPDC_HIST8_PARAM1_VALUE4. */
#define BF_EPDC_HIST8_PARAM1_VALUE4(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST8_PARAM1_VALUE4) & BM_EPDC_HIST8_PARAM1_VALUE4)

/*! @brief Set the VALUE4 field to a new value. */
#define BW_EPDC_HIST8_PARAM1_VALUE4(x, v) (HW_EPDC_HIST8_PARAM1_WR(x, (HW_EPDC_HIST8_PARAM1_RD(x) & ~BM_EPDC_HIST8_PARAM1_VALUE4) | BF_EPDC_HIST8_PARAM1_VALUE4(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST8_PARAM1, field VALUE5[12:8] (RW)
 *
 * GRAY5 value for 8-level histogram
 */
/*@{*/
#define BP_EPDC_HIST8_PARAM1_VALUE5 (8U)   /*!< Bit position for EPDC_HIST8_PARAM1_VALUE5. */
#define BM_EPDC_HIST8_PARAM1_VALUE5 (0x00001F00U) /*!< Bit mask for EPDC_HIST8_PARAM1_VALUE5. */
#define BS_EPDC_HIST8_PARAM1_VALUE5 (5U)   /*!< Bit field size in bits for EPDC_HIST8_PARAM1_VALUE5. */

/*! @brief Read current value of the EPDC_HIST8_PARAM1_VALUE5 field. */
#define BR_EPDC_HIST8_PARAM1_VALUE5(x) (HW_EPDC_HIST8_PARAM1(x).B.VALUE5)

/*! @brief Format value for bitfield EPDC_HIST8_PARAM1_VALUE5. */
#define BF_EPDC_HIST8_PARAM1_VALUE5(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST8_PARAM1_VALUE5) & BM_EPDC_HIST8_PARAM1_VALUE5)

/*! @brief Set the VALUE5 field to a new value. */
#define BW_EPDC_HIST8_PARAM1_VALUE5(x, v) (HW_EPDC_HIST8_PARAM1_WR(x, (HW_EPDC_HIST8_PARAM1_RD(x) & ~BM_EPDC_HIST8_PARAM1_VALUE5) | BF_EPDC_HIST8_PARAM1_VALUE5(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST8_PARAM1, field VALUE6[20:16] (RW)
 *
 * GRAY6 value for 8-level histogram
 */
/*@{*/
#define BP_EPDC_HIST8_PARAM1_VALUE6 (16U)  /*!< Bit position for EPDC_HIST8_PARAM1_VALUE6. */
#define BM_EPDC_HIST8_PARAM1_VALUE6 (0x001F0000U) /*!< Bit mask for EPDC_HIST8_PARAM1_VALUE6. */
#define BS_EPDC_HIST8_PARAM1_VALUE6 (5U)   /*!< Bit field size in bits for EPDC_HIST8_PARAM1_VALUE6. */

/*! @brief Read current value of the EPDC_HIST8_PARAM1_VALUE6 field. */
#define BR_EPDC_HIST8_PARAM1_VALUE6(x) (HW_EPDC_HIST8_PARAM1(x).B.VALUE6)

/*! @brief Format value for bitfield EPDC_HIST8_PARAM1_VALUE6. */
#define BF_EPDC_HIST8_PARAM1_VALUE6(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST8_PARAM1_VALUE6) & BM_EPDC_HIST8_PARAM1_VALUE6)

/*! @brief Set the VALUE6 field to a new value. */
#define BW_EPDC_HIST8_PARAM1_VALUE6(x, v) (HW_EPDC_HIST8_PARAM1_WR(x, (HW_EPDC_HIST8_PARAM1_RD(x) & ~BM_EPDC_HIST8_PARAM1_VALUE6) | BF_EPDC_HIST8_PARAM1_VALUE6(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST8_PARAM1, field VALUE7[28:24] (RW)
 *
 * GRAY7 (White) value for 8-level histogram
 */
/*@{*/
#define BP_EPDC_HIST8_PARAM1_VALUE7 (24U)  /*!< Bit position for EPDC_HIST8_PARAM1_VALUE7. */
#define BM_EPDC_HIST8_PARAM1_VALUE7 (0x1F000000U) /*!< Bit mask for EPDC_HIST8_PARAM1_VALUE7. */
#define BS_EPDC_HIST8_PARAM1_VALUE7 (5U)   /*!< Bit field size in bits for EPDC_HIST8_PARAM1_VALUE7. */

/*! @brief Read current value of the EPDC_HIST8_PARAM1_VALUE7 field. */
#define BR_EPDC_HIST8_PARAM1_VALUE7(x) (HW_EPDC_HIST8_PARAM1(x).B.VALUE7)

/*! @brief Format value for bitfield EPDC_HIST8_PARAM1_VALUE7. */
#define BF_EPDC_HIST8_PARAM1_VALUE7(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST8_PARAM1_VALUE7) & BM_EPDC_HIST8_PARAM1_VALUE7)

/*! @brief Set the VALUE7 field to a new value. */
#define BW_EPDC_HIST8_PARAM1_VALUE7(x, v) (HW_EPDC_HIST8_PARAM1_WR(x, (HW_EPDC_HIST8_PARAM1_RD(x) & ~BM_EPDC_HIST8_PARAM1_VALUE7) | BF_EPDC_HIST8_PARAM1_VALUE7(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_HIST16_PARAM0 - 16-level Histogram Parameter 0 Register.
 ******************************************************************************/

/*!
 * @brief HW_EPDC_HIST16_PARAM0 - 16-level Histogram Parameter 0 Register. (RW)
 *
 * Reset value: 0x03020100U
 *
 * This register specifies four of the valid values for a 16-level histogram. If
 * all pixels in a bitmap match these two values, STATUS[3] will be set at the
 * end of frame processing. All comparator values should be programmed such that
 * they are consistent with the TFT_PIXEL_FORMAT control field.
 */
typedef union _hw_epdc_hist16_param0
{
    uint32_t U;
    struct _hw_epdc_hist16_param0_bitfields
    {
        uint32_t VALUE0 : 5;           /*!< [4:0]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t VALUE1 : 5;           /*!< [12:8]  */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t VALUE2 : 5;           /*!< [20:16]  */
        uint32_t RESERVED2 : 3;        /*!< [23:21]  */
        uint32_t VALUE3 : 5;           /*!< [28:24]  */
        uint32_t RESERVED3 : 3;        /*!< [31:29]  */
    } B;
} hw_epdc_hist16_param0_t;

/*!
 * @name Constants and macros for entire EPDC_HIST16_PARAM0 register
 */
/*@{*/
#define HW_EPDC_HIST16_PARAM0_ADDR(x) ((uintptr_t)(x) + 0x650U)

#define HW_EPDC_HIST16_PARAM0(x) (*(__IO hw_epdc_hist16_param0_t *) HW_EPDC_HIST16_PARAM0_ADDR(x))
#define HW_EPDC_HIST16_PARAM0_RD(x) (HW_EPDC_HIST16_PARAM0(x).U)
#define HW_EPDC_HIST16_PARAM0_WR(x, v) (HW_EPDC_HIST16_PARAM0(x).U = (v))
#define HW_EPDC_HIST16_PARAM0_SET(x, v) (HW_EPDC_HIST16_PARAM0_WR(x, HW_EPDC_HIST16_PARAM0_RD(x) |  (v)))
#define HW_EPDC_HIST16_PARAM0_CLR(x, v) (HW_EPDC_HIST16_PARAM0_WR(x, HW_EPDC_HIST16_PARAM0_RD(x) & ~(v)))
#define HW_EPDC_HIST16_PARAM0_TOG(x, v) (HW_EPDC_HIST16_PARAM0_WR(x, HW_EPDC_HIST16_PARAM0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_HIST16_PARAM0 bitfields
 */

/*!
 * @name Register EPDC_HIST16_PARAM0, field VALUE0[4:0] (RW)
 *
 * GRAY0 (Black) value for 16-level histogram
 */
/*@{*/
#define BP_EPDC_HIST16_PARAM0_VALUE0 (0U)  /*!< Bit position for EPDC_HIST16_PARAM0_VALUE0. */
#define BM_EPDC_HIST16_PARAM0_VALUE0 (0x0000001FU) /*!< Bit mask for EPDC_HIST16_PARAM0_VALUE0. */
#define BS_EPDC_HIST16_PARAM0_VALUE0 (5U)  /*!< Bit field size in bits for EPDC_HIST16_PARAM0_VALUE0. */

/*! @brief Read current value of the EPDC_HIST16_PARAM0_VALUE0 field. */
#define BR_EPDC_HIST16_PARAM0_VALUE0(x) (HW_EPDC_HIST16_PARAM0(x).B.VALUE0)

/*! @brief Format value for bitfield EPDC_HIST16_PARAM0_VALUE0. */
#define BF_EPDC_HIST16_PARAM0_VALUE0(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST16_PARAM0_VALUE0) & BM_EPDC_HIST16_PARAM0_VALUE0)

/*! @brief Set the VALUE0 field to a new value. */
#define BW_EPDC_HIST16_PARAM0_VALUE0(x, v) (HW_EPDC_HIST16_PARAM0_WR(x, (HW_EPDC_HIST16_PARAM0_RD(x) & ~BM_EPDC_HIST16_PARAM0_VALUE0) | BF_EPDC_HIST16_PARAM0_VALUE0(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST16_PARAM0, field VALUE1[12:8] (RW)
 *
 * GRAY1 value for 16-level histogram
 */
/*@{*/
#define BP_EPDC_HIST16_PARAM0_VALUE1 (8U)  /*!< Bit position for EPDC_HIST16_PARAM0_VALUE1. */
#define BM_EPDC_HIST16_PARAM0_VALUE1 (0x00001F00U) /*!< Bit mask for EPDC_HIST16_PARAM0_VALUE1. */
#define BS_EPDC_HIST16_PARAM0_VALUE1 (5U)  /*!< Bit field size in bits for EPDC_HIST16_PARAM0_VALUE1. */

/*! @brief Read current value of the EPDC_HIST16_PARAM0_VALUE1 field. */
#define BR_EPDC_HIST16_PARAM0_VALUE1(x) (HW_EPDC_HIST16_PARAM0(x).B.VALUE1)

/*! @brief Format value for bitfield EPDC_HIST16_PARAM0_VALUE1. */
#define BF_EPDC_HIST16_PARAM0_VALUE1(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST16_PARAM0_VALUE1) & BM_EPDC_HIST16_PARAM0_VALUE1)

/*! @brief Set the VALUE1 field to a new value. */
#define BW_EPDC_HIST16_PARAM0_VALUE1(x, v) (HW_EPDC_HIST16_PARAM0_WR(x, (HW_EPDC_HIST16_PARAM0_RD(x) & ~BM_EPDC_HIST16_PARAM0_VALUE1) | BF_EPDC_HIST16_PARAM0_VALUE1(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST16_PARAM0, field VALUE2[20:16] (RW)
 *
 * GRAY2 value for 16-level histogram
 */
/*@{*/
#define BP_EPDC_HIST16_PARAM0_VALUE2 (16U) /*!< Bit position for EPDC_HIST16_PARAM0_VALUE2. */
#define BM_EPDC_HIST16_PARAM0_VALUE2 (0x001F0000U) /*!< Bit mask for EPDC_HIST16_PARAM0_VALUE2. */
#define BS_EPDC_HIST16_PARAM0_VALUE2 (5U)  /*!< Bit field size in bits for EPDC_HIST16_PARAM0_VALUE2. */

/*! @brief Read current value of the EPDC_HIST16_PARAM0_VALUE2 field. */
#define BR_EPDC_HIST16_PARAM0_VALUE2(x) (HW_EPDC_HIST16_PARAM0(x).B.VALUE2)

/*! @brief Format value for bitfield EPDC_HIST16_PARAM0_VALUE2. */
#define BF_EPDC_HIST16_PARAM0_VALUE2(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST16_PARAM0_VALUE2) & BM_EPDC_HIST16_PARAM0_VALUE2)

/*! @brief Set the VALUE2 field to a new value. */
#define BW_EPDC_HIST16_PARAM0_VALUE2(x, v) (HW_EPDC_HIST16_PARAM0_WR(x, (HW_EPDC_HIST16_PARAM0_RD(x) & ~BM_EPDC_HIST16_PARAM0_VALUE2) | BF_EPDC_HIST16_PARAM0_VALUE2(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST16_PARAM0, field VALUE3[28:24] (RW)
 *
 * GRAY3 value for 16-level histogram
 */
/*@{*/
#define BP_EPDC_HIST16_PARAM0_VALUE3 (24U) /*!< Bit position for EPDC_HIST16_PARAM0_VALUE3. */
#define BM_EPDC_HIST16_PARAM0_VALUE3 (0x1F000000U) /*!< Bit mask for EPDC_HIST16_PARAM0_VALUE3. */
#define BS_EPDC_HIST16_PARAM0_VALUE3 (5U)  /*!< Bit field size in bits for EPDC_HIST16_PARAM0_VALUE3. */

/*! @brief Read current value of the EPDC_HIST16_PARAM0_VALUE3 field. */
#define BR_EPDC_HIST16_PARAM0_VALUE3(x) (HW_EPDC_HIST16_PARAM0(x).B.VALUE3)

/*! @brief Format value for bitfield EPDC_HIST16_PARAM0_VALUE3. */
#define BF_EPDC_HIST16_PARAM0_VALUE3(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST16_PARAM0_VALUE3) & BM_EPDC_HIST16_PARAM0_VALUE3)

/*! @brief Set the VALUE3 field to a new value. */
#define BW_EPDC_HIST16_PARAM0_VALUE3(x, v) (HW_EPDC_HIST16_PARAM0_WR(x, (HW_EPDC_HIST16_PARAM0_RD(x) & ~BM_EPDC_HIST16_PARAM0_VALUE3) | BF_EPDC_HIST16_PARAM0_VALUE3(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_HIST16_PARAM1 - 16-level Histogram Parameter Register.
 ******************************************************************************/

/*!
 * @brief HW_EPDC_HIST16_PARAM1 - 16-level Histogram Parameter Register. (RW)
 *
 * Reset value: 0x07060504U
 *
 * This register specifies four of the valid values for a 16-level histogram. If
 * all pixels in a bitmap match these two values, STATUS[3] will be set at the
 * end of frame processing. All comparator values should be programmed such that
 * they are consistent with the TFT_PIXEL_FORMAT control field.
 */
typedef union _hw_epdc_hist16_param1
{
    uint32_t U;
    struct _hw_epdc_hist16_param1_bitfields
    {
        uint32_t VALUE4 : 5;           /*!< [4:0]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t VALUE5 : 5;           /*!< [12:8]  */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t VALUE6 : 5;           /*!< [20:16]  */
        uint32_t RESERVED2 : 3;        /*!< [23:21]  */
        uint32_t VALUE7 : 5;           /*!< [28:24]  */
        uint32_t RESERVED3 : 3;        /*!< [31:29]  */
    } B;
} hw_epdc_hist16_param1_t;

/*!
 * @name Constants and macros for entire EPDC_HIST16_PARAM1 register
 */
/*@{*/
#define HW_EPDC_HIST16_PARAM1_ADDR(x) ((uintptr_t)(x) + 0x660U)

#define HW_EPDC_HIST16_PARAM1(x) (*(__IO hw_epdc_hist16_param1_t *) HW_EPDC_HIST16_PARAM1_ADDR(x))
#define HW_EPDC_HIST16_PARAM1_RD(x) (HW_EPDC_HIST16_PARAM1(x).U)
#define HW_EPDC_HIST16_PARAM1_WR(x, v) (HW_EPDC_HIST16_PARAM1(x).U = (v))
#define HW_EPDC_HIST16_PARAM1_SET(x, v) (HW_EPDC_HIST16_PARAM1_WR(x, HW_EPDC_HIST16_PARAM1_RD(x) |  (v)))
#define HW_EPDC_HIST16_PARAM1_CLR(x, v) (HW_EPDC_HIST16_PARAM1_WR(x, HW_EPDC_HIST16_PARAM1_RD(x) & ~(v)))
#define HW_EPDC_HIST16_PARAM1_TOG(x, v) (HW_EPDC_HIST16_PARAM1_WR(x, HW_EPDC_HIST16_PARAM1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_HIST16_PARAM1 bitfields
 */

/*!
 * @name Register EPDC_HIST16_PARAM1, field VALUE4[4:0] (RW)
 *
 * GRAY4 value for 16-level histogram
 */
/*@{*/
#define BP_EPDC_HIST16_PARAM1_VALUE4 (0U)  /*!< Bit position for EPDC_HIST16_PARAM1_VALUE4. */
#define BM_EPDC_HIST16_PARAM1_VALUE4 (0x0000001FU) /*!< Bit mask for EPDC_HIST16_PARAM1_VALUE4. */
#define BS_EPDC_HIST16_PARAM1_VALUE4 (5U)  /*!< Bit field size in bits for EPDC_HIST16_PARAM1_VALUE4. */

/*! @brief Read current value of the EPDC_HIST16_PARAM1_VALUE4 field. */
#define BR_EPDC_HIST16_PARAM1_VALUE4(x) (HW_EPDC_HIST16_PARAM1(x).B.VALUE4)

/*! @brief Format value for bitfield EPDC_HIST16_PARAM1_VALUE4. */
#define BF_EPDC_HIST16_PARAM1_VALUE4(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST16_PARAM1_VALUE4) & BM_EPDC_HIST16_PARAM1_VALUE4)

/*! @brief Set the VALUE4 field to a new value. */
#define BW_EPDC_HIST16_PARAM1_VALUE4(x, v) (HW_EPDC_HIST16_PARAM1_WR(x, (HW_EPDC_HIST16_PARAM1_RD(x) & ~BM_EPDC_HIST16_PARAM1_VALUE4) | BF_EPDC_HIST16_PARAM1_VALUE4(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST16_PARAM1, field VALUE5[12:8] (RW)
 *
 * GRAY5 value for 16-level histogram
 */
/*@{*/
#define BP_EPDC_HIST16_PARAM1_VALUE5 (8U)  /*!< Bit position for EPDC_HIST16_PARAM1_VALUE5. */
#define BM_EPDC_HIST16_PARAM1_VALUE5 (0x00001F00U) /*!< Bit mask for EPDC_HIST16_PARAM1_VALUE5. */
#define BS_EPDC_HIST16_PARAM1_VALUE5 (5U)  /*!< Bit field size in bits for EPDC_HIST16_PARAM1_VALUE5. */

/*! @brief Read current value of the EPDC_HIST16_PARAM1_VALUE5 field. */
#define BR_EPDC_HIST16_PARAM1_VALUE5(x) (HW_EPDC_HIST16_PARAM1(x).B.VALUE5)

/*! @brief Format value for bitfield EPDC_HIST16_PARAM1_VALUE5. */
#define BF_EPDC_HIST16_PARAM1_VALUE5(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST16_PARAM1_VALUE5) & BM_EPDC_HIST16_PARAM1_VALUE5)

/*! @brief Set the VALUE5 field to a new value. */
#define BW_EPDC_HIST16_PARAM1_VALUE5(x, v) (HW_EPDC_HIST16_PARAM1_WR(x, (HW_EPDC_HIST16_PARAM1_RD(x) & ~BM_EPDC_HIST16_PARAM1_VALUE5) | BF_EPDC_HIST16_PARAM1_VALUE5(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST16_PARAM1, field VALUE6[20:16] (RW)
 *
 * GRAY6 value for 16-level histogram
 */
/*@{*/
#define BP_EPDC_HIST16_PARAM1_VALUE6 (16U) /*!< Bit position for EPDC_HIST16_PARAM1_VALUE6. */
#define BM_EPDC_HIST16_PARAM1_VALUE6 (0x001F0000U) /*!< Bit mask for EPDC_HIST16_PARAM1_VALUE6. */
#define BS_EPDC_HIST16_PARAM1_VALUE6 (5U)  /*!< Bit field size in bits for EPDC_HIST16_PARAM1_VALUE6. */

/*! @brief Read current value of the EPDC_HIST16_PARAM1_VALUE6 field. */
#define BR_EPDC_HIST16_PARAM1_VALUE6(x) (HW_EPDC_HIST16_PARAM1(x).B.VALUE6)

/*! @brief Format value for bitfield EPDC_HIST16_PARAM1_VALUE6. */
#define BF_EPDC_HIST16_PARAM1_VALUE6(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST16_PARAM1_VALUE6) & BM_EPDC_HIST16_PARAM1_VALUE6)

/*! @brief Set the VALUE6 field to a new value. */
#define BW_EPDC_HIST16_PARAM1_VALUE6(x, v) (HW_EPDC_HIST16_PARAM1_WR(x, (HW_EPDC_HIST16_PARAM1_RD(x) & ~BM_EPDC_HIST16_PARAM1_VALUE6) | BF_EPDC_HIST16_PARAM1_VALUE6(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST16_PARAM1, field VALUE7[28:24] (RW)
 *
 * GRAY7 value for 16-level histogram
 */
/*@{*/
#define BP_EPDC_HIST16_PARAM1_VALUE7 (24U) /*!< Bit position for EPDC_HIST16_PARAM1_VALUE7. */
#define BM_EPDC_HIST16_PARAM1_VALUE7 (0x1F000000U) /*!< Bit mask for EPDC_HIST16_PARAM1_VALUE7. */
#define BS_EPDC_HIST16_PARAM1_VALUE7 (5U)  /*!< Bit field size in bits for EPDC_HIST16_PARAM1_VALUE7. */

/*! @brief Read current value of the EPDC_HIST16_PARAM1_VALUE7 field. */
#define BR_EPDC_HIST16_PARAM1_VALUE7(x) (HW_EPDC_HIST16_PARAM1(x).B.VALUE7)

/*! @brief Format value for bitfield EPDC_HIST16_PARAM1_VALUE7. */
#define BF_EPDC_HIST16_PARAM1_VALUE7(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST16_PARAM1_VALUE7) & BM_EPDC_HIST16_PARAM1_VALUE7)

/*! @brief Set the VALUE7 field to a new value. */
#define BW_EPDC_HIST16_PARAM1_VALUE7(x, v) (HW_EPDC_HIST16_PARAM1_WR(x, (HW_EPDC_HIST16_PARAM1_RD(x) & ~BM_EPDC_HIST16_PARAM1_VALUE7) | BF_EPDC_HIST16_PARAM1_VALUE7(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_HIST16_PARAM2 - 16-level Histogram Parameter Register.
 ******************************************************************************/

/*!
 * @brief HW_EPDC_HIST16_PARAM2 - 16-level Histogram Parameter Register. (RW)
 *
 * Reset value: 0x0B0A0908U
 *
 * This register specifies four of the valid values for a 16-level histogram. If
 * all pixels in a bitmap match these two values, STATUS[3] will be set at the
 * end of frame processing. All comparator values should be programmed such that
 * they are consistent with the TFT_PIXEL_FORMAT control field.
 */
typedef union _hw_epdc_hist16_param2
{
    uint32_t U;
    struct _hw_epdc_hist16_param2_bitfields
    {
        uint32_t VALUE8 : 5;           /*!< [4:0]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t VALUE9 : 5;           /*!< [12:8]  */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t VALUE10 : 5;          /*!< [20:16]  */
        uint32_t RESERVED2 : 3;        /*!< [23:21]  */
        uint32_t VALUE11 : 5;          /*!< [28:24]  */
        uint32_t RESERVED3 : 3;        /*!< [31:29]  */
    } B;
} hw_epdc_hist16_param2_t;

/*!
 * @name Constants and macros for entire EPDC_HIST16_PARAM2 register
 */
/*@{*/
#define HW_EPDC_HIST16_PARAM2_ADDR(x) ((uintptr_t)(x) + 0x670U)

#define HW_EPDC_HIST16_PARAM2(x) (*(__IO hw_epdc_hist16_param2_t *) HW_EPDC_HIST16_PARAM2_ADDR(x))
#define HW_EPDC_HIST16_PARAM2_RD(x) (HW_EPDC_HIST16_PARAM2(x).U)
#define HW_EPDC_HIST16_PARAM2_WR(x, v) (HW_EPDC_HIST16_PARAM2(x).U = (v))
#define HW_EPDC_HIST16_PARAM2_SET(x, v) (HW_EPDC_HIST16_PARAM2_WR(x, HW_EPDC_HIST16_PARAM2_RD(x) |  (v)))
#define HW_EPDC_HIST16_PARAM2_CLR(x, v) (HW_EPDC_HIST16_PARAM2_WR(x, HW_EPDC_HIST16_PARAM2_RD(x) & ~(v)))
#define HW_EPDC_HIST16_PARAM2_TOG(x, v) (HW_EPDC_HIST16_PARAM2_WR(x, HW_EPDC_HIST16_PARAM2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_HIST16_PARAM2 bitfields
 */

/*!
 * @name Register EPDC_HIST16_PARAM2, field VALUE8[4:0] (RW)
 *
 * GRAY8 value for 16-level histogram
 */
/*@{*/
#define BP_EPDC_HIST16_PARAM2_VALUE8 (0U)  /*!< Bit position for EPDC_HIST16_PARAM2_VALUE8. */
#define BM_EPDC_HIST16_PARAM2_VALUE8 (0x0000001FU) /*!< Bit mask for EPDC_HIST16_PARAM2_VALUE8. */
#define BS_EPDC_HIST16_PARAM2_VALUE8 (5U)  /*!< Bit field size in bits for EPDC_HIST16_PARAM2_VALUE8. */

/*! @brief Read current value of the EPDC_HIST16_PARAM2_VALUE8 field. */
#define BR_EPDC_HIST16_PARAM2_VALUE8(x) (HW_EPDC_HIST16_PARAM2(x).B.VALUE8)

/*! @brief Format value for bitfield EPDC_HIST16_PARAM2_VALUE8. */
#define BF_EPDC_HIST16_PARAM2_VALUE8(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST16_PARAM2_VALUE8) & BM_EPDC_HIST16_PARAM2_VALUE8)

/*! @brief Set the VALUE8 field to a new value. */
#define BW_EPDC_HIST16_PARAM2_VALUE8(x, v) (HW_EPDC_HIST16_PARAM2_WR(x, (HW_EPDC_HIST16_PARAM2_RD(x) & ~BM_EPDC_HIST16_PARAM2_VALUE8) | BF_EPDC_HIST16_PARAM2_VALUE8(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST16_PARAM2, field VALUE9[12:8] (RW)
 *
 * GRAY9 value for 16-level histogram
 */
/*@{*/
#define BP_EPDC_HIST16_PARAM2_VALUE9 (8U)  /*!< Bit position for EPDC_HIST16_PARAM2_VALUE9. */
#define BM_EPDC_HIST16_PARAM2_VALUE9 (0x00001F00U) /*!< Bit mask for EPDC_HIST16_PARAM2_VALUE9. */
#define BS_EPDC_HIST16_PARAM2_VALUE9 (5U)  /*!< Bit field size in bits for EPDC_HIST16_PARAM2_VALUE9. */

/*! @brief Read current value of the EPDC_HIST16_PARAM2_VALUE9 field. */
#define BR_EPDC_HIST16_PARAM2_VALUE9(x) (HW_EPDC_HIST16_PARAM2(x).B.VALUE9)

/*! @brief Format value for bitfield EPDC_HIST16_PARAM2_VALUE9. */
#define BF_EPDC_HIST16_PARAM2_VALUE9(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST16_PARAM2_VALUE9) & BM_EPDC_HIST16_PARAM2_VALUE9)

/*! @brief Set the VALUE9 field to a new value. */
#define BW_EPDC_HIST16_PARAM2_VALUE9(x, v) (HW_EPDC_HIST16_PARAM2_WR(x, (HW_EPDC_HIST16_PARAM2_RD(x) & ~BM_EPDC_HIST16_PARAM2_VALUE9) | BF_EPDC_HIST16_PARAM2_VALUE9(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST16_PARAM2, field VALUE10[20:16] (RW)
 *
 * GRAY10 value for 16-level histogram
 */
/*@{*/
#define BP_EPDC_HIST16_PARAM2_VALUE10 (16U) /*!< Bit position for EPDC_HIST16_PARAM2_VALUE10. */
#define BM_EPDC_HIST16_PARAM2_VALUE10 (0x001F0000U) /*!< Bit mask for EPDC_HIST16_PARAM2_VALUE10. */
#define BS_EPDC_HIST16_PARAM2_VALUE10 (5U) /*!< Bit field size in bits for EPDC_HIST16_PARAM2_VALUE10. */

/*! @brief Read current value of the EPDC_HIST16_PARAM2_VALUE10 field. */
#define BR_EPDC_HIST16_PARAM2_VALUE10(x) (HW_EPDC_HIST16_PARAM2(x).B.VALUE10)

/*! @brief Format value for bitfield EPDC_HIST16_PARAM2_VALUE10. */
#define BF_EPDC_HIST16_PARAM2_VALUE10(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST16_PARAM2_VALUE10) & BM_EPDC_HIST16_PARAM2_VALUE10)

/*! @brief Set the VALUE10 field to a new value. */
#define BW_EPDC_HIST16_PARAM2_VALUE10(x, v) (HW_EPDC_HIST16_PARAM2_WR(x, (HW_EPDC_HIST16_PARAM2_RD(x) & ~BM_EPDC_HIST16_PARAM2_VALUE10) | BF_EPDC_HIST16_PARAM2_VALUE10(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST16_PARAM2, field VALUE11[28:24] (RW)
 *
 * GRAY11 value for 16-level histogram
 */
/*@{*/
#define BP_EPDC_HIST16_PARAM2_VALUE11 (24U) /*!< Bit position for EPDC_HIST16_PARAM2_VALUE11. */
#define BM_EPDC_HIST16_PARAM2_VALUE11 (0x1F000000U) /*!< Bit mask for EPDC_HIST16_PARAM2_VALUE11. */
#define BS_EPDC_HIST16_PARAM2_VALUE11 (5U) /*!< Bit field size in bits for EPDC_HIST16_PARAM2_VALUE11. */

/*! @brief Read current value of the EPDC_HIST16_PARAM2_VALUE11 field. */
#define BR_EPDC_HIST16_PARAM2_VALUE11(x) (HW_EPDC_HIST16_PARAM2(x).B.VALUE11)

/*! @brief Format value for bitfield EPDC_HIST16_PARAM2_VALUE11. */
#define BF_EPDC_HIST16_PARAM2_VALUE11(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST16_PARAM2_VALUE11) & BM_EPDC_HIST16_PARAM2_VALUE11)

/*! @brief Set the VALUE11 field to a new value. */
#define BW_EPDC_HIST16_PARAM2_VALUE11(x, v) (HW_EPDC_HIST16_PARAM2_WR(x, (HW_EPDC_HIST16_PARAM2_RD(x) & ~BM_EPDC_HIST16_PARAM2_VALUE11) | BF_EPDC_HIST16_PARAM2_VALUE11(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_HIST16_PARAM3 - 16-level Histogram Parameter Register.
 ******************************************************************************/

/*!
 * @brief HW_EPDC_HIST16_PARAM3 - 16-level Histogram Parameter Register. (RW)
 *
 * Reset value: 0x0F0E0D0CU
 *
 * This register specifies four of the valid values for a 16-level histogram. If
 * all pixels in a bitmap match these two values, STATUS[3] will be set at the
 * end of frame processing. All comparator values should be programmed such that
 * they are consistent with the TFT_PIXEL_FORMAT control field.
 */
typedef union _hw_epdc_hist16_param3
{
    uint32_t U;
    struct _hw_epdc_hist16_param3_bitfields
    {
        uint32_t VALUE12 : 5;          /*!< [4:0]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t VALUE13 : 5;          /*!< [12:8]  */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t VALUE14 : 5;          /*!< [20:16]  */
        uint32_t RESERVED2 : 3;        /*!< [23:21]  */
        uint32_t VALUE15 : 5;          /*!< [28:24]  */
        uint32_t RESERVED3 : 3;        /*!< [31:29]  */
    } B;
} hw_epdc_hist16_param3_t;

/*!
 * @name Constants and macros for entire EPDC_HIST16_PARAM3 register
 */
/*@{*/
#define HW_EPDC_HIST16_PARAM3_ADDR(x) ((uintptr_t)(x) + 0x680U)

#define HW_EPDC_HIST16_PARAM3(x) (*(__IO hw_epdc_hist16_param3_t *) HW_EPDC_HIST16_PARAM3_ADDR(x))
#define HW_EPDC_HIST16_PARAM3_RD(x) (HW_EPDC_HIST16_PARAM3(x).U)
#define HW_EPDC_HIST16_PARAM3_WR(x, v) (HW_EPDC_HIST16_PARAM3(x).U = (v))
#define HW_EPDC_HIST16_PARAM3_SET(x, v) (HW_EPDC_HIST16_PARAM3_WR(x, HW_EPDC_HIST16_PARAM3_RD(x) |  (v)))
#define HW_EPDC_HIST16_PARAM3_CLR(x, v) (HW_EPDC_HIST16_PARAM3_WR(x, HW_EPDC_HIST16_PARAM3_RD(x) & ~(v)))
#define HW_EPDC_HIST16_PARAM3_TOG(x, v) (HW_EPDC_HIST16_PARAM3_WR(x, HW_EPDC_HIST16_PARAM3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_HIST16_PARAM3 bitfields
 */

/*!
 * @name Register EPDC_HIST16_PARAM3, field VALUE12[4:0] (RW)
 *
 * GRAY12 value for 16-level histogram
 */
/*@{*/
#define BP_EPDC_HIST16_PARAM3_VALUE12 (0U) /*!< Bit position for EPDC_HIST16_PARAM3_VALUE12. */
#define BM_EPDC_HIST16_PARAM3_VALUE12 (0x0000001FU) /*!< Bit mask for EPDC_HIST16_PARAM3_VALUE12. */
#define BS_EPDC_HIST16_PARAM3_VALUE12 (5U) /*!< Bit field size in bits for EPDC_HIST16_PARAM3_VALUE12. */

/*! @brief Read current value of the EPDC_HIST16_PARAM3_VALUE12 field. */
#define BR_EPDC_HIST16_PARAM3_VALUE12(x) (HW_EPDC_HIST16_PARAM3(x).B.VALUE12)

/*! @brief Format value for bitfield EPDC_HIST16_PARAM3_VALUE12. */
#define BF_EPDC_HIST16_PARAM3_VALUE12(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST16_PARAM3_VALUE12) & BM_EPDC_HIST16_PARAM3_VALUE12)

/*! @brief Set the VALUE12 field to a new value. */
#define BW_EPDC_HIST16_PARAM3_VALUE12(x, v) (HW_EPDC_HIST16_PARAM3_WR(x, (HW_EPDC_HIST16_PARAM3_RD(x) & ~BM_EPDC_HIST16_PARAM3_VALUE12) | BF_EPDC_HIST16_PARAM3_VALUE12(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST16_PARAM3, field VALUE13[12:8] (RW)
 *
 * GRAY13 value for 16-level histogram
 */
/*@{*/
#define BP_EPDC_HIST16_PARAM3_VALUE13 (8U) /*!< Bit position for EPDC_HIST16_PARAM3_VALUE13. */
#define BM_EPDC_HIST16_PARAM3_VALUE13 (0x00001F00U) /*!< Bit mask for EPDC_HIST16_PARAM3_VALUE13. */
#define BS_EPDC_HIST16_PARAM3_VALUE13 (5U) /*!< Bit field size in bits for EPDC_HIST16_PARAM3_VALUE13. */

/*! @brief Read current value of the EPDC_HIST16_PARAM3_VALUE13 field. */
#define BR_EPDC_HIST16_PARAM3_VALUE13(x) (HW_EPDC_HIST16_PARAM3(x).B.VALUE13)

/*! @brief Format value for bitfield EPDC_HIST16_PARAM3_VALUE13. */
#define BF_EPDC_HIST16_PARAM3_VALUE13(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST16_PARAM3_VALUE13) & BM_EPDC_HIST16_PARAM3_VALUE13)

/*! @brief Set the VALUE13 field to a new value. */
#define BW_EPDC_HIST16_PARAM3_VALUE13(x, v) (HW_EPDC_HIST16_PARAM3_WR(x, (HW_EPDC_HIST16_PARAM3_RD(x) & ~BM_EPDC_HIST16_PARAM3_VALUE13) | BF_EPDC_HIST16_PARAM3_VALUE13(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST16_PARAM3, field VALUE14[20:16] (RW)
 *
 * GRAY14 value for 16-level histogram
 */
/*@{*/
#define BP_EPDC_HIST16_PARAM3_VALUE14 (16U) /*!< Bit position for EPDC_HIST16_PARAM3_VALUE14. */
#define BM_EPDC_HIST16_PARAM3_VALUE14 (0x001F0000U) /*!< Bit mask for EPDC_HIST16_PARAM3_VALUE14. */
#define BS_EPDC_HIST16_PARAM3_VALUE14 (5U) /*!< Bit field size in bits for EPDC_HIST16_PARAM3_VALUE14. */

/*! @brief Read current value of the EPDC_HIST16_PARAM3_VALUE14 field. */
#define BR_EPDC_HIST16_PARAM3_VALUE14(x) (HW_EPDC_HIST16_PARAM3(x).B.VALUE14)

/*! @brief Format value for bitfield EPDC_HIST16_PARAM3_VALUE14. */
#define BF_EPDC_HIST16_PARAM3_VALUE14(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST16_PARAM3_VALUE14) & BM_EPDC_HIST16_PARAM3_VALUE14)

/*! @brief Set the VALUE14 field to a new value. */
#define BW_EPDC_HIST16_PARAM3_VALUE14(x, v) (HW_EPDC_HIST16_PARAM3_WR(x, (HW_EPDC_HIST16_PARAM3_RD(x) & ~BM_EPDC_HIST16_PARAM3_VALUE14) | BF_EPDC_HIST16_PARAM3_VALUE14(v)))
/*@}*/

/*!
 * @name Register EPDC_HIST16_PARAM3, field VALUE15[28:24] (RW)
 *
 * GRAY15 (White) value for 16-level histogram
 */
/*@{*/
#define BP_EPDC_HIST16_PARAM3_VALUE15 (24U) /*!< Bit position for EPDC_HIST16_PARAM3_VALUE15. */
#define BM_EPDC_HIST16_PARAM3_VALUE15 (0x1F000000U) /*!< Bit mask for EPDC_HIST16_PARAM3_VALUE15. */
#define BS_EPDC_HIST16_PARAM3_VALUE15 (5U) /*!< Bit field size in bits for EPDC_HIST16_PARAM3_VALUE15. */

/*! @brief Read current value of the EPDC_HIST16_PARAM3_VALUE15 field. */
#define BR_EPDC_HIST16_PARAM3_VALUE15(x) (HW_EPDC_HIST16_PARAM3(x).B.VALUE15)

/*! @brief Format value for bitfield EPDC_HIST16_PARAM3_VALUE15. */
#define BF_EPDC_HIST16_PARAM3_VALUE15(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_HIST16_PARAM3_VALUE15) & BM_EPDC_HIST16_PARAM3_VALUE15)

/*! @brief Set the VALUE15 field to a new value. */
#define BW_EPDC_HIST16_PARAM3_VALUE15(x, v) (HW_EPDC_HIST16_PARAM3_WR(x, (HW_EPDC_HIST16_PARAM3_RD(x) & ~BM_EPDC_HIST16_PARAM3_VALUE15) | BF_EPDC_HIST16_PARAM3_VALUE15(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_GPIO - EPDC General Purpose I/O Debug register
 ******************************************************************************/

/*!
 * @brief HW_EPDC_GPIO - EPDC General Purpose I/O Debug register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPIO register to control ipp_epdc_bdr[1:0], ipp_epdc_pwr[3:0] and
 * ipp_epdc_pwrcom output signals Houses software control signal reisters
 */
typedef union _hw_epdc_gpio
{
    uint32_t U;
    struct _hw_epdc_gpio_bitfields
    {
        uint32_t BDR : 2;              /*!< [1:0]  */
        uint32_t PWRCTRL : 4;          /*!< [5:2]  */
        uint32_t PWRCOM : 1;           /*!< [6]  */
        uint32_t PWRWAKE : 1;          /*!< [7]  */
        uint32_t PWRSTAT : 1;          /*!< [8]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_epdc_gpio_t;

/*!
 * @name Constants and macros for entire EPDC_GPIO register
 */
/*@{*/
#define HW_EPDC_GPIO_ADDR(x)     ((uintptr_t)(x) + 0x700U)
#define HW_EPDC_GPIO_SET_ADDR(x) (HW_EPDC_GPIO_ADDR(x) + 0x4U)
#define HW_EPDC_GPIO_CLR_ADDR(x) (HW_EPDC_GPIO_ADDR(x) + 0x8U)
#define HW_EPDC_GPIO_TOG_ADDR(x) (HW_EPDC_GPIO_ADDR(x) + 0xCU)

#define HW_EPDC_GPIO(x)          (*(__IO hw_epdc_gpio_t *) HW_EPDC_GPIO_ADDR(x))
#define HW_EPDC_GPIO_RD(x)       (HW_EPDC_GPIO(x).U)
#define HW_EPDC_GPIO_WR(x, v)    (HW_EPDC_GPIO(x).U = (v))
#define HW_EPDC_GPIO_SET(x, v)   ((*(uint32_t *) HW_EPDC_GPIO_SET_ADDR(x)) = (v))
#define HW_EPDC_GPIO_CLR(x, v)   ((*(uint32_t *) HW_EPDC_GPIO_CLR_ADDR(x)) = (v))
#define HW_EPDC_GPIO_TOG(x, v)   ((*(uint32_t *) HW_EPDC_GPIO_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual EPDC_GPIO bitfields
 */

/*!
 * @name Register EPDC_GPIO, field BDR[1:0] (RW)
 *
 * Controls ipp_epdc_bdr[1:0] output
 */
/*@{*/
#define BP_EPDC_GPIO_BDR     (0U)          /*!< Bit position for EPDC_GPIO_BDR. */
#define BM_EPDC_GPIO_BDR     (0x00000003U) /*!< Bit mask for EPDC_GPIO_BDR. */
#define BS_EPDC_GPIO_BDR     (2U)          /*!< Bit field size in bits for EPDC_GPIO_BDR. */

/*! @brief Read current value of the EPDC_GPIO_BDR field. */
#define BR_EPDC_GPIO_BDR(x)  (HW_EPDC_GPIO(x).B.BDR)

/*! @brief Format value for bitfield EPDC_GPIO_BDR. */
#define BF_EPDC_GPIO_BDR(v)  ((uint32_t)((uint32_t)(v) << BP_EPDC_GPIO_BDR) & BM_EPDC_GPIO_BDR)

/*! @brief Set the BDR field to a new value. */
#define BW_EPDC_GPIO_BDR(x, v) (HW_EPDC_GPIO_WR(x, (HW_EPDC_GPIO_RD(x) & ~BM_EPDC_GPIO_BDR) | BF_EPDC_GPIO_BDR(v)))
/*@}*/

/*!
 * @name Register EPDC_GPIO, field PWRCTRL[5:2] (RW)
 *
 * Controls ipp_epdc_pwrctrl[3:0] output
 */
/*@{*/
#define BP_EPDC_GPIO_PWRCTRL (2U)          /*!< Bit position for EPDC_GPIO_PWRCTRL. */
#define BM_EPDC_GPIO_PWRCTRL (0x0000003CU) /*!< Bit mask for EPDC_GPIO_PWRCTRL. */
#define BS_EPDC_GPIO_PWRCTRL (4U)          /*!< Bit field size in bits for EPDC_GPIO_PWRCTRL. */

/*! @brief Read current value of the EPDC_GPIO_PWRCTRL field. */
#define BR_EPDC_GPIO_PWRCTRL(x) (HW_EPDC_GPIO(x).B.PWRCTRL)

/*! @brief Format value for bitfield EPDC_GPIO_PWRCTRL. */
#define BF_EPDC_GPIO_PWRCTRL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_GPIO_PWRCTRL) & BM_EPDC_GPIO_PWRCTRL)

/*! @brief Set the PWRCTRL field to a new value. */
#define BW_EPDC_GPIO_PWRCTRL(x, v) (HW_EPDC_GPIO_WR(x, (HW_EPDC_GPIO_RD(x) & ~BM_EPDC_GPIO_PWRCTRL) | BF_EPDC_GPIO_PWRCTRL(v)))
/*@}*/

/*!
 * @name Register EPDC_GPIO, field PWRCOM[6] (RW)
 *
 * Controls ipp_epdc_pwrcom output
 */
/*@{*/
#define BP_EPDC_GPIO_PWRCOM  (6U)          /*!< Bit position for EPDC_GPIO_PWRCOM. */
#define BM_EPDC_GPIO_PWRCOM  (0x00000040U) /*!< Bit mask for EPDC_GPIO_PWRCOM. */
#define BS_EPDC_GPIO_PWRCOM  (1U)          /*!< Bit field size in bits for EPDC_GPIO_PWRCOM. */

/*! @brief Read current value of the EPDC_GPIO_PWRCOM field. */
#define BR_EPDC_GPIO_PWRCOM(x) (HW_EPDC_GPIO(x).B.PWRCOM)

/*! @brief Format value for bitfield EPDC_GPIO_PWRCOM. */
#define BF_EPDC_GPIO_PWRCOM(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_GPIO_PWRCOM) & BM_EPDC_GPIO_PWRCOM)

/*! @brief Set the PWRCOM field to a new value. */
#define BW_EPDC_GPIO_PWRCOM(x, v) (HW_EPDC_GPIO_WR(x, (HW_EPDC_GPIO_RD(x) & ~BM_EPDC_GPIO_PWRCOM) | BF_EPDC_GPIO_PWRCOM(v)))
/*@}*/

/*!
 * @name Register EPDC_GPIO, field PWRWAKE[7] (RW)
 *
 * Controls ipp_epdc_pwrwake output
 */
/*@{*/
#define BP_EPDC_GPIO_PWRWAKE (7U)          /*!< Bit position for EPDC_GPIO_PWRWAKE. */
#define BM_EPDC_GPIO_PWRWAKE (0x00000080U) /*!< Bit mask for EPDC_GPIO_PWRWAKE. */
#define BS_EPDC_GPIO_PWRWAKE (1U)          /*!< Bit field size in bits for EPDC_GPIO_PWRWAKE. */

/*! @brief Read current value of the EPDC_GPIO_PWRWAKE field. */
#define BR_EPDC_GPIO_PWRWAKE(x) (HW_EPDC_GPIO(x).B.PWRWAKE)

/*! @brief Format value for bitfield EPDC_GPIO_PWRWAKE. */
#define BF_EPDC_GPIO_PWRWAKE(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_GPIO_PWRWAKE) & BM_EPDC_GPIO_PWRWAKE)

/*! @brief Set the PWRWAKE field to a new value. */
#define BW_EPDC_GPIO_PWRWAKE(x, v) (HW_EPDC_GPIO_WR(x, (HW_EPDC_GPIO_RD(x) & ~BM_EPDC_GPIO_PWRWAKE) | BF_EPDC_GPIO_PWRWAKE(v)))
/*@}*/

/*!
 * @name Register EPDC_GPIO, field PWRSTAT[8] (RO)
 *
 * reflect ipp_epdc_pwrstat input
 */
/*@{*/
#define BP_EPDC_GPIO_PWRSTAT (8U)          /*!< Bit position for EPDC_GPIO_PWRSTAT. */
#define BM_EPDC_GPIO_PWRSTAT (0x00000100U) /*!< Bit mask for EPDC_GPIO_PWRSTAT. */
#define BS_EPDC_GPIO_PWRSTAT (1U)          /*!< Bit field size in bits for EPDC_GPIO_PWRSTAT. */

/*! @brief Read current value of the EPDC_GPIO_PWRSTAT field. */
#define BR_EPDC_GPIO_PWRSTAT(x) (HW_EPDC_GPIO(x).B.PWRSTAT)
/*@}*/




/*******************************************************************************
 * HW_EPDC_VERSION - EPDC Version Register
 ******************************************************************************/

/*!
 * @brief HW_EPDC_VERSION - EPDC Version Register (RO)
 *
 * Reset value: 0x03000000U
 *
 * This register reflects the version number for the EPDC. EXAMPLE No Example.
 */
typedef union _hw_epdc_version
{
    uint32_t U;
    struct _hw_epdc_version_bitfields
    {
        uint32_t STEP : 16;            /*!< [15:0]  */
        uint32_t MINOR : 8;            /*!< [23:16]  */
        uint32_t MAJOR : 8;            /*!< [31:24]  */
    } B;
} hw_epdc_version_t;

/*!
 * @name Constants and macros for entire EPDC_VERSION register
 */
/*@{*/
#define HW_EPDC_VERSION_ADDR(x)  ((uintptr_t)(x) + 0x7F0U)

#define HW_EPDC_VERSION(x)       (*(__I hw_epdc_version_t *) HW_EPDC_VERSION_ADDR(x))
#define HW_EPDC_VERSION_RD(x)    (HW_EPDC_VERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual EPDC_VERSION bitfields
 */

/*!
 * @name Register EPDC_VERSION, field STEP[15:0] (RO)
 *
 * Fixed read-only value reflecting the stepping of the RTL version.
 */
/*@{*/
#define BP_EPDC_VERSION_STEP (0U)          /*!< Bit position for EPDC_VERSION_STEP. */
#define BM_EPDC_VERSION_STEP (0x0000FFFFU) /*!< Bit mask for EPDC_VERSION_STEP. */
#define BS_EPDC_VERSION_STEP (16U)         /*!< Bit field size in bits for EPDC_VERSION_STEP. */

/*! @brief Read current value of the EPDC_VERSION_STEP field. */
#define BR_EPDC_VERSION_STEP(x) (HW_EPDC_VERSION(x).B.STEP)
/*@}*/

/*!
 * @name Register EPDC_VERSION, field MINOR[23:16] (RO)
 *
 * Fixed read-only value reflecting the MINOR field of the RTL version.
 */
/*@{*/
#define BP_EPDC_VERSION_MINOR (16U)        /*!< Bit position for EPDC_VERSION_MINOR. */
#define BM_EPDC_VERSION_MINOR (0x00FF0000U) /*!< Bit mask for EPDC_VERSION_MINOR. */
#define BS_EPDC_VERSION_MINOR (8U)         /*!< Bit field size in bits for EPDC_VERSION_MINOR. */

/*! @brief Read current value of the EPDC_VERSION_MINOR field. */
#define BR_EPDC_VERSION_MINOR(x) (HW_EPDC_VERSION(x).B.MINOR)
/*@}*/

/*!
 * @name Register EPDC_VERSION, field MAJOR[31:24] (RO)
 *
 * Fixed read-only value reflecting the MAJOR field of the RTL version.
 */
/*@{*/
#define BP_EPDC_VERSION_MAJOR (24U)        /*!< Bit position for EPDC_VERSION_MAJOR. */
#define BM_EPDC_VERSION_MAJOR (0xFF000000U) /*!< Bit mask for EPDC_VERSION_MAJOR. */
#define BS_EPDC_VERSION_MAJOR (8U)         /*!< Bit field size in bits for EPDC_VERSION_MAJOR. */

/*! @brief Read current value of the EPDC_VERSION_MAJOR field. */
#define BR_EPDC_VERSION_MAJOR(x) (HW_EPDC_VERSION(x).B.MAJOR)
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_0_0 - Panel Interface Signal Generator Register 0_0
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_0_0 - Panel Interface Signal Generator Register 0_0 (RW)
 *
 * Reset value: 0x00000F00U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_0_0
{
    uint32_t U;
    struct _hw_epdc_pigeon_0_0_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t POL : 1;              /*!< [1]  */
        uint32_t INC_SEL : 2;          /*!< [3:2]  */
        uint32_t OFFSET : 4;           /*!< [7:4]  */
        uint32_t MASK_CNT_SEL : 4;     /*!< [11:8]  */
        uint32_t MASK_CNT : 12;        /*!< [23:12]  */
        uint32_t STATE_MASK : 8;       /*!< [31:24]  */
    } B;
} hw_epdc_pigeon_0_0_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_0_0 register
 */
/*@{*/
#define HW_EPDC_PIGEON_0_0_ADDR(x) ((uintptr_t)(x) + 0x800U)

#define HW_EPDC_PIGEON_0_0(x)    (*(__IO hw_epdc_pigeon_0_0_t *) HW_EPDC_PIGEON_0_0_ADDR(x))
#define HW_EPDC_PIGEON_0_0_RD(x) (HW_EPDC_PIGEON_0_0(x).U)
#define HW_EPDC_PIGEON_0_0_WR(x, v) (HW_EPDC_PIGEON_0_0(x).U = (v))
#define HW_EPDC_PIGEON_0_0_SET(x, v) (HW_EPDC_PIGEON_0_0_WR(x, HW_EPDC_PIGEON_0_0_RD(x) |  (v)))
#define HW_EPDC_PIGEON_0_0_CLR(x, v) (HW_EPDC_PIGEON_0_0_WR(x, HW_EPDC_PIGEON_0_0_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_0_0_TOG(x, v) (HW_EPDC_PIGEON_0_0_WR(x, HW_EPDC_PIGEON_0_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_0_0 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_0_0, field EN[0] (RW)
 *
 * enable pigeon mode on this signal
 */
/*@{*/
#define BP_EPDC_PIGEON_0_0_EN (0U)         /*!< Bit position for EPDC_PIGEON_0_0_EN. */
#define BM_EPDC_PIGEON_0_0_EN (0x00000001U) /*!< Bit mask for EPDC_PIGEON_0_0_EN. */
#define BS_EPDC_PIGEON_0_0_EN (1U)         /*!< Bit field size in bits for EPDC_PIGEON_0_0_EN. */

/*! @brief Read current value of the EPDC_PIGEON_0_0_EN field. */
#define BR_EPDC_PIGEON_0_0_EN(x) (HW_EPDC_PIGEON_0_0(x).B.EN)

/*! @brief Format value for bitfield EPDC_PIGEON_0_0_EN. */
#define BF_EPDC_PIGEON_0_0_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_0_0_EN) & BM_EPDC_PIGEON_0_0_EN)

/*! @brief Set the EN field to a new value. */
#define BW_EPDC_PIGEON_0_0_EN(x, v) (HW_EPDC_PIGEON_0_0_WR(x, (HW_EPDC_PIGEON_0_0_RD(x) & ~BM_EPDC_PIGEON_0_0_EN) | BF_EPDC_PIGEON_0_0_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_0_0, field POL[1] (RW)
 *
 * polarity of signal output
 *
 * Values:
 * - 0 - normal signal (active high)
 * - 1 - inverted signal (active low)
 */
/*@{*/
#define BP_EPDC_PIGEON_0_0_POL (1U)        /*!< Bit position for EPDC_PIGEON_0_0_POL. */
#define BM_EPDC_PIGEON_0_0_POL (0x00000002U) /*!< Bit mask for EPDC_PIGEON_0_0_POL. */
#define BS_EPDC_PIGEON_0_0_POL (1U)        /*!< Bit field size in bits for EPDC_PIGEON_0_0_POL. */

#define BV_EPDC_PIGEON_0_0_POL_ACTIVE_HIGH (0U)      /*!< Bit field value for EPDC_PIGEON_0_0_POL: normal signal (active high) */
#define BV_EPDC_PIGEON_0_0_POL_ACTIVE_LOW (0x1U)     /*!< Bit field value for EPDC_PIGEON_0_0_POL: inverted signal (active low) */

/*! @brief Read current value of the EPDC_PIGEON_0_0_POL field. */
#define BR_EPDC_PIGEON_0_0_POL(x) (HW_EPDC_PIGEON_0_0(x).B.POL)

/*! @brief Format value for bitfield EPDC_PIGEON_0_0_POL. */
#define BF_EPDC_PIGEON_0_0_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_0_0_POL) & BM_EPDC_PIGEON_0_0_POL)

/*! @brief Set the POL field to a new value. */
#define BW_EPDC_PIGEON_0_0_POL(x, v) (HW_EPDC_PIGEON_0_0_WR(x, (HW_EPDC_PIGEON_0_0_RD(x) & ~BM_EPDC_PIGEON_0_0_POL) | BF_EPDC_PIGEON_0_0_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_0_0, field INC_SEL[3:2] (RW)
 *
 * event to incrment local counter
 *
 * Values:
 * - 0 - pclk
 * - 1 - line start pulse
 * - 10 - frame start pulse
 * - 11 - use another signal as tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_0_0_INC_SEL (2U)    /*!< Bit position for EPDC_PIGEON_0_0_INC_SEL. */
#define BM_EPDC_PIGEON_0_0_INC_SEL (0x0000000CU) /*!< Bit mask for EPDC_PIGEON_0_0_INC_SEL. */
#define BS_EPDC_PIGEON_0_0_INC_SEL (2U)    /*!< Bit field size in bits for EPDC_PIGEON_0_0_INC_SEL. */

#define BV_EPDC_PIGEON_0_0_INC_SEL_PCLK (0U)         /*!< Bit field value for EPDC_PIGEON_0_0_INC_SEL: pclk */
#define BV_EPDC_PIGEON_0_0_INC_SEL_LINE (0x1U)       /*!< Bit field value for EPDC_PIGEON_0_0_INC_SEL: line start pulse */
#define BV_EPDC_PIGEON_0_0_INC_SEL_FRAME (0x2U)      /*!< Bit field value for EPDC_PIGEON_0_0_INC_SEL: frame start pulse */
#define BV_EPDC_PIGEON_0_0_INC_SEL_SIG_ANOTHER (0x3U) /*!< Bit field value for EPDC_PIGEON_0_0_INC_SEL: use another signal as tick event */

/*! @brief Read current value of the EPDC_PIGEON_0_0_INC_SEL field. */
#define BR_EPDC_PIGEON_0_0_INC_SEL(x) (HW_EPDC_PIGEON_0_0(x).B.INC_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_0_0_INC_SEL. */
#define BF_EPDC_PIGEON_0_0_INC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_0_0_INC_SEL) & BM_EPDC_PIGEON_0_0_INC_SEL)

/*! @brief Set the INC_SEL field to a new value. */
#define BW_EPDC_PIGEON_0_0_INC_SEL(x, v) (HW_EPDC_PIGEON_0_0_WR(x, (HW_EPDC_PIGEON_0_0_RD(x) & ~BM_EPDC_PIGEON_0_0_INC_SEL) | BF_EPDC_PIGEON_0_0_INC_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_0_0, field OFFSET[7:4] (RW)
 *
 * offset on pclk unit. 0=aligne with data, positive value means delay, minus
 * value mean ahead. Supported range depends on panel mode
 */
/*@{*/
#define BP_EPDC_PIGEON_0_0_OFFSET (4U)     /*!< Bit position for EPDC_PIGEON_0_0_OFFSET. */
#define BM_EPDC_PIGEON_0_0_OFFSET (0x000000F0U) /*!< Bit mask for EPDC_PIGEON_0_0_OFFSET. */
#define BS_EPDC_PIGEON_0_0_OFFSET (4U)     /*!< Bit field size in bits for EPDC_PIGEON_0_0_OFFSET. */

/*! @brief Read current value of the EPDC_PIGEON_0_0_OFFSET field. */
#define BR_EPDC_PIGEON_0_0_OFFSET(x) (HW_EPDC_PIGEON_0_0(x).B.OFFSET)

/*! @brief Format value for bitfield EPDC_PIGEON_0_0_OFFSET. */
#define BF_EPDC_PIGEON_0_0_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_0_0_OFFSET) & BM_EPDC_PIGEON_0_0_OFFSET)

/*! @brief Set the OFFSET field to a new value. */
#define BW_EPDC_PIGEON_0_0_OFFSET(x, v) (HW_EPDC_PIGEON_0_0_WR(x, (HW_EPDC_PIGEON_0_0_RD(x) & ~BM_EPDC_PIGEON_0_0_OFFSET) | BF_EPDC_PIGEON_0_0_OFFSET(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_0_0, field MASK_CNT_SEL[11:8] (RW)
 *
 * select global counters as mask condition, use together with MASK_CNT
 *
 * Values:
 * - 0 - pclk counter within one hscan state
 * - 1 - pclk cycle within one hscan state
 * - 10 - line counter within one vscan state
 * - 11 - line cycle within one vscan state
 * - 100 - frame counter
 * - 101 - frame cycle
 * - 110 - horizontal counter (pclk counter within one line )
 * - 111 - vertical counter (line counter within one frame)
 */
/*@{*/
#define BP_EPDC_PIGEON_0_0_MASK_CNT_SEL (8U) /*!< Bit position for EPDC_PIGEON_0_0_MASK_CNT_SEL. */
#define BM_EPDC_PIGEON_0_0_MASK_CNT_SEL (0x00000F00U) /*!< Bit mask for EPDC_PIGEON_0_0_MASK_CNT_SEL. */
#define BS_EPDC_PIGEON_0_0_MASK_CNT_SEL (4U) /*!< Bit field size in bits for EPDC_PIGEON_0_0_MASK_CNT_SEL. */

#define BV_EPDC_PIGEON_0_0_MASK_CNT_SEL_HSTATE_CNT (0U) /*!< Bit field value for EPDC_PIGEON_0_0_MASK_CNT_SEL: pclk counter within one hscan state */
#define BV_EPDC_PIGEON_0_0_MASK_CNT_SEL_HSTATE_CYCLE (0x1U) /*!< Bit field value for EPDC_PIGEON_0_0_MASK_CNT_SEL: pclk cycle within one hscan state */
#define BV_EPDC_PIGEON_0_0_MASK_CNT_SEL_VSTATE_CNT (0x2U) /*!< Bit field value for EPDC_PIGEON_0_0_MASK_CNT_SEL: line counter within one vscan state */
#define BV_EPDC_PIGEON_0_0_MASK_CNT_SEL_VSTATE_CYCLE (0x3U) /*!< Bit field value for EPDC_PIGEON_0_0_MASK_CNT_SEL: line cycle within one vscan state */
#define BV_EPDC_PIGEON_0_0_MASK_CNT_SEL_FRAME_CNT (0x4U) /*!< Bit field value for EPDC_PIGEON_0_0_MASK_CNT_SEL: frame counter */
#define BV_EPDC_PIGEON_0_0_MASK_CNT_SEL_FRAME_CYCLE (0x5U) /*!< Bit field value for EPDC_PIGEON_0_0_MASK_CNT_SEL: frame cycle */
#define BV_EPDC_PIGEON_0_0_MASK_CNT_SEL_HCNT (0x6U)  /*!< Bit field value for EPDC_PIGEON_0_0_MASK_CNT_SEL: horizontal counter (pclk counter within one line ) */
#define BV_EPDC_PIGEON_0_0_MASK_CNT_SEL_VCNT (0x7U)  /*!< Bit field value for EPDC_PIGEON_0_0_MASK_CNT_SEL: vertical counter (line counter within one frame) */

/*! @brief Read current value of the EPDC_PIGEON_0_0_MASK_CNT_SEL field. */
#define BR_EPDC_PIGEON_0_0_MASK_CNT_SEL(x) (HW_EPDC_PIGEON_0_0(x).B.MASK_CNT_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_0_0_MASK_CNT_SEL. */
#define BF_EPDC_PIGEON_0_0_MASK_CNT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_0_0_MASK_CNT_SEL) & BM_EPDC_PIGEON_0_0_MASK_CNT_SEL)

/*! @brief Set the MASK_CNT_SEL field to a new value. */
#define BW_EPDC_PIGEON_0_0_MASK_CNT_SEL(x, v) (HW_EPDC_PIGEON_0_0_WR(x, (HW_EPDC_PIGEON_0_0_RD(x) & ~BM_EPDC_PIGEON_0_0_MASK_CNT_SEL) | BF_EPDC_PIGEON_0_0_MASK_CNT_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_0_0, field MASK_CNT[23:12] (RW)
 *
 * When the global counter selected through MASK_CNT_SEL matches value in this
 * reg, pigeon local counter start ticking. 0=disable
 */
/*@{*/
#define BP_EPDC_PIGEON_0_0_MASK_CNT (12U)  /*!< Bit position for EPDC_PIGEON_0_0_MASK_CNT. */
#define BM_EPDC_PIGEON_0_0_MASK_CNT (0x00FFF000U) /*!< Bit mask for EPDC_PIGEON_0_0_MASK_CNT. */
#define BS_EPDC_PIGEON_0_0_MASK_CNT (12U)  /*!< Bit field size in bits for EPDC_PIGEON_0_0_MASK_CNT. */

/*! @brief Read current value of the EPDC_PIGEON_0_0_MASK_CNT field. */
#define BR_EPDC_PIGEON_0_0_MASK_CNT(x) (HW_EPDC_PIGEON_0_0(x).B.MASK_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_0_0_MASK_CNT. */
#define BF_EPDC_PIGEON_0_0_MASK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_0_0_MASK_CNT) & BM_EPDC_PIGEON_0_0_MASK_CNT)

/*! @brief Set the MASK_CNT field to a new value. */
#define BW_EPDC_PIGEON_0_0_MASK_CNT(x, v) (HW_EPDC_PIGEON_0_0_WR(x, (HW_EPDC_PIGEON_0_0_RD(x) & ~BM_EPDC_PIGEON_0_0_MASK_CNT) | BF_EPDC_PIGEON_0_0_MASK_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_0_0, field STATE_MASK[31:24] (RW)
 *
 * state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan
 * states as reference point for local counter to start ticking
 *
 * Values:
 * - 1 - FRAME SYNC
 * - 10 - FRAME BEGIN
 * - 100 - FRAME DATA
 * - 1000 - FRAME END
 * - 10000 - LINE SYNC
 * - 100000 - LINE BEGIN
 * - 1000000 - LINE DATA
 * - 10000000 - LINE END
 */
/*@{*/
#define BP_EPDC_PIGEON_0_0_STATE_MASK (24U) /*!< Bit position for EPDC_PIGEON_0_0_STATE_MASK. */
#define BM_EPDC_PIGEON_0_0_STATE_MASK (0xFF000000U) /*!< Bit mask for EPDC_PIGEON_0_0_STATE_MASK. */
#define BS_EPDC_PIGEON_0_0_STATE_MASK (8U) /*!< Bit field size in bits for EPDC_PIGEON_0_0_STATE_MASK. */

#define BV_EPDC_PIGEON_0_0_STATE_MASK_FS (0x1U)      /*!< Bit field value for EPDC_PIGEON_0_0_STATE_MASK: FRAME SYNC */
#define BV_EPDC_PIGEON_0_0_STATE_MASK_FB (0x2U)      /*!< Bit field value for EPDC_PIGEON_0_0_STATE_MASK: FRAME BEGIN */
#define BV_EPDC_PIGEON_0_0_STATE_MASK_FD (0x4U)      /*!< Bit field value for EPDC_PIGEON_0_0_STATE_MASK: FRAME DATA */
#define BV_EPDC_PIGEON_0_0_STATE_MASK_FE (0x8U)      /*!< Bit field value for EPDC_PIGEON_0_0_STATE_MASK: FRAME END */
#define BV_EPDC_PIGEON_0_0_STATE_MASK_LS (0x10U)     /*!< Bit field value for EPDC_PIGEON_0_0_STATE_MASK: LINE SYNC */
#define BV_EPDC_PIGEON_0_0_STATE_MASK_LB (0x20U)     /*!< Bit field value for EPDC_PIGEON_0_0_STATE_MASK: LINE BEGIN */
#define BV_EPDC_PIGEON_0_0_STATE_MASK_LD (0x40U)     /*!< Bit field value for EPDC_PIGEON_0_0_STATE_MASK: LINE DATA */
#define BV_EPDC_PIGEON_0_0_STATE_MASK_LE (0x80U)     /*!< Bit field value for EPDC_PIGEON_0_0_STATE_MASK: LINE END */

/*! @brief Read current value of the EPDC_PIGEON_0_0_STATE_MASK field. */
#define BR_EPDC_PIGEON_0_0_STATE_MASK(x) (HW_EPDC_PIGEON_0_0(x).B.STATE_MASK)

/*! @brief Format value for bitfield EPDC_PIGEON_0_0_STATE_MASK. */
#define BF_EPDC_PIGEON_0_0_STATE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_0_0_STATE_MASK) & BM_EPDC_PIGEON_0_0_STATE_MASK)

/*! @brief Set the STATE_MASK field to a new value. */
#define BW_EPDC_PIGEON_0_0_STATE_MASK(x, v) (HW_EPDC_PIGEON_0_0_WR(x, (HW_EPDC_PIGEON_0_0_RD(x) & ~BM_EPDC_PIGEON_0_0_STATE_MASK) | BF_EPDC_PIGEON_0_0_STATE_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_0_1 - Panel Interface Signal Generator Register 0_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_0_1 - Panel Interface Signal Generator Register 0_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_0_1
{
    uint32_t U;
    struct _hw_epdc_pigeon_0_1_bitfields
    {
        uint32_t SET_CNT : 16;         /*!< [15:0]  */
        uint32_t CLR_CNT : 16;         /*!< [31:16]  */
    } B;
} hw_epdc_pigeon_0_1_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_0_1 register
 */
/*@{*/
#define HW_EPDC_PIGEON_0_1_ADDR(x) ((uintptr_t)(x) + 0x810U)

#define HW_EPDC_PIGEON_0_1(x)    (*(__IO hw_epdc_pigeon_0_1_t *) HW_EPDC_PIGEON_0_1_ADDR(x))
#define HW_EPDC_PIGEON_0_1_RD(x) (HW_EPDC_PIGEON_0_1(x).U)
#define HW_EPDC_PIGEON_0_1_WR(x, v) (HW_EPDC_PIGEON_0_1(x).U = (v))
#define HW_EPDC_PIGEON_0_1_SET(x, v) (HW_EPDC_PIGEON_0_1_WR(x, HW_EPDC_PIGEON_0_1_RD(x) |  (v)))
#define HW_EPDC_PIGEON_0_1_CLR(x, v) (HW_EPDC_PIGEON_0_1_WR(x, HW_EPDC_PIGEON_0_1_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_0_1_TOG(x, v) (HW_EPDC_PIGEON_0_1_WR(x, HW_EPDC_PIGEON_0_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_0_1 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_0_1, field SET_CNT[15:0] (RW)
 *
 * assert signal output when counter match this value
 *
 * Values:
 * - 0 - start as active
 */
/*@{*/
#define BP_EPDC_PIGEON_0_1_SET_CNT (0U)    /*!< Bit position for EPDC_PIGEON_0_1_SET_CNT. */
#define BM_EPDC_PIGEON_0_1_SET_CNT (0x0000FFFFU) /*!< Bit mask for EPDC_PIGEON_0_1_SET_CNT. */
#define BS_EPDC_PIGEON_0_1_SET_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_0_1_SET_CNT. */

#define BV_EPDC_PIGEON_0_1_SET_CNT_START_ACTIVE (0U) /*!< Bit field value for EPDC_PIGEON_0_1_SET_CNT: start as active */

/*! @brief Read current value of the EPDC_PIGEON_0_1_SET_CNT field. */
#define BR_EPDC_PIGEON_0_1_SET_CNT(x) (HW_EPDC_PIGEON_0_1(x).B.SET_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_0_1_SET_CNT. */
#define BF_EPDC_PIGEON_0_1_SET_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_0_1_SET_CNT) & BM_EPDC_PIGEON_0_1_SET_CNT)

/*! @brief Set the SET_CNT field to a new value. */
#define BW_EPDC_PIGEON_0_1_SET_CNT(x, v) (HW_EPDC_PIGEON_0_1_WR(x, (HW_EPDC_PIGEON_0_1_RD(x) & ~BM_EPDC_PIGEON_0_1_SET_CNT) | BF_EPDC_PIGEON_0_1_SET_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_0_1, field CLR_CNT[31:16] (RW)
 *
 * deassert signal output when counter match this value
 *
 * Values:
 * - 0 - keep active until mask off
 */
/*@{*/
#define BP_EPDC_PIGEON_0_1_CLR_CNT (16U)   /*!< Bit position for EPDC_PIGEON_0_1_CLR_CNT. */
#define BM_EPDC_PIGEON_0_1_CLR_CNT (0xFFFF0000U) /*!< Bit mask for EPDC_PIGEON_0_1_CLR_CNT. */
#define BS_EPDC_PIGEON_0_1_CLR_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_0_1_CLR_CNT. */

#define BV_EPDC_PIGEON_0_1_CLR_CNT_CLEAR_USING_MASK (0U) /*!< Bit field value for EPDC_PIGEON_0_1_CLR_CNT: keep active until mask off */

/*! @brief Read current value of the EPDC_PIGEON_0_1_CLR_CNT field. */
#define BR_EPDC_PIGEON_0_1_CLR_CNT(x) (HW_EPDC_PIGEON_0_1(x).B.CLR_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_0_1_CLR_CNT. */
#define BF_EPDC_PIGEON_0_1_CLR_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_0_1_CLR_CNT) & BM_EPDC_PIGEON_0_1_CLR_CNT)

/*! @brief Set the CLR_CNT field to a new value. */
#define BW_EPDC_PIGEON_0_1_CLR_CNT(x, v) (HW_EPDC_PIGEON_0_1_WR(x, (HW_EPDC_PIGEON_0_1_RD(x) & ~BM_EPDC_PIGEON_0_1_CLR_CNT) | BF_EPDC_PIGEON_0_1_CLR_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_0_2 - Panel Interface Signal Generator Register 0_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_0_2 - Panel Interface Signal Generator Register 0_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_0_2
{
    uint32_t U;
    struct _hw_epdc_pigeon_0_2_bitfields
    {
        uint32_t SIG_LOGIC : 4;        /*!< [3:0]  */
        uint32_t SIG_ANOTHER : 5;      /*!< [8:4]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_epdc_pigeon_0_2_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_0_2 register
 */
/*@{*/
#define HW_EPDC_PIGEON_0_2_ADDR(x) ((uintptr_t)(x) + 0x820U)

#define HW_EPDC_PIGEON_0_2(x)    (*(__IO hw_epdc_pigeon_0_2_t *) HW_EPDC_PIGEON_0_2_ADDR(x))
#define HW_EPDC_PIGEON_0_2_RD(x) (HW_EPDC_PIGEON_0_2(x).U)
#define HW_EPDC_PIGEON_0_2_WR(x, v) (HW_EPDC_PIGEON_0_2(x).U = (v))
#define HW_EPDC_PIGEON_0_2_SET(x, v) (HW_EPDC_PIGEON_0_2_WR(x, HW_EPDC_PIGEON_0_2_RD(x) |  (v)))
#define HW_EPDC_PIGEON_0_2_CLR(x, v) (HW_EPDC_PIGEON_0_2_WR(x, HW_EPDC_PIGEON_0_2_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_0_2_TOG(x, v) (HW_EPDC_PIGEON_0_2_WR(x, HW_EPDC_PIGEON_0_2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_0_2 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_0_2, field SIG_LOGIC[3:0] (RW)
 *
 * logic operation with another signal sigout : final output signal of this
 * generator mask : final mask of this generator this_sig : intermediate signal of
 * this generator before logic operation other_masks : intermediate mask result of
 * this generator before logic operation sig_another : signal selected other
 * generators
 *
 * Values:
 * - 0 - no logic operation
 * - 1 - sigout = sig_another AND this_sig
 * - 10 - sigout = sig_another OR this_sig
 * - 11 - mask = sig_another AND other_masks
 */
/*@{*/
#define BP_EPDC_PIGEON_0_2_SIG_LOGIC (0U)  /*!< Bit position for EPDC_PIGEON_0_2_SIG_LOGIC. */
#define BM_EPDC_PIGEON_0_2_SIG_LOGIC (0x0000000FU) /*!< Bit mask for EPDC_PIGEON_0_2_SIG_LOGIC. */
#define BS_EPDC_PIGEON_0_2_SIG_LOGIC (4U)  /*!< Bit field size in bits for EPDC_PIGEON_0_2_SIG_LOGIC. */

#define BV_EPDC_PIGEON_0_2_SIG_LOGIC_DIS (0U)        /*!< Bit field value for EPDC_PIGEON_0_2_SIG_LOGIC: no logic operation */
#define BV_EPDC_PIGEON_0_2_SIG_LOGIC_AND (0x1U)      /*!< Bit field value for EPDC_PIGEON_0_2_SIG_LOGIC: sigout = sig_another AND this_sig */
#define BV_EPDC_PIGEON_0_2_SIG_LOGIC_OR (0x2U)       /*!< Bit field value for EPDC_PIGEON_0_2_SIG_LOGIC: sigout = sig_another OR this_sig */
#define BV_EPDC_PIGEON_0_2_SIG_LOGIC_MASK (0x3U)     /*!< Bit field value for EPDC_PIGEON_0_2_SIG_LOGIC: mask = sig_another AND other_masks */

/*! @brief Read current value of the EPDC_PIGEON_0_2_SIG_LOGIC field. */
#define BR_EPDC_PIGEON_0_2_SIG_LOGIC(x) (HW_EPDC_PIGEON_0_2(x).B.SIG_LOGIC)

/*! @brief Format value for bitfield EPDC_PIGEON_0_2_SIG_LOGIC. */
#define BF_EPDC_PIGEON_0_2_SIG_LOGIC(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_0_2_SIG_LOGIC) & BM_EPDC_PIGEON_0_2_SIG_LOGIC)

/*! @brief Set the SIG_LOGIC field to a new value. */
#define BW_EPDC_PIGEON_0_2_SIG_LOGIC(x, v) (HW_EPDC_PIGEON_0_2_WR(x, (HW_EPDC_PIGEON_0_2_RD(x) & ~BM_EPDC_PIGEON_0_2_SIG_LOGIC) | BF_EPDC_PIGEON_0_2_SIG_LOGIC(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_0_2, field SIG_ANOTHER[8:4] (RW)
 *
 * select another signal for logic operation or as mask or counter tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_0_2_SIG_ANOTHER (4U) /*!< Bit position for EPDC_PIGEON_0_2_SIG_ANOTHER. */
#define BM_EPDC_PIGEON_0_2_SIG_ANOTHER (0x000001F0U) /*!< Bit mask for EPDC_PIGEON_0_2_SIG_ANOTHER. */
#define BS_EPDC_PIGEON_0_2_SIG_ANOTHER (5U) /*!< Bit field size in bits for EPDC_PIGEON_0_2_SIG_ANOTHER. */

/*! @brief Read current value of the EPDC_PIGEON_0_2_SIG_ANOTHER field. */
#define BR_EPDC_PIGEON_0_2_SIG_ANOTHER(x) (HW_EPDC_PIGEON_0_2(x).B.SIG_ANOTHER)

/*! @brief Format value for bitfield EPDC_PIGEON_0_2_SIG_ANOTHER. */
#define BF_EPDC_PIGEON_0_2_SIG_ANOTHER(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_0_2_SIG_ANOTHER) & BM_EPDC_PIGEON_0_2_SIG_ANOTHER)

/*! @brief Set the SIG_ANOTHER field to a new value. */
#define BW_EPDC_PIGEON_0_2_SIG_ANOTHER(x, v) (HW_EPDC_PIGEON_0_2_WR(x, (HW_EPDC_PIGEON_0_2_RD(x) & ~BM_EPDC_PIGEON_0_2_SIG_ANOTHER) | BF_EPDC_PIGEON_0_2_SIG_ANOTHER(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_1_0 - Panel Interface Signal Generator Register 1_0
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_1_0 - Panel Interface Signal Generator Register 1_0 (RW)
 *
 * Reset value: 0x00000F00U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_1_0
{
    uint32_t U;
    struct _hw_epdc_pigeon_1_0_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t POL : 1;              /*!< [1]  */
        uint32_t INC_SEL : 2;          /*!< [3:2]  */
        uint32_t OFFSET : 4;           /*!< [7:4]  */
        uint32_t MASK_CNT_SEL : 4;     /*!< [11:8]  */
        uint32_t MASK_CNT : 12;        /*!< [23:12]  */
        uint32_t STATE_MASK : 8;       /*!< [31:24]  */
    } B;
} hw_epdc_pigeon_1_0_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_1_0 register
 */
/*@{*/
#define HW_EPDC_PIGEON_1_0_ADDR(x) ((uintptr_t)(x) + 0x840U)

#define HW_EPDC_PIGEON_1_0(x)    (*(__IO hw_epdc_pigeon_1_0_t *) HW_EPDC_PIGEON_1_0_ADDR(x))
#define HW_EPDC_PIGEON_1_0_RD(x) (HW_EPDC_PIGEON_1_0(x).U)
#define HW_EPDC_PIGEON_1_0_WR(x, v) (HW_EPDC_PIGEON_1_0(x).U = (v))
#define HW_EPDC_PIGEON_1_0_SET(x, v) (HW_EPDC_PIGEON_1_0_WR(x, HW_EPDC_PIGEON_1_0_RD(x) |  (v)))
#define HW_EPDC_PIGEON_1_0_CLR(x, v) (HW_EPDC_PIGEON_1_0_WR(x, HW_EPDC_PIGEON_1_0_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_1_0_TOG(x, v) (HW_EPDC_PIGEON_1_0_WR(x, HW_EPDC_PIGEON_1_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_1_0 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_1_0, field EN[0] (RW)
 *
 * enable pigeon mode on this signal
 */
/*@{*/
#define BP_EPDC_PIGEON_1_0_EN (0U)         /*!< Bit position for EPDC_PIGEON_1_0_EN. */
#define BM_EPDC_PIGEON_1_0_EN (0x00000001U) /*!< Bit mask for EPDC_PIGEON_1_0_EN. */
#define BS_EPDC_PIGEON_1_0_EN (1U)         /*!< Bit field size in bits for EPDC_PIGEON_1_0_EN. */

/*! @brief Read current value of the EPDC_PIGEON_1_0_EN field. */
#define BR_EPDC_PIGEON_1_0_EN(x) (HW_EPDC_PIGEON_1_0(x).B.EN)

/*! @brief Format value for bitfield EPDC_PIGEON_1_0_EN. */
#define BF_EPDC_PIGEON_1_0_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_1_0_EN) & BM_EPDC_PIGEON_1_0_EN)

/*! @brief Set the EN field to a new value. */
#define BW_EPDC_PIGEON_1_0_EN(x, v) (HW_EPDC_PIGEON_1_0_WR(x, (HW_EPDC_PIGEON_1_0_RD(x) & ~BM_EPDC_PIGEON_1_0_EN) | BF_EPDC_PIGEON_1_0_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_1_0, field POL[1] (RW)
 *
 * polarity of signal output
 *
 * Values:
 * - 0 - normal signal (active high)
 * - 1 - inverted signal (active low)
 */
/*@{*/
#define BP_EPDC_PIGEON_1_0_POL (1U)        /*!< Bit position for EPDC_PIGEON_1_0_POL. */
#define BM_EPDC_PIGEON_1_0_POL (0x00000002U) /*!< Bit mask for EPDC_PIGEON_1_0_POL. */
#define BS_EPDC_PIGEON_1_0_POL (1U)        /*!< Bit field size in bits for EPDC_PIGEON_1_0_POL. */

#define BV_EPDC_PIGEON_1_0_POL_ACTIVE_HIGH (0U)      /*!< Bit field value for EPDC_PIGEON_1_0_POL: normal signal (active high) */
#define BV_EPDC_PIGEON_1_0_POL_ACTIVE_LOW (0x1U)     /*!< Bit field value for EPDC_PIGEON_1_0_POL: inverted signal (active low) */

/*! @brief Read current value of the EPDC_PIGEON_1_0_POL field. */
#define BR_EPDC_PIGEON_1_0_POL(x) (HW_EPDC_PIGEON_1_0(x).B.POL)

/*! @brief Format value for bitfield EPDC_PIGEON_1_0_POL. */
#define BF_EPDC_PIGEON_1_0_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_1_0_POL) & BM_EPDC_PIGEON_1_0_POL)

/*! @brief Set the POL field to a new value. */
#define BW_EPDC_PIGEON_1_0_POL(x, v) (HW_EPDC_PIGEON_1_0_WR(x, (HW_EPDC_PIGEON_1_0_RD(x) & ~BM_EPDC_PIGEON_1_0_POL) | BF_EPDC_PIGEON_1_0_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_1_0, field INC_SEL[3:2] (RW)
 *
 * event to incrment local counter
 *
 * Values:
 * - 0 - pclk
 * - 1 - line start pulse
 * - 10 - frame start pulse
 * - 11 - use another signal as tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_1_0_INC_SEL (2U)    /*!< Bit position for EPDC_PIGEON_1_0_INC_SEL. */
#define BM_EPDC_PIGEON_1_0_INC_SEL (0x0000000CU) /*!< Bit mask for EPDC_PIGEON_1_0_INC_SEL. */
#define BS_EPDC_PIGEON_1_0_INC_SEL (2U)    /*!< Bit field size in bits for EPDC_PIGEON_1_0_INC_SEL. */

#define BV_EPDC_PIGEON_1_0_INC_SEL_PCLK (0U)         /*!< Bit field value for EPDC_PIGEON_1_0_INC_SEL: pclk */
#define BV_EPDC_PIGEON_1_0_INC_SEL_LINE (0x1U)       /*!< Bit field value for EPDC_PIGEON_1_0_INC_SEL: line start pulse */
#define BV_EPDC_PIGEON_1_0_INC_SEL_FRAME (0x2U)      /*!< Bit field value for EPDC_PIGEON_1_0_INC_SEL: frame start pulse */
#define BV_EPDC_PIGEON_1_0_INC_SEL_SIG_ANOTHER (0x3U) /*!< Bit field value for EPDC_PIGEON_1_0_INC_SEL: use another signal as tick event */

/*! @brief Read current value of the EPDC_PIGEON_1_0_INC_SEL field. */
#define BR_EPDC_PIGEON_1_0_INC_SEL(x) (HW_EPDC_PIGEON_1_0(x).B.INC_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_1_0_INC_SEL. */
#define BF_EPDC_PIGEON_1_0_INC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_1_0_INC_SEL) & BM_EPDC_PIGEON_1_0_INC_SEL)

/*! @brief Set the INC_SEL field to a new value. */
#define BW_EPDC_PIGEON_1_0_INC_SEL(x, v) (HW_EPDC_PIGEON_1_0_WR(x, (HW_EPDC_PIGEON_1_0_RD(x) & ~BM_EPDC_PIGEON_1_0_INC_SEL) | BF_EPDC_PIGEON_1_0_INC_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_1_0, field OFFSET[7:4] (RW)
 *
 * offset on pclk unit. 0=aligne with data, positive value means delay, minus
 * value mean ahead. Supported range depends on panel mode
 */
/*@{*/
#define BP_EPDC_PIGEON_1_0_OFFSET (4U)     /*!< Bit position for EPDC_PIGEON_1_0_OFFSET. */
#define BM_EPDC_PIGEON_1_0_OFFSET (0x000000F0U) /*!< Bit mask for EPDC_PIGEON_1_0_OFFSET. */
#define BS_EPDC_PIGEON_1_0_OFFSET (4U)     /*!< Bit field size in bits for EPDC_PIGEON_1_0_OFFSET. */

/*! @brief Read current value of the EPDC_PIGEON_1_0_OFFSET field. */
#define BR_EPDC_PIGEON_1_0_OFFSET(x) (HW_EPDC_PIGEON_1_0(x).B.OFFSET)

/*! @brief Format value for bitfield EPDC_PIGEON_1_0_OFFSET. */
#define BF_EPDC_PIGEON_1_0_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_1_0_OFFSET) & BM_EPDC_PIGEON_1_0_OFFSET)

/*! @brief Set the OFFSET field to a new value. */
#define BW_EPDC_PIGEON_1_0_OFFSET(x, v) (HW_EPDC_PIGEON_1_0_WR(x, (HW_EPDC_PIGEON_1_0_RD(x) & ~BM_EPDC_PIGEON_1_0_OFFSET) | BF_EPDC_PIGEON_1_0_OFFSET(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_1_0, field MASK_CNT_SEL[11:8] (RW)
 *
 * select global counters as mask condition, use together with MASK_CNT
 *
 * Values:
 * - 0 - pclk counter within one hscan state
 * - 1 - pclk cycle within one hscan state
 * - 10 - line counter within one vscan state
 * - 11 - line cycle within one vscan state
 * - 100 - frame counter
 * - 101 - frame cycle
 * - 110 - horizontal counter (pclk counter within one line )
 * - 111 - vertical counter (line counter within one frame)
 */
/*@{*/
#define BP_EPDC_PIGEON_1_0_MASK_CNT_SEL (8U) /*!< Bit position for EPDC_PIGEON_1_0_MASK_CNT_SEL. */
#define BM_EPDC_PIGEON_1_0_MASK_CNT_SEL (0x00000F00U) /*!< Bit mask for EPDC_PIGEON_1_0_MASK_CNT_SEL. */
#define BS_EPDC_PIGEON_1_0_MASK_CNT_SEL (4U) /*!< Bit field size in bits for EPDC_PIGEON_1_0_MASK_CNT_SEL. */

#define BV_EPDC_PIGEON_1_0_MASK_CNT_SEL_HSTATE_CNT (0U) /*!< Bit field value for EPDC_PIGEON_1_0_MASK_CNT_SEL: pclk counter within one hscan state */
#define BV_EPDC_PIGEON_1_0_MASK_CNT_SEL_HSTATE_CYCLE (0x1U) /*!< Bit field value for EPDC_PIGEON_1_0_MASK_CNT_SEL: pclk cycle within one hscan state */
#define BV_EPDC_PIGEON_1_0_MASK_CNT_SEL_VSTATE_CNT (0x2U) /*!< Bit field value for EPDC_PIGEON_1_0_MASK_CNT_SEL: line counter within one vscan state */
#define BV_EPDC_PIGEON_1_0_MASK_CNT_SEL_VSTATE_CYCLE (0x3U) /*!< Bit field value for EPDC_PIGEON_1_0_MASK_CNT_SEL: line cycle within one vscan state */
#define BV_EPDC_PIGEON_1_0_MASK_CNT_SEL_FRAME_CNT (0x4U) /*!< Bit field value for EPDC_PIGEON_1_0_MASK_CNT_SEL: frame counter */
#define BV_EPDC_PIGEON_1_0_MASK_CNT_SEL_FRAME_CYCLE (0x5U) /*!< Bit field value for EPDC_PIGEON_1_0_MASK_CNT_SEL: frame cycle */
#define BV_EPDC_PIGEON_1_0_MASK_CNT_SEL_HCNT (0x6U)  /*!< Bit field value for EPDC_PIGEON_1_0_MASK_CNT_SEL: horizontal counter (pclk counter within one line ) */
#define BV_EPDC_PIGEON_1_0_MASK_CNT_SEL_VCNT (0x7U)  /*!< Bit field value for EPDC_PIGEON_1_0_MASK_CNT_SEL: vertical counter (line counter within one frame) */

/*! @brief Read current value of the EPDC_PIGEON_1_0_MASK_CNT_SEL field. */
#define BR_EPDC_PIGEON_1_0_MASK_CNT_SEL(x) (HW_EPDC_PIGEON_1_0(x).B.MASK_CNT_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_1_0_MASK_CNT_SEL. */
#define BF_EPDC_PIGEON_1_0_MASK_CNT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_1_0_MASK_CNT_SEL) & BM_EPDC_PIGEON_1_0_MASK_CNT_SEL)

/*! @brief Set the MASK_CNT_SEL field to a new value. */
#define BW_EPDC_PIGEON_1_0_MASK_CNT_SEL(x, v) (HW_EPDC_PIGEON_1_0_WR(x, (HW_EPDC_PIGEON_1_0_RD(x) & ~BM_EPDC_PIGEON_1_0_MASK_CNT_SEL) | BF_EPDC_PIGEON_1_0_MASK_CNT_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_1_0, field MASK_CNT[23:12] (RW)
 *
 * When the global counter selected through MASK_CNT_SEL matches value in this
 * reg, pigeon local counter start ticking. 0=disable
 */
/*@{*/
#define BP_EPDC_PIGEON_1_0_MASK_CNT (12U)  /*!< Bit position for EPDC_PIGEON_1_0_MASK_CNT. */
#define BM_EPDC_PIGEON_1_0_MASK_CNT (0x00FFF000U) /*!< Bit mask for EPDC_PIGEON_1_0_MASK_CNT. */
#define BS_EPDC_PIGEON_1_0_MASK_CNT (12U)  /*!< Bit field size in bits for EPDC_PIGEON_1_0_MASK_CNT. */

/*! @brief Read current value of the EPDC_PIGEON_1_0_MASK_CNT field. */
#define BR_EPDC_PIGEON_1_0_MASK_CNT(x) (HW_EPDC_PIGEON_1_0(x).B.MASK_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_1_0_MASK_CNT. */
#define BF_EPDC_PIGEON_1_0_MASK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_1_0_MASK_CNT) & BM_EPDC_PIGEON_1_0_MASK_CNT)

/*! @brief Set the MASK_CNT field to a new value. */
#define BW_EPDC_PIGEON_1_0_MASK_CNT(x, v) (HW_EPDC_PIGEON_1_0_WR(x, (HW_EPDC_PIGEON_1_0_RD(x) & ~BM_EPDC_PIGEON_1_0_MASK_CNT) | BF_EPDC_PIGEON_1_0_MASK_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_1_0, field STATE_MASK[31:24] (RW)
 *
 * state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan
 * states as reference point for local counter to start ticking
 *
 * Values:
 * - 1 - FRAME SYNC
 * - 10 - FRAME BEGIN
 * - 100 - FRAME DATA
 * - 1000 - FRAME END
 * - 10000 - LINE SYNC
 * - 100000 - LINE BEGIN
 * - 1000000 - LINE DATA
 * - 10000000 - LINE END
 */
/*@{*/
#define BP_EPDC_PIGEON_1_0_STATE_MASK (24U) /*!< Bit position for EPDC_PIGEON_1_0_STATE_MASK. */
#define BM_EPDC_PIGEON_1_0_STATE_MASK (0xFF000000U) /*!< Bit mask for EPDC_PIGEON_1_0_STATE_MASK. */
#define BS_EPDC_PIGEON_1_0_STATE_MASK (8U) /*!< Bit field size in bits for EPDC_PIGEON_1_0_STATE_MASK. */

#define BV_EPDC_PIGEON_1_0_STATE_MASK_FS (0x1U)      /*!< Bit field value for EPDC_PIGEON_1_0_STATE_MASK: FRAME SYNC */
#define BV_EPDC_PIGEON_1_0_STATE_MASK_FB (0x2U)      /*!< Bit field value for EPDC_PIGEON_1_0_STATE_MASK: FRAME BEGIN */
#define BV_EPDC_PIGEON_1_0_STATE_MASK_FD (0x4U)      /*!< Bit field value for EPDC_PIGEON_1_0_STATE_MASK: FRAME DATA */
#define BV_EPDC_PIGEON_1_0_STATE_MASK_FE (0x8U)      /*!< Bit field value for EPDC_PIGEON_1_0_STATE_MASK: FRAME END */
#define BV_EPDC_PIGEON_1_0_STATE_MASK_LS (0x10U)     /*!< Bit field value for EPDC_PIGEON_1_0_STATE_MASK: LINE SYNC */
#define BV_EPDC_PIGEON_1_0_STATE_MASK_LB (0x20U)     /*!< Bit field value for EPDC_PIGEON_1_0_STATE_MASK: LINE BEGIN */
#define BV_EPDC_PIGEON_1_0_STATE_MASK_LD (0x40U)     /*!< Bit field value for EPDC_PIGEON_1_0_STATE_MASK: LINE DATA */
#define BV_EPDC_PIGEON_1_0_STATE_MASK_LE (0x80U)     /*!< Bit field value for EPDC_PIGEON_1_0_STATE_MASK: LINE END */

/*! @brief Read current value of the EPDC_PIGEON_1_0_STATE_MASK field. */
#define BR_EPDC_PIGEON_1_0_STATE_MASK(x) (HW_EPDC_PIGEON_1_0(x).B.STATE_MASK)

/*! @brief Format value for bitfield EPDC_PIGEON_1_0_STATE_MASK. */
#define BF_EPDC_PIGEON_1_0_STATE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_1_0_STATE_MASK) & BM_EPDC_PIGEON_1_0_STATE_MASK)

/*! @brief Set the STATE_MASK field to a new value. */
#define BW_EPDC_PIGEON_1_0_STATE_MASK(x, v) (HW_EPDC_PIGEON_1_0_WR(x, (HW_EPDC_PIGEON_1_0_RD(x) & ~BM_EPDC_PIGEON_1_0_STATE_MASK) | BF_EPDC_PIGEON_1_0_STATE_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_1_1 - Panel Interface Signal Generator Register 1_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_1_1 - Panel Interface Signal Generator Register 1_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_1_1
{
    uint32_t U;
    struct _hw_epdc_pigeon_1_1_bitfields
    {
        uint32_t SET_CNT : 16;         /*!< [15:0]  */
        uint32_t CLR_CNT : 16;         /*!< [31:16]  */
    } B;
} hw_epdc_pigeon_1_1_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_1_1 register
 */
/*@{*/
#define HW_EPDC_PIGEON_1_1_ADDR(x) ((uintptr_t)(x) + 0x850U)

#define HW_EPDC_PIGEON_1_1(x)    (*(__IO hw_epdc_pigeon_1_1_t *) HW_EPDC_PIGEON_1_1_ADDR(x))
#define HW_EPDC_PIGEON_1_1_RD(x) (HW_EPDC_PIGEON_1_1(x).U)
#define HW_EPDC_PIGEON_1_1_WR(x, v) (HW_EPDC_PIGEON_1_1(x).U = (v))
#define HW_EPDC_PIGEON_1_1_SET(x, v) (HW_EPDC_PIGEON_1_1_WR(x, HW_EPDC_PIGEON_1_1_RD(x) |  (v)))
#define HW_EPDC_PIGEON_1_1_CLR(x, v) (HW_EPDC_PIGEON_1_1_WR(x, HW_EPDC_PIGEON_1_1_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_1_1_TOG(x, v) (HW_EPDC_PIGEON_1_1_WR(x, HW_EPDC_PIGEON_1_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_1_1 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_1_1, field SET_CNT[15:0] (RW)
 *
 * assert signal output when counter match this value
 *
 * Values:
 * - 0 - start as active
 */
/*@{*/
#define BP_EPDC_PIGEON_1_1_SET_CNT (0U)    /*!< Bit position for EPDC_PIGEON_1_1_SET_CNT. */
#define BM_EPDC_PIGEON_1_1_SET_CNT (0x0000FFFFU) /*!< Bit mask for EPDC_PIGEON_1_1_SET_CNT. */
#define BS_EPDC_PIGEON_1_1_SET_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_1_1_SET_CNT. */

#define BV_EPDC_PIGEON_1_1_SET_CNT_START_ACTIVE (0U) /*!< Bit field value for EPDC_PIGEON_1_1_SET_CNT: start as active */

/*! @brief Read current value of the EPDC_PIGEON_1_1_SET_CNT field. */
#define BR_EPDC_PIGEON_1_1_SET_CNT(x) (HW_EPDC_PIGEON_1_1(x).B.SET_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_1_1_SET_CNT. */
#define BF_EPDC_PIGEON_1_1_SET_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_1_1_SET_CNT) & BM_EPDC_PIGEON_1_1_SET_CNT)

/*! @brief Set the SET_CNT field to a new value. */
#define BW_EPDC_PIGEON_1_1_SET_CNT(x, v) (HW_EPDC_PIGEON_1_1_WR(x, (HW_EPDC_PIGEON_1_1_RD(x) & ~BM_EPDC_PIGEON_1_1_SET_CNT) | BF_EPDC_PIGEON_1_1_SET_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_1_1, field CLR_CNT[31:16] (RW)
 *
 * deassert signal output when counter match this value
 *
 * Values:
 * - 0 - keep active until mask off
 */
/*@{*/
#define BP_EPDC_PIGEON_1_1_CLR_CNT (16U)   /*!< Bit position for EPDC_PIGEON_1_1_CLR_CNT. */
#define BM_EPDC_PIGEON_1_1_CLR_CNT (0xFFFF0000U) /*!< Bit mask for EPDC_PIGEON_1_1_CLR_CNT. */
#define BS_EPDC_PIGEON_1_1_CLR_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_1_1_CLR_CNT. */

#define BV_EPDC_PIGEON_1_1_CLR_CNT_CLEAR_USING_MASK (0U) /*!< Bit field value for EPDC_PIGEON_1_1_CLR_CNT: keep active until mask off */

/*! @brief Read current value of the EPDC_PIGEON_1_1_CLR_CNT field. */
#define BR_EPDC_PIGEON_1_1_CLR_CNT(x) (HW_EPDC_PIGEON_1_1(x).B.CLR_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_1_1_CLR_CNT. */
#define BF_EPDC_PIGEON_1_1_CLR_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_1_1_CLR_CNT) & BM_EPDC_PIGEON_1_1_CLR_CNT)

/*! @brief Set the CLR_CNT field to a new value. */
#define BW_EPDC_PIGEON_1_1_CLR_CNT(x, v) (HW_EPDC_PIGEON_1_1_WR(x, (HW_EPDC_PIGEON_1_1_RD(x) & ~BM_EPDC_PIGEON_1_1_CLR_CNT) | BF_EPDC_PIGEON_1_1_CLR_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_1_2 - Panel Interface Signal Generator Register 1_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_1_2 - Panel Interface Signal Generator Register 1_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_1_2
{
    uint32_t U;
    struct _hw_epdc_pigeon_1_2_bitfields
    {
        uint32_t SIG_LOGIC : 4;        /*!< [3:0]  */
        uint32_t SIG_ANOTHER : 5;      /*!< [8:4]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_epdc_pigeon_1_2_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_1_2 register
 */
/*@{*/
#define HW_EPDC_PIGEON_1_2_ADDR(x) ((uintptr_t)(x) + 0x860U)

#define HW_EPDC_PIGEON_1_2(x)    (*(__IO hw_epdc_pigeon_1_2_t *) HW_EPDC_PIGEON_1_2_ADDR(x))
#define HW_EPDC_PIGEON_1_2_RD(x) (HW_EPDC_PIGEON_1_2(x).U)
#define HW_EPDC_PIGEON_1_2_WR(x, v) (HW_EPDC_PIGEON_1_2(x).U = (v))
#define HW_EPDC_PIGEON_1_2_SET(x, v) (HW_EPDC_PIGEON_1_2_WR(x, HW_EPDC_PIGEON_1_2_RD(x) |  (v)))
#define HW_EPDC_PIGEON_1_2_CLR(x, v) (HW_EPDC_PIGEON_1_2_WR(x, HW_EPDC_PIGEON_1_2_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_1_2_TOG(x, v) (HW_EPDC_PIGEON_1_2_WR(x, HW_EPDC_PIGEON_1_2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_1_2 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_1_2, field SIG_LOGIC[3:0] (RW)
 *
 * logic operation with another signal sigout : final output signal of this
 * generator mask : final mask of this generator this_sig : intermediate signal of
 * this generator before logic operation other_masks : intermediate mask result of
 * this generator before logic operation sig_another : signal selected other
 * generators
 *
 * Values:
 * - 0 - no logic operation
 * - 1 - sigout = sig_another AND this_sig
 * - 10 - sigout = sig_another OR this_sig
 * - 11 - mask = sig_another AND other_masks
 */
/*@{*/
#define BP_EPDC_PIGEON_1_2_SIG_LOGIC (0U)  /*!< Bit position for EPDC_PIGEON_1_2_SIG_LOGIC. */
#define BM_EPDC_PIGEON_1_2_SIG_LOGIC (0x0000000FU) /*!< Bit mask for EPDC_PIGEON_1_2_SIG_LOGIC. */
#define BS_EPDC_PIGEON_1_2_SIG_LOGIC (4U)  /*!< Bit field size in bits for EPDC_PIGEON_1_2_SIG_LOGIC. */

#define BV_EPDC_PIGEON_1_2_SIG_LOGIC_DIS (0U)        /*!< Bit field value for EPDC_PIGEON_1_2_SIG_LOGIC: no logic operation */
#define BV_EPDC_PIGEON_1_2_SIG_LOGIC_AND (0x1U)      /*!< Bit field value for EPDC_PIGEON_1_2_SIG_LOGIC: sigout = sig_another AND this_sig */
#define BV_EPDC_PIGEON_1_2_SIG_LOGIC_OR (0x2U)       /*!< Bit field value for EPDC_PIGEON_1_2_SIG_LOGIC: sigout = sig_another OR this_sig */
#define BV_EPDC_PIGEON_1_2_SIG_LOGIC_MASK (0x3U)     /*!< Bit field value for EPDC_PIGEON_1_2_SIG_LOGIC: mask = sig_another AND other_masks */

/*! @brief Read current value of the EPDC_PIGEON_1_2_SIG_LOGIC field. */
#define BR_EPDC_PIGEON_1_2_SIG_LOGIC(x) (HW_EPDC_PIGEON_1_2(x).B.SIG_LOGIC)

/*! @brief Format value for bitfield EPDC_PIGEON_1_2_SIG_LOGIC. */
#define BF_EPDC_PIGEON_1_2_SIG_LOGIC(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_1_2_SIG_LOGIC) & BM_EPDC_PIGEON_1_2_SIG_LOGIC)

/*! @brief Set the SIG_LOGIC field to a new value. */
#define BW_EPDC_PIGEON_1_2_SIG_LOGIC(x, v) (HW_EPDC_PIGEON_1_2_WR(x, (HW_EPDC_PIGEON_1_2_RD(x) & ~BM_EPDC_PIGEON_1_2_SIG_LOGIC) | BF_EPDC_PIGEON_1_2_SIG_LOGIC(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_1_2, field SIG_ANOTHER[8:4] (RW)
 *
 * select another signal for logic operation or as mask or counter tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_1_2_SIG_ANOTHER (4U) /*!< Bit position for EPDC_PIGEON_1_2_SIG_ANOTHER. */
#define BM_EPDC_PIGEON_1_2_SIG_ANOTHER (0x000001F0U) /*!< Bit mask for EPDC_PIGEON_1_2_SIG_ANOTHER. */
#define BS_EPDC_PIGEON_1_2_SIG_ANOTHER (5U) /*!< Bit field size in bits for EPDC_PIGEON_1_2_SIG_ANOTHER. */

/*! @brief Read current value of the EPDC_PIGEON_1_2_SIG_ANOTHER field. */
#define BR_EPDC_PIGEON_1_2_SIG_ANOTHER(x) (HW_EPDC_PIGEON_1_2(x).B.SIG_ANOTHER)

/*! @brief Format value for bitfield EPDC_PIGEON_1_2_SIG_ANOTHER. */
#define BF_EPDC_PIGEON_1_2_SIG_ANOTHER(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_1_2_SIG_ANOTHER) & BM_EPDC_PIGEON_1_2_SIG_ANOTHER)

/*! @brief Set the SIG_ANOTHER field to a new value. */
#define BW_EPDC_PIGEON_1_2_SIG_ANOTHER(x, v) (HW_EPDC_PIGEON_1_2_WR(x, (HW_EPDC_PIGEON_1_2_RD(x) & ~BM_EPDC_PIGEON_1_2_SIG_ANOTHER) | BF_EPDC_PIGEON_1_2_SIG_ANOTHER(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_2_0 - Panel Interface Signal Generator Register 2_0
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_2_0 - Panel Interface Signal Generator Register 2_0 (RW)
 *
 * Reset value: 0x00000F00U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_2_0
{
    uint32_t U;
    struct _hw_epdc_pigeon_2_0_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t POL : 1;              /*!< [1]  */
        uint32_t INC_SEL : 2;          /*!< [3:2]  */
        uint32_t OFFSET : 4;           /*!< [7:4]  */
        uint32_t MASK_CNT_SEL : 4;     /*!< [11:8]  */
        uint32_t MASK_CNT : 12;        /*!< [23:12]  */
        uint32_t STATE_MASK : 8;       /*!< [31:24]  */
    } B;
} hw_epdc_pigeon_2_0_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_2_0 register
 */
/*@{*/
#define HW_EPDC_PIGEON_2_0_ADDR(x) ((uintptr_t)(x) + 0x880U)

#define HW_EPDC_PIGEON_2_0(x)    (*(__IO hw_epdc_pigeon_2_0_t *) HW_EPDC_PIGEON_2_0_ADDR(x))
#define HW_EPDC_PIGEON_2_0_RD(x) (HW_EPDC_PIGEON_2_0(x).U)
#define HW_EPDC_PIGEON_2_0_WR(x, v) (HW_EPDC_PIGEON_2_0(x).U = (v))
#define HW_EPDC_PIGEON_2_0_SET(x, v) (HW_EPDC_PIGEON_2_0_WR(x, HW_EPDC_PIGEON_2_0_RD(x) |  (v)))
#define HW_EPDC_PIGEON_2_0_CLR(x, v) (HW_EPDC_PIGEON_2_0_WR(x, HW_EPDC_PIGEON_2_0_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_2_0_TOG(x, v) (HW_EPDC_PIGEON_2_0_WR(x, HW_EPDC_PIGEON_2_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_2_0 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_2_0, field EN[0] (RW)
 *
 * enable pigeon mode on this signal
 */
/*@{*/
#define BP_EPDC_PIGEON_2_0_EN (0U)         /*!< Bit position for EPDC_PIGEON_2_0_EN. */
#define BM_EPDC_PIGEON_2_0_EN (0x00000001U) /*!< Bit mask for EPDC_PIGEON_2_0_EN. */
#define BS_EPDC_PIGEON_2_0_EN (1U)         /*!< Bit field size in bits for EPDC_PIGEON_2_0_EN. */

/*! @brief Read current value of the EPDC_PIGEON_2_0_EN field. */
#define BR_EPDC_PIGEON_2_0_EN(x) (HW_EPDC_PIGEON_2_0(x).B.EN)

/*! @brief Format value for bitfield EPDC_PIGEON_2_0_EN. */
#define BF_EPDC_PIGEON_2_0_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_2_0_EN) & BM_EPDC_PIGEON_2_0_EN)

/*! @brief Set the EN field to a new value. */
#define BW_EPDC_PIGEON_2_0_EN(x, v) (HW_EPDC_PIGEON_2_0_WR(x, (HW_EPDC_PIGEON_2_0_RD(x) & ~BM_EPDC_PIGEON_2_0_EN) | BF_EPDC_PIGEON_2_0_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_2_0, field POL[1] (RW)
 *
 * polarity of signal output
 *
 * Values:
 * - 0 - normal signal (active high)
 * - 1 - inverted signal (active low)
 */
/*@{*/
#define BP_EPDC_PIGEON_2_0_POL (1U)        /*!< Bit position for EPDC_PIGEON_2_0_POL. */
#define BM_EPDC_PIGEON_2_0_POL (0x00000002U) /*!< Bit mask for EPDC_PIGEON_2_0_POL. */
#define BS_EPDC_PIGEON_2_0_POL (1U)        /*!< Bit field size in bits for EPDC_PIGEON_2_0_POL. */

#define BV_EPDC_PIGEON_2_0_POL_ACTIVE_HIGH (0U)      /*!< Bit field value for EPDC_PIGEON_2_0_POL: normal signal (active high) */
#define BV_EPDC_PIGEON_2_0_POL_ACTIVE_LOW (0x1U)     /*!< Bit field value for EPDC_PIGEON_2_0_POL: inverted signal (active low) */

/*! @brief Read current value of the EPDC_PIGEON_2_0_POL field. */
#define BR_EPDC_PIGEON_2_0_POL(x) (HW_EPDC_PIGEON_2_0(x).B.POL)

/*! @brief Format value for bitfield EPDC_PIGEON_2_0_POL. */
#define BF_EPDC_PIGEON_2_0_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_2_0_POL) & BM_EPDC_PIGEON_2_0_POL)

/*! @brief Set the POL field to a new value. */
#define BW_EPDC_PIGEON_2_0_POL(x, v) (HW_EPDC_PIGEON_2_0_WR(x, (HW_EPDC_PIGEON_2_0_RD(x) & ~BM_EPDC_PIGEON_2_0_POL) | BF_EPDC_PIGEON_2_0_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_2_0, field INC_SEL[3:2] (RW)
 *
 * event to incrment local counter
 *
 * Values:
 * - 0 - pclk
 * - 1 - line start pulse
 * - 10 - frame start pulse
 * - 11 - use another signal as tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_2_0_INC_SEL (2U)    /*!< Bit position for EPDC_PIGEON_2_0_INC_SEL. */
#define BM_EPDC_PIGEON_2_0_INC_SEL (0x0000000CU) /*!< Bit mask for EPDC_PIGEON_2_0_INC_SEL. */
#define BS_EPDC_PIGEON_2_0_INC_SEL (2U)    /*!< Bit field size in bits for EPDC_PIGEON_2_0_INC_SEL. */

#define BV_EPDC_PIGEON_2_0_INC_SEL_PCLK (0U)         /*!< Bit field value for EPDC_PIGEON_2_0_INC_SEL: pclk */
#define BV_EPDC_PIGEON_2_0_INC_SEL_LINE (0x1U)       /*!< Bit field value for EPDC_PIGEON_2_0_INC_SEL: line start pulse */
#define BV_EPDC_PIGEON_2_0_INC_SEL_FRAME (0x2U)      /*!< Bit field value for EPDC_PIGEON_2_0_INC_SEL: frame start pulse */
#define BV_EPDC_PIGEON_2_0_INC_SEL_SIG_ANOTHER (0x3U) /*!< Bit field value for EPDC_PIGEON_2_0_INC_SEL: use another signal as tick event */

/*! @brief Read current value of the EPDC_PIGEON_2_0_INC_SEL field. */
#define BR_EPDC_PIGEON_2_0_INC_SEL(x) (HW_EPDC_PIGEON_2_0(x).B.INC_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_2_0_INC_SEL. */
#define BF_EPDC_PIGEON_2_0_INC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_2_0_INC_SEL) & BM_EPDC_PIGEON_2_0_INC_SEL)

/*! @brief Set the INC_SEL field to a new value. */
#define BW_EPDC_PIGEON_2_0_INC_SEL(x, v) (HW_EPDC_PIGEON_2_0_WR(x, (HW_EPDC_PIGEON_2_0_RD(x) & ~BM_EPDC_PIGEON_2_0_INC_SEL) | BF_EPDC_PIGEON_2_0_INC_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_2_0, field OFFSET[7:4] (RW)
 *
 * offset on pclk unit. 0=aligne with data, positive value means delay, minus
 * value mean ahead. Supported range depends on panel mode
 */
/*@{*/
#define BP_EPDC_PIGEON_2_0_OFFSET (4U)     /*!< Bit position for EPDC_PIGEON_2_0_OFFSET. */
#define BM_EPDC_PIGEON_2_0_OFFSET (0x000000F0U) /*!< Bit mask for EPDC_PIGEON_2_0_OFFSET. */
#define BS_EPDC_PIGEON_2_0_OFFSET (4U)     /*!< Bit field size in bits for EPDC_PIGEON_2_0_OFFSET. */

/*! @brief Read current value of the EPDC_PIGEON_2_0_OFFSET field. */
#define BR_EPDC_PIGEON_2_0_OFFSET(x) (HW_EPDC_PIGEON_2_0(x).B.OFFSET)

/*! @brief Format value for bitfield EPDC_PIGEON_2_0_OFFSET. */
#define BF_EPDC_PIGEON_2_0_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_2_0_OFFSET) & BM_EPDC_PIGEON_2_0_OFFSET)

/*! @brief Set the OFFSET field to a new value. */
#define BW_EPDC_PIGEON_2_0_OFFSET(x, v) (HW_EPDC_PIGEON_2_0_WR(x, (HW_EPDC_PIGEON_2_0_RD(x) & ~BM_EPDC_PIGEON_2_0_OFFSET) | BF_EPDC_PIGEON_2_0_OFFSET(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_2_0, field MASK_CNT_SEL[11:8] (RW)
 *
 * select global counters as mask condition, use together with MASK_CNT
 *
 * Values:
 * - 0 - pclk counter within one hscan state
 * - 1 - pclk cycle within one hscan state
 * - 10 - line counter within one vscan state
 * - 11 - line cycle within one vscan state
 * - 100 - frame counter
 * - 101 - frame cycle
 * - 110 - horizontal counter (pclk counter within one line )
 * - 111 - vertical counter (line counter within one frame)
 */
/*@{*/
#define BP_EPDC_PIGEON_2_0_MASK_CNT_SEL (8U) /*!< Bit position for EPDC_PIGEON_2_0_MASK_CNT_SEL. */
#define BM_EPDC_PIGEON_2_0_MASK_CNT_SEL (0x00000F00U) /*!< Bit mask for EPDC_PIGEON_2_0_MASK_CNT_SEL. */
#define BS_EPDC_PIGEON_2_0_MASK_CNT_SEL (4U) /*!< Bit field size in bits for EPDC_PIGEON_2_0_MASK_CNT_SEL. */

#define BV_EPDC_PIGEON_2_0_MASK_CNT_SEL_HSTATE_CNT (0U) /*!< Bit field value for EPDC_PIGEON_2_0_MASK_CNT_SEL: pclk counter within one hscan state */
#define BV_EPDC_PIGEON_2_0_MASK_CNT_SEL_HSTATE_CYCLE (0x1U) /*!< Bit field value for EPDC_PIGEON_2_0_MASK_CNT_SEL: pclk cycle within one hscan state */
#define BV_EPDC_PIGEON_2_0_MASK_CNT_SEL_VSTATE_CNT (0x2U) /*!< Bit field value for EPDC_PIGEON_2_0_MASK_CNT_SEL: line counter within one vscan state */
#define BV_EPDC_PIGEON_2_0_MASK_CNT_SEL_VSTATE_CYCLE (0x3U) /*!< Bit field value for EPDC_PIGEON_2_0_MASK_CNT_SEL: line cycle within one vscan state */
#define BV_EPDC_PIGEON_2_0_MASK_CNT_SEL_FRAME_CNT (0x4U) /*!< Bit field value for EPDC_PIGEON_2_0_MASK_CNT_SEL: frame counter */
#define BV_EPDC_PIGEON_2_0_MASK_CNT_SEL_FRAME_CYCLE (0x5U) /*!< Bit field value for EPDC_PIGEON_2_0_MASK_CNT_SEL: frame cycle */
#define BV_EPDC_PIGEON_2_0_MASK_CNT_SEL_HCNT (0x6U)  /*!< Bit field value for EPDC_PIGEON_2_0_MASK_CNT_SEL: horizontal counter (pclk counter within one line ) */
#define BV_EPDC_PIGEON_2_0_MASK_CNT_SEL_VCNT (0x7U)  /*!< Bit field value for EPDC_PIGEON_2_0_MASK_CNT_SEL: vertical counter (line counter within one frame) */

/*! @brief Read current value of the EPDC_PIGEON_2_0_MASK_CNT_SEL field. */
#define BR_EPDC_PIGEON_2_0_MASK_CNT_SEL(x) (HW_EPDC_PIGEON_2_0(x).B.MASK_CNT_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_2_0_MASK_CNT_SEL. */
#define BF_EPDC_PIGEON_2_0_MASK_CNT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_2_0_MASK_CNT_SEL) & BM_EPDC_PIGEON_2_0_MASK_CNT_SEL)

/*! @brief Set the MASK_CNT_SEL field to a new value. */
#define BW_EPDC_PIGEON_2_0_MASK_CNT_SEL(x, v) (HW_EPDC_PIGEON_2_0_WR(x, (HW_EPDC_PIGEON_2_0_RD(x) & ~BM_EPDC_PIGEON_2_0_MASK_CNT_SEL) | BF_EPDC_PIGEON_2_0_MASK_CNT_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_2_0, field MASK_CNT[23:12] (RW)
 *
 * When the global counter selected through MASK_CNT_SEL matches value in this
 * reg, pigeon local counter start ticking. 0=disable
 */
/*@{*/
#define BP_EPDC_PIGEON_2_0_MASK_CNT (12U)  /*!< Bit position for EPDC_PIGEON_2_0_MASK_CNT. */
#define BM_EPDC_PIGEON_2_0_MASK_CNT (0x00FFF000U) /*!< Bit mask for EPDC_PIGEON_2_0_MASK_CNT. */
#define BS_EPDC_PIGEON_2_0_MASK_CNT (12U)  /*!< Bit field size in bits for EPDC_PIGEON_2_0_MASK_CNT. */

/*! @brief Read current value of the EPDC_PIGEON_2_0_MASK_CNT field. */
#define BR_EPDC_PIGEON_2_0_MASK_CNT(x) (HW_EPDC_PIGEON_2_0(x).B.MASK_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_2_0_MASK_CNT. */
#define BF_EPDC_PIGEON_2_0_MASK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_2_0_MASK_CNT) & BM_EPDC_PIGEON_2_0_MASK_CNT)

/*! @brief Set the MASK_CNT field to a new value. */
#define BW_EPDC_PIGEON_2_0_MASK_CNT(x, v) (HW_EPDC_PIGEON_2_0_WR(x, (HW_EPDC_PIGEON_2_0_RD(x) & ~BM_EPDC_PIGEON_2_0_MASK_CNT) | BF_EPDC_PIGEON_2_0_MASK_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_2_0, field STATE_MASK[31:24] (RW)
 *
 * state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan
 * states as reference point for local counter to start ticking
 *
 * Values:
 * - 1 - FRAME SYNC
 * - 10 - FRAME BEGIN
 * - 100 - FRAME DATA
 * - 1000 - FRAME END
 * - 10000 - LINE SYNC
 * - 100000 - LINE BEGIN
 * - 1000000 - LINE DATA
 * - 10000000 - LINE END
 */
/*@{*/
#define BP_EPDC_PIGEON_2_0_STATE_MASK (24U) /*!< Bit position for EPDC_PIGEON_2_0_STATE_MASK. */
#define BM_EPDC_PIGEON_2_0_STATE_MASK (0xFF000000U) /*!< Bit mask for EPDC_PIGEON_2_0_STATE_MASK. */
#define BS_EPDC_PIGEON_2_0_STATE_MASK (8U) /*!< Bit field size in bits for EPDC_PIGEON_2_0_STATE_MASK. */

#define BV_EPDC_PIGEON_2_0_STATE_MASK_FS (0x1U)      /*!< Bit field value for EPDC_PIGEON_2_0_STATE_MASK: FRAME SYNC */
#define BV_EPDC_PIGEON_2_0_STATE_MASK_FB (0x2U)      /*!< Bit field value for EPDC_PIGEON_2_0_STATE_MASK: FRAME BEGIN */
#define BV_EPDC_PIGEON_2_0_STATE_MASK_FD (0x4U)      /*!< Bit field value for EPDC_PIGEON_2_0_STATE_MASK: FRAME DATA */
#define BV_EPDC_PIGEON_2_0_STATE_MASK_FE (0x8U)      /*!< Bit field value for EPDC_PIGEON_2_0_STATE_MASK: FRAME END */
#define BV_EPDC_PIGEON_2_0_STATE_MASK_LS (0x10U)     /*!< Bit field value for EPDC_PIGEON_2_0_STATE_MASK: LINE SYNC */
#define BV_EPDC_PIGEON_2_0_STATE_MASK_LB (0x20U)     /*!< Bit field value for EPDC_PIGEON_2_0_STATE_MASK: LINE BEGIN */
#define BV_EPDC_PIGEON_2_0_STATE_MASK_LD (0x40U)     /*!< Bit field value for EPDC_PIGEON_2_0_STATE_MASK: LINE DATA */
#define BV_EPDC_PIGEON_2_0_STATE_MASK_LE (0x80U)     /*!< Bit field value for EPDC_PIGEON_2_0_STATE_MASK: LINE END */

/*! @brief Read current value of the EPDC_PIGEON_2_0_STATE_MASK field. */
#define BR_EPDC_PIGEON_2_0_STATE_MASK(x) (HW_EPDC_PIGEON_2_0(x).B.STATE_MASK)

/*! @brief Format value for bitfield EPDC_PIGEON_2_0_STATE_MASK. */
#define BF_EPDC_PIGEON_2_0_STATE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_2_0_STATE_MASK) & BM_EPDC_PIGEON_2_0_STATE_MASK)

/*! @brief Set the STATE_MASK field to a new value. */
#define BW_EPDC_PIGEON_2_0_STATE_MASK(x, v) (HW_EPDC_PIGEON_2_0_WR(x, (HW_EPDC_PIGEON_2_0_RD(x) & ~BM_EPDC_PIGEON_2_0_STATE_MASK) | BF_EPDC_PIGEON_2_0_STATE_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_2_1 - Panel Interface Signal Generator Register 2_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_2_1 - Panel Interface Signal Generator Register 2_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_2_1
{
    uint32_t U;
    struct _hw_epdc_pigeon_2_1_bitfields
    {
        uint32_t SET_CNT : 16;         /*!< [15:0]  */
        uint32_t CLR_CNT : 16;         /*!< [31:16]  */
    } B;
} hw_epdc_pigeon_2_1_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_2_1 register
 */
/*@{*/
#define HW_EPDC_PIGEON_2_1_ADDR(x) ((uintptr_t)(x) + 0x890U)

#define HW_EPDC_PIGEON_2_1(x)    (*(__IO hw_epdc_pigeon_2_1_t *) HW_EPDC_PIGEON_2_1_ADDR(x))
#define HW_EPDC_PIGEON_2_1_RD(x) (HW_EPDC_PIGEON_2_1(x).U)
#define HW_EPDC_PIGEON_2_1_WR(x, v) (HW_EPDC_PIGEON_2_1(x).U = (v))
#define HW_EPDC_PIGEON_2_1_SET(x, v) (HW_EPDC_PIGEON_2_1_WR(x, HW_EPDC_PIGEON_2_1_RD(x) |  (v)))
#define HW_EPDC_PIGEON_2_1_CLR(x, v) (HW_EPDC_PIGEON_2_1_WR(x, HW_EPDC_PIGEON_2_1_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_2_1_TOG(x, v) (HW_EPDC_PIGEON_2_1_WR(x, HW_EPDC_PIGEON_2_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_2_1 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_2_1, field SET_CNT[15:0] (RW)
 *
 * assert signal output when counter match this value
 *
 * Values:
 * - 0 - start as active
 */
/*@{*/
#define BP_EPDC_PIGEON_2_1_SET_CNT (0U)    /*!< Bit position for EPDC_PIGEON_2_1_SET_CNT. */
#define BM_EPDC_PIGEON_2_1_SET_CNT (0x0000FFFFU) /*!< Bit mask for EPDC_PIGEON_2_1_SET_CNT. */
#define BS_EPDC_PIGEON_2_1_SET_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_2_1_SET_CNT. */

#define BV_EPDC_PIGEON_2_1_SET_CNT_START_ACTIVE (0U) /*!< Bit field value for EPDC_PIGEON_2_1_SET_CNT: start as active */

/*! @brief Read current value of the EPDC_PIGEON_2_1_SET_CNT field. */
#define BR_EPDC_PIGEON_2_1_SET_CNT(x) (HW_EPDC_PIGEON_2_1(x).B.SET_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_2_1_SET_CNT. */
#define BF_EPDC_PIGEON_2_1_SET_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_2_1_SET_CNT) & BM_EPDC_PIGEON_2_1_SET_CNT)

/*! @brief Set the SET_CNT field to a new value. */
#define BW_EPDC_PIGEON_2_1_SET_CNT(x, v) (HW_EPDC_PIGEON_2_1_WR(x, (HW_EPDC_PIGEON_2_1_RD(x) & ~BM_EPDC_PIGEON_2_1_SET_CNT) | BF_EPDC_PIGEON_2_1_SET_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_2_1, field CLR_CNT[31:16] (RW)
 *
 * deassert signal output when counter match this value
 *
 * Values:
 * - 0 - keep active until mask off
 */
/*@{*/
#define BP_EPDC_PIGEON_2_1_CLR_CNT (16U)   /*!< Bit position for EPDC_PIGEON_2_1_CLR_CNT. */
#define BM_EPDC_PIGEON_2_1_CLR_CNT (0xFFFF0000U) /*!< Bit mask for EPDC_PIGEON_2_1_CLR_CNT. */
#define BS_EPDC_PIGEON_2_1_CLR_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_2_1_CLR_CNT. */

#define BV_EPDC_PIGEON_2_1_CLR_CNT_CLEAR_USING_MASK (0U) /*!< Bit field value for EPDC_PIGEON_2_1_CLR_CNT: keep active until mask off */

/*! @brief Read current value of the EPDC_PIGEON_2_1_CLR_CNT field. */
#define BR_EPDC_PIGEON_2_1_CLR_CNT(x) (HW_EPDC_PIGEON_2_1(x).B.CLR_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_2_1_CLR_CNT. */
#define BF_EPDC_PIGEON_2_1_CLR_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_2_1_CLR_CNT) & BM_EPDC_PIGEON_2_1_CLR_CNT)

/*! @brief Set the CLR_CNT field to a new value. */
#define BW_EPDC_PIGEON_2_1_CLR_CNT(x, v) (HW_EPDC_PIGEON_2_1_WR(x, (HW_EPDC_PIGEON_2_1_RD(x) & ~BM_EPDC_PIGEON_2_1_CLR_CNT) | BF_EPDC_PIGEON_2_1_CLR_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_2_2 - Panel Interface Signal Generator Register 2_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_2_2 - Panel Interface Signal Generator Register 2_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_2_2
{
    uint32_t U;
    struct _hw_epdc_pigeon_2_2_bitfields
    {
        uint32_t SIG_LOGIC : 4;        /*!< [3:0]  */
        uint32_t SIG_ANOTHER : 5;      /*!< [8:4]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_epdc_pigeon_2_2_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_2_2 register
 */
/*@{*/
#define HW_EPDC_PIGEON_2_2_ADDR(x) ((uintptr_t)(x) + 0x8A0U)

#define HW_EPDC_PIGEON_2_2(x)    (*(__IO hw_epdc_pigeon_2_2_t *) HW_EPDC_PIGEON_2_2_ADDR(x))
#define HW_EPDC_PIGEON_2_2_RD(x) (HW_EPDC_PIGEON_2_2(x).U)
#define HW_EPDC_PIGEON_2_2_WR(x, v) (HW_EPDC_PIGEON_2_2(x).U = (v))
#define HW_EPDC_PIGEON_2_2_SET(x, v) (HW_EPDC_PIGEON_2_2_WR(x, HW_EPDC_PIGEON_2_2_RD(x) |  (v)))
#define HW_EPDC_PIGEON_2_2_CLR(x, v) (HW_EPDC_PIGEON_2_2_WR(x, HW_EPDC_PIGEON_2_2_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_2_2_TOG(x, v) (HW_EPDC_PIGEON_2_2_WR(x, HW_EPDC_PIGEON_2_2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_2_2 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_2_2, field SIG_LOGIC[3:0] (RW)
 *
 * logic operation with another signal sigout : final output signal of this
 * generator mask : final mask of this generator this_sig : intermediate signal of
 * this generator before logic operation other_masks : intermediate mask result of
 * this generator before logic operation sig_another : signal selected other
 * generators
 *
 * Values:
 * - 0 - no logic operation
 * - 1 - sigout = sig_another AND this_sig
 * - 10 - sigout = sig_another OR this_sig
 * - 11 - mask = sig_another AND other_masks
 */
/*@{*/
#define BP_EPDC_PIGEON_2_2_SIG_LOGIC (0U)  /*!< Bit position for EPDC_PIGEON_2_2_SIG_LOGIC. */
#define BM_EPDC_PIGEON_2_2_SIG_LOGIC (0x0000000FU) /*!< Bit mask for EPDC_PIGEON_2_2_SIG_LOGIC. */
#define BS_EPDC_PIGEON_2_2_SIG_LOGIC (4U)  /*!< Bit field size in bits for EPDC_PIGEON_2_2_SIG_LOGIC. */

#define BV_EPDC_PIGEON_2_2_SIG_LOGIC_DIS (0U)        /*!< Bit field value for EPDC_PIGEON_2_2_SIG_LOGIC: no logic operation */
#define BV_EPDC_PIGEON_2_2_SIG_LOGIC_AND (0x1U)      /*!< Bit field value for EPDC_PIGEON_2_2_SIG_LOGIC: sigout = sig_another AND this_sig */
#define BV_EPDC_PIGEON_2_2_SIG_LOGIC_OR (0x2U)       /*!< Bit field value for EPDC_PIGEON_2_2_SIG_LOGIC: sigout = sig_another OR this_sig */
#define BV_EPDC_PIGEON_2_2_SIG_LOGIC_MASK (0x3U)     /*!< Bit field value for EPDC_PIGEON_2_2_SIG_LOGIC: mask = sig_another AND other_masks */

/*! @brief Read current value of the EPDC_PIGEON_2_2_SIG_LOGIC field. */
#define BR_EPDC_PIGEON_2_2_SIG_LOGIC(x) (HW_EPDC_PIGEON_2_2(x).B.SIG_LOGIC)

/*! @brief Format value for bitfield EPDC_PIGEON_2_2_SIG_LOGIC. */
#define BF_EPDC_PIGEON_2_2_SIG_LOGIC(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_2_2_SIG_LOGIC) & BM_EPDC_PIGEON_2_2_SIG_LOGIC)

/*! @brief Set the SIG_LOGIC field to a new value. */
#define BW_EPDC_PIGEON_2_2_SIG_LOGIC(x, v) (HW_EPDC_PIGEON_2_2_WR(x, (HW_EPDC_PIGEON_2_2_RD(x) & ~BM_EPDC_PIGEON_2_2_SIG_LOGIC) | BF_EPDC_PIGEON_2_2_SIG_LOGIC(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_2_2, field SIG_ANOTHER[8:4] (RW)
 *
 * select another signal for logic operation or as mask or counter tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_2_2_SIG_ANOTHER (4U) /*!< Bit position for EPDC_PIGEON_2_2_SIG_ANOTHER. */
#define BM_EPDC_PIGEON_2_2_SIG_ANOTHER (0x000001F0U) /*!< Bit mask for EPDC_PIGEON_2_2_SIG_ANOTHER. */
#define BS_EPDC_PIGEON_2_2_SIG_ANOTHER (5U) /*!< Bit field size in bits for EPDC_PIGEON_2_2_SIG_ANOTHER. */

/*! @brief Read current value of the EPDC_PIGEON_2_2_SIG_ANOTHER field. */
#define BR_EPDC_PIGEON_2_2_SIG_ANOTHER(x) (HW_EPDC_PIGEON_2_2(x).B.SIG_ANOTHER)

/*! @brief Format value for bitfield EPDC_PIGEON_2_2_SIG_ANOTHER. */
#define BF_EPDC_PIGEON_2_2_SIG_ANOTHER(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_2_2_SIG_ANOTHER) & BM_EPDC_PIGEON_2_2_SIG_ANOTHER)

/*! @brief Set the SIG_ANOTHER field to a new value. */
#define BW_EPDC_PIGEON_2_2_SIG_ANOTHER(x, v) (HW_EPDC_PIGEON_2_2_WR(x, (HW_EPDC_PIGEON_2_2_RD(x) & ~BM_EPDC_PIGEON_2_2_SIG_ANOTHER) | BF_EPDC_PIGEON_2_2_SIG_ANOTHER(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_3_0 - Panel Interface Signal Generator Register 3_0
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_3_0 - Panel Interface Signal Generator Register 3_0 (RW)
 *
 * Reset value: 0x00000F00U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_3_0
{
    uint32_t U;
    struct _hw_epdc_pigeon_3_0_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t POL : 1;              /*!< [1]  */
        uint32_t INC_SEL : 2;          /*!< [3:2]  */
        uint32_t OFFSET : 4;           /*!< [7:4]  */
        uint32_t MASK_CNT_SEL : 4;     /*!< [11:8]  */
        uint32_t MASK_CNT : 12;        /*!< [23:12]  */
        uint32_t STATE_MASK : 8;       /*!< [31:24]  */
    } B;
} hw_epdc_pigeon_3_0_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_3_0 register
 */
/*@{*/
#define HW_EPDC_PIGEON_3_0_ADDR(x) ((uintptr_t)(x) + 0x8C0U)

#define HW_EPDC_PIGEON_3_0(x)    (*(__IO hw_epdc_pigeon_3_0_t *) HW_EPDC_PIGEON_3_0_ADDR(x))
#define HW_EPDC_PIGEON_3_0_RD(x) (HW_EPDC_PIGEON_3_0(x).U)
#define HW_EPDC_PIGEON_3_0_WR(x, v) (HW_EPDC_PIGEON_3_0(x).U = (v))
#define HW_EPDC_PIGEON_3_0_SET(x, v) (HW_EPDC_PIGEON_3_0_WR(x, HW_EPDC_PIGEON_3_0_RD(x) |  (v)))
#define HW_EPDC_PIGEON_3_0_CLR(x, v) (HW_EPDC_PIGEON_3_0_WR(x, HW_EPDC_PIGEON_3_0_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_3_0_TOG(x, v) (HW_EPDC_PIGEON_3_0_WR(x, HW_EPDC_PIGEON_3_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_3_0 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_3_0, field EN[0] (RW)
 *
 * enable pigeon mode on this signal
 */
/*@{*/
#define BP_EPDC_PIGEON_3_0_EN (0U)         /*!< Bit position for EPDC_PIGEON_3_0_EN. */
#define BM_EPDC_PIGEON_3_0_EN (0x00000001U) /*!< Bit mask for EPDC_PIGEON_3_0_EN. */
#define BS_EPDC_PIGEON_3_0_EN (1U)         /*!< Bit field size in bits for EPDC_PIGEON_3_0_EN. */

/*! @brief Read current value of the EPDC_PIGEON_3_0_EN field. */
#define BR_EPDC_PIGEON_3_0_EN(x) (HW_EPDC_PIGEON_3_0(x).B.EN)

/*! @brief Format value for bitfield EPDC_PIGEON_3_0_EN. */
#define BF_EPDC_PIGEON_3_0_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_3_0_EN) & BM_EPDC_PIGEON_3_0_EN)

/*! @brief Set the EN field to a new value. */
#define BW_EPDC_PIGEON_3_0_EN(x, v) (HW_EPDC_PIGEON_3_0_WR(x, (HW_EPDC_PIGEON_3_0_RD(x) & ~BM_EPDC_PIGEON_3_0_EN) | BF_EPDC_PIGEON_3_0_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_3_0, field POL[1] (RW)
 *
 * polarity of signal output
 *
 * Values:
 * - 0 - normal signal (active high)
 * - 1 - inverted signal (active low)
 */
/*@{*/
#define BP_EPDC_PIGEON_3_0_POL (1U)        /*!< Bit position for EPDC_PIGEON_3_0_POL. */
#define BM_EPDC_PIGEON_3_0_POL (0x00000002U) /*!< Bit mask for EPDC_PIGEON_3_0_POL. */
#define BS_EPDC_PIGEON_3_0_POL (1U)        /*!< Bit field size in bits for EPDC_PIGEON_3_0_POL. */

#define BV_EPDC_PIGEON_3_0_POL_ACTIVE_HIGH (0U)      /*!< Bit field value for EPDC_PIGEON_3_0_POL: normal signal (active high) */
#define BV_EPDC_PIGEON_3_0_POL_ACTIVE_LOW (0x1U)     /*!< Bit field value for EPDC_PIGEON_3_0_POL: inverted signal (active low) */

/*! @brief Read current value of the EPDC_PIGEON_3_0_POL field. */
#define BR_EPDC_PIGEON_3_0_POL(x) (HW_EPDC_PIGEON_3_0(x).B.POL)

/*! @brief Format value for bitfield EPDC_PIGEON_3_0_POL. */
#define BF_EPDC_PIGEON_3_0_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_3_0_POL) & BM_EPDC_PIGEON_3_0_POL)

/*! @brief Set the POL field to a new value. */
#define BW_EPDC_PIGEON_3_0_POL(x, v) (HW_EPDC_PIGEON_3_0_WR(x, (HW_EPDC_PIGEON_3_0_RD(x) & ~BM_EPDC_PIGEON_3_0_POL) | BF_EPDC_PIGEON_3_0_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_3_0, field INC_SEL[3:2] (RW)
 *
 * event to incrment local counter
 *
 * Values:
 * - 0 - pclk
 * - 1 - line start pulse
 * - 10 - frame start pulse
 * - 11 - use another signal as tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_3_0_INC_SEL (2U)    /*!< Bit position for EPDC_PIGEON_3_0_INC_SEL. */
#define BM_EPDC_PIGEON_3_0_INC_SEL (0x0000000CU) /*!< Bit mask for EPDC_PIGEON_3_0_INC_SEL. */
#define BS_EPDC_PIGEON_3_0_INC_SEL (2U)    /*!< Bit field size in bits for EPDC_PIGEON_3_0_INC_SEL. */

#define BV_EPDC_PIGEON_3_0_INC_SEL_PCLK (0U)         /*!< Bit field value for EPDC_PIGEON_3_0_INC_SEL: pclk */
#define BV_EPDC_PIGEON_3_0_INC_SEL_LINE (0x1U)       /*!< Bit field value for EPDC_PIGEON_3_0_INC_SEL: line start pulse */
#define BV_EPDC_PIGEON_3_0_INC_SEL_FRAME (0x2U)      /*!< Bit field value for EPDC_PIGEON_3_0_INC_SEL: frame start pulse */
#define BV_EPDC_PIGEON_3_0_INC_SEL_SIG_ANOTHER (0x3U) /*!< Bit field value for EPDC_PIGEON_3_0_INC_SEL: use another signal as tick event */

/*! @brief Read current value of the EPDC_PIGEON_3_0_INC_SEL field. */
#define BR_EPDC_PIGEON_3_0_INC_SEL(x) (HW_EPDC_PIGEON_3_0(x).B.INC_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_3_0_INC_SEL. */
#define BF_EPDC_PIGEON_3_0_INC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_3_0_INC_SEL) & BM_EPDC_PIGEON_3_0_INC_SEL)

/*! @brief Set the INC_SEL field to a new value. */
#define BW_EPDC_PIGEON_3_0_INC_SEL(x, v) (HW_EPDC_PIGEON_3_0_WR(x, (HW_EPDC_PIGEON_3_0_RD(x) & ~BM_EPDC_PIGEON_3_0_INC_SEL) | BF_EPDC_PIGEON_3_0_INC_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_3_0, field OFFSET[7:4] (RW)
 *
 * offset on pclk unit. 0=aligne with data, positive value means delay, minus
 * value mean ahead. Supported range depends on panel mode
 */
/*@{*/
#define BP_EPDC_PIGEON_3_0_OFFSET (4U)     /*!< Bit position for EPDC_PIGEON_3_0_OFFSET. */
#define BM_EPDC_PIGEON_3_0_OFFSET (0x000000F0U) /*!< Bit mask for EPDC_PIGEON_3_0_OFFSET. */
#define BS_EPDC_PIGEON_3_0_OFFSET (4U)     /*!< Bit field size in bits for EPDC_PIGEON_3_0_OFFSET. */

/*! @brief Read current value of the EPDC_PIGEON_3_0_OFFSET field. */
#define BR_EPDC_PIGEON_3_0_OFFSET(x) (HW_EPDC_PIGEON_3_0(x).B.OFFSET)

/*! @brief Format value for bitfield EPDC_PIGEON_3_0_OFFSET. */
#define BF_EPDC_PIGEON_3_0_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_3_0_OFFSET) & BM_EPDC_PIGEON_3_0_OFFSET)

/*! @brief Set the OFFSET field to a new value. */
#define BW_EPDC_PIGEON_3_0_OFFSET(x, v) (HW_EPDC_PIGEON_3_0_WR(x, (HW_EPDC_PIGEON_3_0_RD(x) & ~BM_EPDC_PIGEON_3_0_OFFSET) | BF_EPDC_PIGEON_3_0_OFFSET(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_3_0, field MASK_CNT_SEL[11:8] (RW)
 *
 * select global counters as mask condition, use together with MASK_CNT
 *
 * Values:
 * - 0 - pclk counter within one hscan state
 * - 1 - pclk cycle within one hscan state
 * - 10 - line counter within one vscan state
 * - 11 - line cycle within one vscan state
 * - 100 - frame counter
 * - 101 - frame cycle
 * - 110 - horizontal counter (pclk counter within one line )
 * - 111 - vertical counter (line counter within one frame)
 */
/*@{*/
#define BP_EPDC_PIGEON_3_0_MASK_CNT_SEL (8U) /*!< Bit position for EPDC_PIGEON_3_0_MASK_CNT_SEL. */
#define BM_EPDC_PIGEON_3_0_MASK_CNT_SEL (0x00000F00U) /*!< Bit mask for EPDC_PIGEON_3_0_MASK_CNT_SEL. */
#define BS_EPDC_PIGEON_3_0_MASK_CNT_SEL (4U) /*!< Bit field size in bits for EPDC_PIGEON_3_0_MASK_CNT_SEL. */

#define BV_EPDC_PIGEON_3_0_MASK_CNT_SEL_HSTATE_CNT (0U) /*!< Bit field value for EPDC_PIGEON_3_0_MASK_CNT_SEL: pclk counter within one hscan state */
#define BV_EPDC_PIGEON_3_0_MASK_CNT_SEL_HSTATE_CYCLE (0x1U) /*!< Bit field value for EPDC_PIGEON_3_0_MASK_CNT_SEL: pclk cycle within one hscan state */
#define BV_EPDC_PIGEON_3_0_MASK_CNT_SEL_VSTATE_CNT (0x2U) /*!< Bit field value for EPDC_PIGEON_3_0_MASK_CNT_SEL: line counter within one vscan state */
#define BV_EPDC_PIGEON_3_0_MASK_CNT_SEL_VSTATE_CYCLE (0x3U) /*!< Bit field value for EPDC_PIGEON_3_0_MASK_CNT_SEL: line cycle within one vscan state */
#define BV_EPDC_PIGEON_3_0_MASK_CNT_SEL_FRAME_CNT (0x4U) /*!< Bit field value for EPDC_PIGEON_3_0_MASK_CNT_SEL: frame counter */
#define BV_EPDC_PIGEON_3_0_MASK_CNT_SEL_FRAME_CYCLE (0x5U) /*!< Bit field value for EPDC_PIGEON_3_0_MASK_CNT_SEL: frame cycle */
#define BV_EPDC_PIGEON_3_0_MASK_CNT_SEL_HCNT (0x6U)  /*!< Bit field value for EPDC_PIGEON_3_0_MASK_CNT_SEL: horizontal counter (pclk counter within one line ) */
#define BV_EPDC_PIGEON_3_0_MASK_CNT_SEL_VCNT (0x7U)  /*!< Bit field value for EPDC_PIGEON_3_0_MASK_CNT_SEL: vertical counter (line counter within one frame) */

/*! @brief Read current value of the EPDC_PIGEON_3_0_MASK_CNT_SEL field. */
#define BR_EPDC_PIGEON_3_0_MASK_CNT_SEL(x) (HW_EPDC_PIGEON_3_0(x).B.MASK_CNT_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_3_0_MASK_CNT_SEL. */
#define BF_EPDC_PIGEON_3_0_MASK_CNT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_3_0_MASK_CNT_SEL) & BM_EPDC_PIGEON_3_0_MASK_CNT_SEL)

/*! @brief Set the MASK_CNT_SEL field to a new value. */
#define BW_EPDC_PIGEON_3_0_MASK_CNT_SEL(x, v) (HW_EPDC_PIGEON_3_0_WR(x, (HW_EPDC_PIGEON_3_0_RD(x) & ~BM_EPDC_PIGEON_3_0_MASK_CNT_SEL) | BF_EPDC_PIGEON_3_0_MASK_CNT_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_3_0, field MASK_CNT[23:12] (RW)
 *
 * When the global counter selected through MASK_CNT_SEL matches value in this
 * reg, pigeon local counter start ticking. 0=disable
 */
/*@{*/
#define BP_EPDC_PIGEON_3_0_MASK_CNT (12U)  /*!< Bit position for EPDC_PIGEON_3_0_MASK_CNT. */
#define BM_EPDC_PIGEON_3_0_MASK_CNT (0x00FFF000U) /*!< Bit mask for EPDC_PIGEON_3_0_MASK_CNT. */
#define BS_EPDC_PIGEON_3_0_MASK_CNT (12U)  /*!< Bit field size in bits for EPDC_PIGEON_3_0_MASK_CNT. */

/*! @brief Read current value of the EPDC_PIGEON_3_0_MASK_CNT field. */
#define BR_EPDC_PIGEON_3_0_MASK_CNT(x) (HW_EPDC_PIGEON_3_0(x).B.MASK_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_3_0_MASK_CNT. */
#define BF_EPDC_PIGEON_3_0_MASK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_3_0_MASK_CNT) & BM_EPDC_PIGEON_3_0_MASK_CNT)

/*! @brief Set the MASK_CNT field to a new value. */
#define BW_EPDC_PIGEON_3_0_MASK_CNT(x, v) (HW_EPDC_PIGEON_3_0_WR(x, (HW_EPDC_PIGEON_3_0_RD(x) & ~BM_EPDC_PIGEON_3_0_MASK_CNT) | BF_EPDC_PIGEON_3_0_MASK_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_3_0, field STATE_MASK[31:24] (RW)
 *
 * state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan
 * states as reference point for local counter to start ticking
 *
 * Values:
 * - 1 - FRAME SYNC
 * - 10 - FRAME BEGIN
 * - 100 - FRAME DATA
 * - 1000 - FRAME END
 * - 10000 - LINE SYNC
 * - 100000 - LINE BEGIN
 * - 1000000 - LINE DATA
 * - 10000000 - LINE END
 */
/*@{*/
#define BP_EPDC_PIGEON_3_0_STATE_MASK (24U) /*!< Bit position for EPDC_PIGEON_3_0_STATE_MASK. */
#define BM_EPDC_PIGEON_3_0_STATE_MASK (0xFF000000U) /*!< Bit mask for EPDC_PIGEON_3_0_STATE_MASK. */
#define BS_EPDC_PIGEON_3_0_STATE_MASK (8U) /*!< Bit field size in bits for EPDC_PIGEON_3_0_STATE_MASK. */

#define BV_EPDC_PIGEON_3_0_STATE_MASK_FS (0x1U)      /*!< Bit field value for EPDC_PIGEON_3_0_STATE_MASK: FRAME SYNC */
#define BV_EPDC_PIGEON_3_0_STATE_MASK_FB (0x2U)      /*!< Bit field value for EPDC_PIGEON_3_0_STATE_MASK: FRAME BEGIN */
#define BV_EPDC_PIGEON_3_0_STATE_MASK_FD (0x4U)      /*!< Bit field value for EPDC_PIGEON_3_0_STATE_MASK: FRAME DATA */
#define BV_EPDC_PIGEON_3_0_STATE_MASK_FE (0x8U)      /*!< Bit field value for EPDC_PIGEON_3_0_STATE_MASK: FRAME END */
#define BV_EPDC_PIGEON_3_0_STATE_MASK_LS (0x10U)     /*!< Bit field value for EPDC_PIGEON_3_0_STATE_MASK: LINE SYNC */
#define BV_EPDC_PIGEON_3_0_STATE_MASK_LB (0x20U)     /*!< Bit field value for EPDC_PIGEON_3_0_STATE_MASK: LINE BEGIN */
#define BV_EPDC_PIGEON_3_0_STATE_MASK_LD (0x40U)     /*!< Bit field value for EPDC_PIGEON_3_0_STATE_MASK: LINE DATA */
#define BV_EPDC_PIGEON_3_0_STATE_MASK_LE (0x80U)     /*!< Bit field value for EPDC_PIGEON_3_0_STATE_MASK: LINE END */

/*! @brief Read current value of the EPDC_PIGEON_3_0_STATE_MASK field. */
#define BR_EPDC_PIGEON_3_0_STATE_MASK(x) (HW_EPDC_PIGEON_3_0(x).B.STATE_MASK)

/*! @brief Format value for bitfield EPDC_PIGEON_3_0_STATE_MASK. */
#define BF_EPDC_PIGEON_3_0_STATE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_3_0_STATE_MASK) & BM_EPDC_PIGEON_3_0_STATE_MASK)

/*! @brief Set the STATE_MASK field to a new value. */
#define BW_EPDC_PIGEON_3_0_STATE_MASK(x, v) (HW_EPDC_PIGEON_3_0_WR(x, (HW_EPDC_PIGEON_3_0_RD(x) & ~BM_EPDC_PIGEON_3_0_STATE_MASK) | BF_EPDC_PIGEON_3_0_STATE_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_3_1 - Panel Interface Signal Generator Register 3_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_3_1 - Panel Interface Signal Generator Register 3_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_3_1
{
    uint32_t U;
    struct _hw_epdc_pigeon_3_1_bitfields
    {
        uint32_t SET_CNT : 16;         /*!< [15:0]  */
        uint32_t CLR_CNT : 16;         /*!< [31:16]  */
    } B;
} hw_epdc_pigeon_3_1_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_3_1 register
 */
/*@{*/
#define HW_EPDC_PIGEON_3_1_ADDR(x) ((uintptr_t)(x) + 0x8D0U)

#define HW_EPDC_PIGEON_3_1(x)    (*(__IO hw_epdc_pigeon_3_1_t *) HW_EPDC_PIGEON_3_1_ADDR(x))
#define HW_EPDC_PIGEON_3_1_RD(x) (HW_EPDC_PIGEON_3_1(x).U)
#define HW_EPDC_PIGEON_3_1_WR(x, v) (HW_EPDC_PIGEON_3_1(x).U = (v))
#define HW_EPDC_PIGEON_3_1_SET(x, v) (HW_EPDC_PIGEON_3_1_WR(x, HW_EPDC_PIGEON_3_1_RD(x) |  (v)))
#define HW_EPDC_PIGEON_3_1_CLR(x, v) (HW_EPDC_PIGEON_3_1_WR(x, HW_EPDC_PIGEON_3_1_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_3_1_TOG(x, v) (HW_EPDC_PIGEON_3_1_WR(x, HW_EPDC_PIGEON_3_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_3_1 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_3_1, field SET_CNT[15:0] (RW)
 *
 * assert signal output when counter match this value
 *
 * Values:
 * - 0 - start as active
 */
/*@{*/
#define BP_EPDC_PIGEON_3_1_SET_CNT (0U)    /*!< Bit position for EPDC_PIGEON_3_1_SET_CNT. */
#define BM_EPDC_PIGEON_3_1_SET_CNT (0x0000FFFFU) /*!< Bit mask for EPDC_PIGEON_3_1_SET_CNT. */
#define BS_EPDC_PIGEON_3_1_SET_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_3_1_SET_CNT. */

#define BV_EPDC_PIGEON_3_1_SET_CNT_START_ACTIVE (0U) /*!< Bit field value for EPDC_PIGEON_3_1_SET_CNT: start as active */

/*! @brief Read current value of the EPDC_PIGEON_3_1_SET_CNT field. */
#define BR_EPDC_PIGEON_3_1_SET_CNT(x) (HW_EPDC_PIGEON_3_1(x).B.SET_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_3_1_SET_CNT. */
#define BF_EPDC_PIGEON_3_1_SET_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_3_1_SET_CNT) & BM_EPDC_PIGEON_3_1_SET_CNT)

/*! @brief Set the SET_CNT field to a new value. */
#define BW_EPDC_PIGEON_3_1_SET_CNT(x, v) (HW_EPDC_PIGEON_3_1_WR(x, (HW_EPDC_PIGEON_3_1_RD(x) & ~BM_EPDC_PIGEON_3_1_SET_CNT) | BF_EPDC_PIGEON_3_1_SET_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_3_1, field CLR_CNT[31:16] (RW)
 *
 * deassert signal output when counter match this value
 *
 * Values:
 * - 0 - keep active until mask off
 */
/*@{*/
#define BP_EPDC_PIGEON_3_1_CLR_CNT (16U)   /*!< Bit position for EPDC_PIGEON_3_1_CLR_CNT. */
#define BM_EPDC_PIGEON_3_1_CLR_CNT (0xFFFF0000U) /*!< Bit mask for EPDC_PIGEON_3_1_CLR_CNT. */
#define BS_EPDC_PIGEON_3_1_CLR_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_3_1_CLR_CNT. */

#define BV_EPDC_PIGEON_3_1_CLR_CNT_CLEAR_USING_MASK (0U) /*!< Bit field value for EPDC_PIGEON_3_1_CLR_CNT: keep active until mask off */

/*! @brief Read current value of the EPDC_PIGEON_3_1_CLR_CNT field. */
#define BR_EPDC_PIGEON_3_1_CLR_CNT(x) (HW_EPDC_PIGEON_3_1(x).B.CLR_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_3_1_CLR_CNT. */
#define BF_EPDC_PIGEON_3_1_CLR_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_3_1_CLR_CNT) & BM_EPDC_PIGEON_3_1_CLR_CNT)

/*! @brief Set the CLR_CNT field to a new value. */
#define BW_EPDC_PIGEON_3_1_CLR_CNT(x, v) (HW_EPDC_PIGEON_3_1_WR(x, (HW_EPDC_PIGEON_3_1_RD(x) & ~BM_EPDC_PIGEON_3_1_CLR_CNT) | BF_EPDC_PIGEON_3_1_CLR_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_3_2 - Panel Interface Signal Generator Register 3_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_3_2 - Panel Interface Signal Generator Register 3_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_3_2
{
    uint32_t U;
    struct _hw_epdc_pigeon_3_2_bitfields
    {
        uint32_t SIG_LOGIC : 4;        /*!< [3:0]  */
        uint32_t SIG_ANOTHER : 5;      /*!< [8:4]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_epdc_pigeon_3_2_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_3_2 register
 */
/*@{*/
#define HW_EPDC_PIGEON_3_2_ADDR(x) ((uintptr_t)(x) + 0x8E0U)

#define HW_EPDC_PIGEON_3_2(x)    (*(__IO hw_epdc_pigeon_3_2_t *) HW_EPDC_PIGEON_3_2_ADDR(x))
#define HW_EPDC_PIGEON_3_2_RD(x) (HW_EPDC_PIGEON_3_2(x).U)
#define HW_EPDC_PIGEON_3_2_WR(x, v) (HW_EPDC_PIGEON_3_2(x).U = (v))
#define HW_EPDC_PIGEON_3_2_SET(x, v) (HW_EPDC_PIGEON_3_2_WR(x, HW_EPDC_PIGEON_3_2_RD(x) |  (v)))
#define HW_EPDC_PIGEON_3_2_CLR(x, v) (HW_EPDC_PIGEON_3_2_WR(x, HW_EPDC_PIGEON_3_2_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_3_2_TOG(x, v) (HW_EPDC_PIGEON_3_2_WR(x, HW_EPDC_PIGEON_3_2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_3_2 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_3_2, field SIG_LOGIC[3:0] (RW)
 *
 * logic operation with another signal sigout : final output signal of this
 * generator mask : final mask of this generator this_sig : intermediate signal of
 * this generator before logic operation other_masks : intermediate mask result of
 * this generator before logic operation sig_another : signal selected other
 * generators
 *
 * Values:
 * - 0 - no logic operation
 * - 1 - sigout = sig_another AND this_sig
 * - 10 - sigout = sig_another OR this_sig
 * - 11 - mask = sig_another AND other_masks
 */
/*@{*/
#define BP_EPDC_PIGEON_3_2_SIG_LOGIC (0U)  /*!< Bit position for EPDC_PIGEON_3_2_SIG_LOGIC. */
#define BM_EPDC_PIGEON_3_2_SIG_LOGIC (0x0000000FU) /*!< Bit mask for EPDC_PIGEON_3_2_SIG_LOGIC. */
#define BS_EPDC_PIGEON_3_2_SIG_LOGIC (4U)  /*!< Bit field size in bits for EPDC_PIGEON_3_2_SIG_LOGIC. */

#define BV_EPDC_PIGEON_3_2_SIG_LOGIC_DIS (0U)        /*!< Bit field value for EPDC_PIGEON_3_2_SIG_LOGIC: no logic operation */
#define BV_EPDC_PIGEON_3_2_SIG_LOGIC_AND (0x1U)      /*!< Bit field value for EPDC_PIGEON_3_2_SIG_LOGIC: sigout = sig_another AND this_sig */
#define BV_EPDC_PIGEON_3_2_SIG_LOGIC_OR (0x2U)       /*!< Bit field value for EPDC_PIGEON_3_2_SIG_LOGIC: sigout = sig_another OR this_sig */
#define BV_EPDC_PIGEON_3_2_SIG_LOGIC_MASK (0x3U)     /*!< Bit field value for EPDC_PIGEON_3_2_SIG_LOGIC: mask = sig_another AND other_masks */

/*! @brief Read current value of the EPDC_PIGEON_3_2_SIG_LOGIC field. */
#define BR_EPDC_PIGEON_3_2_SIG_LOGIC(x) (HW_EPDC_PIGEON_3_2(x).B.SIG_LOGIC)

/*! @brief Format value for bitfield EPDC_PIGEON_3_2_SIG_LOGIC. */
#define BF_EPDC_PIGEON_3_2_SIG_LOGIC(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_3_2_SIG_LOGIC) & BM_EPDC_PIGEON_3_2_SIG_LOGIC)

/*! @brief Set the SIG_LOGIC field to a new value. */
#define BW_EPDC_PIGEON_3_2_SIG_LOGIC(x, v) (HW_EPDC_PIGEON_3_2_WR(x, (HW_EPDC_PIGEON_3_2_RD(x) & ~BM_EPDC_PIGEON_3_2_SIG_LOGIC) | BF_EPDC_PIGEON_3_2_SIG_LOGIC(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_3_2, field SIG_ANOTHER[8:4] (RW)
 *
 * select another signal for logic operation or as mask or counter tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_3_2_SIG_ANOTHER (4U) /*!< Bit position for EPDC_PIGEON_3_2_SIG_ANOTHER. */
#define BM_EPDC_PIGEON_3_2_SIG_ANOTHER (0x000001F0U) /*!< Bit mask for EPDC_PIGEON_3_2_SIG_ANOTHER. */
#define BS_EPDC_PIGEON_3_2_SIG_ANOTHER (5U) /*!< Bit field size in bits for EPDC_PIGEON_3_2_SIG_ANOTHER. */

/*! @brief Read current value of the EPDC_PIGEON_3_2_SIG_ANOTHER field. */
#define BR_EPDC_PIGEON_3_2_SIG_ANOTHER(x) (HW_EPDC_PIGEON_3_2(x).B.SIG_ANOTHER)

/*! @brief Format value for bitfield EPDC_PIGEON_3_2_SIG_ANOTHER. */
#define BF_EPDC_PIGEON_3_2_SIG_ANOTHER(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_3_2_SIG_ANOTHER) & BM_EPDC_PIGEON_3_2_SIG_ANOTHER)

/*! @brief Set the SIG_ANOTHER field to a new value. */
#define BW_EPDC_PIGEON_3_2_SIG_ANOTHER(x, v) (HW_EPDC_PIGEON_3_2_WR(x, (HW_EPDC_PIGEON_3_2_RD(x) & ~BM_EPDC_PIGEON_3_2_SIG_ANOTHER) | BF_EPDC_PIGEON_3_2_SIG_ANOTHER(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_4_0 - Panel Interface Signal Generator Register 4_0
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_4_0 - Panel Interface Signal Generator Register 4_0 (RW)
 *
 * Reset value: 0x00000F00U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_4_0
{
    uint32_t U;
    struct _hw_epdc_pigeon_4_0_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t POL : 1;              /*!< [1]  */
        uint32_t INC_SEL : 2;          /*!< [3:2]  */
        uint32_t OFFSET : 4;           /*!< [7:4]  */
        uint32_t MASK_CNT_SEL : 4;     /*!< [11:8]  */
        uint32_t MASK_CNT : 12;        /*!< [23:12]  */
        uint32_t STATE_MASK : 8;       /*!< [31:24]  */
    } B;
} hw_epdc_pigeon_4_0_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_4_0 register
 */
/*@{*/
#define HW_EPDC_PIGEON_4_0_ADDR(x) ((uintptr_t)(x) + 0x900U)

#define HW_EPDC_PIGEON_4_0(x)    (*(__IO hw_epdc_pigeon_4_0_t *) HW_EPDC_PIGEON_4_0_ADDR(x))
#define HW_EPDC_PIGEON_4_0_RD(x) (HW_EPDC_PIGEON_4_0(x).U)
#define HW_EPDC_PIGEON_4_0_WR(x, v) (HW_EPDC_PIGEON_4_0(x).U = (v))
#define HW_EPDC_PIGEON_4_0_SET(x, v) (HW_EPDC_PIGEON_4_0_WR(x, HW_EPDC_PIGEON_4_0_RD(x) |  (v)))
#define HW_EPDC_PIGEON_4_0_CLR(x, v) (HW_EPDC_PIGEON_4_0_WR(x, HW_EPDC_PIGEON_4_0_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_4_0_TOG(x, v) (HW_EPDC_PIGEON_4_0_WR(x, HW_EPDC_PIGEON_4_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_4_0 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_4_0, field EN[0] (RW)
 *
 * enable pigeon mode on this signal
 */
/*@{*/
#define BP_EPDC_PIGEON_4_0_EN (0U)         /*!< Bit position for EPDC_PIGEON_4_0_EN. */
#define BM_EPDC_PIGEON_4_0_EN (0x00000001U) /*!< Bit mask for EPDC_PIGEON_4_0_EN. */
#define BS_EPDC_PIGEON_4_0_EN (1U)         /*!< Bit field size in bits for EPDC_PIGEON_4_0_EN. */

/*! @brief Read current value of the EPDC_PIGEON_4_0_EN field. */
#define BR_EPDC_PIGEON_4_0_EN(x) (HW_EPDC_PIGEON_4_0(x).B.EN)

/*! @brief Format value for bitfield EPDC_PIGEON_4_0_EN. */
#define BF_EPDC_PIGEON_4_0_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_4_0_EN) & BM_EPDC_PIGEON_4_0_EN)

/*! @brief Set the EN field to a new value. */
#define BW_EPDC_PIGEON_4_0_EN(x, v) (HW_EPDC_PIGEON_4_0_WR(x, (HW_EPDC_PIGEON_4_0_RD(x) & ~BM_EPDC_PIGEON_4_0_EN) | BF_EPDC_PIGEON_4_0_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_4_0, field POL[1] (RW)
 *
 * polarity of signal output
 *
 * Values:
 * - 0 - normal signal (active high)
 * - 1 - inverted signal (active low)
 */
/*@{*/
#define BP_EPDC_PIGEON_4_0_POL (1U)        /*!< Bit position for EPDC_PIGEON_4_0_POL. */
#define BM_EPDC_PIGEON_4_0_POL (0x00000002U) /*!< Bit mask for EPDC_PIGEON_4_0_POL. */
#define BS_EPDC_PIGEON_4_0_POL (1U)        /*!< Bit field size in bits for EPDC_PIGEON_4_0_POL. */

#define BV_EPDC_PIGEON_4_0_POL_ACTIVE_HIGH (0U)      /*!< Bit field value for EPDC_PIGEON_4_0_POL: normal signal (active high) */
#define BV_EPDC_PIGEON_4_0_POL_ACTIVE_LOW (0x1U)     /*!< Bit field value for EPDC_PIGEON_4_0_POL: inverted signal (active low) */

/*! @brief Read current value of the EPDC_PIGEON_4_0_POL field. */
#define BR_EPDC_PIGEON_4_0_POL(x) (HW_EPDC_PIGEON_4_0(x).B.POL)

/*! @brief Format value for bitfield EPDC_PIGEON_4_0_POL. */
#define BF_EPDC_PIGEON_4_0_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_4_0_POL) & BM_EPDC_PIGEON_4_0_POL)

/*! @brief Set the POL field to a new value. */
#define BW_EPDC_PIGEON_4_0_POL(x, v) (HW_EPDC_PIGEON_4_0_WR(x, (HW_EPDC_PIGEON_4_0_RD(x) & ~BM_EPDC_PIGEON_4_0_POL) | BF_EPDC_PIGEON_4_0_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_4_0, field INC_SEL[3:2] (RW)
 *
 * event to incrment local counter
 *
 * Values:
 * - 0 - pclk
 * - 1 - line start pulse
 * - 10 - frame start pulse
 * - 11 - use another signal as tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_4_0_INC_SEL (2U)    /*!< Bit position for EPDC_PIGEON_4_0_INC_SEL. */
#define BM_EPDC_PIGEON_4_0_INC_SEL (0x0000000CU) /*!< Bit mask for EPDC_PIGEON_4_0_INC_SEL. */
#define BS_EPDC_PIGEON_4_0_INC_SEL (2U)    /*!< Bit field size in bits for EPDC_PIGEON_4_0_INC_SEL. */

#define BV_EPDC_PIGEON_4_0_INC_SEL_PCLK (0U)         /*!< Bit field value for EPDC_PIGEON_4_0_INC_SEL: pclk */
#define BV_EPDC_PIGEON_4_0_INC_SEL_LINE (0x1U)       /*!< Bit field value for EPDC_PIGEON_4_0_INC_SEL: line start pulse */
#define BV_EPDC_PIGEON_4_0_INC_SEL_FRAME (0x2U)      /*!< Bit field value for EPDC_PIGEON_4_0_INC_SEL: frame start pulse */
#define BV_EPDC_PIGEON_4_0_INC_SEL_SIG_ANOTHER (0x3U) /*!< Bit field value for EPDC_PIGEON_4_0_INC_SEL: use another signal as tick event */

/*! @brief Read current value of the EPDC_PIGEON_4_0_INC_SEL field. */
#define BR_EPDC_PIGEON_4_0_INC_SEL(x) (HW_EPDC_PIGEON_4_0(x).B.INC_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_4_0_INC_SEL. */
#define BF_EPDC_PIGEON_4_0_INC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_4_0_INC_SEL) & BM_EPDC_PIGEON_4_0_INC_SEL)

/*! @brief Set the INC_SEL field to a new value. */
#define BW_EPDC_PIGEON_4_0_INC_SEL(x, v) (HW_EPDC_PIGEON_4_0_WR(x, (HW_EPDC_PIGEON_4_0_RD(x) & ~BM_EPDC_PIGEON_4_0_INC_SEL) | BF_EPDC_PIGEON_4_0_INC_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_4_0, field OFFSET[7:4] (RW)
 *
 * offset on pclk unit. 0=aligne with data, positive value means delay, minus
 * value mean ahead. Supported range depends on panel mode
 */
/*@{*/
#define BP_EPDC_PIGEON_4_0_OFFSET (4U)     /*!< Bit position for EPDC_PIGEON_4_0_OFFSET. */
#define BM_EPDC_PIGEON_4_0_OFFSET (0x000000F0U) /*!< Bit mask for EPDC_PIGEON_4_0_OFFSET. */
#define BS_EPDC_PIGEON_4_0_OFFSET (4U)     /*!< Bit field size in bits for EPDC_PIGEON_4_0_OFFSET. */

/*! @brief Read current value of the EPDC_PIGEON_4_0_OFFSET field. */
#define BR_EPDC_PIGEON_4_0_OFFSET(x) (HW_EPDC_PIGEON_4_0(x).B.OFFSET)

/*! @brief Format value for bitfield EPDC_PIGEON_4_0_OFFSET. */
#define BF_EPDC_PIGEON_4_0_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_4_0_OFFSET) & BM_EPDC_PIGEON_4_0_OFFSET)

/*! @brief Set the OFFSET field to a new value. */
#define BW_EPDC_PIGEON_4_0_OFFSET(x, v) (HW_EPDC_PIGEON_4_0_WR(x, (HW_EPDC_PIGEON_4_0_RD(x) & ~BM_EPDC_PIGEON_4_0_OFFSET) | BF_EPDC_PIGEON_4_0_OFFSET(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_4_0, field MASK_CNT_SEL[11:8] (RW)
 *
 * select global counters as mask condition, use together with MASK_CNT
 *
 * Values:
 * - 0 - pclk counter within one hscan state
 * - 1 - pclk cycle within one hscan state
 * - 10 - line counter within one vscan state
 * - 11 - line cycle within one vscan state
 * - 100 - frame counter
 * - 101 - frame cycle
 * - 110 - horizontal counter (pclk counter within one line )
 * - 111 - vertical counter (line counter within one frame)
 */
/*@{*/
#define BP_EPDC_PIGEON_4_0_MASK_CNT_SEL (8U) /*!< Bit position for EPDC_PIGEON_4_0_MASK_CNT_SEL. */
#define BM_EPDC_PIGEON_4_0_MASK_CNT_SEL (0x00000F00U) /*!< Bit mask for EPDC_PIGEON_4_0_MASK_CNT_SEL. */
#define BS_EPDC_PIGEON_4_0_MASK_CNT_SEL (4U) /*!< Bit field size in bits for EPDC_PIGEON_4_0_MASK_CNT_SEL. */

#define BV_EPDC_PIGEON_4_0_MASK_CNT_SEL_HSTATE_CNT (0U) /*!< Bit field value for EPDC_PIGEON_4_0_MASK_CNT_SEL: pclk counter within one hscan state */
#define BV_EPDC_PIGEON_4_0_MASK_CNT_SEL_HSTATE_CYCLE (0x1U) /*!< Bit field value for EPDC_PIGEON_4_0_MASK_CNT_SEL: pclk cycle within one hscan state */
#define BV_EPDC_PIGEON_4_0_MASK_CNT_SEL_VSTATE_CNT (0x2U) /*!< Bit field value for EPDC_PIGEON_4_0_MASK_CNT_SEL: line counter within one vscan state */
#define BV_EPDC_PIGEON_4_0_MASK_CNT_SEL_VSTATE_CYCLE (0x3U) /*!< Bit field value for EPDC_PIGEON_4_0_MASK_CNT_SEL: line cycle within one vscan state */
#define BV_EPDC_PIGEON_4_0_MASK_CNT_SEL_FRAME_CNT (0x4U) /*!< Bit field value for EPDC_PIGEON_4_0_MASK_CNT_SEL: frame counter */
#define BV_EPDC_PIGEON_4_0_MASK_CNT_SEL_FRAME_CYCLE (0x5U) /*!< Bit field value for EPDC_PIGEON_4_0_MASK_CNT_SEL: frame cycle */
#define BV_EPDC_PIGEON_4_0_MASK_CNT_SEL_HCNT (0x6U)  /*!< Bit field value for EPDC_PIGEON_4_0_MASK_CNT_SEL: horizontal counter (pclk counter within one line ) */
#define BV_EPDC_PIGEON_4_0_MASK_CNT_SEL_VCNT (0x7U)  /*!< Bit field value for EPDC_PIGEON_4_0_MASK_CNT_SEL: vertical counter (line counter within one frame) */

/*! @brief Read current value of the EPDC_PIGEON_4_0_MASK_CNT_SEL field. */
#define BR_EPDC_PIGEON_4_0_MASK_CNT_SEL(x) (HW_EPDC_PIGEON_4_0(x).B.MASK_CNT_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_4_0_MASK_CNT_SEL. */
#define BF_EPDC_PIGEON_4_0_MASK_CNT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_4_0_MASK_CNT_SEL) & BM_EPDC_PIGEON_4_0_MASK_CNT_SEL)

/*! @brief Set the MASK_CNT_SEL field to a new value. */
#define BW_EPDC_PIGEON_4_0_MASK_CNT_SEL(x, v) (HW_EPDC_PIGEON_4_0_WR(x, (HW_EPDC_PIGEON_4_0_RD(x) & ~BM_EPDC_PIGEON_4_0_MASK_CNT_SEL) | BF_EPDC_PIGEON_4_0_MASK_CNT_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_4_0, field MASK_CNT[23:12] (RW)
 *
 * When the global counter selected through MASK_CNT_SEL matches value in this
 * reg, pigeon local counter start ticking. 0=disable
 */
/*@{*/
#define BP_EPDC_PIGEON_4_0_MASK_CNT (12U)  /*!< Bit position for EPDC_PIGEON_4_0_MASK_CNT. */
#define BM_EPDC_PIGEON_4_0_MASK_CNT (0x00FFF000U) /*!< Bit mask for EPDC_PIGEON_4_0_MASK_CNT. */
#define BS_EPDC_PIGEON_4_0_MASK_CNT (12U)  /*!< Bit field size in bits for EPDC_PIGEON_4_0_MASK_CNT. */

/*! @brief Read current value of the EPDC_PIGEON_4_0_MASK_CNT field. */
#define BR_EPDC_PIGEON_4_0_MASK_CNT(x) (HW_EPDC_PIGEON_4_0(x).B.MASK_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_4_0_MASK_CNT. */
#define BF_EPDC_PIGEON_4_0_MASK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_4_0_MASK_CNT) & BM_EPDC_PIGEON_4_0_MASK_CNT)

/*! @brief Set the MASK_CNT field to a new value. */
#define BW_EPDC_PIGEON_4_0_MASK_CNT(x, v) (HW_EPDC_PIGEON_4_0_WR(x, (HW_EPDC_PIGEON_4_0_RD(x) & ~BM_EPDC_PIGEON_4_0_MASK_CNT) | BF_EPDC_PIGEON_4_0_MASK_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_4_0, field STATE_MASK[31:24] (RW)
 *
 * state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan
 * states as reference point for local counter to start ticking
 *
 * Values:
 * - 1 - FRAME SYNC
 * - 10 - FRAME BEGIN
 * - 100 - FRAME DATA
 * - 1000 - FRAME END
 * - 10000 - LINE SYNC
 * - 100000 - LINE BEGIN
 * - 1000000 - LINE DATA
 * - 10000000 - LINE END
 */
/*@{*/
#define BP_EPDC_PIGEON_4_0_STATE_MASK (24U) /*!< Bit position for EPDC_PIGEON_4_0_STATE_MASK. */
#define BM_EPDC_PIGEON_4_0_STATE_MASK (0xFF000000U) /*!< Bit mask for EPDC_PIGEON_4_0_STATE_MASK. */
#define BS_EPDC_PIGEON_4_0_STATE_MASK (8U) /*!< Bit field size in bits for EPDC_PIGEON_4_0_STATE_MASK. */

#define BV_EPDC_PIGEON_4_0_STATE_MASK_FS (0x1U)      /*!< Bit field value for EPDC_PIGEON_4_0_STATE_MASK: FRAME SYNC */
#define BV_EPDC_PIGEON_4_0_STATE_MASK_FB (0x2U)      /*!< Bit field value for EPDC_PIGEON_4_0_STATE_MASK: FRAME BEGIN */
#define BV_EPDC_PIGEON_4_0_STATE_MASK_FD (0x4U)      /*!< Bit field value for EPDC_PIGEON_4_0_STATE_MASK: FRAME DATA */
#define BV_EPDC_PIGEON_4_0_STATE_MASK_FE (0x8U)      /*!< Bit field value for EPDC_PIGEON_4_0_STATE_MASK: FRAME END */
#define BV_EPDC_PIGEON_4_0_STATE_MASK_LS (0x10U)     /*!< Bit field value for EPDC_PIGEON_4_0_STATE_MASK: LINE SYNC */
#define BV_EPDC_PIGEON_4_0_STATE_MASK_LB (0x20U)     /*!< Bit field value for EPDC_PIGEON_4_0_STATE_MASK: LINE BEGIN */
#define BV_EPDC_PIGEON_4_0_STATE_MASK_LD (0x40U)     /*!< Bit field value for EPDC_PIGEON_4_0_STATE_MASK: LINE DATA */
#define BV_EPDC_PIGEON_4_0_STATE_MASK_LE (0x80U)     /*!< Bit field value for EPDC_PIGEON_4_0_STATE_MASK: LINE END */

/*! @brief Read current value of the EPDC_PIGEON_4_0_STATE_MASK field. */
#define BR_EPDC_PIGEON_4_0_STATE_MASK(x) (HW_EPDC_PIGEON_4_0(x).B.STATE_MASK)

/*! @brief Format value for bitfield EPDC_PIGEON_4_0_STATE_MASK. */
#define BF_EPDC_PIGEON_4_0_STATE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_4_0_STATE_MASK) & BM_EPDC_PIGEON_4_0_STATE_MASK)

/*! @brief Set the STATE_MASK field to a new value. */
#define BW_EPDC_PIGEON_4_0_STATE_MASK(x, v) (HW_EPDC_PIGEON_4_0_WR(x, (HW_EPDC_PIGEON_4_0_RD(x) & ~BM_EPDC_PIGEON_4_0_STATE_MASK) | BF_EPDC_PIGEON_4_0_STATE_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_4_1 - Panel Interface Signal Generator Register 4_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_4_1 - Panel Interface Signal Generator Register 4_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_4_1
{
    uint32_t U;
    struct _hw_epdc_pigeon_4_1_bitfields
    {
        uint32_t SET_CNT : 16;         /*!< [15:0]  */
        uint32_t CLR_CNT : 16;         /*!< [31:16]  */
    } B;
} hw_epdc_pigeon_4_1_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_4_1 register
 */
/*@{*/
#define HW_EPDC_PIGEON_4_1_ADDR(x) ((uintptr_t)(x) + 0x910U)

#define HW_EPDC_PIGEON_4_1(x)    (*(__IO hw_epdc_pigeon_4_1_t *) HW_EPDC_PIGEON_4_1_ADDR(x))
#define HW_EPDC_PIGEON_4_1_RD(x) (HW_EPDC_PIGEON_4_1(x).U)
#define HW_EPDC_PIGEON_4_1_WR(x, v) (HW_EPDC_PIGEON_4_1(x).U = (v))
#define HW_EPDC_PIGEON_4_1_SET(x, v) (HW_EPDC_PIGEON_4_1_WR(x, HW_EPDC_PIGEON_4_1_RD(x) |  (v)))
#define HW_EPDC_PIGEON_4_1_CLR(x, v) (HW_EPDC_PIGEON_4_1_WR(x, HW_EPDC_PIGEON_4_1_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_4_1_TOG(x, v) (HW_EPDC_PIGEON_4_1_WR(x, HW_EPDC_PIGEON_4_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_4_1 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_4_1, field SET_CNT[15:0] (RW)
 *
 * assert signal output when counter match this value
 *
 * Values:
 * - 0 - start as active
 */
/*@{*/
#define BP_EPDC_PIGEON_4_1_SET_CNT (0U)    /*!< Bit position for EPDC_PIGEON_4_1_SET_CNT. */
#define BM_EPDC_PIGEON_4_1_SET_CNT (0x0000FFFFU) /*!< Bit mask for EPDC_PIGEON_4_1_SET_CNT. */
#define BS_EPDC_PIGEON_4_1_SET_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_4_1_SET_CNT. */

#define BV_EPDC_PIGEON_4_1_SET_CNT_START_ACTIVE (0U) /*!< Bit field value for EPDC_PIGEON_4_1_SET_CNT: start as active */

/*! @brief Read current value of the EPDC_PIGEON_4_1_SET_CNT field. */
#define BR_EPDC_PIGEON_4_1_SET_CNT(x) (HW_EPDC_PIGEON_4_1(x).B.SET_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_4_1_SET_CNT. */
#define BF_EPDC_PIGEON_4_1_SET_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_4_1_SET_CNT) & BM_EPDC_PIGEON_4_1_SET_CNT)

/*! @brief Set the SET_CNT field to a new value. */
#define BW_EPDC_PIGEON_4_1_SET_CNT(x, v) (HW_EPDC_PIGEON_4_1_WR(x, (HW_EPDC_PIGEON_4_1_RD(x) & ~BM_EPDC_PIGEON_4_1_SET_CNT) | BF_EPDC_PIGEON_4_1_SET_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_4_1, field CLR_CNT[31:16] (RW)
 *
 * deassert signal output when counter match this value
 *
 * Values:
 * - 0 - keep active until mask off
 */
/*@{*/
#define BP_EPDC_PIGEON_4_1_CLR_CNT (16U)   /*!< Bit position for EPDC_PIGEON_4_1_CLR_CNT. */
#define BM_EPDC_PIGEON_4_1_CLR_CNT (0xFFFF0000U) /*!< Bit mask for EPDC_PIGEON_4_1_CLR_CNT. */
#define BS_EPDC_PIGEON_4_1_CLR_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_4_1_CLR_CNT. */

#define BV_EPDC_PIGEON_4_1_CLR_CNT_CLEAR_USING_MASK (0U) /*!< Bit field value for EPDC_PIGEON_4_1_CLR_CNT: keep active until mask off */

/*! @brief Read current value of the EPDC_PIGEON_4_1_CLR_CNT field. */
#define BR_EPDC_PIGEON_4_1_CLR_CNT(x) (HW_EPDC_PIGEON_4_1(x).B.CLR_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_4_1_CLR_CNT. */
#define BF_EPDC_PIGEON_4_1_CLR_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_4_1_CLR_CNT) & BM_EPDC_PIGEON_4_1_CLR_CNT)

/*! @brief Set the CLR_CNT field to a new value. */
#define BW_EPDC_PIGEON_4_1_CLR_CNT(x, v) (HW_EPDC_PIGEON_4_1_WR(x, (HW_EPDC_PIGEON_4_1_RD(x) & ~BM_EPDC_PIGEON_4_1_CLR_CNT) | BF_EPDC_PIGEON_4_1_CLR_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_4_2 - Panel Interface Signal Generator Register 4_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_4_2 - Panel Interface Signal Generator Register 4_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_4_2
{
    uint32_t U;
    struct _hw_epdc_pigeon_4_2_bitfields
    {
        uint32_t SIG_LOGIC : 4;        /*!< [3:0]  */
        uint32_t SIG_ANOTHER : 5;      /*!< [8:4]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_epdc_pigeon_4_2_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_4_2 register
 */
/*@{*/
#define HW_EPDC_PIGEON_4_2_ADDR(x) ((uintptr_t)(x) + 0x920U)

#define HW_EPDC_PIGEON_4_2(x)    (*(__IO hw_epdc_pigeon_4_2_t *) HW_EPDC_PIGEON_4_2_ADDR(x))
#define HW_EPDC_PIGEON_4_2_RD(x) (HW_EPDC_PIGEON_4_2(x).U)
#define HW_EPDC_PIGEON_4_2_WR(x, v) (HW_EPDC_PIGEON_4_2(x).U = (v))
#define HW_EPDC_PIGEON_4_2_SET(x, v) (HW_EPDC_PIGEON_4_2_WR(x, HW_EPDC_PIGEON_4_2_RD(x) |  (v)))
#define HW_EPDC_PIGEON_4_2_CLR(x, v) (HW_EPDC_PIGEON_4_2_WR(x, HW_EPDC_PIGEON_4_2_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_4_2_TOG(x, v) (HW_EPDC_PIGEON_4_2_WR(x, HW_EPDC_PIGEON_4_2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_4_2 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_4_2, field SIG_LOGIC[3:0] (RW)
 *
 * logic operation with another signal sigout : final output signal of this
 * generator mask : final mask of this generator this_sig : intermediate signal of
 * this generator before logic operation other_masks : intermediate mask result of
 * this generator before logic operation sig_another : signal selected other
 * generators
 *
 * Values:
 * - 0 - no logic operation
 * - 1 - sigout = sig_another AND this_sig
 * - 10 - sigout = sig_another OR this_sig
 * - 11 - mask = sig_another AND other_masks
 */
/*@{*/
#define BP_EPDC_PIGEON_4_2_SIG_LOGIC (0U)  /*!< Bit position for EPDC_PIGEON_4_2_SIG_LOGIC. */
#define BM_EPDC_PIGEON_4_2_SIG_LOGIC (0x0000000FU) /*!< Bit mask for EPDC_PIGEON_4_2_SIG_LOGIC. */
#define BS_EPDC_PIGEON_4_2_SIG_LOGIC (4U)  /*!< Bit field size in bits for EPDC_PIGEON_4_2_SIG_LOGIC. */

#define BV_EPDC_PIGEON_4_2_SIG_LOGIC_DIS (0U)        /*!< Bit field value for EPDC_PIGEON_4_2_SIG_LOGIC: no logic operation */
#define BV_EPDC_PIGEON_4_2_SIG_LOGIC_AND (0x1U)      /*!< Bit field value for EPDC_PIGEON_4_2_SIG_LOGIC: sigout = sig_another AND this_sig */
#define BV_EPDC_PIGEON_4_2_SIG_LOGIC_OR (0x2U)       /*!< Bit field value for EPDC_PIGEON_4_2_SIG_LOGIC: sigout = sig_another OR this_sig */
#define BV_EPDC_PIGEON_4_2_SIG_LOGIC_MASK (0x3U)     /*!< Bit field value for EPDC_PIGEON_4_2_SIG_LOGIC: mask = sig_another AND other_masks */

/*! @brief Read current value of the EPDC_PIGEON_4_2_SIG_LOGIC field. */
#define BR_EPDC_PIGEON_4_2_SIG_LOGIC(x) (HW_EPDC_PIGEON_4_2(x).B.SIG_LOGIC)

/*! @brief Format value for bitfield EPDC_PIGEON_4_2_SIG_LOGIC. */
#define BF_EPDC_PIGEON_4_2_SIG_LOGIC(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_4_2_SIG_LOGIC) & BM_EPDC_PIGEON_4_2_SIG_LOGIC)

/*! @brief Set the SIG_LOGIC field to a new value. */
#define BW_EPDC_PIGEON_4_2_SIG_LOGIC(x, v) (HW_EPDC_PIGEON_4_2_WR(x, (HW_EPDC_PIGEON_4_2_RD(x) & ~BM_EPDC_PIGEON_4_2_SIG_LOGIC) | BF_EPDC_PIGEON_4_2_SIG_LOGIC(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_4_2, field SIG_ANOTHER[8:4] (RW)
 *
 * select another signal for logic operation or as mask or counter tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_4_2_SIG_ANOTHER (4U) /*!< Bit position for EPDC_PIGEON_4_2_SIG_ANOTHER. */
#define BM_EPDC_PIGEON_4_2_SIG_ANOTHER (0x000001F0U) /*!< Bit mask for EPDC_PIGEON_4_2_SIG_ANOTHER. */
#define BS_EPDC_PIGEON_4_2_SIG_ANOTHER (5U) /*!< Bit field size in bits for EPDC_PIGEON_4_2_SIG_ANOTHER. */

/*! @brief Read current value of the EPDC_PIGEON_4_2_SIG_ANOTHER field. */
#define BR_EPDC_PIGEON_4_2_SIG_ANOTHER(x) (HW_EPDC_PIGEON_4_2(x).B.SIG_ANOTHER)

/*! @brief Format value for bitfield EPDC_PIGEON_4_2_SIG_ANOTHER. */
#define BF_EPDC_PIGEON_4_2_SIG_ANOTHER(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_4_2_SIG_ANOTHER) & BM_EPDC_PIGEON_4_2_SIG_ANOTHER)

/*! @brief Set the SIG_ANOTHER field to a new value. */
#define BW_EPDC_PIGEON_4_2_SIG_ANOTHER(x, v) (HW_EPDC_PIGEON_4_2_WR(x, (HW_EPDC_PIGEON_4_2_RD(x) & ~BM_EPDC_PIGEON_4_2_SIG_ANOTHER) | BF_EPDC_PIGEON_4_2_SIG_ANOTHER(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_5_0 - Panel Interface Signal Generator Register 5_0
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_5_0 - Panel Interface Signal Generator Register 5_0 (RW)
 *
 * Reset value: 0x00000F00U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_5_0
{
    uint32_t U;
    struct _hw_epdc_pigeon_5_0_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t POL : 1;              /*!< [1]  */
        uint32_t INC_SEL : 2;          /*!< [3:2]  */
        uint32_t OFFSET : 4;           /*!< [7:4]  */
        uint32_t MASK_CNT_SEL : 4;     /*!< [11:8]  */
        uint32_t MASK_CNT : 12;        /*!< [23:12]  */
        uint32_t STATE_MASK : 8;       /*!< [31:24]  */
    } B;
} hw_epdc_pigeon_5_0_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_5_0 register
 */
/*@{*/
#define HW_EPDC_PIGEON_5_0_ADDR(x) ((uintptr_t)(x) + 0x940U)

#define HW_EPDC_PIGEON_5_0(x)    (*(__IO hw_epdc_pigeon_5_0_t *) HW_EPDC_PIGEON_5_0_ADDR(x))
#define HW_EPDC_PIGEON_5_0_RD(x) (HW_EPDC_PIGEON_5_0(x).U)
#define HW_EPDC_PIGEON_5_0_WR(x, v) (HW_EPDC_PIGEON_5_0(x).U = (v))
#define HW_EPDC_PIGEON_5_0_SET(x, v) (HW_EPDC_PIGEON_5_0_WR(x, HW_EPDC_PIGEON_5_0_RD(x) |  (v)))
#define HW_EPDC_PIGEON_5_0_CLR(x, v) (HW_EPDC_PIGEON_5_0_WR(x, HW_EPDC_PIGEON_5_0_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_5_0_TOG(x, v) (HW_EPDC_PIGEON_5_0_WR(x, HW_EPDC_PIGEON_5_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_5_0 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_5_0, field EN[0] (RW)
 *
 * enable pigeon mode on this signal
 */
/*@{*/
#define BP_EPDC_PIGEON_5_0_EN (0U)         /*!< Bit position for EPDC_PIGEON_5_0_EN. */
#define BM_EPDC_PIGEON_5_0_EN (0x00000001U) /*!< Bit mask for EPDC_PIGEON_5_0_EN. */
#define BS_EPDC_PIGEON_5_0_EN (1U)         /*!< Bit field size in bits for EPDC_PIGEON_5_0_EN. */

/*! @brief Read current value of the EPDC_PIGEON_5_0_EN field. */
#define BR_EPDC_PIGEON_5_0_EN(x) (HW_EPDC_PIGEON_5_0(x).B.EN)

/*! @brief Format value for bitfield EPDC_PIGEON_5_0_EN. */
#define BF_EPDC_PIGEON_5_0_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_5_0_EN) & BM_EPDC_PIGEON_5_0_EN)

/*! @brief Set the EN field to a new value. */
#define BW_EPDC_PIGEON_5_0_EN(x, v) (HW_EPDC_PIGEON_5_0_WR(x, (HW_EPDC_PIGEON_5_0_RD(x) & ~BM_EPDC_PIGEON_5_0_EN) | BF_EPDC_PIGEON_5_0_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_5_0, field POL[1] (RW)
 *
 * polarity of signal output
 *
 * Values:
 * - 0 - normal signal (active high)
 * - 1 - inverted signal (active low)
 */
/*@{*/
#define BP_EPDC_PIGEON_5_0_POL (1U)        /*!< Bit position for EPDC_PIGEON_5_0_POL. */
#define BM_EPDC_PIGEON_5_0_POL (0x00000002U) /*!< Bit mask for EPDC_PIGEON_5_0_POL. */
#define BS_EPDC_PIGEON_5_0_POL (1U)        /*!< Bit field size in bits for EPDC_PIGEON_5_0_POL. */

#define BV_EPDC_PIGEON_5_0_POL_ACTIVE_HIGH (0U)      /*!< Bit field value for EPDC_PIGEON_5_0_POL: normal signal (active high) */
#define BV_EPDC_PIGEON_5_0_POL_ACTIVE_LOW (0x1U)     /*!< Bit field value for EPDC_PIGEON_5_0_POL: inverted signal (active low) */

/*! @brief Read current value of the EPDC_PIGEON_5_0_POL field. */
#define BR_EPDC_PIGEON_5_0_POL(x) (HW_EPDC_PIGEON_5_0(x).B.POL)

/*! @brief Format value for bitfield EPDC_PIGEON_5_0_POL. */
#define BF_EPDC_PIGEON_5_0_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_5_0_POL) & BM_EPDC_PIGEON_5_0_POL)

/*! @brief Set the POL field to a new value. */
#define BW_EPDC_PIGEON_5_0_POL(x, v) (HW_EPDC_PIGEON_5_0_WR(x, (HW_EPDC_PIGEON_5_0_RD(x) & ~BM_EPDC_PIGEON_5_0_POL) | BF_EPDC_PIGEON_5_0_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_5_0, field INC_SEL[3:2] (RW)
 *
 * event to incrment local counter
 *
 * Values:
 * - 0 - pclk
 * - 1 - line start pulse
 * - 10 - frame start pulse
 * - 11 - use another signal as tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_5_0_INC_SEL (2U)    /*!< Bit position for EPDC_PIGEON_5_0_INC_SEL. */
#define BM_EPDC_PIGEON_5_0_INC_SEL (0x0000000CU) /*!< Bit mask for EPDC_PIGEON_5_0_INC_SEL. */
#define BS_EPDC_PIGEON_5_0_INC_SEL (2U)    /*!< Bit field size in bits for EPDC_PIGEON_5_0_INC_SEL. */

#define BV_EPDC_PIGEON_5_0_INC_SEL_PCLK (0U)         /*!< Bit field value for EPDC_PIGEON_5_0_INC_SEL: pclk */
#define BV_EPDC_PIGEON_5_0_INC_SEL_LINE (0x1U)       /*!< Bit field value for EPDC_PIGEON_5_0_INC_SEL: line start pulse */
#define BV_EPDC_PIGEON_5_0_INC_SEL_FRAME (0x2U)      /*!< Bit field value for EPDC_PIGEON_5_0_INC_SEL: frame start pulse */
#define BV_EPDC_PIGEON_5_0_INC_SEL_SIG_ANOTHER (0x3U) /*!< Bit field value for EPDC_PIGEON_5_0_INC_SEL: use another signal as tick event */

/*! @brief Read current value of the EPDC_PIGEON_5_0_INC_SEL field. */
#define BR_EPDC_PIGEON_5_0_INC_SEL(x) (HW_EPDC_PIGEON_5_0(x).B.INC_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_5_0_INC_SEL. */
#define BF_EPDC_PIGEON_5_0_INC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_5_0_INC_SEL) & BM_EPDC_PIGEON_5_0_INC_SEL)

/*! @brief Set the INC_SEL field to a new value. */
#define BW_EPDC_PIGEON_5_0_INC_SEL(x, v) (HW_EPDC_PIGEON_5_0_WR(x, (HW_EPDC_PIGEON_5_0_RD(x) & ~BM_EPDC_PIGEON_5_0_INC_SEL) | BF_EPDC_PIGEON_5_0_INC_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_5_0, field OFFSET[7:4] (RW)
 *
 * offset on pclk unit. 0=aligne with data, positive value means delay, minus
 * value mean ahead. Supported range depends on panel mode
 */
/*@{*/
#define BP_EPDC_PIGEON_5_0_OFFSET (4U)     /*!< Bit position for EPDC_PIGEON_5_0_OFFSET. */
#define BM_EPDC_PIGEON_5_0_OFFSET (0x000000F0U) /*!< Bit mask for EPDC_PIGEON_5_0_OFFSET. */
#define BS_EPDC_PIGEON_5_0_OFFSET (4U)     /*!< Bit field size in bits for EPDC_PIGEON_5_0_OFFSET. */

/*! @brief Read current value of the EPDC_PIGEON_5_0_OFFSET field. */
#define BR_EPDC_PIGEON_5_0_OFFSET(x) (HW_EPDC_PIGEON_5_0(x).B.OFFSET)

/*! @brief Format value for bitfield EPDC_PIGEON_5_0_OFFSET. */
#define BF_EPDC_PIGEON_5_0_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_5_0_OFFSET) & BM_EPDC_PIGEON_5_0_OFFSET)

/*! @brief Set the OFFSET field to a new value. */
#define BW_EPDC_PIGEON_5_0_OFFSET(x, v) (HW_EPDC_PIGEON_5_0_WR(x, (HW_EPDC_PIGEON_5_0_RD(x) & ~BM_EPDC_PIGEON_5_0_OFFSET) | BF_EPDC_PIGEON_5_0_OFFSET(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_5_0, field MASK_CNT_SEL[11:8] (RW)
 *
 * select global counters as mask condition, use together with MASK_CNT
 *
 * Values:
 * - 0 - pclk counter within one hscan state
 * - 1 - pclk cycle within one hscan state
 * - 10 - line counter within one vscan state
 * - 11 - line cycle within one vscan state
 * - 100 - frame counter
 * - 101 - frame cycle
 * - 110 - horizontal counter (pclk counter within one line )
 * - 111 - vertical counter (line counter within one frame)
 */
/*@{*/
#define BP_EPDC_PIGEON_5_0_MASK_CNT_SEL (8U) /*!< Bit position for EPDC_PIGEON_5_0_MASK_CNT_SEL. */
#define BM_EPDC_PIGEON_5_0_MASK_CNT_SEL (0x00000F00U) /*!< Bit mask for EPDC_PIGEON_5_0_MASK_CNT_SEL. */
#define BS_EPDC_PIGEON_5_0_MASK_CNT_SEL (4U) /*!< Bit field size in bits for EPDC_PIGEON_5_0_MASK_CNT_SEL. */

#define BV_EPDC_PIGEON_5_0_MASK_CNT_SEL_HSTATE_CNT (0U) /*!< Bit field value for EPDC_PIGEON_5_0_MASK_CNT_SEL: pclk counter within one hscan state */
#define BV_EPDC_PIGEON_5_0_MASK_CNT_SEL_HSTATE_CYCLE (0x1U) /*!< Bit field value for EPDC_PIGEON_5_0_MASK_CNT_SEL: pclk cycle within one hscan state */
#define BV_EPDC_PIGEON_5_0_MASK_CNT_SEL_VSTATE_CNT (0x2U) /*!< Bit field value for EPDC_PIGEON_5_0_MASK_CNT_SEL: line counter within one vscan state */
#define BV_EPDC_PIGEON_5_0_MASK_CNT_SEL_VSTATE_CYCLE (0x3U) /*!< Bit field value for EPDC_PIGEON_5_0_MASK_CNT_SEL: line cycle within one vscan state */
#define BV_EPDC_PIGEON_5_0_MASK_CNT_SEL_FRAME_CNT (0x4U) /*!< Bit field value for EPDC_PIGEON_5_0_MASK_CNT_SEL: frame counter */
#define BV_EPDC_PIGEON_5_0_MASK_CNT_SEL_FRAME_CYCLE (0x5U) /*!< Bit field value for EPDC_PIGEON_5_0_MASK_CNT_SEL: frame cycle */
#define BV_EPDC_PIGEON_5_0_MASK_CNT_SEL_HCNT (0x6U)  /*!< Bit field value for EPDC_PIGEON_5_0_MASK_CNT_SEL: horizontal counter (pclk counter within one line ) */
#define BV_EPDC_PIGEON_5_0_MASK_CNT_SEL_VCNT (0x7U)  /*!< Bit field value for EPDC_PIGEON_5_0_MASK_CNT_SEL: vertical counter (line counter within one frame) */

/*! @brief Read current value of the EPDC_PIGEON_5_0_MASK_CNT_SEL field. */
#define BR_EPDC_PIGEON_5_0_MASK_CNT_SEL(x) (HW_EPDC_PIGEON_5_0(x).B.MASK_CNT_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_5_0_MASK_CNT_SEL. */
#define BF_EPDC_PIGEON_5_0_MASK_CNT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_5_0_MASK_CNT_SEL) & BM_EPDC_PIGEON_5_0_MASK_CNT_SEL)

/*! @brief Set the MASK_CNT_SEL field to a new value. */
#define BW_EPDC_PIGEON_5_0_MASK_CNT_SEL(x, v) (HW_EPDC_PIGEON_5_0_WR(x, (HW_EPDC_PIGEON_5_0_RD(x) & ~BM_EPDC_PIGEON_5_0_MASK_CNT_SEL) | BF_EPDC_PIGEON_5_0_MASK_CNT_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_5_0, field MASK_CNT[23:12] (RW)
 *
 * When the global counter selected through MASK_CNT_SEL matches value in this
 * reg, pigeon local counter start ticking. 0=disable
 */
/*@{*/
#define BP_EPDC_PIGEON_5_0_MASK_CNT (12U)  /*!< Bit position for EPDC_PIGEON_5_0_MASK_CNT. */
#define BM_EPDC_PIGEON_5_0_MASK_CNT (0x00FFF000U) /*!< Bit mask for EPDC_PIGEON_5_0_MASK_CNT. */
#define BS_EPDC_PIGEON_5_0_MASK_CNT (12U)  /*!< Bit field size in bits for EPDC_PIGEON_5_0_MASK_CNT. */

/*! @brief Read current value of the EPDC_PIGEON_5_0_MASK_CNT field. */
#define BR_EPDC_PIGEON_5_0_MASK_CNT(x) (HW_EPDC_PIGEON_5_0(x).B.MASK_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_5_0_MASK_CNT. */
#define BF_EPDC_PIGEON_5_0_MASK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_5_0_MASK_CNT) & BM_EPDC_PIGEON_5_0_MASK_CNT)

/*! @brief Set the MASK_CNT field to a new value. */
#define BW_EPDC_PIGEON_5_0_MASK_CNT(x, v) (HW_EPDC_PIGEON_5_0_WR(x, (HW_EPDC_PIGEON_5_0_RD(x) & ~BM_EPDC_PIGEON_5_0_MASK_CNT) | BF_EPDC_PIGEON_5_0_MASK_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_5_0, field STATE_MASK[31:24] (RW)
 *
 * state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan
 * states as reference point for local counter to start ticking
 *
 * Values:
 * - 1 - FRAME SYNC
 * - 10 - FRAME BEGIN
 * - 100 - FRAME DATA
 * - 1000 - FRAME END
 * - 10000 - LINE SYNC
 * - 100000 - LINE BEGIN
 * - 1000000 - LINE DATA
 * - 10000000 - LINE END
 */
/*@{*/
#define BP_EPDC_PIGEON_5_0_STATE_MASK (24U) /*!< Bit position for EPDC_PIGEON_5_0_STATE_MASK. */
#define BM_EPDC_PIGEON_5_0_STATE_MASK (0xFF000000U) /*!< Bit mask for EPDC_PIGEON_5_0_STATE_MASK. */
#define BS_EPDC_PIGEON_5_0_STATE_MASK (8U) /*!< Bit field size in bits for EPDC_PIGEON_5_0_STATE_MASK. */

#define BV_EPDC_PIGEON_5_0_STATE_MASK_FS (0x1U)      /*!< Bit field value for EPDC_PIGEON_5_0_STATE_MASK: FRAME SYNC */
#define BV_EPDC_PIGEON_5_0_STATE_MASK_FB (0x2U)      /*!< Bit field value for EPDC_PIGEON_5_0_STATE_MASK: FRAME BEGIN */
#define BV_EPDC_PIGEON_5_0_STATE_MASK_FD (0x4U)      /*!< Bit field value for EPDC_PIGEON_5_0_STATE_MASK: FRAME DATA */
#define BV_EPDC_PIGEON_5_0_STATE_MASK_FE (0x8U)      /*!< Bit field value for EPDC_PIGEON_5_0_STATE_MASK: FRAME END */
#define BV_EPDC_PIGEON_5_0_STATE_MASK_LS (0x10U)     /*!< Bit field value for EPDC_PIGEON_5_0_STATE_MASK: LINE SYNC */
#define BV_EPDC_PIGEON_5_0_STATE_MASK_LB (0x20U)     /*!< Bit field value for EPDC_PIGEON_5_0_STATE_MASK: LINE BEGIN */
#define BV_EPDC_PIGEON_5_0_STATE_MASK_LD (0x40U)     /*!< Bit field value for EPDC_PIGEON_5_0_STATE_MASK: LINE DATA */
#define BV_EPDC_PIGEON_5_0_STATE_MASK_LE (0x80U)     /*!< Bit field value for EPDC_PIGEON_5_0_STATE_MASK: LINE END */

/*! @brief Read current value of the EPDC_PIGEON_5_0_STATE_MASK field. */
#define BR_EPDC_PIGEON_5_0_STATE_MASK(x) (HW_EPDC_PIGEON_5_0(x).B.STATE_MASK)

/*! @brief Format value for bitfield EPDC_PIGEON_5_0_STATE_MASK. */
#define BF_EPDC_PIGEON_5_0_STATE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_5_0_STATE_MASK) & BM_EPDC_PIGEON_5_0_STATE_MASK)

/*! @brief Set the STATE_MASK field to a new value. */
#define BW_EPDC_PIGEON_5_0_STATE_MASK(x, v) (HW_EPDC_PIGEON_5_0_WR(x, (HW_EPDC_PIGEON_5_0_RD(x) & ~BM_EPDC_PIGEON_5_0_STATE_MASK) | BF_EPDC_PIGEON_5_0_STATE_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_5_1 - Panel Interface Signal Generator Register 5_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_5_1 - Panel Interface Signal Generator Register 5_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_5_1
{
    uint32_t U;
    struct _hw_epdc_pigeon_5_1_bitfields
    {
        uint32_t SET_CNT : 16;         /*!< [15:0]  */
        uint32_t CLR_CNT : 16;         /*!< [31:16]  */
    } B;
} hw_epdc_pigeon_5_1_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_5_1 register
 */
/*@{*/
#define HW_EPDC_PIGEON_5_1_ADDR(x) ((uintptr_t)(x) + 0x950U)

#define HW_EPDC_PIGEON_5_1(x)    (*(__IO hw_epdc_pigeon_5_1_t *) HW_EPDC_PIGEON_5_1_ADDR(x))
#define HW_EPDC_PIGEON_5_1_RD(x) (HW_EPDC_PIGEON_5_1(x).U)
#define HW_EPDC_PIGEON_5_1_WR(x, v) (HW_EPDC_PIGEON_5_1(x).U = (v))
#define HW_EPDC_PIGEON_5_1_SET(x, v) (HW_EPDC_PIGEON_5_1_WR(x, HW_EPDC_PIGEON_5_1_RD(x) |  (v)))
#define HW_EPDC_PIGEON_5_1_CLR(x, v) (HW_EPDC_PIGEON_5_1_WR(x, HW_EPDC_PIGEON_5_1_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_5_1_TOG(x, v) (HW_EPDC_PIGEON_5_1_WR(x, HW_EPDC_PIGEON_5_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_5_1 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_5_1, field SET_CNT[15:0] (RW)
 *
 * assert signal output when counter match this value
 *
 * Values:
 * - 0 - start as active
 */
/*@{*/
#define BP_EPDC_PIGEON_5_1_SET_CNT (0U)    /*!< Bit position for EPDC_PIGEON_5_1_SET_CNT. */
#define BM_EPDC_PIGEON_5_1_SET_CNT (0x0000FFFFU) /*!< Bit mask for EPDC_PIGEON_5_1_SET_CNT. */
#define BS_EPDC_PIGEON_5_1_SET_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_5_1_SET_CNT. */

#define BV_EPDC_PIGEON_5_1_SET_CNT_START_ACTIVE (0U) /*!< Bit field value for EPDC_PIGEON_5_1_SET_CNT: start as active */

/*! @brief Read current value of the EPDC_PIGEON_5_1_SET_CNT field. */
#define BR_EPDC_PIGEON_5_1_SET_CNT(x) (HW_EPDC_PIGEON_5_1(x).B.SET_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_5_1_SET_CNT. */
#define BF_EPDC_PIGEON_5_1_SET_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_5_1_SET_CNT) & BM_EPDC_PIGEON_5_1_SET_CNT)

/*! @brief Set the SET_CNT field to a new value. */
#define BW_EPDC_PIGEON_5_1_SET_CNT(x, v) (HW_EPDC_PIGEON_5_1_WR(x, (HW_EPDC_PIGEON_5_1_RD(x) & ~BM_EPDC_PIGEON_5_1_SET_CNT) | BF_EPDC_PIGEON_5_1_SET_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_5_1, field CLR_CNT[31:16] (RW)
 *
 * deassert signal output when counter match this value
 *
 * Values:
 * - 0 - keep active until mask off
 */
/*@{*/
#define BP_EPDC_PIGEON_5_1_CLR_CNT (16U)   /*!< Bit position for EPDC_PIGEON_5_1_CLR_CNT. */
#define BM_EPDC_PIGEON_5_1_CLR_CNT (0xFFFF0000U) /*!< Bit mask for EPDC_PIGEON_5_1_CLR_CNT. */
#define BS_EPDC_PIGEON_5_1_CLR_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_5_1_CLR_CNT. */

#define BV_EPDC_PIGEON_5_1_CLR_CNT_CLEAR_USING_MASK (0U) /*!< Bit field value for EPDC_PIGEON_5_1_CLR_CNT: keep active until mask off */

/*! @brief Read current value of the EPDC_PIGEON_5_1_CLR_CNT field. */
#define BR_EPDC_PIGEON_5_1_CLR_CNT(x) (HW_EPDC_PIGEON_5_1(x).B.CLR_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_5_1_CLR_CNT. */
#define BF_EPDC_PIGEON_5_1_CLR_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_5_1_CLR_CNT) & BM_EPDC_PIGEON_5_1_CLR_CNT)

/*! @brief Set the CLR_CNT field to a new value. */
#define BW_EPDC_PIGEON_5_1_CLR_CNT(x, v) (HW_EPDC_PIGEON_5_1_WR(x, (HW_EPDC_PIGEON_5_1_RD(x) & ~BM_EPDC_PIGEON_5_1_CLR_CNT) | BF_EPDC_PIGEON_5_1_CLR_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_5_2 - Panel Interface Signal Generator Register 5_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_5_2 - Panel Interface Signal Generator Register 5_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_5_2
{
    uint32_t U;
    struct _hw_epdc_pigeon_5_2_bitfields
    {
        uint32_t SIG_LOGIC : 4;        /*!< [3:0]  */
        uint32_t SIG_ANOTHER : 5;      /*!< [8:4]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_epdc_pigeon_5_2_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_5_2 register
 */
/*@{*/
#define HW_EPDC_PIGEON_5_2_ADDR(x) ((uintptr_t)(x) + 0x960U)

#define HW_EPDC_PIGEON_5_2(x)    (*(__IO hw_epdc_pigeon_5_2_t *) HW_EPDC_PIGEON_5_2_ADDR(x))
#define HW_EPDC_PIGEON_5_2_RD(x) (HW_EPDC_PIGEON_5_2(x).U)
#define HW_EPDC_PIGEON_5_2_WR(x, v) (HW_EPDC_PIGEON_5_2(x).U = (v))
#define HW_EPDC_PIGEON_5_2_SET(x, v) (HW_EPDC_PIGEON_5_2_WR(x, HW_EPDC_PIGEON_5_2_RD(x) |  (v)))
#define HW_EPDC_PIGEON_5_2_CLR(x, v) (HW_EPDC_PIGEON_5_2_WR(x, HW_EPDC_PIGEON_5_2_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_5_2_TOG(x, v) (HW_EPDC_PIGEON_5_2_WR(x, HW_EPDC_PIGEON_5_2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_5_2 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_5_2, field SIG_LOGIC[3:0] (RW)
 *
 * logic operation with another signal sigout : final output signal of this
 * generator mask : final mask of this generator this_sig : intermediate signal of
 * this generator before logic operation other_masks : intermediate mask result of
 * this generator before logic operation sig_another : signal selected other
 * generators
 *
 * Values:
 * - 0 - no logic operation
 * - 1 - sigout = sig_another AND this_sig
 * - 10 - sigout = sig_another OR this_sig
 * - 11 - mask = sig_another AND other_masks
 */
/*@{*/
#define BP_EPDC_PIGEON_5_2_SIG_LOGIC (0U)  /*!< Bit position for EPDC_PIGEON_5_2_SIG_LOGIC. */
#define BM_EPDC_PIGEON_5_2_SIG_LOGIC (0x0000000FU) /*!< Bit mask for EPDC_PIGEON_5_2_SIG_LOGIC. */
#define BS_EPDC_PIGEON_5_2_SIG_LOGIC (4U)  /*!< Bit field size in bits for EPDC_PIGEON_5_2_SIG_LOGIC. */

#define BV_EPDC_PIGEON_5_2_SIG_LOGIC_DIS (0U)        /*!< Bit field value for EPDC_PIGEON_5_2_SIG_LOGIC: no logic operation */
#define BV_EPDC_PIGEON_5_2_SIG_LOGIC_AND (0x1U)      /*!< Bit field value for EPDC_PIGEON_5_2_SIG_LOGIC: sigout = sig_another AND this_sig */
#define BV_EPDC_PIGEON_5_2_SIG_LOGIC_OR (0x2U)       /*!< Bit field value for EPDC_PIGEON_5_2_SIG_LOGIC: sigout = sig_another OR this_sig */
#define BV_EPDC_PIGEON_5_2_SIG_LOGIC_MASK (0x3U)     /*!< Bit field value for EPDC_PIGEON_5_2_SIG_LOGIC: mask = sig_another AND other_masks */

/*! @brief Read current value of the EPDC_PIGEON_5_2_SIG_LOGIC field. */
#define BR_EPDC_PIGEON_5_2_SIG_LOGIC(x) (HW_EPDC_PIGEON_5_2(x).B.SIG_LOGIC)

/*! @brief Format value for bitfield EPDC_PIGEON_5_2_SIG_LOGIC. */
#define BF_EPDC_PIGEON_5_2_SIG_LOGIC(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_5_2_SIG_LOGIC) & BM_EPDC_PIGEON_5_2_SIG_LOGIC)

/*! @brief Set the SIG_LOGIC field to a new value. */
#define BW_EPDC_PIGEON_5_2_SIG_LOGIC(x, v) (HW_EPDC_PIGEON_5_2_WR(x, (HW_EPDC_PIGEON_5_2_RD(x) & ~BM_EPDC_PIGEON_5_2_SIG_LOGIC) | BF_EPDC_PIGEON_5_2_SIG_LOGIC(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_5_2, field SIG_ANOTHER[8:4] (RW)
 *
 * select another signal for logic operation or as mask or counter tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_5_2_SIG_ANOTHER (4U) /*!< Bit position for EPDC_PIGEON_5_2_SIG_ANOTHER. */
#define BM_EPDC_PIGEON_5_2_SIG_ANOTHER (0x000001F0U) /*!< Bit mask for EPDC_PIGEON_5_2_SIG_ANOTHER. */
#define BS_EPDC_PIGEON_5_2_SIG_ANOTHER (5U) /*!< Bit field size in bits for EPDC_PIGEON_5_2_SIG_ANOTHER. */

/*! @brief Read current value of the EPDC_PIGEON_5_2_SIG_ANOTHER field. */
#define BR_EPDC_PIGEON_5_2_SIG_ANOTHER(x) (HW_EPDC_PIGEON_5_2(x).B.SIG_ANOTHER)

/*! @brief Format value for bitfield EPDC_PIGEON_5_2_SIG_ANOTHER. */
#define BF_EPDC_PIGEON_5_2_SIG_ANOTHER(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_5_2_SIG_ANOTHER) & BM_EPDC_PIGEON_5_2_SIG_ANOTHER)

/*! @brief Set the SIG_ANOTHER field to a new value. */
#define BW_EPDC_PIGEON_5_2_SIG_ANOTHER(x, v) (HW_EPDC_PIGEON_5_2_WR(x, (HW_EPDC_PIGEON_5_2_RD(x) & ~BM_EPDC_PIGEON_5_2_SIG_ANOTHER) | BF_EPDC_PIGEON_5_2_SIG_ANOTHER(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_6_0 - Panel Interface Signal Generator Register 6_0
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_6_0 - Panel Interface Signal Generator Register 6_0 (RW)
 *
 * Reset value: 0x00000F00U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_6_0
{
    uint32_t U;
    struct _hw_epdc_pigeon_6_0_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t POL : 1;              /*!< [1]  */
        uint32_t INC_SEL : 2;          /*!< [3:2]  */
        uint32_t OFFSET : 4;           /*!< [7:4]  */
        uint32_t MASK_CNT_SEL : 4;     /*!< [11:8]  */
        uint32_t MASK_CNT : 12;        /*!< [23:12]  */
        uint32_t STATE_MASK : 8;       /*!< [31:24]  */
    } B;
} hw_epdc_pigeon_6_0_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_6_0 register
 */
/*@{*/
#define HW_EPDC_PIGEON_6_0_ADDR(x) ((uintptr_t)(x) + 0x980U)

#define HW_EPDC_PIGEON_6_0(x)    (*(__IO hw_epdc_pigeon_6_0_t *) HW_EPDC_PIGEON_6_0_ADDR(x))
#define HW_EPDC_PIGEON_6_0_RD(x) (HW_EPDC_PIGEON_6_0(x).U)
#define HW_EPDC_PIGEON_6_0_WR(x, v) (HW_EPDC_PIGEON_6_0(x).U = (v))
#define HW_EPDC_PIGEON_6_0_SET(x, v) (HW_EPDC_PIGEON_6_0_WR(x, HW_EPDC_PIGEON_6_0_RD(x) |  (v)))
#define HW_EPDC_PIGEON_6_0_CLR(x, v) (HW_EPDC_PIGEON_6_0_WR(x, HW_EPDC_PIGEON_6_0_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_6_0_TOG(x, v) (HW_EPDC_PIGEON_6_0_WR(x, HW_EPDC_PIGEON_6_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_6_0 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_6_0, field EN[0] (RW)
 *
 * enable pigeon mode on this signal
 */
/*@{*/
#define BP_EPDC_PIGEON_6_0_EN (0U)         /*!< Bit position for EPDC_PIGEON_6_0_EN. */
#define BM_EPDC_PIGEON_6_0_EN (0x00000001U) /*!< Bit mask for EPDC_PIGEON_6_0_EN. */
#define BS_EPDC_PIGEON_6_0_EN (1U)         /*!< Bit field size in bits for EPDC_PIGEON_6_0_EN. */

/*! @brief Read current value of the EPDC_PIGEON_6_0_EN field. */
#define BR_EPDC_PIGEON_6_0_EN(x) (HW_EPDC_PIGEON_6_0(x).B.EN)

/*! @brief Format value for bitfield EPDC_PIGEON_6_0_EN. */
#define BF_EPDC_PIGEON_6_0_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_6_0_EN) & BM_EPDC_PIGEON_6_0_EN)

/*! @brief Set the EN field to a new value. */
#define BW_EPDC_PIGEON_6_0_EN(x, v) (HW_EPDC_PIGEON_6_0_WR(x, (HW_EPDC_PIGEON_6_0_RD(x) & ~BM_EPDC_PIGEON_6_0_EN) | BF_EPDC_PIGEON_6_0_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_6_0, field POL[1] (RW)
 *
 * polarity of signal output
 *
 * Values:
 * - 0 - normal signal (active high)
 * - 1 - inverted signal (active low)
 */
/*@{*/
#define BP_EPDC_PIGEON_6_0_POL (1U)        /*!< Bit position for EPDC_PIGEON_6_0_POL. */
#define BM_EPDC_PIGEON_6_0_POL (0x00000002U) /*!< Bit mask for EPDC_PIGEON_6_0_POL. */
#define BS_EPDC_PIGEON_6_0_POL (1U)        /*!< Bit field size in bits for EPDC_PIGEON_6_0_POL. */

#define BV_EPDC_PIGEON_6_0_POL_ACTIVE_HIGH (0U)      /*!< Bit field value for EPDC_PIGEON_6_0_POL: normal signal (active high) */
#define BV_EPDC_PIGEON_6_0_POL_ACTIVE_LOW (0x1U)     /*!< Bit field value for EPDC_PIGEON_6_0_POL: inverted signal (active low) */

/*! @brief Read current value of the EPDC_PIGEON_6_0_POL field. */
#define BR_EPDC_PIGEON_6_0_POL(x) (HW_EPDC_PIGEON_6_0(x).B.POL)

/*! @brief Format value for bitfield EPDC_PIGEON_6_0_POL. */
#define BF_EPDC_PIGEON_6_0_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_6_0_POL) & BM_EPDC_PIGEON_6_0_POL)

/*! @brief Set the POL field to a new value. */
#define BW_EPDC_PIGEON_6_0_POL(x, v) (HW_EPDC_PIGEON_6_0_WR(x, (HW_EPDC_PIGEON_6_0_RD(x) & ~BM_EPDC_PIGEON_6_0_POL) | BF_EPDC_PIGEON_6_0_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_6_0, field INC_SEL[3:2] (RW)
 *
 * event to incrment local counter
 *
 * Values:
 * - 0 - pclk
 * - 1 - line start pulse
 * - 10 - frame start pulse
 * - 11 - use another signal as tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_6_0_INC_SEL (2U)    /*!< Bit position for EPDC_PIGEON_6_0_INC_SEL. */
#define BM_EPDC_PIGEON_6_0_INC_SEL (0x0000000CU) /*!< Bit mask for EPDC_PIGEON_6_0_INC_SEL. */
#define BS_EPDC_PIGEON_6_0_INC_SEL (2U)    /*!< Bit field size in bits for EPDC_PIGEON_6_0_INC_SEL. */

#define BV_EPDC_PIGEON_6_0_INC_SEL_PCLK (0U)         /*!< Bit field value for EPDC_PIGEON_6_0_INC_SEL: pclk */
#define BV_EPDC_PIGEON_6_0_INC_SEL_LINE (0x1U)       /*!< Bit field value for EPDC_PIGEON_6_0_INC_SEL: line start pulse */
#define BV_EPDC_PIGEON_6_0_INC_SEL_FRAME (0x2U)      /*!< Bit field value for EPDC_PIGEON_6_0_INC_SEL: frame start pulse */
#define BV_EPDC_PIGEON_6_0_INC_SEL_SIG_ANOTHER (0x3U) /*!< Bit field value for EPDC_PIGEON_6_0_INC_SEL: use another signal as tick event */

/*! @brief Read current value of the EPDC_PIGEON_6_0_INC_SEL field. */
#define BR_EPDC_PIGEON_6_0_INC_SEL(x) (HW_EPDC_PIGEON_6_0(x).B.INC_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_6_0_INC_SEL. */
#define BF_EPDC_PIGEON_6_0_INC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_6_0_INC_SEL) & BM_EPDC_PIGEON_6_0_INC_SEL)

/*! @brief Set the INC_SEL field to a new value. */
#define BW_EPDC_PIGEON_6_0_INC_SEL(x, v) (HW_EPDC_PIGEON_6_0_WR(x, (HW_EPDC_PIGEON_6_0_RD(x) & ~BM_EPDC_PIGEON_6_0_INC_SEL) | BF_EPDC_PIGEON_6_0_INC_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_6_0, field OFFSET[7:4] (RW)
 *
 * offset on pclk unit. 0=aligne with data, positive value means delay, minus
 * value mean ahead. Supported range depends on panel mode
 */
/*@{*/
#define BP_EPDC_PIGEON_6_0_OFFSET (4U)     /*!< Bit position for EPDC_PIGEON_6_0_OFFSET. */
#define BM_EPDC_PIGEON_6_0_OFFSET (0x000000F0U) /*!< Bit mask for EPDC_PIGEON_6_0_OFFSET. */
#define BS_EPDC_PIGEON_6_0_OFFSET (4U)     /*!< Bit field size in bits for EPDC_PIGEON_6_0_OFFSET. */

/*! @brief Read current value of the EPDC_PIGEON_6_0_OFFSET field. */
#define BR_EPDC_PIGEON_6_0_OFFSET(x) (HW_EPDC_PIGEON_6_0(x).B.OFFSET)

/*! @brief Format value for bitfield EPDC_PIGEON_6_0_OFFSET. */
#define BF_EPDC_PIGEON_6_0_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_6_0_OFFSET) & BM_EPDC_PIGEON_6_0_OFFSET)

/*! @brief Set the OFFSET field to a new value. */
#define BW_EPDC_PIGEON_6_0_OFFSET(x, v) (HW_EPDC_PIGEON_6_0_WR(x, (HW_EPDC_PIGEON_6_0_RD(x) & ~BM_EPDC_PIGEON_6_0_OFFSET) | BF_EPDC_PIGEON_6_0_OFFSET(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_6_0, field MASK_CNT_SEL[11:8] (RW)
 *
 * select global counters as mask condition, use together with MASK_CNT
 *
 * Values:
 * - 0 - pclk counter within one hscan state
 * - 1 - pclk cycle within one hscan state
 * - 10 - line counter within one vscan state
 * - 11 - line cycle within one vscan state
 * - 100 - frame counter
 * - 101 - frame cycle
 * - 110 - horizontal counter (pclk counter within one line )
 * - 111 - vertical counter (line counter within one frame)
 */
/*@{*/
#define BP_EPDC_PIGEON_6_0_MASK_CNT_SEL (8U) /*!< Bit position for EPDC_PIGEON_6_0_MASK_CNT_SEL. */
#define BM_EPDC_PIGEON_6_0_MASK_CNT_SEL (0x00000F00U) /*!< Bit mask for EPDC_PIGEON_6_0_MASK_CNT_SEL. */
#define BS_EPDC_PIGEON_6_0_MASK_CNT_SEL (4U) /*!< Bit field size in bits for EPDC_PIGEON_6_0_MASK_CNT_SEL. */

#define BV_EPDC_PIGEON_6_0_MASK_CNT_SEL_HSTATE_CNT (0U) /*!< Bit field value for EPDC_PIGEON_6_0_MASK_CNT_SEL: pclk counter within one hscan state */
#define BV_EPDC_PIGEON_6_0_MASK_CNT_SEL_HSTATE_CYCLE (0x1U) /*!< Bit field value for EPDC_PIGEON_6_0_MASK_CNT_SEL: pclk cycle within one hscan state */
#define BV_EPDC_PIGEON_6_0_MASK_CNT_SEL_VSTATE_CNT (0x2U) /*!< Bit field value for EPDC_PIGEON_6_0_MASK_CNT_SEL: line counter within one vscan state */
#define BV_EPDC_PIGEON_6_0_MASK_CNT_SEL_VSTATE_CYCLE (0x3U) /*!< Bit field value for EPDC_PIGEON_6_0_MASK_CNT_SEL: line cycle within one vscan state */
#define BV_EPDC_PIGEON_6_0_MASK_CNT_SEL_FRAME_CNT (0x4U) /*!< Bit field value for EPDC_PIGEON_6_0_MASK_CNT_SEL: frame counter */
#define BV_EPDC_PIGEON_6_0_MASK_CNT_SEL_FRAME_CYCLE (0x5U) /*!< Bit field value for EPDC_PIGEON_6_0_MASK_CNT_SEL: frame cycle */
#define BV_EPDC_PIGEON_6_0_MASK_CNT_SEL_HCNT (0x6U)  /*!< Bit field value for EPDC_PIGEON_6_0_MASK_CNT_SEL: horizontal counter (pclk counter within one line ) */
#define BV_EPDC_PIGEON_6_0_MASK_CNT_SEL_VCNT (0x7U)  /*!< Bit field value for EPDC_PIGEON_6_0_MASK_CNT_SEL: vertical counter (line counter within one frame) */

/*! @brief Read current value of the EPDC_PIGEON_6_0_MASK_CNT_SEL field. */
#define BR_EPDC_PIGEON_6_0_MASK_CNT_SEL(x) (HW_EPDC_PIGEON_6_0(x).B.MASK_CNT_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_6_0_MASK_CNT_SEL. */
#define BF_EPDC_PIGEON_6_0_MASK_CNT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_6_0_MASK_CNT_SEL) & BM_EPDC_PIGEON_6_0_MASK_CNT_SEL)

/*! @brief Set the MASK_CNT_SEL field to a new value. */
#define BW_EPDC_PIGEON_6_0_MASK_CNT_SEL(x, v) (HW_EPDC_PIGEON_6_0_WR(x, (HW_EPDC_PIGEON_6_0_RD(x) & ~BM_EPDC_PIGEON_6_0_MASK_CNT_SEL) | BF_EPDC_PIGEON_6_0_MASK_CNT_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_6_0, field MASK_CNT[23:12] (RW)
 *
 * When the global counter selected through MASK_CNT_SEL matches value in this
 * reg, pigeon local counter start ticking. 0=disable
 */
/*@{*/
#define BP_EPDC_PIGEON_6_0_MASK_CNT (12U)  /*!< Bit position for EPDC_PIGEON_6_0_MASK_CNT. */
#define BM_EPDC_PIGEON_6_0_MASK_CNT (0x00FFF000U) /*!< Bit mask for EPDC_PIGEON_6_0_MASK_CNT. */
#define BS_EPDC_PIGEON_6_0_MASK_CNT (12U)  /*!< Bit field size in bits for EPDC_PIGEON_6_0_MASK_CNT. */

/*! @brief Read current value of the EPDC_PIGEON_6_0_MASK_CNT field. */
#define BR_EPDC_PIGEON_6_0_MASK_CNT(x) (HW_EPDC_PIGEON_6_0(x).B.MASK_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_6_0_MASK_CNT. */
#define BF_EPDC_PIGEON_6_0_MASK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_6_0_MASK_CNT) & BM_EPDC_PIGEON_6_0_MASK_CNT)

/*! @brief Set the MASK_CNT field to a new value. */
#define BW_EPDC_PIGEON_6_0_MASK_CNT(x, v) (HW_EPDC_PIGEON_6_0_WR(x, (HW_EPDC_PIGEON_6_0_RD(x) & ~BM_EPDC_PIGEON_6_0_MASK_CNT) | BF_EPDC_PIGEON_6_0_MASK_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_6_0, field STATE_MASK[31:24] (RW)
 *
 * state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan
 * states as reference point for local counter to start ticking
 *
 * Values:
 * - 1 - FRAME SYNC
 * - 10 - FRAME BEGIN
 * - 100 - FRAME DATA
 * - 1000 - FRAME END
 * - 10000 - LINE SYNC
 * - 100000 - LINE BEGIN
 * - 1000000 - LINE DATA
 * - 10000000 - LINE END
 */
/*@{*/
#define BP_EPDC_PIGEON_6_0_STATE_MASK (24U) /*!< Bit position for EPDC_PIGEON_6_0_STATE_MASK. */
#define BM_EPDC_PIGEON_6_0_STATE_MASK (0xFF000000U) /*!< Bit mask for EPDC_PIGEON_6_0_STATE_MASK. */
#define BS_EPDC_PIGEON_6_0_STATE_MASK (8U) /*!< Bit field size in bits for EPDC_PIGEON_6_0_STATE_MASK. */

#define BV_EPDC_PIGEON_6_0_STATE_MASK_FS (0x1U)      /*!< Bit field value for EPDC_PIGEON_6_0_STATE_MASK: FRAME SYNC */
#define BV_EPDC_PIGEON_6_0_STATE_MASK_FB (0x2U)      /*!< Bit field value for EPDC_PIGEON_6_0_STATE_MASK: FRAME BEGIN */
#define BV_EPDC_PIGEON_6_0_STATE_MASK_FD (0x4U)      /*!< Bit field value for EPDC_PIGEON_6_0_STATE_MASK: FRAME DATA */
#define BV_EPDC_PIGEON_6_0_STATE_MASK_FE (0x8U)      /*!< Bit field value for EPDC_PIGEON_6_0_STATE_MASK: FRAME END */
#define BV_EPDC_PIGEON_6_0_STATE_MASK_LS (0x10U)     /*!< Bit field value for EPDC_PIGEON_6_0_STATE_MASK: LINE SYNC */
#define BV_EPDC_PIGEON_6_0_STATE_MASK_LB (0x20U)     /*!< Bit field value for EPDC_PIGEON_6_0_STATE_MASK: LINE BEGIN */
#define BV_EPDC_PIGEON_6_0_STATE_MASK_LD (0x40U)     /*!< Bit field value for EPDC_PIGEON_6_0_STATE_MASK: LINE DATA */
#define BV_EPDC_PIGEON_6_0_STATE_MASK_LE (0x80U)     /*!< Bit field value for EPDC_PIGEON_6_0_STATE_MASK: LINE END */

/*! @brief Read current value of the EPDC_PIGEON_6_0_STATE_MASK field. */
#define BR_EPDC_PIGEON_6_0_STATE_MASK(x) (HW_EPDC_PIGEON_6_0(x).B.STATE_MASK)

/*! @brief Format value for bitfield EPDC_PIGEON_6_0_STATE_MASK. */
#define BF_EPDC_PIGEON_6_0_STATE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_6_0_STATE_MASK) & BM_EPDC_PIGEON_6_0_STATE_MASK)

/*! @brief Set the STATE_MASK field to a new value. */
#define BW_EPDC_PIGEON_6_0_STATE_MASK(x, v) (HW_EPDC_PIGEON_6_0_WR(x, (HW_EPDC_PIGEON_6_0_RD(x) & ~BM_EPDC_PIGEON_6_0_STATE_MASK) | BF_EPDC_PIGEON_6_0_STATE_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_6_1 - Panel Interface Signal Generator Register 6_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_6_1 - Panel Interface Signal Generator Register 6_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_6_1
{
    uint32_t U;
    struct _hw_epdc_pigeon_6_1_bitfields
    {
        uint32_t SET_CNT : 16;         /*!< [15:0]  */
        uint32_t CLR_CNT : 16;         /*!< [31:16]  */
    } B;
} hw_epdc_pigeon_6_1_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_6_1 register
 */
/*@{*/
#define HW_EPDC_PIGEON_6_1_ADDR(x) ((uintptr_t)(x) + 0x990U)

#define HW_EPDC_PIGEON_6_1(x)    (*(__IO hw_epdc_pigeon_6_1_t *) HW_EPDC_PIGEON_6_1_ADDR(x))
#define HW_EPDC_PIGEON_6_1_RD(x) (HW_EPDC_PIGEON_6_1(x).U)
#define HW_EPDC_PIGEON_6_1_WR(x, v) (HW_EPDC_PIGEON_6_1(x).U = (v))
#define HW_EPDC_PIGEON_6_1_SET(x, v) (HW_EPDC_PIGEON_6_1_WR(x, HW_EPDC_PIGEON_6_1_RD(x) |  (v)))
#define HW_EPDC_PIGEON_6_1_CLR(x, v) (HW_EPDC_PIGEON_6_1_WR(x, HW_EPDC_PIGEON_6_1_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_6_1_TOG(x, v) (HW_EPDC_PIGEON_6_1_WR(x, HW_EPDC_PIGEON_6_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_6_1 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_6_1, field SET_CNT[15:0] (RW)
 *
 * assert signal output when counter match this value
 *
 * Values:
 * - 0 - start as active
 */
/*@{*/
#define BP_EPDC_PIGEON_6_1_SET_CNT (0U)    /*!< Bit position for EPDC_PIGEON_6_1_SET_CNT. */
#define BM_EPDC_PIGEON_6_1_SET_CNT (0x0000FFFFU) /*!< Bit mask for EPDC_PIGEON_6_1_SET_CNT. */
#define BS_EPDC_PIGEON_6_1_SET_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_6_1_SET_CNT. */

#define BV_EPDC_PIGEON_6_1_SET_CNT_START_ACTIVE (0U) /*!< Bit field value for EPDC_PIGEON_6_1_SET_CNT: start as active */

/*! @brief Read current value of the EPDC_PIGEON_6_1_SET_CNT field. */
#define BR_EPDC_PIGEON_6_1_SET_CNT(x) (HW_EPDC_PIGEON_6_1(x).B.SET_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_6_1_SET_CNT. */
#define BF_EPDC_PIGEON_6_1_SET_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_6_1_SET_CNT) & BM_EPDC_PIGEON_6_1_SET_CNT)

/*! @brief Set the SET_CNT field to a new value. */
#define BW_EPDC_PIGEON_6_1_SET_CNT(x, v) (HW_EPDC_PIGEON_6_1_WR(x, (HW_EPDC_PIGEON_6_1_RD(x) & ~BM_EPDC_PIGEON_6_1_SET_CNT) | BF_EPDC_PIGEON_6_1_SET_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_6_1, field CLR_CNT[31:16] (RW)
 *
 * deassert signal output when counter match this value
 *
 * Values:
 * - 0 - keep active until mask off
 */
/*@{*/
#define BP_EPDC_PIGEON_6_1_CLR_CNT (16U)   /*!< Bit position for EPDC_PIGEON_6_1_CLR_CNT. */
#define BM_EPDC_PIGEON_6_1_CLR_CNT (0xFFFF0000U) /*!< Bit mask for EPDC_PIGEON_6_1_CLR_CNT. */
#define BS_EPDC_PIGEON_6_1_CLR_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_6_1_CLR_CNT. */

#define BV_EPDC_PIGEON_6_1_CLR_CNT_CLEAR_USING_MASK (0U) /*!< Bit field value for EPDC_PIGEON_6_1_CLR_CNT: keep active until mask off */

/*! @brief Read current value of the EPDC_PIGEON_6_1_CLR_CNT field. */
#define BR_EPDC_PIGEON_6_1_CLR_CNT(x) (HW_EPDC_PIGEON_6_1(x).B.CLR_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_6_1_CLR_CNT. */
#define BF_EPDC_PIGEON_6_1_CLR_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_6_1_CLR_CNT) & BM_EPDC_PIGEON_6_1_CLR_CNT)

/*! @brief Set the CLR_CNT field to a new value. */
#define BW_EPDC_PIGEON_6_1_CLR_CNT(x, v) (HW_EPDC_PIGEON_6_1_WR(x, (HW_EPDC_PIGEON_6_1_RD(x) & ~BM_EPDC_PIGEON_6_1_CLR_CNT) | BF_EPDC_PIGEON_6_1_CLR_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_6_2 - Panel Interface Signal Generator Register 6_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_6_2 - Panel Interface Signal Generator Register 6_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_6_2
{
    uint32_t U;
    struct _hw_epdc_pigeon_6_2_bitfields
    {
        uint32_t SIG_LOGIC : 4;        /*!< [3:0]  */
        uint32_t SIG_ANOTHER : 5;      /*!< [8:4]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_epdc_pigeon_6_2_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_6_2 register
 */
/*@{*/
#define HW_EPDC_PIGEON_6_2_ADDR(x) ((uintptr_t)(x) + 0x9A0U)

#define HW_EPDC_PIGEON_6_2(x)    (*(__IO hw_epdc_pigeon_6_2_t *) HW_EPDC_PIGEON_6_2_ADDR(x))
#define HW_EPDC_PIGEON_6_2_RD(x) (HW_EPDC_PIGEON_6_2(x).U)
#define HW_EPDC_PIGEON_6_2_WR(x, v) (HW_EPDC_PIGEON_6_2(x).U = (v))
#define HW_EPDC_PIGEON_6_2_SET(x, v) (HW_EPDC_PIGEON_6_2_WR(x, HW_EPDC_PIGEON_6_2_RD(x) |  (v)))
#define HW_EPDC_PIGEON_6_2_CLR(x, v) (HW_EPDC_PIGEON_6_2_WR(x, HW_EPDC_PIGEON_6_2_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_6_2_TOG(x, v) (HW_EPDC_PIGEON_6_2_WR(x, HW_EPDC_PIGEON_6_2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_6_2 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_6_2, field SIG_LOGIC[3:0] (RW)
 *
 * logic operation with another signal sigout : final output signal of this
 * generator mask : final mask of this generator this_sig : intermediate signal of
 * this generator before logic operation other_masks : intermediate mask result of
 * this generator before logic operation sig_another : signal selected other
 * generators
 *
 * Values:
 * - 0 - no logic operation
 * - 1 - sigout = sig_another AND this_sig
 * - 10 - sigout = sig_another OR this_sig
 * - 11 - mask = sig_another AND other_masks
 */
/*@{*/
#define BP_EPDC_PIGEON_6_2_SIG_LOGIC (0U)  /*!< Bit position for EPDC_PIGEON_6_2_SIG_LOGIC. */
#define BM_EPDC_PIGEON_6_2_SIG_LOGIC (0x0000000FU) /*!< Bit mask for EPDC_PIGEON_6_2_SIG_LOGIC. */
#define BS_EPDC_PIGEON_6_2_SIG_LOGIC (4U)  /*!< Bit field size in bits for EPDC_PIGEON_6_2_SIG_LOGIC. */

#define BV_EPDC_PIGEON_6_2_SIG_LOGIC_DIS (0U)        /*!< Bit field value for EPDC_PIGEON_6_2_SIG_LOGIC: no logic operation */
#define BV_EPDC_PIGEON_6_2_SIG_LOGIC_AND (0x1U)      /*!< Bit field value for EPDC_PIGEON_6_2_SIG_LOGIC: sigout = sig_another AND this_sig */
#define BV_EPDC_PIGEON_6_2_SIG_LOGIC_OR (0x2U)       /*!< Bit field value for EPDC_PIGEON_6_2_SIG_LOGIC: sigout = sig_another OR this_sig */
#define BV_EPDC_PIGEON_6_2_SIG_LOGIC_MASK (0x3U)     /*!< Bit field value for EPDC_PIGEON_6_2_SIG_LOGIC: mask = sig_another AND other_masks */

/*! @brief Read current value of the EPDC_PIGEON_6_2_SIG_LOGIC field. */
#define BR_EPDC_PIGEON_6_2_SIG_LOGIC(x) (HW_EPDC_PIGEON_6_2(x).B.SIG_LOGIC)

/*! @brief Format value for bitfield EPDC_PIGEON_6_2_SIG_LOGIC. */
#define BF_EPDC_PIGEON_6_2_SIG_LOGIC(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_6_2_SIG_LOGIC) & BM_EPDC_PIGEON_6_2_SIG_LOGIC)

/*! @brief Set the SIG_LOGIC field to a new value. */
#define BW_EPDC_PIGEON_6_2_SIG_LOGIC(x, v) (HW_EPDC_PIGEON_6_2_WR(x, (HW_EPDC_PIGEON_6_2_RD(x) & ~BM_EPDC_PIGEON_6_2_SIG_LOGIC) | BF_EPDC_PIGEON_6_2_SIG_LOGIC(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_6_2, field SIG_ANOTHER[8:4] (RW)
 *
 * select another signal for logic operation or as mask or counter tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_6_2_SIG_ANOTHER (4U) /*!< Bit position for EPDC_PIGEON_6_2_SIG_ANOTHER. */
#define BM_EPDC_PIGEON_6_2_SIG_ANOTHER (0x000001F0U) /*!< Bit mask for EPDC_PIGEON_6_2_SIG_ANOTHER. */
#define BS_EPDC_PIGEON_6_2_SIG_ANOTHER (5U) /*!< Bit field size in bits for EPDC_PIGEON_6_2_SIG_ANOTHER. */

/*! @brief Read current value of the EPDC_PIGEON_6_2_SIG_ANOTHER field. */
#define BR_EPDC_PIGEON_6_2_SIG_ANOTHER(x) (HW_EPDC_PIGEON_6_2(x).B.SIG_ANOTHER)

/*! @brief Format value for bitfield EPDC_PIGEON_6_2_SIG_ANOTHER. */
#define BF_EPDC_PIGEON_6_2_SIG_ANOTHER(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_6_2_SIG_ANOTHER) & BM_EPDC_PIGEON_6_2_SIG_ANOTHER)

/*! @brief Set the SIG_ANOTHER field to a new value. */
#define BW_EPDC_PIGEON_6_2_SIG_ANOTHER(x, v) (HW_EPDC_PIGEON_6_2_WR(x, (HW_EPDC_PIGEON_6_2_RD(x) & ~BM_EPDC_PIGEON_6_2_SIG_ANOTHER) | BF_EPDC_PIGEON_6_2_SIG_ANOTHER(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_7_0 - Panel Interface Signal Generator Register 7_0
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_7_0 - Panel Interface Signal Generator Register 7_0 (RW)
 *
 * Reset value: 0x00000F00U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_7_0
{
    uint32_t U;
    struct _hw_epdc_pigeon_7_0_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t POL : 1;              /*!< [1]  */
        uint32_t INC_SEL : 2;          /*!< [3:2]  */
        uint32_t OFFSET : 4;           /*!< [7:4]  */
        uint32_t MASK_CNT_SEL : 4;     /*!< [11:8]  */
        uint32_t MASK_CNT : 12;        /*!< [23:12]  */
        uint32_t STATE_MASK : 8;       /*!< [31:24]  */
    } B;
} hw_epdc_pigeon_7_0_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_7_0 register
 */
/*@{*/
#define HW_EPDC_PIGEON_7_0_ADDR(x) ((uintptr_t)(x) + 0x9C0U)

#define HW_EPDC_PIGEON_7_0(x)    (*(__IO hw_epdc_pigeon_7_0_t *) HW_EPDC_PIGEON_7_0_ADDR(x))
#define HW_EPDC_PIGEON_7_0_RD(x) (HW_EPDC_PIGEON_7_0(x).U)
#define HW_EPDC_PIGEON_7_0_WR(x, v) (HW_EPDC_PIGEON_7_0(x).U = (v))
#define HW_EPDC_PIGEON_7_0_SET(x, v) (HW_EPDC_PIGEON_7_0_WR(x, HW_EPDC_PIGEON_7_0_RD(x) |  (v)))
#define HW_EPDC_PIGEON_7_0_CLR(x, v) (HW_EPDC_PIGEON_7_0_WR(x, HW_EPDC_PIGEON_7_0_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_7_0_TOG(x, v) (HW_EPDC_PIGEON_7_0_WR(x, HW_EPDC_PIGEON_7_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_7_0 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_7_0, field EN[0] (RW)
 *
 * enable pigeon mode on this signal
 */
/*@{*/
#define BP_EPDC_PIGEON_7_0_EN (0U)         /*!< Bit position for EPDC_PIGEON_7_0_EN. */
#define BM_EPDC_PIGEON_7_0_EN (0x00000001U) /*!< Bit mask for EPDC_PIGEON_7_0_EN. */
#define BS_EPDC_PIGEON_7_0_EN (1U)         /*!< Bit field size in bits for EPDC_PIGEON_7_0_EN. */

/*! @brief Read current value of the EPDC_PIGEON_7_0_EN field. */
#define BR_EPDC_PIGEON_7_0_EN(x) (HW_EPDC_PIGEON_7_0(x).B.EN)

/*! @brief Format value for bitfield EPDC_PIGEON_7_0_EN. */
#define BF_EPDC_PIGEON_7_0_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_7_0_EN) & BM_EPDC_PIGEON_7_0_EN)

/*! @brief Set the EN field to a new value. */
#define BW_EPDC_PIGEON_7_0_EN(x, v) (HW_EPDC_PIGEON_7_0_WR(x, (HW_EPDC_PIGEON_7_0_RD(x) & ~BM_EPDC_PIGEON_7_0_EN) | BF_EPDC_PIGEON_7_0_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_7_0, field POL[1] (RW)
 *
 * polarity of signal output
 *
 * Values:
 * - 0 - normal signal (active high)
 * - 1 - inverted signal (active low)
 */
/*@{*/
#define BP_EPDC_PIGEON_7_0_POL (1U)        /*!< Bit position for EPDC_PIGEON_7_0_POL. */
#define BM_EPDC_PIGEON_7_0_POL (0x00000002U) /*!< Bit mask for EPDC_PIGEON_7_0_POL. */
#define BS_EPDC_PIGEON_7_0_POL (1U)        /*!< Bit field size in bits for EPDC_PIGEON_7_0_POL. */

#define BV_EPDC_PIGEON_7_0_POL_ACTIVE_HIGH (0U)      /*!< Bit field value for EPDC_PIGEON_7_0_POL: normal signal (active high) */
#define BV_EPDC_PIGEON_7_0_POL_ACTIVE_LOW (0x1U)     /*!< Bit field value for EPDC_PIGEON_7_0_POL: inverted signal (active low) */

/*! @brief Read current value of the EPDC_PIGEON_7_0_POL field. */
#define BR_EPDC_PIGEON_7_0_POL(x) (HW_EPDC_PIGEON_7_0(x).B.POL)

/*! @brief Format value for bitfield EPDC_PIGEON_7_0_POL. */
#define BF_EPDC_PIGEON_7_0_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_7_0_POL) & BM_EPDC_PIGEON_7_0_POL)

/*! @brief Set the POL field to a new value. */
#define BW_EPDC_PIGEON_7_0_POL(x, v) (HW_EPDC_PIGEON_7_0_WR(x, (HW_EPDC_PIGEON_7_0_RD(x) & ~BM_EPDC_PIGEON_7_0_POL) | BF_EPDC_PIGEON_7_0_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_7_0, field INC_SEL[3:2] (RW)
 *
 * event to incrment local counter
 *
 * Values:
 * - 0 - pclk
 * - 1 - line start pulse
 * - 10 - frame start pulse
 * - 11 - use another signal as tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_7_0_INC_SEL (2U)    /*!< Bit position for EPDC_PIGEON_7_0_INC_SEL. */
#define BM_EPDC_PIGEON_7_0_INC_SEL (0x0000000CU) /*!< Bit mask for EPDC_PIGEON_7_0_INC_SEL. */
#define BS_EPDC_PIGEON_7_0_INC_SEL (2U)    /*!< Bit field size in bits for EPDC_PIGEON_7_0_INC_SEL. */

#define BV_EPDC_PIGEON_7_0_INC_SEL_PCLK (0U)         /*!< Bit field value for EPDC_PIGEON_7_0_INC_SEL: pclk */
#define BV_EPDC_PIGEON_7_0_INC_SEL_LINE (0x1U)       /*!< Bit field value for EPDC_PIGEON_7_0_INC_SEL: line start pulse */
#define BV_EPDC_PIGEON_7_0_INC_SEL_FRAME (0x2U)      /*!< Bit field value for EPDC_PIGEON_7_0_INC_SEL: frame start pulse */
#define BV_EPDC_PIGEON_7_0_INC_SEL_SIG_ANOTHER (0x3U) /*!< Bit field value for EPDC_PIGEON_7_0_INC_SEL: use another signal as tick event */

/*! @brief Read current value of the EPDC_PIGEON_7_0_INC_SEL field. */
#define BR_EPDC_PIGEON_7_0_INC_SEL(x) (HW_EPDC_PIGEON_7_0(x).B.INC_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_7_0_INC_SEL. */
#define BF_EPDC_PIGEON_7_0_INC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_7_0_INC_SEL) & BM_EPDC_PIGEON_7_0_INC_SEL)

/*! @brief Set the INC_SEL field to a new value. */
#define BW_EPDC_PIGEON_7_0_INC_SEL(x, v) (HW_EPDC_PIGEON_7_0_WR(x, (HW_EPDC_PIGEON_7_0_RD(x) & ~BM_EPDC_PIGEON_7_0_INC_SEL) | BF_EPDC_PIGEON_7_0_INC_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_7_0, field OFFSET[7:4] (RW)
 *
 * offset on pclk unit. 0=aligne with data, positive value means delay, minus
 * value mean ahead. Supported range depends on panel mode
 */
/*@{*/
#define BP_EPDC_PIGEON_7_0_OFFSET (4U)     /*!< Bit position for EPDC_PIGEON_7_0_OFFSET. */
#define BM_EPDC_PIGEON_7_0_OFFSET (0x000000F0U) /*!< Bit mask for EPDC_PIGEON_7_0_OFFSET. */
#define BS_EPDC_PIGEON_7_0_OFFSET (4U)     /*!< Bit field size in bits for EPDC_PIGEON_7_0_OFFSET. */

/*! @brief Read current value of the EPDC_PIGEON_7_0_OFFSET field. */
#define BR_EPDC_PIGEON_7_0_OFFSET(x) (HW_EPDC_PIGEON_7_0(x).B.OFFSET)

/*! @brief Format value for bitfield EPDC_PIGEON_7_0_OFFSET. */
#define BF_EPDC_PIGEON_7_0_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_7_0_OFFSET) & BM_EPDC_PIGEON_7_0_OFFSET)

/*! @brief Set the OFFSET field to a new value. */
#define BW_EPDC_PIGEON_7_0_OFFSET(x, v) (HW_EPDC_PIGEON_7_0_WR(x, (HW_EPDC_PIGEON_7_0_RD(x) & ~BM_EPDC_PIGEON_7_0_OFFSET) | BF_EPDC_PIGEON_7_0_OFFSET(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_7_0, field MASK_CNT_SEL[11:8] (RW)
 *
 * select global counters as mask condition, use together with MASK_CNT
 *
 * Values:
 * - 0 - pclk counter within one hscan state
 * - 1 - pclk cycle within one hscan state
 * - 10 - line counter within one vscan state
 * - 11 - line cycle within one vscan state
 * - 100 - frame counter
 * - 101 - frame cycle
 * - 110 - horizontal counter (pclk counter within one line )
 * - 111 - vertical counter (line counter within one frame)
 */
/*@{*/
#define BP_EPDC_PIGEON_7_0_MASK_CNT_SEL (8U) /*!< Bit position for EPDC_PIGEON_7_0_MASK_CNT_SEL. */
#define BM_EPDC_PIGEON_7_0_MASK_CNT_SEL (0x00000F00U) /*!< Bit mask for EPDC_PIGEON_7_0_MASK_CNT_SEL. */
#define BS_EPDC_PIGEON_7_0_MASK_CNT_SEL (4U) /*!< Bit field size in bits for EPDC_PIGEON_7_0_MASK_CNT_SEL. */

#define BV_EPDC_PIGEON_7_0_MASK_CNT_SEL_HSTATE_CNT (0U) /*!< Bit field value for EPDC_PIGEON_7_0_MASK_CNT_SEL: pclk counter within one hscan state */
#define BV_EPDC_PIGEON_7_0_MASK_CNT_SEL_HSTATE_CYCLE (0x1U) /*!< Bit field value for EPDC_PIGEON_7_0_MASK_CNT_SEL: pclk cycle within one hscan state */
#define BV_EPDC_PIGEON_7_0_MASK_CNT_SEL_VSTATE_CNT (0x2U) /*!< Bit field value for EPDC_PIGEON_7_0_MASK_CNT_SEL: line counter within one vscan state */
#define BV_EPDC_PIGEON_7_0_MASK_CNT_SEL_VSTATE_CYCLE (0x3U) /*!< Bit field value for EPDC_PIGEON_7_0_MASK_CNT_SEL: line cycle within one vscan state */
#define BV_EPDC_PIGEON_7_0_MASK_CNT_SEL_FRAME_CNT (0x4U) /*!< Bit field value for EPDC_PIGEON_7_0_MASK_CNT_SEL: frame counter */
#define BV_EPDC_PIGEON_7_0_MASK_CNT_SEL_FRAME_CYCLE (0x5U) /*!< Bit field value for EPDC_PIGEON_7_0_MASK_CNT_SEL: frame cycle */
#define BV_EPDC_PIGEON_7_0_MASK_CNT_SEL_HCNT (0x6U)  /*!< Bit field value for EPDC_PIGEON_7_0_MASK_CNT_SEL: horizontal counter (pclk counter within one line ) */
#define BV_EPDC_PIGEON_7_0_MASK_CNT_SEL_VCNT (0x7U)  /*!< Bit field value for EPDC_PIGEON_7_0_MASK_CNT_SEL: vertical counter (line counter within one frame) */

/*! @brief Read current value of the EPDC_PIGEON_7_0_MASK_CNT_SEL field. */
#define BR_EPDC_PIGEON_7_0_MASK_CNT_SEL(x) (HW_EPDC_PIGEON_7_0(x).B.MASK_CNT_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_7_0_MASK_CNT_SEL. */
#define BF_EPDC_PIGEON_7_0_MASK_CNT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_7_0_MASK_CNT_SEL) & BM_EPDC_PIGEON_7_0_MASK_CNT_SEL)

/*! @brief Set the MASK_CNT_SEL field to a new value. */
#define BW_EPDC_PIGEON_7_0_MASK_CNT_SEL(x, v) (HW_EPDC_PIGEON_7_0_WR(x, (HW_EPDC_PIGEON_7_0_RD(x) & ~BM_EPDC_PIGEON_7_0_MASK_CNT_SEL) | BF_EPDC_PIGEON_7_0_MASK_CNT_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_7_0, field MASK_CNT[23:12] (RW)
 *
 * When the global counter selected through MASK_CNT_SEL matches value in this
 * reg, pigeon local counter start ticking. 0=disable
 */
/*@{*/
#define BP_EPDC_PIGEON_7_0_MASK_CNT (12U)  /*!< Bit position for EPDC_PIGEON_7_0_MASK_CNT. */
#define BM_EPDC_PIGEON_7_0_MASK_CNT (0x00FFF000U) /*!< Bit mask for EPDC_PIGEON_7_0_MASK_CNT. */
#define BS_EPDC_PIGEON_7_0_MASK_CNT (12U)  /*!< Bit field size in bits for EPDC_PIGEON_7_0_MASK_CNT. */

/*! @brief Read current value of the EPDC_PIGEON_7_0_MASK_CNT field. */
#define BR_EPDC_PIGEON_7_0_MASK_CNT(x) (HW_EPDC_PIGEON_7_0(x).B.MASK_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_7_0_MASK_CNT. */
#define BF_EPDC_PIGEON_7_0_MASK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_7_0_MASK_CNT) & BM_EPDC_PIGEON_7_0_MASK_CNT)

/*! @brief Set the MASK_CNT field to a new value. */
#define BW_EPDC_PIGEON_7_0_MASK_CNT(x, v) (HW_EPDC_PIGEON_7_0_WR(x, (HW_EPDC_PIGEON_7_0_RD(x) & ~BM_EPDC_PIGEON_7_0_MASK_CNT) | BF_EPDC_PIGEON_7_0_MASK_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_7_0, field STATE_MASK[31:24] (RW)
 *
 * state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan
 * states as reference point for local counter to start ticking
 *
 * Values:
 * - 1 - FRAME SYNC
 * - 10 - FRAME BEGIN
 * - 100 - FRAME DATA
 * - 1000 - FRAME END
 * - 10000 - LINE SYNC
 * - 100000 - LINE BEGIN
 * - 1000000 - LINE DATA
 * - 10000000 - LINE END
 */
/*@{*/
#define BP_EPDC_PIGEON_7_0_STATE_MASK (24U) /*!< Bit position for EPDC_PIGEON_7_0_STATE_MASK. */
#define BM_EPDC_PIGEON_7_0_STATE_MASK (0xFF000000U) /*!< Bit mask for EPDC_PIGEON_7_0_STATE_MASK. */
#define BS_EPDC_PIGEON_7_0_STATE_MASK (8U) /*!< Bit field size in bits for EPDC_PIGEON_7_0_STATE_MASK. */

#define BV_EPDC_PIGEON_7_0_STATE_MASK_FS (0x1U)      /*!< Bit field value for EPDC_PIGEON_7_0_STATE_MASK: FRAME SYNC */
#define BV_EPDC_PIGEON_7_0_STATE_MASK_FB (0x2U)      /*!< Bit field value for EPDC_PIGEON_7_0_STATE_MASK: FRAME BEGIN */
#define BV_EPDC_PIGEON_7_0_STATE_MASK_FD (0x4U)      /*!< Bit field value for EPDC_PIGEON_7_0_STATE_MASK: FRAME DATA */
#define BV_EPDC_PIGEON_7_0_STATE_MASK_FE (0x8U)      /*!< Bit field value for EPDC_PIGEON_7_0_STATE_MASK: FRAME END */
#define BV_EPDC_PIGEON_7_0_STATE_MASK_LS (0x10U)     /*!< Bit field value for EPDC_PIGEON_7_0_STATE_MASK: LINE SYNC */
#define BV_EPDC_PIGEON_7_0_STATE_MASK_LB (0x20U)     /*!< Bit field value for EPDC_PIGEON_7_0_STATE_MASK: LINE BEGIN */
#define BV_EPDC_PIGEON_7_0_STATE_MASK_LD (0x40U)     /*!< Bit field value for EPDC_PIGEON_7_0_STATE_MASK: LINE DATA */
#define BV_EPDC_PIGEON_7_0_STATE_MASK_LE (0x80U)     /*!< Bit field value for EPDC_PIGEON_7_0_STATE_MASK: LINE END */

/*! @brief Read current value of the EPDC_PIGEON_7_0_STATE_MASK field. */
#define BR_EPDC_PIGEON_7_0_STATE_MASK(x) (HW_EPDC_PIGEON_7_0(x).B.STATE_MASK)

/*! @brief Format value for bitfield EPDC_PIGEON_7_0_STATE_MASK. */
#define BF_EPDC_PIGEON_7_0_STATE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_7_0_STATE_MASK) & BM_EPDC_PIGEON_7_0_STATE_MASK)

/*! @brief Set the STATE_MASK field to a new value. */
#define BW_EPDC_PIGEON_7_0_STATE_MASK(x, v) (HW_EPDC_PIGEON_7_0_WR(x, (HW_EPDC_PIGEON_7_0_RD(x) & ~BM_EPDC_PIGEON_7_0_STATE_MASK) | BF_EPDC_PIGEON_7_0_STATE_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_7_1 - Panel Interface Signal Generator Register 7_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_7_1 - Panel Interface Signal Generator Register 7_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_7_1
{
    uint32_t U;
    struct _hw_epdc_pigeon_7_1_bitfields
    {
        uint32_t SET_CNT : 16;         /*!< [15:0]  */
        uint32_t CLR_CNT : 16;         /*!< [31:16]  */
    } B;
} hw_epdc_pigeon_7_1_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_7_1 register
 */
/*@{*/
#define HW_EPDC_PIGEON_7_1_ADDR(x) ((uintptr_t)(x) + 0x9D0U)

#define HW_EPDC_PIGEON_7_1(x)    (*(__IO hw_epdc_pigeon_7_1_t *) HW_EPDC_PIGEON_7_1_ADDR(x))
#define HW_EPDC_PIGEON_7_1_RD(x) (HW_EPDC_PIGEON_7_1(x).U)
#define HW_EPDC_PIGEON_7_1_WR(x, v) (HW_EPDC_PIGEON_7_1(x).U = (v))
#define HW_EPDC_PIGEON_7_1_SET(x, v) (HW_EPDC_PIGEON_7_1_WR(x, HW_EPDC_PIGEON_7_1_RD(x) |  (v)))
#define HW_EPDC_PIGEON_7_1_CLR(x, v) (HW_EPDC_PIGEON_7_1_WR(x, HW_EPDC_PIGEON_7_1_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_7_1_TOG(x, v) (HW_EPDC_PIGEON_7_1_WR(x, HW_EPDC_PIGEON_7_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_7_1 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_7_1, field SET_CNT[15:0] (RW)
 *
 * assert signal output when counter match this value
 *
 * Values:
 * - 0 - start as active
 */
/*@{*/
#define BP_EPDC_PIGEON_7_1_SET_CNT (0U)    /*!< Bit position for EPDC_PIGEON_7_1_SET_CNT. */
#define BM_EPDC_PIGEON_7_1_SET_CNT (0x0000FFFFU) /*!< Bit mask for EPDC_PIGEON_7_1_SET_CNT. */
#define BS_EPDC_PIGEON_7_1_SET_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_7_1_SET_CNT. */

#define BV_EPDC_PIGEON_7_1_SET_CNT_START_ACTIVE (0U) /*!< Bit field value for EPDC_PIGEON_7_1_SET_CNT: start as active */

/*! @brief Read current value of the EPDC_PIGEON_7_1_SET_CNT field. */
#define BR_EPDC_PIGEON_7_1_SET_CNT(x) (HW_EPDC_PIGEON_7_1(x).B.SET_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_7_1_SET_CNT. */
#define BF_EPDC_PIGEON_7_1_SET_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_7_1_SET_CNT) & BM_EPDC_PIGEON_7_1_SET_CNT)

/*! @brief Set the SET_CNT field to a new value. */
#define BW_EPDC_PIGEON_7_1_SET_CNT(x, v) (HW_EPDC_PIGEON_7_1_WR(x, (HW_EPDC_PIGEON_7_1_RD(x) & ~BM_EPDC_PIGEON_7_1_SET_CNT) | BF_EPDC_PIGEON_7_1_SET_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_7_1, field CLR_CNT[31:16] (RW)
 *
 * deassert signal output when counter match this value
 *
 * Values:
 * - 0 - keep active until mask off
 */
/*@{*/
#define BP_EPDC_PIGEON_7_1_CLR_CNT (16U)   /*!< Bit position for EPDC_PIGEON_7_1_CLR_CNT. */
#define BM_EPDC_PIGEON_7_1_CLR_CNT (0xFFFF0000U) /*!< Bit mask for EPDC_PIGEON_7_1_CLR_CNT. */
#define BS_EPDC_PIGEON_7_1_CLR_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_7_1_CLR_CNT. */

#define BV_EPDC_PIGEON_7_1_CLR_CNT_CLEAR_USING_MASK (0U) /*!< Bit field value for EPDC_PIGEON_7_1_CLR_CNT: keep active until mask off */

/*! @brief Read current value of the EPDC_PIGEON_7_1_CLR_CNT field. */
#define BR_EPDC_PIGEON_7_1_CLR_CNT(x) (HW_EPDC_PIGEON_7_1(x).B.CLR_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_7_1_CLR_CNT. */
#define BF_EPDC_PIGEON_7_1_CLR_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_7_1_CLR_CNT) & BM_EPDC_PIGEON_7_1_CLR_CNT)

/*! @brief Set the CLR_CNT field to a new value. */
#define BW_EPDC_PIGEON_7_1_CLR_CNT(x, v) (HW_EPDC_PIGEON_7_1_WR(x, (HW_EPDC_PIGEON_7_1_RD(x) & ~BM_EPDC_PIGEON_7_1_CLR_CNT) | BF_EPDC_PIGEON_7_1_CLR_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_7_2 - Panel Interface Signal Generator Register 7_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_7_2 - Panel Interface Signal Generator Register 7_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_7_2
{
    uint32_t U;
    struct _hw_epdc_pigeon_7_2_bitfields
    {
        uint32_t SIG_LOGIC : 4;        /*!< [3:0]  */
        uint32_t SIG_ANOTHER : 5;      /*!< [8:4]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_epdc_pigeon_7_2_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_7_2 register
 */
/*@{*/
#define HW_EPDC_PIGEON_7_2_ADDR(x) ((uintptr_t)(x) + 0x9E0U)

#define HW_EPDC_PIGEON_7_2(x)    (*(__IO hw_epdc_pigeon_7_2_t *) HW_EPDC_PIGEON_7_2_ADDR(x))
#define HW_EPDC_PIGEON_7_2_RD(x) (HW_EPDC_PIGEON_7_2(x).U)
#define HW_EPDC_PIGEON_7_2_WR(x, v) (HW_EPDC_PIGEON_7_2(x).U = (v))
#define HW_EPDC_PIGEON_7_2_SET(x, v) (HW_EPDC_PIGEON_7_2_WR(x, HW_EPDC_PIGEON_7_2_RD(x) |  (v)))
#define HW_EPDC_PIGEON_7_2_CLR(x, v) (HW_EPDC_PIGEON_7_2_WR(x, HW_EPDC_PIGEON_7_2_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_7_2_TOG(x, v) (HW_EPDC_PIGEON_7_2_WR(x, HW_EPDC_PIGEON_7_2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_7_2 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_7_2, field SIG_LOGIC[3:0] (RW)
 *
 * logic operation with another signal sigout : final output signal of this
 * generator mask : final mask of this generator this_sig : intermediate signal of
 * this generator before logic operation other_masks : intermediate mask result of
 * this generator before logic operation sig_another : signal selected other
 * generators
 *
 * Values:
 * - 0 - no logic operation
 * - 1 - sigout = sig_another AND this_sig
 * - 10 - sigout = sig_another OR this_sig
 * - 11 - mask = sig_another AND other_masks
 */
/*@{*/
#define BP_EPDC_PIGEON_7_2_SIG_LOGIC (0U)  /*!< Bit position for EPDC_PIGEON_7_2_SIG_LOGIC. */
#define BM_EPDC_PIGEON_7_2_SIG_LOGIC (0x0000000FU) /*!< Bit mask for EPDC_PIGEON_7_2_SIG_LOGIC. */
#define BS_EPDC_PIGEON_7_2_SIG_LOGIC (4U)  /*!< Bit field size in bits for EPDC_PIGEON_7_2_SIG_LOGIC. */

#define BV_EPDC_PIGEON_7_2_SIG_LOGIC_DIS (0U)        /*!< Bit field value for EPDC_PIGEON_7_2_SIG_LOGIC: no logic operation */
#define BV_EPDC_PIGEON_7_2_SIG_LOGIC_AND (0x1U)      /*!< Bit field value for EPDC_PIGEON_7_2_SIG_LOGIC: sigout = sig_another AND this_sig */
#define BV_EPDC_PIGEON_7_2_SIG_LOGIC_OR (0x2U)       /*!< Bit field value for EPDC_PIGEON_7_2_SIG_LOGIC: sigout = sig_another OR this_sig */
#define BV_EPDC_PIGEON_7_2_SIG_LOGIC_MASK (0x3U)     /*!< Bit field value for EPDC_PIGEON_7_2_SIG_LOGIC: mask = sig_another AND other_masks */

/*! @brief Read current value of the EPDC_PIGEON_7_2_SIG_LOGIC field. */
#define BR_EPDC_PIGEON_7_2_SIG_LOGIC(x) (HW_EPDC_PIGEON_7_2(x).B.SIG_LOGIC)

/*! @brief Format value for bitfield EPDC_PIGEON_7_2_SIG_LOGIC. */
#define BF_EPDC_PIGEON_7_2_SIG_LOGIC(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_7_2_SIG_LOGIC) & BM_EPDC_PIGEON_7_2_SIG_LOGIC)

/*! @brief Set the SIG_LOGIC field to a new value. */
#define BW_EPDC_PIGEON_7_2_SIG_LOGIC(x, v) (HW_EPDC_PIGEON_7_2_WR(x, (HW_EPDC_PIGEON_7_2_RD(x) & ~BM_EPDC_PIGEON_7_2_SIG_LOGIC) | BF_EPDC_PIGEON_7_2_SIG_LOGIC(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_7_2, field SIG_ANOTHER[8:4] (RW)
 *
 * select another signal for logic operation or as mask or counter tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_7_2_SIG_ANOTHER (4U) /*!< Bit position for EPDC_PIGEON_7_2_SIG_ANOTHER. */
#define BM_EPDC_PIGEON_7_2_SIG_ANOTHER (0x000001F0U) /*!< Bit mask for EPDC_PIGEON_7_2_SIG_ANOTHER. */
#define BS_EPDC_PIGEON_7_2_SIG_ANOTHER (5U) /*!< Bit field size in bits for EPDC_PIGEON_7_2_SIG_ANOTHER. */

/*! @brief Read current value of the EPDC_PIGEON_7_2_SIG_ANOTHER field. */
#define BR_EPDC_PIGEON_7_2_SIG_ANOTHER(x) (HW_EPDC_PIGEON_7_2(x).B.SIG_ANOTHER)

/*! @brief Format value for bitfield EPDC_PIGEON_7_2_SIG_ANOTHER. */
#define BF_EPDC_PIGEON_7_2_SIG_ANOTHER(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_7_2_SIG_ANOTHER) & BM_EPDC_PIGEON_7_2_SIG_ANOTHER)

/*! @brief Set the SIG_ANOTHER field to a new value. */
#define BW_EPDC_PIGEON_7_2_SIG_ANOTHER(x, v) (HW_EPDC_PIGEON_7_2_WR(x, (HW_EPDC_PIGEON_7_2_RD(x) & ~BM_EPDC_PIGEON_7_2_SIG_ANOTHER) | BF_EPDC_PIGEON_7_2_SIG_ANOTHER(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_8_0 - Panel Interface Signal Generator Register 8_0
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_8_0 - Panel Interface Signal Generator Register 8_0 (RW)
 *
 * Reset value: 0x00000F00U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_8_0
{
    uint32_t U;
    struct _hw_epdc_pigeon_8_0_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t POL : 1;              /*!< [1]  */
        uint32_t INC_SEL : 2;          /*!< [3:2]  */
        uint32_t OFFSET : 4;           /*!< [7:4]  */
        uint32_t MASK_CNT_SEL : 4;     /*!< [11:8]  */
        uint32_t MASK_CNT : 12;        /*!< [23:12]  */
        uint32_t STATE_MASK : 8;       /*!< [31:24]  */
    } B;
} hw_epdc_pigeon_8_0_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_8_0 register
 */
/*@{*/
#define HW_EPDC_PIGEON_8_0_ADDR(x) ((uintptr_t)(x) + 0xA00U)

#define HW_EPDC_PIGEON_8_0(x)    (*(__IO hw_epdc_pigeon_8_0_t *) HW_EPDC_PIGEON_8_0_ADDR(x))
#define HW_EPDC_PIGEON_8_0_RD(x) (HW_EPDC_PIGEON_8_0(x).U)
#define HW_EPDC_PIGEON_8_0_WR(x, v) (HW_EPDC_PIGEON_8_0(x).U = (v))
#define HW_EPDC_PIGEON_8_0_SET(x, v) (HW_EPDC_PIGEON_8_0_WR(x, HW_EPDC_PIGEON_8_0_RD(x) |  (v)))
#define HW_EPDC_PIGEON_8_0_CLR(x, v) (HW_EPDC_PIGEON_8_0_WR(x, HW_EPDC_PIGEON_8_0_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_8_0_TOG(x, v) (HW_EPDC_PIGEON_8_0_WR(x, HW_EPDC_PIGEON_8_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_8_0 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_8_0, field EN[0] (RW)
 *
 * enable pigeon mode on this signal
 */
/*@{*/
#define BP_EPDC_PIGEON_8_0_EN (0U)         /*!< Bit position for EPDC_PIGEON_8_0_EN. */
#define BM_EPDC_PIGEON_8_0_EN (0x00000001U) /*!< Bit mask for EPDC_PIGEON_8_0_EN. */
#define BS_EPDC_PIGEON_8_0_EN (1U)         /*!< Bit field size in bits for EPDC_PIGEON_8_0_EN. */

/*! @brief Read current value of the EPDC_PIGEON_8_0_EN field. */
#define BR_EPDC_PIGEON_8_0_EN(x) (HW_EPDC_PIGEON_8_0(x).B.EN)

/*! @brief Format value for bitfield EPDC_PIGEON_8_0_EN. */
#define BF_EPDC_PIGEON_8_0_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_8_0_EN) & BM_EPDC_PIGEON_8_0_EN)

/*! @brief Set the EN field to a new value. */
#define BW_EPDC_PIGEON_8_0_EN(x, v) (HW_EPDC_PIGEON_8_0_WR(x, (HW_EPDC_PIGEON_8_0_RD(x) & ~BM_EPDC_PIGEON_8_0_EN) | BF_EPDC_PIGEON_8_0_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_8_0, field POL[1] (RW)
 *
 * polarity of signal output
 *
 * Values:
 * - 0 - normal signal (active high)
 * - 1 - inverted signal (active low)
 */
/*@{*/
#define BP_EPDC_PIGEON_8_0_POL (1U)        /*!< Bit position for EPDC_PIGEON_8_0_POL. */
#define BM_EPDC_PIGEON_8_0_POL (0x00000002U) /*!< Bit mask for EPDC_PIGEON_8_0_POL. */
#define BS_EPDC_PIGEON_8_0_POL (1U)        /*!< Bit field size in bits for EPDC_PIGEON_8_0_POL. */

#define BV_EPDC_PIGEON_8_0_POL_ACTIVE_HIGH (0U)      /*!< Bit field value for EPDC_PIGEON_8_0_POL: normal signal (active high) */
#define BV_EPDC_PIGEON_8_0_POL_ACTIVE_LOW (0x1U)     /*!< Bit field value for EPDC_PIGEON_8_0_POL: inverted signal (active low) */

/*! @brief Read current value of the EPDC_PIGEON_8_0_POL field. */
#define BR_EPDC_PIGEON_8_0_POL(x) (HW_EPDC_PIGEON_8_0(x).B.POL)

/*! @brief Format value for bitfield EPDC_PIGEON_8_0_POL. */
#define BF_EPDC_PIGEON_8_0_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_8_0_POL) & BM_EPDC_PIGEON_8_0_POL)

/*! @brief Set the POL field to a new value. */
#define BW_EPDC_PIGEON_8_0_POL(x, v) (HW_EPDC_PIGEON_8_0_WR(x, (HW_EPDC_PIGEON_8_0_RD(x) & ~BM_EPDC_PIGEON_8_0_POL) | BF_EPDC_PIGEON_8_0_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_8_0, field INC_SEL[3:2] (RW)
 *
 * event to incrment local counter
 *
 * Values:
 * - 0 - pclk
 * - 1 - line start pulse
 * - 10 - frame start pulse
 * - 11 - use another signal as tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_8_0_INC_SEL (2U)    /*!< Bit position for EPDC_PIGEON_8_0_INC_SEL. */
#define BM_EPDC_PIGEON_8_0_INC_SEL (0x0000000CU) /*!< Bit mask for EPDC_PIGEON_8_0_INC_SEL. */
#define BS_EPDC_PIGEON_8_0_INC_SEL (2U)    /*!< Bit field size in bits for EPDC_PIGEON_8_0_INC_SEL. */

#define BV_EPDC_PIGEON_8_0_INC_SEL_PCLK (0U)         /*!< Bit field value for EPDC_PIGEON_8_0_INC_SEL: pclk */
#define BV_EPDC_PIGEON_8_0_INC_SEL_LINE (0x1U)       /*!< Bit field value for EPDC_PIGEON_8_0_INC_SEL: line start pulse */
#define BV_EPDC_PIGEON_8_0_INC_SEL_FRAME (0x2U)      /*!< Bit field value for EPDC_PIGEON_8_0_INC_SEL: frame start pulse */
#define BV_EPDC_PIGEON_8_0_INC_SEL_SIG_ANOTHER (0x3U) /*!< Bit field value for EPDC_PIGEON_8_0_INC_SEL: use another signal as tick event */

/*! @brief Read current value of the EPDC_PIGEON_8_0_INC_SEL field. */
#define BR_EPDC_PIGEON_8_0_INC_SEL(x) (HW_EPDC_PIGEON_8_0(x).B.INC_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_8_0_INC_SEL. */
#define BF_EPDC_PIGEON_8_0_INC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_8_0_INC_SEL) & BM_EPDC_PIGEON_8_0_INC_SEL)

/*! @brief Set the INC_SEL field to a new value. */
#define BW_EPDC_PIGEON_8_0_INC_SEL(x, v) (HW_EPDC_PIGEON_8_0_WR(x, (HW_EPDC_PIGEON_8_0_RD(x) & ~BM_EPDC_PIGEON_8_0_INC_SEL) | BF_EPDC_PIGEON_8_0_INC_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_8_0, field OFFSET[7:4] (RW)
 *
 * offset on pclk unit. 0=aligne with data, positive value means delay, minus
 * value mean ahead. Supported range depends on panel mode
 */
/*@{*/
#define BP_EPDC_PIGEON_8_0_OFFSET (4U)     /*!< Bit position for EPDC_PIGEON_8_0_OFFSET. */
#define BM_EPDC_PIGEON_8_0_OFFSET (0x000000F0U) /*!< Bit mask for EPDC_PIGEON_8_0_OFFSET. */
#define BS_EPDC_PIGEON_8_0_OFFSET (4U)     /*!< Bit field size in bits for EPDC_PIGEON_8_0_OFFSET. */

/*! @brief Read current value of the EPDC_PIGEON_8_0_OFFSET field. */
#define BR_EPDC_PIGEON_8_0_OFFSET(x) (HW_EPDC_PIGEON_8_0(x).B.OFFSET)

/*! @brief Format value for bitfield EPDC_PIGEON_8_0_OFFSET. */
#define BF_EPDC_PIGEON_8_0_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_8_0_OFFSET) & BM_EPDC_PIGEON_8_0_OFFSET)

/*! @brief Set the OFFSET field to a new value. */
#define BW_EPDC_PIGEON_8_0_OFFSET(x, v) (HW_EPDC_PIGEON_8_0_WR(x, (HW_EPDC_PIGEON_8_0_RD(x) & ~BM_EPDC_PIGEON_8_0_OFFSET) | BF_EPDC_PIGEON_8_0_OFFSET(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_8_0, field MASK_CNT_SEL[11:8] (RW)
 *
 * select global counters as mask condition, use together with MASK_CNT
 *
 * Values:
 * - 0 - pclk counter within one hscan state
 * - 1 - pclk cycle within one hscan state
 * - 10 - line counter within one vscan state
 * - 11 - line cycle within one vscan state
 * - 100 - frame counter
 * - 101 - frame cycle
 * - 110 - horizontal counter (pclk counter within one line )
 * - 111 - vertical counter (line counter within one frame)
 */
/*@{*/
#define BP_EPDC_PIGEON_8_0_MASK_CNT_SEL (8U) /*!< Bit position for EPDC_PIGEON_8_0_MASK_CNT_SEL. */
#define BM_EPDC_PIGEON_8_0_MASK_CNT_SEL (0x00000F00U) /*!< Bit mask for EPDC_PIGEON_8_0_MASK_CNT_SEL. */
#define BS_EPDC_PIGEON_8_0_MASK_CNT_SEL (4U) /*!< Bit field size in bits for EPDC_PIGEON_8_0_MASK_CNT_SEL. */

#define BV_EPDC_PIGEON_8_0_MASK_CNT_SEL_HSTATE_CNT (0U) /*!< Bit field value for EPDC_PIGEON_8_0_MASK_CNT_SEL: pclk counter within one hscan state */
#define BV_EPDC_PIGEON_8_0_MASK_CNT_SEL_HSTATE_CYCLE (0x1U) /*!< Bit field value for EPDC_PIGEON_8_0_MASK_CNT_SEL: pclk cycle within one hscan state */
#define BV_EPDC_PIGEON_8_0_MASK_CNT_SEL_VSTATE_CNT (0x2U) /*!< Bit field value for EPDC_PIGEON_8_0_MASK_CNT_SEL: line counter within one vscan state */
#define BV_EPDC_PIGEON_8_0_MASK_CNT_SEL_VSTATE_CYCLE (0x3U) /*!< Bit field value for EPDC_PIGEON_8_0_MASK_CNT_SEL: line cycle within one vscan state */
#define BV_EPDC_PIGEON_8_0_MASK_CNT_SEL_FRAME_CNT (0x4U) /*!< Bit field value for EPDC_PIGEON_8_0_MASK_CNT_SEL: frame counter */
#define BV_EPDC_PIGEON_8_0_MASK_CNT_SEL_FRAME_CYCLE (0x5U) /*!< Bit field value for EPDC_PIGEON_8_0_MASK_CNT_SEL: frame cycle */
#define BV_EPDC_PIGEON_8_0_MASK_CNT_SEL_HCNT (0x6U)  /*!< Bit field value for EPDC_PIGEON_8_0_MASK_CNT_SEL: horizontal counter (pclk counter within one line ) */
#define BV_EPDC_PIGEON_8_0_MASK_CNT_SEL_VCNT (0x7U)  /*!< Bit field value for EPDC_PIGEON_8_0_MASK_CNT_SEL: vertical counter (line counter within one frame) */

/*! @brief Read current value of the EPDC_PIGEON_8_0_MASK_CNT_SEL field. */
#define BR_EPDC_PIGEON_8_0_MASK_CNT_SEL(x) (HW_EPDC_PIGEON_8_0(x).B.MASK_CNT_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_8_0_MASK_CNT_SEL. */
#define BF_EPDC_PIGEON_8_0_MASK_CNT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_8_0_MASK_CNT_SEL) & BM_EPDC_PIGEON_8_0_MASK_CNT_SEL)

/*! @brief Set the MASK_CNT_SEL field to a new value. */
#define BW_EPDC_PIGEON_8_0_MASK_CNT_SEL(x, v) (HW_EPDC_PIGEON_8_0_WR(x, (HW_EPDC_PIGEON_8_0_RD(x) & ~BM_EPDC_PIGEON_8_0_MASK_CNT_SEL) | BF_EPDC_PIGEON_8_0_MASK_CNT_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_8_0, field MASK_CNT[23:12] (RW)
 *
 * When the global counter selected through MASK_CNT_SEL matches value in this
 * reg, pigeon local counter start ticking. 0=disable
 */
/*@{*/
#define BP_EPDC_PIGEON_8_0_MASK_CNT (12U)  /*!< Bit position for EPDC_PIGEON_8_0_MASK_CNT. */
#define BM_EPDC_PIGEON_8_0_MASK_CNT (0x00FFF000U) /*!< Bit mask for EPDC_PIGEON_8_0_MASK_CNT. */
#define BS_EPDC_PIGEON_8_0_MASK_CNT (12U)  /*!< Bit field size in bits for EPDC_PIGEON_8_0_MASK_CNT. */

/*! @brief Read current value of the EPDC_PIGEON_8_0_MASK_CNT field. */
#define BR_EPDC_PIGEON_8_0_MASK_CNT(x) (HW_EPDC_PIGEON_8_0(x).B.MASK_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_8_0_MASK_CNT. */
#define BF_EPDC_PIGEON_8_0_MASK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_8_0_MASK_CNT) & BM_EPDC_PIGEON_8_0_MASK_CNT)

/*! @brief Set the MASK_CNT field to a new value. */
#define BW_EPDC_PIGEON_8_0_MASK_CNT(x, v) (HW_EPDC_PIGEON_8_0_WR(x, (HW_EPDC_PIGEON_8_0_RD(x) & ~BM_EPDC_PIGEON_8_0_MASK_CNT) | BF_EPDC_PIGEON_8_0_MASK_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_8_0, field STATE_MASK[31:24] (RW)
 *
 * state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan
 * states as reference point for local counter to start ticking
 *
 * Values:
 * - 1 - FRAME SYNC
 * - 10 - FRAME BEGIN
 * - 100 - FRAME DATA
 * - 1000 - FRAME END
 * - 10000 - LINE SYNC
 * - 100000 - LINE BEGIN
 * - 1000000 - LINE DATA
 * - 10000000 - LINE END
 */
/*@{*/
#define BP_EPDC_PIGEON_8_0_STATE_MASK (24U) /*!< Bit position for EPDC_PIGEON_8_0_STATE_MASK. */
#define BM_EPDC_PIGEON_8_0_STATE_MASK (0xFF000000U) /*!< Bit mask for EPDC_PIGEON_8_0_STATE_MASK. */
#define BS_EPDC_PIGEON_8_0_STATE_MASK (8U) /*!< Bit field size in bits for EPDC_PIGEON_8_0_STATE_MASK. */

#define BV_EPDC_PIGEON_8_0_STATE_MASK_FS (0x1U)      /*!< Bit field value for EPDC_PIGEON_8_0_STATE_MASK: FRAME SYNC */
#define BV_EPDC_PIGEON_8_0_STATE_MASK_FB (0x2U)      /*!< Bit field value for EPDC_PIGEON_8_0_STATE_MASK: FRAME BEGIN */
#define BV_EPDC_PIGEON_8_0_STATE_MASK_FD (0x4U)      /*!< Bit field value for EPDC_PIGEON_8_0_STATE_MASK: FRAME DATA */
#define BV_EPDC_PIGEON_8_0_STATE_MASK_FE (0x8U)      /*!< Bit field value for EPDC_PIGEON_8_0_STATE_MASK: FRAME END */
#define BV_EPDC_PIGEON_8_0_STATE_MASK_LS (0x10U)     /*!< Bit field value for EPDC_PIGEON_8_0_STATE_MASK: LINE SYNC */
#define BV_EPDC_PIGEON_8_0_STATE_MASK_LB (0x20U)     /*!< Bit field value for EPDC_PIGEON_8_0_STATE_MASK: LINE BEGIN */
#define BV_EPDC_PIGEON_8_0_STATE_MASK_LD (0x40U)     /*!< Bit field value for EPDC_PIGEON_8_0_STATE_MASK: LINE DATA */
#define BV_EPDC_PIGEON_8_0_STATE_MASK_LE (0x80U)     /*!< Bit field value for EPDC_PIGEON_8_0_STATE_MASK: LINE END */

/*! @brief Read current value of the EPDC_PIGEON_8_0_STATE_MASK field. */
#define BR_EPDC_PIGEON_8_0_STATE_MASK(x) (HW_EPDC_PIGEON_8_0(x).B.STATE_MASK)

/*! @brief Format value for bitfield EPDC_PIGEON_8_0_STATE_MASK. */
#define BF_EPDC_PIGEON_8_0_STATE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_8_0_STATE_MASK) & BM_EPDC_PIGEON_8_0_STATE_MASK)

/*! @brief Set the STATE_MASK field to a new value. */
#define BW_EPDC_PIGEON_8_0_STATE_MASK(x, v) (HW_EPDC_PIGEON_8_0_WR(x, (HW_EPDC_PIGEON_8_0_RD(x) & ~BM_EPDC_PIGEON_8_0_STATE_MASK) | BF_EPDC_PIGEON_8_0_STATE_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_8_1 - Panel Interface Signal Generator Register 8_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_8_1 - Panel Interface Signal Generator Register 8_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_8_1
{
    uint32_t U;
    struct _hw_epdc_pigeon_8_1_bitfields
    {
        uint32_t SET_CNT : 16;         /*!< [15:0]  */
        uint32_t CLR_CNT : 16;         /*!< [31:16]  */
    } B;
} hw_epdc_pigeon_8_1_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_8_1 register
 */
/*@{*/
#define HW_EPDC_PIGEON_8_1_ADDR(x) ((uintptr_t)(x) + 0xA10U)

#define HW_EPDC_PIGEON_8_1(x)    (*(__IO hw_epdc_pigeon_8_1_t *) HW_EPDC_PIGEON_8_1_ADDR(x))
#define HW_EPDC_PIGEON_8_1_RD(x) (HW_EPDC_PIGEON_8_1(x).U)
#define HW_EPDC_PIGEON_8_1_WR(x, v) (HW_EPDC_PIGEON_8_1(x).U = (v))
#define HW_EPDC_PIGEON_8_1_SET(x, v) (HW_EPDC_PIGEON_8_1_WR(x, HW_EPDC_PIGEON_8_1_RD(x) |  (v)))
#define HW_EPDC_PIGEON_8_1_CLR(x, v) (HW_EPDC_PIGEON_8_1_WR(x, HW_EPDC_PIGEON_8_1_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_8_1_TOG(x, v) (HW_EPDC_PIGEON_8_1_WR(x, HW_EPDC_PIGEON_8_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_8_1 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_8_1, field SET_CNT[15:0] (RW)
 *
 * assert signal output when counter match this value
 *
 * Values:
 * - 0 - start as active
 */
/*@{*/
#define BP_EPDC_PIGEON_8_1_SET_CNT (0U)    /*!< Bit position for EPDC_PIGEON_8_1_SET_CNT. */
#define BM_EPDC_PIGEON_8_1_SET_CNT (0x0000FFFFU) /*!< Bit mask for EPDC_PIGEON_8_1_SET_CNT. */
#define BS_EPDC_PIGEON_8_1_SET_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_8_1_SET_CNT. */

#define BV_EPDC_PIGEON_8_1_SET_CNT_START_ACTIVE (0U) /*!< Bit field value for EPDC_PIGEON_8_1_SET_CNT: start as active */

/*! @brief Read current value of the EPDC_PIGEON_8_1_SET_CNT field. */
#define BR_EPDC_PIGEON_8_1_SET_CNT(x) (HW_EPDC_PIGEON_8_1(x).B.SET_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_8_1_SET_CNT. */
#define BF_EPDC_PIGEON_8_1_SET_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_8_1_SET_CNT) & BM_EPDC_PIGEON_8_1_SET_CNT)

/*! @brief Set the SET_CNT field to a new value. */
#define BW_EPDC_PIGEON_8_1_SET_CNT(x, v) (HW_EPDC_PIGEON_8_1_WR(x, (HW_EPDC_PIGEON_8_1_RD(x) & ~BM_EPDC_PIGEON_8_1_SET_CNT) | BF_EPDC_PIGEON_8_1_SET_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_8_1, field CLR_CNT[31:16] (RW)
 *
 * deassert signal output when counter match this value
 *
 * Values:
 * - 0 - keep active until mask off
 */
/*@{*/
#define BP_EPDC_PIGEON_8_1_CLR_CNT (16U)   /*!< Bit position for EPDC_PIGEON_8_1_CLR_CNT. */
#define BM_EPDC_PIGEON_8_1_CLR_CNT (0xFFFF0000U) /*!< Bit mask for EPDC_PIGEON_8_1_CLR_CNT. */
#define BS_EPDC_PIGEON_8_1_CLR_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_8_1_CLR_CNT. */

#define BV_EPDC_PIGEON_8_1_CLR_CNT_CLEAR_USING_MASK (0U) /*!< Bit field value for EPDC_PIGEON_8_1_CLR_CNT: keep active until mask off */

/*! @brief Read current value of the EPDC_PIGEON_8_1_CLR_CNT field. */
#define BR_EPDC_PIGEON_8_1_CLR_CNT(x) (HW_EPDC_PIGEON_8_1(x).B.CLR_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_8_1_CLR_CNT. */
#define BF_EPDC_PIGEON_8_1_CLR_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_8_1_CLR_CNT) & BM_EPDC_PIGEON_8_1_CLR_CNT)

/*! @brief Set the CLR_CNT field to a new value. */
#define BW_EPDC_PIGEON_8_1_CLR_CNT(x, v) (HW_EPDC_PIGEON_8_1_WR(x, (HW_EPDC_PIGEON_8_1_RD(x) & ~BM_EPDC_PIGEON_8_1_CLR_CNT) | BF_EPDC_PIGEON_8_1_CLR_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_8_2 - Panel Interface Signal Generator Register 8_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_8_2 - Panel Interface Signal Generator Register 8_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_8_2
{
    uint32_t U;
    struct _hw_epdc_pigeon_8_2_bitfields
    {
        uint32_t SIG_LOGIC : 4;        /*!< [3:0]  */
        uint32_t SIG_ANOTHER : 5;      /*!< [8:4]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_epdc_pigeon_8_2_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_8_2 register
 */
/*@{*/
#define HW_EPDC_PIGEON_8_2_ADDR(x) ((uintptr_t)(x) + 0xA20U)

#define HW_EPDC_PIGEON_8_2(x)    (*(__IO hw_epdc_pigeon_8_2_t *) HW_EPDC_PIGEON_8_2_ADDR(x))
#define HW_EPDC_PIGEON_8_2_RD(x) (HW_EPDC_PIGEON_8_2(x).U)
#define HW_EPDC_PIGEON_8_2_WR(x, v) (HW_EPDC_PIGEON_8_2(x).U = (v))
#define HW_EPDC_PIGEON_8_2_SET(x, v) (HW_EPDC_PIGEON_8_2_WR(x, HW_EPDC_PIGEON_8_2_RD(x) |  (v)))
#define HW_EPDC_PIGEON_8_2_CLR(x, v) (HW_EPDC_PIGEON_8_2_WR(x, HW_EPDC_PIGEON_8_2_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_8_2_TOG(x, v) (HW_EPDC_PIGEON_8_2_WR(x, HW_EPDC_PIGEON_8_2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_8_2 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_8_2, field SIG_LOGIC[3:0] (RW)
 *
 * logic operation with another signal sigout : final output signal of this
 * generator mask : final mask of this generator this_sig : intermediate signal of
 * this generator before logic operation other_masks : intermediate mask result of
 * this generator before logic operation sig_another : signal selected other
 * generators
 *
 * Values:
 * - 0 - no logic operation
 * - 1 - sigout = sig_another AND this_sig
 * - 10 - sigout = sig_another OR this_sig
 * - 11 - mask = sig_another AND other_masks
 */
/*@{*/
#define BP_EPDC_PIGEON_8_2_SIG_LOGIC (0U)  /*!< Bit position for EPDC_PIGEON_8_2_SIG_LOGIC. */
#define BM_EPDC_PIGEON_8_2_SIG_LOGIC (0x0000000FU) /*!< Bit mask for EPDC_PIGEON_8_2_SIG_LOGIC. */
#define BS_EPDC_PIGEON_8_2_SIG_LOGIC (4U)  /*!< Bit field size in bits for EPDC_PIGEON_8_2_SIG_LOGIC. */

#define BV_EPDC_PIGEON_8_2_SIG_LOGIC_DIS (0U)        /*!< Bit field value for EPDC_PIGEON_8_2_SIG_LOGIC: no logic operation */
#define BV_EPDC_PIGEON_8_2_SIG_LOGIC_AND (0x1U)      /*!< Bit field value for EPDC_PIGEON_8_2_SIG_LOGIC: sigout = sig_another AND this_sig */
#define BV_EPDC_PIGEON_8_2_SIG_LOGIC_OR (0x2U)       /*!< Bit field value for EPDC_PIGEON_8_2_SIG_LOGIC: sigout = sig_another OR this_sig */
#define BV_EPDC_PIGEON_8_2_SIG_LOGIC_MASK (0x3U)     /*!< Bit field value for EPDC_PIGEON_8_2_SIG_LOGIC: mask = sig_another AND other_masks */

/*! @brief Read current value of the EPDC_PIGEON_8_2_SIG_LOGIC field. */
#define BR_EPDC_PIGEON_8_2_SIG_LOGIC(x) (HW_EPDC_PIGEON_8_2(x).B.SIG_LOGIC)

/*! @brief Format value for bitfield EPDC_PIGEON_8_2_SIG_LOGIC. */
#define BF_EPDC_PIGEON_8_2_SIG_LOGIC(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_8_2_SIG_LOGIC) & BM_EPDC_PIGEON_8_2_SIG_LOGIC)

/*! @brief Set the SIG_LOGIC field to a new value. */
#define BW_EPDC_PIGEON_8_2_SIG_LOGIC(x, v) (HW_EPDC_PIGEON_8_2_WR(x, (HW_EPDC_PIGEON_8_2_RD(x) & ~BM_EPDC_PIGEON_8_2_SIG_LOGIC) | BF_EPDC_PIGEON_8_2_SIG_LOGIC(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_8_2, field SIG_ANOTHER[8:4] (RW)
 *
 * select another signal for logic operation or as mask or counter tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_8_2_SIG_ANOTHER (4U) /*!< Bit position for EPDC_PIGEON_8_2_SIG_ANOTHER. */
#define BM_EPDC_PIGEON_8_2_SIG_ANOTHER (0x000001F0U) /*!< Bit mask for EPDC_PIGEON_8_2_SIG_ANOTHER. */
#define BS_EPDC_PIGEON_8_2_SIG_ANOTHER (5U) /*!< Bit field size in bits for EPDC_PIGEON_8_2_SIG_ANOTHER. */

/*! @brief Read current value of the EPDC_PIGEON_8_2_SIG_ANOTHER field. */
#define BR_EPDC_PIGEON_8_2_SIG_ANOTHER(x) (HW_EPDC_PIGEON_8_2(x).B.SIG_ANOTHER)

/*! @brief Format value for bitfield EPDC_PIGEON_8_2_SIG_ANOTHER. */
#define BF_EPDC_PIGEON_8_2_SIG_ANOTHER(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_8_2_SIG_ANOTHER) & BM_EPDC_PIGEON_8_2_SIG_ANOTHER)

/*! @brief Set the SIG_ANOTHER field to a new value. */
#define BW_EPDC_PIGEON_8_2_SIG_ANOTHER(x, v) (HW_EPDC_PIGEON_8_2_WR(x, (HW_EPDC_PIGEON_8_2_RD(x) & ~BM_EPDC_PIGEON_8_2_SIG_ANOTHER) | BF_EPDC_PIGEON_8_2_SIG_ANOTHER(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_9_0 - Panel Interface Signal Generator Register 9_0
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_9_0 - Panel Interface Signal Generator Register 9_0 (RW)
 *
 * Reset value: 0x00000F00U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_9_0
{
    uint32_t U;
    struct _hw_epdc_pigeon_9_0_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t POL : 1;              /*!< [1]  */
        uint32_t INC_SEL : 2;          /*!< [3:2]  */
        uint32_t OFFSET : 4;           /*!< [7:4]  */
        uint32_t MASK_CNT_SEL : 4;     /*!< [11:8]  */
        uint32_t MASK_CNT : 12;        /*!< [23:12]  */
        uint32_t STATE_MASK : 8;       /*!< [31:24]  */
    } B;
} hw_epdc_pigeon_9_0_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_9_0 register
 */
/*@{*/
#define HW_EPDC_PIGEON_9_0_ADDR(x) ((uintptr_t)(x) + 0xA40U)

#define HW_EPDC_PIGEON_9_0(x)    (*(__IO hw_epdc_pigeon_9_0_t *) HW_EPDC_PIGEON_9_0_ADDR(x))
#define HW_EPDC_PIGEON_9_0_RD(x) (HW_EPDC_PIGEON_9_0(x).U)
#define HW_EPDC_PIGEON_9_0_WR(x, v) (HW_EPDC_PIGEON_9_0(x).U = (v))
#define HW_EPDC_PIGEON_9_0_SET(x, v) (HW_EPDC_PIGEON_9_0_WR(x, HW_EPDC_PIGEON_9_0_RD(x) |  (v)))
#define HW_EPDC_PIGEON_9_0_CLR(x, v) (HW_EPDC_PIGEON_9_0_WR(x, HW_EPDC_PIGEON_9_0_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_9_0_TOG(x, v) (HW_EPDC_PIGEON_9_0_WR(x, HW_EPDC_PIGEON_9_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_9_0 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_9_0, field EN[0] (RW)
 *
 * enable pigeon mode on this signal
 */
/*@{*/
#define BP_EPDC_PIGEON_9_0_EN (0U)         /*!< Bit position for EPDC_PIGEON_9_0_EN. */
#define BM_EPDC_PIGEON_9_0_EN (0x00000001U) /*!< Bit mask for EPDC_PIGEON_9_0_EN. */
#define BS_EPDC_PIGEON_9_0_EN (1U)         /*!< Bit field size in bits for EPDC_PIGEON_9_0_EN. */

/*! @brief Read current value of the EPDC_PIGEON_9_0_EN field. */
#define BR_EPDC_PIGEON_9_0_EN(x) (HW_EPDC_PIGEON_9_0(x).B.EN)

/*! @brief Format value for bitfield EPDC_PIGEON_9_0_EN. */
#define BF_EPDC_PIGEON_9_0_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_9_0_EN) & BM_EPDC_PIGEON_9_0_EN)

/*! @brief Set the EN field to a new value. */
#define BW_EPDC_PIGEON_9_0_EN(x, v) (HW_EPDC_PIGEON_9_0_WR(x, (HW_EPDC_PIGEON_9_0_RD(x) & ~BM_EPDC_PIGEON_9_0_EN) | BF_EPDC_PIGEON_9_0_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_9_0, field POL[1] (RW)
 *
 * polarity of signal output
 *
 * Values:
 * - 0 - normal signal (active high)
 * - 1 - inverted signal (active low)
 */
/*@{*/
#define BP_EPDC_PIGEON_9_0_POL (1U)        /*!< Bit position for EPDC_PIGEON_9_0_POL. */
#define BM_EPDC_PIGEON_9_0_POL (0x00000002U) /*!< Bit mask for EPDC_PIGEON_9_0_POL. */
#define BS_EPDC_PIGEON_9_0_POL (1U)        /*!< Bit field size in bits for EPDC_PIGEON_9_0_POL. */

#define BV_EPDC_PIGEON_9_0_POL_ACTIVE_HIGH (0U)      /*!< Bit field value for EPDC_PIGEON_9_0_POL: normal signal (active high) */
#define BV_EPDC_PIGEON_9_0_POL_ACTIVE_LOW (0x1U)     /*!< Bit field value for EPDC_PIGEON_9_0_POL: inverted signal (active low) */

/*! @brief Read current value of the EPDC_PIGEON_9_0_POL field. */
#define BR_EPDC_PIGEON_9_0_POL(x) (HW_EPDC_PIGEON_9_0(x).B.POL)

/*! @brief Format value for bitfield EPDC_PIGEON_9_0_POL. */
#define BF_EPDC_PIGEON_9_0_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_9_0_POL) & BM_EPDC_PIGEON_9_0_POL)

/*! @brief Set the POL field to a new value. */
#define BW_EPDC_PIGEON_9_0_POL(x, v) (HW_EPDC_PIGEON_9_0_WR(x, (HW_EPDC_PIGEON_9_0_RD(x) & ~BM_EPDC_PIGEON_9_0_POL) | BF_EPDC_PIGEON_9_0_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_9_0, field INC_SEL[3:2] (RW)
 *
 * event to incrment local counter
 *
 * Values:
 * - 0 - pclk
 * - 1 - line start pulse
 * - 10 - frame start pulse
 * - 11 - use another signal as tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_9_0_INC_SEL (2U)    /*!< Bit position for EPDC_PIGEON_9_0_INC_SEL. */
#define BM_EPDC_PIGEON_9_0_INC_SEL (0x0000000CU) /*!< Bit mask for EPDC_PIGEON_9_0_INC_SEL. */
#define BS_EPDC_PIGEON_9_0_INC_SEL (2U)    /*!< Bit field size in bits for EPDC_PIGEON_9_0_INC_SEL. */

#define BV_EPDC_PIGEON_9_0_INC_SEL_PCLK (0U)         /*!< Bit field value for EPDC_PIGEON_9_0_INC_SEL: pclk */
#define BV_EPDC_PIGEON_9_0_INC_SEL_LINE (0x1U)       /*!< Bit field value for EPDC_PIGEON_9_0_INC_SEL: line start pulse */
#define BV_EPDC_PIGEON_9_0_INC_SEL_FRAME (0x2U)      /*!< Bit field value for EPDC_PIGEON_9_0_INC_SEL: frame start pulse */
#define BV_EPDC_PIGEON_9_0_INC_SEL_SIG_ANOTHER (0x3U) /*!< Bit field value for EPDC_PIGEON_9_0_INC_SEL: use another signal as tick event */

/*! @brief Read current value of the EPDC_PIGEON_9_0_INC_SEL field. */
#define BR_EPDC_PIGEON_9_0_INC_SEL(x) (HW_EPDC_PIGEON_9_0(x).B.INC_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_9_0_INC_SEL. */
#define BF_EPDC_PIGEON_9_0_INC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_9_0_INC_SEL) & BM_EPDC_PIGEON_9_0_INC_SEL)

/*! @brief Set the INC_SEL field to a new value. */
#define BW_EPDC_PIGEON_9_0_INC_SEL(x, v) (HW_EPDC_PIGEON_9_0_WR(x, (HW_EPDC_PIGEON_9_0_RD(x) & ~BM_EPDC_PIGEON_9_0_INC_SEL) | BF_EPDC_PIGEON_9_0_INC_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_9_0, field OFFSET[7:4] (RW)
 *
 * offset on pclk unit. 0=aligne with data, positive value means delay, minus
 * value mean ahead. Supported range depends on panel mode
 */
/*@{*/
#define BP_EPDC_PIGEON_9_0_OFFSET (4U)     /*!< Bit position for EPDC_PIGEON_9_0_OFFSET. */
#define BM_EPDC_PIGEON_9_0_OFFSET (0x000000F0U) /*!< Bit mask for EPDC_PIGEON_9_0_OFFSET. */
#define BS_EPDC_PIGEON_9_0_OFFSET (4U)     /*!< Bit field size in bits for EPDC_PIGEON_9_0_OFFSET. */

/*! @brief Read current value of the EPDC_PIGEON_9_0_OFFSET field. */
#define BR_EPDC_PIGEON_9_0_OFFSET(x) (HW_EPDC_PIGEON_9_0(x).B.OFFSET)

/*! @brief Format value for bitfield EPDC_PIGEON_9_0_OFFSET. */
#define BF_EPDC_PIGEON_9_0_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_9_0_OFFSET) & BM_EPDC_PIGEON_9_0_OFFSET)

/*! @brief Set the OFFSET field to a new value. */
#define BW_EPDC_PIGEON_9_0_OFFSET(x, v) (HW_EPDC_PIGEON_9_0_WR(x, (HW_EPDC_PIGEON_9_0_RD(x) & ~BM_EPDC_PIGEON_9_0_OFFSET) | BF_EPDC_PIGEON_9_0_OFFSET(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_9_0, field MASK_CNT_SEL[11:8] (RW)
 *
 * select global counters as mask condition, use together with MASK_CNT
 *
 * Values:
 * - 0 - pclk counter within one hscan state
 * - 1 - pclk cycle within one hscan state
 * - 10 - line counter within one vscan state
 * - 11 - line cycle within one vscan state
 * - 100 - frame counter
 * - 101 - frame cycle
 * - 110 - horizontal counter (pclk counter within one line )
 * - 111 - vertical counter (line counter within one frame)
 */
/*@{*/
#define BP_EPDC_PIGEON_9_0_MASK_CNT_SEL (8U) /*!< Bit position for EPDC_PIGEON_9_0_MASK_CNT_SEL. */
#define BM_EPDC_PIGEON_9_0_MASK_CNT_SEL (0x00000F00U) /*!< Bit mask for EPDC_PIGEON_9_0_MASK_CNT_SEL. */
#define BS_EPDC_PIGEON_9_0_MASK_CNT_SEL (4U) /*!< Bit field size in bits for EPDC_PIGEON_9_0_MASK_CNT_SEL. */

#define BV_EPDC_PIGEON_9_0_MASK_CNT_SEL_HSTATE_CNT (0U) /*!< Bit field value for EPDC_PIGEON_9_0_MASK_CNT_SEL: pclk counter within one hscan state */
#define BV_EPDC_PIGEON_9_0_MASK_CNT_SEL_HSTATE_CYCLE (0x1U) /*!< Bit field value for EPDC_PIGEON_9_0_MASK_CNT_SEL: pclk cycle within one hscan state */
#define BV_EPDC_PIGEON_9_0_MASK_CNT_SEL_VSTATE_CNT (0x2U) /*!< Bit field value for EPDC_PIGEON_9_0_MASK_CNT_SEL: line counter within one vscan state */
#define BV_EPDC_PIGEON_9_0_MASK_CNT_SEL_VSTATE_CYCLE (0x3U) /*!< Bit field value for EPDC_PIGEON_9_0_MASK_CNT_SEL: line cycle within one vscan state */
#define BV_EPDC_PIGEON_9_0_MASK_CNT_SEL_FRAME_CNT (0x4U) /*!< Bit field value for EPDC_PIGEON_9_0_MASK_CNT_SEL: frame counter */
#define BV_EPDC_PIGEON_9_0_MASK_CNT_SEL_FRAME_CYCLE (0x5U) /*!< Bit field value for EPDC_PIGEON_9_0_MASK_CNT_SEL: frame cycle */
#define BV_EPDC_PIGEON_9_0_MASK_CNT_SEL_HCNT (0x6U)  /*!< Bit field value for EPDC_PIGEON_9_0_MASK_CNT_SEL: horizontal counter (pclk counter within one line ) */
#define BV_EPDC_PIGEON_9_0_MASK_CNT_SEL_VCNT (0x7U)  /*!< Bit field value for EPDC_PIGEON_9_0_MASK_CNT_SEL: vertical counter (line counter within one frame) */

/*! @brief Read current value of the EPDC_PIGEON_9_0_MASK_CNT_SEL field. */
#define BR_EPDC_PIGEON_9_0_MASK_CNT_SEL(x) (HW_EPDC_PIGEON_9_0(x).B.MASK_CNT_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_9_0_MASK_CNT_SEL. */
#define BF_EPDC_PIGEON_9_0_MASK_CNT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_9_0_MASK_CNT_SEL) & BM_EPDC_PIGEON_9_0_MASK_CNT_SEL)

/*! @brief Set the MASK_CNT_SEL field to a new value. */
#define BW_EPDC_PIGEON_9_0_MASK_CNT_SEL(x, v) (HW_EPDC_PIGEON_9_0_WR(x, (HW_EPDC_PIGEON_9_0_RD(x) & ~BM_EPDC_PIGEON_9_0_MASK_CNT_SEL) | BF_EPDC_PIGEON_9_0_MASK_CNT_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_9_0, field MASK_CNT[23:12] (RW)
 *
 * When the global counter selected through MASK_CNT_SEL matches value in this
 * reg, pigeon local counter start ticking. 0=disable
 */
/*@{*/
#define BP_EPDC_PIGEON_9_0_MASK_CNT (12U)  /*!< Bit position for EPDC_PIGEON_9_0_MASK_CNT. */
#define BM_EPDC_PIGEON_9_0_MASK_CNT (0x00FFF000U) /*!< Bit mask for EPDC_PIGEON_9_0_MASK_CNT. */
#define BS_EPDC_PIGEON_9_0_MASK_CNT (12U)  /*!< Bit field size in bits for EPDC_PIGEON_9_0_MASK_CNT. */

/*! @brief Read current value of the EPDC_PIGEON_9_0_MASK_CNT field. */
#define BR_EPDC_PIGEON_9_0_MASK_CNT(x) (HW_EPDC_PIGEON_9_0(x).B.MASK_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_9_0_MASK_CNT. */
#define BF_EPDC_PIGEON_9_0_MASK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_9_0_MASK_CNT) & BM_EPDC_PIGEON_9_0_MASK_CNT)

/*! @brief Set the MASK_CNT field to a new value. */
#define BW_EPDC_PIGEON_9_0_MASK_CNT(x, v) (HW_EPDC_PIGEON_9_0_WR(x, (HW_EPDC_PIGEON_9_0_RD(x) & ~BM_EPDC_PIGEON_9_0_MASK_CNT) | BF_EPDC_PIGEON_9_0_MASK_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_9_0, field STATE_MASK[31:24] (RW)
 *
 * state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan
 * states as reference point for local counter to start ticking
 *
 * Values:
 * - 1 - FRAME SYNC
 * - 10 - FRAME BEGIN
 * - 100 - FRAME DATA
 * - 1000 - FRAME END
 * - 10000 - LINE SYNC
 * - 100000 - LINE BEGIN
 * - 1000000 - LINE DATA
 * - 10000000 - LINE END
 */
/*@{*/
#define BP_EPDC_PIGEON_9_0_STATE_MASK (24U) /*!< Bit position for EPDC_PIGEON_9_0_STATE_MASK. */
#define BM_EPDC_PIGEON_9_0_STATE_MASK (0xFF000000U) /*!< Bit mask for EPDC_PIGEON_9_0_STATE_MASK. */
#define BS_EPDC_PIGEON_9_0_STATE_MASK (8U) /*!< Bit field size in bits for EPDC_PIGEON_9_0_STATE_MASK. */

#define BV_EPDC_PIGEON_9_0_STATE_MASK_FS (0x1U)      /*!< Bit field value for EPDC_PIGEON_9_0_STATE_MASK: FRAME SYNC */
#define BV_EPDC_PIGEON_9_0_STATE_MASK_FB (0x2U)      /*!< Bit field value for EPDC_PIGEON_9_0_STATE_MASK: FRAME BEGIN */
#define BV_EPDC_PIGEON_9_0_STATE_MASK_FD (0x4U)      /*!< Bit field value for EPDC_PIGEON_9_0_STATE_MASK: FRAME DATA */
#define BV_EPDC_PIGEON_9_0_STATE_MASK_FE (0x8U)      /*!< Bit field value for EPDC_PIGEON_9_0_STATE_MASK: FRAME END */
#define BV_EPDC_PIGEON_9_0_STATE_MASK_LS (0x10U)     /*!< Bit field value for EPDC_PIGEON_9_0_STATE_MASK: LINE SYNC */
#define BV_EPDC_PIGEON_9_0_STATE_MASK_LB (0x20U)     /*!< Bit field value for EPDC_PIGEON_9_0_STATE_MASK: LINE BEGIN */
#define BV_EPDC_PIGEON_9_0_STATE_MASK_LD (0x40U)     /*!< Bit field value for EPDC_PIGEON_9_0_STATE_MASK: LINE DATA */
#define BV_EPDC_PIGEON_9_0_STATE_MASK_LE (0x80U)     /*!< Bit field value for EPDC_PIGEON_9_0_STATE_MASK: LINE END */

/*! @brief Read current value of the EPDC_PIGEON_9_0_STATE_MASK field. */
#define BR_EPDC_PIGEON_9_0_STATE_MASK(x) (HW_EPDC_PIGEON_9_0(x).B.STATE_MASK)

/*! @brief Format value for bitfield EPDC_PIGEON_9_0_STATE_MASK. */
#define BF_EPDC_PIGEON_9_0_STATE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_9_0_STATE_MASK) & BM_EPDC_PIGEON_9_0_STATE_MASK)

/*! @brief Set the STATE_MASK field to a new value. */
#define BW_EPDC_PIGEON_9_0_STATE_MASK(x, v) (HW_EPDC_PIGEON_9_0_WR(x, (HW_EPDC_PIGEON_9_0_RD(x) & ~BM_EPDC_PIGEON_9_0_STATE_MASK) | BF_EPDC_PIGEON_9_0_STATE_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_9_1 - Panel Interface Signal Generator Register 9_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_9_1 - Panel Interface Signal Generator Register 9_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_9_1
{
    uint32_t U;
    struct _hw_epdc_pigeon_9_1_bitfields
    {
        uint32_t SET_CNT : 16;         /*!< [15:0]  */
        uint32_t CLR_CNT : 16;         /*!< [31:16]  */
    } B;
} hw_epdc_pigeon_9_1_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_9_1 register
 */
/*@{*/
#define HW_EPDC_PIGEON_9_1_ADDR(x) ((uintptr_t)(x) + 0xA50U)

#define HW_EPDC_PIGEON_9_1(x)    (*(__IO hw_epdc_pigeon_9_1_t *) HW_EPDC_PIGEON_9_1_ADDR(x))
#define HW_EPDC_PIGEON_9_1_RD(x) (HW_EPDC_PIGEON_9_1(x).U)
#define HW_EPDC_PIGEON_9_1_WR(x, v) (HW_EPDC_PIGEON_9_1(x).U = (v))
#define HW_EPDC_PIGEON_9_1_SET(x, v) (HW_EPDC_PIGEON_9_1_WR(x, HW_EPDC_PIGEON_9_1_RD(x) |  (v)))
#define HW_EPDC_PIGEON_9_1_CLR(x, v) (HW_EPDC_PIGEON_9_1_WR(x, HW_EPDC_PIGEON_9_1_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_9_1_TOG(x, v) (HW_EPDC_PIGEON_9_1_WR(x, HW_EPDC_PIGEON_9_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_9_1 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_9_1, field SET_CNT[15:0] (RW)
 *
 * assert signal output when counter match this value
 *
 * Values:
 * - 0 - start as active
 */
/*@{*/
#define BP_EPDC_PIGEON_9_1_SET_CNT (0U)    /*!< Bit position for EPDC_PIGEON_9_1_SET_CNT. */
#define BM_EPDC_PIGEON_9_1_SET_CNT (0x0000FFFFU) /*!< Bit mask for EPDC_PIGEON_9_1_SET_CNT. */
#define BS_EPDC_PIGEON_9_1_SET_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_9_1_SET_CNT. */

#define BV_EPDC_PIGEON_9_1_SET_CNT_START_ACTIVE (0U) /*!< Bit field value for EPDC_PIGEON_9_1_SET_CNT: start as active */

/*! @brief Read current value of the EPDC_PIGEON_9_1_SET_CNT field. */
#define BR_EPDC_PIGEON_9_1_SET_CNT(x) (HW_EPDC_PIGEON_9_1(x).B.SET_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_9_1_SET_CNT. */
#define BF_EPDC_PIGEON_9_1_SET_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_9_1_SET_CNT) & BM_EPDC_PIGEON_9_1_SET_CNT)

/*! @brief Set the SET_CNT field to a new value. */
#define BW_EPDC_PIGEON_9_1_SET_CNT(x, v) (HW_EPDC_PIGEON_9_1_WR(x, (HW_EPDC_PIGEON_9_1_RD(x) & ~BM_EPDC_PIGEON_9_1_SET_CNT) | BF_EPDC_PIGEON_9_1_SET_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_9_1, field CLR_CNT[31:16] (RW)
 *
 * deassert signal output when counter match this value
 *
 * Values:
 * - 0 - keep active until mask off
 */
/*@{*/
#define BP_EPDC_PIGEON_9_1_CLR_CNT (16U)   /*!< Bit position for EPDC_PIGEON_9_1_CLR_CNT. */
#define BM_EPDC_PIGEON_9_1_CLR_CNT (0xFFFF0000U) /*!< Bit mask for EPDC_PIGEON_9_1_CLR_CNT. */
#define BS_EPDC_PIGEON_9_1_CLR_CNT (16U)   /*!< Bit field size in bits for EPDC_PIGEON_9_1_CLR_CNT. */

#define BV_EPDC_PIGEON_9_1_CLR_CNT_CLEAR_USING_MASK (0U) /*!< Bit field value for EPDC_PIGEON_9_1_CLR_CNT: keep active until mask off */

/*! @brief Read current value of the EPDC_PIGEON_9_1_CLR_CNT field. */
#define BR_EPDC_PIGEON_9_1_CLR_CNT(x) (HW_EPDC_PIGEON_9_1(x).B.CLR_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_9_1_CLR_CNT. */
#define BF_EPDC_PIGEON_9_1_CLR_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_9_1_CLR_CNT) & BM_EPDC_PIGEON_9_1_CLR_CNT)

/*! @brief Set the CLR_CNT field to a new value. */
#define BW_EPDC_PIGEON_9_1_CLR_CNT(x, v) (HW_EPDC_PIGEON_9_1_WR(x, (HW_EPDC_PIGEON_9_1_RD(x) & ~BM_EPDC_PIGEON_9_1_CLR_CNT) | BF_EPDC_PIGEON_9_1_CLR_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_9_2 - Panel Interface Signal Generator Register 9_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_9_2 - Panel Interface Signal Generator Register 9_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_9_2
{
    uint32_t U;
    struct _hw_epdc_pigeon_9_2_bitfields
    {
        uint32_t SIG_LOGIC : 4;        /*!< [3:0]  */
        uint32_t SIG_ANOTHER : 5;      /*!< [8:4]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_epdc_pigeon_9_2_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_9_2 register
 */
/*@{*/
#define HW_EPDC_PIGEON_9_2_ADDR(x) ((uintptr_t)(x) + 0xA60U)

#define HW_EPDC_PIGEON_9_2(x)    (*(__IO hw_epdc_pigeon_9_2_t *) HW_EPDC_PIGEON_9_2_ADDR(x))
#define HW_EPDC_PIGEON_9_2_RD(x) (HW_EPDC_PIGEON_9_2(x).U)
#define HW_EPDC_PIGEON_9_2_WR(x, v) (HW_EPDC_PIGEON_9_2(x).U = (v))
#define HW_EPDC_PIGEON_9_2_SET(x, v) (HW_EPDC_PIGEON_9_2_WR(x, HW_EPDC_PIGEON_9_2_RD(x) |  (v)))
#define HW_EPDC_PIGEON_9_2_CLR(x, v) (HW_EPDC_PIGEON_9_2_WR(x, HW_EPDC_PIGEON_9_2_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_9_2_TOG(x, v) (HW_EPDC_PIGEON_9_2_WR(x, HW_EPDC_PIGEON_9_2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_9_2 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_9_2, field SIG_LOGIC[3:0] (RW)
 *
 * logic operation with another signal sigout : final output signal of this
 * generator mask : final mask of this generator this_sig : intermediate signal of
 * this generator before logic operation other_masks : intermediate mask result of
 * this generator before logic operation sig_another : signal selected other
 * generators
 *
 * Values:
 * - 0 - no logic operation
 * - 1 - sigout = sig_another AND this_sig
 * - 10 - sigout = sig_another OR this_sig
 * - 11 - mask = sig_another AND other_masks
 */
/*@{*/
#define BP_EPDC_PIGEON_9_2_SIG_LOGIC (0U)  /*!< Bit position for EPDC_PIGEON_9_2_SIG_LOGIC. */
#define BM_EPDC_PIGEON_9_2_SIG_LOGIC (0x0000000FU) /*!< Bit mask for EPDC_PIGEON_9_2_SIG_LOGIC. */
#define BS_EPDC_PIGEON_9_2_SIG_LOGIC (4U)  /*!< Bit field size in bits for EPDC_PIGEON_9_2_SIG_LOGIC. */

#define BV_EPDC_PIGEON_9_2_SIG_LOGIC_DIS (0U)        /*!< Bit field value for EPDC_PIGEON_9_2_SIG_LOGIC: no logic operation */
#define BV_EPDC_PIGEON_9_2_SIG_LOGIC_AND (0x1U)      /*!< Bit field value for EPDC_PIGEON_9_2_SIG_LOGIC: sigout = sig_another AND this_sig */
#define BV_EPDC_PIGEON_9_2_SIG_LOGIC_OR (0x2U)       /*!< Bit field value for EPDC_PIGEON_9_2_SIG_LOGIC: sigout = sig_another OR this_sig */
#define BV_EPDC_PIGEON_9_2_SIG_LOGIC_MASK (0x3U)     /*!< Bit field value for EPDC_PIGEON_9_2_SIG_LOGIC: mask = sig_another AND other_masks */

/*! @brief Read current value of the EPDC_PIGEON_9_2_SIG_LOGIC field. */
#define BR_EPDC_PIGEON_9_2_SIG_LOGIC(x) (HW_EPDC_PIGEON_9_2(x).B.SIG_LOGIC)

/*! @brief Format value for bitfield EPDC_PIGEON_9_2_SIG_LOGIC. */
#define BF_EPDC_PIGEON_9_2_SIG_LOGIC(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_9_2_SIG_LOGIC) & BM_EPDC_PIGEON_9_2_SIG_LOGIC)

/*! @brief Set the SIG_LOGIC field to a new value. */
#define BW_EPDC_PIGEON_9_2_SIG_LOGIC(x, v) (HW_EPDC_PIGEON_9_2_WR(x, (HW_EPDC_PIGEON_9_2_RD(x) & ~BM_EPDC_PIGEON_9_2_SIG_LOGIC) | BF_EPDC_PIGEON_9_2_SIG_LOGIC(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_9_2, field SIG_ANOTHER[8:4] (RW)
 *
 * select another signal for logic operation or as mask or counter tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_9_2_SIG_ANOTHER (4U) /*!< Bit position for EPDC_PIGEON_9_2_SIG_ANOTHER. */
#define BM_EPDC_PIGEON_9_2_SIG_ANOTHER (0x000001F0U) /*!< Bit mask for EPDC_PIGEON_9_2_SIG_ANOTHER. */
#define BS_EPDC_PIGEON_9_2_SIG_ANOTHER (5U) /*!< Bit field size in bits for EPDC_PIGEON_9_2_SIG_ANOTHER. */

/*! @brief Read current value of the EPDC_PIGEON_9_2_SIG_ANOTHER field. */
#define BR_EPDC_PIGEON_9_2_SIG_ANOTHER(x) (HW_EPDC_PIGEON_9_2(x).B.SIG_ANOTHER)

/*! @brief Format value for bitfield EPDC_PIGEON_9_2_SIG_ANOTHER. */
#define BF_EPDC_PIGEON_9_2_SIG_ANOTHER(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_9_2_SIG_ANOTHER) & BM_EPDC_PIGEON_9_2_SIG_ANOTHER)

/*! @brief Set the SIG_ANOTHER field to a new value. */
#define BW_EPDC_PIGEON_9_2_SIG_ANOTHER(x, v) (HW_EPDC_PIGEON_9_2_WR(x, (HW_EPDC_PIGEON_9_2_RD(x) & ~BM_EPDC_PIGEON_9_2_SIG_ANOTHER) | BF_EPDC_PIGEON_9_2_SIG_ANOTHER(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_10_0 - Panel Interface Signal Generator Register 10_0
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_10_0 - Panel Interface Signal Generator Register 10_0 (RW)
 *
 * Reset value: 0x00000F00U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_10_0
{
    uint32_t U;
    struct _hw_epdc_pigeon_10_0_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t POL : 1;              /*!< [1]  */
        uint32_t INC_SEL : 2;          /*!< [3:2]  */
        uint32_t OFFSET : 4;           /*!< [7:4]  */
        uint32_t MASK_CNT_SEL : 4;     /*!< [11:8]  */
        uint32_t MASK_CNT : 12;        /*!< [23:12]  */
        uint32_t STATE_MASK : 8;       /*!< [31:24]  */
    } B;
} hw_epdc_pigeon_10_0_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_10_0 register
 */
/*@{*/
#define HW_EPDC_PIGEON_10_0_ADDR(x) ((uintptr_t)(x) + 0xA80U)

#define HW_EPDC_PIGEON_10_0(x)   (*(__IO hw_epdc_pigeon_10_0_t *) HW_EPDC_PIGEON_10_0_ADDR(x))
#define HW_EPDC_PIGEON_10_0_RD(x) (HW_EPDC_PIGEON_10_0(x).U)
#define HW_EPDC_PIGEON_10_0_WR(x, v) (HW_EPDC_PIGEON_10_0(x).U = (v))
#define HW_EPDC_PIGEON_10_0_SET(x, v) (HW_EPDC_PIGEON_10_0_WR(x, HW_EPDC_PIGEON_10_0_RD(x) |  (v)))
#define HW_EPDC_PIGEON_10_0_CLR(x, v) (HW_EPDC_PIGEON_10_0_WR(x, HW_EPDC_PIGEON_10_0_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_10_0_TOG(x, v) (HW_EPDC_PIGEON_10_0_WR(x, HW_EPDC_PIGEON_10_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_10_0 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_10_0, field EN[0] (RW)
 *
 * enable pigeon mode on this signal
 */
/*@{*/
#define BP_EPDC_PIGEON_10_0_EN (0U)        /*!< Bit position for EPDC_PIGEON_10_0_EN. */
#define BM_EPDC_PIGEON_10_0_EN (0x00000001U) /*!< Bit mask for EPDC_PIGEON_10_0_EN. */
#define BS_EPDC_PIGEON_10_0_EN (1U)        /*!< Bit field size in bits for EPDC_PIGEON_10_0_EN. */

/*! @brief Read current value of the EPDC_PIGEON_10_0_EN field. */
#define BR_EPDC_PIGEON_10_0_EN(x) (HW_EPDC_PIGEON_10_0(x).B.EN)

/*! @brief Format value for bitfield EPDC_PIGEON_10_0_EN. */
#define BF_EPDC_PIGEON_10_0_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_10_0_EN) & BM_EPDC_PIGEON_10_0_EN)

/*! @brief Set the EN field to a new value. */
#define BW_EPDC_PIGEON_10_0_EN(x, v) (HW_EPDC_PIGEON_10_0_WR(x, (HW_EPDC_PIGEON_10_0_RD(x) & ~BM_EPDC_PIGEON_10_0_EN) | BF_EPDC_PIGEON_10_0_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_10_0, field POL[1] (RW)
 *
 * polarity of signal output
 *
 * Values:
 * - 0 - normal signal (active high)
 * - 1 - inverted signal (active low)
 */
/*@{*/
#define BP_EPDC_PIGEON_10_0_POL (1U)       /*!< Bit position for EPDC_PIGEON_10_0_POL. */
#define BM_EPDC_PIGEON_10_0_POL (0x00000002U) /*!< Bit mask for EPDC_PIGEON_10_0_POL. */
#define BS_EPDC_PIGEON_10_0_POL (1U)       /*!< Bit field size in bits for EPDC_PIGEON_10_0_POL. */

#define BV_EPDC_PIGEON_10_0_POL_ACTIVE_HIGH (0U)     /*!< Bit field value for EPDC_PIGEON_10_0_POL: normal signal (active high) */
#define BV_EPDC_PIGEON_10_0_POL_ACTIVE_LOW (0x1U)    /*!< Bit field value for EPDC_PIGEON_10_0_POL: inverted signal (active low) */

/*! @brief Read current value of the EPDC_PIGEON_10_0_POL field. */
#define BR_EPDC_PIGEON_10_0_POL(x) (HW_EPDC_PIGEON_10_0(x).B.POL)

/*! @brief Format value for bitfield EPDC_PIGEON_10_0_POL. */
#define BF_EPDC_PIGEON_10_0_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_10_0_POL) & BM_EPDC_PIGEON_10_0_POL)

/*! @brief Set the POL field to a new value. */
#define BW_EPDC_PIGEON_10_0_POL(x, v) (HW_EPDC_PIGEON_10_0_WR(x, (HW_EPDC_PIGEON_10_0_RD(x) & ~BM_EPDC_PIGEON_10_0_POL) | BF_EPDC_PIGEON_10_0_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_10_0, field INC_SEL[3:2] (RW)
 *
 * event to incrment local counter
 *
 * Values:
 * - 0 - pclk
 * - 1 - line start pulse
 * - 10 - frame start pulse
 * - 11 - use another signal as tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_10_0_INC_SEL (2U)   /*!< Bit position for EPDC_PIGEON_10_0_INC_SEL. */
#define BM_EPDC_PIGEON_10_0_INC_SEL (0x0000000CU) /*!< Bit mask for EPDC_PIGEON_10_0_INC_SEL. */
#define BS_EPDC_PIGEON_10_0_INC_SEL (2U)   /*!< Bit field size in bits for EPDC_PIGEON_10_0_INC_SEL. */

#define BV_EPDC_PIGEON_10_0_INC_SEL_PCLK (0U)        /*!< Bit field value for EPDC_PIGEON_10_0_INC_SEL: pclk */
#define BV_EPDC_PIGEON_10_0_INC_SEL_LINE (0x1U)      /*!< Bit field value for EPDC_PIGEON_10_0_INC_SEL: line start pulse */
#define BV_EPDC_PIGEON_10_0_INC_SEL_FRAME (0x2U)     /*!< Bit field value for EPDC_PIGEON_10_0_INC_SEL: frame start pulse */
#define BV_EPDC_PIGEON_10_0_INC_SEL_SIG_ANOTHER (0x3U) /*!< Bit field value for EPDC_PIGEON_10_0_INC_SEL: use another signal as tick event */

/*! @brief Read current value of the EPDC_PIGEON_10_0_INC_SEL field. */
#define BR_EPDC_PIGEON_10_0_INC_SEL(x) (HW_EPDC_PIGEON_10_0(x).B.INC_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_10_0_INC_SEL. */
#define BF_EPDC_PIGEON_10_0_INC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_10_0_INC_SEL) & BM_EPDC_PIGEON_10_0_INC_SEL)

/*! @brief Set the INC_SEL field to a new value. */
#define BW_EPDC_PIGEON_10_0_INC_SEL(x, v) (HW_EPDC_PIGEON_10_0_WR(x, (HW_EPDC_PIGEON_10_0_RD(x) & ~BM_EPDC_PIGEON_10_0_INC_SEL) | BF_EPDC_PIGEON_10_0_INC_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_10_0, field OFFSET[7:4] (RW)
 *
 * offset on pclk unit. 0=aligne with data, positive value means delay, minus
 * value mean ahead. Supported range depends on panel mode
 */
/*@{*/
#define BP_EPDC_PIGEON_10_0_OFFSET (4U)    /*!< Bit position for EPDC_PIGEON_10_0_OFFSET. */
#define BM_EPDC_PIGEON_10_0_OFFSET (0x000000F0U) /*!< Bit mask for EPDC_PIGEON_10_0_OFFSET. */
#define BS_EPDC_PIGEON_10_0_OFFSET (4U)    /*!< Bit field size in bits for EPDC_PIGEON_10_0_OFFSET. */

/*! @brief Read current value of the EPDC_PIGEON_10_0_OFFSET field. */
#define BR_EPDC_PIGEON_10_0_OFFSET(x) (HW_EPDC_PIGEON_10_0(x).B.OFFSET)

/*! @brief Format value for bitfield EPDC_PIGEON_10_0_OFFSET. */
#define BF_EPDC_PIGEON_10_0_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_10_0_OFFSET) & BM_EPDC_PIGEON_10_0_OFFSET)

/*! @brief Set the OFFSET field to a new value. */
#define BW_EPDC_PIGEON_10_0_OFFSET(x, v) (HW_EPDC_PIGEON_10_0_WR(x, (HW_EPDC_PIGEON_10_0_RD(x) & ~BM_EPDC_PIGEON_10_0_OFFSET) | BF_EPDC_PIGEON_10_0_OFFSET(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_10_0, field MASK_CNT_SEL[11:8] (RW)
 *
 * select global counters as mask condition, use together with MASK_CNT
 *
 * Values:
 * - 0 - pclk counter within one hscan state
 * - 1 - pclk cycle within one hscan state
 * - 10 - line counter within one vscan state
 * - 11 - line cycle within one vscan state
 * - 100 - frame counter
 * - 101 - frame cycle
 * - 110 - horizontal counter (pclk counter within one line )
 * - 111 - vertical counter (line counter within one frame)
 */
/*@{*/
#define BP_EPDC_PIGEON_10_0_MASK_CNT_SEL (8U) /*!< Bit position for EPDC_PIGEON_10_0_MASK_CNT_SEL. */
#define BM_EPDC_PIGEON_10_0_MASK_CNT_SEL (0x00000F00U) /*!< Bit mask for EPDC_PIGEON_10_0_MASK_CNT_SEL. */
#define BS_EPDC_PIGEON_10_0_MASK_CNT_SEL (4U) /*!< Bit field size in bits for EPDC_PIGEON_10_0_MASK_CNT_SEL. */

#define BV_EPDC_PIGEON_10_0_MASK_CNT_SEL_HSTATE_CNT (0U) /*!< Bit field value for EPDC_PIGEON_10_0_MASK_CNT_SEL: pclk counter within one hscan state */
#define BV_EPDC_PIGEON_10_0_MASK_CNT_SEL_HSTATE_CYCLE (0x1U) /*!< Bit field value for EPDC_PIGEON_10_0_MASK_CNT_SEL: pclk cycle within one hscan state */
#define BV_EPDC_PIGEON_10_0_MASK_CNT_SEL_VSTATE_CNT (0x2U) /*!< Bit field value for EPDC_PIGEON_10_0_MASK_CNT_SEL: line counter within one vscan state */
#define BV_EPDC_PIGEON_10_0_MASK_CNT_SEL_VSTATE_CYCLE (0x3U) /*!< Bit field value for EPDC_PIGEON_10_0_MASK_CNT_SEL: line cycle within one vscan state */
#define BV_EPDC_PIGEON_10_0_MASK_CNT_SEL_FRAME_CNT (0x4U) /*!< Bit field value for EPDC_PIGEON_10_0_MASK_CNT_SEL: frame counter */
#define BV_EPDC_PIGEON_10_0_MASK_CNT_SEL_FRAME_CYCLE (0x5U) /*!< Bit field value for EPDC_PIGEON_10_0_MASK_CNT_SEL: frame cycle */
#define BV_EPDC_PIGEON_10_0_MASK_CNT_SEL_HCNT (0x6U) /*!< Bit field value for EPDC_PIGEON_10_0_MASK_CNT_SEL: horizontal counter (pclk counter within one line ) */
#define BV_EPDC_PIGEON_10_0_MASK_CNT_SEL_VCNT (0x7U) /*!< Bit field value for EPDC_PIGEON_10_0_MASK_CNT_SEL: vertical counter (line counter within one frame) */

/*! @brief Read current value of the EPDC_PIGEON_10_0_MASK_CNT_SEL field. */
#define BR_EPDC_PIGEON_10_0_MASK_CNT_SEL(x) (HW_EPDC_PIGEON_10_0(x).B.MASK_CNT_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_10_0_MASK_CNT_SEL. */
#define BF_EPDC_PIGEON_10_0_MASK_CNT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_10_0_MASK_CNT_SEL) & BM_EPDC_PIGEON_10_0_MASK_CNT_SEL)

/*! @brief Set the MASK_CNT_SEL field to a new value. */
#define BW_EPDC_PIGEON_10_0_MASK_CNT_SEL(x, v) (HW_EPDC_PIGEON_10_0_WR(x, (HW_EPDC_PIGEON_10_0_RD(x) & ~BM_EPDC_PIGEON_10_0_MASK_CNT_SEL) | BF_EPDC_PIGEON_10_0_MASK_CNT_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_10_0, field MASK_CNT[23:12] (RW)
 *
 * When the global counter selected through MASK_CNT_SEL matches value in this
 * reg, pigeon local counter start ticking. 0=disable
 */
/*@{*/
#define BP_EPDC_PIGEON_10_0_MASK_CNT (12U) /*!< Bit position for EPDC_PIGEON_10_0_MASK_CNT. */
#define BM_EPDC_PIGEON_10_0_MASK_CNT (0x00FFF000U) /*!< Bit mask for EPDC_PIGEON_10_0_MASK_CNT. */
#define BS_EPDC_PIGEON_10_0_MASK_CNT (12U) /*!< Bit field size in bits for EPDC_PIGEON_10_0_MASK_CNT. */

/*! @brief Read current value of the EPDC_PIGEON_10_0_MASK_CNT field. */
#define BR_EPDC_PIGEON_10_0_MASK_CNT(x) (HW_EPDC_PIGEON_10_0(x).B.MASK_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_10_0_MASK_CNT. */
#define BF_EPDC_PIGEON_10_0_MASK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_10_0_MASK_CNT) & BM_EPDC_PIGEON_10_0_MASK_CNT)

/*! @brief Set the MASK_CNT field to a new value. */
#define BW_EPDC_PIGEON_10_0_MASK_CNT(x, v) (HW_EPDC_PIGEON_10_0_WR(x, (HW_EPDC_PIGEON_10_0_RD(x) & ~BM_EPDC_PIGEON_10_0_MASK_CNT) | BF_EPDC_PIGEON_10_0_MASK_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_10_0, field STATE_MASK[31:24] (RW)
 *
 * state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan
 * states as reference point for local counter to start ticking
 *
 * Values:
 * - 1 - FRAME SYNC
 * - 10 - FRAME BEGIN
 * - 100 - FRAME DATA
 * - 1000 - FRAME END
 * - 10000 - LINE SYNC
 * - 100000 - LINE BEGIN
 * - 1000000 - LINE DATA
 * - 10000000 - LINE END
 */
/*@{*/
#define BP_EPDC_PIGEON_10_0_STATE_MASK (24U) /*!< Bit position for EPDC_PIGEON_10_0_STATE_MASK. */
#define BM_EPDC_PIGEON_10_0_STATE_MASK (0xFF000000U) /*!< Bit mask for EPDC_PIGEON_10_0_STATE_MASK. */
#define BS_EPDC_PIGEON_10_0_STATE_MASK (8U) /*!< Bit field size in bits for EPDC_PIGEON_10_0_STATE_MASK. */

#define BV_EPDC_PIGEON_10_0_STATE_MASK_FS (0x1U)     /*!< Bit field value for EPDC_PIGEON_10_0_STATE_MASK: FRAME SYNC */
#define BV_EPDC_PIGEON_10_0_STATE_MASK_FB (0x2U)     /*!< Bit field value for EPDC_PIGEON_10_0_STATE_MASK: FRAME BEGIN */
#define BV_EPDC_PIGEON_10_0_STATE_MASK_FD (0x4U)     /*!< Bit field value for EPDC_PIGEON_10_0_STATE_MASK: FRAME DATA */
#define BV_EPDC_PIGEON_10_0_STATE_MASK_FE (0x8U)     /*!< Bit field value for EPDC_PIGEON_10_0_STATE_MASK: FRAME END */
#define BV_EPDC_PIGEON_10_0_STATE_MASK_LS (0x10U)    /*!< Bit field value for EPDC_PIGEON_10_0_STATE_MASK: LINE SYNC */
#define BV_EPDC_PIGEON_10_0_STATE_MASK_LB (0x20U)    /*!< Bit field value for EPDC_PIGEON_10_0_STATE_MASK: LINE BEGIN */
#define BV_EPDC_PIGEON_10_0_STATE_MASK_LD (0x40U)    /*!< Bit field value for EPDC_PIGEON_10_0_STATE_MASK: LINE DATA */
#define BV_EPDC_PIGEON_10_0_STATE_MASK_LE (0x80U)    /*!< Bit field value for EPDC_PIGEON_10_0_STATE_MASK: LINE END */

/*! @brief Read current value of the EPDC_PIGEON_10_0_STATE_MASK field. */
#define BR_EPDC_PIGEON_10_0_STATE_MASK(x) (HW_EPDC_PIGEON_10_0(x).B.STATE_MASK)

/*! @brief Format value for bitfield EPDC_PIGEON_10_0_STATE_MASK. */
#define BF_EPDC_PIGEON_10_0_STATE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_10_0_STATE_MASK) & BM_EPDC_PIGEON_10_0_STATE_MASK)

/*! @brief Set the STATE_MASK field to a new value. */
#define BW_EPDC_PIGEON_10_0_STATE_MASK(x, v) (HW_EPDC_PIGEON_10_0_WR(x, (HW_EPDC_PIGEON_10_0_RD(x) & ~BM_EPDC_PIGEON_10_0_STATE_MASK) | BF_EPDC_PIGEON_10_0_STATE_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_10_1 - Panel Interface Signal Generator Register 10_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_10_1 - Panel Interface Signal Generator Register 10_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_10_1
{
    uint32_t U;
    struct _hw_epdc_pigeon_10_1_bitfields
    {
        uint32_t SET_CNT : 16;         /*!< [15:0]  */
        uint32_t CLR_CNT : 16;         /*!< [31:16]  */
    } B;
} hw_epdc_pigeon_10_1_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_10_1 register
 */
/*@{*/
#define HW_EPDC_PIGEON_10_1_ADDR(x) ((uintptr_t)(x) + 0xA90U)

#define HW_EPDC_PIGEON_10_1(x)   (*(__IO hw_epdc_pigeon_10_1_t *) HW_EPDC_PIGEON_10_1_ADDR(x))
#define HW_EPDC_PIGEON_10_1_RD(x) (HW_EPDC_PIGEON_10_1(x).U)
#define HW_EPDC_PIGEON_10_1_WR(x, v) (HW_EPDC_PIGEON_10_1(x).U = (v))
#define HW_EPDC_PIGEON_10_1_SET(x, v) (HW_EPDC_PIGEON_10_1_WR(x, HW_EPDC_PIGEON_10_1_RD(x) |  (v)))
#define HW_EPDC_PIGEON_10_1_CLR(x, v) (HW_EPDC_PIGEON_10_1_WR(x, HW_EPDC_PIGEON_10_1_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_10_1_TOG(x, v) (HW_EPDC_PIGEON_10_1_WR(x, HW_EPDC_PIGEON_10_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_10_1 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_10_1, field SET_CNT[15:0] (RW)
 *
 * assert signal output when counter match this value
 *
 * Values:
 * - 0 - start as active
 */
/*@{*/
#define BP_EPDC_PIGEON_10_1_SET_CNT (0U)   /*!< Bit position for EPDC_PIGEON_10_1_SET_CNT. */
#define BM_EPDC_PIGEON_10_1_SET_CNT (0x0000FFFFU) /*!< Bit mask for EPDC_PIGEON_10_1_SET_CNT. */
#define BS_EPDC_PIGEON_10_1_SET_CNT (16U)  /*!< Bit field size in bits for EPDC_PIGEON_10_1_SET_CNT. */

#define BV_EPDC_PIGEON_10_1_SET_CNT_START_ACTIVE (0U) /*!< Bit field value for EPDC_PIGEON_10_1_SET_CNT: start as active */

/*! @brief Read current value of the EPDC_PIGEON_10_1_SET_CNT field. */
#define BR_EPDC_PIGEON_10_1_SET_CNT(x) (HW_EPDC_PIGEON_10_1(x).B.SET_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_10_1_SET_CNT. */
#define BF_EPDC_PIGEON_10_1_SET_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_10_1_SET_CNT) & BM_EPDC_PIGEON_10_1_SET_CNT)

/*! @brief Set the SET_CNT field to a new value. */
#define BW_EPDC_PIGEON_10_1_SET_CNT(x, v) (HW_EPDC_PIGEON_10_1_WR(x, (HW_EPDC_PIGEON_10_1_RD(x) & ~BM_EPDC_PIGEON_10_1_SET_CNT) | BF_EPDC_PIGEON_10_1_SET_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_10_1, field CLR_CNT[31:16] (RW)
 *
 * deassert signal output when counter match this value
 *
 * Values:
 * - 0 - keep active until mask off
 */
/*@{*/
#define BP_EPDC_PIGEON_10_1_CLR_CNT (16U)  /*!< Bit position for EPDC_PIGEON_10_1_CLR_CNT. */
#define BM_EPDC_PIGEON_10_1_CLR_CNT (0xFFFF0000U) /*!< Bit mask for EPDC_PIGEON_10_1_CLR_CNT. */
#define BS_EPDC_PIGEON_10_1_CLR_CNT (16U)  /*!< Bit field size in bits for EPDC_PIGEON_10_1_CLR_CNT. */

#define BV_EPDC_PIGEON_10_1_CLR_CNT_CLEAR_USING_MASK (0U) /*!< Bit field value for EPDC_PIGEON_10_1_CLR_CNT: keep active until mask off */

/*! @brief Read current value of the EPDC_PIGEON_10_1_CLR_CNT field. */
#define BR_EPDC_PIGEON_10_1_CLR_CNT(x) (HW_EPDC_PIGEON_10_1(x).B.CLR_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_10_1_CLR_CNT. */
#define BF_EPDC_PIGEON_10_1_CLR_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_10_1_CLR_CNT) & BM_EPDC_PIGEON_10_1_CLR_CNT)

/*! @brief Set the CLR_CNT field to a new value. */
#define BW_EPDC_PIGEON_10_1_CLR_CNT(x, v) (HW_EPDC_PIGEON_10_1_WR(x, (HW_EPDC_PIGEON_10_1_RD(x) & ~BM_EPDC_PIGEON_10_1_CLR_CNT) | BF_EPDC_PIGEON_10_1_CLR_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_10_2 - Panel Interface Signal Generator Register 10_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_10_2 - Panel Interface Signal Generator Register 10_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_10_2
{
    uint32_t U;
    struct _hw_epdc_pigeon_10_2_bitfields
    {
        uint32_t SIG_LOGIC : 4;        /*!< [3:0]  */
        uint32_t SIG_ANOTHER : 5;      /*!< [8:4]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_epdc_pigeon_10_2_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_10_2 register
 */
/*@{*/
#define HW_EPDC_PIGEON_10_2_ADDR(x) ((uintptr_t)(x) + 0xAA0U)

#define HW_EPDC_PIGEON_10_2(x)   (*(__IO hw_epdc_pigeon_10_2_t *) HW_EPDC_PIGEON_10_2_ADDR(x))
#define HW_EPDC_PIGEON_10_2_RD(x) (HW_EPDC_PIGEON_10_2(x).U)
#define HW_EPDC_PIGEON_10_2_WR(x, v) (HW_EPDC_PIGEON_10_2(x).U = (v))
#define HW_EPDC_PIGEON_10_2_SET(x, v) (HW_EPDC_PIGEON_10_2_WR(x, HW_EPDC_PIGEON_10_2_RD(x) |  (v)))
#define HW_EPDC_PIGEON_10_2_CLR(x, v) (HW_EPDC_PIGEON_10_2_WR(x, HW_EPDC_PIGEON_10_2_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_10_2_TOG(x, v) (HW_EPDC_PIGEON_10_2_WR(x, HW_EPDC_PIGEON_10_2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_10_2 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_10_2, field SIG_LOGIC[3:0] (RW)
 *
 * logic operation with another signal sigout : final output signal of this
 * generator mask : final mask of this generator this_sig : intermediate signal of
 * this generator before logic operation other_masks : intermediate mask result of
 * this generator before logic operation sig_another : signal selected other
 * generators
 *
 * Values:
 * - 0 - no logic operation
 * - 1 - sigout = sig_another AND this_sig
 * - 10 - sigout = sig_another OR this_sig
 * - 11 - mask = sig_another AND other_masks
 */
/*@{*/
#define BP_EPDC_PIGEON_10_2_SIG_LOGIC (0U) /*!< Bit position for EPDC_PIGEON_10_2_SIG_LOGIC. */
#define BM_EPDC_PIGEON_10_2_SIG_LOGIC (0x0000000FU) /*!< Bit mask for EPDC_PIGEON_10_2_SIG_LOGIC. */
#define BS_EPDC_PIGEON_10_2_SIG_LOGIC (4U) /*!< Bit field size in bits for EPDC_PIGEON_10_2_SIG_LOGIC. */

#define BV_EPDC_PIGEON_10_2_SIG_LOGIC_DIS (0U)       /*!< Bit field value for EPDC_PIGEON_10_2_SIG_LOGIC: no logic operation */
#define BV_EPDC_PIGEON_10_2_SIG_LOGIC_AND (0x1U)     /*!< Bit field value for EPDC_PIGEON_10_2_SIG_LOGIC: sigout = sig_another AND this_sig */
#define BV_EPDC_PIGEON_10_2_SIG_LOGIC_OR (0x2U)      /*!< Bit field value for EPDC_PIGEON_10_2_SIG_LOGIC: sigout = sig_another OR this_sig */
#define BV_EPDC_PIGEON_10_2_SIG_LOGIC_MASK (0x3U)    /*!< Bit field value for EPDC_PIGEON_10_2_SIG_LOGIC: mask = sig_another AND other_masks */

/*! @brief Read current value of the EPDC_PIGEON_10_2_SIG_LOGIC field. */
#define BR_EPDC_PIGEON_10_2_SIG_LOGIC(x) (HW_EPDC_PIGEON_10_2(x).B.SIG_LOGIC)

/*! @brief Format value for bitfield EPDC_PIGEON_10_2_SIG_LOGIC. */
#define BF_EPDC_PIGEON_10_2_SIG_LOGIC(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_10_2_SIG_LOGIC) & BM_EPDC_PIGEON_10_2_SIG_LOGIC)

/*! @brief Set the SIG_LOGIC field to a new value. */
#define BW_EPDC_PIGEON_10_2_SIG_LOGIC(x, v) (HW_EPDC_PIGEON_10_2_WR(x, (HW_EPDC_PIGEON_10_2_RD(x) & ~BM_EPDC_PIGEON_10_2_SIG_LOGIC) | BF_EPDC_PIGEON_10_2_SIG_LOGIC(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_10_2, field SIG_ANOTHER[8:4] (RW)
 *
 * select another signal for logic operation or as mask or counter tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_10_2_SIG_ANOTHER (4U) /*!< Bit position for EPDC_PIGEON_10_2_SIG_ANOTHER. */
#define BM_EPDC_PIGEON_10_2_SIG_ANOTHER (0x000001F0U) /*!< Bit mask for EPDC_PIGEON_10_2_SIG_ANOTHER. */
#define BS_EPDC_PIGEON_10_2_SIG_ANOTHER (5U) /*!< Bit field size in bits for EPDC_PIGEON_10_2_SIG_ANOTHER. */

/*! @brief Read current value of the EPDC_PIGEON_10_2_SIG_ANOTHER field. */
#define BR_EPDC_PIGEON_10_2_SIG_ANOTHER(x) (HW_EPDC_PIGEON_10_2(x).B.SIG_ANOTHER)

/*! @brief Format value for bitfield EPDC_PIGEON_10_2_SIG_ANOTHER. */
#define BF_EPDC_PIGEON_10_2_SIG_ANOTHER(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_10_2_SIG_ANOTHER) & BM_EPDC_PIGEON_10_2_SIG_ANOTHER)

/*! @brief Set the SIG_ANOTHER field to a new value. */
#define BW_EPDC_PIGEON_10_2_SIG_ANOTHER(x, v) (HW_EPDC_PIGEON_10_2_WR(x, (HW_EPDC_PIGEON_10_2_RD(x) & ~BM_EPDC_PIGEON_10_2_SIG_ANOTHER) | BF_EPDC_PIGEON_10_2_SIG_ANOTHER(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_11_0 - Panel Interface Signal Generator Register 11_0
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_11_0 - Panel Interface Signal Generator Register 11_0 (RW)
 *
 * Reset value: 0x00000F00U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_11_0
{
    uint32_t U;
    struct _hw_epdc_pigeon_11_0_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t POL : 1;              /*!< [1]  */
        uint32_t INC_SEL : 2;          /*!< [3:2]  */
        uint32_t OFFSET : 4;           /*!< [7:4]  */
        uint32_t MASK_CNT_SEL : 4;     /*!< [11:8]  */
        uint32_t MASK_CNT : 12;        /*!< [23:12]  */
        uint32_t STATE_MASK : 8;       /*!< [31:24]  */
    } B;
} hw_epdc_pigeon_11_0_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_11_0 register
 */
/*@{*/
#define HW_EPDC_PIGEON_11_0_ADDR(x) ((uintptr_t)(x) + 0xAC0U)

#define HW_EPDC_PIGEON_11_0(x)   (*(__IO hw_epdc_pigeon_11_0_t *) HW_EPDC_PIGEON_11_0_ADDR(x))
#define HW_EPDC_PIGEON_11_0_RD(x) (HW_EPDC_PIGEON_11_0(x).U)
#define HW_EPDC_PIGEON_11_0_WR(x, v) (HW_EPDC_PIGEON_11_0(x).U = (v))
#define HW_EPDC_PIGEON_11_0_SET(x, v) (HW_EPDC_PIGEON_11_0_WR(x, HW_EPDC_PIGEON_11_0_RD(x) |  (v)))
#define HW_EPDC_PIGEON_11_0_CLR(x, v) (HW_EPDC_PIGEON_11_0_WR(x, HW_EPDC_PIGEON_11_0_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_11_0_TOG(x, v) (HW_EPDC_PIGEON_11_0_WR(x, HW_EPDC_PIGEON_11_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_11_0 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_11_0, field EN[0] (RW)
 *
 * enable pigeon mode on this signal
 */
/*@{*/
#define BP_EPDC_PIGEON_11_0_EN (0U)        /*!< Bit position for EPDC_PIGEON_11_0_EN. */
#define BM_EPDC_PIGEON_11_0_EN (0x00000001U) /*!< Bit mask for EPDC_PIGEON_11_0_EN. */
#define BS_EPDC_PIGEON_11_0_EN (1U)        /*!< Bit field size in bits for EPDC_PIGEON_11_0_EN. */

/*! @brief Read current value of the EPDC_PIGEON_11_0_EN field. */
#define BR_EPDC_PIGEON_11_0_EN(x) (HW_EPDC_PIGEON_11_0(x).B.EN)

/*! @brief Format value for bitfield EPDC_PIGEON_11_0_EN. */
#define BF_EPDC_PIGEON_11_0_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_11_0_EN) & BM_EPDC_PIGEON_11_0_EN)

/*! @brief Set the EN field to a new value. */
#define BW_EPDC_PIGEON_11_0_EN(x, v) (HW_EPDC_PIGEON_11_0_WR(x, (HW_EPDC_PIGEON_11_0_RD(x) & ~BM_EPDC_PIGEON_11_0_EN) | BF_EPDC_PIGEON_11_0_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_11_0, field POL[1] (RW)
 *
 * polarity of signal output
 *
 * Values:
 * - 0 - normal signal (active high)
 * - 1 - inverted signal (active low)
 */
/*@{*/
#define BP_EPDC_PIGEON_11_0_POL (1U)       /*!< Bit position for EPDC_PIGEON_11_0_POL. */
#define BM_EPDC_PIGEON_11_0_POL (0x00000002U) /*!< Bit mask for EPDC_PIGEON_11_0_POL. */
#define BS_EPDC_PIGEON_11_0_POL (1U)       /*!< Bit field size in bits for EPDC_PIGEON_11_0_POL. */

#define BV_EPDC_PIGEON_11_0_POL_ACTIVE_HIGH (0U)     /*!< Bit field value for EPDC_PIGEON_11_0_POL: normal signal (active high) */
#define BV_EPDC_PIGEON_11_0_POL_ACTIVE_LOW (0x1U)    /*!< Bit field value for EPDC_PIGEON_11_0_POL: inverted signal (active low) */

/*! @brief Read current value of the EPDC_PIGEON_11_0_POL field. */
#define BR_EPDC_PIGEON_11_0_POL(x) (HW_EPDC_PIGEON_11_0(x).B.POL)

/*! @brief Format value for bitfield EPDC_PIGEON_11_0_POL. */
#define BF_EPDC_PIGEON_11_0_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_11_0_POL) & BM_EPDC_PIGEON_11_0_POL)

/*! @brief Set the POL field to a new value. */
#define BW_EPDC_PIGEON_11_0_POL(x, v) (HW_EPDC_PIGEON_11_0_WR(x, (HW_EPDC_PIGEON_11_0_RD(x) & ~BM_EPDC_PIGEON_11_0_POL) | BF_EPDC_PIGEON_11_0_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_11_0, field INC_SEL[3:2] (RW)
 *
 * event to incrment local counter
 *
 * Values:
 * - 0 - pclk
 * - 1 - line start pulse
 * - 10 - frame start pulse
 * - 11 - use another signal as tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_11_0_INC_SEL (2U)   /*!< Bit position for EPDC_PIGEON_11_0_INC_SEL. */
#define BM_EPDC_PIGEON_11_0_INC_SEL (0x0000000CU) /*!< Bit mask for EPDC_PIGEON_11_0_INC_SEL. */
#define BS_EPDC_PIGEON_11_0_INC_SEL (2U)   /*!< Bit field size in bits for EPDC_PIGEON_11_0_INC_SEL. */

#define BV_EPDC_PIGEON_11_0_INC_SEL_PCLK (0U)        /*!< Bit field value for EPDC_PIGEON_11_0_INC_SEL: pclk */
#define BV_EPDC_PIGEON_11_0_INC_SEL_LINE (0x1U)      /*!< Bit field value for EPDC_PIGEON_11_0_INC_SEL: line start pulse */
#define BV_EPDC_PIGEON_11_0_INC_SEL_FRAME (0x2U)     /*!< Bit field value for EPDC_PIGEON_11_0_INC_SEL: frame start pulse */
#define BV_EPDC_PIGEON_11_0_INC_SEL_SIG_ANOTHER (0x3U) /*!< Bit field value for EPDC_PIGEON_11_0_INC_SEL: use another signal as tick event */

/*! @brief Read current value of the EPDC_PIGEON_11_0_INC_SEL field. */
#define BR_EPDC_PIGEON_11_0_INC_SEL(x) (HW_EPDC_PIGEON_11_0(x).B.INC_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_11_0_INC_SEL. */
#define BF_EPDC_PIGEON_11_0_INC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_11_0_INC_SEL) & BM_EPDC_PIGEON_11_0_INC_SEL)

/*! @brief Set the INC_SEL field to a new value. */
#define BW_EPDC_PIGEON_11_0_INC_SEL(x, v) (HW_EPDC_PIGEON_11_0_WR(x, (HW_EPDC_PIGEON_11_0_RD(x) & ~BM_EPDC_PIGEON_11_0_INC_SEL) | BF_EPDC_PIGEON_11_0_INC_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_11_0, field OFFSET[7:4] (RW)
 *
 * offset on pclk unit. 0=aligne with data, positive value means delay, minus
 * value mean ahead. Supported range depends on panel mode
 */
/*@{*/
#define BP_EPDC_PIGEON_11_0_OFFSET (4U)    /*!< Bit position for EPDC_PIGEON_11_0_OFFSET. */
#define BM_EPDC_PIGEON_11_0_OFFSET (0x000000F0U) /*!< Bit mask for EPDC_PIGEON_11_0_OFFSET. */
#define BS_EPDC_PIGEON_11_0_OFFSET (4U)    /*!< Bit field size in bits for EPDC_PIGEON_11_0_OFFSET. */

/*! @brief Read current value of the EPDC_PIGEON_11_0_OFFSET field. */
#define BR_EPDC_PIGEON_11_0_OFFSET(x) (HW_EPDC_PIGEON_11_0(x).B.OFFSET)

/*! @brief Format value for bitfield EPDC_PIGEON_11_0_OFFSET. */
#define BF_EPDC_PIGEON_11_0_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_11_0_OFFSET) & BM_EPDC_PIGEON_11_0_OFFSET)

/*! @brief Set the OFFSET field to a new value. */
#define BW_EPDC_PIGEON_11_0_OFFSET(x, v) (HW_EPDC_PIGEON_11_0_WR(x, (HW_EPDC_PIGEON_11_0_RD(x) & ~BM_EPDC_PIGEON_11_0_OFFSET) | BF_EPDC_PIGEON_11_0_OFFSET(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_11_0, field MASK_CNT_SEL[11:8] (RW)
 *
 * select global counters as mask condition, use together with MASK_CNT
 *
 * Values:
 * - 0 - pclk counter within one hscan state
 * - 1 - pclk cycle within one hscan state
 * - 10 - line counter within one vscan state
 * - 11 - line cycle within one vscan state
 * - 100 - frame counter
 * - 101 - frame cycle
 * - 110 - horizontal counter (pclk counter within one line )
 * - 111 - vertical counter (line counter within one frame)
 */
/*@{*/
#define BP_EPDC_PIGEON_11_0_MASK_CNT_SEL (8U) /*!< Bit position for EPDC_PIGEON_11_0_MASK_CNT_SEL. */
#define BM_EPDC_PIGEON_11_0_MASK_CNT_SEL (0x00000F00U) /*!< Bit mask for EPDC_PIGEON_11_0_MASK_CNT_SEL. */
#define BS_EPDC_PIGEON_11_0_MASK_CNT_SEL (4U) /*!< Bit field size in bits for EPDC_PIGEON_11_0_MASK_CNT_SEL. */

#define BV_EPDC_PIGEON_11_0_MASK_CNT_SEL_HSTATE_CNT (0U) /*!< Bit field value for EPDC_PIGEON_11_0_MASK_CNT_SEL: pclk counter within one hscan state */
#define BV_EPDC_PIGEON_11_0_MASK_CNT_SEL_HSTATE_CYCLE (0x1U) /*!< Bit field value for EPDC_PIGEON_11_0_MASK_CNT_SEL: pclk cycle within one hscan state */
#define BV_EPDC_PIGEON_11_0_MASK_CNT_SEL_VSTATE_CNT (0x2U) /*!< Bit field value for EPDC_PIGEON_11_0_MASK_CNT_SEL: line counter within one vscan state */
#define BV_EPDC_PIGEON_11_0_MASK_CNT_SEL_VSTATE_CYCLE (0x3U) /*!< Bit field value for EPDC_PIGEON_11_0_MASK_CNT_SEL: line cycle within one vscan state */
#define BV_EPDC_PIGEON_11_0_MASK_CNT_SEL_FRAME_CNT (0x4U) /*!< Bit field value for EPDC_PIGEON_11_0_MASK_CNT_SEL: frame counter */
#define BV_EPDC_PIGEON_11_0_MASK_CNT_SEL_FRAME_CYCLE (0x5U) /*!< Bit field value for EPDC_PIGEON_11_0_MASK_CNT_SEL: frame cycle */
#define BV_EPDC_PIGEON_11_0_MASK_CNT_SEL_HCNT (0x6U) /*!< Bit field value for EPDC_PIGEON_11_0_MASK_CNT_SEL: horizontal counter (pclk counter within one line ) */
#define BV_EPDC_PIGEON_11_0_MASK_CNT_SEL_VCNT (0x7U) /*!< Bit field value for EPDC_PIGEON_11_0_MASK_CNT_SEL: vertical counter (line counter within one frame) */

/*! @brief Read current value of the EPDC_PIGEON_11_0_MASK_CNT_SEL field. */
#define BR_EPDC_PIGEON_11_0_MASK_CNT_SEL(x) (HW_EPDC_PIGEON_11_0(x).B.MASK_CNT_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_11_0_MASK_CNT_SEL. */
#define BF_EPDC_PIGEON_11_0_MASK_CNT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_11_0_MASK_CNT_SEL) & BM_EPDC_PIGEON_11_0_MASK_CNT_SEL)

/*! @brief Set the MASK_CNT_SEL field to a new value. */
#define BW_EPDC_PIGEON_11_0_MASK_CNT_SEL(x, v) (HW_EPDC_PIGEON_11_0_WR(x, (HW_EPDC_PIGEON_11_0_RD(x) & ~BM_EPDC_PIGEON_11_0_MASK_CNT_SEL) | BF_EPDC_PIGEON_11_0_MASK_CNT_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_11_0, field MASK_CNT[23:12] (RW)
 *
 * When the global counter selected through MASK_CNT_SEL matches value in this
 * reg, pigeon local counter start ticking. 0=disable
 */
/*@{*/
#define BP_EPDC_PIGEON_11_0_MASK_CNT (12U) /*!< Bit position for EPDC_PIGEON_11_0_MASK_CNT. */
#define BM_EPDC_PIGEON_11_0_MASK_CNT (0x00FFF000U) /*!< Bit mask for EPDC_PIGEON_11_0_MASK_CNT. */
#define BS_EPDC_PIGEON_11_0_MASK_CNT (12U) /*!< Bit field size in bits for EPDC_PIGEON_11_0_MASK_CNT. */

/*! @brief Read current value of the EPDC_PIGEON_11_0_MASK_CNT field. */
#define BR_EPDC_PIGEON_11_0_MASK_CNT(x) (HW_EPDC_PIGEON_11_0(x).B.MASK_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_11_0_MASK_CNT. */
#define BF_EPDC_PIGEON_11_0_MASK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_11_0_MASK_CNT) & BM_EPDC_PIGEON_11_0_MASK_CNT)

/*! @brief Set the MASK_CNT field to a new value. */
#define BW_EPDC_PIGEON_11_0_MASK_CNT(x, v) (HW_EPDC_PIGEON_11_0_WR(x, (HW_EPDC_PIGEON_11_0_RD(x) & ~BM_EPDC_PIGEON_11_0_MASK_CNT) | BF_EPDC_PIGEON_11_0_MASK_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_11_0, field STATE_MASK[31:24] (RW)
 *
 * state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan
 * states as reference point for local counter to start ticking
 *
 * Values:
 * - 1 - FRAME SYNC
 * - 10 - FRAME BEGIN
 * - 100 - FRAME DATA
 * - 1000 - FRAME END
 * - 10000 - LINE SYNC
 * - 100000 - LINE BEGIN
 * - 1000000 - LINE DATA
 * - 10000000 - LINE END
 */
/*@{*/
#define BP_EPDC_PIGEON_11_0_STATE_MASK (24U) /*!< Bit position for EPDC_PIGEON_11_0_STATE_MASK. */
#define BM_EPDC_PIGEON_11_0_STATE_MASK (0xFF000000U) /*!< Bit mask for EPDC_PIGEON_11_0_STATE_MASK. */
#define BS_EPDC_PIGEON_11_0_STATE_MASK (8U) /*!< Bit field size in bits for EPDC_PIGEON_11_0_STATE_MASK. */

#define BV_EPDC_PIGEON_11_0_STATE_MASK_FS (0x1U)     /*!< Bit field value for EPDC_PIGEON_11_0_STATE_MASK: FRAME SYNC */
#define BV_EPDC_PIGEON_11_0_STATE_MASK_FB (0x2U)     /*!< Bit field value for EPDC_PIGEON_11_0_STATE_MASK: FRAME BEGIN */
#define BV_EPDC_PIGEON_11_0_STATE_MASK_FD (0x4U)     /*!< Bit field value for EPDC_PIGEON_11_0_STATE_MASK: FRAME DATA */
#define BV_EPDC_PIGEON_11_0_STATE_MASK_FE (0x8U)     /*!< Bit field value for EPDC_PIGEON_11_0_STATE_MASK: FRAME END */
#define BV_EPDC_PIGEON_11_0_STATE_MASK_LS (0x10U)    /*!< Bit field value for EPDC_PIGEON_11_0_STATE_MASK: LINE SYNC */
#define BV_EPDC_PIGEON_11_0_STATE_MASK_LB (0x20U)    /*!< Bit field value for EPDC_PIGEON_11_0_STATE_MASK: LINE BEGIN */
#define BV_EPDC_PIGEON_11_0_STATE_MASK_LD (0x40U)    /*!< Bit field value for EPDC_PIGEON_11_0_STATE_MASK: LINE DATA */
#define BV_EPDC_PIGEON_11_0_STATE_MASK_LE (0x80U)    /*!< Bit field value for EPDC_PIGEON_11_0_STATE_MASK: LINE END */

/*! @brief Read current value of the EPDC_PIGEON_11_0_STATE_MASK field. */
#define BR_EPDC_PIGEON_11_0_STATE_MASK(x) (HW_EPDC_PIGEON_11_0(x).B.STATE_MASK)

/*! @brief Format value for bitfield EPDC_PIGEON_11_0_STATE_MASK. */
#define BF_EPDC_PIGEON_11_0_STATE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_11_0_STATE_MASK) & BM_EPDC_PIGEON_11_0_STATE_MASK)

/*! @brief Set the STATE_MASK field to a new value. */
#define BW_EPDC_PIGEON_11_0_STATE_MASK(x, v) (HW_EPDC_PIGEON_11_0_WR(x, (HW_EPDC_PIGEON_11_0_RD(x) & ~BM_EPDC_PIGEON_11_0_STATE_MASK) | BF_EPDC_PIGEON_11_0_STATE_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_11_1 - Panel Interface Signal Generator Register 11_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_11_1 - Panel Interface Signal Generator Register 11_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_11_1
{
    uint32_t U;
    struct _hw_epdc_pigeon_11_1_bitfields
    {
        uint32_t SET_CNT : 16;         /*!< [15:0]  */
        uint32_t CLR_CNT : 16;         /*!< [31:16]  */
    } B;
} hw_epdc_pigeon_11_1_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_11_1 register
 */
/*@{*/
#define HW_EPDC_PIGEON_11_1_ADDR(x) ((uintptr_t)(x) + 0xAD0U)

#define HW_EPDC_PIGEON_11_1(x)   (*(__IO hw_epdc_pigeon_11_1_t *) HW_EPDC_PIGEON_11_1_ADDR(x))
#define HW_EPDC_PIGEON_11_1_RD(x) (HW_EPDC_PIGEON_11_1(x).U)
#define HW_EPDC_PIGEON_11_1_WR(x, v) (HW_EPDC_PIGEON_11_1(x).U = (v))
#define HW_EPDC_PIGEON_11_1_SET(x, v) (HW_EPDC_PIGEON_11_1_WR(x, HW_EPDC_PIGEON_11_1_RD(x) |  (v)))
#define HW_EPDC_PIGEON_11_1_CLR(x, v) (HW_EPDC_PIGEON_11_1_WR(x, HW_EPDC_PIGEON_11_1_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_11_1_TOG(x, v) (HW_EPDC_PIGEON_11_1_WR(x, HW_EPDC_PIGEON_11_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_11_1 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_11_1, field SET_CNT[15:0] (RW)
 *
 * assert signal output when counter match this value
 *
 * Values:
 * - 0 - start as active
 */
/*@{*/
#define BP_EPDC_PIGEON_11_1_SET_CNT (0U)   /*!< Bit position for EPDC_PIGEON_11_1_SET_CNT. */
#define BM_EPDC_PIGEON_11_1_SET_CNT (0x0000FFFFU) /*!< Bit mask for EPDC_PIGEON_11_1_SET_CNT. */
#define BS_EPDC_PIGEON_11_1_SET_CNT (16U)  /*!< Bit field size in bits for EPDC_PIGEON_11_1_SET_CNT. */

#define BV_EPDC_PIGEON_11_1_SET_CNT_START_ACTIVE (0U) /*!< Bit field value for EPDC_PIGEON_11_1_SET_CNT: start as active */

/*! @brief Read current value of the EPDC_PIGEON_11_1_SET_CNT field. */
#define BR_EPDC_PIGEON_11_1_SET_CNT(x) (HW_EPDC_PIGEON_11_1(x).B.SET_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_11_1_SET_CNT. */
#define BF_EPDC_PIGEON_11_1_SET_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_11_1_SET_CNT) & BM_EPDC_PIGEON_11_1_SET_CNT)

/*! @brief Set the SET_CNT field to a new value. */
#define BW_EPDC_PIGEON_11_1_SET_CNT(x, v) (HW_EPDC_PIGEON_11_1_WR(x, (HW_EPDC_PIGEON_11_1_RD(x) & ~BM_EPDC_PIGEON_11_1_SET_CNT) | BF_EPDC_PIGEON_11_1_SET_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_11_1, field CLR_CNT[31:16] (RW)
 *
 * deassert signal output when counter match this value
 *
 * Values:
 * - 0 - keep active until mask off
 */
/*@{*/
#define BP_EPDC_PIGEON_11_1_CLR_CNT (16U)  /*!< Bit position for EPDC_PIGEON_11_1_CLR_CNT. */
#define BM_EPDC_PIGEON_11_1_CLR_CNT (0xFFFF0000U) /*!< Bit mask for EPDC_PIGEON_11_1_CLR_CNT. */
#define BS_EPDC_PIGEON_11_1_CLR_CNT (16U)  /*!< Bit field size in bits for EPDC_PIGEON_11_1_CLR_CNT. */

#define BV_EPDC_PIGEON_11_1_CLR_CNT_CLEAR_USING_MASK (0U) /*!< Bit field value for EPDC_PIGEON_11_1_CLR_CNT: keep active until mask off */

/*! @brief Read current value of the EPDC_PIGEON_11_1_CLR_CNT field. */
#define BR_EPDC_PIGEON_11_1_CLR_CNT(x) (HW_EPDC_PIGEON_11_1(x).B.CLR_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_11_1_CLR_CNT. */
#define BF_EPDC_PIGEON_11_1_CLR_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_11_1_CLR_CNT) & BM_EPDC_PIGEON_11_1_CLR_CNT)

/*! @brief Set the CLR_CNT field to a new value. */
#define BW_EPDC_PIGEON_11_1_CLR_CNT(x, v) (HW_EPDC_PIGEON_11_1_WR(x, (HW_EPDC_PIGEON_11_1_RD(x) & ~BM_EPDC_PIGEON_11_1_CLR_CNT) | BF_EPDC_PIGEON_11_1_CLR_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_11_2 - Panel Interface Signal Generator Register 11_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_11_2 - Panel Interface Signal Generator Register 11_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_11_2
{
    uint32_t U;
    struct _hw_epdc_pigeon_11_2_bitfields
    {
        uint32_t SIG_LOGIC : 4;        /*!< [3:0]  */
        uint32_t SIG_ANOTHER : 5;      /*!< [8:4]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_epdc_pigeon_11_2_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_11_2 register
 */
/*@{*/
#define HW_EPDC_PIGEON_11_2_ADDR(x) ((uintptr_t)(x) + 0xAE0U)

#define HW_EPDC_PIGEON_11_2(x)   (*(__IO hw_epdc_pigeon_11_2_t *) HW_EPDC_PIGEON_11_2_ADDR(x))
#define HW_EPDC_PIGEON_11_2_RD(x) (HW_EPDC_PIGEON_11_2(x).U)
#define HW_EPDC_PIGEON_11_2_WR(x, v) (HW_EPDC_PIGEON_11_2(x).U = (v))
#define HW_EPDC_PIGEON_11_2_SET(x, v) (HW_EPDC_PIGEON_11_2_WR(x, HW_EPDC_PIGEON_11_2_RD(x) |  (v)))
#define HW_EPDC_PIGEON_11_2_CLR(x, v) (HW_EPDC_PIGEON_11_2_WR(x, HW_EPDC_PIGEON_11_2_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_11_2_TOG(x, v) (HW_EPDC_PIGEON_11_2_WR(x, HW_EPDC_PIGEON_11_2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_11_2 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_11_2, field SIG_LOGIC[3:0] (RW)
 *
 * logic operation with another signal sigout : final output signal of this
 * generator mask : final mask of this generator this_sig : intermediate signal of
 * this generator before logic operation other_masks : intermediate mask result of
 * this generator before logic operation sig_another : signal selected other
 * generators
 *
 * Values:
 * - 0 - no logic operation
 * - 1 - sigout = sig_another AND this_sig
 * - 10 - sigout = sig_another OR this_sig
 * - 11 - mask = sig_another AND other_masks
 */
/*@{*/
#define BP_EPDC_PIGEON_11_2_SIG_LOGIC (0U) /*!< Bit position for EPDC_PIGEON_11_2_SIG_LOGIC. */
#define BM_EPDC_PIGEON_11_2_SIG_LOGIC (0x0000000FU) /*!< Bit mask for EPDC_PIGEON_11_2_SIG_LOGIC. */
#define BS_EPDC_PIGEON_11_2_SIG_LOGIC (4U) /*!< Bit field size in bits for EPDC_PIGEON_11_2_SIG_LOGIC. */

#define BV_EPDC_PIGEON_11_2_SIG_LOGIC_DIS (0U)       /*!< Bit field value for EPDC_PIGEON_11_2_SIG_LOGIC: no logic operation */
#define BV_EPDC_PIGEON_11_2_SIG_LOGIC_AND (0x1U)     /*!< Bit field value for EPDC_PIGEON_11_2_SIG_LOGIC: sigout = sig_another AND this_sig */
#define BV_EPDC_PIGEON_11_2_SIG_LOGIC_OR (0x2U)      /*!< Bit field value for EPDC_PIGEON_11_2_SIG_LOGIC: sigout = sig_another OR this_sig */
#define BV_EPDC_PIGEON_11_2_SIG_LOGIC_MASK (0x3U)    /*!< Bit field value for EPDC_PIGEON_11_2_SIG_LOGIC: mask = sig_another AND other_masks */

/*! @brief Read current value of the EPDC_PIGEON_11_2_SIG_LOGIC field. */
#define BR_EPDC_PIGEON_11_2_SIG_LOGIC(x) (HW_EPDC_PIGEON_11_2(x).B.SIG_LOGIC)

/*! @brief Format value for bitfield EPDC_PIGEON_11_2_SIG_LOGIC. */
#define BF_EPDC_PIGEON_11_2_SIG_LOGIC(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_11_2_SIG_LOGIC) & BM_EPDC_PIGEON_11_2_SIG_LOGIC)

/*! @brief Set the SIG_LOGIC field to a new value. */
#define BW_EPDC_PIGEON_11_2_SIG_LOGIC(x, v) (HW_EPDC_PIGEON_11_2_WR(x, (HW_EPDC_PIGEON_11_2_RD(x) & ~BM_EPDC_PIGEON_11_2_SIG_LOGIC) | BF_EPDC_PIGEON_11_2_SIG_LOGIC(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_11_2, field SIG_ANOTHER[8:4] (RW)
 *
 * select another signal for logic operation or as mask or counter tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_11_2_SIG_ANOTHER (4U) /*!< Bit position for EPDC_PIGEON_11_2_SIG_ANOTHER. */
#define BM_EPDC_PIGEON_11_2_SIG_ANOTHER (0x000001F0U) /*!< Bit mask for EPDC_PIGEON_11_2_SIG_ANOTHER. */
#define BS_EPDC_PIGEON_11_2_SIG_ANOTHER (5U) /*!< Bit field size in bits for EPDC_PIGEON_11_2_SIG_ANOTHER. */

/*! @brief Read current value of the EPDC_PIGEON_11_2_SIG_ANOTHER field. */
#define BR_EPDC_PIGEON_11_2_SIG_ANOTHER(x) (HW_EPDC_PIGEON_11_2(x).B.SIG_ANOTHER)

/*! @brief Format value for bitfield EPDC_PIGEON_11_2_SIG_ANOTHER. */
#define BF_EPDC_PIGEON_11_2_SIG_ANOTHER(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_11_2_SIG_ANOTHER) & BM_EPDC_PIGEON_11_2_SIG_ANOTHER)

/*! @brief Set the SIG_ANOTHER field to a new value. */
#define BW_EPDC_PIGEON_11_2_SIG_ANOTHER(x, v) (HW_EPDC_PIGEON_11_2_WR(x, (HW_EPDC_PIGEON_11_2_RD(x) & ~BM_EPDC_PIGEON_11_2_SIG_ANOTHER) | BF_EPDC_PIGEON_11_2_SIG_ANOTHER(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_12_0 - Panel Interface Signal Generator Register 12_0
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_12_0 - Panel Interface Signal Generator Register 12_0 (RW)
 *
 * Reset value: 0x00000F00U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_12_0
{
    uint32_t U;
    struct _hw_epdc_pigeon_12_0_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t POL : 1;              /*!< [1]  */
        uint32_t INC_SEL : 2;          /*!< [3:2]  */
        uint32_t OFFSET : 4;           /*!< [7:4]  */
        uint32_t MASK_CNT_SEL : 4;     /*!< [11:8]  */
        uint32_t MASK_CNT : 12;        /*!< [23:12]  */
        uint32_t STATE_MASK : 8;       /*!< [31:24]  */
    } B;
} hw_epdc_pigeon_12_0_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_12_0 register
 */
/*@{*/
#define HW_EPDC_PIGEON_12_0_ADDR(x) ((uintptr_t)(x) + 0xB00U)

#define HW_EPDC_PIGEON_12_0(x)   (*(__IO hw_epdc_pigeon_12_0_t *) HW_EPDC_PIGEON_12_0_ADDR(x))
#define HW_EPDC_PIGEON_12_0_RD(x) (HW_EPDC_PIGEON_12_0(x).U)
#define HW_EPDC_PIGEON_12_0_WR(x, v) (HW_EPDC_PIGEON_12_0(x).U = (v))
#define HW_EPDC_PIGEON_12_0_SET(x, v) (HW_EPDC_PIGEON_12_0_WR(x, HW_EPDC_PIGEON_12_0_RD(x) |  (v)))
#define HW_EPDC_PIGEON_12_0_CLR(x, v) (HW_EPDC_PIGEON_12_0_WR(x, HW_EPDC_PIGEON_12_0_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_12_0_TOG(x, v) (HW_EPDC_PIGEON_12_0_WR(x, HW_EPDC_PIGEON_12_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_12_0 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_12_0, field EN[0] (RW)
 *
 * enable pigeon mode on this signal
 */
/*@{*/
#define BP_EPDC_PIGEON_12_0_EN (0U)        /*!< Bit position for EPDC_PIGEON_12_0_EN. */
#define BM_EPDC_PIGEON_12_0_EN (0x00000001U) /*!< Bit mask for EPDC_PIGEON_12_0_EN. */
#define BS_EPDC_PIGEON_12_0_EN (1U)        /*!< Bit field size in bits for EPDC_PIGEON_12_0_EN. */

/*! @brief Read current value of the EPDC_PIGEON_12_0_EN field. */
#define BR_EPDC_PIGEON_12_0_EN(x) (HW_EPDC_PIGEON_12_0(x).B.EN)

/*! @brief Format value for bitfield EPDC_PIGEON_12_0_EN. */
#define BF_EPDC_PIGEON_12_0_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_12_0_EN) & BM_EPDC_PIGEON_12_0_EN)

/*! @brief Set the EN field to a new value. */
#define BW_EPDC_PIGEON_12_0_EN(x, v) (HW_EPDC_PIGEON_12_0_WR(x, (HW_EPDC_PIGEON_12_0_RD(x) & ~BM_EPDC_PIGEON_12_0_EN) | BF_EPDC_PIGEON_12_0_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_12_0, field POL[1] (RW)
 *
 * polarity of signal output
 *
 * Values:
 * - 0 - normal signal (active high)
 * - 1 - inverted signal (active low)
 */
/*@{*/
#define BP_EPDC_PIGEON_12_0_POL (1U)       /*!< Bit position for EPDC_PIGEON_12_0_POL. */
#define BM_EPDC_PIGEON_12_0_POL (0x00000002U) /*!< Bit mask for EPDC_PIGEON_12_0_POL. */
#define BS_EPDC_PIGEON_12_0_POL (1U)       /*!< Bit field size in bits for EPDC_PIGEON_12_0_POL. */

#define BV_EPDC_PIGEON_12_0_POL_ACTIVE_HIGH (0U)     /*!< Bit field value for EPDC_PIGEON_12_0_POL: normal signal (active high) */
#define BV_EPDC_PIGEON_12_0_POL_ACTIVE_LOW (0x1U)    /*!< Bit field value for EPDC_PIGEON_12_0_POL: inverted signal (active low) */

/*! @brief Read current value of the EPDC_PIGEON_12_0_POL field. */
#define BR_EPDC_PIGEON_12_0_POL(x) (HW_EPDC_PIGEON_12_0(x).B.POL)

/*! @brief Format value for bitfield EPDC_PIGEON_12_0_POL. */
#define BF_EPDC_PIGEON_12_0_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_12_0_POL) & BM_EPDC_PIGEON_12_0_POL)

/*! @brief Set the POL field to a new value. */
#define BW_EPDC_PIGEON_12_0_POL(x, v) (HW_EPDC_PIGEON_12_0_WR(x, (HW_EPDC_PIGEON_12_0_RD(x) & ~BM_EPDC_PIGEON_12_0_POL) | BF_EPDC_PIGEON_12_0_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_12_0, field INC_SEL[3:2] (RW)
 *
 * event to incrment local counter
 *
 * Values:
 * - 0 - pclk
 * - 1 - line start pulse
 * - 10 - frame start pulse
 * - 11 - use another signal as tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_12_0_INC_SEL (2U)   /*!< Bit position for EPDC_PIGEON_12_0_INC_SEL. */
#define BM_EPDC_PIGEON_12_0_INC_SEL (0x0000000CU) /*!< Bit mask for EPDC_PIGEON_12_0_INC_SEL. */
#define BS_EPDC_PIGEON_12_0_INC_SEL (2U)   /*!< Bit field size in bits for EPDC_PIGEON_12_0_INC_SEL. */

#define BV_EPDC_PIGEON_12_0_INC_SEL_PCLK (0U)        /*!< Bit field value for EPDC_PIGEON_12_0_INC_SEL: pclk */
#define BV_EPDC_PIGEON_12_0_INC_SEL_LINE (0x1U)      /*!< Bit field value for EPDC_PIGEON_12_0_INC_SEL: line start pulse */
#define BV_EPDC_PIGEON_12_0_INC_SEL_FRAME (0x2U)     /*!< Bit field value for EPDC_PIGEON_12_0_INC_SEL: frame start pulse */
#define BV_EPDC_PIGEON_12_0_INC_SEL_SIG_ANOTHER (0x3U) /*!< Bit field value for EPDC_PIGEON_12_0_INC_SEL: use another signal as tick event */

/*! @brief Read current value of the EPDC_PIGEON_12_0_INC_SEL field. */
#define BR_EPDC_PIGEON_12_0_INC_SEL(x) (HW_EPDC_PIGEON_12_0(x).B.INC_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_12_0_INC_SEL. */
#define BF_EPDC_PIGEON_12_0_INC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_12_0_INC_SEL) & BM_EPDC_PIGEON_12_0_INC_SEL)

/*! @brief Set the INC_SEL field to a new value. */
#define BW_EPDC_PIGEON_12_0_INC_SEL(x, v) (HW_EPDC_PIGEON_12_0_WR(x, (HW_EPDC_PIGEON_12_0_RD(x) & ~BM_EPDC_PIGEON_12_0_INC_SEL) | BF_EPDC_PIGEON_12_0_INC_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_12_0, field OFFSET[7:4] (RW)
 *
 * offset on pclk unit. 0=aligne with data, positive value means delay, minus
 * value mean ahead. Supported range depends on panel mode
 */
/*@{*/
#define BP_EPDC_PIGEON_12_0_OFFSET (4U)    /*!< Bit position for EPDC_PIGEON_12_0_OFFSET. */
#define BM_EPDC_PIGEON_12_0_OFFSET (0x000000F0U) /*!< Bit mask for EPDC_PIGEON_12_0_OFFSET. */
#define BS_EPDC_PIGEON_12_0_OFFSET (4U)    /*!< Bit field size in bits for EPDC_PIGEON_12_0_OFFSET. */

/*! @brief Read current value of the EPDC_PIGEON_12_0_OFFSET field. */
#define BR_EPDC_PIGEON_12_0_OFFSET(x) (HW_EPDC_PIGEON_12_0(x).B.OFFSET)

/*! @brief Format value for bitfield EPDC_PIGEON_12_0_OFFSET. */
#define BF_EPDC_PIGEON_12_0_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_12_0_OFFSET) & BM_EPDC_PIGEON_12_0_OFFSET)

/*! @brief Set the OFFSET field to a new value. */
#define BW_EPDC_PIGEON_12_0_OFFSET(x, v) (HW_EPDC_PIGEON_12_0_WR(x, (HW_EPDC_PIGEON_12_0_RD(x) & ~BM_EPDC_PIGEON_12_0_OFFSET) | BF_EPDC_PIGEON_12_0_OFFSET(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_12_0, field MASK_CNT_SEL[11:8] (RW)
 *
 * select global counters as mask condition, use together with MASK_CNT
 *
 * Values:
 * - 0 - pclk counter within one hscan state
 * - 1 - pclk cycle within one hscan state
 * - 10 - line counter within one vscan state
 * - 11 - line cycle within one vscan state
 * - 100 - frame counter
 * - 101 - frame cycle
 * - 110 - horizontal counter (pclk counter within one line )
 * - 111 - vertical counter (line counter within one frame)
 */
/*@{*/
#define BP_EPDC_PIGEON_12_0_MASK_CNT_SEL (8U) /*!< Bit position for EPDC_PIGEON_12_0_MASK_CNT_SEL. */
#define BM_EPDC_PIGEON_12_0_MASK_CNT_SEL (0x00000F00U) /*!< Bit mask for EPDC_PIGEON_12_0_MASK_CNT_SEL. */
#define BS_EPDC_PIGEON_12_0_MASK_CNT_SEL (4U) /*!< Bit field size in bits for EPDC_PIGEON_12_0_MASK_CNT_SEL. */

#define BV_EPDC_PIGEON_12_0_MASK_CNT_SEL_HSTATE_CNT (0U) /*!< Bit field value for EPDC_PIGEON_12_0_MASK_CNT_SEL: pclk counter within one hscan state */
#define BV_EPDC_PIGEON_12_0_MASK_CNT_SEL_HSTATE_CYCLE (0x1U) /*!< Bit field value for EPDC_PIGEON_12_0_MASK_CNT_SEL: pclk cycle within one hscan state */
#define BV_EPDC_PIGEON_12_0_MASK_CNT_SEL_VSTATE_CNT (0x2U) /*!< Bit field value for EPDC_PIGEON_12_0_MASK_CNT_SEL: line counter within one vscan state */
#define BV_EPDC_PIGEON_12_0_MASK_CNT_SEL_VSTATE_CYCLE (0x3U) /*!< Bit field value for EPDC_PIGEON_12_0_MASK_CNT_SEL: line cycle within one vscan state */
#define BV_EPDC_PIGEON_12_0_MASK_CNT_SEL_FRAME_CNT (0x4U) /*!< Bit field value for EPDC_PIGEON_12_0_MASK_CNT_SEL: frame counter */
#define BV_EPDC_PIGEON_12_0_MASK_CNT_SEL_FRAME_CYCLE (0x5U) /*!< Bit field value for EPDC_PIGEON_12_0_MASK_CNT_SEL: frame cycle */
#define BV_EPDC_PIGEON_12_0_MASK_CNT_SEL_HCNT (0x6U) /*!< Bit field value for EPDC_PIGEON_12_0_MASK_CNT_SEL: horizontal counter (pclk counter within one line ) */
#define BV_EPDC_PIGEON_12_0_MASK_CNT_SEL_VCNT (0x7U) /*!< Bit field value for EPDC_PIGEON_12_0_MASK_CNT_SEL: vertical counter (line counter within one frame) */

/*! @brief Read current value of the EPDC_PIGEON_12_0_MASK_CNT_SEL field. */
#define BR_EPDC_PIGEON_12_0_MASK_CNT_SEL(x) (HW_EPDC_PIGEON_12_0(x).B.MASK_CNT_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_12_0_MASK_CNT_SEL. */
#define BF_EPDC_PIGEON_12_0_MASK_CNT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_12_0_MASK_CNT_SEL) & BM_EPDC_PIGEON_12_0_MASK_CNT_SEL)

/*! @brief Set the MASK_CNT_SEL field to a new value. */
#define BW_EPDC_PIGEON_12_0_MASK_CNT_SEL(x, v) (HW_EPDC_PIGEON_12_0_WR(x, (HW_EPDC_PIGEON_12_0_RD(x) & ~BM_EPDC_PIGEON_12_0_MASK_CNT_SEL) | BF_EPDC_PIGEON_12_0_MASK_CNT_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_12_0, field MASK_CNT[23:12] (RW)
 *
 * When the global counter selected through MASK_CNT_SEL matches value in this
 * reg, pigeon local counter start ticking. 0=disable
 */
/*@{*/
#define BP_EPDC_PIGEON_12_0_MASK_CNT (12U) /*!< Bit position for EPDC_PIGEON_12_0_MASK_CNT. */
#define BM_EPDC_PIGEON_12_0_MASK_CNT (0x00FFF000U) /*!< Bit mask for EPDC_PIGEON_12_0_MASK_CNT. */
#define BS_EPDC_PIGEON_12_0_MASK_CNT (12U) /*!< Bit field size in bits for EPDC_PIGEON_12_0_MASK_CNT. */

/*! @brief Read current value of the EPDC_PIGEON_12_0_MASK_CNT field. */
#define BR_EPDC_PIGEON_12_0_MASK_CNT(x) (HW_EPDC_PIGEON_12_0(x).B.MASK_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_12_0_MASK_CNT. */
#define BF_EPDC_PIGEON_12_0_MASK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_12_0_MASK_CNT) & BM_EPDC_PIGEON_12_0_MASK_CNT)

/*! @brief Set the MASK_CNT field to a new value. */
#define BW_EPDC_PIGEON_12_0_MASK_CNT(x, v) (HW_EPDC_PIGEON_12_0_WR(x, (HW_EPDC_PIGEON_12_0_RD(x) & ~BM_EPDC_PIGEON_12_0_MASK_CNT) | BF_EPDC_PIGEON_12_0_MASK_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_12_0, field STATE_MASK[31:24] (RW)
 *
 * state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan
 * states as reference point for local counter to start ticking
 *
 * Values:
 * - 1 - FRAME SYNC
 * - 10 - FRAME BEGIN
 * - 100 - FRAME DATA
 * - 1000 - FRAME END
 * - 10000 - LINE SYNC
 * - 100000 - LINE BEGIN
 * - 1000000 - LINE DATA
 * - 10000000 - LINE END
 */
/*@{*/
#define BP_EPDC_PIGEON_12_0_STATE_MASK (24U) /*!< Bit position for EPDC_PIGEON_12_0_STATE_MASK. */
#define BM_EPDC_PIGEON_12_0_STATE_MASK (0xFF000000U) /*!< Bit mask for EPDC_PIGEON_12_0_STATE_MASK. */
#define BS_EPDC_PIGEON_12_0_STATE_MASK (8U) /*!< Bit field size in bits for EPDC_PIGEON_12_0_STATE_MASK. */

#define BV_EPDC_PIGEON_12_0_STATE_MASK_FS (0x1U)     /*!< Bit field value for EPDC_PIGEON_12_0_STATE_MASK: FRAME SYNC */
#define BV_EPDC_PIGEON_12_0_STATE_MASK_FB (0x2U)     /*!< Bit field value for EPDC_PIGEON_12_0_STATE_MASK: FRAME BEGIN */
#define BV_EPDC_PIGEON_12_0_STATE_MASK_FD (0x4U)     /*!< Bit field value for EPDC_PIGEON_12_0_STATE_MASK: FRAME DATA */
#define BV_EPDC_PIGEON_12_0_STATE_MASK_FE (0x8U)     /*!< Bit field value for EPDC_PIGEON_12_0_STATE_MASK: FRAME END */
#define BV_EPDC_PIGEON_12_0_STATE_MASK_LS (0x10U)    /*!< Bit field value for EPDC_PIGEON_12_0_STATE_MASK: LINE SYNC */
#define BV_EPDC_PIGEON_12_0_STATE_MASK_LB (0x20U)    /*!< Bit field value for EPDC_PIGEON_12_0_STATE_MASK: LINE BEGIN */
#define BV_EPDC_PIGEON_12_0_STATE_MASK_LD (0x40U)    /*!< Bit field value for EPDC_PIGEON_12_0_STATE_MASK: LINE DATA */
#define BV_EPDC_PIGEON_12_0_STATE_MASK_LE (0x80U)    /*!< Bit field value for EPDC_PIGEON_12_0_STATE_MASK: LINE END */

/*! @brief Read current value of the EPDC_PIGEON_12_0_STATE_MASK field. */
#define BR_EPDC_PIGEON_12_0_STATE_MASK(x) (HW_EPDC_PIGEON_12_0(x).B.STATE_MASK)

/*! @brief Format value for bitfield EPDC_PIGEON_12_0_STATE_MASK. */
#define BF_EPDC_PIGEON_12_0_STATE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_12_0_STATE_MASK) & BM_EPDC_PIGEON_12_0_STATE_MASK)

/*! @brief Set the STATE_MASK field to a new value. */
#define BW_EPDC_PIGEON_12_0_STATE_MASK(x, v) (HW_EPDC_PIGEON_12_0_WR(x, (HW_EPDC_PIGEON_12_0_RD(x) & ~BM_EPDC_PIGEON_12_0_STATE_MASK) | BF_EPDC_PIGEON_12_0_STATE_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_12_1 - Panel Interface Signal Generator Register 12_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_12_1 - Panel Interface Signal Generator Register 12_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_12_1
{
    uint32_t U;
    struct _hw_epdc_pigeon_12_1_bitfields
    {
        uint32_t SET_CNT : 16;         /*!< [15:0]  */
        uint32_t CLR_CNT : 16;         /*!< [31:16]  */
    } B;
} hw_epdc_pigeon_12_1_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_12_1 register
 */
/*@{*/
#define HW_EPDC_PIGEON_12_1_ADDR(x) ((uintptr_t)(x) + 0xB10U)

#define HW_EPDC_PIGEON_12_1(x)   (*(__IO hw_epdc_pigeon_12_1_t *) HW_EPDC_PIGEON_12_1_ADDR(x))
#define HW_EPDC_PIGEON_12_1_RD(x) (HW_EPDC_PIGEON_12_1(x).U)
#define HW_EPDC_PIGEON_12_1_WR(x, v) (HW_EPDC_PIGEON_12_1(x).U = (v))
#define HW_EPDC_PIGEON_12_1_SET(x, v) (HW_EPDC_PIGEON_12_1_WR(x, HW_EPDC_PIGEON_12_1_RD(x) |  (v)))
#define HW_EPDC_PIGEON_12_1_CLR(x, v) (HW_EPDC_PIGEON_12_1_WR(x, HW_EPDC_PIGEON_12_1_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_12_1_TOG(x, v) (HW_EPDC_PIGEON_12_1_WR(x, HW_EPDC_PIGEON_12_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_12_1 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_12_1, field SET_CNT[15:0] (RW)
 *
 * assert signal output when counter match this value
 *
 * Values:
 * - 0 - start as active
 */
/*@{*/
#define BP_EPDC_PIGEON_12_1_SET_CNT (0U)   /*!< Bit position for EPDC_PIGEON_12_1_SET_CNT. */
#define BM_EPDC_PIGEON_12_1_SET_CNT (0x0000FFFFU) /*!< Bit mask for EPDC_PIGEON_12_1_SET_CNT. */
#define BS_EPDC_PIGEON_12_1_SET_CNT (16U)  /*!< Bit field size in bits for EPDC_PIGEON_12_1_SET_CNT. */

#define BV_EPDC_PIGEON_12_1_SET_CNT_START_ACTIVE (0U) /*!< Bit field value for EPDC_PIGEON_12_1_SET_CNT: start as active */

/*! @brief Read current value of the EPDC_PIGEON_12_1_SET_CNT field. */
#define BR_EPDC_PIGEON_12_1_SET_CNT(x) (HW_EPDC_PIGEON_12_1(x).B.SET_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_12_1_SET_CNT. */
#define BF_EPDC_PIGEON_12_1_SET_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_12_1_SET_CNT) & BM_EPDC_PIGEON_12_1_SET_CNT)

/*! @brief Set the SET_CNT field to a new value. */
#define BW_EPDC_PIGEON_12_1_SET_CNT(x, v) (HW_EPDC_PIGEON_12_1_WR(x, (HW_EPDC_PIGEON_12_1_RD(x) & ~BM_EPDC_PIGEON_12_1_SET_CNT) | BF_EPDC_PIGEON_12_1_SET_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_12_1, field CLR_CNT[31:16] (RW)
 *
 * deassert signal output when counter match this value
 *
 * Values:
 * - 0 - keep active until mask off
 */
/*@{*/
#define BP_EPDC_PIGEON_12_1_CLR_CNT (16U)  /*!< Bit position for EPDC_PIGEON_12_1_CLR_CNT. */
#define BM_EPDC_PIGEON_12_1_CLR_CNT (0xFFFF0000U) /*!< Bit mask for EPDC_PIGEON_12_1_CLR_CNT. */
#define BS_EPDC_PIGEON_12_1_CLR_CNT (16U)  /*!< Bit field size in bits for EPDC_PIGEON_12_1_CLR_CNT. */

#define BV_EPDC_PIGEON_12_1_CLR_CNT_CLEAR_USING_MASK (0U) /*!< Bit field value for EPDC_PIGEON_12_1_CLR_CNT: keep active until mask off */

/*! @brief Read current value of the EPDC_PIGEON_12_1_CLR_CNT field. */
#define BR_EPDC_PIGEON_12_1_CLR_CNT(x) (HW_EPDC_PIGEON_12_1(x).B.CLR_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_12_1_CLR_CNT. */
#define BF_EPDC_PIGEON_12_1_CLR_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_12_1_CLR_CNT) & BM_EPDC_PIGEON_12_1_CLR_CNT)

/*! @brief Set the CLR_CNT field to a new value. */
#define BW_EPDC_PIGEON_12_1_CLR_CNT(x, v) (HW_EPDC_PIGEON_12_1_WR(x, (HW_EPDC_PIGEON_12_1_RD(x) & ~BM_EPDC_PIGEON_12_1_CLR_CNT) | BF_EPDC_PIGEON_12_1_CLR_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_12_2 - Panel Interface Signal Generator Register 12_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_12_2 - Panel Interface Signal Generator Register 12_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_12_2
{
    uint32_t U;
    struct _hw_epdc_pigeon_12_2_bitfields
    {
        uint32_t SIG_LOGIC : 4;        /*!< [3:0]  */
        uint32_t SIG_ANOTHER : 5;      /*!< [8:4]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_epdc_pigeon_12_2_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_12_2 register
 */
/*@{*/
#define HW_EPDC_PIGEON_12_2_ADDR(x) ((uintptr_t)(x) + 0xB20U)

#define HW_EPDC_PIGEON_12_2(x)   (*(__IO hw_epdc_pigeon_12_2_t *) HW_EPDC_PIGEON_12_2_ADDR(x))
#define HW_EPDC_PIGEON_12_2_RD(x) (HW_EPDC_PIGEON_12_2(x).U)
#define HW_EPDC_PIGEON_12_2_WR(x, v) (HW_EPDC_PIGEON_12_2(x).U = (v))
#define HW_EPDC_PIGEON_12_2_SET(x, v) (HW_EPDC_PIGEON_12_2_WR(x, HW_EPDC_PIGEON_12_2_RD(x) |  (v)))
#define HW_EPDC_PIGEON_12_2_CLR(x, v) (HW_EPDC_PIGEON_12_2_WR(x, HW_EPDC_PIGEON_12_2_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_12_2_TOG(x, v) (HW_EPDC_PIGEON_12_2_WR(x, HW_EPDC_PIGEON_12_2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_12_2 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_12_2, field SIG_LOGIC[3:0] (RW)
 *
 * logic operation with another signal sigout : final output signal of this
 * generator mask : final mask of this generator this_sig : intermediate signal of
 * this generator before logic operation other_masks : intermediate mask result of
 * this generator before logic operation sig_another : signal selected other
 * generators
 *
 * Values:
 * - 0 - no logic operation
 * - 1 - sigout = sig_another AND this_sig
 * - 10 - sigout = sig_another OR this_sig
 * - 11 - mask = sig_another AND other_masks
 */
/*@{*/
#define BP_EPDC_PIGEON_12_2_SIG_LOGIC (0U) /*!< Bit position for EPDC_PIGEON_12_2_SIG_LOGIC. */
#define BM_EPDC_PIGEON_12_2_SIG_LOGIC (0x0000000FU) /*!< Bit mask for EPDC_PIGEON_12_2_SIG_LOGIC. */
#define BS_EPDC_PIGEON_12_2_SIG_LOGIC (4U) /*!< Bit field size in bits for EPDC_PIGEON_12_2_SIG_LOGIC. */

#define BV_EPDC_PIGEON_12_2_SIG_LOGIC_DIS (0U)       /*!< Bit field value for EPDC_PIGEON_12_2_SIG_LOGIC: no logic operation */
#define BV_EPDC_PIGEON_12_2_SIG_LOGIC_AND (0x1U)     /*!< Bit field value for EPDC_PIGEON_12_2_SIG_LOGIC: sigout = sig_another AND this_sig */
#define BV_EPDC_PIGEON_12_2_SIG_LOGIC_OR (0x2U)      /*!< Bit field value for EPDC_PIGEON_12_2_SIG_LOGIC: sigout = sig_another OR this_sig */
#define BV_EPDC_PIGEON_12_2_SIG_LOGIC_MASK (0x3U)    /*!< Bit field value for EPDC_PIGEON_12_2_SIG_LOGIC: mask = sig_another AND other_masks */

/*! @brief Read current value of the EPDC_PIGEON_12_2_SIG_LOGIC field. */
#define BR_EPDC_PIGEON_12_2_SIG_LOGIC(x) (HW_EPDC_PIGEON_12_2(x).B.SIG_LOGIC)

/*! @brief Format value for bitfield EPDC_PIGEON_12_2_SIG_LOGIC. */
#define BF_EPDC_PIGEON_12_2_SIG_LOGIC(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_12_2_SIG_LOGIC) & BM_EPDC_PIGEON_12_2_SIG_LOGIC)

/*! @brief Set the SIG_LOGIC field to a new value. */
#define BW_EPDC_PIGEON_12_2_SIG_LOGIC(x, v) (HW_EPDC_PIGEON_12_2_WR(x, (HW_EPDC_PIGEON_12_2_RD(x) & ~BM_EPDC_PIGEON_12_2_SIG_LOGIC) | BF_EPDC_PIGEON_12_2_SIG_LOGIC(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_12_2, field SIG_ANOTHER[8:4] (RW)
 *
 * select another signal for logic operation or as mask or counter tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_12_2_SIG_ANOTHER (4U) /*!< Bit position for EPDC_PIGEON_12_2_SIG_ANOTHER. */
#define BM_EPDC_PIGEON_12_2_SIG_ANOTHER (0x000001F0U) /*!< Bit mask for EPDC_PIGEON_12_2_SIG_ANOTHER. */
#define BS_EPDC_PIGEON_12_2_SIG_ANOTHER (5U) /*!< Bit field size in bits for EPDC_PIGEON_12_2_SIG_ANOTHER. */

/*! @brief Read current value of the EPDC_PIGEON_12_2_SIG_ANOTHER field. */
#define BR_EPDC_PIGEON_12_2_SIG_ANOTHER(x) (HW_EPDC_PIGEON_12_2(x).B.SIG_ANOTHER)

/*! @brief Format value for bitfield EPDC_PIGEON_12_2_SIG_ANOTHER. */
#define BF_EPDC_PIGEON_12_2_SIG_ANOTHER(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_12_2_SIG_ANOTHER) & BM_EPDC_PIGEON_12_2_SIG_ANOTHER)

/*! @brief Set the SIG_ANOTHER field to a new value. */
#define BW_EPDC_PIGEON_12_2_SIG_ANOTHER(x, v) (HW_EPDC_PIGEON_12_2_WR(x, (HW_EPDC_PIGEON_12_2_RD(x) & ~BM_EPDC_PIGEON_12_2_SIG_ANOTHER) | BF_EPDC_PIGEON_12_2_SIG_ANOTHER(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_13_0 - Panel Interface Signal Generator Register 13_0
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_13_0 - Panel Interface Signal Generator Register 13_0 (RW)
 *
 * Reset value: 0x00000F00U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_13_0
{
    uint32_t U;
    struct _hw_epdc_pigeon_13_0_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t POL : 1;              /*!< [1]  */
        uint32_t INC_SEL : 2;          /*!< [3:2]  */
        uint32_t OFFSET : 4;           /*!< [7:4]  */
        uint32_t MASK_CNT_SEL : 4;     /*!< [11:8]  */
        uint32_t MASK_CNT : 12;        /*!< [23:12]  */
        uint32_t STATE_MASK : 8;       /*!< [31:24]  */
    } B;
} hw_epdc_pigeon_13_0_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_13_0 register
 */
/*@{*/
#define HW_EPDC_PIGEON_13_0_ADDR(x) ((uintptr_t)(x) + 0xB40U)

#define HW_EPDC_PIGEON_13_0(x)   (*(__IO hw_epdc_pigeon_13_0_t *) HW_EPDC_PIGEON_13_0_ADDR(x))
#define HW_EPDC_PIGEON_13_0_RD(x) (HW_EPDC_PIGEON_13_0(x).U)
#define HW_EPDC_PIGEON_13_0_WR(x, v) (HW_EPDC_PIGEON_13_0(x).U = (v))
#define HW_EPDC_PIGEON_13_0_SET(x, v) (HW_EPDC_PIGEON_13_0_WR(x, HW_EPDC_PIGEON_13_0_RD(x) |  (v)))
#define HW_EPDC_PIGEON_13_0_CLR(x, v) (HW_EPDC_PIGEON_13_0_WR(x, HW_EPDC_PIGEON_13_0_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_13_0_TOG(x, v) (HW_EPDC_PIGEON_13_0_WR(x, HW_EPDC_PIGEON_13_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_13_0 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_13_0, field EN[0] (RW)
 *
 * enable pigeon mode on this signal
 */
/*@{*/
#define BP_EPDC_PIGEON_13_0_EN (0U)        /*!< Bit position for EPDC_PIGEON_13_0_EN. */
#define BM_EPDC_PIGEON_13_0_EN (0x00000001U) /*!< Bit mask for EPDC_PIGEON_13_0_EN. */
#define BS_EPDC_PIGEON_13_0_EN (1U)        /*!< Bit field size in bits for EPDC_PIGEON_13_0_EN. */

/*! @brief Read current value of the EPDC_PIGEON_13_0_EN field. */
#define BR_EPDC_PIGEON_13_0_EN(x) (HW_EPDC_PIGEON_13_0(x).B.EN)

/*! @brief Format value for bitfield EPDC_PIGEON_13_0_EN. */
#define BF_EPDC_PIGEON_13_0_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_13_0_EN) & BM_EPDC_PIGEON_13_0_EN)

/*! @brief Set the EN field to a new value. */
#define BW_EPDC_PIGEON_13_0_EN(x, v) (HW_EPDC_PIGEON_13_0_WR(x, (HW_EPDC_PIGEON_13_0_RD(x) & ~BM_EPDC_PIGEON_13_0_EN) | BF_EPDC_PIGEON_13_0_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_13_0, field POL[1] (RW)
 *
 * polarity of signal output
 *
 * Values:
 * - 0 - normal signal (active high)
 * - 1 - inverted signal (active low)
 */
/*@{*/
#define BP_EPDC_PIGEON_13_0_POL (1U)       /*!< Bit position for EPDC_PIGEON_13_0_POL. */
#define BM_EPDC_PIGEON_13_0_POL (0x00000002U) /*!< Bit mask for EPDC_PIGEON_13_0_POL. */
#define BS_EPDC_PIGEON_13_0_POL (1U)       /*!< Bit field size in bits for EPDC_PIGEON_13_0_POL. */

#define BV_EPDC_PIGEON_13_0_POL_ACTIVE_HIGH (0U)     /*!< Bit field value for EPDC_PIGEON_13_0_POL: normal signal (active high) */
#define BV_EPDC_PIGEON_13_0_POL_ACTIVE_LOW (0x1U)    /*!< Bit field value for EPDC_PIGEON_13_0_POL: inverted signal (active low) */

/*! @brief Read current value of the EPDC_PIGEON_13_0_POL field. */
#define BR_EPDC_PIGEON_13_0_POL(x) (HW_EPDC_PIGEON_13_0(x).B.POL)

/*! @brief Format value for bitfield EPDC_PIGEON_13_0_POL. */
#define BF_EPDC_PIGEON_13_0_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_13_0_POL) & BM_EPDC_PIGEON_13_0_POL)

/*! @brief Set the POL field to a new value. */
#define BW_EPDC_PIGEON_13_0_POL(x, v) (HW_EPDC_PIGEON_13_0_WR(x, (HW_EPDC_PIGEON_13_0_RD(x) & ~BM_EPDC_PIGEON_13_0_POL) | BF_EPDC_PIGEON_13_0_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_13_0, field INC_SEL[3:2] (RW)
 *
 * event to incrment local counter
 *
 * Values:
 * - 0 - pclk
 * - 1 - line start pulse
 * - 10 - frame start pulse
 * - 11 - use another signal as tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_13_0_INC_SEL (2U)   /*!< Bit position for EPDC_PIGEON_13_0_INC_SEL. */
#define BM_EPDC_PIGEON_13_0_INC_SEL (0x0000000CU) /*!< Bit mask for EPDC_PIGEON_13_0_INC_SEL. */
#define BS_EPDC_PIGEON_13_0_INC_SEL (2U)   /*!< Bit field size in bits for EPDC_PIGEON_13_0_INC_SEL. */

#define BV_EPDC_PIGEON_13_0_INC_SEL_PCLK (0U)        /*!< Bit field value for EPDC_PIGEON_13_0_INC_SEL: pclk */
#define BV_EPDC_PIGEON_13_0_INC_SEL_LINE (0x1U)      /*!< Bit field value for EPDC_PIGEON_13_0_INC_SEL: line start pulse */
#define BV_EPDC_PIGEON_13_0_INC_SEL_FRAME (0x2U)     /*!< Bit field value for EPDC_PIGEON_13_0_INC_SEL: frame start pulse */
#define BV_EPDC_PIGEON_13_0_INC_SEL_SIG_ANOTHER (0x3U) /*!< Bit field value for EPDC_PIGEON_13_0_INC_SEL: use another signal as tick event */

/*! @brief Read current value of the EPDC_PIGEON_13_0_INC_SEL field. */
#define BR_EPDC_PIGEON_13_0_INC_SEL(x) (HW_EPDC_PIGEON_13_0(x).B.INC_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_13_0_INC_SEL. */
#define BF_EPDC_PIGEON_13_0_INC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_13_0_INC_SEL) & BM_EPDC_PIGEON_13_0_INC_SEL)

/*! @brief Set the INC_SEL field to a new value. */
#define BW_EPDC_PIGEON_13_0_INC_SEL(x, v) (HW_EPDC_PIGEON_13_0_WR(x, (HW_EPDC_PIGEON_13_0_RD(x) & ~BM_EPDC_PIGEON_13_0_INC_SEL) | BF_EPDC_PIGEON_13_0_INC_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_13_0, field OFFSET[7:4] (RW)
 *
 * offset on pclk unit. 0=aligne with data, positive value means delay, minus
 * value mean ahead. Supported range depends on panel mode
 */
/*@{*/
#define BP_EPDC_PIGEON_13_0_OFFSET (4U)    /*!< Bit position for EPDC_PIGEON_13_0_OFFSET. */
#define BM_EPDC_PIGEON_13_0_OFFSET (0x000000F0U) /*!< Bit mask for EPDC_PIGEON_13_0_OFFSET. */
#define BS_EPDC_PIGEON_13_0_OFFSET (4U)    /*!< Bit field size in bits for EPDC_PIGEON_13_0_OFFSET. */

/*! @brief Read current value of the EPDC_PIGEON_13_0_OFFSET field. */
#define BR_EPDC_PIGEON_13_0_OFFSET(x) (HW_EPDC_PIGEON_13_0(x).B.OFFSET)

/*! @brief Format value for bitfield EPDC_PIGEON_13_0_OFFSET. */
#define BF_EPDC_PIGEON_13_0_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_13_0_OFFSET) & BM_EPDC_PIGEON_13_0_OFFSET)

/*! @brief Set the OFFSET field to a new value. */
#define BW_EPDC_PIGEON_13_0_OFFSET(x, v) (HW_EPDC_PIGEON_13_0_WR(x, (HW_EPDC_PIGEON_13_0_RD(x) & ~BM_EPDC_PIGEON_13_0_OFFSET) | BF_EPDC_PIGEON_13_0_OFFSET(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_13_0, field MASK_CNT_SEL[11:8] (RW)
 *
 * select global counters as mask condition, use together with MASK_CNT
 *
 * Values:
 * - 0 - pclk counter within one hscan state
 * - 1 - pclk cycle within one hscan state
 * - 10 - line counter within one vscan state
 * - 11 - line cycle within one vscan state
 * - 100 - frame counter
 * - 101 - frame cycle
 * - 110 - horizontal counter (pclk counter within one line )
 * - 111 - vertical counter (line counter within one frame)
 */
/*@{*/
#define BP_EPDC_PIGEON_13_0_MASK_CNT_SEL (8U) /*!< Bit position for EPDC_PIGEON_13_0_MASK_CNT_SEL. */
#define BM_EPDC_PIGEON_13_0_MASK_CNT_SEL (0x00000F00U) /*!< Bit mask for EPDC_PIGEON_13_0_MASK_CNT_SEL. */
#define BS_EPDC_PIGEON_13_0_MASK_CNT_SEL (4U) /*!< Bit field size in bits for EPDC_PIGEON_13_0_MASK_CNT_SEL. */

#define BV_EPDC_PIGEON_13_0_MASK_CNT_SEL_HSTATE_CNT (0U) /*!< Bit field value for EPDC_PIGEON_13_0_MASK_CNT_SEL: pclk counter within one hscan state */
#define BV_EPDC_PIGEON_13_0_MASK_CNT_SEL_HSTATE_CYCLE (0x1U) /*!< Bit field value for EPDC_PIGEON_13_0_MASK_CNT_SEL: pclk cycle within one hscan state */
#define BV_EPDC_PIGEON_13_0_MASK_CNT_SEL_VSTATE_CNT (0x2U) /*!< Bit field value for EPDC_PIGEON_13_0_MASK_CNT_SEL: line counter within one vscan state */
#define BV_EPDC_PIGEON_13_0_MASK_CNT_SEL_VSTATE_CYCLE (0x3U) /*!< Bit field value for EPDC_PIGEON_13_0_MASK_CNT_SEL: line cycle within one vscan state */
#define BV_EPDC_PIGEON_13_0_MASK_CNT_SEL_FRAME_CNT (0x4U) /*!< Bit field value for EPDC_PIGEON_13_0_MASK_CNT_SEL: frame counter */
#define BV_EPDC_PIGEON_13_0_MASK_CNT_SEL_FRAME_CYCLE (0x5U) /*!< Bit field value for EPDC_PIGEON_13_0_MASK_CNT_SEL: frame cycle */
#define BV_EPDC_PIGEON_13_0_MASK_CNT_SEL_HCNT (0x6U) /*!< Bit field value for EPDC_PIGEON_13_0_MASK_CNT_SEL: horizontal counter (pclk counter within one line ) */
#define BV_EPDC_PIGEON_13_0_MASK_CNT_SEL_VCNT (0x7U) /*!< Bit field value for EPDC_PIGEON_13_0_MASK_CNT_SEL: vertical counter (line counter within one frame) */

/*! @brief Read current value of the EPDC_PIGEON_13_0_MASK_CNT_SEL field. */
#define BR_EPDC_PIGEON_13_0_MASK_CNT_SEL(x) (HW_EPDC_PIGEON_13_0(x).B.MASK_CNT_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_13_0_MASK_CNT_SEL. */
#define BF_EPDC_PIGEON_13_0_MASK_CNT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_13_0_MASK_CNT_SEL) & BM_EPDC_PIGEON_13_0_MASK_CNT_SEL)

/*! @brief Set the MASK_CNT_SEL field to a new value. */
#define BW_EPDC_PIGEON_13_0_MASK_CNT_SEL(x, v) (HW_EPDC_PIGEON_13_0_WR(x, (HW_EPDC_PIGEON_13_0_RD(x) & ~BM_EPDC_PIGEON_13_0_MASK_CNT_SEL) | BF_EPDC_PIGEON_13_0_MASK_CNT_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_13_0, field MASK_CNT[23:12] (RW)
 *
 * When the global counter selected through MASK_CNT_SEL matches value in this
 * reg, pigeon local counter start ticking. 0=disable
 */
/*@{*/
#define BP_EPDC_PIGEON_13_0_MASK_CNT (12U) /*!< Bit position for EPDC_PIGEON_13_0_MASK_CNT. */
#define BM_EPDC_PIGEON_13_0_MASK_CNT (0x00FFF000U) /*!< Bit mask for EPDC_PIGEON_13_0_MASK_CNT. */
#define BS_EPDC_PIGEON_13_0_MASK_CNT (12U) /*!< Bit field size in bits for EPDC_PIGEON_13_0_MASK_CNT. */

/*! @brief Read current value of the EPDC_PIGEON_13_0_MASK_CNT field. */
#define BR_EPDC_PIGEON_13_0_MASK_CNT(x) (HW_EPDC_PIGEON_13_0(x).B.MASK_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_13_0_MASK_CNT. */
#define BF_EPDC_PIGEON_13_0_MASK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_13_0_MASK_CNT) & BM_EPDC_PIGEON_13_0_MASK_CNT)

/*! @brief Set the MASK_CNT field to a new value. */
#define BW_EPDC_PIGEON_13_0_MASK_CNT(x, v) (HW_EPDC_PIGEON_13_0_WR(x, (HW_EPDC_PIGEON_13_0_RD(x) & ~BM_EPDC_PIGEON_13_0_MASK_CNT) | BF_EPDC_PIGEON_13_0_MASK_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_13_0, field STATE_MASK[31:24] (RW)
 *
 * state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan
 * states as reference point for local counter to start ticking
 *
 * Values:
 * - 1 - FRAME SYNC
 * - 10 - FRAME BEGIN
 * - 100 - FRAME DATA
 * - 1000 - FRAME END
 * - 10000 - LINE SYNC
 * - 100000 - LINE BEGIN
 * - 1000000 - LINE DATA
 * - 10000000 - LINE END
 */
/*@{*/
#define BP_EPDC_PIGEON_13_0_STATE_MASK (24U) /*!< Bit position for EPDC_PIGEON_13_0_STATE_MASK. */
#define BM_EPDC_PIGEON_13_0_STATE_MASK (0xFF000000U) /*!< Bit mask for EPDC_PIGEON_13_0_STATE_MASK. */
#define BS_EPDC_PIGEON_13_0_STATE_MASK (8U) /*!< Bit field size in bits for EPDC_PIGEON_13_0_STATE_MASK. */

#define BV_EPDC_PIGEON_13_0_STATE_MASK_FS (0x1U)     /*!< Bit field value for EPDC_PIGEON_13_0_STATE_MASK: FRAME SYNC */
#define BV_EPDC_PIGEON_13_0_STATE_MASK_FB (0x2U)     /*!< Bit field value for EPDC_PIGEON_13_0_STATE_MASK: FRAME BEGIN */
#define BV_EPDC_PIGEON_13_0_STATE_MASK_FD (0x4U)     /*!< Bit field value for EPDC_PIGEON_13_0_STATE_MASK: FRAME DATA */
#define BV_EPDC_PIGEON_13_0_STATE_MASK_FE (0x8U)     /*!< Bit field value for EPDC_PIGEON_13_0_STATE_MASK: FRAME END */
#define BV_EPDC_PIGEON_13_0_STATE_MASK_LS (0x10U)    /*!< Bit field value for EPDC_PIGEON_13_0_STATE_MASK: LINE SYNC */
#define BV_EPDC_PIGEON_13_0_STATE_MASK_LB (0x20U)    /*!< Bit field value for EPDC_PIGEON_13_0_STATE_MASK: LINE BEGIN */
#define BV_EPDC_PIGEON_13_0_STATE_MASK_LD (0x40U)    /*!< Bit field value for EPDC_PIGEON_13_0_STATE_MASK: LINE DATA */
#define BV_EPDC_PIGEON_13_0_STATE_MASK_LE (0x80U)    /*!< Bit field value for EPDC_PIGEON_13_0_STATE_MASK: LINE END */

/*! @brief Read current value of the EPDC_PIGEON_13_0_STATE_MASK field. */
#define BR_EPDC_PIGEON_13_0_STATE_MASK(x) (HW_EPDC_PIGEON_13_0(x).B.STATE_MASK)

/*! @brief Format value for bitfield EPDC_PIGEON_13_0_STATE_MASK. */
#define BF_EPDC_PIGEON_13_0_STATE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_13_0_STATE_MASK) & BM_EPDC_PIGEON_13_0_STATE_MASK)

/*! @brief Set the STATE_MASK field to a new value. */
#define BW_EPDC_PIGEON_13_0_STATE_MASK(x, v) (HW_EPDC_PIGEON_13_0_WR(x, (HW_EPDC_PIGEON_13_0_RD(x) & ~BM_EPDC_PIGEON_13_0_STATE_MASK) | BF_EPDC_PIGEON_13_0_STATE_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_13_1 - Panel Interface Signal Generator Register 13_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_13_1 - Panel Interface Signal Generator Register 13_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_13_1
{
    uint32_t U;
    struct _hw_epdc_pigeon_13_1_bitfields
    {
        uint32_t SET_CNT : 16;         /*!< [15:0]  */
        uint32_t CLR_CNT : 16;         /*!< [31:16]  */
    } B;
} hw_epdc_pigeon_13_1_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_13_1 register
 */
/*@{*/
#define HW_EPDC_PIGEON_13_1_ADDR(x) ((uintptr_t)(x) + 0xB50U)

#define HW_EPDC_PIGEON_13_1(x)   (*(__IO hw_epdc_pigeon_13_1_t *) HW_EPDC_PIGEON_13_1_ADDR(x))
#define HW_EPDC_PIGEON_13_1_RD(x) (HW_EPDC_PIGEON_13_1(x).U)
#define HW_EPDC_PIGEON_13_1_WR(x, v) (HW_EPDC_PIGEON_13_1(x).U = (v))
#define HW_EPDC_PIGEON_13_1_SET(x, v) (HW_EPDC_PIGEON_13_1_WR(x, HW_EPDC_PIGEON_13_1_RD(x) |  (v)))
#define HW_EPDC_PIGEON_13_1_CLR(x, v) (HW_EPDC_PIGEON_13_1_WR(x, HW_EPDC_PIGEON_13_1_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_13_1_TOG(x, v) (HW_EPDC_PIGEON_13_1_WR(x, HW_EPDC_PIGEON_13_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_13_1 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_13_1, field SET_CNT[15:0] (RW)
 *
 * assert signal output when counter match this value
 *
 * Values:
 * - 0 - start as active
 */
/*@{*/
#define BP_EPDC_PIGEON_13_1_SET_CNT (0U)   /*!< Bit position for EPDC_PIGEON_13_1_SET_CNT. */
#define BM_EPDC_PIGEON_13_1_SET_CNT (0x0000FFFFU) /*!< Bit mask for EPDC_PIGEON_13_1_SET_CNT. */
#define BS_EPDC_PIGEON_13_1_SET_CNT (16U)  /*!< Bit field size in bits for EPDC_PIGEON_13_1_SET_CNT. */

#define BV_EPDC_PIGEON_13_1_SET_CNT_START_ACTIVE (0U) /*!< Bit field value for EPDC_PIGEON_13_1_SET_CNT: start as active */

/*! @brief Read current value of the EPDC_PIGEON_13_1_SET_CNT field. */
#define BR_EPDC_PIGEON_13_1_SET_CNT(x) (HW_EPDC_PIGEON_13_1(x).B.SET_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_13_1_SET_CNT. */
#define BF_EPDC_PIGEON_13_1_SET_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_13_1_SET_CNT) & BM_EPDC_PIGEON_13_1_SET_CNT)

/*! @brief Set the SET_CNT field to a new value. */
#define BW_EPDC_PIGEON_13_1_SET_CNT(x, v) (HW_EPDC_PIGEON_13_1_WR(x, (HW_EPDC_PIGEON_13_1_RD(x) & ~BM_EPDC_PIGEON_13_1_SET_CNT) | BF_EPDC_PIGEON_13_1_SET_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_13_1, field CLR_CNT[31:16] (RW)
 *
 * deassert signal output when counter match this value
 *
 * Values:
 * - 0 - keep active until mask off
 */
/*@{*/
#define BP_EPDC_PIGEON_13_1_CLR_CNT (16U)  /*!< Bit position for EPDC_PIGEON_13_1_CLR_CNT. */
#define BM_EPDC_PIGEON_13_1_CLR_CNT (0xFFFF0000U) /*!< Bit mask for EPDC_PIGEON_13_1_CLR_CNT. */
#define BS_EPDC_PIGEON_13_1_CLR_CNT (16U)  /*!< Bit field size in bits for EPDC_PIGEON_13_1_CLR_CNT. */

#define BV_EPDC_PIGEON_13_1_CLR_CNT_CLEAR_USING_MASK (0U) /*!< Bit field value for EPDC_PIGEON_13_1_CLR_CNT: keep active until mask off */

/*! @brief Read current value of the EPDC_PIGEON_13_1_CLR_CNT field. */
#define BR_EPDC_PIGEON_13_1_CLR_CNT(x) (HW_EPDC_PIGEON_13_1(x).B.CLR_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_13_1_CLR_CNT. */
#define BF_EPDC_PIGEON_13_1_CLR_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_13_1_CLR_CNT) & BM_EPDC_PIGEON_13_1_CLR_CNT)

/*! @brief Set the CLR_CNT field to a new value. */
#define BW_EPDC_PIGEON_13_1_CLR_CNT(x, v) (HW_EPDC_PIGEON_13_1_WR(x, (HW_EPDC_PIGEON_13_1_RD(x) & ~BM_EPDC_PIGEON_13_1_CLR_CNT) | BF_EPDC_PIGEON_13_1_CLR_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_13_2 - Panel Interface Signal Generator Register 13_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_13_2 - Panel Interface Signal Generator Register 13_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_13_2
{
    uint32_t U;
    struct _hw_epdc_pigeon_13_2_bitfields
    {
        uint32_t SIG_LOGIC : 4;        /*!< [3:0]  */
        uint32_t SIG_ANOTHER : 5;      /*!< [8:4]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_epdc_pigeon_13_2_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_13_2 register
 */
/*@{*/
#define HW_EPDC_PIGEON_13_2_ADDR(x) ((uintptr_t)(x) + 0xB60U)

#define HW_EPDC_PIGEON_13_2(x)   (*(__IO hw_epdc_pigeon_13_2_t *) HW_EPDC_PIGEON_13_2_ADDR(x))
#define HW_EPDC_PIGEON_13_2_RD(x) (HW_EPDC_PIGEON_13_2(x).U)
#define HW_EPDC_PIGEON_13_2_WR(x, v) (HW_EPDC_PIGEON_13_2(x).U = (v))
#define HW_EPDC_PIGEON_13_2_SET(x, v) (HW_EPDC_PIGEON_13_2_WR(x, HW_EPDC_PIGEON_13_2_RD(x) |  (v)))
#define HW_EPDC_PIGEON_13_2_CLR(x, v) (HW_EPDC_PIGEON_13_2_WR(x, HW_EPDC_PIGEON_13_2_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_13_2_TOG(x, v) (HW_EPDC_PIGEON_13_2_WR(x, HW_EPDC_PIGEON_13_2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_13_2 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_13_2, field SIG_LOGIC[3:0] (RW)
 *
 * logic operation with another signal sigout : final output signal of this
 * generator mask : final mask of this generator this_sig : intermediate signal of
 * this generator before logic operation other_masks : intermediate mask result of
 * this generator before logic operation sig_another : signal selected other
 * generators
 *
 * Values:
 * - 0 - no logic operation
 * - 1 - sigout = sig_another AND this_sig
 * - 10 - sigout = sig_another OR this_sig
 * - 11 - mask = sig_another AND other_masks
 */
/*@{*/
#define BP_EPDC_PIGEON_13_2_SIG_LOGIC (0U) /*!< Bit position for EPDC_PIGEON_13_2_SIG_LOGIC. */
#define BM_EPDC_PIGEON_13_2_SIG_LOGIC (0x0000000FU) /*!< Bit mask for EPDC_PIGEON_13_2_SIG_LOGIC. */
#define BS_EPDC_PIGEON_13_2_SIG_LOGIC (4U) /*!< Bit field size in bits for EPDC_PIGEON_13_2_SIG_LOGIC. */

#define BV_EPDC_PIGEON_13_2_SIG_LOGIC_DIS (0U)       /*!< Bit field value for EPDC_PIGEON_13_2_SIG_LOGIC: no logic operation */
#define BV_EPDC_PIGEON_13_2_SIG_LOGIC_AND (0x1U)     /*!< Bit field value for EPDC_PIGEON_13_2_SIG_LOGIC: sigout = sig_another AND this_sig */
#define BV_EPDC_PIGEON_13_2_SIG_LOGIC_OR (0x2U)      /*!< Bit field value for EPDC_PIGEON_13_2_SIG_LOGIC: sigout = sig_another OR this_sig */
#define BV_EPDC_PIGEON_13_2_SIG_LOGIC_MASK (0x3U)    /*!< Bit field value for EPDC_PIGEON_13_2_SIG_LOGIC: mask = sig_another AND other_masks */

/*! @brief Read current value of the EPDC_PIGEON_13_2_SIG_LOGIC field. */
#define BR_EPDC_PIGEON_13_2_SIG_LOGIC(x) (HW_EPDC_PIGEON_13_2(x).B.SIG_LOGIC)

/*! @brief Format value for bitfield EPDC_PIGEON_13_2_SIG_LOGIC. */
#define BF_EPDC_PIGEON_13_2_SIG_LOGIC(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_13_2_SIG_LOGIC) & BM_EPDC_PIGEON_13_2_SIG_LOGIC)

/*! @brief Set the SIG_LOGIC field to a new value. */
#define BW_EPDC_PIGEON_13_2_SIG_LOGIC(x, v) (HW_EPDC_PIGEON_13_2_WR(x, (HW_EPDC_PIGEON_13_2_RD(x) & ~BM_EPDC_PIGEON_13_2_SIG_LOGIC) | BF_EPDC_PIGEON_13_2_SIG_LOGIC(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_13_2, field SIG_ANOTHER[8:4] (RW)
 *
 * select another signal for logic operation or as mask or counter tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_13_2_SIG_ANOTHER (4U) /*!< Bit position for EPDC_PIGEON_13_2_SIG_ANOTHER. */
#define BM_EPDC_PIGEON_13_2_SIG_ANOTHER (0x000001F0U) /*!< Bit mask for EPDC_PIGEON_13_2_SIG_ANOTHER. */
#define BS_EPDC_PIGEON_13_2_SIG_ANOTHER (5U) /*!< Bit field size in bits for EPDC_PIGEON_13_2_SIG_ANOTHER. */

/*! @brief Read current value of the EPDC_PIGEON_13_2_SIG_ANOTHER field. */
#define BR_EPDC_PIGEON_13_2_SIG_ANOTHER(x) (HW_EPDC_PIGEON_13_2(x).B.SIG_ANOTHER)

/*! @brief Format value for bitfield EPDC_PIGEON_13_2_SIG_ANOTHER. */
#define BF_EPDC_PIGEON_13_2_SIG_ANOTHER(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_13_2_SIG_ANOTHER) & BM_EPDC_PIGEON_13_2_SIG_ANOTHER)

/*! @brief Set the SIG_ANOTHER field to a new value. */
#define BW_EPDC_PIGEON_13_2_SIG_ANOTHER(x, v) (HW_EPDC_PIGEON_13_2_WR(x, (HW_EPDC_PIGEON_13_2_RD(x) & ~BM_EPDC_PIGEON_13_2_SIG_ANOTHER) | BF_EPDC_PIGEON_13_2_SIG_ANOTHER(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_14_0 - Panel Interface Signal Generator Register 14_0
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_14_0 - Panel Interface Signal Generator Register 14_0 (RW)
 *
 * Reset value: 0x00000F00U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_14_0
{
    uint32_t U;
    struct _hw_epdc_pigeon_14_0_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t POL : 1;              /*!< [1]  */
        uint32_t INC_SEL : 2;          /*!< [3:2]  */
        uint32_t OFFSET : 4;           /*!< [7:4]  */
        uint32_t MASK_CNT_SEL : 4;     /*!< [11:8]  */
        uint32_t MASK_CNT : 12;        /*!< [23:12]  */
        uint32_t STATE_MASK : 8;       /*!< [31:24]  */
    } B;
} hw_epdc_pigeon_14_0_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_14_0 register
 */
/*@{*/
#define HW_EPDC_PIGEON_14_0_ADDR(x) ((uintptr_t)(x) + 0xB80U)

#define HW_EPDC_PIGEON_14_0(x)   (*(__IO hw_epdc_pigeon_14_0_t *) HW_EPDC_PIGEON_14_0_ADDR(x))
#define HW_EPDC_PIGEON_14_0_RD(x) (HW_EPDC_PIGEON_14_0(x).U)
#define HW_EPDC_PIGEON_14_0_WR(x, v) (HW_EPDC_PIGEON_14_0(x).U = (v))
#define HW_EPDC_PIGEON_14_0_SET(x, v) (HW_EPDC_PIGEON_14_0_WR(x, HW_EPDC_PIGEON_14_0_RD(x) |  (v)))
#define HW_EPDC_PIGEON_14_0_CLR(x, v) (HW_EPDC_PIGEON_14_0_WR(x, HW_EPDC_PIGEON_14_0_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_14_0_TOG(x, v) (HW_EPDC_PIGEON_14_0_WR(x, HW_EPDC_PIGEON_14_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_14_0 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_14_0, field EN[0] (RW)
 *
 * enable pigeon mode on this signal
 */
/*@{*/
#define BP_EPDC_PIGEON_14_0_EN (0U)        /*!< Bit position for EPDC_PIGEON_14_0_EN. */
#define BM_EPDC_PIGEON_14_0_EN (0x00000001U) /*!< Bit mask for EPDC_PIGEON_14_0_EN. */
#define BS_EPDC_PIGEON_14_0_EN (1U)        /*!< Bit field size in bits for EPDC_PIGEON_14_0_EN. */

/*! @brief Read current value of the EPDC_PIGEON_14_0_EN field. */
#define BR_EPDC_PIGEON_14_0_EN(x) (HW_EPDC_PIGEON_14_0(x).B.EN)

/*! @brief Format value for bitfield EPDC_PIGEON_14_0_EN. */
#define BF_EPDC_PIGEON_14_0_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_14_0_EN) & BM_EPDC_PIGEON_14_0_EN)

/*! @brief Set the EN field to a new value. */
#define BW_EPDC_PIGEON_14_0_EN(x, v) (HW_EPDC_PIGEON_14_0_WR(x, (HW_EPDC_PIGEON_14_0_RD(x) & ~BM_EPDC_PIGEON_14_0_EN) | BF_EPDC_PIGEON_14_0_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_14_0, field POL[1] (RW)
 *
 * polarity of signal output
 *
 * Values:
 * - 0 - normal signal (active high)
 * - 1 - inverted signal (active low)
 */
/*@{*/
#define BP_EPDC_PIGEON_14_0_POL (1U)       /*!< Bit position for EPDC_PIGEON_14_0_POL. */
#define BM_EPDC_PIGEON_14_0_POL (0x00000002U) /*!< Bit mask for EPDC_PIGEON_14_0_POL. */
#define BS_EPDC_PIGEON_14_0_POL (1U)       /*!< Bit field size in bits for EPDC_PIGEON_14_0_POL. */

#define BV_EPDC_PIGEON_14_0_POL_ACTIVE_HIGH (0U)     /*!< Bit field value for EPDC_PIGEON_14_0_POL: normal signal (active high) */
#define BV_EPDC_PIGEON_14_0_POL_ACTIVE_LOW (0x1U)    /*!< Bit field value for EPDC_PIGEON_14_0_POL: inverted signal (active low) */

/*! @brief Read current value of the EPDC_PIGEON_14_0_POL field. */
#define BR_EPDC_PIGEON_14_0_POL(x) (HW_EPDC_PIGEON_14_0(x).B.POL)

/*! @brief Format value for bitfield EPDC_PIGEON_14_0_POL. */
#define BF_EPDC_PIGEON_14_0_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_14_0_POL) & BM_EPDC_PIGEON_14_0_POL)

/*! @brief Set the POL field to a new value. */
#define BW_EPDC_PIGEON_14_0_POL(x, v) (HW_EPDC_PIGEON_14_0_WR(x, (HW_EPDC_PIGEON_14_0_RD(x) & ~BM_EPDC_PIGEON_14_0_POL) | BF_EPDC_PIGEON_14_0_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_14_0, field INC_SEL[3:2] (RW)
 *
 * event to incrment local counter
 *
 * Values:
 * - 0 - pclk
 * - 1 - line start pulse
 * - 10 - frame start pulse
 * - 11 - use another signal as tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_14_0_INC_SEL (2U)   /*!< Bit position for EPDC_PIGEON_14_0_INC_SEL. */
#define BM_EPDC_PIGEON_14_0_INC_SEL (0x0000000CU) /*!< Bit mask for EPDC_PIGEON_14_0_INC_SEL. */
#define BS_EPDC_PIGEON_14_0_INC_SEL (2U)   /*!< Bit field size in bits for EPDC_PIGEON_14_0_INC_SEL. */

#define BV_EPDC_PIGEON_14_0_INC_SEL_PCLK (0U)        /*!< Bit field value for EPDC_PIGEON_14_0_INC_SEL: pclk */
#define BV_EPDC_PIGEON_14_0_INC_SEL_LINE (0x1U)      /*!< Bit field value for EPDC_PIGEON_14_0_INC_SEL: line start pulse */
#define BV_EPDC_PIGEON_14_0_INC_SEL_FRAME (0x2U)     /*!< Bit field value for EPDC_PIGEON_14_0_INC_SEL: frame start pulse */
#define BV_EPDC_PIGEON_14_0_INC_SEL_SIG_ANOTHER (0x3U) /*!< Bit field value for EPDC_PIGEON_14_0_INC_SEL: use another signal as tick event */

/*! @brief Read current value of the EPDC_PIGEON_14_0_INC_SEL field. */
#define BR_EPDC_PIGEON_14_0_INC_SEL(x) (HW_EPDC_PIGEON_14_0(x).B.INC_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_14_0_INC_SEL. */
#define BF_EPDC_PIGEON_14_0_INC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_14_0_INC_SEL) & BM_EPDC_PIGEON_14_0_INC_SEL)

/*! @brief Set the INC_SEL field to a new value. */
#define BW_EPDC_PIGEON_14_0_INC_SEL(x, v) (HW_EPDC_PIGEON_14_0_WR(x, (HW_EPDC_PIGEON_14_0_RD(x) & ~BM_EPDC_PIGEON_14_0_INC_SEL) | BF_EPDC_PIGEON_14_0_INC_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_14_0, field OFFSET[7:4] (RW)
 *
 * offset on pclk unit. 0=aligne with data, positive value means delay, minus
 * value mean ahead. Supported range depends on panel mode
 */
/*@{*/
#define BP_EPDC_PIGEON_14_0_OFFSET (4U)    /*!< Bit position for EPDC_PIGEON_14_0_OFFSET. */
#define BM_EPDC_PIGEON_14_0_OFFSET (0x000000F0U) /*!< Bit mask for EPDC_PIGEON_14_0_OFFSET. */
#define BS_EPDC_PIGEON_14_0_OFFSET (4U)    /*!< Bit field size in bits for EPDC_PIGEON_14_0_OFFSET. */

/*! @brief Read current value of the EPDC_PIGEON_14_0_OFFSET field. */
#define BR_EPDC_PIGEON_14_0_OFFSET(x) (HW_EPDC_PIGEON_14_0(x).B.OFFSET)

/*! @brief Format value for bitfield EPDC_PIGEON_14_0_OFFSET. */
#define BF_EPDC_PIGEON_14_0_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_14_0_OFFSET) & BM_EPDC_PIGEON_14_0_OFFSET)

/*! @brief Set the OFFSET field to a new value. */
#define BW_EPDC_PIGEON_14_0_OFFSET(x, v) (HW_EPDC_PIGEON_14_0_WR(x, (HW_EPDC_PIGEON_14_0_RD(x) & ~BM_EPDC_PIGEON_14_0_OFFSET) | BF_EPDC_PIGEON_14_0_OFFSET(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_14_0, field MASK_CNT_SEL[11:8] (RW)
 *
 * select global counters as mask condition, use together with MASK_CNT
 *
 * Values:
 * - 0 - pclk counter within one hscan state
 * - 1 - pclk cycle within one hscan state
 * - 10 - line counter within one vscan state
 * - 11 - line cycle within one vscan state
 * - 100 - frame counter
 * - 101 - frame cycle
 * - 110 - horizontal counter (pclk counter within one line )
 * - 111 - vertical counter (line counter within one frame)
 */
/*@{*/
#define BP_EPDC_PIGEON_14_0_MASK_CNT_SEL (8U) /*!< Bit position for EPDC_PIGEON_14_0_MASK_CNT_SEL. */
#define BM_EPDC_PIGEON_14_0_MASK_CNT_SEL (0x00000F00U) /*!< Bit mask for EPDC_PIGEON_14_0_MASK_CNT_SEL. */
#define BS_EPDC_PIGEON_14_0_MASK_CNT_SEL (4U) /*!< Bit field size in bits for EPDC_PIGEON_14_0_MASK_CNT_SEL. */

#define BV_EPDC_PIGEON_14_0_MASK_CNT_SEL_HSTATE_CNT (0U) /*!< Bit field value for EPDC_PIGEON_14_0_MASK_CNT_SEL: pclk counter within one hscan state */
#define BV_EPDC_PIGEON_14_0_MASK_CNT_SEL_HSTATE_CYCLE (0x1U) /*!< Bit field value for EPDC_PIGEON_14_0_MASK_CNT_SEL: pclk cycle within one hscan state */
#define BV_EPDC_PIGEON_14_0_MASK_CNT_SEL_VSTATE_CNT (0x2U) /*!< Bit field value for EPDC_PIGEON_14_0_MASK_CNT_SEL: line counter within one vscan state */
#define BV_EPDC_PIGEON_14_0_MASK_CNT_SEL_VSTATE_CYCLE (0x3U) /*!< Bit field value for EPDC_PIGEON_14_0_MASK_CNT_SEL: line cycle within one vscan state */
#define BV_EPDC_PIGEON_14_0_MASK_CNT_SEL_FRAME_CNT (0x4U) /*!< Bit field value for EPDC_PIGEON_14_0_MASK_CNT_SEL: frame counter */
#define BV_EPDC_PIGEON_14_0_MASK_CNT_SEL_FRAME_CYCLE (0x5U) /*!< Bit field value for EPDC_PIGEON_14_0_MASK_CNT_SEL: frame cycle */
#define BV_EPDC_PIGEON_14_0_MASK_CNT_SEL_HCNT (0x6U) /*!< Bit field value for EPDC_PIGEON_14_0_MASK_CNT_SEL: horizontal counter (pclk counter within one line ) */
#define BV_EPDC_PIGEON_14_0_MASK_CNT_SEL_VCNT (0x7U) /*!< Bit field value for EPDC_PIGEON_14_0_MASK_CNT_SEL: vertical counter (line counter within one frame) */

/*! @brief Read current value of the EPDC_PIGEON_14_0_MASK_CNT_SEL field. */
#define BR_EPDC_PIGEON_14_0_MASK_CNT_SEL(x) (HW_EPDC_PIGEON_14_0(x).B.MASK_CNT_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_14_0_MASK_CNT_SEL. */
#define BF_EPDC_PIGEON_14_0_MASK_CNT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_14_0_MASK_CNT_SEL) & BM_EPDC_PIGEON_14_0_MASK_CNT_SEL)

/*! @brief Set the MASK_CNT_SEL field to a new value. */
#define BW_EPDC_PIGEON_14_0_MASK_CNT_SEL(x, v) (HW_EPDC_PIGEON_14_0_WR(x, (HW_EPDC_PIGEON_14_0_RD(x) & ~BM_EPDC_PIGEON_14_0_MASK_CNT_SEL) | BF_EPDC_PIGEON_14_0_MASK_CNT_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_14_0, field MASK_CNT[23:12] (RW)
 *
 * When the global counter selected through MASK_CNT_SEL matches value in this
 * reg, pigeon local counter start ticking. 0=disable
 */
/*@{*/
#define BP_EPDC_PIGEON_14_0_MASK_CNT (12U) /*!< Bit position for EPDC_PIGEON_14_0_MASK_CNT. */
#define BM_EPDC_PIGEON_14_0_MASK_CNT (0x00FFF000U) /*!< Bit mask for EPDC_PIGEON_14_0_MASK_CNT. */
#define BS_EPDC_PIGEON_14_0_MASK_CNT (12U) /*!< Bit field size in bits for EPDC_PIGEON_14_0_MASK_CNT. */

/*! @brief Read current value of the EPDC_PIGEON_14_0_MASK_CNT field. */
#define BR_EPDC_PIGEON_14_0_MASK_CNT(x) (HW_EPDC_PIGEON_14_0(x).B.MASK_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_14_0_MASK_CNT. */
#define BF_EPDC_PIGEON_14_0_MASK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_14_0_MASK_CNT) & BM_EPDC_PIGEON_14_0_MASK_CNT)

/*! @brief Set the MASK_CNT field to a new value. */
#define BW_EPDC_PIGEON_14_0_MASK_CNT(x, v) (HW_EPDC_PIGEON_14_0_WR(x, (HW_EPDC_PIGEON_14_0_RD(x) & ~BM_EPDC_PIGEON_14_0_MASK_CNT) | BF_EPDC_PIGEON_14_0_MASK_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_14_0, field STATE_MASK[31:24] (RW)
 *
 * state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan
 * states as reference point for local counter to start ticking
 *
 * Values:
 * - 1 - FRAME SYNC
 * - 10 - FRAME BEGIN
 * - 100 - FRAME DATA
 * - 1000 - FRAME END
 * - 10000 - LINE SYNC
 * - 100000 - LINE BEGIN
 * - 1000000 - LINE DATA
 * - 10000000 - LINE END
 */
/*@{*/
#define BP_EPDC_PIGEON_14_0_STATE_MASK (24U) /*!< Bit position for EPDC_PIGEON_14_0_STATE_MASK. */
#define BM_EPDC_PIGEON_14_0_STATE_MASK (0xFF000000U) /*!< Bit mask for EPDC_PIGEON_14_0_STATE_MASK. */
#define BS_EPDC_PIGEON_14_0_STATE_MASK (8U) /*!< Bit field size in bits for EPDC_PIGEON_14_0_STATE_MASK. */

#define BV_EPDC_PIGEON_14_0_STATE_MASK_FS (0x1U)     /*!< Bit field value for EPDC_PIGEON_14_0_STATE_MASK: FRAME SYNC */
#define BV_EPDC_PIGEON_14_0_STATE_MASK_FB (0x2U)     /*!< Bit field value for EPDC_PIGEON_14_0_STATE_MASK: FRAME BEGIN */
#define BV_EPDC_PIGEON_14_0_STATE_MASK_FD (0x4U)     /*!< Bit field value for EPDC_PIGEON_14_0_STATE_MASK: FRAME DATA */
#define BV_EPDC_PIGEON_14_0_STATE_MASK_FE (0x8U)     /*!< Bit field value for EPDC_PIGEON_14_0_STATE_MASK: FRAME END */
#define BV_EPDC_PIGEON_14_0_STATE_MASK_LS (0x10U)    /*!< Bit field value for EPDC_PIGEON_14_0_STATE_MASK: LINE SYNC */
#define BV_EPDC_PIGEON_14_0_STATE_MASK_LB (0x20U)    /*!< Bit field value for EPDC_PIGEON_14_0_STATE_MASK: LINE BEGIN */
#define BV_EPDC_PIGEON_14_0_STATE_MASK_LD (0x40U)    /*!< Bit field value for EPDC_PIGEON_14_0_STATE_MASK: LINE DATA */
#define BV_EPDC_PIGEON_14_0_STATE_MASK_LE (0x80U)    /*!< Bit field value for EPDC_PIGEON_14_0_STATE_MASK: LINE END */

/*! @brief Read current value of the EPDC_PIGEON_14_0_STATE_MASK field. */
#define BR_EPDC_PIGEON_14_0_STATE_MASK(x) (HW_EPDC_PIGEON_14_0(x).B.STATE_MASK)

/*! @brief Format value for bitfield EPDC_PIGEON_14_0_STATE_MASK. */
#define BF_EPDC_PIGEON_14_0_STATE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_14_0_STATE_MASK) & BM_EPDC_PIGEON_14_0_STATE_MASK)

/*! @brief Set the STATE_MASK field to a new value. */
#define BW_EPDC_PIGEON_14_0_STATE_MASK(x, v) (HW_EPDC_PIGEON_14_0_WR(x, (HW_EPDC_PIGEON_14_0_RD(x) & ~BM_EPDC_PIGEON_14_0_STATE_MASK) | BF_EPDC_PIGEON_14_0_STATE_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_14_1 - Panel Interface Signal Generator Register 14_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_14_1 - Panel Interface Signal Generator Register 14_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_14_1
{
    uint32_t U;
    struct _hw_epdc_pigeon_14_1_bitfields
    {
        uint32_t SET_CNT : 16;         /*!< [15:0]  */
        uint32_t CLR_CNT : 16;         /*!< [31:16]  */
    } B;
} hw_epdc_pigeon_14_1_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_14_1 register
 */
/*@{*/
#define HW_EPDC_PIGEON_14_1_ADDR(x) ((uintptr_t)(x) + 0xB90U)

#define HW_EPDC_PIGEON_14_1(x)   (*(__IO hw_epdc_pigeon_14_1_t *) HW_EPDC_PIGEON_14_1_ADDR(x))
#define HW_EPDC_PIGEON_14_1_RD(x) (HW_EPDC_PIGEON_14_1(x).U)
#define HW_EPDC_PIGEON_14_1_WR(x, v) (HW_EPDC_PIGEON_14_1(x).U = (v))
#define HW_EPDC_PIGEON_14_1_SET(x, v) (HW_EPDC_PIGEON_14_1_WR(x, HW_EPDC_PIGEON_14_1_RD(x) |  (v)))
#define HW_EPDC_PIGEON_14_1_CLR(x, v) (HW_EPDC_PIGEON_14_1_WR(x, HW_EPDC_PIGEON_14_1_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_14_1_TOG(x, v) (HW_EPDC_PIGEON_14_1_WR(x, HW_EPDC_PIGEON_14_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_14_1 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_14_1, field SET_CNT[15:0] (RW)
 *
 * assert signal output when counter match this value
 *
 * Values:
 * - 0 - start as active
 */
/*@{*/
#define BP_EPDC_PIGEON_14_1_SET_CNT (0U)   /*!< Bit position for EPDC_PIGEON_14_1_SET_CNT. */
#define BM_EPDC_PIGEON_14_1_SET_CNT (0x0000FFFFU) /*!< Bit mask for EPDC_PIGEON_14_1_SET_CNT. */
#define BS_EPDC_PIGEON_14_1_SET_CNT (16U)  /*!< Bit field size in bits for EPDC_PIGEON_14_1_SET_CNT. */

#define BV_EPDC_PIGEON_14_1_SET_CNT_START_ACTIVE (0U) /*!< Bit field value for EPDC_PIGEON_14_1_SET_CNT: start as active */

/*! @brief Read current value of the EPDC_PIGEON_14_1_SET_CNT field. */
#define BR_EPDC_PIGEON_14_1_SET_CNT(x) (HW_EPDC_PIGEON_14_1(x).B.SET_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_14_1_SET_CNT. */
#define BF_EPDC_PIGEON_14_1_SET_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_14_1_SET_CNT) & BM_EPDC_PIGEON_14_1_SET_CNT)

/*! @brief Set the SET_CNT field to a new value. */
#define BW_EPDC_PIGEON_14_1_SET_CNT(x, v) (HW_EPDC_PIGEON_14_1_WR(x, (HW_EPDC_PIGEON_14_1_RD(x) & ~BM_EPDC_PIGEON_14_1_SET_CNT) | BF_EPDC_PIGEON_14_1_SET_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_14_1, field CLR_CNT[31:16] (RW)
 *
 * deassert signal output when counter match this value
 *
 * Values:
 * - 0 - keep active until mask off
 */
/*@{*/
#define BP_EPDC_PIGEON_14_1_CLR_CNT (16U)  /*!< Bit position for EPDC_PIGEON_14_1_CLR_CNT. */
#define BM_EPDC_PIGEON_14_1_CLR_CNT (0xFFFF0000U) /*!< Bit mask for EPDC_PIGEON_14_1_CLR_CNT. */
#define BS_EPDC_PIGEON_14_1_CLR_CNT (16U)  /*!< Bit field size in bits for EPDC_PIGEON_14_1_CLR_CNT. */

#define BV_EPDC_PIGEON_14_1_CLR_CNT_CLEAR_USING_MASK (0U) /*!< Bit field value for EPDC_PIGEON_14_1_CLR_CNT: keep active until mask off */

/*! @brief Read current value of the EPDC_PIGEON_14_1_CLR_CNT field. */
#define BR_EPDC_PIGEON_14_1_CLR_CNT(x) (HW_EPDC_PIGEON_14_1(x).B.CLR_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_14_1_CLR_CNT. */
#define BF_EPDC_PIGEON_14_1_CLR_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_14_1_CLR_CNT) & BM_EPDC_PIGEON_14_1_CLR_CNT)

/*! @brief Set the CLR_CNT field to a new value. */
#define BW_EPDC_PIGEON_14_1_CLR_CNT(x, v) (HW_EPDC_PIGEON_14_1_WR(x, (HW_EPDC_PIGEON_14_1_RD(x) & ~BM_EPDC_PIGEON_14_1_CLR_CNT) | BF_EPDC_PIGEON_14_1_CLR_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_14_2 - Panel Interface Signal Generator Register 14_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_14_2 - Panel Interface Signal Generator Register 14_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_14_2
{
    uint32_t U;
    struct _hw_epdc_pigeon_14_2_bitfields
    {
        uint32_t SIG_LOGIC : 4;        /*!< [3:0]  */
        uint32_t SIG_ANOTHER : 5;      /*!< [8:4]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_epdc_pigeon_14_2_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_14_2 register
 */
/*@{*/
#define HW_EPDC_PIGEON_14_2_ADDR(x) ((uintptr_t)(x) + 0xBA0U)

#define HW_EPDC_PIGEON_14_2(x)   (*(__IO hw_epdc_pigeon_14_2_t *) HW_EPDC_PIGEON_14_2_ADDR(x))
#define HW_EPDC_PIGEON_14_2_RD(x) (HW_EPDC_PIGEON_14_2(x).U)
#define HW_EPDC_PIGEON_14_2_WR(x, v) (HW_EPDC_PIGEON_14_2(x).U = (v))
#define HW_EPDC_PIGEON_14_2_SET(x, v) (HW_EPDC_PIGEON_14_2_WR(x, HW_EPDC_PIGEON_14_2_RD(x) |  (v)))
#define HW_EPDC_PIGEON_14_2_CLR(x, v) (HW_EPDC_PIGEON_14_2_WR(x, HW_EPDC_PIGEON_14_2_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_14_2_TOG(x, v) (HW_EPDC_PIGEON_14_2_WR(x, HW_EPDC_PIGEON_14_2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_14_2 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_14_2, field SIG_LOGIC[3:0] (RW)
 *
 * logic operation with another signal sigout : final output signal of this
 * generator mask : final mask of this generator this_sig : intermediate signal of
 * this generator before logic operation other_masks : intermediate mask result of
 * this generator before logic operation sig_another : signal selected other
 * generators
 *
 * Values:
 * - 0 - no logic operation
 * - 1 - sigout = sig_another AND this_sig
 * - 10 - sigout = sig_another OR this_sig
 * - 11 - mask = sig_another AND other_masks
 */
/*@{*/
#define BP_EPDC_PIGEON_14_2_SIG_LOGIC (0U) /*!< Bit position for EPDC_PIGEON_14_2_SIG_LOGIC. */
#define BM_EPDC_PIGEON_14_2_SIG_LOGIC (0x0000000FU) /*!< Bit mask for EPDC_PIGEON_14_2_SIG_LOGIC. */
#define BS_EPDC_PIGEON_14_2_SIG_LOGIC (4U) /*!< Bit field size in bits for EPDC_PIGEON_14_2_SIG_LOGIC. */

#define BV_EPDC_PIGEON_14_2_SIG_LOGIC_DIS (0U)       /*!< Bit field value for EPDC_PIGEON_14_2_SIG_LOGIC: no logic operation */
#define BV_EPDC_PIGEON_14_2_SIG_LOGIC_AND (0x1U)     /*!< Bit field value for EPDC_PIGEON_14_2_SIG_LOGIC: sigout = sig_another AND this_sig */
#define BV_EPDC_PIGEON_14_2_SIG_LOGIC_OR (0x2U)      /*!< Bit field value for EPDC_PIGEON_14_2_SIG_LOGIC: sigout = sig_another OR this_sig */
#define BV_EPDC_PIGEON_14_2_SIG_LOGIC_MASK (0x3U)    /*!< Bit field value for EPDC_PIGEON_14_2_SIG_LOGIC: mask = sig_another AND other_masks */

/*! @brief Read current value of the EPDC_PIGEON_14_2_SIG_LOGIC field. */
#define BR_EPDC_PIGEON_14_2_SIG_LOGIC(x) (HW_EPDC_PIGEON_14_2(x).B.SIG_LOGIC)

/*! @brief Format value for bitfield EPDC_PIGEON_14_2_SIG_LOGIC. */
#define BF_EPDC_PIGEON_14_2_SIG_LOGIC(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_14_2_SIG_LOGIC) & BM_EPDC_PIGEON_14_2_SIG_LOGIC)

/*! @brief Set the SIG_LOGIC field to a new value. */
#define BW_EPDC_PIGEON_14_2_SIG_LOGIC(x, v) (HW_EPDC_PIGEON_14_2_WR(x, (HW_EPDC_PIGEON_14_2_RD(x) & ~BM_EPDC_PIGEON_14_2_SIG_LOGIC) | BF_EPDC_PIGEON_14_2_SIG_LOGIC(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_14_2, field SIG_ANOTHER[8:4] (RW)
 *
 * select another signal for logic operation or as mask or counter tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_14_2_SIG_ANOTHER (4U) /*!< Bit position for EPDC_PIGEON_14_2_SIG_ANOTHER. */
#define BM_EPDC_PIGEON_14_2_SIG_ANOTHER (0x000001F0U) /*!< Bit mask for EPDC_PIGEON_14_2_SIG_ANOTHER. */
#define BS_EPDC_PIGEON_14_2_SIG_ANOTHER (5U) /*!< Bit field size in bits for EPDC_PIGEON_14_2_SIG_ANOTHER. */

/*! @brief Read current value of the EPDC_PIGEON_14_2_SIG_ANOTHER field. */
#define BR_EPDC_PIGEON_14_2_SIG_ANOTHER(x) (HW_EPDC_PIGEON_14_2(x).B.SIG_ANOTHER)

/*! @brief Format value for bitfield EPDC_PIGEON_14_2_SIG_ANOTHER. */
#define BF_EPDC_PIGEON_14_2_SIG_ANOTHER(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_14_2_SIG_ANOTHER) & BM_EPDC_PIGEON_14_2_SIG_ANOTHER)

/*! @brief Set the SIG_ANOTHER field to a new value. */
#define BW_EPDC_PIGEON_14_2_SIG_ANOTHER(x, v) (HW_EPDC_PIGEON_14_2_WR(x, (HW_EPDC_PIGEON_14_2_RD(x) & ~BM_EPDC_PIGEON_14_2_SIG_ANOTHER) | BF_EPDC_PIGEON_14_2_SIG_ANOTHER(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_15_0 - Panel Interface Signal Generator Register 15_0
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_15_0 - Panel Interface Signal Generator Register 15_0 (RW)
 *
 * Reset value: 0x00000F00U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_15_0
{
    uint32_t U;
    struct _hw_epdc_pigeon_15_0_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t POL : 1;              /*!< [1]  */
        uint32_t INC_SEL : 2;          /*!< [3:2]  */
        uint32_t OFFSET : 4;           /*!< [7:4]  */
        uint32_t MASK_CNT_SEL : 4;     /*!< [11:8]  */
        uint32_t MASK_CNT : 12;        /*!< [23:12]  */
        uint32_t STATE_MASK : 8;       /*!< [31:24]  */
    } B;
} hw_epdc_pigeon_15_0_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_15_0 register
 */
/*@{*/
#define HW_EPDC_PIGEON_15_0_ADDR(x) ((uintptr_t)(x) + 0xBC0U)

#define HW_EPDC_PIGEON_15_0(x)   (*(__IO hw_epdc_pigeon_15_0_t *) HW_EPDC_PIGEON_15_0_ADDR(x))
#define HW_EPDC_PIGEON_15_0_RD(x) (HW_EPDC_PIGEON_15_0(x).U)
#define HW_EPDC_PIGEON_15_0_WR(x, v) (HW_EPDC_PIGEON_15_0(x).U = (v))
#define HW_EPDC_PIGEON_15_0_SET(x, v) (HW_EPDC_PIGEON_15_0_WR(x, HW_EPDC_PIGEON_15_0_RD(x) |  (v)))
#define HW_EPDC_PIGEON_15_0_CLR(x, v) (HW_EPDC_PIGEON_15_0_WR(x, HW_EPDC_PIGEON_15_0_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_15_0_TOG(x, v) (HW_EPDC_PIGEON_15_0_WR(x, HW_EPDC_PIGEON_15_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_15_0 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_15_0, field EN[0] (RW)
 *
 * enable pigeon mode on this signal
 */
/*@{*/
#define BP_EPDC_PIGEON_15_0_EN (0U)        /*!< Bit position for EPDC_PIGEON_15_0_EN. */
#define BM_EPDC_PIGEON_15_0_EN (0x00000001U) /*!< Bit mask for EPDC_PIGEON_15_0_EN. */
#define BS_EPDC_PIGEON_15_0_EN (1U)        /*!< Bit field size in bits for EPDC_PIGEON_15_0_EN. */

/*! @brief Read current value of the EPDC_PIGEON_15_0_EN field. */
#define BR_EPDC_PIGEON_15_0_EN(x) (HW_EPDC_PIGEON_15_0(x).B.EN)

/*! @brief Format value for bitfield EPDC_PIGEON_15_0_EN. */
#define BF_EPDC_PIGEON_15_0_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_15_0_EN) & BM_EPDC_PIGEON_15_0_EN)

/*! @brief Set the EN field to a new value. */
#define BW_EPDC_PIGEON_15_0_EN(x, v) (HW_EPDC_PIGEON_15_0_WR(x, (HW_EPDC_PIGEON_15_0_RD(x) & ~BM_EPDC_PIGEON_15_0_EN) | BF_EPDC_PIGEON_15_0_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_15_0, field POL[1] (RW)
 *
 * polarity of signal output
 *
 * Values:
 * - 0 - normal signal (active high)
 * - 1 - inverted signal (active low)
 */
/*@{*/
#define BP_EPDC_PIGEON_15_0_POL (1U)       /*!< Bit position for EPDC_PIGEON_15_0_POL. */
#define BM_EPDC_PIGEON_15_0_POL (0x00000002U) /*!< Bit mask for EPDC_PIGEON_15_0_POL. */
#define BS_EPDC_PIGEON_15_0_POL (1U)       /*!< Bit field size in bits for EPDC_PIGEON_15_0_POL. */

#define BV_EPDC_PIGEON_15_0_POL_ACTIVE_HIGH (0U)     /*!< Bit field value for EPDC_PIGEON_15_0_POL: normal signal (active high) */
#define BV_EPDC_PIGEON_15_0_POL_ACTIVE_LOW (0x1U)    /*!< Bit field value for EPDC_PIGEON_15_0_POL: inverted signal (active low) */

/*! @brief Read current value of the EPDC_PIGEON_15_0_POL field. */
#define BR_EPDC_PIGEON_15_0_POL(x) (HW_EPDC_PIGEON_15_0(x).B.POL)

/*! @brief Format value for bitfield EPDC_PIGEON_15_0_POL. */
#define BF_EPDC_PIGEON_15_0_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_15_0_POL) & BM_EPDC_PIGEON_15_0_POL)

/*! @brief Set the POL field to a new value. */
#define BW_EPDC_PIGEON_15_0_POL(x, v) (HW_EPDC_PIGEON_15_0_WR(x, (HW_EPDC_PIGEON_15_0_RD(x) & ~BM_EPDC_PIGEON_15_0_POL) | BF_EPDC_PIGEON_15_0_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_15_0, field INC_SEL[3:2] (RW)
 *
 * event to incrment local counter
 *
 * Values:
 * - 0 - pclk
 * - 1 - line start pulse
 * - 10 - frame start pulse
 * - 11 - use another signal as tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_15_0_INC_SEL (2U)   /*!< Bit position for EPDC_PIGEON_15_0_INC_SEL. */
#define BM_EPDC_PIGEON_15_0_INC_SEL (0x0000000CU) /*!< Bit mask for EPDC_PIGEON_15_0_INC_SEL. */
#define BS_EPDC_PIGEON_15_0_INC_SEL (2U)   /*!< Bit field size in bits for EPDC_PIGEON_15_0_INC_SEL. */

#define BV_EPDC_PIGEON_15_0_INC_SEL_PCLK (0U)        /*!< Bit field value for EPDC_PIGEON_15_0_INC_SEL: pclk */
#define BV_EPDC_PIGEON_15_0_INC_SEL_LINE (0x1U)      /*!< Bit field value for EPDC_PIGEON_15_0_INC_SEL: line start pulse */
#define BV_EPDC_PIGEON_15_0_INC_SEL_FRAME (0x2U)     /*!< Bit field value for EPDC_PIGEON_15_0_INC_SEL: frame start pulse */
#define BV_EPDC_PIGEON_15_0_INC_SEL_SIG_ANOTHER (0x3U) /*!< Bit field value for EPDC_PIGEON_15_0_INC_SEL: use another signal as tick event */

/*! @brief Read current value of the EPDC_PIGEON_15_0_INC_SEL field. */
#define BR_EPDC_PIGEON_15_0_INC_SEL(x) (HW_EPDC_PIGEON_15_0(x).B.INC_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_15_0_INC_SEL. */
#define BF_EPDC_PIGEON_15_0_INC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_15_0_INC_SEL) & BM_EPDC_PIGEON_15_0_INC_SEL)

/*! @brief Set the INC_SEL field to a new value. */
#define BW_EPDC_PIGEON_15_0_INC_SEL(x, v) (HW_EPDC_PIGEON_15_0_WR(x, (HW_EPDC_PIGEON_15_0_RD(x) & ~BM_EPDC_PIGEON_15_0_INC_SEL) | BF_EPDC_PIGEON_15_0_INC_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_15_0, field OFFSET[7:4] (RW)
 *
 * offset on pclk unit. 0=aligne with data, positive value means delay, minus
 * value mean ahead. Supported range depends on panel mode
 */
/*@{*/
#define BP_EPDC_PIGEON_15_0_OFFSET (4U)    /*!< Bit position for EPDC_PIGEON_15_0_OFFSET. */
#define BM_EPDC_PIGEON_15_0_OFFSET (0x000000F0U) /*!< Bit mask for EPDC_PIGEON_15_0_OFFSET. */
#define BS_EPDC_PIGEON_15_0_OFFSET (4U)    /*!< Bit field size in bits for EPDC_PIGEON_15_0_OFFSET. */

/*! @brief Read current value of the EPDC_PIGEON_15_0_OFFSET field. */
#define BR_EPDC_PIGEON_15_0_OFFSET(x) (HW_EPDC_PIGEON_15_0(x).B.OFFSET)

/*! @brief Format value for bitfield EPDC_PIGEON_15_0_OFFSET. */
#define BF_EPDC_PIGEON_15_0_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_15_0_OFFSET) & BM_EPDC_PIGEON_15_0_OFFSET)

/*! @brief Set the OFFSET field to a new value. */
#define BW_EPDC_PIGEON_15_0_OFFSET(x, v) (HW_EPDC_PIGEON_15_0_WR(x, (HW_EPDC_PIGEON_15_0_RD(x) & ~BM_EPDC_PIGEON_15_0_OFFSET) | BF_EPDC_PIGEON_15_0_OFFSET(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_15_0, field MASK_CNT_SEL[11:8] (RW)
 *
 * select global counters as mask condition, use together with MASK_CNT
 *
 * Values:
 * - 0 - pclk counter within one hscan state
 * - 1 - pclk cycle within one hscan state
 * - 10 - line counter within one vscan state
 * - 11 - line cycle within one vscan state
 * - 100 - frame counter
 * - 101 - frame cycle
 * - 110 - horizontal counter (pclk counter within one line )
 * - 111 - vertical counter (line counter within one frame)
 */
/*@{*/
#define BP_EPDC_PIGEON_15_0_MASK_CNT_SEL (8U) /*!< Bit position for EPDC_PIGEON_15_0_MASK_CNT_SEL. */
#define BM_EPDC_PIGEON_15_0_MASK_CNT_SEL (0x00000F00U) /*!< Bit mask for EPDC_PIGEON_15_0_MASK_CNT_SEL. */
#define BS_EPDC_PIGEON_15_0_MASK_CNT_SEL (4U) /*!< Bit field size in bits for EPDC_PIGEON_15_0_MASK_CNT_SEL. */

#define BV_EPDC_PIGEON_15_0_MASK_CNT_SEL_HSTATE_CNT (0U) /*!< Bit field value for EPDC_PIGEON_15_0_MASK_CNT_SEL: pclk counter within one hscan state */
#define BV_EPDC_PIGEON_15_0_MASK_CNT_SEL_HSTATE_CYCLE (0x1U) /*!< Bit field value for EPDC_PIGEON_15_0_MASK_CNT_SEL: pclk cycle within one hscan state */
#define BV_EPDC_PIGEON_15_0_MASK_CNT_SEL_VSTATE_CNT (0x2U) /*!< Bit field value for EPDC_PIGEON_15_0_MASK_CNT_SEL: line counter within one vscan state */
#define BV_EPDC_PIGEON_15_0_MASK_CNT_SEL_VSTATE_CYCLE (0x3U) /*!< Bit field value for EPDC_PIGEON_15_0_MASK_CNT_SEL: line cycle within one vscan state */
#define BV_EPDC_PIGEON_15_0_MASK_CNT_SEL_FRAME_CNT (0x4U) /*!< Bit field value for EPDC_PIGEON_15_0_MASK_CNT_SEL: frame counter */
#define BV_EPDC_PIGEON_15_0_MASK_CNT_SEL_FRAME_CYCLE (0x5U) /*!< Bit field value for EPDC_PIGEON_15_0_MASK_CNT_SEL: frame cycle */
#define BV_EPDC_PIGEON_15_0_MASK_CNT_SEL_HCNT (0x6U) /*!< Bit field value for EPDC_PIGEON_15_0_MASK_CNT_SEL: horizontal counter (pclk counter within one line ) */
#define BV_EPDC_PIGEON_15_0_MASK_CNT_SEL_VCNT (0x7U) /*!< Bit field value for EPDC_PIGEON_15_0_MASK_CNT_SEL: vertical counter (line counter within one frame) */

/*! @brief Read current value of the EPDC_PIGEON_15_0_MASK_CNT_SEL field. */
#define BR_EPDC_PIGEON_15_0_MASK_CNT_SEL(x) (HW_EPDC_PIGEON_15_0(x).B.MASK_CNT_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_15_0_MASK_CNT_SEL. */
#define BF_EPDC_PIGEON_15_0_MASK_CNT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_15_0_MASK_CNT_SEL) & BM_EPDC_PIGEON_15_0_MASK_CNT_SEL)

/*! @brief Set the MASK_CNT_SEL field to a new value. */
#define BW_EPDC_PIGEON_15_0_MASK_CNT_SEL(x, v) (HW_EPDC_PIGEON_15_0_WR(x, (HW_EPDC_PIGEON_15_0_RD(x) & ~BM_EPDC_PIGEON_15_0_MASK_CNT_SEL) | BF_EPDC_PIGEON_15_0_MASK_CNT_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_15_0, field MASK_CNT[23:12] (RW)
 *
 * When the global counter selected through MASK_CNT_SEL matches value in this
 * reg, pigeon local counter start ticking. 0=disable
 */
/*@{*/
#define BP_EPDC_PIGEON_15_0_MASK_CNT (12U) /*!< Bit position for EPDC_PIGEON_15_0_MASK_CNT. */
#define BM_EPDC_PIGEON_15_0_MASK_CNT (0x00FFF000U) /*!< Bit mask for EPDC_PIGEON_15_0_MASK_CNT. */
#define BS_EPDC_PIGEON_15_0_MASK_CNT (12U) /*!< Bit field size in bits for EPDC_PIGEON_15_0_MASK_CNT. */

/*! @brief Read current value of the EPDC_PIGEON_15_0_MASK_CNT field. */
#define BR_EPDC_PIGEON_15_0_MASK_CNT(x) (HW_EPDC_PIGEON_15_0(x).B.MASK_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_15_0_MASK_CNT. */
#define BF_EPDC_PIGEON_15_0_MASK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_15_0_MASK_CNT) & BM_EPDC_PIGEON_15_0_MASK_CNT)

/*! @brief Set the MASK_CNT field to a new value. */
#define BW_EPDC_PIGEON_15_0_MASK_CNT(x, v) (HW_EPDC_PIGEON_15_0_WR(x, (HW_EPDC_PIGEON_15_0_RD(x) & ~BM_EPDC_PIGEON_15_0_MASK_CNT) | BF_EPDC_PIGEON_15_0_MASK_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_15_0, field STATE_MASK[31:24] (RW)
 *
 * state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan
 * states as reference point for local counter to start ticking
 *
 * Values:
 * - 1 - FRAME SYNC
 * - 10 - FRAME BEGIN
 * - 100 - FRAME DATA
 * - 1000 - FRAME END
 * - 10000 - LINE SYNC
 * - 100000 - LINE BEGIN
 * - 1000000 - LINE DATA
 * - 10000000 - LINE END
 */
/*@{*/
#define BP_EPDC_PIGEON_15_0_STATE_MASK (24U) /*!< Bit position for EPDC_PIGEON_15_0_STATE_MASK. */
#define BM_EPDC_PIGEON_15_0_STATE_MASK (0xFF000000U) /*!< Bit mask for EPDC_PIGEON_15_0_STATE_MASK. */
#define BS_EPDC_PIGEON_15_0_STATE_MASK (8U) /*!< Bit field size in bits for EPDC_PIGEON_15_0_STATE_MASK. */

#define BV_EPDC_PIGEON_15_0_STATE_MASK_FS (0x1U)     /*!< Bit field value for EPDC_PIGEON_15_0_STATE_MASK: FRAME SYNC */
#define BV_EPDC_PIGEON_15_0_STATE_MASK_FB (0x2U)     /*!< Bit field value for EPDC_PIGEON_15_0_STATE_MASK: FRAME BEGIN */
#define BV_EPDC_PIGEON_15_0_STATE_MASK_FD (0x4U)     /*!< Bit field value for EPDC_PIGEON_15_0_STATE_MASK: FRAME DATA */
#define BV_EPDC_PIGEON_15_0_STATE_MASK_FE (0x8U)     /*!< Bit field value for EPDC_PIGEON_15_0_STATE_MASK: FRAME END */
#define BV_EPDC_PIGEON_15_0_STATE_MASK_LS (0x10U)    /*!< Bit field value for EPDC_PIGEON_15_0_STATE_MASK: LINE SYNC */
#define BV_EPDC_PIGEON_15_0_STATE_MASK_LB (0x20U)    /*!< Bit field value for EPDC_PIGEON_15_0_STATE_MASK: LINE BEGIN */
#define BV_EPDC_PIGEON_15_0_STATE_MASK_LD (0x40U)    /*!< Bit field value for EPDC_PIGEON_15_0_STATE_MASK: LINE DATA */
#define BV_EPDC_PIGEON_15_0_STATE_MASK_LE (0x80U)    /*!< Bit field value for EPDC_PIGEON_15_0_STATE_MASK: LINE END */

/*! @brief Read current value of the EPDC_PIGEON_15_0_STATE_MASK field. */
#define BR_EPDC_PIGEON_15_0_STATE_MASK(x) (HW_EPDC_PIGEON_15_0(x).B.STATE_MASK)

/*! @brief Format value for bitfield EPDC_PIGEON_15_0_STATE_MASK. */
#define BF_EPDC_PIGEON_15_0_STATE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_15_0_STATE_MASK) & BM_EPDC_PIGEON_15_0_STATE_MASK)

/*! @brief Set the STATE_MASK field to a new value. */
#define BW_EPDC_PIGEON_15_0_STATE_MASK(x, v) (HW_EPDC_PIGEON_15_0_WR(x, (HW_EPDC_PIGEON_15_0_RD(x) & ~BM_EPDC_PIGEON_15_0_STATE_MASK) | BF_EPDC_PIGEON_15_0_STATE_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_15_1 - Panel Interface Signal Generator Register 15_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_15_1 - Panel Interface Signal Generator Register 15_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_15_1
{
    uint32_t U;
    struct _hw_epdc_pigeon_15_1_bitfields
    {
        uint32_t SET_CNT : 16;         /*!< [15:0]  */
        uint32_t CLR_CNT : 16;         /*!< [31:16]  */
    } B;
} hw_epdc_pigeon_15_1_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_15_1 register
 */
/*@{*/
#define HW_EPDC_PIGEON_15_1_ADDR(x) ((uintptr_t)(x) + 0xBD0U)

#define HW_EPDC_PIGEON_15_1(x)   (*(__IO hw_epdc_pigeon_15_1_t *) HW_EPDC_PIGEON_15_1_ADDR(x))
#define HW_EPDC_PIGEON_15_1_RD(x) (HW_EPDC_PIGEON_15_1(x).U)
#define HW_EPDC_PIGEON_15_1_WR(x, v) (HW_EPDC_PIGEON_15_1(x).U = (v))
#define HW_EPDC_PIGEON_15_1_SET(x, v) (HW_EPDC_PIGEON_15_1_WR(x, HW_EPDC_PIGEON_15_1_RD(x) |  (v)))
#define HW_EPDC_PIGEON_15_1_CLR(x, v) (HW_EPDC_PIGEON_15_1_WR(x, HW_EPDC_PIGEON_15_1_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_15_1_TOG(x, v) (HW_EPDC_PIGEON_15_1_WR(x, HW_EPDC_PIGEON_15_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_15_1 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_15_1, field SET_CNT[15:0] (RW)
 *
 * assert signal output when counter match this value
 *
 * Values:
 * - 0 - start as active
 */
/*@{*/
#define BP_EPDC_PIGEON_15_1_SET_CNT (0U)   /*!< Bit position for EPDC_PIGEON_15_1_SET_CNT. */
#define BM_EPDC_PIGEON_15_1_SET_CNT (0x0000FFFFU) /*!< Bit mask for EPDC_PIGEON_15_1_SET_CNT. */
#define BS_EPDC_PIGEON_15_1_SET_CNT (16U)  /*!< Bit field size in bits for EPDC_PIGEON_15_1_SET_CNT. */

#define BV_EPDC_PIGEON_15_1_SET_CNT_START_ACTIVE (0U) /*!< Bit field value for EPDC_PIGEON_15_1_SET_CNT: start as active */

/*! @brief Read current value of the EPDC_PIGEON_15_1_SET_CNT field. */
#define BR_EPDC_PIGEON_15_1_SET_CNT(x) (HW_EPDC_PIGEON_15_1(x).B.SET_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_15_1_SET_CNT. */
#define BF_EPDC_PIGEON_15_1_SET_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_15_1_SET_CNT) & BM_EPDC_PIGEON_15_1_SET_CNT)

/*! @brief Set the SET_CNT field to a new value. */
#define BW_EPDC_PIGEON_15_1_SET_CNT(x, v) (HW_EPDC_PIGEON_15_1_WR(x, (HW_EPDC_PIGEON_15_1_RD(x) & ~BM_EPDC_PIGEON_15_1_SET_CNT) | BF_EPDC_PIGEON_15_1_SET_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_15_1, field CLR_CNT[31:16] (RW)
 *
 * deassert signal output when counter match this value
 *
 * Values:
 * - 0 - keep active until mask off
 */
/*@{*/
#define BP_EPDC_PIGEON_15_1_CLR_CNT (16U)  /*!< Bit position for EPDC_PIGEON_15_1_CLR_CNT. */
#define BM_EPDC_PIGEON_15_1_CLR_CNT (0xFFFF0000U) /*!< Bit mask for EPDC_PIGEON_15_1_CLR_CNT. */
#define BS_EPDC_PIGEON_15_1_CLR_CNT (16U)  /*!< Bit field size in bits for EPDC_PIGEON_15_1_CLR_CNT. */

#define BV_EPDC_PIGEON_15_1_CLR_CNT_CLEAR_USING_MASK (0U) /*!< Bit field value for EPDC_PIGEON_15_1_CLR_CNT: keep active until mask off */

/*! @brief Read current value of the EPDC_PIGEON_15_1_CLR_CNT field. */
#define BR_EPDC_PIGEON_15_1_CLR_CNT(x) (HW_EPDC_PIGEON_15_1(x).B.CLR_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_15_1_CLR_CNT. */
#define BF_EPDC_PIGEON_15_1_CLR_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_15_1_CLR_CNT) & BM_EPDC_PIGEON_15_1_CLR_CNT)

/*! @brief Set the CLR_CNT field to a new value. */
#define BW_EPDC_PIGEON_15_1_CLR_CNT(x, v) (HW_EPDC_PIGEON_15_1_WR(x, (HW_EPDC_PIGEON_15_1_RD(x) & ~BM_EPDC_PIGEON_15_1_CLR_CNT) | BF_EPDC_PIGEON_15_1_CLR_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_15_2 - Panel Interface Signal Generator Register 15_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_15_2 - Panel Interface Signal Generator Register 15_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_15_2
{
    uint32_t U;
    struct _hw_epdc_pigeon_15_2_bitfields
    {
        uint32_t SIG_LOGIC : 4;        /*!< [3:0]  */
        uint32_t SIG_ANOTHER : 5;      /*!< [8:4]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_epdc_pigeon_15_2_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_15_2 register
 */
/*@{*/
#define HW_EPDC_PIGEON_15_2_ADDR(x) ((uintptr_t)(x) + 0xBE0U)

#define HW_EPDC_PIGEON_15_2(x)   (*(__IO hw_epdc_pigeon_15_2_t *) HW_EPDC_PIGEON_15_2_ADDR(x))
#define HW_EPDC_PIGEON_15_2_RD(x) (HW_EPDC_PIGEON_15_2(x).U)
#define HW_EPDC_PIGEON_15_2_WR(x, v) (HW_EPDC_PIGEON_15_2(x).U = (v))
#define HW_EPDC_PIGEON_15_2_SET(x, v) (HW_EPDC_PIGEON_15_2_WR(x, HW_EPDC_PIGEON_15_2_RD(x) |  (v)))
#define HW_EPDC_PIGEON_15_2_CLR(x, v) (HW_EPDC_PIGEON_15_2_WR(x, HW_EPDC_PIGEON_15_2_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_15_2_TOG(x, v) (HW_EPDC_PIGEON_15_2_WR(x, HW_EPDC_PIGEON_15_2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_15_2 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_15_2, field SIG_LOGIC[3:0] (RW)
 *
 * logic operation with another signal sigout : final output signal of this
 * generator mask : final mask of this generator this_sig : intermediate signal of
 * this generator before logic operation other_masks : intermediate mask result of
 * this generator before logic operation sig_another : signal selected other
 * generators
 *
 * Values:
 * - 0 - no logic operation
 * - 1 - sigout = sig_another AND this_sig
 * - 10 - sigout = sig_another OR this_sig
 * - 11 - mask = sig_another AND other_masks
 */
/*@{*/
#define BP_EPDC_PIGEON_15_2_SIG_LOGIC (0U) /*!< Bit position for EPDC_PIGEON_15_2_SIG_LOGIC. */
#define BM_EPDC_PIGEON_15_2_SIG_LOGIC (0x0000000FU) /*!< Bit mask for EPDC_PIGEON_15_2_SIG_LOGIC. */
#define BS_EPDC_PIGEON_15_2_SIG_LOGIC (4U) /*!< Bit field size in bits for EPDC_PIGEON_15_2_SIG_LOGIC. */

#define BV_EPDC_PIGEON_15_2_SIG_LOGIC_DIS (0U)       /*!< Bit field value for EPDC_PIGEON_15_2_SIG_LOGIC: no logic operation */
#define BV_EPDC_PIGEON_15_2_SIG_LOGIC_AND (0x1U)     /*!< Bit field value for EPDC_PIGEON_15_2_SIG_LOGIC: sigout = sig_another AND this_sig */
#define BV_EPDC_PIGEON_15_2_SIG_LOGIC_OR (0x2U)      /*!< Bit field value for EPDC_PIGEON_15_2_SIG_LOGIC: sigout = sig_another OR this_sig */
#define BV_EPDC_PIGEON_15_2_SIG_LOGIC_MASK (0x3U)    /*!< Bit field value for EPDC_PIGEON_15_2_SIG_LOGIC: mask = sig_another AND other_masks */

/*! @brief Read current value of the EPDC_PIGEON_15_2_SIG_LOGIC field. */
#define BR_EPDC_PIGEON_15_2_SIG_LOGIC(x) (HW_EPDC_PIGEON_15_2(x).B.SIG_LOGIC)

/*! @brief Format value for bitfield EPDC_PIGEON_15_2_SIG_LOGIC. */
#define BF_EPDC_PIGEON_15_2_SIG_LOGIC(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_15_2_SIG_LOGIC) & BM_EPDC_PIGEON_15_2_SIG_LOGIC)

/*! @brief Set the SIG_LOGIC field to a new value. */
#define BW_EPDC_PIGEON_15_2_SIG_LOGIC(x, v) (HW_EPDC_PIGEON_15_2_WR(x, (HW_EPDC_PIGEON_15_2_RD(x) & ~BM_EPDC_PIGEON_15_2_SIG_LOGIC) | BF_EPDC_PIGEON_15_2_SIG_LOGIC(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_15_2, field SIG_ANOTHER[8:4] (RW)
 *
 * select another signal for logic operation or as mask or counter tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_15_2_SIG_ANOTHER (4U) /*!< Bit position for EPDC_PIGEON_15_2_SIG_ANOTHER. */
#define BM_EPDC_PIGEON_15_2_SIG_ANOTHER (0x000001F0U) /*!< Bit mask for EPDC_PIGEON_15_2_SIG_ANOTHER. */
#define BS_EPDC_PIGEON_15_2_SIG_ANOTHER (5U) /*!< Bit field size in bits for EPDC_PIGEON_15_2_SIG_ANOTHER. */

/*! @brief Read current value of the EPDC_PIGEON_15_2_SIG_ANOTHER field. */
#define BR_EPDC_PIGEON_15_2_SIG_ANOTHER(x) (HW_EPDC_PIGEON_15_2(x).B.SIG_ANOTHER)

/*! @brief Format value for bitfield EPDC_PIGEON_15_2_SIG_ANOTHER. */
#define BF_EPDC_PIGEON_15_2_SIG_ANOTHER(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_15_2_SIG_ANOTHER) & BM_EPDC_PIGEON_15_2_SIG_ANOTHER)

/*! @brief Set the SIG_ANOTHER field to a new value. */
#define BW_EPDC_PIGEON_15_2_SIG_ANOTHER(x, v) (HW_EPDC_PIGEON_15_2_WR(x, (HW_EPDC_PIGEON_15_2_RD(x) & ~BM_EPDC_PIGEON_15_2_SIG_ANOTHER) | BF_EPDC_PIGEON_15_2_SIG_ANOTHER(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_16_0 - Panel Interface Signal Generator Register 16_0
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_16_0 - Panel Interface Signal Generator Register 16_0 (RW)
 *
 * Reset value: 0x00000F00U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_16_0
{
    uint32_t U;
    struct _hw_epdc_pigeon_16_0_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t POL : 1;              /*!< [1]  */
        uint32_t INC_SEL : 2;          /*!< [3:2]  */
        uint32_t OFFSET : 4;           /*!< [7:4]  */
        uint32_t MASK_CNT_SEL : 4;     /*!< [11:8]  */
        uint32_t MASK_CNT : 12;        /*!< [23:12]  */
        uint32_t STATE_MASK : 8;       /*!< [31:24]  */
    } B;
} hw_epdc_pigeon_16_0_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_16_0 register
 */
/*@{*/
#define HW_EPDC_PIGEON_16_0_ADDR(x) ((uintptr_t)(x) + 0xC00U)

#define HW_EPDC_PIGEON_16_0(x)   (*(__IO hw_epdc_pigeon_16_0_t *) HW_EPDC_PIGEON_16_0_ADDR(x))
#define HW_EPDC_PIGEON_16_0_RD(x) (HW_EPDC_PIGEON_16_0(x).U)
#define HW_EPDC_PIGEON_16_0_WR(x, v) (HW_EPDC_PIGEON_16_0(x).U = (v))
#define HW_EPDC_PIGEON_16_0_SET(x, v) (HW_EPDC_PIGEON_16_0_WR(x, HW_EPDC_PIGEON_16_0_RD(x) |  (v)))
#define HW_EPDC_PIGEON_16_0_CLR(x, v) (HW_EPDC_PIGEON_16_0_WR(x, HW_EPDC_PIGEON_16_0_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_16_0_TOG(x, v) (HW_EPDC_PIGEON_16_0_WR(x, HW_EPDC_PIGEON_16_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_16_0 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_16_0, field EN[0] (RW)
 *
 * enable pigeon mode on this signal
 */
/*@{*/
#define BP_EPDC_PIGEON_16_0_EN (0U)        /*!< Bit position for EPDC_PIGEON_16_0_EN. */
#define BM_EPDC_PIGEON_16_0_EN (0x00000001U) /*!< Bit mask for EPDC_PIGEON_16_0_EN. */
#define BS_EPDC_PIGEON_16_0_EN (1U)        /*!< Bit field size in bits for EPDC_PIGEON_16_0_EN. */

/*! @brief Read current value of the EPDC_PIGEON_16_0_EN field. */
#define BR_EPDC_PIGEON_16_0_EN(x) (HW_EPDC_PIGEON_16_0(x).B.EN)

/*! @brief Format value for bitfield EPDC_PIGEON_16_0_EN. */
#define BF_EPDC_PIGEON_16_0_EN(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_16_0_EN) & BM_EPDC_PIGEON_16_0_EN)

/*! @brief Set the EN field to a new value. */
#define BW_EPDC_PIGEON_16_0_EN(x, v) (HW_EPDC_PIGEON_16_0_WR(x, (HW_EPDC_PIGEON_16_0_RD(x) & ~BM_EPDC_PIGEON_16_0_EN) | BF_EPDC_PIGEON_16_0_EN(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_16_0, field POL[1] (RW)
 *
 * polarity of signal output
 *
 * Values:
 * - 0 - normal signal (active high)
 * - 1 - inverted signal (active low)
 */
/*@{*/
#define BP_EPDC_PIGEON_16_0_POL (1U)       /*!< Bit position for EPDC_PIGEON_16_0_POL. */
#define BM_EPDC_PIGEON_16_0_POL (0x00000002U) /*!< Bit mask for EPDC_PIGEON_16_0_POL. */
#define BS_EPDC_PIGEON_16_0_POL (1U)       /*!< Bit field size in bits for EPDC_PIGEON_16_0_POL. */

#define BV_EPDC_PIGEON_16_0_POL_ACTIVE_HIGH (0U)     /*!< Bit field value for EPDC_PIGEON_16_0_POL: normal signal (active high) */
#define BV_EPDC_PIGEON_16_0_POL_ACTIVE_LOW (0x1U)    /*!< Bit field value for EPDC_PIGEON_16_0_POL: inverted signal (active low) */

/*! @brief Read current value of the EPDC_PIGEON_16_0_POL field. */
#define BR_EPDC_PIGEON_16_0_POL(x) (HW_EPDC_PIGEON_16_0(x).B.POL)

/*! @brief Format value for bitfield EPDC_PIGEON_16_0_POL. */
#define BF_EPDC_PIGEON_16_0_POL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_16_0_POL) & BM_EPDC_PIGEON_16_0_POL)

/*! @brief Set the POL field to a new value. */
#define BW_EPDC_PIGEON_16_0_POL(x, v) (HW_EPDC_PIGEON_16_0_WR(x, (HW_EPDC_PIGEON_16_0_RD(x) & ~BM_EPDC_PIGEON_16_0_POL) | BF_EPDC_PIGEON_16_0_POL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_16_0, field INC_SEL[3:2] (RW)
 *
 * event to incrment local counter
 *
 * Values:
 * - 0 - pclk
 * - 1 - line start pulse
 * - 10 - frame start pulse
 * - 11 - use another signal as tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_16_0_INC_SEL (2U)   /*!< Bit position for EPDC_PIGEON_16_0_INC_SEL. */
#define BM_EPDC_PIGEON_16_0_INC_SEL (0x0000000CU) /*!< Bit mask for EPDC_PIGEON_16_0_INC_SEL. */
#define BS_EPDC_PIGEON_16_0_INC_SEL (2U)   /*!< Bit field size in bits for EPDC_PIGEON_16_0_INC_SEL. */

#define BV_EPDC_PIGEON_16_0_INC_SEL_PCLK (0U)        /*!< Bit field value for EPDC_PIGEON_16_0_INC_SEL: pclk */
#define BV_EPDC_PIGEON_16_0_INC_SEL_LINE (0x1U)      /*!< Bit field value for EPDC_PIGEON_16_0_INC_SEL: line start pulse */
#define BV_EPDC_PIGEON_16_0_INC_SEL_FRAME (0x2U)     /*!< Bit field value for EPDC_PIGEON_16_0_INC_SEL: frame start pulse */
#define BV_EPDC_PIGEON_16_0_INC_SEL_SIG_ANOTHER (0x3U) /*!< Bit field value for EPDC_PIGEON_16_0_INC_SEL: use another signal as tick event */

/*! @brief Read current value of the EPDC_PIGEON_16_0_INC_SEL field. */
#define BR_EPDC_PIGEON_16_0_INC_SEL(x) (HW_EPDC_PIGEON_16_0(x).B.INC_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_16_0_INC_SEL. */
#define BF_EPDC_PIGEON_16_0_INC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_16_0_INC_SEL) & BM_EPDC_PIGEON_16_0_INC_SEL)

/*! @brief Set the INC_SEL field to a new value. */
#define BW_EPDC_PIGEON_16_0_INC_SEL(x, v) (HW_EPDC_PIGEON_16_0_WR(x, (HW_EPDC_PIGEON_16_0_RD(x) & ~BM_EPDC_PIGEON_16_0_INC_SEL) | BF_EPDC_PIGEON_16_0_INC_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_16_0, field OFFSET[7:4] (RW)
 *
 * offset on pclk unit. 0=aligne with data, positive value means delay, minus
 * value mean ahead. Supported range depends on panel mode
 */
/*@{*/
#define BP_EPDC_PIGEON_16_0_OFFSET (4U)    /*!< Bit position for EPDC_PIGEON_16_0_OFFSET. */
#define BM_EPDC_PIGEON_16_0_OFFSET (0x000000F0U) /*!< Bit mask for EPDC_PIGEON_16_0_OFFSET. */
#define BS_EPDC_PIGEON_16_0_OFFSET (4U)    /*!< Bit field size in bits for EPDC_PIGEON_16_0_OFFSET. */

/*! @brief Read current value of the EPDC_PIGEON_16_0_OFFSET field. */
#define BR_EPDC_PIGEON_16_0_OFFSET(x) (HW_EPDC_PIGEON_16_0(x).B.OFFSET)

/*! @brief Format value for bitfield EPDC_PIGEON_16_0_OFFSET. */
#define BF_EPDC_PIGEON_16_0_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_16_0_OFFSET) & BM_EPDC_PIGEON_16_0_OFFSET)

/*! @brief Set the OFFSET field to a new value. */
#define BW_EPDC_PIGEON_16_0_OFFSET(x, v) (HW_EPDC_PIGEON_16_0_WR(x, (HW_EPDC_PIGEON_16_0_RD(x) & ~BM_EPDC_PIGEON_16_0_OFFSET) | BF_EPDC_PIGEON_16_0_OFFSET(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_16_0, field MASK_CNT_SEL[11:8] (RW)
 *
 * select global counters as mask condition, use together with MASK_CNT
 *
 * Values:
 * - 0 - pclk counter within one hscan state
 * - 1 - pclk cycle within one hscan state
 * - 10 - line counter within one vscan state
 * - 11 - line cycle within one vscan state
 * - 100 - frame counter
 * - 101 - frame cycle
 * - 110 - horizontal counter (pclk counter within one line )
 * - 111 - vertical counter (line counter within one frame)
 */
/*@{*/
#define BP_EPDC_PIGEON_16_0_MASK_CNT_SEL (8U) /*!< Bit position for EPDC_PIGEON_16_0_MASK_CNT_SEL. */
#define BM_EPDC_PIGEON_16_0_MASK_CNT_SEL (0x00000F00U) /*!< Bit mask for EPDC_PIGEON_16_0_MASK_CNT_SEL. */
#define BS_EPDC_PIGEON_16_0_MASK_CNT_SEL (4U) /*!< Bit field size in bits for EPDC_PIGEON_16_0_MASK_CNT_SEL. */

#define BV_EPDC_PIGEON_16_0_MASK_CNT_SEL_HSTATE_CNT (0U) /*!< Bit field value for EPDC_PIGEON_16_0_MASK_CNT_SEL: pclk counter within one hscan state */
#define BV_EPDC_PIGEON_16_0_MASK_CNT_SEL_HSTATE_CYCLE (0x1U) /*!< Bit field value for EPDC_PIGEON_16_0_MASK_CNT_SEL: pclk cycle within one hscan state */
#define BV_EPDC_PIGEON_16_0_MASK_CNT_SEL_VSTATE_CNT (0x2U) /*!< Bit field value for EPDC_PIGEON_16_0_MASK_CNT_SEL: line counter within one vscan state */
#define BV_EPDC_PIGEON_16_0_MASK_CNT_SEL_VSTATE_CYCLE (0x3U) /*!< Bit field value for EPDC_PIGEON_16_0_MASK_CNT_SEL: line cycle within one vscan state */
#define BV_EPDC_PIGEON_16_0_MASK_CNT_SEL_FRAME_CNT (0x4U) /*!< Bit field value for EPDC_PIGEON_16_0_MASK_CNT_SEL: frame counter */
#define BV_EPDC_PIGEON_16_0_MASK_CNT_SEL_FRAME_CYCLE (0x5U) /*!< Bit field value for EPDC_PIGEON_16_0_MASK_CNT_SEL: frame cycle */
#define BV_EPDC_PIGEON_16_0_MASK_CNT_SEL_HCNT (0x6U) /*!< Bit field value for EPDC_PIGEON_16_0_MASK_CNT_SEL: horizontal counter (pclk counter within one line ) */
#define BV_EPDC_PIGEON_16_0_MASK_CNT_SEL_VCNT (0x7U) /*!< Bit field value for EPDC_PIGEON_16_0_MASK_CNT_SEL: vertical counter (line counter within one frame) */

/*! @brief Read current value of the EPDC_PIGEON_16_0_MASK_CNT_SEL field. */
#define BR_EPDC_PIGEON_16_0_MASK_CNT_SEL(x) (HW_EPDC_PIGEON_16_0(x).B.MASK_CNT_SEL)

/*! @brief Format value for bitfield EPDC_PIGEON_16_0_MASK_CNT_SEL. */
#define BF_EPDC_PIGEON_16_0_MASK_CNT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_16_0_MASK_CNT_SEL) & BM_EPDC_PIGEON_16_0_MASK_CNT_SEL)

/*! @brief Set the MASK_CNT_SEL field to a new value. */
#define BW_EPDC_PIGEON_16_0_MASK_CNT_SEL(x, v) (HW_EPDC_PIGEON_16_0_WR(x, (HW_EPDC_PIGEON_16_0_RD(x) & ~BM_EPDC_PIGEON_16_0_MASK_CNT_SEL) | BF_EPDC_PIGEON_16_0_MASK_CNT_SEL(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_16_0, field MASK_CNT[23:12] (RW)
 *
 * When the global counter selected through MASK_CNT_SEL matches value in this
 * reg, pigeon local counter start ticking. 0=disable
 */
/*@{*/
#define BP_EPDC_PIGEON_16_0_MASK_CNT (12U) /*!< Bit position for EPDC_PIGEON_16_0_MASK_CNT. */
#define BM_EPDC_PIGEON_16_0_MASK_CNT (0x00FFF000U) /*!< Bit mask for EPDC_PIGEON_16_0_MASK_CNT. */
#define BS_EPDC_PIGEON_16_0_MASK_CNT (12U) /*!< Bit field size in bits for EPDC_PIGEON_16_0_MASK_CNT. */

/*! @brief Read current value of the EPDC_PIGEON_16_0_MASK_CNT field. */
#define BR_EPDC_PIGEON_16_0_MASK_CNT(x) (HW_EPDC_PIGEON_16_0(x).B.MASK_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_16_0_MASK_CNT. */
#define BF_EPDC_PIGEON_16_0_MASK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_16_0_MASK_CNT) & BM_EPDC_PIGEON_16_0_MASK_CNT)

/*! @brief Set the MASK_CNT field to a new value. */
#define BW_EPDC_PIGEON_16_0_MASK_CNT(x, v) (HW_EPDC_PIGEON_16_0_WR(x, (HW_EPDC_PIGEON_16_0_RD(x) & ~BM_EPDC_PIGEON_16_0_MASK_CNT) | BF_EPDC_PIGEON_16_0_MASK_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_16_0, field STATE_MASK[31:24] (RW)
 *
 * state_mask = (FS|FB|FD|FE) and (LS|LB|LD|LE) , select any combination of scan
 * states as reference point for local counter to start ticking
 *
 * Values:
 * - 1 - FRAME SYNC
 * - 10 - FRAME BEGIN
 * - 100 - FRAME DATA
 * - 1000 - FRAME END
 * - 10000 - LINE SYNC
 * - 100000 - LINE BEGIN
 * - 1000000 - LINE DATA
 * - 10000000 - LINE END
 */
/*@{*/
#define BP_EPDC_PIGEON_16_0_STATE_MASK (24U) /*!< Bit position for EPDC_PIGEON_16_0_STATE_MASK. */
#define BM_EPDC_PIGEON_16_0_STATE_MASK (0xFF000000U) /*!< Bit mask for EPDC_PIGEON_16_0_STATE_MASK. */
#define BS_EPDC_PIGEON_16_0_STATE_MASK (8U) /*!< Bit field size in bits for EPDC_PIGEON_16_0_STATE_MASK. */

#define BV_EPDC_PIGEON_16_0_STATE_MASK_FS (0x1U)     /*!< Bit field value for EPDC_PIGEON_16_0_STATE_MASK: FRAME SYNC */
#define BV_EPDC_PIGEON_16_0_STATE_MASK_FB (0x2U)     /*!< Bit field value for EPDC_PIGEON_16_0_STATE_MASK: FRAME BEGIN */
#define BV_EPDC_PIGEON_16_0_STATE_MASK_FD (0x4U)     /*!< Bit field value for EPDC_PIGEON_16_0_STATE_MASK: FRAME DATA */
#define BV_EPDC_PIGEON_16_0_STATE_MASK_FE (0x8U)     /*!< Bit field value for EPDC_PIGEON_16_0_STATE_MASK: FRAME END */
#define BV_EPDC_PIGEON_16_0_STATE_MASK_LS (0x10U)    /*!< Bit field value for EPDC_PIGEON_16_0_STATE_MASK: LINE SYNC */
#define BV_EPDC_PIGEON_16_0_STATE_MASK_LB (0x20U)    /*!< Bit field value for EPDC_PIGEON_16_0_STATE_MASK: LINE BEGIN */
#define BV_EPDC_PIGEON_16_0_STATE_MASK_LD (0x40U)    /*!< Bit field value for EPDC_PIGEON_16_0_STATE_MASK: LINE DATA */
#define BV_EPDC_PIGEON_16_0_STATE_MASK_LE (0x80U)    /*!< Bit field value for EPDC_PIGEON_16_0_STATE_MASK: LINE END */

/*! @brief Read current value of the EPDC_PIGEON_16_0_STATE_MASK field. */
#define BR_EPDC_PIGEON_16_0_STATE_MASK(x) (HW_EPDC_PIGEON_16_0(x).B.STATE_MASK)

/*! @brief Format value for bitfield EPDC_PIGEON_16_0_STATE_MASK. */
#define BF_EPDC_PIGEON_16_0_STATE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_16_0_STATE_MASK) & BM_EPDC_PIGEON_16_0_STATE_MASK)

/*! @brief Set the STATE_MASK field to a new value. */
#define BW_EPDC_PIGEON_16_0_STATE_MASK(x, v) (HW_EPDC_PIGEON_16_0_WR(x, (HW_EPDC_PIGEON_16_0_RD(x) & ~BM_EPDC_PIGEON_16_0_STATE_MASK) | BF_EPDC_PIGEON_16_0_STATE_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_16_1 - Panel Interface Signal Generator Register 16_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_16_1 - Panel Interface Signal Generator Register 16_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_16_1
{
    uint32_t U;
    struct _hw_epdc_pigeon_16_1_bitfields
    {
        uint32_t SET_CNT : 16;         /*!< [15:0]  */
        uint32_t CLR_CNT : 16;         /*!< [31:16]  */
    } B;
} hw_epdc_pigeon_16_1_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_16_1 register
 */
/*@{*/
#define HW_EPDC_PIGEON_16_1_ADDR(x) ((uintptr_t)(x) + 0xC10U)

#define HW_EPDC_PIGEON_16_1(x)   (*(__IO hw_epdc_pigeon_16_1_t *) HW_EPDC_PIGEON_16_1_ADDR(x))
#define HW_EPDC_PIGEON_16_1_RD(x) (HW_EPDC_PIGEON_16_1(x).U)
#define HW_EPDC_PIGEON_16_1_WR(x, v) (HW_EPDC_PIGEON_16_1(x).U = (v))
#define HW_EPDC_PIGEON_16_1_SET(x, v) (HW_EPDC_PIGEON_16_1_WR(x, HW_EPDC_PIGEON_16_1_RD(x) |  (v)))
#define HW_EPDC_PIGEON_16_1_CLR(x, v) (HW_EPDC_PIGEON_16_1_WR(x, HW_EPDC_PIGEON_16_1_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_16_1_TOG(x, v) (HW_EPDC_PIGEON_16_1_WR(x, HW_EPDC_PIGEON_16_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_16_1 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_16_1, field SET_CNT[15:0] (RW)
 *
 * assert signal output when counter match this value
 *
 * Values:
 * - 0 - start as active
 */
/*@{*/
#define BP_EPDC_PIGEON_16_1_SET_CNT (0U)   /*!< Bit position for EPDC_PIGEON_16_1_SET_CNT. */
#define BM_EPDC_PIGEON_16_1_SET_CNT (0x0000FFFFU) /*!< Bit mask for EPDC_PIGEON_16_1_SET_CNT. */
#define BS_EPDC_PIGEON_16_1_SET_CNT (16U)  /*!< Bit field size in bits for EPDC_PIGEON_16_1_SET_CNT. */

#define BV_EPDC_PIGEON_16_1_SET_CNT_START_ACTIVE (0U) /*!< Bit field value for EPDC_PIGEON_16_1_SET_CNT: start as active */

/*! @brief Read current value of the EPDC_PIGEON_16_1_SET_CNT field. */
#define BR_EPDC_PIGEON_16_1_SET_CNT(x) (HW_EPDC_PIGEON_16_1(x).B.SET_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_16_1_SET_CNT. */
#define BF_EPDC_PIGEON_16_1_SET_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_16_1_SET_CNT) & BM_EPDC_PIGEON_16_1_SET_CNT)

/*! @brief Set the SET_CNT field to a new value. */
#define BW_EPDC_PIGEON_16_1_SET_CNT(x, v) (HW_EPDC_PIGEON_16_1_WR(x, (HW_EPDC_PIGEON_16_1_RD(x) & ~BM_EPDC_PIGEON_16_1_SET_CNT) | BF_EPDC_PIGEON_16_1_SET_CNT(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_16_1, field CLR_CNT[31:16] (RW)
 *
 * deassert signal output when counter match this value
 *
 * Values:
 * - 0 - keep active until mask off
 */
/*@{*/
#define BP_EPDC_PIGEON_16_1_CLR_CNT (16U)  /*!< Bit position for EPDC_PIGEON_16_1_CLR_CNT. */
#define BM_EPDC_PIGEON_16_1_CLR_CNT (0xFFFF0000U) /*!< Bit mask for EPDC_PIGEON_16_1_CLR_CNT. */
#define BS_EPDC_PIGEON_16_1_CLR_CNT (16U)  /*!< Bit field size in bits for EPDC_PIGEON_16_1_CLR_CNT. */

#define BV_EPDC_PIGEON_16_1_CLR_CNT_CLEAR_USING_MASK (0U) /*!< Bit field value for EPDC_PIGEON_16_1_CLR_CNT: keep active until mask off */

/*! @brief Read current value of the EPDC_PIGEON_16_1_CLR_CNT field. */
#define BR_EPDC_PIGEON_16_1_CLR_CNT(x) (HW_EPDC_PIGEON_16_1(x).B.CLR_CNT)

/*! @brief Format value for bitfield EPDC_PIGEON_16_1_CLR_CNT. */
#define BF_EPDC_PIGEON_16_1_CLR_CNT(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_16_1_CLR_CNT) & BM_EPDC_PIGEON_16_1_CLR_CNT)

/*! @brief Set the CLR_CNT field to a new value. */
#define BW_EPDC_PIGEON_16_1_CLR_CNT(x, v) (HW_EPDC_PIGEON_16_1_WR(x, (HW_EPDC_PIGEON_16_1_RD(x) & ~BM_EPDC_PIGEON_16_1_CLR_CNT) | BF_EPDC_PIGEON_16_1_CLR_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_EPDC_PIGEON_16_2 - Panel Interface Signal Generator Register 16_1
 ******************************************************************************/

/*!
 * @brief HW_EPDC_PIGEON_16_2 - Panel Interface Signal Generator Register 16_1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * parameters for timing signal generation
 */
typedef union _hw_epdc_pigeon_16_2
{
    uint32_t U;
    struct _hw_epdc_pigeon_16_2_bitfields
    {
        uint32_t SIG_LOGIC : 4;        /*!< [3:0]  */
        uint32_t SIG_ANOTHER : 5;      /*!< [8:4]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_epdc_pigeon_16_2_t;

/*!
 * @name Constants and macros for entire EPDC_PIGEON_16_2 register
 */
/*@{*/
#define HW_EPDC_PIGEON_16_2_ADDR(x) ((uintptr_t)(x) + 0xC20U)

#define HW_EPDC_PIGEON_16_2(x)   (*(__IO hw_epdc_pigeon_16_2_t *) HW_EPDC_PIGEON_16_2_ADDR(x))
#define HW_EPDC_PIGEON_16_2_RD(x) (HW_EPDC_PIGEON_16_2(x).U)
#define HW_EPDC_PIGEON_16_2_WR(x, v) (HW_EPDC_PIGEON_16_2(x).U = (v))
#define HW_EPDC_PIGEON_16_2_SET(x, v) (HW_EPDC_PIGEON_16_2_WR(x, HW_EPDC_PIGEON_16_2_RD(x) |  (v)))
#define HW_EPDC_PIGEON_16_2_CLR(x, v) (HW_EPDC_PIGEON_16_2_WR(x, HW_EPDC_PIGEON_16_2_RD(x) & ~(v)))
#define HW_EPDC_PIGEON_16_2_TOG(x, v) (HW_EPDC_PIGEON_16_2_WR(x, HW_EPDC_PIGEON_16_2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual EPDC_PIGEON_16_2 bitfields
 */

/*!
 * @name Register EPDC_PIGEON_16_2, field SIG_LOGIC[3:0] (RW)
 *
 * logic operation with another signal sigout : final output signal of this
 * generator mask : final mask of this generator this_sig : intermediate signal of
 * this generator before logic operation other_masks : intermediate mask result of
 * this generator before logic operation sig_another : signal selected other
 * generators
 *
 * Values:
 * - 0 - no logic operation
 * - 1 - sigout = sig_another AND this_sig
 * - 10 - sigout = sig_another OR this_sig
 * - 11 - mask = sig_another AND other_masks
 */
/*@{*/
#define BP_EPDC_PIGEON_16_2_SIG_LOGIC (0U) /*!< Bit position for EPDC_PIGEON_16_2_SIG_LOGIC. */
#define BM_EPDC_PIGEON_16_2_SIG_LOGIC (0x0000000FU) /*!< Bit mask for EPDC_PIGEON_16_2_SIG_LOGIC. */
#define BS_EPDC_PIGEON_16_2_SIG_LOGIC (4U) /*!< Bit field size in bits for EPDC_PIGEON_16_2_SIG_LOGIC. */

#define BV_EPDC_PIGEON_16_2_SIG_LOGIC_DIS (0U)       /*!< Bit field value for EPDC_PIGEON_16_2_SIG_LOGIC: no logic operation */
#define BV_EPDC_PIGEON_16_2_SIG_LOGIC_AND (0x1U)     /*!< Bit field value for EPDC_PIGEON_16_2_SIG_LOGIC: sigout = sig_another AND this_sig */
#define BV_EPDC_PIGEON_16_2_SIG_LOGIC_OR (0x2U)      /*!< Bit field value for EPDC_PIGEON_16_2_SIG_LOGIC: sigout = sig_another OR this_sig */
#define BV_EPDC_PIGEON_16_2_SIG_LOGIC_MASK (0x3U)    /*!< Bit field value for EPDC_PIGEON_16_2_SIG_LOGIC: mask = sig_another AND other_masks */

/*! @brief Read current value of the EPDC_PIGEON_16_2_SIG_LOGIC field. */
#define BR_EPDC_PIGEON_16_2_SIG_LOGIC(x) (HW_EPDC_PIGEON_16_2(x).B.SIG_LOGIC)

/*! @brief Format value for bitfield EPDC_PIGEON_16_2_SIG_LOGIC. */
#define BF_EPDC_PIGEON_16_2_SIG_LOGIC(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_16_2_SIG_LOGIC) & BM_EPDC_PIGEON_16_2_SIG_LOGIC)

/*! @brief Set the SIG_LOGIC field to a new value. */
#define BW_EPDC_PIGEON_16_2_SIG_LOGIC(x, v) (HW_EPDC_PIGEON_16_2_WR(x, (HW_EPDC_PIGEON_16_2_RD(x) & ~BM_EPDC_PIGEON_16_2_SIG_LOGIC) | BF_EPDC_PIGEON_16_2_SIG_LOGIC(v)))
/*@}*/

/*!
 * @name Register EPDC_PIGEON_16_2, field SIG_ANOTHER[8:4] (RW)
 *
 * select another signal for logic operation or as mask or counter tick event
 */
/*@{*/
#define BP_EPDC_PIGEON_16_2_SIG_ANOTHER (4U) /*!< Bit position for EPDC_PIGEON_16_2_SIG_ANOTHER. */
#define BM_EPDC_PIGEON_16_2_SIG_ANOTHER (0x000001F0U) /*!< Bit mask for EPDC_PIGEON_16_2_SIG_ANOTHER. */
#define BS_EPDC_PIGEON_16_2_SIG_ANOTHER (5U) /*!< Bit field size in bits for EPDC_PIGEON_16_2_SIG_ANOTHER. */

/*! @brief Read current value of the EPDC_PIGEON_16_2_SIG_ANOTHER field. */
#define BR_EPDC_PIGEON_16_2_SIG_ANOTHER(x) (HW_EPDC_PIGEON_16_2(x).B.SIG_ANOTHER)

/*! @brief Format value for bitfield EPDC_PIGEON_16_2_SIG_ANOTHER. */
#define BF_EPDC_PIGEON_16_2_SIG_ANOTHER(v) ((uint32_t)((uint32_t)(v) << BP_EPDC_PIGEON_16_2_SIG_ANOTHER) & BM_EPDC_PIGEON_16_2_SIG_ANOTHER)

/*! @brief Set the SIG_ANOTHER field to a new value. */
#define BW_EPDC_PIGEON_16_2_SIG_ANOTHER(x, v) (HW_EPDC_PIGEON_16_2_WR(x, (HW_EPDC_PIGEON_16_2_RD(x) & ~BM_EPDC_PIGEON_16_2_SIG_ANOTHER) | BF_EPDC_PIGEON_16_2_SIG_ANOTHER(v)))
/*@}*/

/*******************************************************************************
 * hw_epdc_t - module struct
 ******************************************************************************/
/*!
 * @brief All EPDC module registers.
 */
#pragma pack(1)
typedef struct _hw_epdc
{
    __IO hw_epdc_ctrl_t CTRL;              /*!< [0x0] EPDC Control Register */
    uint8_t _reserved0[12];
    __IO hw_epdc_wb_addr_tce_t WB_ADDR_TCE; /*!< [0x10] EPDC Working Buffer Address for TCE */
    uint8_t _reserved1[12];
    __IO hw_epdc_wvaddr_t WVADDR;          /*!< [0x20] EPDC Waveform Address Pointer */
    uint8_t _reserved2[12];
    __IO hw_epdc_wb_addr_t WB_ADDR;        /*!< [0x30] EPDC Working Buffer Address */
    uint8_t _reserved3[12];
    __IO hw_epdc_res_t RES;                /*!< [0x40] EPDC Screen Resolution */
    uint8_t _reserved4[12];
    __IO hw_epdc_format_t FORMAT;          /*!< [0x50] EPDC Format Control Register */
    uint8_t _reserved5[12];
    __IO hw_epdc_wb_field0_t WB_FIELD0;    /*!< [0x60] Working Buffer Field Setting */
    uint8_t _reserved6[12];
    __IO hw_epdc_wb_field1_t WB_FIELD1;    /*!< [0x70] Working Buffer Field Setting */
    uint8_t _reserved7[12];
    __IO hw_epdc_wb_field2_t WB_FIELD2;    /*!< [0x80] Working Buffer Field Setting */
    uint8_t _reserved8[12];
    __IO hw_epdc_wb_field3_t WB_FIELD3;    /*!< [0x90] Working Buffer Field Setting */
    uint8_t _reserved9[12];
    __IO hw_epdc_fifoctrl_t FIFOCTRL;      /*!< [0xA0] EPDC FIFO control register */
    uint8_t _reserved10[92];
    __IO hw_epdc_upd_addr_t UPD_ADDR;      /*!< [0x100] EPDC Update Region Address */
    uint8_t _reserved11[12];
    __IO hw_epdc_upd_stride_t UPD_STRIDE;  /*!< [0x110] EPDC Update Region Stride */
    uint8_t _reserved12[12];
    __IO hw_epdc_upd_cord_t UPD_CORD;      /*!< [0x120] EPDC Update Command Co-ordinate */
    uint8_t _reserved13[28];
    __IO hw_epdc_upd_size_t UPD_SIZE;      /*!< [0x140] EPDC Update Command Size */
    uint8_t _reserved14[28];
    __IO hw_epdc_upd_ctrl_t UPD_CTRL;      /*!< [0x160] EPDC Update Command Control */
    uint8_t _reserved15[28];
    __IO hw_epdc_upd_fixed_t UPD_FIXED;    /*!< [0x180] EPDC Update Fixed Pixel Control */
    uint8_t _reserved16[28];
    __IO hw_epdc_temp_t TEMP;              /*!< [0x1A0] EPDC Temperature Register */
    uint8_t _reserved17[28];
    __IO hw_epdc_autowv_lut_t AUTOWV_LUT;  /*!< [0x1C0] Waveform Mode Lookup Table Control Register. */
    uint8_t _reserved18[28];
    __IO hw_epdc_lut_standby1_t LUT_STANDBY1; /*!< [0x1E0] EPDC LUT Standby Register for LUT 31~0 */
    uint8_t _reserved19[12];
    __IO hw_epdc_lut_standby2_t LUT_STANDBY2; /*!< [0x1F0] EPDC LUT Standby Registerr for LUT 63~32 */
    uint8_t _reserved20[12];
    __IO hw_epdc_tce_ctrl_t TCE_CTRL;      /*!< [0x200] EPDC Timing Control Engine Control Register */
    uint8_t _reserved21[28];
    __IO hw_epdc_tce_sdcfg_t TCE_SDCFG;    /*!< [0x220] EPDC Timing Control Engine Source-Driver Config Register */
    uint8_t _reserved22[28];
    __IO hw_epdc_tce_gdcfg_t TCE_GDCFG;    /*!< [0x240] EPDC Timing Control Engine Gate-Driver Config Register */
    uint8_t _reserved23[28];
    __IO hw_epdc_tce_hscan1_t TCE_HSCAN1;  /*!< [0x260] EPDC Timing Control Engine Horizontal Timing Register 1 */
    uint8_t _reserved24[28];
    __IO hw_epdc_tce_hscan2_t TCE_HSCAN2;  /*!< [0x280] EPDC Timing Control Engine Horizontal Timing Register 2 */
    uint8_t _reserved25[28];
    __IO hw_epdc_tce_vscan_t TCE_VSCAN;    /*!< [0x2A0] EPDC Timing Control Engine Vertical Timing Register */
    uint8_t _reserved26[28];
    __IO hw_epdc_tce_oe_t TCE_OE;          /*!< [0x2C0] EPDC Timing Control Engine OE timing control Register */
    uint8_t _reserved27[28];
    __IO hw_epdc_tce_polarity_t TCE_POLARITY; /*!< [0x2E0] EPDC Timing Control Engine Driver Polarity Register */
    uint8_t _reserved28[28];
    __IO hw_epdc_tce_timing1_t TCE_TIMING1; /*!< [0x300] EPDC Timing Control Engine Timing Register 1 */
    uint8_t _reserved29[12];
    __IO hw_epdc_tce_timing2_t TCE_TIMING2; /*!< [0x310] EPDC Timing Control Engine Timing Register 2 */
    uint8_t _reserved30[12];
    __IO hw_epdc_tce_timing3_t TCE_TIMING3; /*!< [0x320] EPDC Timing Control Engine Timing Register 3 */
    uint8_t _reserved31[92];
    __IO hw_epdc_pigeon_ctrl0_t PIGEON_CTRL0; /*!< [0x380] EPDC Pigeon Mode Control Register 0 */
    uint8_t _reserved32[12];
    __IO hw_epdc_pigeon_ctrl1_t PIGEON_CTRL1; /*!< [0x390] EPDC Pigeon Mode Control Register 1 */
    uint8_t _reserved33[44];
    __IO hw_epdc_irq_mask1_t IRQ_MASK1;    /*!< [0x3C0] EPDC IRQ Mask Register for LUT 0~31 */
    uint8_t _reserved34[12];
    __IO hw_epdc_irq_mask2_t IRQ_MASK2;    /*!< [0x3D0] EPDC IRQ Mask Register for LUT 32~63 */
    uint8_t _reserved35[12];
    __IO hw_epdc_irq1_t IRQ1;              /*!< [0x3E0] EPDC Interrupt Register for LUT 0~31 */
    uint8_t _reserved36[12];
    __IO hw_epdc_irq2_t IRQ2;              /*!< [0x3F0] EPDC Interrupt Registerr for LUT 32~63 */
    uint8_t _reserved37[12];
    __IO hw_epdc_irq_mask_t IRQ_MASK;      /*!< [0x400] EPDC IRQ Mask Register */
    uint8_t _reserved38[28];
    __IO hw_epdc_irq_t IRQ;                /*!< [0x420] EPDC Interrupt Register */
    uint8_t _reserved39[28];
    __IO hw_epdc_status_luts1_t STATUS_LUTS1; /*!< [0x440] EPDC Status Register - LUTs */
    uint8_t _reserved40[12];
    __IO hw_epdc_status_luts2_t STATUS_LUTS2; /*!< [0x450] EPDC Status Register - LUTs */
    uint8_t _reserved41[12];
    __I hw_epdc_status_nextlut_t STATUS_NEXTLUT; /*!< [0x460] EPDC Status Register - Next Available LUT */
    uint8_t _reserved42[28];
    __I hw_epdc_status_col1_t STATUS_COL1; /*!< [0x480] EPDC LUT Collision Status */
    uint8_t _reserved43[12];
    __I hw_epdc_status_col2_t STATUS_COL2; /*!< [0x490] EPDC LUT Collision Status */
    uint8_t _reserved44[12];
    __IO hw_epdc_status_t STATUS;          /*!< [0x4A0] EPDC General Status Register */
    uint8_t _reserved45[28];
    __I hw_epdc_upd_col_cord_t UPD_COL_CORD; /*!< [0x4C0] EPDC Collision Region Co-ordinate */
    uint8_t _reserved46[28];
    __I hw_epdc_upd_col_size_t UPD_COL_SIZE; /*!< [0x4E0] EPDC Collision Region Size */
    uint8_t _reserved47[284];
    __IO hw_epdc_hist1_param_t HIST1_PARAM; /*!< [0x600] 1-level Histogram Parameter Register. */
    uint8_t _reserved48[12];
    __IO hw_epdc_hist2_param_t HIST2_PARAM; /*!< [0x610] 2-level Histogram Parameter Register. */
    uint8_t _reserved49[12];
    __IO hw_epdc_hist4_param_t HIST4_PARAM; /*!< [0x620] 4-level Histogram Parameter Register. */
    uint8_t _reserved50[12];
    __IO hw_epdc_hist8_param0_t HIST8_PARAM0; /*!< [0x630] 8-level Histogram Parameter 0 Register. */
    uint8_t _reserved51[12];
    __IO hw_epdc_hist8_param1_t HIST8_PARAM1; /*!< [0x640] 8-level Histogram Parameter 1 Register. */
    uint8_t _reserved52[12];
    __IO hw_epdc_hist16_param0_t HIST16_PARAM0; /*!< [0x650] 16-level Histogram Parameter 0 Register. */
    uint8_t _reserved53[12];
    __IO hw_epdc_hist16_param1_t HIST16_PARAM1; /*!< [0x660] 16-level Histogram Parameter Register. */
    uint8_t _reserved54[12];
    __IO hw_epdc_hist16_param2_t HIST16_PARAM2; /*!< [0x670] 16-level Histogram Parameter Register. */
    uint8_t _reserved55[12];
    __IO hw_epdc_hist16_param3_t HIST16_PARAM3; /*!< [0x680] 16-level Histogram Parameter Register. */
    uint8_t _reserved56[124];
    __IO hw_epdc_gpio_t GPIO;              /*!< [0x700] EPDC General Purpose I/O Debug register */
    uint8_t _reserved57[236];
    __I hw_epdc_version_t VERSION;         /*!< [0x7F0] EPDC Version Register */
    uint8_t _reserved58[12];
    __IO hw_epdc_pigeon_0_0_t PIGEON_0_0;  /*!< [0x800] Panel Interface Signal Generator Register 0_0 */
    uint8_t _reserved59[12];
    __IO hw_epdc_pigeon_0_1_t PIGEON_0_1;  /*!< [0x810] Panel Interface Signal Generator Register 0_1 */
    uint8_t _reserved60[12];
    __IO hw_epdc_pigeon_0_2_t PIGEON_0_2;  /*!< [0x820] Panel Interface Signal Generator Register 0_1 */
    uint8_t _reserved61[28];
    __IO hw_epdc_pigeon_1_0_t PIGEON_1_0;  /*!< [0x840] Panel Interface Signal Generator Register 1_0 */
    uint8_t _reserved62[12];
    __IO hw_epdc_pigeon_1_1_t PIGEON_1_1;  /*!< [0x850] Panel Interface Signal Generator Register 1_1 */
    uint8_t _reserved63[12];
    __IO hw_epdc_pigeon_1_2_t PIGEON_1_2;  /*!< [0x860] Panel Interface Signal Generator Register 1_1 */
    uint8_t _reserved64[28];
    __IO hw_epdc_pigeon_2_0_t PIGEON_2_0;  /*!< [0x880] Panel Interface Signal Generator Register 2_0 */
    uint8_t _reserved65[12];
    __IO hw_epdc_pigeon_2_1_t PIGEON_2_1;  /*!< [0x890] Panel Interface Signal Generator Register 2_1 */
    uint8_t _reserved66[12];
    __IO hw_epdc_pigeon_2_2_t PIGEON_2_2;  /*!< [0x8A0] Panel Interface Signal Generator Register 2_1 */
    uint8_t _reserved67[28];
    __IO hw_epdc_pigeon_3_0_t PIGEON_3_0;  /*!< [0x8C0] Panel Interface Signal Generator Register 3_0 */
    uint8_t _reserved68[12];
    __IO hw_epdc_pigeon_3_1_t PIGEON_3_1;  /*!< [0x8D0] Panel Interface Signal Generator Register 3_1 */
    uint8_t _reserved69[12];
    __IO hw_epdc_pigeon_3_2_t PIGEON_3_2;  /*!< [0x8E0] Panel Interface Signal Generator Register 3_1 */
    uint8_t _reserved70[28];
    __IO hw_epdc_pigeon_4_0_t PIGEON_4_0;  /*!< [0x900] Panel Interface Signal Generator Register 4_0 */
    uint8_t _reserved71[12];
    __IO hw_epdc_pigeon_4_1_t PIGEON_4_1;  /*!< [0x910] Panel Interface Signal Generator Register 4_1 */
    uint8_t _reserved72[12];
    __IO hw_epdc_pigeon_4_2_t PIGEON_4_2;  /*!< [0x920] Panel Interface Signal Generator Register 4_1 */
    uint8_t _reserved73[28];
    __IO hw_epdc_pigeon_5_0_t PIGEON_5_0;  /*!< [0x940] Panel Interface Signal Generator Register 5_0 */
    uint8_t _reserved74[12];
    __IO hw_epdc_pigeon_5_1_t PIGEON_5_1;  /*!< [0x950] Panel Interface Signal Generator Register 5_1 */
    uint8_t _reserved75[12];
    __IO hw_epdc_pigeon_5_2_t PIGEON_5_2;  /*!< [0x960] Panel Interface Signal Generator Register 5_1 */
    uint8_t _reserved76[28];
    __IO hw_epdc_pigeon_6_0_t PIGEON_6_0;  /*!< [0x980] Panel Interface Signal Generator Register 6_0 */
    uint8_t _reserved77[12];
    __IO hw_epdc_pigeon_6_1_t PIGEON_6_1;  /*!< [0x990] Panel Interface Signal Generator Register 6_1 */
    uint8_t _reserved78[12];
    __IO hw_epdc_pigeon_6_2_t PIGEON_6_2;  /*!< [0x9A0] Panel Interface Signal Generator Register 6_1 */
    uint8_t _reserved79[28];
    __IO hw_epdc_pigeon_7_0_t PIGEON_7_0;  /*!< [0x9C0] Panel Interface Signal Generator Register 7_0 */
    uint8_t _reserved80[12];
    __IO hw_epdc_pigeon_7_1_t PIGEON_7_1;  /*!< [0x9D0] Panel Interface Signal Generator Register 7_1 */
    uint8_t _reserved81[12];
    __IO hw_epdc_pigeon_7_2_t PIGEON_7_2;  /*!< [0x9E0] Panel Interface Signal Generator Register 7_1 */
    uint8_t _reserved82[28];
    __IO hw_epdc_pigeon_8_0_t PIGEON_8_0;  /*!< [0xA00] Panel Interface Signal Generator Register 8_0 */
    uint8_t _reserved83[12];
    __IO hw_epdc_pigeon_8_1_t PIGEON_8_1;  /*!< [0xA10] Panel Interface Signal Generator Register 8_1 */
    uint8_t _reserved84[12];
    __IO hw_epdc_pigeon_8_2_t PIGEON_8_2;  /*!< [0xA20] Panel Interface Signal Generator Register 8_1 */
    uint8_t _reserved85[28];
    __IO hw_epdc_pigeon_9_0_t PIGEON_9_0;  /*!< [0xA40] Panel Interface Signal Generator Register 9_0 */
    uint8_t _reserved86[12];
    __IO hw_epdc_pigeon_9_1_t PIGEON_9_1;  /*!< [0xA50] Panel Interface Signal Generator Register 9_1 */
    uint8_t _reserved87[12];
    __IO hw_epdc_pigeon_9_2_t PIGEON_9_2;  /*!< [0xA60] Panel Interface Signal Generator Register 9_1 */
    uint8_t _reserved88[28];
    __IO hw_epdc_pigeon_10_0_t PIGEON_10_0; /*!< [0xA80] Panel Interface Signal Generator Register 10_0 */
    uint8_t _reserved89[12];
    __IO hw_epdc_pigeon_10_1_t PIGEON_10_1; /*!< [0xA90] Panel Interface Signal Generator Register 10_1 */
    uint8_t _reserved90[12];
    __IO hw_epdc_pigeon_10_2_t PIGEON_10_2; /*!< [0xAA0] Panel Interface Signal Generator Register 10_1 */
    uint8_t _reserved91[28];
    __IO hw_epdc_pigeon_11_0_t PIGEON_11_0; /*!< [0xAC0] Panel Interface Signal Generator Register 11_0 */
    uint8_t _reserved92[12];
    __IO hw_epdc_pigeon_11_1_t PIGEON_11_1; /*!< [0xAD0] Panel Interface Signal Generator Register 11_1 */
    uint8_t _reserved93[12];
    __IO hw_epdc_pigeon_11_2_t PIGEON_11_2; /*!< [0xAE0] Panel Interface Signal Generator Register 11_1 */
    uint8_t _reserved94[28];
    __IO hw_epdc_pigeon_12_0_t PIGEON_12_0; /*!< [0xB00] Panel Interface Signal Generator Register 12_0 */
    uint8_t _reserved95[12];
    __IO hw_epdc_pigeon_12_1_t PIGEON_12_1; /*!< [0xB10] Panel Interface Signal Generator Register 12_1 */
    uint8_t _reserved96[12];
    __IO hw_epdc_pigeon_12_2_t PIGEON_12_2; /*!< [0xB20] Panel Interface Signal Generator Register 12_1 */
    uint8_t _reserved97[28];
    __IO hw_epdc_pigeon_13_0_t PIGEON_13_0; /*!< [0xB40] Panel Interface Signal Generator Register 13_0 */
    uint8_t _reserved98[12];
    __IO hw_epdc_pigeon_13_1_t PIGEON_13_1; /*!< [0xB50] Panel Interface Signal Generator Register 13_1 */
    uint8_t _reserved99[12];
    __IO hw_epdc_pigeon_13_2_t PIGEON_13_2; /*!< [0xB60] Panel Interface Signal Generator Register 13_1 */
    uint8_t _reserved100[28];
    __IO hw_epdc_pigeon_14_0_t PIGEON_14_0; /*!< [0xB80] Panel Interface Signal Generator Register 14_0 */
    uint8_t _reserved101[12];
    __IO hw_epdc_pigeon_14_1_t PIGEON_14_1; /*!< [0xB90] Panel Interface Signal Generator Register 14_1 */
    uint8_t _reserved102[12];
    __IO hw_epdc_pigeon_14_2_t PIGEON_14_2; /*!< [0xBA0] Panel Interface Signal Generator Register 14_1 */
    uint8_t _reserved103[28];
    __IO hw_epdc_pigeon_15_0_t PIGEON_15_0; /*!< [0xBC0] Panel Interface Signal Generator Register 15_0 */
    uint8_t _reserved104[12];
    __IO hw_epdc_pigeon_15_1_t PIGEON_15_1; /*!< [0xBD0] Panel Interface Signal Generator Register 15_1 */
    uint8_t _reserved105[12];
    __IO hw_epdc_pigeon_15_2_t PIGEON_15_2; /*!< [0xBE0] Panel Interface Signal Generator Register 15_1 */
    uint8_t _reserved106[28];
    __IO hw_epdc_pigeon_16_0_t PIGEON_16_0; /*!< [0xC00] Panel Interface Signal Generator Register 16_0 */
    uint8_t _reserved107[12];
    __IO hw_epdc_pigeon_16_1_t PIGEON_16_1; /*!< [0xC10] Panel Interface Signal Generator Register 16_1 */
    uint8_t _reserved108[12];
    __IO hw_epdc_pigeon_16_2_t PIGEON_16_2; /*!< [0xC20] Panel Interface Signal Generator Register 16_1 */
} hw_epdc_t;
#pragma pack()

/*! @brief Macro to access all EPDC registers. */
/*! @param x EPDC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_EPDC_REGS(EPDC_BASE)</code>. */
#define HW_EPDC_REGS(x) (*(hw_epdc_t *)(x))

/*
 * iMX7D FTM
 *
 * FlexTimer Module (FTM)
 *
 * Registers defined in this header file:
 * - HW_FTM_SC - Status And Control
 * - HW_FTM_CNT - Counter
 * - HW_FTM_MOD - Modulo
 * - HW_FTM_CnSC - Channel (n) Status And Control
 * - HW_FTM_CnV - Channel (n) Value
 * - HW_FTM_CNTIN - Counter Initial Value
 * - HW_FTM_STATUS - Capture And Compare Status
 * - HW_FTM_MODE - Features Mode Selection
 * - HW_FTM_SYNC - Synchronization
 * - HW_FTM_OUTINIT - Initial State For Channels Output
 * - HW_FTM_OUTMASK - Output Mask
 * - HW_FTM_COMBINE - Function For Linked Channels
 * - HW_FTM_DEADTIME - Deadtime Insertion Control
 * - HW_FTM_EXTTRIG - FTM External Trigger
 * - HW_FTM_POL - Channels Polarity
 * - HW_FTM_FMS - Fault Mode Status
 * - HW_FTM_FILTER - Input Capture Filter Control
 * - HW_FTM_QDCTRL - Quadrature Decoder Control And Status
 * - HW_FTM_CONF - Configuration
 * - HW_FTM_SYNCONF - Synchronization Configuration
 * - HW_FTM_INVCTRL - FTM Inverting Control
 * - HW_FTM_SWOCTRL - FTM Software Output Control
 * - HW_FTM_PWMLOAD - FTM PWM Load
 *
 * - hw_ftm_t - Struct containing all module registers.
 */

#define HW_FTM_INSTANCE_COUNT (2U) /*!< Number of instances of the FTM module. */
#define HW_FTM1 (0U) /*!< Instance number for FTM1. */
#define HW_FTM2 (1U) /*!< Instance number for FTM2. */
#define FTM1_BASE             (0x30640000U) /*!< Base address for FTM1. */
#define FTM2_BASE             (0x30650000U) /*!< Base address for FTM2. */
/*! Array initializer of FTM base addresses. */
#define FTM_BASE_ADDRS        { FTM1_BASE, FTM2_BASE }

/*******************************************************************************
 * HW_FTM_SC - Status And Control
 ******************************************************************************/

/*!
 * @brief HW_FTM_SC - Status And Control (RW)
 *
 * Reset value: 0x00000000U
 *
 * SC contains the overflow status flag and control bits used to configure the
 * interrupt enable, FTM configuration, clock source, and prescaler factor. These
 * controls relate to all channels within this module.
 */
typedef union _hw_ftm_sc
{
    uint32_t U;
    struct _hw_ftm_sc_bitfields
    {
        uint32_t PS : 3;               /*!< [2:0] Prescale Factor Selection */
        uint32_t CLKS : 2;             /*!< [4:3] Clock Source Selection */
        uint32_t CPWMS : 1;            /*!< [5] Center-Aligned PWM Select */
        uint32_t TOIE : 1;             /*!< [6] Timer Overflow Interrupt Enable */
        uint32_t TOF : 1;              /*!< [7] Timer Overflow Flag */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_ftm_sc_t;

/*!
 * @name Constants and macros for entire FTM_SC register
 */
/*@{*/
#define HW_FTM_SC_ADDR(x)        ((uintptr_t)(x) + 0x0U)

#define HW_FTM_SC(x)             (*(__IO hw_ftm_sc_t *) HW_FTM_SC_ADDR(x))
#define HW_FTM_SC_RD(x)          (HW_FTM_SC(x).U)
#define HW_FTM_SC_WR(x, v)       (HW_FTM_SC(x).U = (v))
#define HW_FTM_SC_SET(x, v)      (HW_FTM_SC_WR(x, HW_FTM_SC_RD(x) |  (v)))
#define HW_FTM_SC_CLR(x, v)      (HW_FTM_SC_WR(x, HW_FTM_SC_RD(x) & ~(v)))
#define HW_FTM_SC_TOG(x, v)      (HW_FTM_SC_WR(x, HW_FTM_SC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_SC bitfields
 */

/*!
 * @name Register FTM_SC, field PS[2:0] (RW)
 *
 * Selects one of 8 division factors for the clock source selected by CLKS. The
 * new prescaler factor affects the clock source on the next system clock cycle
 * after the new value is updated into the register bits. This field is write
 * protected. It can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 000 - Divide by 1
 * - 001 - Divide by 2
 * - 010 - Divide by 4
 * - 011 - Divide by 8
 * - 100 - Divide by 16
 * - 101 - Divide by 32
 * - 110 - Divide by 64
 * - 111 - Divide by 128
 */
/*@{*/
#define BP_FTM_SC_PS         (0U)          /*!< Bit position for FTM_SC_PS. */
#define BM_FTM_SC_PS         (0x00000007U) /*!< Bit mask for FTM_SC_PS. */
#define BS_FTM_SC_PS         (3U)          /*!< Bit field size in bits for FTM_SC_PS. */

/*! @brief Read current value of the FTM_SC_PS field. */
#define BR_FTM_SC_PS(x)      (HW_FTM_SC(x).B.PS)

/*! @brief Format value for bitfield FTM_SC_PS. */
#define BF_FTM_SC_PS(v)      ((uint32_t)((uint32_t)(v) << BP_FTM_SC_PS) & BM_FTM_SC_PS)

/*! @brief Set the PS field to a new value. */
#define BW_FTM_SC_PS(x, v)   (HW_FTM_SC_WR(x, (HW_FTM_SC_RD(x) & ~BM_FTM_SC_PS) | BF_FTM_SC_PS(v)))
/*@}*/

/*!
 * @name Register FTM_SC, field CLKS[4:3] (RW)
 *
 * Selects FTM counter clock sources. This field is write protected. It can be
 * written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 00 - No clock selected. This in effect disables the FTM counter.
 * - 01 - System clock
 * - 10 - Reserved
 */
/*@{*/
#define BP_FTM_SC_CLKS       (3U)          /*!< Bit position for FTM_SC_CLKS. */
#define BM_FTM_SC_CLKS       (0x00000018U) /*!< Bit mask for FTM_SC_CLKS. */
#define BS_FTM_SC_CLKS       (2U)          /*!< Bit field size in bits for FTM_SC_CLKS. */

/*! @brief Read current value of the FTM_SC_CLKS field. */
#define BR_FTM_SC_CLKS(x)    (HW_FTM_SC(x).B.CLKS)

/*! @brief Format value for bitfield FTM_SC_CLKS. */
#define BF_FTM_SC_CLKS(v)    ((uint32_t)((uint32_t)(v) << BP_FTM_SC_CLKS) & BM_FTM_SC_CLKS)

/*! @brief Set the CLKS field to a new value. */
#define BW_FTM_SC_CLKS(x, v) (HW_FTM_SC_WR(x, (HW_FTM_SC_RD(x) & ~BM_FTM_SC_CLKS) | BF_FTM_SC_CLKS(v)))
/*@}*/

/*!
 * @name Register FTM_SC, field CPWMS[5] (RW)
 *
 * Selects CPWM mode. This mode configures the FTM to operate in Up-Down
 * Counting mode. This field is write protected. It can be written only when MODE[WPDIS]
 * = 1.
 *
 * Values:
 * - 0 - FTM counter operates in Up Counting mode.
 * - 1 - FTM counter operates in Up-Down Counting mode.
 */
/*@{*/
#define BP_FTM_SC_CPWMS      (5U)          /*!< Bit position for FTM_SC_CPWMS. */
#define BM_FTM_SC_CPWMS      (0x00000020U) /*!< Bit mask for FTM_SC_CPWMS. */
#define BS_FTM_SC_CPWMS      (1U)          /*!< Bit field size in bits for FTM_SC_CPWMS. */

/*! @brief Read current value of the FTM_SC_CPWMS field. */
#define BR_FTM_SC_CPWMS(x)   (HW_FTM_SC(x).B.CPWMS)

/*! @brief Format value for bitfield FTM_SC_CPWMS. */
#define BF_FTM_SC_CPWMS(v)   ((uint32_t)((uint32_t)(v) << BP_FTM_SC_CPWMS) & BM_FTM_SC_CPWMS)

/*! @brief Set the CPWMS field to a new value. */
#define BW_FTM_SC_CPWMS(x, v) (HW_FTM_SC_WR(x, (HW_FTM_SC_RD(x) & ~BM_FTM_SC_CPWMS) | BF_FTM_SC_CPWMS(v)))
/*@}*/

/*!
 * @name Register FTM_SC, field TOIE[6] (RW)
 *
 * Enables FTM overflow interrupts.
 *
 * Values:
 * - 0 - Disable TOF interrupts. Use software polling.
 * - 1 - Enable TOF interrupts. An interrupt is generated when TOF equals one.
 */
/*@{*/
#define BP_FTM_SC_TOIE       (6U)          /*!< Bit position for FTM_SC_TOIE. */
#define BM_FTM_SC_TOIE       (0x00000040U) /*!< Bit mask for FTM_SC_TOIE. */
#define BS_FTM_SC_TOIE       (1U)          /*!< Bit field size in bits for FTM_SC_TOIE. */

/*! @brief Read current value of the FTM_SC_TOIE field. */
#define BR_FTM_SC_TOIE(x)    (HW_FTM_SC(x).B.TOIE)

/*! @brief Format value for bitfield FTM_SC_TOIE. */
#define BF_FTM_SC_TOIE(v)    ((uint32_t)((uint32_t)(v) << BP_FTM_SC_TOIE) & BM_FTM_SC_TOIE)

/*! @brief Set the TOIE field to a new value. */
#define BW_FTM_SC_TOIE(x, v) (HW_FTM_SC_WR(x, (HW_FTM_SC_RD(x) & ~BM_FTM_SC_TOIE) | BF_FTM_SC_TOIE(v)))
/*@}*/

/*!
 * @name Register FTM_SC, field TOF[7] (ROWZ)
 *
 * Set by hardware when the FTM counter passes the value in the MOD register.
 * The TOF bit is cleared by reading the SC register while TOF is set and then
 * writing a 0 to TOF bit. Writing a 1 to TOF has no effect. If another FTM overflow
 * occurs between the read and write operations, the write operation has no
 * effect; therefore, TOF remains set indicating an overflow has occurred. In this
 * case, a TOF interrupt request is not lost due to the clearing sequence for a
 * previous TOF.
 *
 * Values:
 * - 0 - FTM counter has not overflowed.
 * - 1 - FTM counter has overflowed.
 */
/*@{*/
#define BP_FTM_SC_TOF        (7U)          /*!< Bit position for FTM_SC_TOF. */
#define BM_FTM_SC_TOF        (0x00000080U) /*!< Bit mask for FTM_SC_TOF. */
#define BS_FTM_SC_TOF        (1U)          /*!< Bit field size in bits for FTM_SC_TOF. */

/*! @brief Read current value of the FTM_SC_TOF field. */
#define BR_FTM_SC_TOF(x)     (HW_FTM_SC(x).B.TOF)

/*! @brief Format value for bitfield FTM_SC_TOF. */
#define BF_FTM_SC_TOF(v)     ((uint32_t)((uint32_t)(v) << BP_FTM_SC_TOF) & BM_FTM_SC_TOF)

/*! @brief Set the TOF field to a new value. */
#define BW_FTM_SC_TOF(x, v)  (HW_FTM_SC_WR(x, (HW_FTM_SC_RD(x) & ~BM_FTM_SC_TOF) | BF_FTM_SC_TOF(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_CNT - Counter
 ******************************************************************************/

/*!
 * @brief HW_FTM_CNT - Counter (RW)
 *
 * Reset value: 0x00000000U
 *
 * The CNT register contains the FTM counter value. Reset clears the CNT
 * register. Writing any value to COUNT updates the counter with its initial value,
 * CNTIN. When BDM is active, the FTM counter is frozen. This is the value that you
 * may read.
 */
typedef union _hw_ftm_cnt
{
    uint32_t U;
    struct _hw_ftm_cnt_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0] Counter Value */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_ftm_cnt_t;

/*!
 * @name Constants and macros for entire FTM_CNT register
 */
/*@{*/
#define HW_FTM_CNT_ADDR(x)       ((uintptr_t)(x) + 0x4U)

#define HW_FTM_CNT(x)            (*(__IO hw_ftm_cnt_t *) HW_FTM_CNT_ADDR(x))
#define HW_FTM_CNT_RD(x)         (HW_FTM_CNT(x).U)
#define HW_FTM_CNT_WR(x, v)      (HW_FTM_CNT(x).U = (v))
#define HW_FTM_CNT_SET(x, v)     (HW_FTM_CNT_WR(x, HW_FTM_CNT_RD(x) |  (v)))
#define HW_FTM_CNT_CLR(x, v)     (HW_FTM_CNT_WR(x, HW_FTM_CNT_RD(x) & ~(v)))
#define HW_FTM_CNT_TOG(x, v)     (HW_FTM_CNT_WR(x, HW_FTM_CNT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_CNT bitfields
 */

/*!
 * @name Register FTM_CNT, field COUNT[15:0] (RW)
 */
/*@{*/
#define BP_FTM_CNT_COUNT     (0U)          /*!< Bit position for FTM_CNT_COUNT. */
#define BM_FTM_CNT_COUNT     (0x0000FFFFU) /*!< Bit mask for FTM_CNT_COUNT. */
#define BS_FTM_CNT_COUNT     (16U)         /*!< Bit field size in bits for FTM_CNT_COUNT. */

/*! @brief Read current value of the FTM_CNT_COUNT field. */
#define BR_FTM_CNT_COUNT(x)  (HW_FTM_CNT(x).B.COUNT)

/*! @brief Format value for bitfield FTM_CNT_COUNT. */
#define BF_FTM_CNT_COUNT(v)  ((uint32_t)((uint32_t)(v) << BP_FTM_CNT_COUNT) & BM_FTM_CNT_COUNT)

/*! @brief Set the COUNT field to a new value. */
#define BW_FTM_CNT_COUNT(x, v) (HW_FTM_CNT_WR(x, (HW_FTM_CNT_RD(x) & ~BM_FTM_CNT_COUNT) | BF_FTM_CNT_COUNT(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_MOD - Modulo
 ******************************************************************************/

/*!
 * @brief HW_FTM_MOD - Modulo (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Modulo register contains the modulo value for the FTM counter. After the
 * FTM counter reaches the modulo value, the overflow flag (TOF) becomes set at
 * the next clock, and the next value of FTM counter depends on the selected
 * counting method; see Counter. Writing to the MOD register latches the value into a
 * buffer. The MOD register is updated with the value of its write buffer
 * according to Registers updated from write buffers. If FTMEN = 0, this write coherency
 * mechanism may be manually reset by writing to the SC register whether BDM is
 * active or not. Initialize the FTM counter, by writing to CNT, before writing
 * to the MOD register to avoid confusion about when the first counter overflow
 * will occur.
 */
typedef union _hw_ftm_mod
{
    uint32_t U;
    struct _hw_ftm_mod_bitfields
    {
        uint32_t MOD : 16;             /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_ftm_mod_t;

/*!
 * @name Constants and macros for entire FTM_MOD register
 */
/*@{*/
#define HW_FTM_MOD_ADDR(x)       ((uintptr_t)(x) + 0x8U)

#define HW_FTM_MOD(x)            (*(__IO hw_ftm_mod_t *) HW_FTM_MOD_ADDR(x))
#define HW_FTM_MOD_RD(x)         (HW_FTM_MOD(x).U)
#define HW_FTM_MOD_WR(x, v)      (HW_FTM_MOD(x).U = (v))
#define HW_FTM_MOD_SET(x, v)     (HW_FTM_MOD_WR(x, HW_FTM_MOD_RD(x) |  (v)))
#define HW_FTM_MOD_CLR(x, v)     (HW_FTM_MOD_WR(x, HW_FTM_MOD_RD(x) & ~(v)))
#define HW_FTM_MOD_TOG(x, v)     (HW_FTM_MOD_WR(x, HW_FTM_MOD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_MOD bitfields
 */

/*!
 * @name Register FTM_MOD, field MOD[15:0] (RW)
 *
 * Modulo Value
 */
/*@{*/
#define BP_FTM_MOD_MOD       (0U)          /*!< Bit position for FTM_MOD_MOD. */
#define BM_FTM_MOD_MOD       (0x0000FFFFU) /*!< Bit mask for FTM_MOD_MOD. */
#define BS_FTM_MOD_MOD       (16U)         /*!< Bit field size in bits for FTM_MOD_MOD. */

/*! @brief Read current value of the FTM_MOD_MOD field. */
#define BR_FTM_MOD_MOD(x)    (HW_FTM_MOD(x).B.MOD)

/*! @brief Format value for bitfield FTM_MOD_MOD. */
#define BF_FTM_MOD_MOD(v)    ((uint32_t)((uint32_t)(v) << BP_FTM_MOD_MOD) & BM_FTM_MOD_MOD)

/*! @brief Set the MOD field to a new value. */
#define BW_FTM_MOD_MOD(x, v) (HW_FTM_MOD_WR(x, (HW_FTM_MOD_RD(x) & ~BM_FTM_MOD_MOD) | BF_FTM_MOD_MOD(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_CnSC - Channel (n) Status And Control
 ******************************************************************************/

/*!
 * @brief HW_FTM_CnSC - Channel (n) Status And Control (RW)
 *
 * Reset value: 0x00000000U
 *
 * CnSC contains the channel-interrupt-status flag and control bits used to
 * configure the interrupt enable, channel configuration, and pin function. Mode,
 * edge, and level selection DECAPEN COMBINE CPWMS MSnB:MSnA ELSnB:ELSnA Mode
 * Configuration X X X XX 00 Pin not used for FTM-revert the channel pin to general
 * purpose I/O or other peripheral control 0 0 0 00 01 Input Capture Capture on
 * Rising Edge Only 10 Capture on Falling Edge Only 11 Capture on Rising or Falling
 * Edge 01 01 Output Compare Toggle Output on match 10 Clear Output on match 11
 * Set Output on match 1X 10 Edge-Aligned PWM High-true pulses (clear Output on
 * match) X1 Low-true pulses (set Output on match) 1 XX 10 Center-Aligned PWM
 * High-true pulses (clear Output on match-up) X1 Low-true pulses (set Output on
 * match-up) 1 0 XX 10 Combine PWM High-true pulses (set on channel (n) match, and
 * clear on channel (n+1) match) X1 Low-true pulses (clear on channel (n) match, and
 * set on channel (n+1) match) 1 0 0 X0 See the following table (). Dual Edge
 * Capture One-Shot Capture mode X1 Continuous Capture mode Dual Edge Capture mode -
 * edge polarity selection ELSnB ELSnA Channel Port Enable Detected Edges 0 0
 * Disabled No edge 0 1 Enabled Rising edge 1 0 Enabled Falling edge 1 1 Enabled
 * Rising and falling edges
 */
typedef union _hw_ftm_cnsc
{
    uint32_t U;
    struct _hw_ftm_cnsc_bitfields
    {
        uint32_t DMA : 1;              /*!< [0] DMA Enable */
        uint32_t ICRST : 1;            /*!< [1] FTM counter reset by the selected input
                                        * capture event. */
        uint32_t ELSA : 1;             /*!< [2] Edge or Level Select */
        uint32_t ELSB : 1;             /*!< [3] Edge or Level Select */
        uint32_t MSA : 1;              /*!< [4] Channel Mode Select */
        uint32_t MSB : 1;              /*!< [5] Channel Mode Select */
        uint32_t CHIE : 1;             /*!< [6] Channel Interrupt Enable */
        uint32_t CHF : 1;              /*!< [7] Channel Flag */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_ftm_cnsc_t;

/*!
 * @name Constants and macros for entire FTM_CnSC register
 */
/*@{*/
#define HW_FTM_CnSC_COUNT (8U)

#define HW_FTM_CnSC_ADDR(x, n)   ((uintptr_t)(x) + 0xCU + (0x8U * (n)))

#define HW_FTM_CnSC(x, n)        (*(__IO hw_ftm_cnsc_t *) HW_FTM_CnSC_ADDR(x, n))
#define HW_FTM_CnSC_RD(x, n)     (HW_FTM_CnSC(x, n).U)
#define HW_FTM_CnSC_WR(x, n, v)  (HW_FTM_CnSC(x, n).U = (v))
#define HW_FTM_CnSC_SET(x, n, v) (HW_FTM_CnSC_WR(x, n, HW_FTM_CnSC_RD(x, n) |  (v)))
#define HW_FTM_CnSC_CLR(x, n, v) (HW_FTM_CnSC_WR(x, n, HW_FTM_CnSC_RD(x, n) & ~(v)))
#define HW_FTM_CnSC_TOG(x, n, v) (HW_FTM_CnSC_WR(x, n, HW_FTM_CnSC_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_CnSC bitfields
 */

/*!
 * @name Register FTM_CnSC, field DMA[0] (RW)
 *
 * Enables DMA transfers for the channel.
 *
 * Values:
 * - 0 - Disable DMA transfers.
 * - 1 - Enable DMA transfers.
 */
/*@{*/
#define BP_FTM_CnSC_DMA      (0U)          /*!< Bit position for FTM_CnSC_DMA. */
#define BM_FTM_CnSC_DMA      (0x00000001U) /*!< Bit mask for FTM_CnSC_DMA. */
#define BS_FTM_CnSC_DMA      (1U)          /*!< Bit field size in bits for FTM_CnSC_DMA. */

/*! @brief Read current value of the FTM_CnSC_DMA field. */
#define BR_FTM_CnSC_DMA(x, n) (HW_FTM_CnSC(x, n).B.DMA)

/*! @brief Format value for bitfield FTM_CnSC_DMA. */
#define BF_FTM_CnSC_DMA(v)   ((uint32_t)((uint32_t)(v) << BP_FTM_CnSC_DMA) & BM_FTM_CnSC_DMA)

/*! @brief Set the DMA field to a new value. */
#define BW_FTM_CnSC_DMA(x, n, v) (HW_FTM_CnSC_WR(x, n, (HW_FTM_CnSC_RD(x, n) & ~BM_FTM_CnSC_DMA) | BF_FTM_CnSC_DMA(v)))
/*@}*/

/*!
 * @name Register FTM_CnSC, field ICRST[1] (RW)
 *
 * FTM counter reset is driven by the selected event of the channel (n) in the
 * Input Capture mode. This field is write protected. It can be written only when
 * MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - FTM counter is not reset when the selected channel (n) input event is
 *     detected.
 * - 1 - FTM counter is reset when the selected channel (n) input event is
 *     detected.
 */
/*@{*/
#define BP_FTM_CnSC_ICRST    (1U)          /*!< Bit position for FTM_CnSC_ICRST. */
#define BM_FTM_CnSC_ICRST    (0x00000002U) /*!< Bit mask for FTM_CnSC_ICRST. */
#define BS_FTM_CnSC_ICRST    (1U)          /*!< Bit field size in bits for FTM_CnSC_ICRST. */

/*! @brief Read current value of the FTM_CnSC_ICRST field. */
#define BR_FTM_CnSC_ICRST(x, n) (HW_FTM_CnSC(x, n).B.ICRST)

/*! @brief Format value for bitfield FTM_CnSC_ICRST. */
#define BF_FTM_CnSC_ICRST(v) ((uint32_t)((uint32_t)(v) << BP_FTM_CnSC_ICRST) & BM_FTM_CnSC_ICRST)

/*! @brief Set the ICRST field to a new value. */
#define BW_FTM_CnSC_ICRST(x, n, v) (HW_FTM_CnSC_WR(x, n, (HW_FTM_CnSC_RD(x, n) & ~BM_FTM_CnSC_ICRST) | BF_FTM_CnSC_ICRST(v)))
/*@}*/

/*!
 * @name Register FTM_CnSC, field ELSA[2] (RW)
 *
 * The functionality of ELSB and ELSA depends on the channel mode. See . This
 * field is write protected. It can be written only when MODE[WPDIS] = 1.
 */
/*@{*/
#define BP_FTM_CnSC_ELSA     (2U)          /*!< Bit position for FTM_CnSC_ELSA. */
#define BM_FTM_CnSC_ELSA     (0x00000004U) /*!< Bit mask for FTM_CnSC_ELSA. */
#define BS_FTM_CnSC_ELSA     (1U)          /*!< Bit field size in bits for FTM_CnSC_ELSA. */

/*! @brief Read current value of the FTM_CnSC_ELSA field. */
#define BR_FTM_CnSC_ELSA(x, n) (HW_FTM_CnSC(x, n).B.ELSA)

/*! @brief Format value for bitfield FTM_CnSC_ELSA. */
#define BF_FTM_CnSC_ELSA(v)  ((uint32_t)((uint32_t)(v) << BP_FTM_CnSC_ELSA) & BM_FTM_CnSC_ELSA)

/*! @brief Set the ELSA field to a new value. */
#define BW_FTM_CnSC_ELSA(x, n, v) (HW_FTM_CnSC_WR(x, n, (HW_FTM_CnSC_RD(x, n) & ~BM_FTM_CnSC_ELSA) | BF_FTM_CnSC_ELSA(v)))
/*@}*/

/*!
 * @name Register FTM_CnSC, field ELSB[3] (RW)
 *
 * The functionality of ELSB and ELSA depends on the channel mode. See . This
 * field is write protected. It can be written only when MODE[WPDIS] = 1.
 */
/*@{*/
#define BP_FTM_CnSC_ELSB     (3U)          /*!< Bit position for FTM_CnSC_ELSB. */
#define BM_FTM_CnSC_ELSB     (0x00000008U) /*!< Bit mask for FTM_CnSC_ELSB. */
#define BS_FTM_CnSC_ELSB     (1U)          /*!< Bit field size in bits for FTM_CnSC_ELSB. */

/*! @brief Read current value of the FTM_CnSC_ELSB field. */
#define BR_FTM_CnSC_ELSB(x, n) (HW_FTM_CnSC(x, n).B.ELSB)

/*! @brief Format value for bitfield FTM_CnSC_ELSB. */
#define BF_FTM_CnSC_ELSB(v)  ((uint32_t)((uint32_t)(v) << BP_FTM_CnSC_ELSB) & BM_FTM_CnSC_ELSB)

/*! @brief Set the ELSB field to a new value. */
#define BW_FTM_CnSC_ELSB(x, n, v) (HW_FTM_CnSC_WR(x, n, (HW_FTM_CnSC_RD(x, n) & ~BM_FTM_CnSC_ELSB) | BF_FTM_CnSC_ELSB(v)))
/*@}*/

/*!
 * @name Register FTM_CnSC, field MSA[4] (RW)
 *
 * Used for further selections in the channel logic. Its functionality is
 * dependent on the channel mode. See . This field is write protected. It can be
 * written only when MODE[WPDIS] = 1.
 */
/*@{*/
#define BP_FTM_CnSC_MSA      (4U)          /*!< Bit position for FTM_CnSC_MSA. */
#define BM_FTM_CnSC_MSA      (0x00000010U) /*!< Bit mask for FTM_CnSC_MSA. */
#define BS_FTM_CnSC_MSA      (1U)          /*!< Bit field size in bits for FTM_CnSC_MSA. */

/*! @brief Read current value of the FTM_CnSC_MSA field. */
#define BR_FTM_CnSC_MSA(x, n) (HW_FTM_CnSC(x, n).B.MSA)

/*! @brief Format value for bitfield FTM_CnSC_MSA. */
#define BF_FTM_CnSC_MSA(v)   ((uint32_t)((uint32_t)(v) << BP_FTM_CnSC_MSA) & BM_FTM_CnSC_MSA)

/*! @brief Set the MSA field to a new value. */
#define BW_FTM_CnSC_MSA(x, n, v) (HW_FTM_CnSC_WR(x, n, (HW_FTM_CnSC_RD(x, n) & ~BM_FTM_CnSC_MSA) | BF_FTM_CnSC_MSA(v)))
/*@}*/

/*!
 * @name Register FTM_CnSC, field MSB[5] (RW)
 *
 * Used for further selections in the channel logic. Its functionality is
 * dependent on the channel mode. See . This field is write protected. It can be
 * written only when MODE[WPDIS] = 1.
 */
/*@{*/
#define BP_FTM_CnSC_MSB      (5U)          /*!< Bit position for FTM_CnSC_MSB. */
#define BM_FTM_CnSC_MSB      (0x00000020U) /*!< Bit mask for FTM_CnSC_MSB. */
#define BS_FTM_CnSC_MSB      (1U)          /*!< Bit field size in bits for FTM_CnSC_MSB. */

/*! @brief Read current value of the FTM_CnSC_MSB field. */
#define BR_FTM_CnSC_MSB(x, n) (HW_FTM_CnSC(x, n).B.MSB)

/*! @brief Format value for bitfield FTM_CnSC_MSB. */
#define BF_FTM_CnSC_MSB(v)   ((uint32_t)((uint32_t)(v) << BP_FTM_CnSC_MSB) & BM_FTM_CnSC_MSB)

/*! @brief Set the MSB field to a new value. */
#define BW_FTM_CnSC_MSB(x, n, v) (HW_FTM_CnSC_WR(x, n, (HW_FTM_CnSC_RD(x, n) & ~BM_FTM_CnSC_MSB) | BF_FTM_CnSC_MSB(v)))
/*@}*/

/*!
 * @name Register FTM_CnSC, field CHIE[6] (RW)
 *
 * Enables channel interrupts.
 *
 * Values:
 * - 0 - Disable channel interrupts. Use software polling.
 * - 1 - Enable channel interrupts.
 */
/*@{*/
#define BP_FTM_CnSC_CHIE     (6U)          /*!< Bit position for FTM_CnSC_CHIE. */
#define BM_FTM_CnSC_CHIE     (0x00000040U) /*!< Bit mask for FTM_CnSC_CHIE. */
#define BS_FTM_CnSC_CHIE     (1U)          /*!< Bit field size in bits for FTM_CnSC_CHIE. */

/*! @brief Read current value of the FTM_CnSC_CHIE field. */
#define BR_FTM_CnSC_CHIE(x, n) (HW_FTM_CnSC(x, n).B.CHIE)

/*! @brief Format value for bitfield FTM_CnSC_CHIE. */
#define BF_FTM_CnSC_CHIE(v)  ((uint32_t)((uint32_t)(v) << BP_FTM_CnSC_CHIE) & BM_FTM_CnSC_CHIE)

/*! @brief Set the CHIE field to a new value. */
#define BW_FTM_CnSC_CHIE(x, n, v) (HW_FTM_CnSC_WR(x, n, (HW_FTM_CnSC_RD(x, n) & ~BM_FTM_CnSC_CHIE) | BF_FTM_CnSC_CHIE(v)))
/*@}*/

/*!
 * @name Register FTM_CnSC, field CHF[7] (ROWZ)
 *
 * Set by hardware when an event occurs on the channel. CHF is cleared by
 * reading the CSC register while CHnF is set and then writing a 0 to the CHF bit.
 * Writing a 1 to CHF has no effect. If another event occurs between the read and
 * write operations, the write operation has no effect; therefore, CHF remains set
 * indicating an event has occurred. In this case a CHF interrupt request is not
 * lost due to the clearing sequence for a previous CHF.
 *
 * Values:
 * - 0 - No channel event has occurred.
 * - 1 - A channel event has occurred.
 */
/*@{*/
#define BP_FTM_CnSC_CHF      (7U)          /*!< Bit position for FTM_CnSC_CHF. */
#define BM_FTM_CnSC_CHF      (0x00000080U) /*!< Bit mask for FTM_CnSC_CHF. */
#define BS_FTM_CnSC_CHF      (1U)          /*!< Bit field size in bits for FTM_CnSC_CHF. */

/*! @brief Read current value of the FTM_CnSC_CHF field. */
#define BR_FTM_CnSC_CHF(x, n) (HW_FTM_CnSC(x, n).B.CHF)

/*! @brief Format value for bitfield FTM_CnSC_CHF. */
#define BF_FTM_CnSC_CHF(v)   ((uint32_t)((uint32_t)(v) << BP_FTM_CnSC_CHF) & BM_FTM_CnSC_CHF)

/*! @brief Set the CHF field to a new value. */
#define BW_FTM_CnSC_CHF(x, n, v) (HW_FTM_CnSC_WR(x, n, (HW_FTM_CnSC_RD(x, n) & ~BM_FTM_CnSC_CHF) | BF_FTM_CnSC_CHF(v)))
/*@}*/
/*******************************************************************************
 * HW_FTM_CnV - Channel (n) Value
 ******************************************************************************/

/*!
 * @brief HW_FTM_CnV - Channel (n) Value (RW)
 *
 * Reset value: 0x00000000U
 *
 * These registers contain the captured FTM counter value for the input modes or
 * the match value for the output modes. In Input Capture, Capture Test, and
 * Dual Edge Capture modes, any write to a CnV register is ignored. In output modes,
 * writing to a CnV register latches the value into a buffer. A CnV register is
 * updated with the value of its write buffer according to Registers updated from
 * write buffers. If FTMEN = 0, this write coherency mechanism may be manually
 * reset by writing to the CnSC register whether BDM mode is active or not.
 */
typedef union _hw_ftm_cnv
{
    uint32_t U;
    struct _hw_ftm_cnv_bitfields
    {
        uint32_t VAL : 16;             /*!< [15:0] Channel Value */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_ftm_cnv_t;

/*!
 * @name Constants and macros for entire FTM_CnV register
 */
/*@{*/
#define HW_FTM_CnV_COUNT (8U)

#define HW_FTM_CnV_ADDR(x, n)    ((uintptr_t)(x) + 0x10U + (0x8U * (n)))

#define HW_FTM_CnV(x, n)         (*(__IO hw_ftm_cnv_t *) HW_FTM_CnV_ADDR(x, n))
#define HW_FTM_CnV_RD(x, n)      (HW_FTM_CnV(x, n).U)
#define HW_FTM_CnV_WR(x, n, v)   (HW_FTM_CnV(x, n).U = (v))
#define HW_FTM_CnV_SET(x, n, v)  (HW_FTM_CnV_WR(x, n, HW_FTM_CnV_RD(x, n) |  (v)))
#define HW_FTM_CnV_CLR(x, n, v)  (HW_FTM_CnV_WR(x, n, HW_FTM_CnV_RD(x, n) & ~(v)))
#define HW_FTM_CnV_TOG(x, n, v)  (HW_FTM_CnV_WR(x, n, HW_FTM_CnV_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_CnV bitfields
 */

/*!
 * @name Register FTM_CnV, field VAL[15:0] (RW)
 *
 * Captured FTM counter value of the input modes or the match value for the
 * output modes
 */
/*@{*/
#define BP_FTM_CnV_VAL       (0U)          /*!< Bit position for FTM_CnV_VAL. */
#define BM_FTM_CnV_VAL       (0x0000FFFFU) /*!< Bit mask for FTM_CnV_VAL. */
#define BS_FTM_CnV_VAL       (16U)         /*!< Bit field size in bits for FTM_CnV_VAL. */

/*! @brief Read current value of the FTM_CnV_VAL field. */
#define BR_FTM_CnV_VAL(x, n) (HW_FTM_CnV(x, n).B.VAL)

/*! @brief Format value for bitfield FTM_CnV_VAL. */
#define BF_FTM_CnV_VAL(v)    ((uint32_t)((uint32_t)(v) << BP_FTM_CnV_VAL) & BM_FTM_CnV_VAL)

/*! @brief Set the VAL field to a new value. */
#define BW_FTM_CnV_VAL(x, n, v) (HW_FTM_CnV_WR(x, n, (HW_FTM_CnV_RD(x, n) & ~BM_FTM_CnV_VAL) | BF_FTM_CnV_VAL(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_CNTIN - Counter Initial Value
 ******************************************************************************/

/*!
 * @brief HW_FTM_CNTIN - Counter Initial Value (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Counter Initial Value register contains the initial value for the FTM
 * counter. Writing to the CNTIN register latches the value into a buffer. The CNTIN
 * register is updated with the value of its write buffer according to Registers
 * updated from write buffers. When the FTM clock is initially selected, by
 * writing a non-zero value to the CLKS bits, the FTM counter starts with the value
 * 0x0000. To avoid this behavior, before the first write to select the FTM clock,
 * write the new value to the the CNTIN register and then initialize the FTM
 * counter by writing any value to the CNT register.
 */
typedef union _hw_ftm_cntin
{
    uint32_t U;
    struct _hw_ftm_cntin_bitfields
    {
        uint32_t INIT : 16;            /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_ftm_cntin_t;

/*!
 * @name Constants and macros for entire FTM_CNTIN register
 */
/*@{*/
#define HW_FTM_CNTIN_ADDR(x)     ((uintptr_t)(x) + 0x4CU)

#define HW_FTM_CNTIN(x)          (*(__IO hw_ftm_cntin_t *) HW_FTM_CNTIN_ADDR(x))
#define HW_FTM_CNTIN_RD(x)       (HW_FTM_CNTIN(x).U)
#define HW_FTM_CNTIN_WR(x, v)    (HW_FTM_CNTIN(x).U = (v))
#define HW_FTM_CNTIN_SET(x, v)   (HW_FTM_CNTIN_WR(x, HW_FTM_CNTIN_RD(x) |  (v)))
#define HW_FTM_CNTIN_CLR(x, v)   (HW_FTM_CNTIN_WR(x, HW_FTM_CNTIN_RD(x) & ~(v)))
#define HW_FTM_CNTIN_TOG(x, v)   (HW_FTM_CNTIN_WR(x, HW_FTM_CNTIN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_CNTIN bitfields
 */

/*!
 * @name Register FTM_CNTIN, field INIT[15:0] (RW)
 *
 * Initial Value Of The FTM Counter
 */
/*@{*/
#define BP_FTM_CNTIN_INIT    (0U)          /*!< Bit position for FTM_CNTIN_INIT. */
#define BM_FTM_CNTIN_INIT    (0x0000FFFFU) /*!< Bit mask for FTM_CNTIN_INIT. */
#define BS_FTM_CNTIN_INIT    (16U)         /*!< Bit field size in bits for FTM_CNTIN_INIT. */

/*! @brief Read current value of the FTM_CNTIN_INIT field. */
#define BR_FTM_CNTIN_INIT(x) (HW_FTM_CNTIN(x).B.INIT)

/*! @brief Format value for bitfield FTM_CNTIN_INIT. */
#define BF_FTM_CNTIN_INIT(v) ((uint32_t)((uint32_t)(v) << BP_FTM_CNTIN_INIT) & BM_FTM_CNTIN_INIT)

/*! @brief Set the INIT field to a new value. */
#define BW_FTM_CNTIN_INIT(x, v) (HW_FTM_CNTIN_WR(x, (HW_FTM_CNTIN_RD(x) & ~BM_FTM_CNTIN_INIT) | BF_FTM_CNTIN_INIT(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_STATUS - Capture And Compare Status
 ******************************************************************************/

/*!
 * @brief HW_FTM_STATUS - Capture And Compare Status (RW)
 *
 * Reset value: 0x00000000U
 *
 * The STATUS register contains a copy of the status flag CHnF bit in CnSC for
 * each FTM channel for software convenience. Each CHnF bit in STATUS is a mirror
 * of CHnF bit in CnSC. All CHnF bits can be checked using only one read of
 * STATUS. All CHnF bits can be cleared by reading STATUS followed by writing 0x00 to
 * STATUS. Hardware sets the individual channel flags when an event occurs on the
 * channel. CHnF is cleared by reading STATUS while CHnF is set and then writing
 * a 0 to the CHnF bit. Writing a 1 to CHnF has no effect. If another event
 * occurs between the read and write operations, the write operation has no effect;
 * therefore, CHnF remains set indicating an event has occurred. In this case, a
 * CHnF interrupt request is not lost due to the clearing sequence for a previous
 * CHnF.
 */
typedef union _hw_ftm_status
{
    uint32_t U;
    struct _hw_ftm_status_bitfields
    {
        uint32_t CH0F : 1;             /*!< [0] Channel 0 Flag */
        uint32_t CH1F : 1;             /*!< [1] Channel 1 Flag */
        uint32_t CH2F : 1;             /*!< [2] Channel 2 Flag */
        uint32_t CH3F : 1;             /*!< [3] Channel 3 Flag */
        uint32_t CH4F : 1;             /*!< [4] Channel 4 Flag */
        uint32_t CH5F : 1;             /*!< [5] Channel 5 Flag */
        uint32_t CH6F : 1;             /*!< [6] Channel 6 Flag */
        uint32_t CH7F : 1;             /*!< [7] Channel 7 Flag */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_ftm_status_t;

/*!
 * @name Constants and macros for entire FTM_STATUS register
 */
/*@{*/
#define HW_FTM_STATUS_ADDR(x)    ((uintptr_t)(x) + 0x50U)

#define HW_FTM_STATUS(x)         (*(__IO hw_ftm_status_t *) HW_FTM_STATUS_ADDR(x))
#define HW_FTM_STATUS_RD(x)      (HW_FTM_STATUS(x).U)
#define HW_FTM_STATUS_WR(x, v)   (HW_FTM_STATUS(x).U = (v))
#define HW_FTM_STATUS_SET(x, v)  (HW_FTM_STATUS_WR(x, HW_FTM_STATUS_RD(x) |  (v)))
#define HW_FTM_STATUS_CLR(x, v)  (HW_FTM_STATUS_WR(x, HW_FTM_STATUS_RD(x) & ~(v)))
#define HW_FTM_STATUS_TOG(x, v)  (HW_FTM_STATUS_WR(x, HW_FTM_STATUS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_STATUS bitfields
 */

/*!
 * @name Register FTM_STATUS, field CH0F[0] (ROWZ)
 *
 * See the register description.
 *
 * Values:
 * - 0 - No channel event has occurred.
 * - 1 - A channel event has occurred.
 */
/*@{*/
#define BP_FTM_STATUS_CH0F   (0U)          /*!< Bit position for FTM_STATUS_CH0F. */
#define BM_FTM_STATUS_CH0F   (0x00000001U) /*!< Bit mask for FTM_STATUS_CH0F. */
#define BS_FTM_STATUS_CH0F   (1U)          /*!< Bit field size in bits for FTM_STATUS_CH0F. */

/*! @brief Read current value of the FTM_STATUS_CH0F field. */
#define BR_FTM_STATUS_CH0F(x) (HW_FTM_STATUS(x).B.CH0F)

/*! @brief Format value for bitfield FTM_STATUS_CH0F. */
#define BF_FTM_STATUS_CH0F(v) ((uint32_t)((uint32_t)(v) << BP_FTM_STATUS_CH0F) & BM_FTM_STATUS_CH0F)

/*! @brief Set the CH0F field to a new value. */
#define BW_FTM_STATUS_CH0F(x, v) (HW_FTM_STATUS_WR(x, (HW_FTM_STATUS_RD(x) & ~BM_FTM_STATUS_CH0F) | BF_FTM_STATUS_CH0F(v)))
/*@}*/

/*!
 * @name Register FTM_STATUS, field CH1F[1] (ROWZ)
 *
 * See the register description.
 *
 * Values:
 * - 0 - No channel event has occurred.
 * - 1 - A channel event has occurred.
 */
/*@{*/
#define BP_FTM_STATUS_CH1F   (1U)          /*!< Bit position for FTM_STATUS_CH1F. */
#define BM_FTM_STATUS_CH1F   (0x00000002U) /*!< Bit mask for FTM_STATUS_CH1F. */
#define BS_FTM_STATUS_CH1F   (1U)          /*!< Bit field size in bits for FTM_STATUS_CH1F. */

/*! @brief Read current value of the FTM_STATUS_CH1F field. */
#define BR_FTM_STATUS_CH1F(x) (HW_FTM_STATUS(x).B.CH1F)

/*! @brief Format value for bitfield FTM_STATUS_CH1F. */
#define BF_FTM_STATUS_CH1F(v) ((uint32_t)((uint32_t)(v) << BP_FTM_STATUS_CH1F) & BM_FTM_STATUS_CH1F)

/*! @brief Set the CH1F field to a new value. */
#define BW_FTM_STATUS_CH1F(x, v) (HW_FTM_STATUS_WR(x, (HW_FTM_STATUS_RD(x) & ~BM_FTM_STATUS_CH1F) | BF_FTM_STATUS_CH1F(v)))
/*@}*/

/*!
 * @name Register FTM_STATUS, field CH2F[2] (ROWZ)
 *
 * See the register description.
 *
 * Values:
 * - 0 - No channel event has occurred.
 * - 1 - A channel event has occurred.
 */
/*@{*/
#define BP_FTM_STATUS_CH2F   (2U)          /*!< Bit position for FTM_STATUS_CH2F. */
#define BM_FTM_STATUS_CH2F   (0x00000004U) /*!< Bit mask for FTM_STATUS_CH2F. */
#define BS_FTM_STATUS_CH2F   (1U)          /*!< Bit field size in bits for FTM_STATUS_CH2F. */

/*! @brief Read current value of the FTM_STATUS_CH2F field. */
#define BR_FTM_STATUS_CH2F(x) (HW_FTM_STATUS(x).B.CH2F)

/*! @brief Format value for bitfield FTM_STATUS_CH2F. */
#define BF_FTM_STATUS_CH2F(v) ((uint32_t)((uint32_t)(v) << BP_FTM_STATUS_CH2F) & BM_FTM_STATUS_CH2F)

/*! @brief Set the CH2F field to a new value. */
#define BW_FTM_STATUS_CH2F(x, v) (HW_FTM_STATUS_WR(x, (HW_FTM_STATUS_RD(x) & ~BM_FTM_STATUS_CH2F) | BF_FTM_STATUS_CH2F(v)))
/*@}*/

/*!
 * @name Register FTM_STATUS, field CH3F[3] (ROWZ)
 *
 * See the register description.
 *
 * Values:
 * - 0 - No channel event has occurred.
 * - 1 - A channel event has occurred.
 */
/*@{*/
#define BP_FTM_STATUS_CH3F   (3U)          /*!< Bit position for FTM_STATUS_CH3F. */
#define BM_FTM_STATUS_CH3F   (0x00000008U) /*!< Bit mask for FTM_STATUS_CH3F. */
#define BS_FTM_STATUS_CH3F   (1U)          /*!< Bit field size in bits for FTM_STATUS_CH3F. */

/*! @brief Read current value of the FTM_STATUS_CH3F field. */
#define BR_FTM_STATUS_CH3F(x) (HW_FTM_STATUS(x).B.CH3F)

/*! @brief Format value for bitfield FTM_STATUS_CH3F. */
#define BF_FTM_STATUS_CH3F(v) ((uint32_t)((uint32_t)(v) << BP_FTM_STATUS_CH3F) & BM_FTM_STATUS_CH3F)

/*! @brief Set the CH3F field to a new value. */
#define BW_FTM_STATUS_CH3F(x, v) (HW_FTM_STATUS_WR(x, (HW_FTM_STATUS_RD(x) & ~BM_FTM_STATUS_CH3F) | BF_FTM_STATUS_CH3F(v)))
/*@}*/

/*!
 * @name Register FTM_STATUS, field CH4F[4] (ROWZ)
 *
 * See the register description.
 *
 * Values:
 * - 0 - No channel event has occurred.
 * - 1 - A channel event has occurred.
 */
/*@{*/
#define BP_FTM_STATUS_CH4F   (4U)          /*!< Bit position for FTM_STATUS_CH4F. */
#define BM_FTM_STATUS_CH4F   (0x00000010U) /*!< Bit mask for FTM_STATUS_CH4F. */
#define BS_FTM_STATUS_CH4F   (1U)          /*!< Bit field size in bits for FTM_STATUS_CH4F. */

/*! @brief Read current value of the FTM_STATUS_CH4F field. */
#define BR_FTM_STATUS_CH4F(x) (HW_FTM_STATUS(x).B.CH4F)

/*! @brief Format value for bitfield FTM_STATUS_CH4F. */
#define BF_FTM_STATUS_CH4F(v) ((uint32_t)((uint32_t)(v) << BP_FTM_STATUS_CH4F) & BM_FTM_STATUS_CH4F)

/*! @brief Set the CH4F field to a new value. */
#define BW_FTM_STATUS_CH4F(x, v) (HW_FTM_STATUS_WR(x, (HW_FTM_STATUS_RD(x) & ~BM_FTM_STATUS_CH4F) | BF_FTM_STATUS_CH4F(v)))
/*@}*/

/*!
 * @name Register FTM_STATUS, field CH5F[5] (ROWZ)
 *
 * See the register description.
 *
 * Values:
 * - 0 - No channel event has occurred.
 * - 1 - A channel event has occurred.
 */
/*@{*/
#define BP_FTM_STATUS_CH5F   (5U)          /*!< Bit position for FTM_STATUS_CH5F. */
#define BM_FTM_STATUS_CH5F   (0x00000020U) /*!< Bit mask for FTM_STATUS_CH5F. */
#define BS_FTM_STATUS_CH5F   (1U)          /*!< Bit field size in bits for FTM_STATUS_CH5F. */

/*! @brief Read current value of the FTM_STATUS_CH5F field. */
#define BR_FTM_STATUS_CH5F(x) (HW_FTM_STATUS(x).B.CH5F)

/*! @brief Format value for bitfield FTM_STATUS_CH5F. */
#define BF_FTM_STATUS_CH5F(v) ((uint32_t)((uint32_t)(v) << BP_FTM_STATUS_CH5F) & BM_FTM_STATUS_CH5F)

/*! @brief Set the CH5F field to a new value. */
#define BW_FTM_STATUS_CH5F(x, v) (HW_FTM_STATUS_WR(x, (HW_FTM_STATUS_RD(x) & ~BM_FTM_STATUS_CH5F) | BF_FTM_STATUS_CH5F(v)))
/*@}*/

/*!
 * @name Register FTM_STATUS, field CH6F[6] (ROWZ)
 *
 * See the register description.
 *
 * Values:
 * - 0 - No channel event has occurred.
 * - 1 - A channel event has occurred.
 */
/*@{*/
#define BP_FTM_STATUS_CH6F   (6U)          /*!< Bit position for FTM_STATUS_CH6F. */
#define BM_FTM_STATUS_CH6F   (0x00000040U) /*!< Bit mask for FTM_STATUS_CH6F. */
#define BS_FTM_STATUS_CH6F   (1U)          /*!< Bit field size in bits for FTM_STATUS_CH6F. */

/*! @brief Read current value of the FTM_STATUS_CH6F field. */
#define BR_FTM_STATUS_CH6F(x) (HW_FTM_STATUS(x).B.CH6F)

/*! @brief Format value for bitfield FTM_STATUS_CH6F. */
#define BF_FTM_STATUS_CH6F(v) ((uint32_t)((uint32_t)(v) << BP_FTM_STATUS_CH6F) & BM_FTM_STATUS_CH6F)

/*! @brief Set the CH6F field to a new value. */
#define BW_FTM_STATUS_CH6F(x, v) (HW_FTM_STATUS_WR(x, (HW_FTM_STATUS_RD(x) & ~BM_FTM_STATUS_CH6F) | BF_FTM_STATUS_CH6F(v)))
/*@}*/

/*!
 * @name Register FTM_STATUS, field CH7F[7] (ROWZ)
 *
 * See the register description.
 *
 * Values:
 * - 0 - No channel event has occurred.
 * - 1 - A channel event has occurred.
 */
/*@{*/
#define BP_FTM_STATUS_CH7F   (7U)          /*!< Bit position for FTM_STATUS_CH7F. */
#define BM_FTM_STATUS_CH7F   (0x00000080U) /*!< Bit mask for FTM_STATUS_CH7F. */
#define BS_FTM_STATUS_CH7F   (1U)          /*!< Bit field size in bits for FTM_STATUS_CH7F. */

/*! @brief Read current value of the FTM_STATUS_CH7F field. */
#define BR_FTM_STATUS_CH7F(x) (HW_FTM_STATUS(x).B.CH7F)

/*! @brief Format value for bitfield FTM_STATUS_CH7F. */
#define BF_FTM_STATUS_CH7F(v) ((uint32_t)((uint32_t)(v) << BP_FTM_STATUS_CH7F) & BM_FTM_STATUS_CH7F)

/*! @brief Set the CH7F field to a new value. */
#define BW_FTM_STATUS_CH7F(x, v) (HW_FTM_STATUS_WR(x, (HW_FTM_STATUS_RD(x) & ~BM_FTM_STATUS_CH7F) | BF_FTM_STATUS_CH7F(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_MODE - Features Mode Selection
 ******************************************************************************/

/*!
 * @brief HW_FTM_MODE - Features Mode Selection (RW)
 *
 * Reset value: 0x00000004U
 *
 * This register contains the global enable bit for FTM-specific features and
 * the control bits used to configure: Capture Test mode PWM synchronization Write
 * protection Channel output initialization These controls relate to all channels
 * within this module.
 */
typedef union _hw_ftm_mode
{
    uint32_t U;
    struct _hw_ftm_mode_bitfields
    {
        uint32_t FTMEN : 1;            /*!< [0] FTM Enable */
        uint32_t INIT : 1;             /*!< [1] Initialize The Channels Output */
        uint32_t WPDIS : 1;            /*!< [2] Write Protection Disable */
        uint32_t PWMSYNC : 1;          /*!< [3] PWM Synchronization Mode */
        uint32_t CAPTEST : 1;          /*!< [4] Capture Test Mode Enable */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_ftm_mode_t;

/*!
 * @name Constants and macros for entire FTM_MODE register
 */
/*@{*/
#define HW_FTM_MODE_ADDR(x)      ((uintptr_t)(x) + 0x54U)

#define HW_FTM_MODE(x)           (*(__IO hw_ftm_mode_t *) HW_FTM_MODE_ADDR(x))
#define HW_FTM_MODE_RD(x)        (HW_FTM_MODE(x).U)
#define HW_FTM_MODE_WR(x, v)     (HW_FTM_MODE(x).U = (v))
#define HW_FTM_MODE_SET(x, v)    (HW_FTM_MODE_WR(x, HW_FTM_MODE_RD(x) |  (v)))
#define HW_FTM_MODE_CLR(x, v)    (HW_FTM_MODE_WR(x, HW_FTM_MODE_RD(x) & ~(v)))
#define HW_FTM_MODE_TOG(x, v)    (HW_FTM_MODE_WR(x, HW_FTM_MODE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_MODE bitfields
 */

/*!
 * @name Register FTM_MODE, field FTMEN[0] (RW)
 *
 * This field is write protected. It can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - TPM compatibility. Free running counter and synchronization compatible
 *     with TPM.
 * - 1 - Free running counter and synchronization are different from TPM
 *     behavior.
 */
/*@{*/
#define BP_FTM_MODE_FTMEN    (0U)          /*!< Bit position for FTM_MODE_FTMEN. */
#define BM_FTM_MODE_FTMEN    (0x00000001U) /*!< Bit mask for FTM_MODE_FTMEN. */
#define BS_FTM_MODE_FTMEN    (1U)          /*!< Bit field size in bits for FTM_MODE_FTMEN. */

/*! @brief Read current value of the FTM_MODE_FTMEN field. */
#define BR_FTM_MODE_FTMEN(x) (HW_FTM_MODE(x).B.FTMEN)

/*! @brief Format value for bitfield FTM_MODE_FTMEN. */
#define BF_FTM_MODE_FTMEN(v) ((uint32_t)((uint32_t)(v) << BP_FTM_MODE_FTMEN) & BM_FTM_MODE_FTMEN)

/*! @brief Set the FTMEN field to a new value. */
#define BW_FTM_MODE_FTMEN(x, v) (HW_FTM_MODE_WR(x, (HW_FTM_MODE_RD(x) & ~BM_FTM_MODE_FTMEN) | BF_FTM_MODE_FTMEN(v)))
/*@}*/

/*!
 * @name Register FTM_MODE, field INIT[1] (RW)
 *
 * When a 1 is written to INIT bit the channels output is initialized according
 * to the state of their corresponding bit in the OUTINIT register. Writing a 0
 * to INIT bit has no effect. The INIT bit is always read as 0.
 */
/*@{*/
#define BP_FTM_MODE_INIT     (1U)          /*!< Bit position for FTM_MODE_INIT. */
#define BM_FTM_MODE_INIT     (0x00000002U) /*!< Bit mask for FTM_MODE_INIT. */
#define BS_FTM_MODE_INIT     (1U)          /*!< Bit field size in bits for FTM_MODE_INIT. */

/*! @brief Read current value of the FTM_MODE_INIT field. */
#define BR_FTM_MODE_INIT(x)  (HW_FTM_MODE(x).B.INIT)

/*! @brief Format value for bitfield FTM_MODE_INIT. */
#define BF_FTM_MODE_INIT(v)  ((uint32_t)((uint32_t)(v) << BP_FTM_MODE_INIT) & BM_FTM_MODE_INIT)

/*! @brief Set the INIT field to a new value. */
#define BW_FTM_MODE_INIT(x, v) (HW_FTM_MODE_WR(x, (HW_FTM_MODE_RD(x) & ~BM_FTM_MODE_INIT) | BF_FTM_MODE_INIT(v)))
/*@}*/

/*!
 * @name Register FTM_MODE, field WPDIS[2] (RW)
 *
 * When write protection is enabled (WPDIS = 0), write protected bits cannot be
 * written. When write protection is disabled (WPDIS = 1), write protected bits
 * can be written. The WPDIS bit is the negation of the WPEN bit. WPDIS is cleared
 * when 1 is written to WPEN. WPDIS is set when WPEN bit is read as a 1 and then
 * 1 is written to WPDIS. Writing 0 to WPDIS has no effect.
 *
 * Values:
 * - 0 - Write protection is enabled.
 * - 1 - Write protection is disabled.
 */
/*@{*/
#define BP_FTM_MODE_WPDIS    (2U)          /*!< Bit position for FTM_MODE_WPDIS. */
#define BM_FTM_MODE_WPDIS    (0x00000004U) /*!< Bit mask for FTM_MODE_WPDIS. */
#define BS_FTM_MODE_WPDIS    (1U)          /*!< Bit field size in bits for FTM_MODE_WPDIS. */

/*! @brief Read current value of the FTM_MODE_WPDIS field. */
#define BR_FTM_MODE_WPDIS(x) (HW_FTM_MODE(x).B.WPDIS)

/*! @brief Format value for bitfield FTM_MODE_WPDIS. */
#define BF_FTM_MODE_WPDIS(v) ((uint32_t)((uint32_t)(v) << BP_FTM_MODE_WPDIS) & BM_FTM_MODE_WPDIS)

/*! @brief Set the WPDIS field to a new value. */
#define BW_FTM_MODE_WPDIS(x, v) (HW_FTM_MODE_WR(x, (HW_FTM_MODE_RD(x) & ~BM_FTM_MODE_WPDIS) | BF_FTM_MODE_WPDIS(v)))
/*@}*/

/*!
 * @name Register FTM_MODE, field PWMSYNC[3] (RW)
 *
 * Selects which triggers can be used by MOD, CnV, OUTMASK, and FTM counter
 * synchronization. See PWM synchronization. The PWMSYNC bit configures the
 * synchronization when SYNCMODE is 0.
 *
 * Values:
 * - 0 - No restrictions. Software and hardware triggers can be used by MOD,
 *     CnV, OUTMASK, and FTM counter synchronization.
 * - 1 - Software trigger can only be used by MOD and CnV synchronization, and
 *     hardware triggers can only be used by OUTMASK and FTM counter
 *     synchronization.
 */
/*@{*/
#define BP_FTM_MODE_PWMSYNC  (3U)          /*!< Bit position for FTM_MODE_PWMSYNC. */
#define BM_FTM_MODE_PWMSYNC  (0x00000008U) /*!< Bit mask for FTM_MODE_PWMSYNC. */
#define BS_FTM_MODE_PWMSYNC  (1U)          /*!< Bit field size in bits for FTM_MODE_PWMSYNC. */

/*! @brief Read current value of the FTM_MODE_PWMSYNC field. */
#define BR_FTM_MODE_PWMSYNC(x) (HW_FTM_MODE(x).B.PWMSYNC)

/*! @brief Format value for bitfield FTM_MODE_PWMSYNC. */
#define BF_FTM_MODE_PWMSYNC(v) ((uint32_t)((uint32_t)(v) << BP_FTM_MODE_PWMSYNC) & BM_FTM_MODE_PWMSYNC)

/*! @brief Set the PWMSYNC field to a new value. */
#define BW_FTM_MODE_PWMSYNC(x, v) (HW_FTM_MODE_WR(x, (HW_FTM_MODE_RD(x) & ~BM_FTM_MODE_PWMSYNC) | BF_FTM_MODE_PWMSYNC(v)))
/*@}*/

/*!
 * @name Register FTM_MODE, field CAPTEST[4] (RW)
 *
 * Enables the capture test mode. This field is write protected. It can be
 * written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - Capture test mode is disabled.
 * - 1 - Capture test mode is enabled.
 */
/*@{*/
#define BP_FTM_MODE_CAPTEST  (4U)          /*!< Bit position for FTM_MODE_CAPTEST. */
#define BM_FTM_MODE_CAPTEST  (0x00000010U) /*!< Bit mask for FTM_MODE_CAPTEST. */
#define BS_FTM_MODE_CAPTEST  (1U)          /*!< Bit field size in bits for FTM_MODE_CAPTEST. */

/*! @brief Read current value of the FTM_MODE_CAPTEST field. */
#define BR_FTM_MODE_CAPTEST(x) (HW_FTM_MODE(x).B.CAPTEST)

/*! @brief Format value for bitfield FTM_MODE_CAPTEST. */
#define BF_FTM_MODE_CAPTEST(v) ((uint32_t)((uint32_t)(v) << BP_FTM_MODE_CAPTEST) & BM_FTM_MODE_CAPTEST)

/*! @brief Set the CAPTEST field to a new value. */
#define BW_FTM_MODE_CAPTEST(x, v) (HW_FTM_MODE_WR(x, (HW_FTM_MODE_RD(x) & ~BM_FTM_MODE_CAPTEST) | BF_FTM_MODE_CAPTEST(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_SYNC - Synchronization
 ******************************************************************************/

/*!
 * @brief HW_FTM_SYNC - Synchronization (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register configures the PWM synchronization. A synchronization event can
 * perform the synchronized update of MOD, CV, and OUTMASK registers with the
 * value of their write buffer and the FTM counter initialization. The software
 * trigger, SWSYNC bit, and hardware triggers TRIG0, TRIG1, and TRIG2 bits have a
 * potential conflict if used together when SYNCMODE = 0. Use only hardware or
 * software triggers but not both at the same time, otherwise unpredictable behavior
 * is likely to happen. The selection of the loading point, CNTMAX and CNTMIN
 * bits, is intended to provide the update of MOD, CNTIN, and CnV registers across
 * all enabled channels simultaneously. The use of the loading point selection
 * together with SYNCMODE = 0 and hardware trigger selection, TRIG0, TRIG1, or TRIG2
 * bits, is likely to result in unpredictable behavior. The synchronization
 * event selection also depends on the PWMSYNC (MODE register) and SYNCMODE (SYNCONF
 * register) bits. See PWM synchronization.
 */
typedef union _hw_ftm_sync
{
    uint32_t U;
    struct _hw_ftm_sync_bitfields
    {
        uint32_t CNTMIN : 1;           /*!< [0] Minimum Loading Point Enable */
        uint32_t CNTMAX : 1;           /*!< [1] Maximum Loading Point Enable */
        uint32_t REINIT : 1;           /*!< [2] FTM Counter Reinitialization By
                                        * Synchronization (FTM counter synchronization) */
        uint32_t SYNCHOM : 1;          /*!< [3] Output Mask Synchronization */
        uint32_t TRIG0 : 1;            /*!< [4] PWM Synchronization Hardware Trigger 0 */
        uint32_t TRIG1 : 1;            /*!< [5] PWM Synchronization Hardware Trigger 1 */
        uint32_t TRIG2 : 1;            /*!< [6] PWM Synchronization Hardware Trigger 2 */
        uint32_t SWSYNC : 1;           /*!< [7] PWM Synchronization Software Trigger */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_ftm_sync_t;

/*!
 * @name Constants and macros for entire FTM_SYNC register
 */
/*@{*/
#define HW_FTM_SYNC_ADDR(x)      ((uintptr_t)(x) + 0x58U)

#define HW_FTM_SYNC(x)           (*(__IO hw_ftm_sync_t *) HW_FTM_SYNC_ADDR(x))
#define HW_FTM_SYNC_RD(x)        (HW_FTM_SYNC(x).U)
#define HW_FTM_SYNC_WR(x, v)     (HW_FTM_SYNC(x).U = (v))
#define HW_FTM_SYNC_SET(x, v)    (HW_FTM_SYNC_WR(x, HW_FTM_SYNC_RD(x) |  (v)))
#define HW_FTM_SYNC_CLR(x, v)    (HW_FTM_SYNC_WR(x, HW_FTM_SYNC_RD(x) & ~(v)))
#define HW_FTM_SYNC_TOG(x, v)    (HW_FTM_SYNC_WR(x, HW_FTM_SYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_SYNC bitfields
 */

/*!
 * @name Register FTM_SYNC, field CNTMIN[0] (RW)
 *
 * Selects the minimum loading point to PWM synchronization. See Boundary cycle
 * and loading points. If CNTMIN is one, the selected loading point is when the
 * FTM counter reaches its minimum value (CNTIN register).
 *
 * Values:
 * - 0 - The minimum loading point is disabled.
 * - 1 - The minimum loading point is enabled.
 */
/*@{*/
#define BP_FTM_SYNC_CNTMIN   (0U)          /*!< Bit position for FTM_SYNC_CNTMIN. */
#define BM_FTM_SYNC_CNTMIN   (0x00000001U) /*!< Bit mask for FTM_SYNC_CNTMIN. */
#define BS_FTM_SYNC_CNTMIN   (1U)          /*!< Bit field size in bits for FTM_SYNC_CNTMIN. */

/*! @brief Read current value of the FTM_SYNC_CNTMIN field. */
#define BR_FTM_SYNC_CNTMIN(x) (HW_FTM_SYNC(x).B.CNTMIN)

/*! @brief Format value for bitfield FTM_SYNC_CNTMIN. */
#define BF_FTM_SYNC_CNTMIN(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNC_CNTMIN) & BM_FTM_SYNC_CNTMIN)

/*! @brief Set the CNTMIN field to a new value. */
#define BW_FTM_SYNC_CNTMIN(x, v) (HW_FTM_SYNC_WR(x, (HW_FTM_SYNC_RD(x) & ~BM_FTM_SYNC_CNTMIN) | BF_FTM_SYNC_CNTMIN(v)))
/*@}*/

/*!
 * @name Register FTM_SYNC, field CNTMAX[1] (RW)
 *
 * Selects the maximum loading point to PWM synchronization. See Boundary cycle
 * and loading points. If CNTMAX is 1, the selected loading point is when the FTM
 * counter reaches its maximum value (MOD register).
 *
 * Values:
 * - 0 - The maximum loading point is disabled.
 * - 1 - The maximum loading point is enabled.
 */
/*@{*/
#define BP_FTM_SYNC_CNTMAX   (1U)          /*!< Bit position for FTM_SYNC_CNTMAX. */
#define BM_FTM_SYNC_CNTMAX   (0x00000002U) /*!< Bit mask for FTM_SYNC_CNTMAX. */
#define BS_FTM_SYNC_CNTMAX   (1U)          /*!< Bit field size in bits for FTM_SYNC_CNTMAX. */

/*! @brief Read current value of the FTM_SYNC_CNTMAX field. */
#define BR_FTM_SYNC_CNTMAX(x) (HW_FTM_SYNC(x).B.CNTMAX)

/*! @brief Format value for bitfield FTM_SYNC_CNTMAX. */
#define BF_FTM_SYNC_CNTMAX(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNC_CNTMAX) & BM_FTM_SYNC_CNTMAX)

/*! @brief Set the CNTMAX field to a new value. */
#define BW_FTM_SYNC_CNTMAX(x, v) (HW_FTM_SYNC_WR(x, (HW_FTM_SYNC_RD(x) & ~BM_FTM_SYNC_CNTMAX) | BF_FTM_SYNC_CNTMAX(v)))
/*@}*/

/*!
 * @name Register FTM_SYNC, field REINIT[2] (RW)
 *
 * Determines if the FTM counter is reinitialized when the selected trigger for
 * the synchronization is detected. The REINIT bit configures the synchronization
 * when SYNCMODE is zero.
 *
 * Values:
 * - 0 - FTM counter continues to count normally.
 * - 1 - FTM counter is updated with its initial value when the selected trigger
 *     is detected.
 */
/*@{*/
#define BP_FTM_SYNC_REINIT   (2U)          /*!< Bit position for FTM_SYNC_REINIT. */
#define BM_FTM_SYNC_REINIT   (0x00000004U) /*!< Bit mask for FTM_SYNC_REINIT. */
#define BS_FTM_SYNC_REINIT   (1U)          /*!< Bit field size in bits for FTM_SYNC_REINIT. */

/*! @brief Read current value of the FTM_SYNC_REINIT field. */
#define BR_FTM_SYNC_REINIT(x) (HW_FTM_SYNC(x).B.REINIT)

/*! @brief Format value for bitfield FTM_SYNC_REINIT. */
#define BF_FTM_SYNC_REINIT(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNC_REINIT) & BM_FTM_SYNC_REINIT)

/*! @brief Set the REINIT field to a new value. */
#define BW_FTM_SYNC_REINIT(x, v) (HW_FTM_SYNC_WR(x, (HW_FTM_SYNC_RD(x) & ~BM_FTM_SYNC_REINIT) | BF_FTM_SYNC_REINIT(v)))
/*@}*/

/*!
 * @name Register FTM_SYNC, field SYNCHOM[3] (RW)
 *
 * Selects when the OUTMASK register is updated with the value of its buffer.
 *
 * Values:
 * - 0 - OUTMASK register is updated with the value of its buffer in all rising
 *     edges of the system clock.
 * - 1 - OUTMASK register is updated with the value of its buffer only by the
 *     PWM synchronization.
 */
/*@{*/
#define BP_FTM_SYNC_SYNCHOM  (3U)          /*!< Bit position for FTM_SYNC_SYNCHOM. */
#define BM_FTM_SYNC_SYNCHOM  (0x00000008U) /*!< Bit mask for FTM_SYNC_SYNCHOM. */
#define BS_FTM_SYNC_SYNCHOM  (1U)          /*!< Bit field size in bits for FTM_SYNC_SYNCHOM. */

/*! @brief Read current value of the FTM_SYNC_SYNCHOM field. */
#define BR_FTM_SYNC_SYNCHOM(x) (HW_FTM_SYNC(x).B.SYNCHOM)

/*! @brief Format value for bitfield FTM_SYNC_SYNCHOM. */
#define BF_FTM_SYNC_SYNCHOM(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNC_SYNCHOM) & BM_FTM_SYNC_SYNCHOM)

/*! @brief Set the SYNCHOM field to a new value. */
#define BW_FTM_SYNC_SYNCHOM(x, v) (HW_FTM_SYNC_WR(x, (HW_FTM_SYNC_RD(x) & ~BM_FTM_SYNC_SYNCHOM) | BF_FTM_SYNC_SYNCHOM(v)))
/*@}*/

/*!
 * @name Register FTM_SYNC, field TRIG0[4] (RW)
 *
 * Enables hardware trigger 0 to the PWM synchronization. Hardware trigger 0
 * occurs when a rising edge is detected at the trigger 0 input signal.
 *
 * Values:
 * - 0 - Trigger is disabled.
 * - 1 - Trigger is enabled.
 */
/*@{*/
#define BP_FTM_SYNC_TRIG0    (4U)          /*!< Bit position for FTM_SYNC_TRIG0. */
#define BM_FTM_SYNC_TRIG0    (0x00000010U) /*!< Bit mask for FTM_SYNC_TRIG0. */
#define BS_FTM_SYNC_TRIG0    (1U)          /*!< Bit field size in bits for FTM_SYNC_TRIG0. */

/*! @brief Read current value of the FTM_SYNC_TRIG0 field. */
#define BR_FTM_SYNC_TRIG0(x) (HW_FTM_SYNC(x).B.TRIG0)

/*! @brief Format value for bitfield FTM_SYNC_TRIG0. */
#define BF_FTM_SYNC_TRIG0(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNC_TRIG0) & BM_FTM_SYNC_TRIG0)

/*! @brief Set the TRIG0 field to a new value. */
#define BW_FTM_SYNC_TRIG0(x, v) (HW_FTM_SYNC_WR(x, (HW_FTM_SYNC_RD(x) & ~BM_FTM_SYNC_TRIG0) | BF_FTM_SYNC_TRIG0(v)))
/*@}*/

/*!
 * @name Register FTM_SYNC, field TRIG1[5] (RW)
 *
 * Enables hardware trigger 1 to the PWM synchronization. Hardware trigger 1
 * happens when a rising edge is detected at the trigger 1 input signal.
 *
 * Values:
 * - 0 - Trigger is disabled.
 * - 1 - Trigger is enabled.
 */
/*@{*/
#define BP_FTM_SYNC_TRIG1    (5U)          /*!< Bit position for FTM_SYNC_TRIG1. */
#define BM_FTM_SYNC_TRIG1    (0x00000020U) /*!< Bit mask for FTM_SYNC_TRIG1. */
#define BS_FTM_SYNC_TRIG1    (1U)          /*!< Bit field size in bits for FTM_SYNC_TRIG1. */

/*! @brief Read current value of the FTM_SYNC_TRIG1 field. */
#define BR_FTM_SYNC_TRIG1(x) (HW_FTM_SYNC(x).B.TRIG1)

/*! @brief Format value for bitfield FTM_SYNC_TRIG1. */
#define BF_FTM_SYNC_TRIG1(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNC_TRIG1) & BM_FTM_SYNC_TRIG1)

/*! @brief Set the TRIG1 field to a new value. */
#define BW_FTM_SYNC_TRIG1(x, v) (HW_FTM_SYNC_WR(x, (HW_FTM_SYNC_RD(x) & ~BM_FTM_SYNC_TRIG1) | BF_FTM_SYNC_TRIG1(v)))
/*@}*/

/*!
 * @name Register FTM_SYNC, field TRIG2[6] (RW)
 *
 * Enables hardware trigger 2 to the PWM synchronization. Hardware trigger 2
 * happens when a rising edge is detected at the trigger 2 input signal.
 *
 * Values:
 * - 0 - Trigger is disabled.
 * - 1 - Trigger is enabled.
 */
/*@{*/
#define BP_FTM_SYNC_TRIG2    (6U)          /*!< Bit position for FTM_SYNC_TRIG2. */
#define BM_FTM_SYNC_TRIG2    (0x00000040U) /*!< Bit mask for FTM_SYNC_TRIG2. */
#define BS_FTM_SYNC_TRIG2    (1U)          /*!< Bit field size in bits for FTM_SYNC_TRIG2. */

/*! @brief Read current value of the FTM_SYNC_TRIG2 field. */
#define BR_FTM_SYNC_TRIG2(x) (HW_FTM_SYNC(x).B.TRIG2)

/*! @brief Format value for bitfield FTM_SYNC_TRIG2. */
#define BF_FTM_SYNC_TRIG2(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNC_TRIG2) & BM_FTM_SYNC_TRIG2)

/*! @brief Set the TRIG2 field to a new value. */
#define BW_FTM_SYNC_TRIG2(x, v) (HW_FTM_SYNC_WR(x, (HW_FTM_SYNC_RD(x) & ~BM_FTM_SYNC_TRIG2) | BF_FTM_SYNC_TRIG2(v)))
/*@}*/

/*!
 * @name Register FTM_SYNC, field SWSYNC[7] (RW)
 *
 * Selects the software trigger as the PWM synchronization trigger. The software
 * trigger happens when a 1 is written to SWSYNC bit.
 *
 * Values:
 * - 0 - Software trigger is not selected.
 * - 1 - Software trigger is selected.
 */
/*@{*/
#define BP_FTM_SYNC_SWSYNC   (7U)          /*!< Bit position for FTM_SYNC_SWSYNC. */
#define BM_FTM_SYNC_SWSYNC   (0x00000080U) /*!< Bit mask for FTM_SYNC_SWSYNC. */
#define BS_FTM_SYNC_SWSYNC   (1U)          /*!< Bit field size in bits for FTM_SYNC_SWSYNC. */

/*! @brief Read current value of the FTM_SYNC_SWSYNC field. */
#define BR_FTM_SYNC_SWSYNC(x) (HW_FTM_SYNC(x).B.SWSYNC)

/*! @brief Format value for bitfield FTM_SYNC_SWSYNC. */
#define BF_FTM_SYNC_SWSYNC(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNC_SWSYNC) & BM_FTM_SYNC_SWSYNC)

/*! @brief Set the SWSYNC field to a new value. */
#define BW_FTM_SYNC_SWSYNC(x, v) (HW_FTM_SYNC_WR(x, (HW_FTM_SYNC_RD(x) & ~BM_FTM_SYNC_SWSYNC) | BF_FTM_SYNC_SWSYNC(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_OUTINIT - Initial State For Channels Output
 ******************************************************************************/

/*!
 * @brief HW_FTM_OUTINIT - Initial State For Channels Output (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_ftm_outinit
{
    uint32_t U;
    struct _hw_ftm_outinit_bitfields
    {
        uint32_t CH0OI : 1;            /*!< [0] Channel 0 Output Initialization Value */
        uint32_t CH1OI : 1;            /*!< [1] Channel 1 Output Initialization Value */
        uint32_t CH2OI : 1;            /*!< [2] Channel 2 Output Initialization Value */
        uint32_t CH3OI : 1;            /*!< [3] Channel 3 Output Initialization Value */
        uint32_t CH4OI : 1;            /*!< [4] Channel 4 Output Initialization Value */
        uint32_t CH5OI : 1;            /*!< [5] Channel 5 Output Initialization Value */
        uint32_t CH6OI : 1;            /*!< [6] Channel 6 Output Initialization Value */
        uint32_t CH7OI : 1;            /*!< [7] Channel 7 Output Initialization Value */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_ftm_outinit_t;

/*!
 * @name Constants and macros for entire FTM_OUTINIT register
 */
/*@{*/
#define HW_FTM_OUTINIT_ADDR(x)   ((uintptr_t)(x) + 0x5CU)

#define HW_FTM_OUTINIT(x)        (*(__IO hw_ftm_outinit_t *) HW_FTM_OUTINIT_ADDR(x))
#define HW_FTM_OUTINIT_RD(x)     (HW_FTM_OUTINIT(x).U)
#define HW_FTM_OUTINIT_WR(x, v)  (HW_FTM_OUTINIT(x).U = (v))
#define HW_FTM_OUTINIT_SET(x, v) (HW_FTM_OUTINIT_WR(x, HW_FTM_OUTINIT_RD(x) |  (v)))
#define HW_FTM_OUTINIT_CLR(x, v) (HW_FTM_OUTINIT_WR(x, HW_FTM_OUTINIT_RD(x) & ~(v)))
#define HW_FTM_OUTINIT_TOG(x, v) (HW_FTM_OUTINIT_WR(x, HW_FTM_OUTINIT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_OUTINIT bitfields
 */

/*!
 * @name Register FTM_OUTINIT, field CH0OI[0] (RW)
 *
 * Selects the value that is forced into the channel output when the
 * initialization occurs.
 *
 * Values:
 * - 0 - The initialization value is 0.
 * - 1 - The initialization value is 1.
 */
/*@{*/
#define BP_FTM_OUTINIT_CH0OI (0U)          /*!< Bit position for FTM_OUTINIT_CH0OI. */
#define BM_FTM_OUTINIT_CH0OI (0x00000001U) /*!< Bit mask for FTM_OUTINIT_CH0OI. */
#define BS_FTM_OUTINIT_CH0OI (1U)          /*!< Bit field size in bits for FTM_OUTINIT_CH0OI. */

/*! @brief Read current value of the FTM_OUTINIT_CH0OI field. */
#define BR_FTM_OUTINIT_CH0OI(x) (HW_FTM_OUTINIT(x).B.CH0OI)

/*! @brief Format value for bitfield FTM_OUTINIT_CH0OI. */
#define BF_FTM_OUTINIT_CH0OI(v) ((uint32_t)((uint32_t)(v) << BP_FTM_OUTINIT_CH0OI) & BM_FTM_OUTINIT_CH0OI)

/*! @brief Set the CH0OI field to a new value. */
#define BW_FTM_OUTINIT_CH0OI(x, v) (HW_FTM_OUTINIT_WR(x, (HW_FTM_OUTINIT_RD(x) & ~BM_FTM_OUTINIT_CH0OI) | BF_FTM_OUTINIT_CH0OI(v)))
/*@}*/

/*!
 * @name Register FTM_OUTINIT, field CH1OI[1] (RW)
 *
 * Selects the value that is forced into the channel output when the
 * initialization occurs.
 *
 * Values:
 * - 0 - The initialization value is 0.
 * - 1 - The initialization value is 1.
 */
/*@{*/
#define BP_FTM_OUTINIT_CH1OI (1U)          /*!< Bit position for FTM_OUTINIT_CH1OI. */
#define BM_FTM_OUTINIT_CH1OI (0x00000002U) /*!< Bit mask for FTM_OUTINIT_CH1OI. */
#define BS_FTM_OUTINIT_CH1OI (1U)          /*!< Bit field size in bits for FTM_OUTINIT_CH1OI. */

/*! @brief Read current value of the FTM_OUTINIT_CH1OI field. */
#define BR_FTM_OUTINIT_CH1OI(x) (HW_FTM_OUTINIT(x).B.CH1OI)

/*! @brief Format value for bitfield FTM_OUTINIT_CH1OI. */
#define BF_FTM_OUTINIT_CH1OI(v) ((uint32_t)((uint32_t)(v) << BP_FTM_OUTINIT_CH1OI) & BM_FTM_OUTINIT_CH1OI)

/*! @brief Set the CH1OI field to a new value. */
#define BW_FTM_OUTINIT_CH1OI(x, v) (HW_FTM_OUTINIT_WR(x, (HW_FTM_OUTINIT_RD(x) & ~BM_FTM_OUTINIT_CH1OI) | BF_FTM_OUTINIT_CH1OI(v)))
/*@}*/

/*!
 * @name Register FTM_OUTINIT, field CH2OI[2] (RW)
 *
 * Selects the value that is forced into the channel output when the
 * initialization occurs.
 *
 * Values:
 * - 0 - The initialization value is 0.
 * - 1 - The initialization value is 1.
 */
/*@{*/
#define BP_FTM_OUTINIT_CH2OI (2U)          /*!< Bit position for FTM_OUTINIT_CH2OI. */
#define BM_FTM_OUTINIT_CH2OI (0x00000004U) /*!< Bit mask for FTM_OUTINIT_CH2OI. */
#define BS_FTM_OUTINIT_CH2OI (1U)          /*!< Bit field size in bits for FTM_OUTINIT_CH2OI. */

/*! @brief Read current value of the FTM_OUTINIT_CH2OI field. */
#define BR_FTM_OUTINIT_CH2OI(x) (HW_FTM_OUTINIT(x).B.CH2OI)

/*! @brief Format value for bitfield FTM_OUTINIT_CH2OI. */
#define BF_FTM_OUTINIT_CH2OI(v) ((uint32_t)((uint32_t)(v) << BP_FTM_OUTINIT_CH2OI) & BM_FTM_OUTINIT_CH2OI)

/*! @brief Set the CH2OI field to a new value. */
#define BW_FTM_OUTINIT_CH2OI(x, v) (HW_FTM_OUTINIT_WR(x, (HW_FTM_OUTINIT_RD(x) & ~BM_FTM_OUTINIT_CH2OI) | BF_FTM_OUTINIT_CH2OI(v)))
/*@}*/

/*!
 * @name Register FTM_OUTINIT, field CH3OI[3] (RW)
 *
 * Selects the value that is forced into the channel output when the
 * initialization occurs.
 *
 * Values:
 * - 0 - The initialization value is 0.
 * - 1 - The initialization value is 1.
 */
/*@{*/
#define BP_FTM_OUTINIT_CH3OI (3U)          /*!< Bit position for FTM_OUTINIT_CH3OI. */
#define BM_FTM_OUTINIT_CH3OI (0x00000008U) /*!< Bit mask for FTM_OUTINIT_CH3OI. */
#define BS_FTM_OUTINIT_CH3OI (1U)          /*!< Bit field size in bits for FTM_OUTINIT_CH3OI. */

/*! @brief Read current value of the FTM_OUTINIT_CH3OI field. */
#define BR_FTM_OUTINIT_CH3OI(x) (HW_FTM_OUTINIT(x).B.CH3OI)

/*! @brief Format value for bitfield FTM_OUTINIT_CH3OI. */
#define BF_FTM_OUTINIT_CH3OI(v) ((uint32_t)((uint32_t)(v) << BP_FTM_OUTINIT_CH3OI) & BM_FTM_OUTINIT_CH3OI)

/*! @brief Set the CH3OI field to a new value. */
#define BW_FTM_OUTINIT_CH3OI(x, v) (HW_FTM_OUTINIT_WR(x, (HW_FTM_OUTINIT_RD(x) & ~BM_FTM_OUTINIT_CH3OI) | BF_FTM_OUTINIT_CH3OI(v)))
/*@}*/

/*!
 * @name Register FTM_OUTINIT, field CH4OI[4] (RW)
 *
 * Selects the value that is forced into the channel output when the
 * initialization occurs.
 *
 * Values:
 * - 0 - The initialization value is 0.
 * - 1 - The initialization value is 1.
 */
/*@{*/
#define BP_FTM_OUTINIT_CH4OI (4U)          /*!< Bit position for FTM_OUTINIT_CH4OI. */
#define BM_FTM_OUTINIT_CH4OI (0x00000010U) /*!< Bit mask for FTM_OUTINIT_CH4OI. */
#define BS_FTM_OUTINIT_CH4OI (1U)          /*!< Bit field size in bits for FTM_OUTINIT_CH4OI. */

/*! @brief Read current value of the FTM_OUTINIT_CH4OI field. */
#define BR_FTM_OUTINIT_CH4OI(x) (HW_FTM_OUTINIT(x).B.CH4OI)

/*! @brief Format value for bitfield FTM_OUTINIT_CH4OI. */
#define BF_FTM_OUTINIT_CH4OI(v) ((uint32_t)((uint32_t)(v) << BP_FTM_OUTINIT_CH4OI) & BM_FTM_OUTINIT_CH4OI)

/*! @brief Set the CH4OI field to a new value. */
#define BW_FTM_OUTINIT_CH4OI(x, v) (HW_FTM_OUTINIT_WR(x, (HW_FTM_OUTINIT_RD(x) & ~BM_FTM_OUTINIT_CH4OI) | BF_FTM_OUTINIT_CH4OI(v)))
/*@}*/

/*!
 * @name Register FTM_OUTINIT, field CH5OI[5] (RW)
 *
 * Selects the value that is forced into the channel output when the
 * initialization occurs.
 *
 * Values:
 * - 0 - The initialization value is 0.
 * - 1 - The initialization value is 1.
 */
/*@{*/
#define BP_FTM_OUTINIT_CH5OI (5U)          /*!< Bit position for FTM_OUTINIT_CH5OI. */
#define BM_FTM_OUTINIT_CH5OI (0x00000020U) /*!< Bit mask for FTM_OUTINIT_CH5OI. */
#define BS_FTM_OUTINIT_CH5OI (1U)          /*!< Bit field size in bits for FTM_OUTINIT_CH5OI. */

/*! @brief Read current value of the FTM_OUTINIT_CH5OI field. */
#define BR_FTM_OUTINIT_CH5OI(x) (HW_FTM_OUTINIT(x).B.CH5OI)

/*! @brief Format value for bitfield FTM_OUTINIT_CH5OI. */
#define BF_FTM_OUTINIT_CH5OI(v) ((uint32_t)((uint32_t)(v) << BP_FTM_OUTINIT_CH5OI) & BM_FTM_OUTINIT_CH5OI)

/*! @brief Set the CH5OI field to a new value. */
#define BW_FTM_OUTINIT_CH5OI(x, v) (HW_FTM_OUTINIT_WR(x, (HW_FTM_OUTINIT_RD(x) & ~BM_FTM_OUTINIT_CH5OI) | BF_FTM_OUTINIT_CH5OI(v)))
/*@}*/

/*!
 * @name Register FTM_OUTINIT, field CH6OI[6] (RW)
 *
 * Selects the value that is forced into the channel output when the
 * initialization occurs.
 *
 * Values:
 * - 0 - The initialization value is 0.
 * - 1 - The initialization value is 1.
 */
/*@{*/
#define BP_FTM_OUTINIT_CH6OI (6U)          /*!< Bit position for FTM_OUTINIT_CH6OI. */
#define BM_FTM_OUTINIT_CH6OI (0x00000040U) /*!< Bit mask for FTM_OUTINIT_CH6OI. */
#define BS_FTM_OUTINIT_CH6OI (1U)          /*!< Bit field size in bits for FTM_OUTINIT_CH6OI. */

/*! @brief Read current value of the FTM_OUTINIT_CH6OI field. */
#define BR_FTM_OUTINIT_CH6OI(x) (HW_FTM_OUTINIT(x).B.CH6OI)

/*! @brief Format value for bitfield FTM_OUTINIT_CH6OI. */
#define BF_FTM_OUTINIT_CH6OI(v) ((uint32_t)((uint32_t)(v) << BP_FTM_OUTINIT_CH6OI) & BM_FTM_OUTINIT_CH6OI)

/*! @brief Set the CH6OI field to a new value. */
#define BW_FTM_OUTINIT_CH6OI(x, v) (HW_FTM_OUTINIT_WR(x, (HW_FTM_OUTINIT_RD(x) & ~BM_FTM_OUTINIT_CH6OI) | BF_FTM_OUTINIT_CH6OI(v)))
/*@}*/

/*!
 * @name Register FTM_OUTINIT, field CH7OI[7] (RW)
 *
 * Selects the value that is forced into the channel output when the
 * initialization occurs.
 *
 * Values:
 * - 0 - The initialization value is 0.
 * - 1 - The initialization value is 1.
 */
/*@{*/
#define BP_FTM_OUTINIT_CH7OI (7U)          /*!< Bit position for FTM_OUTINIT_CH7OI. */
#define BM_FTM_OUTINIT_CH7OI (0x00000080U) /*!< Bit mask for FTM_OUTINIT_CH7OI. */
#define BS_FTM_OUTINIT_CH7OI (1U)          /*!< Bit field size in bits for FTM_OUTINIT_CH7OI. */

/*! @brief Read current value of the FTM_OUTINIT_CH7OI field. */
#define BR_FTM_OUTINIT_CH7OI(x) (HW_FTM_OUTINIT(x).B.CH7OI)

/*! @brief Format value for bitfield FTM_OUTINIT_CH7OI. */
#define BF_FTM_OUTINIT_CH7OI(v) ((uint32_t)((uint32_t)(v) << BP_FTM_OUTINIT_CH7OI) & BM_FTM_OUTINIT_CH7OI)

/*! @brief Set the CH7OI field to a new value. */
#define BW_FTM_OUTINIT_CH7OI(x, v) (HW_FTM_OUTINIT_WR(x, (HW_FTM_OUTINIT_RD(x) & ~BM_FTM_OUTINIT_CH7OI) | BF_FTM_OUTINIT_CH7OI(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_OUTMASK - Output Mask
 ******************************************************************************/

/*!
 * @brief HW_FTM_OUTMASK - Output Mask (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides a mask for each FTM channel. The mask of a channel
 * determines if its output responds, that is, it is masked or not, when a match
 * occurs. This feature is used for BLDC control where the PWM signal is presented
 * to an electric motor at specific times to provide electronic commutation. Any
 * write to the OUTMASK register, stores the value in its write buffer. The
 * register is updated with the value of its write buffer according to PWM
 * synchronization.
 */
typedef union _hw_ftm_outmask
{
    uint32_t U;
    struct _hw_ftm_outmask_bitfields
    {
        uint32_t CH0OM : 1;            /*!< [0] Channel 0 Output Mask */
        uint32_t CH1OM : 1;            /*!< [1] Channel 1 Output Mask */
        uint32_t CH2OM : 1;            /*!< [2] Channel 2 Output Mask */
        uint32_t CH3OM : 1;            /*!< [3] Channel 3 Output Mask */
        uint32_t CH4OM : 1;            /*!< [4] Channel 4 Output Mask */
        uint32_t CH5OM : 1;            /*!< [5] Channel 5 Output Mask */
        uint32_t CH6OM : 1;            /*!< [6] Channel 6 Output Mask */
        uint32_t CH7OM : 1;            /*!< [7] Channel 7 Output Mask */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_ftm_outmask_t;

/*!
 * @name Constants and macros for entire FTM_OUTMASK register
 */
/*@{*/
#define HW_FTM_OUTMASK_ADDR(x)   ((uintptr_t)(x) + 0x60U)

#define HW_FTM_OUTMASK(x)        (*(__IO hw_ftm_outmask_t *) HW_FTM_OUTMASK_ADDR(x))
#define HW_FTM_OUTMASK_RD(x)     (HW_FTM_OUTMASK(x).U)
#define HW_FTM_OUTMASK_WR(x, v)  (HW_FTM_OUTMASK(x).U = (v))
#define HW_FTM_OUTMASK_SET(x, v) (HW_FTM_OUTMASK_WR(x, HW_FTM_OUTMASK_RD(x) |  (v)))
#define HW_FTM_OUTMASK_CLR(x, v) (HW_FTM_OUTMASK_WR(x, HW_FTM_OUTMASK_RD(x) & ~(v)))
#define HW_FTM_OUTMASK_TOG(x, v) (HW_FTM_OUTMASK_WR(x, HW_FTM_OUTMASK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_OUTMASK bitfields
 */

/*!
 * @name Register FTM_OUTMASK, field CH0OM[0] (RW)
 *
 * Defines if the channel output is masked or unmasked.
 *
 * Values:
 * - 0 - Channel output is not masked. It continues to operate normally.
 * - 1 - Channel output is masked. It is forced to its inactive state.
 */
/*@{*/
#define BP_FTM_OUTMASK_CH0OM (0U)          /*!< Bit position for FTM_OUTMASK_CH0OM. */
#define BM_FTM_OUTMASK_CH0OM (0x00000001U) /*!< Bit mask for FTM_OUTMASK_CH0OM. */
#define BS_FTM_OUTMASK_CH0OM (1U)          /*!< Bit field size in bits for FTM_OUTMASK_CH0OM. */

/*! @brief Read current value of the FTM_OUTMASK_CH0OM field. */
#define BR_FTM_OUTMASK_CH0OM(x) (HW_FTM_OUTMASK(x).B.CH0OM)

/*! @brief Format value for bitfield FTM_OUTMASK_CH0OM. */
#define BF_FTM_OUTMASK_CH0OM(v) ((uint32_t)((uint32_t)(v) << BP_FTM_OUTMASK_CH0OM) & BM_FTM_OUTMASK_CH0OM)

/*! @brief Set the CH0OM field to a new value. */
#define BW_FTM_OUTMASK_CH0OM(x, v) (HW_FTM_OUTMASK_WR(x, (HW_FTM_OUTMASK_RD(x) & ~BM_FTM_OUTMASK_CH0OM) | BF_FTM_OUTMASK_CH0OM(v)))
/*@}*/

/*!
 * @name Register FTM_OUTMASK, field CH1OM[1] (RW)
 *
 * Defines if the channel output is masked or unmasked.
 *
 * Values:
 * - 0 - Channel output is not masked. It continues to operate normally.
 * - 1 - Channel output is masked. It is forced to its inactive state.
 */
/*@{*/
#define BP_FTM_OUTMASK_CH1OM (1U)          /*!< Bit position for FTM_OUTMASK_CH1OM. */
#define BM_FTM_OUTMASK_CH1OM (0x00000002U) /*!< Bit mask for FTM_OUTMASK_CH1OM. */
#define BS_FTM_OUTMASK_CH1OM (1U)          /*!< Bit field size in bits for FTM_OUTMASK_CH1OM. */

/*! @brief Read current value of the FTM_OUTMASK_CH1OM field. */
#define BR_FTM_OUTMASK_CH1OM(x) (HW_FTM_OUTMASK(x).B.CH1OM)

/*! @brief Format value for bitfield FTM_OUTMASK_CH1OM. */
#define BF_FTM_OUTMASK_CH1OM(v) ((uint32_t)((uint32_t)(v) << BP_FTM_OUTMASK_CH1OM) & BM_FTM_OUTMASK_CH1OM)

/*! @brief Set the CH1OM field to a new value. */
#define BW_FTM_OUTMASK_CH1OM(x, v) (HW_FTM_OUTMASK_WR(x, (HW_FTM_OUTMASK_RD(x) & ~BM_FTM_OUTMASK_CH1OM) | BF_FTM_OUTMASK_CH1OM(v)))
/*@}*/

/*!
 * @name Register FTM_OUTMASK, field CH2OM[2] (RW)
 *
 * Defines if the channel output is masked or unmasked.
 *
 * Values:
 * - 0 - Channel output is not masked. It continues to operate normally.
 * - 1 - Channel output is masked. It is forced to its inactive state.
 */
/*@{*/
#define BP_FTM_OUTMASK_CH2OM (2U)          /*!< Bit position for FTM_OUTMASK_CH2OM. */
#define BM_FTM_OUTMASK_CH2OM (0x00000004U) /*!< Bit mask for FTM_OUTMASK_CH2OM. */
#define BS_FTM_OUTMASK_CH2OM (1U)          /*!< Bit field size in bits for FTM_OUTMASK_CH2OM. */

/*! @brief Read current value of the FTM_OUTMASK_CH2OM field. */
#define BR_FTM_OUTMASK_CH2OM(x) (HW_FTM_OUTMASK(x).B.CH2OM)

/*! @brief Format value for bitfield FTM_OUTMASK_CH2OM. */
#define BF_FTM_OUTMASK_CH2OM(v) ((uint32_t)((uint32_t)(v) << BP_FTM_OUTMASK_CH2OM) & BM_FTM_OUTMASK_CH2OM)

/*! @brief Set the CH2OM field to a new value. */
#define BW_FTM_OUTMASK_CH2OM(x, v) (HW_FTM_OUTMASK_WR(x, (HW_FTM_OUTMASK_RD(x) & ~BM_FTM_OUTMASK_CH2OM) | BF_FTM_OUTMASK_CH2OM(v)))
/*@}*/

/*!
 * @name Register FTM_OUTMASK, field CH3OM[3] (RW)
 *
 * Defines if the channel output is masked or unmasked.
 *
 * Values:
 * - 0 - Channel output is not masked. It continues to operate normally.
 * - 1 - Channel output is masked. It is forced to its inactive state.
 */
/*@{*/
#define BP_FTM_OUTMASK_CH3OM (3U)          /*!< Bit position for FTM_OUTMASK_CH3OM. */
#define BM_FTM_OUTMASK_CH3OM (0x00000008U) /*!< Bit mask for FTM_OUTMASK_CH3OM. */
#define BS_FTM_OUTMASK_CH3OM (1U)          /*!< Bit field size in bits for FTM_OUTMASK_CH3OM. */

/*! @brief Read current value of the FTM_OUTMASK_CH3OM field. */
#define BR_FTM_OUTMASK_CH3OM(x) (HW_FTM_OUTMASK(x).B.CH3OM)

/*! @brief Format value for bitfield FTM_OUTMASK_CH3OM. */
#define BF_FTM_OUTMASK_CH3OM(v) ((uint32_t)((uint32_t)(v) << BP_FTM_OUTMASK_CH3OM) & BM_FTM_OUTMASK_CH3OM)

/*! @brief Set the CH3OM field to a new value. */
#define BW_FTM_OUTMASK_CH3OM(x, v) (HW_FTM_OUTMASK_WR(x, (HW_FTM_OUTMASK_RD(x) & ~BM_FTM_OUTMASK_CH3OM) | BF_FTM_OUTMASK_CH3OM(v)))
/*@}*/

/*!
 * @name Register FTM_OUTMASK, field CH4OM[4] (RW)
 *
 * Defines if the channel output is masked or unmasked.
 *
 * Values:
 * - 0 - Channel output is not masked. It continues to operate normally.
 * - 1 - Channel output is masked. It is forced to its inactive state.
 */
/*@{*/
#define BP_FTM_OUTMASK_CH4OM (4U)          /*!< Bit position for FTM_OUTMASK_CH4OM. */
#define BM_FTM_OUTMASK_CH4OM (0x00000010U) /*!< Bit mask for FTM_OUTMASK_CH4OM. */
#define BS_FTM_OUTMASK_CH4OM (1U)          /*!< Bit field size in bits for FTM_OUTMASK_CH4OM. */

/*! @brief Read current value of the FTM_OUTMASK_CH4OM field. */
#define BR_FTM_OUTMASK_CH4OM(x) (HW_FTM_OUTMASK(x).B.CH4OM)

/*! @brief Format value for bitfield FTM_OUTMASK_CH4OM. */
#define BF_FTM_OUTMASK_CH4OM(v) ((uint32_t)((uint32_t)(v) << BP_FTM_OUTMASK_CH4OM) & BM_FTM_OUTMASK_CH4OM)

/*! @brief Set the CH4OM field to a new value. */
#define BW_FTM_OUTMASK_CH4OM(x, v) (HW_FTM_OUTMASK_WR(x, (HW_FTM_OUTMASK_RD(x) & ~BM_FTM_OUTMASK_CH4OM) | BF_FTM_OUTMASK_CH4OM(v)))
/*@}*/

/*!
 * @name Register FTM_OUTMASK, field CH5OM[5] (RW)
 *
 * Defines if the channel output is masked or unmasked.
 *
 * Values:
 * - 0 - Channel output is not masked. It continues to operate normally.
 * - 1 - Channel output is masked. It is forced to its inactive state.
 */
/*@{*/
#define BP_FTM_OUTMASK_CH5OM (5U)          /*!< Bit position for FTM_OUTMASK_CH5OM. */
#define BM_FTM_OUTMASK_CH5OM (0x00000020U) /*!< Bit mask for FTM_OUTMASK_CH5OM. */
#define BS_FTM_OUTMASK_CH5OM (1U)          /*!< Bit field size in bits for FTM_OUTMASK_CH5OM. */

/*! @brief Read current value of the FTM_OUTMASK_CH5OM field. */
#define BR_FTM_OUTMASK_CH5OM(x) (HW_FTM_OUTMASK(x).B.CH5OM)

/*! @brief Format value for bitfield FTM_OUTMASK_CH5OM. */
#define BF_FTM_OUTMASK_CH5OM(v) ((uint32_t)((uint32_t)(v) << BP_FTM_OUTMASK_CH5OM) & BM_FTM_OUTMASK_CH5OM)

/*! @brief Set the CH5OM field to a new value. */
#define BW_FTM_OUTMASK_CH5OM(x, v) (HW_FTM_OUTMASK_WR(x, (HW_FTM_OUTMASK_RD(x) & ~BM_FTM_OUTMASK_CH5OM) | BF_FTM_OUTMASK_CH5OM(v)))
/*@}*/

/*!
 * @name Register FTM_OUTMASK, field CH6OM[6] (RW)
 *
 * Defines if the channel output is masked or unmasked.
 *
 * Values:
 * - 0 - Channel output is not masked. It continues to operate normally.
 * - 1 - Channel output is masked. It is forced to its inactive state.
 */
/*@{*/
#define BP_FTM_OUTMASK_CH6OM (6U)          /*!< Bit position for FTM_OUTMASK_CH6OM. */
#define BM_FTM_OUTMASK_CH6OM (0x00000040U) /*!< Bit mask for FTM_OUTMASK_CH6OM. */
#define BS_FTM_OUTMASK_CH6OM (1U)          /*!< Bit field size in bits for FTM_OUTMASK_CH6OM. */

/*! @brief Read current value of the FTM_OUTMASK_CH6OM field. */
#define BR_FTM_OUTMASK_CH6OM(x) (HW_FTM_OUTMASK(x).B.CH6OM)

/*! @brief Format value for bitfield FTM_OUTMASK_CH6OM. */
#define BF_FTM_OUTMASK_CH6OM(v) ((uint32_t)((uint32_t)(v) << BP_FTM_OUTMASK_CH6OM) & BM_FTM_OUTMASK_CH6OM)

/*! @brief Set the CH6OM field to a new value. */
#define BW_FTM_OUTMASK_CH6OM(x, v) (HW_FTM_OUTMASK_WR(x, (HW_FTM_OUTMASK_RD(x) & ~BM_FTM_OUTMASK_CH6OM) | BF_FTM_OUTMASK_CH6OM(v)))
/*@}*/

/*!
 * @name Register FTM_OUTMASK, field CH7OM[7] (RW)
 *
 * Defines if the channel output is masked or unmasked.
 *
 * Values:
 * - 0 - Channel output is not masked. It continues to operate normally.
 * - 1 - Channel output is masked. It is forced to its inactive state.
 */
/*@{*/
#define BP_FTM_OUTMASK_CH7OM (7U)          /*!< Bit position for FTM_OUTMASK_CH7OM. */
#define BM_FTM_OUTMASK_CH7OM (0x00000080U) /*!< Bit mask for FTM_OUTMASK_CH7OM. */
#define BS_FTM_OUTMASK_CH7OM (1U)          /*!< Bit field size in bits for FTM_OUTMASK_CH7OM. */

/*! @brief Read current value of the FTM_OUTMASK_CH7OM field. */
#define BR_FTM_OUTMASK_CH7OM(x) (HW_FTM_OUTMASK(x).B.CH7OM)

/*! @brief Format value for bitfield FTM_OUTMASK_CH7OM. */
#define BF_FTM_OUTMASK_CH7OM(v) ((uint32_t)((uint32_t)(v) << BP_FTM_OUTMASK_CH7OM) & BM_FTM_OUTMASK_CH7OM)

/*! @brief Set the CH7OM field to a new value. */
#define BW_FTM_OUTMASK_CH7OM(x, v) (HW_FTM_OUTMASK_WR(x, (HW_FTM_OUTMASK_RD(x) & ~BM_FTM_OUTMASK_CH7OM) | BF_FTM_OUTMASK_CH7OM(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_COMBINE - Function For Linked Channels
 ******************************************************************************/

/*!
 * @brief HW_FTM_COMBINE - Function For Linked Channels (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the control bits used to configure the
 * synchronization, deadtime insertion, Dual Edge Capture mode, Complementary, and Combine mode
 * for each pair of channels (n) and (n+1), where n equals 0, 2, 4, and 6.
 */
typedef union _hw_ftm_combine
{
    uint32_t U;
    struct _hw_ftm_combine_bitfields
    {
        uint32_t COMBINE0 : 1;         /*!< [0] Combine Channels For n = 0 */
        uint32_t COMP0 : 1;            /*!< [1] Complement Of Channel (n) For n = 0 */
        uint32_t DECAPEN0 : 1;         /*!< [2] Dual Edge Capture Mode Enable For n =
                                        * 0 */
        uint32_t DECAP0 : 1;           /*!< [3] Dual Edge Capture Mode Captures For n =
                                        * 0 */
        uint32_t DTEN0 : 1;            /*!< [4] Deadtime Enable For n = 0 */
        uint32_t SYNCEN0 : 1;          /*!< [5] Synchronization Enable For n = 0 */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t COMBINE1 : 1;         /*!< [8] Combine Channels For n = 2 */
        uint32_t COMP1 : 1;            /*!< [9] Complement Of Channel (n) For n = 2 */
        uint32_t DECAPEN1 : 1;         /*!< [10] Dual Edge Capture Mode Enable For n
                                        * = 2 */
        uint32_t DECAP1 : 1;           /*!< [11] Dual Edge Capture Mode Captures For n
                                        * = 2 */
        uint32_t DTEN1 : 1;            /*!< [12] Deadtime Enable For n = 2 */
        uint32_t SYNCEN1 : 1;          /*!< [13] Synchronization Enable For n = 2 */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t COMBINE2 : 1;         /*!< [16] Combine Channels For n = 4 */
        uint32_t COMP2 : 1;            /*!< [17] Complement Of Channel (n) For n = 4 */
        uint32_t DECAPEN2 : 1;         /*!< [18] Dual Edge Capture Mode Enable For n
                                        * = 4 */
        uint32_t DECAP2 : 1;           /*!< [19] Dual Edge Capture Mode Captures For n
                                        * = 4 */
        uint32_t DTEN2 : 1;            /*!< [20] Deadtime Enable For n = 4 */
        uint32_t SYNCEN2 : 1;          /*!< [21] Synchronization Enable For n = 4 */
        uint32_t RESERVED2 : 2;        /*!< [23:22]  */
        uint32_t COMBINE3 : 1;         /*!< [24] Combine Channels For n = 6 */
        uint32_t COMP3 : 1;            /*!< [25] Complement Of Channel (n) for n = 6 */
        uint32_t DECAPEN3 : 1;         /*!< [26] Dual Edge Capture Mode Enable For n
                                        * = 6 */
        uint32_t DECAP3 : 1;           /*!< [27] Dual Edge Capture Mode Captures For n
                                        * = 6 */
        uint32_t DTEN3 : 1;            /*!< [28] Deadtime Enable For n = 6 */
        uint32_t SYNCEN3 : 1;          /*!< [29] Synchronization Enable For n = 6 */
        uint32_t RESERVED3 : 2;        /*!< [31:30]  */
    } B;
} hw_ftm_combine_t;

/*!
 * @name Constants and macros for entire FTM_COMBINE register
 */
/*@{*/
#define HW_FTM_COMBINE_ADDR(x)   ((uintptr_t)(x) + 0x64U)

#define HW_FTM_COMBINE(x)        (*(__IO hw_ftm_combine_t *) HW_FTM_COMBINE_ADDR(x))
#define HW_FTM_COMBINE_RD(x)     (HW_FTM_COMBINE(x).U)
#define HW_FTM_COMBINE_WR(x, v)  (HW_FTM_COMBINE(x).U = (v))
#define HW_FTM_COMBINE_SET(x, v) (HW_FTM_COMBINE_WR(x, HW_FTM_COMBINE_RD(x) |  (v)))
#define HW_FTM_COMBINE_CLR(x, v) (HW_FTM_COMBINE_WR(x, HW_FTM_COMBINE_RD(x) & ~(v)))
#define HW_FTM_COMBINE_TOG(x, v) (HW_FTM_COMBINE_WR(x, HW_FTM_COMBINE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_COMBINE bitfields
 */

/*!
 * @name Register FTM_COMBINE, field COMBINE0[0] (RW)
 *
 * Enables the combine feature for channels (n) and (n+1). This field is write
 * protected. It can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - Channels (n) and (n+1) are independent.
 * - 1 - Channels (n) and (n+1) are combined.
 */
/*@{*/
#define BP_FTM_COMBINE_COMBINE0 (0U)       /*!< Bit position for FTM_COMBINE_COMBINE0. */
#define BM_FTM_COMBINE_COMBINE0 (0x00000001U) /*!< Bit mask for FTM_COMBINE_COMBINE0. */
#define BS_FTM_COMBINE_COMBINE0 (1U)       /*!< Bit field size in bits for FTM_COMBINE_COMBINE0. */

/*! @brief Read current value of the FTM_COMBINE_COMBINE0 field. */
#define BR_FTM_COMBINE_COMBINE0(x) (HW_FTM_COMBINE(x).B.COMBINE0)

/*! @brief Format value for bitfield FTM_COMBINE_COMBINE0. */
#define BF_FTM_COMBINE_COMBINE0(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_COMBINE0) & BM_FTM_COMBINE_COMBINE0)

/*! @brief Set the COMBINE0 field to a new value. */
#define BW_FTM_COMBINE_COMBINE0(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_COMBINE0) | BF_FTM_COMBINE_COMBINE0(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field COMP0[1] (RW)
 *
 * Enables Complementary mode for the combined channels. In Complementary mode
 * the channel (n+1) output is the inverse of the channel (n) output. This field
 * is write protected. It can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The channel (n+1) output is the same as the channel (n) output.
 * - 1 - The channel (n+1) output is the complement of the channel (n) output.
 */
/*@{*/
#define BP_FTM_COMBINE_COMP0 (1U)          /*!< Bit position for FTM_COMBINE_COMP0. */
#define BM_FTM_COMBINE_COMP0 (0x00000002U) /*!< Bit mask for FTM_COMBINE_COMP0. */
#define BS_FTM_COMBINE_COMP0 (1U)          /*!< Bit field size in bits for FTM_COMBINE_COMP0. */

/*! @brief Read current value of the FTM_COMBINE_COMP0 field. */
#define BR_FTM_COMBINE_COMP0(x) (HW_FTM_COMBINE(x).B.COMP0)

/*! @brief Format value for bitfield FTM_COMBINE_COMP0. */
#define BF_FTM_COMBINE_COMP0(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_COMP0) & BM_FTM_COMBINE_COMP0)

/*! @brief Set the COMP0 field to a new value. */
#define BW_FTM_COMBINE_COMP0(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_COMP0) | BF_FTM_COMBINE_COMP0(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field DECAPEN0[2] (RW)
 *
 * Enables the Dual Edge Capture mode in the channels (n) and (n+1). This bit
 * reconfigures the function of MSnA, ELSnB:ELSnA and ELS(n+1)B:ELS(n+1)A bits in
 * Dual Edge Capture mode according to . This field is write protected. It can be
 * written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The Dual Edge Capture mode in this pair of channels is disabled.
 * - 1 - The Dual Edge Capture mode in this pair of channels is enabled.
 */
/*@{*/
#define BP_FTM_COMBINE_DECAPEN0 (2U)       /*!< Bit position for FTM_COMBINE_DECAPEN0. */
#define BM_FTM_COMBINE_DECAPEN0 (0x00000004U) /*!< Bit mask for FTM_COMBINE_DECAPEN0. */
#define BS_FTM_COMBINE_DECAPEN0 (1U)       /*!< Bit field size in bits for FTM_COMBINE_DECAPEN0. */

/*! @brief Read current value of the FTM_COMBINE_DECAPEN0 field. */
#define BR_FTM_COMBINE_DECAPEN0(x) (HW_FTM_COMBINE(x).B.DECAPEN0)

/*! @brief Format value for bitfield FTM_COMBINE_DECAPEN0. */
#define BF_FTM_COMBINE_DECAPEN0(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_DECAPEN0) & BM_FTM_COMBINE_DECAPEN0)

/*! @brief Set the DECAPEN0 field to a new value. */
#define BW_FTM_COMBINE_DECAPEN0(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_DECAPEN0) | BF_FTM_COMBINE_DECAPEN0(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field DECAP0[3] (RW)
 *
 * Enables the capture of the FTM counter value according to the channel (n)
 * input event and the configuration of the dual edge capture bits. This field
 * applies only when DECAPEN = 1. DECAP bit is cleared automatically by hardware if
 * dual edge capture - one-shot mode is selected and when the capture of channel
 * (n+1) event is made.
 *
 * Values:
 * - 0 - The dual edge captures are inactive.
 * - 1 - The dual edge captures are active.
 */
/*@{*/
#define BP_FTM_COMBINE_DECAP0 (3U)         /*!< Bit position for FTM_COMBINE_DECAP0. */
#define BM_FTM_COMBINE_DECAP0 (0x00000008U) /*!< Bit mask for FTM_COMBINE_DECAP0. */
#define BS_FTM_COMBINE_DECAP0 (1U)         /*!< Bit field size in bits for FTM_COMBINE_DECAP0. */

/*! @brief Read current value of the FTM_COMBINE_DECAP0 field. */
#define BR_FTM_COMBINE_DECAP0(x) (HW_FTM_COMBINE(x).B.DECAP0)

/*! @brief Format value for bitfield FTM_COMBINE_DECAP0. */
#define BF_FTM_COMBINE_DECAP0(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_DECAP0) & BM_FTM_COMBINE_DECAP0)

/*! @brief Set the DECAP0 field to a new value. */
#define BW_FTM_COMBINE_DECAP0(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_DECAP0) | BF_FTM_COMBINE_DECAP0(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field DTEN0[4] (RW)
 *
 * Enables the deadtime insertion in the channels (n) and (n+1). This field is
 * write protected. It can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The deadtime insertion in this pair of channels is disabled.
 * - 1 - The deadtime insertion in this pair of channels is enabled.
 */
/*@{*/
#define BP_FTM_COMBINE_DTEN0 (4U)          /*!< Bit position for FTM_COMBINE_DTEN0. */
#define BM_FTM_COMBINE_DTEN0 (0x00000010U) /*!< Bit mask for FTM_COMBINE_DTEN0. */
#define BS_FTM_COMBINE_DTEN0 (1U)          /*!< Bit field size in bits for FTM_COMBINE_DTEN0. */

/*! @brief Read current value of the FTM_COMBINE_DTEN0 field. */
#define BR_FTM_COMBINE_DTEN0(x) (HW_FTM_COMBINE(x).B.DTEN0)

/*! @brief Format value for bitfield FTM_COMBINE_DTEN0. */
#define BF_FTM_COMBINE_DTEN0(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_DTEN0) & BM_FTM_COMBINE_DTEN0)

/*! @brief Set the DTEN0 field to a new value. */
#define BW_FTM_COMBINE_DTEN0(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_DTEN0) | BF_FTM_COMBINE_DTEN0(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field SYNCEN0[5] (RW)
 *
 * Enables PWM synchronization of registers C(n)V and C(n+1)V.
 *
 * Values:
 * - 0 - The PWM synchronization in this pair of channels is disabled.
 * - 1 - The PWM synchronization in this pair of channels is enabled.
 */
/*@{*/
#define BP_FTM_COMBINE_SYNCEN0 (5U)        /*!< Bit position for FTM_COMBINE_SYNCEN0. */
#define BM_FTM_COMBINE_SYNCEN0 (0x00000020U) /*!< Bit mask for FTM_COMBINE_SYNCEN0. */
#define BS_FTM_COMBINE_SYNCEN0 (1U)        /*!< Bit field size in bits for FTM_COMBINE_SYNCEN0. */

/*! @brief Read current value of the FTM_COMBINE_SYNCEN0 field. */
#define BR_FTM_COMBINE_SYNCEN0(x) (HW_FTM_COMBINE(x).B.SYNCEN0)

/*! @brief Format value for bitfield FTM_COMBINE_SYNCEN0. */
#define BF_FTM_COMBINE_SYNCEN0(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_SYNCEN0) & BM_FTM_COMBINE_SYNCEN0)

/*! @brief Set the SYNCEN0 field to a new value. */
#define BW_FTM_COMBINE_SYNCEN0(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_SYNCEN0) | BF_FTM_COMBINE_SYNCEN0(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field COMBINE1[8] (RW)
 *
 * Enables the combine feature for channels (n) and (n+1). This field is write
 * protected. It can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - Channels (n) and (n+1) are independent.
 * - 1 - Channels (n) and (n+1) are combined.
 */
/*@{*/
#define BP_FTM_COMBINE_COMBINE1 (8U)       /*!< Bit position for FTM_COMBINE_COMBINE1. */
#define BM_FTM_COMBINE_COMBINE1 (0x00000100U) /*!< Bit mask for FTM_COMBINE_COMBINE1. */
#define BS_FTM_COMBINE_COMBINE1 (1U)       /*!< Bit field size in bits for FTM_COMBINE_COMBINE1. */

/*! @brief Read current value of the FTM_COMBINE_COMBINE1 field. */
#define BR_FTM_COMBINE_COMBINE1(x) (HW_FTM_COMBINE(x).B.COMBINE1)

/*! @brief Format value for bitfield FTM_COMBINE_COMBINE1. */
#define BF_FTM_COMBINE_COMBINE1(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_COMBINE1) & BM_FTM_COMBINE_COMBINE1)

/*! @brief Set the COMBINE1 field to a new value. */
#define BW_FTM_COMBINE_COMBINE1(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_COMBINE1) | BF_FTM_COMBINE_COMBINE1(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field COMP1[9] (RW)
 *
 * Enables Complementary mode for the combined channels. In Complementary mode
 * the channel (n+1) output is the inverse of the channel (n) output. This field
 * is write protected. It can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The channel (n+1) output is the same as the channel (n) output.
 * - 1 - The channel (n+1) output is the complement of the channel (n) output.
 */
/*@{*/
#define BP_FTM_COMBINE_COMP1 (9U)          /*!< Bit position for FTM_COMBINE_COMP1. */
#define BM_FTM_COMBINE_COMP1 (0x00000200U) /*!< Bit mask for FTM_COMBINE_COMP1. */
#define BS_FTM_COMBINE_COMP1 (1U)          /*!< Bit field size in bits for FTM_COMBINE_COMP1. */

/*! @brief Read current value of the FTM_COMBINE_COMP1 field. */
#define BR_FTM_COMBINE_COMP1(x) (HW_FTM_COMBINE(x).B.COMP1)

/*! @brief Format value for bitfield FTM_COMBINE_COMP1. */
#define BF_FTM_COMBINE_COMP1(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_COMP1) & BM_FTM_COMBINE_COMP1)

/*! @brief Set the COMP1 field to a new value. */
#define BW_FTM_COMBINE_COMP1(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_COMP1) | BF_FTM_COMBINE_COMP1(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field DECAPEN1[10] (RW)
 *
 * Enables the Dual Edge Capture mode in the channels (n) and (n+1). This bit
 * reconfigures the function of MSnA, ELSnB:ELSnA and ELS(n+1)B:ELS(n+1)A bits in
 * Dual Edge Capture mode according to . This field is write protected. It can be
 * written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The Dual Edge Capture mode in this pair of channels is disabled.
 * - 1 - The Dual Edge Capture mode in this pair of channels is enabled.
 */
/*@{*/
#define BP_FTM_COMBINE_DECAPEN1 (10U)      /*!< Bit position for FTM_COMBINE_DECAPEN1. */
#define BM_FTM_COMBINE_DECAPEN1 (0x00000400U) /*!< Bit mask for FTM_COMBINE_DECAPEN1. */
#define BS_FTM_COMBINE_DECAPEN1 (1U)       /*!< Bit field size in bits for FTM_COMBINE_DECAPEN1. */

/*! @brief Read current value of the FTM_COMBINE_DECAPEN1 field. */
#define BR_FTM_COMBINE_DECAPEN1(x) (HW_FTM_COMBINE(x).B.DECAPEN1)

/*! @brief Format value for bitfield FTM_COMBINE_DECAPEN1. */
#define BF_FTM_COMBINE_DECAPEN1(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_DECAPEN1) & BM_FTM_COMBINE_DECAPEN1)

/*! @brief Set the DECAPEN1 field to a new value. */
#define BW_FTM_COMBINE_DECAPEN1(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_DECAPEN1) | BF_FTM_COMBINE_DECAPEN1(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field DECAP1[11] (RW)
 *
 * Enables the capture of the FTM counter value according to the channel (n)
 * input event and the configuration of the dual edge capture bits. This field
 * applies only when DECAPEN = 1. DECAP bit is cleared automatically by hardware if
 * Dual Edge Capture - One-Shot mode is selected and when the capture of channel
 * (n+1) event is made.
 *
 * Values:
 * - 0 - The dual edge captures are inactive.
 * - 1 - The dual edge captures are active.
 */
/*@{*/
#define BP_FTM_COMBINE_DECAP1 (11U)        /*!< Bit position for FTM_COMBINE_DECAP1. */
#define BM_FTM_COMBINE_DECAP1 (0x00000800U) /*!< Bit mask for FTM_COMBINE_DECAP1. */
#define BS_FTM_COMBINE_DECAP1 (1U)         /*!< Bit field size in bits for FTM_COMBINE_DECAP1. */

/*! @brief Read current value of the FTM_COMBINE_DECAP1 field. */
#define BR_FTM_COMBINE_DECAP1(x) (HW_FTM_COMBINE(x).B.DECAP1)

/*! @brief Format value for bitfield FTM_COMBINE_DECAP1. */
#define BF_FTM_COMBINE_DECAP1(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_DECAP1) & BM_FTM_COMBINE_DECAP1)

/*! @brief Set the DECAP1 field to a new value. */
#define BW_FTM_COMBINE_DECAP1(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_DECAP1) | BF_FTM_COMBINE_DECAP1(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field DTEN1[12] (RW)
 *
 * Enables the deadtime insertion in the channels (n) and (n+1). This field is
 * write protected. It can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The deadtime insertion in this pair of channels is disabled.
 * - 1 - The deadtime insertion in this pair of channels is enabled.
 */
/*@{*/
#define BP_FTM_COMBINE_DTEN1 (12U)         /*!< Bit position for FTM_COMBINE_DTEN1. */
#define BM_FTM_COMBINE_DTEN1 (0x00001000U) /*!< Bit mask for FTM_COMBINE_DTEN1. */
#define BS_FTM_COMBINE_DTEN1 (1U)          /*!< Bit field size in bits for FTM_COMBINE_DTEN1. */

/*! @brief Read current value of the FTM_COMBINE_DTEN1 field. */
#define BR_FTM_COMBINE_DTEN1(x) (HW_FTM_COMBINE(x).B.DTEN1)

/*! @brief Format value for bitfield FTM_COMBINE_DTEN1. */
#define BF_FTM_COMBINE_DTEN1(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_DTEN1) & BM_FTM_COMBINE_DTEN1)

/*! @brief Set the DTEN1 field to a new value. */
#define BW_FTM_COMBINE_DTEN1(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_DTEN1) | BF_FTM_COMBINE_DTEN1(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field SYNCEN1[13] (RW)
 *
 * Enables PWM synchronization of registers C(n)V and C(n+1)V.
 *
 * Values:
 * - 0 - The PWM synchronization in this pair of channels is disabled.
 * - 1 - The PWM synchronization in this pair of channels is enabled.
 */
/*@{*/
#define BP_FTM_COMBINE_SYNCEN1 (13U)       /*!< Bit position for FTM_COMBINE_SYNCEN1. */
#define BM_FTM_COMBINE_SYNCEN1 (0x00002000U) /*!< Bit mask for FTM_COMBINE_SYNCEN1. */
#define BS_FTM_COMBINE_SYNCEN1 (1U)        /*!< Bit field size in bits for FTM_COMBINE_SYNCEN1. */

/*! @brief Read current value of the FTM_COMBINE_SYNCEN1 field. */
#define BR_FTM_COMBINE_SYNCEN1(x) (HW_FTM_COMBINE(x).B.SYNCEN1)

/*! @brief Format value for bitfield FTM_COMBINE_SYNCEN1. */
#define BF_FTM_COMBINE_SYNCEN1(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_SYNCEN1) & BM_FTM_COMBINE_SYNCEN1)

/*! @brief Set the SYNCEN1 field to a new value. */
#define BW_FTM_COMBINE_SYNCEN1(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_SYNCEN1) | BF_FTM_COMBINE_SYNCEN1(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field COMBINE2[16] (RW)
 *
 * Enables the combine feature for channels (n) and (n+1). This field is write
 * protected. It can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - Channels (n) and (n+1) are independent.
 * - 1 - Channels (n) and (n+1) are combined.
 */
/*@{*/
#define BP_FTM_COMBINE_COMBINE2 (16U)      /*!< Bit position for FTM_COMBINE_COMBINE2. */
#define BM_FTM_COMBINE_COMBINE2 (0x00010000U) /*!< Bit mask for FTM_COMBINE_COMBINE2. */
#define BS_FTM_COMBINE_COMBINE2 (1U)       /*!< Bit field size in bits for FTM_COMBINE_COMBINE2. */

/*! @brief Read current value of the FTM_COMBINE_COMBINE2 field. */
#define BR_FTM_COMBINE_COMBINE2(x) (HW_FTM_COMBINE(x).B.COMBINE2)

/*! @brief Format value for bitfield FTM_COMBINE_COMBINE2. */
#define BF_FTM_COMBINE_COMBINE2(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_COMBINE2) & BM_FTM_COMBINE_COMBINE2)

/*! @brief Set the COMBINE2 field to a new value. */
#define BW_FTM_COMBINE_COMBINE2(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_COMBINE2) | BF_FTM_COMBINE_COMBINE2(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field COMP2[17] (RW)
 *
 * Enables Complementary mode for the combined channels. In Complementary mode
 * the channel (n+1) output is the inverse of the channel (n) output. This field
 * is write protected. It can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The channel (n+1) output is the same as the channel (n) output.
 * - 1 - The channel (n+1) output is the complement of the channel (n) output.
 */
/*@{*/
#define BP_FTM_COMBINE_COMP2 (17U)         /*!< Bit position for FTM_COMBINE_COMP2. */
#define BM_FTM_COMBINE_COMP2 (0x00020000U) /*!< Bit mask for FTM_COMBINE_COMP2. */
#define BS_FTM_COMBINE_COMP2 (1U)          /*!< Bit field size in bits for FTM_COMBINE_COMP2. */

/*! @brief Read current value of the FTM_COMBINE_COMP2 field. */
#define BR_FTM_COMBINE_COMP2(x) (HW_FTM_COMBINE(x).B.COMP2)

/*! @brief Format value for bitfield FTM_COMBINE_COMP2. */
#define BF_FTM_COMBINE_COMP2(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_COMP2) & BM_FTM_COMBINE_COMP2)

/*! @brief Set the COMP2 field to a new value. */
#define BW_FTM_COMBINE_COMP2(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_COMP2) | BF_FTM_COMBINE_COMP2(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field DECAPEN2[18] (RW)
 *
 * Enables the Dual Edge Capture mode in the channels (n) and (n+1). This bit
 * reconfigures the function of MSnA, ELSnB:ELSnA and ELS(n+1)B:ELS(n+1)A bits in
 * Dual Edge Capture mode according to . This field is write protected. It can be
 * written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The Dual Edge Capture mode in this pair of channels is disabled.
 * - 1 - The Dual Edge Capture mode in this pair of channels is enabled.
 */
/*@{*/
#define BP_FTM_COMBINE_DECAPEN2 (18U)      /*!< Bit position for FTM_COMBINE_DECAPEN2. */
#define BM_FTM_COMBINE_DECAPEN2 (0x00040000U) /*!< Bit mask for FTM_COMBINE_DECAPEN2. */
#define BS_FTM_COMBINE_DECAPEN2 (1U)       /*!< Bit field size in bits for FTM_COMBINE_DECAPEN2. */

/*! @brief Read current value of the FTM_COMBINE_DECAPEN2 field. */
#define BR_FTM_COMBINE_DECAPEN2(x) (HW_FTM_COMBINE(x).B.DECAPEN2)

/*! @brief Format value for bitfield FTM_COMBINE_DECAPEN2. */
#define BF_FTM_COMBINE_DECAPEN2(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_DECAPEN2) & BM_FTM_COMBINE_DECAPEN2)

/*! @brief Set the DECAPEN2 field to a new value. */
#define BW_FTM_COMBINE_DECAPEN2(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_DECAPEN2) | BF_FTM_COMBINE_DECAPEN2(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field DECAP2[19] (RW)
 *
 * Enables the capture of the FTM counter value according to the channel (n)
 * input event and the configuration of the dual edge capture bits. This field
 * applies only when DECAPEN = 1. DECAP bit is cleared automatically by hardware if
 * dual edge capture - one-shot mode is selected and when the capture of channel
 * (n+1) event is made.
 *
 * Values:
 * - 0 - The dual edge captures are inactive.
 * - 1 - The dual edge captures are active.
 */
/*@{*/
#define BP_FTM_COMBINE_DECAP2 (19U)        /*!< Bit position for FTM_COMBINE_DECAP2. */
#define BM_FTM_COMBINE_DECAP2 (0x00080000U) /*!< Bit mask for FTM_COMBINE_DECAP2. */
#define BS_FTM_COMBINE_DECAP2 (1U)         /*!< Bit field size in bits for FTM_COMBINE_DECAP2. */

/*! @brief Read current value of the FTM_COMBINE_DECAP2 field. */
#define BR_FTM_COMBINE_DECAP2(x) (HW_FTM_COMBINE(x).B.DECAP2)

/*! @brief Format value for bitfield FTM_COMBINE_DECAP2. */
#define BF_FTM_COMBINE_DECAP2(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_DECAP2) & BM_FTM_COMBINE_DECAP2)

/*! @brief Set the DECAP2 field to a new value. */
#define BW_FTM_COMBINE_DECAP2(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_DECAP2) | BF_FTM_COMBINE_DECAP2(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field DTEN2[20] (RW)
 *
 * Enables the deadtime insertion in the channels (n) and (n+1). This field is
 * write protected. It can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The deadtime insertion in this pair of channels is disabled.
 * - 1 - The deadtime insertion in this pair of channels is enabled.
 */
/*@{*/
#define BP_FTM_COMBINE_DTEN2 (20U)         /*!< Bit position for FTM_COMBINE_DTEN2. */
#define BM_FTM_COMBINE_DTEN2 (0x00100000U) /*!< Bit mask for FTM_COMBINE_DTEN2. */
#define BS_FTM_COMBINE_DTEN2 (1U)          /*!< Bit field size in bits for FTM_COMBINE_DTEN2. */

/*! @brief Read current value of the FTM_COMBINE_DTEN2 field. */
#define BR_FTM_COMBINE_DTEN2(x) (HW_FTM_COMBINE(x).B.DTEN2)

/*! @brief Format value for bitfield FTM_COMBINE_DTEN2. */
#define BF_FTM_COMBINE_DTEN2(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_DTEN2) & BM_FTM_COMBINE_DTEN2)

/*! @brief Set the DTEN2 field to a new value. */
#define BW_FTM_COMBINE_DTEN2(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_DTEN2) | BF_FTM_COMBINE_DTEN2(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field SYNCEN2[21] (RW)
 *
 * Enables PWM synchronization of registers C(n)V and C(n+1)V.
 *
 * Values:
 * - 0 - The PWM synchronization in this pair of channels is disabled.
 * - 1 - The PWM synchronization in this pair of channels is enabled.
 */
/*@{*/
#define BP_FTM_COMBINE_SYNCEN2 (21U)       /*!< Bit position for FTM_COMBINE_SYNCEN2. */
#define BM_FTM_COMBINE_SYNCEN2 (0x00200000U) /*!< Bit mask for FTM_COMBINE_SYNCEN2. */
#define BS_FTM_COMBINE_SYNCEN2 (1U)        /*!< Bit field size in bits for FTM_COMBINE_SYNCEN2. */

/*! @brief Read current value of the FTM_COMBINE_SYNCEN2 field. */
#define BR_FTM_COMBINE_SYNCEN2(x) (HW_FTM_COMBINE(x).B.SYNCEN2)

/*! @brief Format value for bitfield FTM_COMBINE_SYNCEN2. */
#define BF_FTM_COMBINE_SYNCEN2(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_SYNCEN2) & BM_FTM_COMBINE_SYNCEN2)

/*! @brief Set the SYNCEN2 field to a new value. */
#define BW_FTM_COMBINE_SYNCEN2(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_SYNCEN2) | BF_FTM_COMBINE_SYNCEN2(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field COMBINE3[24] (RW)
 *
 * Enables the combine feature for channels (n) and (n+1). This field is write
 * protected. It can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - Channels (n) and (n+1) are independent.
 * - 1 - Channels (n) and (n+1) are combined.
 */
/*@{*/
#define BP_FTM_COMBINE_COMBINE3 (24U)      /*!< Bit position for FTM_COMBINE_COMBINE3. */
#define BM_FTM_COMBINE_COMBINE3 (0x01000000U) /*!< Bit mask for FTM_COMBINE_COMBINE3. */
#define BS_FTM_COMBINE_COMBINE3 (1U)       /*!< Bit field size in bits for FTM_COMBINE_COMBINE3. */

/*! @brief Read current value of the FTM_COMBINE_COMBINE3 field. */
#define BR_FTM_COMBINE_COMBINE3(x) (HW_FTM_COMBINE(x).B.COMBINE3)

/*! @brief Format value for bitfield FTM_COMBINE_COMBINE3. */
#define BF_FTM_COMBINE_COMBINE3(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_COMBINE3) & BM_FTM_COMBINE_COMBINE3)

/*! @brief Set the COMBINE3 field to a new value. */
#define BW_FTM_COMBINE_COMBINE3(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_COMBINE3) | BF_FTM_COMBINE_COMBINE3(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field COMP3[25] (RW)
 *
 * Enables Complementary mode for the combined channels. In Complementary mode
 * the channel (n+1) output is the inverse of the channel (n) output. This field
 * is write protected. It can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The channel (n+1) output is the same as the channel (n) output.
 * - 1 - The channel (n+1) output is the complement of the channel (n) output.
 */
/*@{*/
#define BP_FTM_COMBINE_COMP3 (25U)         /*!< Bit position for FTM_COMBINE_COMP3. */
#define BM_FTM_COMBINE_COMP3 (0x02000000U) /*!< Bit mask for FTM_COMBINE_COMP3. */
#define BS_FTM_COMBINE_COMP3 (1U)          /*!< Bit field size in bits for FTM_COMBINE_COMP3. */

/*! @brief Read current value of the FTM_COMBINE_COMP3 field. */
#define BR_FTM_COMBINE_COMP3(x) (HW_FTM_COMBINE(x).B.COMP3)

/*! @brief Format value for bitfield FTM_COMBINE_COMP3. */
#define BF_FTM_COMBINE_COMP3(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_COMP3) & BM_FTM_COMBINE_COMP3)

/*! @brief Set the COMP3 field to a new value. */
#define BW_FTM_COMBINE_COMP3(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_COMP3) | BF_FTM_COMBINE_COMP3(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field DECAPEN3[26] (RW)
 *
 * Enables the Dual Edge Capture mode in the channels (n) and (n+1). This bit
 * reconfigures the function of MSnA, ELSnB:ELSnA and ELS(n+1)B:ELS(n+1)A bits in
 * Dual Edge Capture mode according to . This field is write protected. It can be
 * written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The Dual Edge Capture mode in this pair of channels is disabled.
 * - 1 - The Dual Edge Capture mode in this pair of channels is enabled.
 */
/*@{*/
#define BP_FTM_COMBINE_DECAPEN3 (26U)      /*!< Bit position for FTM_COMBINE_DECAPEN3. */
#define BM_FTM_COMBINE_DECAPEN3 (0x04000000U) /*!< Bit mask for FTM_COMBINE_DECAPEN3. */
#define BS_FTM_COMBINE_DECAPEN3 (1U)       /*!< Bit field size in bits for FTM_COMBINE_DECAPEN3. */

/*! @brief Read current value of the FTM_COMBINE_DECAPEN3 field. */
#define BR_FTM_COMBINE_DECAPEN3(x) (HW_FTM_COMBINE(x).B.DECAPEN3)

/*! @brief Format value for bitfield FTM_COMBINE_DECAPEN3. */
#define BF_FTM_COMBINE_DECAPEN3(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_DECAPEN3) & BM_FTM_COMBINE_DECAPEN3)

/*! @brief Set the DECAPEN3 field to a new value. */
#define BW_FTM_COMBINE_DECAPEN3(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_DECAPEN3) | BF_FTM_COMBINE_DECAPEN3(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field DECAP3[27] (RW)
 *
 * Enables the capture of the FTM counter value according to the channel (n)
 * input event and the configuration of the dual edge capture bits. This field
 * applies only when DECAPEN = 1. DECAP bit is cleared automatically by hardware if
 * dual edge capture - one-shot mode is selected and when the capture of channel
 * (n+1) event is made.
 *
 * Values:
 * - 0 - The dual edge captures are inactive.
 * - 1 - The dual edge captures are active.
 */
/*@{*/
#define BP_FTM_COMBINE_DECAP3 (27U)        /*!< Bit position for FTM_COMBINE_DECAP3. */
#define BM_FTM_COMBINE_DECAP3 (0x08000000U) /*!< Bit mask for FTM_COMBINE_DECAP3. */
#define BS_FTM_COMBINE_DECAP3 (1U)         /*!< Bit field size in bits for FTM_COMBINE_DECAP3. */

/*! @brief Read current value of the FTM_COMBINE_DECAP3 field. */
#define BR_FTM_COMBINE_DECAP3(x) (HW_FTM_COMBINE(x).B.DECAP3)

/*! @brief Format value for bitfield FTM_COMBINE_DECAP3. */
#define BF_FTM_COMBINE_DECAP3(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_DECAP3) & BM_FTM_COMBINE_DECAP3)

/*! @brief Set the DECAP3 field to a new value. */
#define BW_FTM_COMBINE_DECAP3(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_DECAP3) | BF_FTM_COMBINE_DECAP3(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field DTEN3[28] (RW)
 *
 * Enables the deadtime insertion in the channels (n) and (n+1). This field is
 * write protected. It can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The deadtime insertion in this pair of channels is disabled.
 * - 1 - The deadtime insertion in this pair of channels is enabled.
 */
/*@{*/
#define BP_FTM_COMBINE_DTEN3 (28U)         /*!< Bit position for FTM_COMBINE_DTEN3. */
#define BM_FTM_COMBINE_DTEN3 (0x10000000U) /*!< Bit mask for FTM_COMBINE_DTEN3. */
#define BS_FTM_COMBINE_DTEN3 (1U)          /*!< Bit field size in bits for FTM_COMBINE_DTEN3. */

/*! @brief Read current value of the FTM_COMBINE_DTEN3 field. */
#define BR_FTM_COMBINE_DTEN3(x) (HW_FTM_COMBINE(x).B.DTEN3)

/*! @brief Format value for bitfield FTM_COMBINE_DTEN3. */
#define BF_FTM_COMBINE_DTEN3(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_DTEN3) & BM_FTM_COMBINE_DTEN3)

/*! @brief Set the DTEN3 field to a new value. */
#define BW_FTM_COMBINE_DTEN3(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_DTEN3) | BF_FTM_COMBINE_DTEN3(v)))
/*@}*/

/*!
 * @name Register FTM_COMBINE, field SYNCEN3[29] (RW)
 *
 * Enables PWM synchronization of registers C(n)V and C(n+1)V.
 *
 * Values:
 * - 0 - The PWM synchronization in this pair of channels is disabled.
 * - 1 - The PWM synchronization in this pair of channels is enabled.
 */
/*@{*/
#define BP_FTM_COMBINE_SYNCEN3 (29U)       /*!< Bit position for FTM_COMBINE_SYNCEN3. */
#define BM_FTM_COMBINE_SYNCEN3 (0x20000000U) /*!< Bit mask for FTM_COMBINE_SYNCEN3. */
#define BS_FTM_COMBINE_SYNCEN3 (1U)        /*!< Bit field size in bits for FTM_COMBINE_SYNCEN3. */

/*! @brief Read current value of the FTM_COMBINE_SYNCEN3 field. */
#define BR_FTM_COMBINE_SYNCEN3(x) (HW_FTM_COMBINE(x).B.SYNCEN3)

/*! @brief Format value for bitfield FTM_COMBINE_SYNCEN3. */
#define BF_FTM_COMBINE_SYNCEN3(v) ((uint32_t)((uint32_t)(v) << BP_FTM_COMBINE_SYNCEN3) & BM_FTM_COMBINE_SYNCEN3)

/*! @brief Set the SYNCEN3 field to a new value. */
#define BW_FTM_COMBINE_SYNCEN3(x, v) (HW_FTM_COMBINE_WR(x, (HW_FTM_COMBINE_RD(x) & ~BM_FTM_COMBINE_SYNCEN3) | BF_FTM_COMBINE_SYNCEN3(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_DEADTIME - Deadtime Insertion Control
 ******************************************************************************/

/*!
 * @brief HW_FTM_DEADTIME - Deadtime Insertion Control (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register selects the deadtime prescaler factor and deadtime value. All
 * FTM channels use this clock prescaler and this deadtime value for the deadtime
 * insertion.
 */
typedef union _hw_ftm_deadtime
{
    uint32_t U;
    struct _hw_ftm_deadtime_bitfields
    {
        uint32_t DTVAL : 6;            /*!< [5:0] Deadtime Value */
        uint32_t DTPS : 2;             /*!< [7:6] Deadtime Prescaler Value */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_ftm_deadtime_t;

/*!
 * @name Constants and macros for entire FTM_DEADTIME register
 */
/*@{*/
#define HW_FTM_DEADTIME_ADDR(x)  ((uintptr_t)(x) + 0x68U)

#define HW_FTM_DEADTIME(x)       (*(__IO hw_ftm_deadtime_t *) HW_FTM_DEADTIME_ADDR(x))
#define HW_FTM_DEADTIME_RD(x)    (HW_FTM_DEADTIME(x).U)
#define HW_FTM_DEADTIME_WR(x, v) (HW_FTM_DEADTIME(x).U = (v))
#define HW_FTM_DEADTIME_SET(x, v) (HW_FTM_DEADTIME_WR(x, HW_FTM_DEADTIME_RD(x) |  (v)))
#define HW_FTM_DEADTIME_CLR(x, v) (HW_FTM_DEADTIME_WR(x, HW_FTM_DEADTIME_RD(x) & ~(v)))
#define HW_FTM_DEADTIME_TOG(x, v) (HW_FTM_DEADTIME_WR(x, HW_FTM_DEADTIME_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_DEADTIME bitfields
 */

/*!
 * @name Register FTM_DEADTIME, field DTVAL[5:0] (RW)
 *
 * Selects the deadtime insertion value for the deadtime counter. The deadtime
 * counter is clocked by a scaled version of the system clock. See the description
 * of DTPS. Deadtime insert value = (DTPS * DTVAL). DTVAL selects the number of
 * deadtime counts inserted as follows: When DTVAL is 0, no counts are inserted.
 * When DTVAL is 1, 1 count is inserted. When DTVAL is 2, 2 counts are inserted.
 * This pattern continues up to a possible 63 counts. This field is write
 * protected. It can be written only when MODE[WPDIS] = 1.
 */
/*@{*/
#define BP_FTM_DEADTIME_DTVAL (0U)         /*!< Bit position for FTM_DEADTIME_DTVAL. */
#define BM_FTM_DEADTIME_DTVAL (0x0000003FU) /*!< Bit mask for FTM_DEADTIME_DTVAL. */
#define BS_FTM_DEADTIME_DTVAL (6U)         /*!< Bit field size in bits for FTM_DEADTIME_DTVAL. */

/*! @brief Read current value of the FTM_DEADTIME_DTVAL field. */
#define BR_FTM_DEADTIME_DTVAL(x) (HW_FTM_DEADTIME(x).B.DTVAL)

/*! @brief Format value for bitfield FTM_DEADTIME_DTVAL. */
#define BF_FTM_DEADTIME_DTVAL(v) ((uint32_t)((uint32_t)(v) << BP_FTM_DEADTIME_DTVAL) & BM_FTM_DEADTIME_DTVAL)

/*! @brief Set the DTVAL field to a new value. */
#define BW_FTM_DEADTIME_DTVAL(x, v) (HW_FTM_DEADTIME_WR(x, (HW_FTM_DEADTIME_RD(x) & ~BM_FTM_DEADTIME_DTVAL) | BF_FTM_DEADTIME_DTVAL(v)))
/*@}*/

/*!
 * @name Register FTM_DEADTIME, field DTPS[7:6] (RW)
 *
 * Selects the division factor of the system clock. This prescaled clock is used
 * by the deadtime counter. This field is write protected. It can be written
 * only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0x - Divide the system clock by 1.
 * - 10 - Divide the system clock by 4.
 * - 11 - Divide the system clock by 16.
 */
/*@{*/
#define BP_FTM_DEADTIME_DTPS (6U)          /*!< Bit position for FTM_DEADTIME_DTPS. */
#define BM_FTM_DEADTIME_DTPS (0x000000C0U) /*!< Bit mask for FTM_DEADTIME_DTPS. */
#define BS_FTM_DEADTIME_DTPS (2U)          /*!< Bit field size in bits for FTM_DEADTIME_DTPS. */

/*! @brief Read current value of the FTM_DEADTIME_DTPS field. */
#define BR_FTM_DEADTIME_DTPS(x) (HW_FTM_DEADTIME(x).B.DTPS)

/*! @brief Format value for bitfield FTM_DEADTIME_DTPS. */
#define BF_FTM_DEADTIME_DTPS(v) ((uint32_t)((uint32_t)(v) << BP_FTM_DEADTIME_DTPS) & BM_FTM_DEADTIME_DTPS)

/*! @brief Set the DTPS field to a new value. */
#define BW_FTM_DEADTIME_DTPS(x, v) (HW_FTM_DEADTIME_WR(x, (HW_FTM_DEADTIME_RD(x) & ~BM_FTM_DEADTIME_DTPS) | BF_FTM_DEADTIME_DTPS(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_EXTTRIG - FTM External Trigger
 ******************************************************************************/

/*!
 * @brief HW_FTM_EXTTRIG - FTM External Trigger (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register: Indicates when a channel trigger was generated Enables the
 * generation of a trigger when the FTM counter is equal to its initial value
 * Selects which channels are used in the generation of the channel triggers Several
 * channels can be selected to generate multiple triggers in one PWM period. See
 * Channel trigger output and Initialization trigger. Channels 6 and 7 are not used
 * to generate channel triggers.
 */
typedef union _hw_ftm_exttrig
{
    uint32_t U;
    struct _hw_ftm_exttrig_bitfields
    {
        uint32_t CH2TRIG : 1;          /*!< [0] Channel 2 Trigger Enable */
        uint32_t CH3TRIG : 1;          /*!< [1] Channel 3 Trigger Enable */
        uint32_t CH4TRIG : 1;          /*!< [2] Channel 4 Trigger Enable */
        uint32_t CH5TRIG : 1;          /*!< [3] Channel 5 Trigger Enable */
        uint32_t CH0TRIG : 1;          /*!< [4] Channel 0 Trigger Enable */
        uint32_t CH1TRIG : 1;          /*!< [5] Channel 1 Trigger Enable */
        uint32_t INITTRIGEN : 1;       /*!< [6] Initialization Trigger Enable */
        uint32_t TRIGF : 1;            /*!< [7] Channel Trigger Flag */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_ftm_exttrig_t;

/*!
 * @name Constants and macros for entire FTM_EXTTRIG register
 */
/*@{*/
#define HW_FTM_EXTTRIG_ADDR(x)   ((uintptr_t)(x) + 0x6CU)

#define HW_FTM_EXTTRIG(x)        (*(__IO hw_ftm_exttrig_t *) HW_FTM_EXTTRIG_ADDR(x))
#define HW_FTM_EXTTRIG_RD(x)     (HW_FTM_EXTTRIG(x).U)
#define HW_FTM_EXTTRIG_WR(x, v)  (HW_FTM_EXTTRIG(x).U = (v))
#define HW_FTM_EXTTRIG_SET(x, v) (HW_FTM_EXTTRIG_WR(x, HW_FTM_EXTTRIG_RD(x) |  (v)))
#define HW_FTM_EXTTRIG_CLR(x, v) (HW_FTM_EXTTRIG_WR(x, HW_FTM_EXTTRIG_RD(x) & ~(v)))
#define HW_FTM_EXTTRIG_TOG(x, v) (HW_FTM_EXTTRIG_WR(x, HW_FTM_EXTTRIG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_EXTTRIG bitfields
 */

/*!
 * @name Register FTM_EXTTRIG, field CH2TRIG[0] (RW)
 *
 * Enables the generation of the channel trigger when the FTM counter is equal
 * to the CnV register.
 *
 * Values:
 * - 0 - The generation of the channel trigger is disabled.
 * - 1 - The generation of the channel trigger is enabled.
 */
/*@{*/
#define BP_FTM_EXTTRIG_CH2TRIG (0U)        /*!< Bit position for FTM_EXTTRIG_CH2TRIG. */
#define BM_FTM_EXTTRIG_CH2TRIG (0x00000001U) /*!< Bit mask for FTM_EXTTRIG_CH2TRIG. */
#define BS_FTM_EXTTRIG_CH2TRIG (1U)        /*!< Bit field size in bits for FTM_EXTTRIG_CH2TRIG. */

/*! @brief Read current value of the FTM_EXTTRIG_CH2TRIG field. */
#define BR_FTM_EXTTRIG_CH2TRIG(x) (HW_FTM_EXTTRIG(x).B.CH2TRIG)

/*! @brief Format value for bitfield FTM_EXTTRIG_CH2TRIG. */
#define BF_FTM_EXTTRIG_CH2TRIG(v) ((uint32_t)((uint32_t)(v) << BP_FTM_EXTTRIG_CH2TRIG) & BM_FTM_EXTTRIG_CH2TRIG)

/*! @brief Set the CH2TRIG field to a new value. */
#define BW_FTM_EXTTRIG_CH2TRIG(x, v) (HW_FTM_EXTTRIG_WR(x, (HW_FTM_EXTTRIG_RD(x) & ~BM_FTM_EXTTRIG_CH2TRIG) | BF_FTM_EXTTRIG_CH2TRIG(v)))
/*@}*/

/*!
 * @name Register FTM_EXTTRIG, field CH3TRIG[1] (RW)
 *
 * Enables the generation of the channel trigger when the FTM counter is equal
 * to the CnV register.
 *
 * Values:
 * - 0 - The generation of the channel trigger is disabled.
 * - 1 - The generation of the channel trigger is enabled.
 */
/*@{*/
#define BP_FTM_EXTTRIG_CH3TRIG (1U)        /*!< Bit position for FTM_EXTTRIG_CH3TRIG. */
#define BM_FTM_EXTTRIG_CH3TRIG (0x00000002U) /*!< Bit mask for FTM_EXTTRIG_CH3TRIG. */
#define BS_FTM_EXTTRIG_CH3TRIG (1U)        /*!< Bit field size in bits for FTM_EXTTRIG_CH3TRIG. */

/*! @brief Read current value of the FTM_EXTTRIG_CH3TRIG field. */
#define BR_FTM_EXTTRIG_CH3TRIG(x) (HW_FTM_EXTTRIG(x).B.CH3TRIG)

/*! @brief Format value for bitfield FTM_EXTTRIG_CH3TRIG. */
#define BF_FTM_EXTTRIG_CH3TRIG(v) ((uint32_t)((uint32_t)(v) << BP_FTM_EXTTRIG_CH3TRIG) & BM_FTM_EXTTRIG_CH3TRIG)

/*! @brief Set the CH3TRIG field to a new value. */
#define BW_FTM_EXTTRIG_CH3TRIG(x, v) (HW_FTM_EXTTRIG_WR(x, (HW_FTM_EXTTRIG_RD(x) & ~BM_FTM_EXTTRIG_CH3TRIG) | BF_FTM_EXTTRIG_CH3TRIG(v)))
/*@}*/

/*!
 * @name Register FTM_EXTTRIG, field CH4TRIG[2] (RW)
 *
 * Enables the generation of the channel trigger when the FTM counter is equal
 * to the CnV register.
 *
 * Values:
 * - 0 - The generation of the channel trigger is disabled.
 * - 1 - The generation of the channel trigger is enabled.
 */
/*@{*/
#define BP_FTM_EXTTRIG_CH4TRIG (2U)        /*!< Bit position for FTM_EXTTRIG_CH4TRIG. */
#define BM_FTM_EXTTRIG_CH4TRIG (0x00000004U) /*!< Bit mask for FTM_EXTTRIG_CH4TRIG. */
#define BS_FTM_EXTTRIG_CH4TRIG (1U)        /*!< Bit field size in bits for FTM_EXTTRIG_CH4TRIG. */

/*! @brief Read current value of the FTM_EXTTRIG_CH4TRIG field. */
#define BR_FTM_EXTTRIG_CH4TRIG(x) (HW_FTM_EXTTRIG(x).B.CH4TRIG)

/*! @brief Format value for bitfield FTM_EXTTRIG_CH4TRIG. */
#define BF_FTM_EXTTRIG_CH4TRIG(v) ((uint32_t)((uint32_t)(v) << BP_FTM_EXTTRIG_CH4TRIG) & BM_FTM_EXTTRIG_CH4TRIG)

/*! @brief Set the CH4TRIG field to a new value. */
#define BW_FTM_EXTTRIG_CH4TRIG(x, v) (HW_FTM_EXTTRIG_WR(x, (HW_FTM_EXTTRIG_RD(x) & ~BM_FTM_EXTTRIG_CH4TRIG) | BF_FTM_EXTTRIG_CH4TRIG(v)))
/*@}*/

/*!
 * @name Register FTM_EXTTRIG, field CH5TRIG[3] (RW)
 *
 * Enables the generation of the channel trigger when the FTM counter is equal
 * to the CnV register.
 *
 * Values:
 * - 0 - The generation of the channel trigger is disabled.
 * - 1 - The generation of the channel trigger is enabled.
 */
/*@{*/
#define BP_FTM_EXTTRIG_CH5TRIG (3U)        /*!< Bit position for FTM_EXTTRIG_CH5TRIG. */
#define BM_FTM_EXTTRIG_CH5TRIG (0x00000008U) /*!< Bit mask for FTM_EXTTRIG_CH5TRIG. */
#define BS_FTM_EXTTRIG_CH5TRIG (1U)        /*!< Bit field size in bits for FTM_EXTTRIG_CH5TRIG. */

/*! @brief Read current value of the FTM_EXTTRIG_CH5TRIG field. */
#define BR_FTM_EXTTRIG_CH5TRIG(x) (HW_FTM_EXTTRIG(x).B.CH5TRIG)

/*! @brief Format value for bitfield FTM_EXTTRIG_CH5TRIG. */
#define BF_FTM_EXTTRIG_CH5TRIG(v) ((uint32_t)((uint32_t)(v) << BP_FTM_EXTTRIG_CH5TRIG) & BM_FTM_EXTTRIG_CH5TRIG)

/*! @brief Set the CH5TRIG field to a new value. */
#define BW_FTM_EXTTRIG_CH5TRIG(x, v) (HW_FTM_EXTTRIG_WR(x, (HW_FTM_EXTTRIG_RD(x) & ~BM_FTM_EXTTRIG_CH5TRIG) | BF_FTM_EXTTRIG_CH5TRIG(v)))
/*@}*/

/*!
 * @name Register FTM_EXTTRIG, field CH0TRIG[4] (RW)
 *
 * Enables the generation of the channel trigger when the FTM counter is equal
 * to the CnV register.
 *
 * Values:
 * - 0 - The generation of the channel trigger is disabled.
 * - 1 - The generation of the channel trigger is enabled.
 */
/*@{*/
#define BP_FTM_EXTTRIG_CH0TRIG (4U)        /*!< Bit position for FTM_EXTTRIG_CH0TRIG. */
#define BM_FTM_EXTTRIG_CH0TRIG (0x00000010U) /*!< Bit mask for FTM_EXTTRIG_CH0TRIG. */
#define BS_FTM_EXTTRIG_CH0TRIG (1U)        /*!< Bit field size in bits for FTM_EXTTRIG_CH0TRIG. */

/*! @brief Read current value of the FTM_EXTTRIG_CH0TRIG field. */
#define BR_FTM_EXTTRIG_CH0TRIG(x) (HW_FTM_EXTTRIG(x).B.CH0TRIG)

/*! @brief Format value for bitfield FTM_EXTTRIG_CH0TRIG. */
#define BF_FTM_EXTTRIG_CH0TRIG(v) ((uint32_t)((uint32_t)(v) << BP_FTM_EXTTRIG_CH0TRIG) & BM_FTM_EXTTRIG_CH0TRIG)

/*! @brief Set the CH0TRIG field to a new value. */
#define BW_FTM_EXTTRIG_CH0TRIG(x, v) (HW_FTM_EXTTRIG_WR(x, (HW_FTM_EXTTRIG_RD(x) & ~BM_FTM_EXTTRIG_CH0TRIG) | BF_FTM_EXTTRIG_CH0TRIG(v)))
/*@}*/

/*!
 * @name Register FTM_EXTTRIG, field CH1TRIG[5] (RW)
 *
 * Enables the generation of the channel trigger when the FTM counter is equal
 * to the CnV register.
 *
 * Values:
 * - 0 - The generation of the channel trigger is disabled.
 * - 1 - The generation of the channel trigger is enabled.
 */
/*@{*/
#define BP_FTM_EXTTRIG_CH1TRIG (5U)        /*!< Bit position for FTM_EXTTRIG_CH1TRIG. */
#define BM_FTM_EXTTRIG_CH1TRIG (0x00000020U) /*!< Bit mask for FTM_EXTTRIG_CH1TRIG. */
#define BS_FTM_EXTTRIG_CH1TRIG (1U)        /*!< Bit field size in bits for FTM_EXTTRIG_CH1TRIG. */

/*! @brief Read current value of the FTM_EXTTRIG_CH1TRIG field. */
#define BR_FTM_EXTTRIG_CH1TRIG(x) (HW_FTM_EXTTRIG(x).B.CH1TRIG)

/*! @brief Format value for bitfield FTM_EXTTRIG_CH1TRIG. */
#define BF_FTM_EXTTRIG_CH1TRIG(v) ((uint32_t)((uint32_t)(v) << BP_FTM_EXTTRIG_CH1TRIG) & BM_FTM_EXTTRIG_CH1TRIG)

/*! @brief Set the CH1TRIG field to a new value. */
#define BW_FTM_EXTTRIG_CH1TRIG(x, v) (HW_FTM_EXTTRIG_WR(x, (HW_FTM_EXTTRIG_RD(x) & ~BM_FTM_EXTTRIG_CH1TRIG) | BF_FTM_EXTTRIG_CH1TRIG(v)))
/*@}*/

/*!
 * @name Register FTM_EXTTRIG, field INITTRIGEN[6] (RW)
 *
 * Enables the generation of the trigger when the FTM counter is equal to the
 * CNTIN register.
 *
 * Values:
 * - 0 - The generation of initialization trigger is disabled.
 * - 1 - The generation of initialization trigger is enabled.
 */
/*@{*/
#define BP_FTM_EXTTRIG_INITTRIGEN (6U)     /*!< Bit position for FTM_EXTTRIG_INITTRIGEN. */
#define BM_FTM_EXTTRIG_INITTRIGEN (0x00000040U) /*!< Bit mask for FTM_EXTTRIG_INITTRIGEN. */
#define BS_FTM_EXTTRIG_INITTRIGEN (1U)     /*!< Bit field size in bits for FTM_EXTTRIG_INITTRIGEN. */

/*! @brief Read current value of the FTM_EXTTRIG_INITTRIGEN field. */
#define BR_FTM_EXTTRIG_INITTRIGEN(x) (HW_FTM_EXTTRIG(x).B.INITTRIGEN)

/*! @brief Format value for bitfield FTM_EXTTRIG_INITTRIGEN. */
#define BF_FTM_EXTTRIG_INITTRIGEN(v) ((uint32_t)((uint32_t)(v) << BP_FTM_EXTTRIG_INITTRIGEN) & BM_FTM_EXTTRIG_INITTRIGEN)

/*! @brief Set the INITTRIGEN field to a new value. */
#define BW_FTM_EXTTRIG_INITTRIGEN(x, v) (HW_FTM_EXTTRIG_WR(x, (HW_FTM_EXTTRIG_RD(x) & ~BM_FTM_EXTTRIG_INITTRIGEN) | BF_FTM_EXTTRIG_INITTRIGEN(v)))
/*@}*/

/*!
 * @name Register FTM_EXTTRIG, field TRIGF[7] (ROWZ)
 *
 * Set by hardware when a channel trigger is generated. Clear TRIGF by reading
 * EXTTRIG while TRIGF is set and then writing a 0 to TRIGF. Writing a 1 to TRIGF
 * has no effect. If another channel trigger is generated before the clearing
 * sequence is completed, the sequence is reset so TRIGF remains set after the clear
 * sequence is completed for the earlier TRIGF.
 *
 * Values:
 * - 0 - No channel trigger was generated.
 * - 1 - A channel trigger was generated.
 */
/*@{*/
#define BP_FTM_EXTTRIG_TRIGF (7U)          /*!< Bit position for FTM_EXTTRIG_TRIGF. */
#define BM_FTM_EXTTRIG_TRIGF (0x00000080U) /*!< Bit mask for FTM_EXTTRIG_TRIGF. */
#define BS_FTM_EXTTRIG_TRIGF (1U)          /*!< Bit field size in bits for FTM_EXTTRIG_TRIGF. */

/*! @brief Read current value of the FTM_EXTTRIG_TRIGF field. */
#define BR_FTM_EXTTRIG_TRIGF(x) (HW_FTM_EXTTRIG(x).B.TRIGF)

/*! @brief Format value for bitfield FTM_EXTTRIG_TRIGF. */
#define BF_FTM_EXTTRIG_TRIGF(v) ((uint32_t)((uint32_t)(v) << BP_FTM_EXTTRIG_TRIGF) & BM_FTM_EXTTRIG_TRIGF)

/*! @brief Set the TRIGF field to a new value. */
#define BW_FTM_EXTTRIG_TRIGF(x, v) (HW_FTM_EXTTRIG_WR(x, (HW_FTM_EXTTRIG_RD(x) & ~BM_FTM_EXTTRIG_TRIGF) | BF_FTM_EXTTRIG_TRIGF(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_POL - Channels Polarity
 ******************************************************************************/

/*!
 * @brief HW_FTM_POL - Channels Polarity (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the output polarity of the FTM channels. The safe value
 * of a channel is the value of its POL bit.
 */
typedef union _hw_ftm_pol
{
    uint32_t U;
    struct _hw_ftm_pol_bitfields
    {
        uint32_t POL0 : 1;             /*!< [0] Channel 0 Polarity */
        uint32_t POL1 : 1;             /*!< [1] Channel 1 Polarity */
        uint32_t POL2 : 1;             /*!< [2] Channel 2 Polarity */
        uint32_t POL3 : 1;             /*!< [3] Channel 3 Polarity */
        uint32_t POL4 : 1;             /*!< [4] Channel 4 Polarity */
        uint32_t POL5 : 1;             /*!< [5] Channel 5 Polarity */
        uint32_t POL6 : 1;             /*!< [6] Channel 6 Polarity */
        uint32_t POL7 : 1;             /*!< [7] Channel 7 Polarity */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_ftm_pol_t;

/*!
 * @name Constants and macros for entire FTM_POL register
 */
/*@{*/
#define HW_FTM_POL_ADDR(x)       ((uintptr_t)(x) + 0x70U)

#define HW_FTM_POL(x)            (*(__IO hw_ftm_pol_t *) HW_FTM_POL_ADDR(x))
#define HW_FTM_POL_RD(x)         (HW_FTM_POL(x).U)
#define HW_FTM_POL_WR(x, v)      (HW_FTM_POL(x).U = (v))
#define HW_FTM_POL_SET(x, v)     (HW_FTM_POL_WR(x, HW_FTM_POL_RD(x) |  (v)))
#define HW_FTM_POL_CLR(x, v)     (HW_FTM_POL_WR(x, HW_FTM_POL_RD(x) & ~(v)))
#define HW_FTM_POL_TOG(x, v)     (HW_FTM_POL_WR(x, HW_FTM_POL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_POL bitfields
 */

/*!
 * @name Register FTM_POL, field POL0[0] (RW)
 *
 * Defines the polarity of the channel output. This field is write protected. It
 * can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The channel polarity is active high.
 * - 1 - The channel polarity is active low.
 */
/*@{*/
#define BP_FTM_POL_POL0      (0U)          /*!< Bit position for FTM_POL_POL0. */
#define BM_FTM_POL_POL0      (0x00000001U) /*!< Bit mask for FTM_POL_POL0. */
#define BS_FTM_POL_POL0      (1U)          /*!< Bit field size in bits for FTM_POL_POL0. */

/*! @brief Read current value of the FTM_POL_POL0 field. */
#define BR_FTM_POL_POL0(x)   (HW_FTM_POL(x).B.POL0)

/*! @brief Format value for bitfield FTM_POL_POL0. */
#define BF_FTM_POL_POL0(v)   ((uint32_t)((uint32_t)(v) << BP_FTM_POL_POL0) & BM_FTM_POL_POL0)

/*! @brief Set the POL0 field to a new value. */
#define BW_FTM_POL_POL0(x, v) (HW_FTM_POL_WR(x, (HW_FTM_POL_RD(x) & ~BM_FTM_POL_POL0) | BF_FTM_POL_POL0(v)))
/*@}*/

/*!
 * @name Register FTM_POL, field POL1[1] (RW)
 *
 * Defines the polarity of the channel output. This field is write protected. It
 * can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The channel polarity is active high.
 * - 1 - The channel polarity is active low.
 */
/*@{*/
#define BP_FTM_POL_POL1      (1U)          /*!< Bit position for FTM_POL_POL1. */
#define BM_FTM_POL_POL1      (0x00000002U) /*!< Bit mask for FTM_POL_POL1. */
#define BS_FTM_POL_POL1      (1U)          /*!< Bit field size in bits for FTM_POL_POL1. */

/*! @brief Read current value of the FTM_POL_POL1 field. */
#define BR_FTM_POL_POL1(x)   (HW_FTM_POL(x).B.POL1)

/*! @brief Format value for bitfield FTM_POL_POL1. */
#define BF_FTM_POL_POL1(v)   ((uint32_t)((uint32_t)(v) << BP_FTM_POL_POL1) & BM_FTM_POL_POL1)

/*! @brief Set the POL1 field to a new value. */
#define BW_FTM_POL_POL1(x, v) (HW_FTM_POL_WR(x, (HW_FTM_POL_RD(x) & ~BM_FTM_POL_POL1) | BF_FTM_POL_POL1(v)))
/*@}*/

/*!
 * @name Register FTM_POL, field POL2[2] (RW)
 *
 * Defines the polarity of the channel output. This field is write protected. It
 * can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The channel polarity is active high.
 * - 1 - The channel polarity is active low.
 */
/*@{*/
#define BP_FTM_POL_POL2      (2U)          /*!< Bit position for FTM_POL_POL2. */
#define BM_FTM_POL_POL2      (0x00000004U) /*!< Bit mask for FTM_POL_POL2. */
#define BS_FTM_POL_POL2      (1U)          /*!< Bit field size in bits for FTM_POL_POL2. */

/*! @brief Read current value of the FTM_POL_POL2 field. */
#define BR_FTM_POL_POL2(x)   (HW_FTM_POL(x).B.POL2)

/*! @brief Format value for bitfield FTM_POL_POL2. */
#define BF_FTM_POL_POL2(v)   ((uint32_t)((uint32_t)(v) << BP_FTM_POL_POL2) & BM_FTM_POL_POL2)

/*! @brief Set the POL2 field to a new value. */
#define BW_FTM_POL_POL2(x, v) (HW_FTM_POL_WR(x, (HW_FTM_POL_RD(x) & ~BM_FTM_POL_POL2) | BF_FTM_POL_POL2(v)))
/*@}*/

/*!
 * @name Register FTM_POL, field POL3[3] (RW)
 *
 * Defines the polarity of the channel output. This field is write protected. It
 * can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The channel polarity is active high.
 * - 1 - The channel polarity is active low.
 */
/*@{*/
#define BP_FTM_POL_POL3      (3U)          /*!< Bit position for FTM_POL_POL3. */
#define BM_FTM_POL_POL3      (0x00000008U) /*!< Bit mask for FTM_POL_POL3. */
#define BS_FTM_POL_POL3      (1U)          /*!< Bit field size in bits for FTM_POL_POL3. */

/*! @brief Read current value of the FTM_POL_POL3 field. */
#define BR_FTM_POL_POL3(x)   (HW_FTM_POL(x).B.POL3)

/*! @brief Format value for bitfield FTM_POL_POL3. */
#define BF_FTM_POL_POL3(v)   ((uint32_t)((uint32_t)(v) << BP_FTM_POL_POL3) & BM_FTM_POL_POL3)

/*! @brief Set the POL3 field to a new value. */
#define BW_FTM_POL_POL3(x, v) (HW_FTM_POL_WR(x, (HW_FTM_POL_RD(x) & ~BM_FTM_POL_POL3) | BF_FTM_POL_POL3(v)))
/*@}*/

/*!
 * @name Register FTM_POL, field POL4[4] (RW)
 *
 * Defines the polarity of the channel output. This field is write protected. It
 * can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The channel polarity is active high.
 * - 1 - The channel polarity is active low.
 */
/*@{*/
#define BP_FTM_POL_POL4      (4U)          /*!< Bit position for FTM_POL_POL4. */
#define BM_FTM_POL_POL4      (0x00000010U) /*!< Bit mask for FTM_POL_POL4. */
#define BS_FTM_POL_POL4      (1U)          /*!< Bit field size in bits for FTM_POL_POL4. */

/*! @brief Read current value of the FTM_POL_POL4 field. */
#define BR_FTM_POL_POL4(x)   (HW_FTM_POL(x).B.POL4)

/*! @brief Format value for bitfield FTM_POL_POL4. */
#define BF_FTM_POL_POL4(v)   ((uint32_t)((uint32_t)(v) << BP_FTM_POL_POL4) & BM_FTM_POL_POL4)

/*! @brief Set the POL4 field to a new value. */
#define BW_FTM_POL_POL4(x, v) (HW_FTM_POL_WR(x, (HW_FTM_POL_RD(x) & ~BM_FTM_POL_POL4) | BF_FTM_POL_POL4(v)))
/*@}*/

/*!
 * @name Register FTM_POL, field POL5[5] (RW)
 *
 * Defines the polarity of the channel output. This field is write protected. It
 * can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The channel polarity is active high.
 * - 1 - The channel polarity is active low.
 */
/*@{*/
#define BP_FTM_POL_POL5      (5U)          /*!< Bit position for FTM_POL_POL5. */
#define BM_FTM_POL_POL5      (0x00000020U) /*!< Bit mask for FTM_POL_POL5. */
#define BS_FTM_POL_POL5      (1U)          /*!< Bit field size in bits for FTM_POL_POL5. */

/*! @brief Read current value of the FTM_POL_POL5 field. */
#define BR_FTM_POL_POL5(x)   (HW_FTM_POL(x).B.POL5)

/*! @brief Format value for bitfield FTM_POL_POL5. */
#define BF_FTM_POL_POL5(v)   ((uint32_t)((uint32_t)(v) << BP_FTM_POL_POL5) & BM_FTM_POL_POL5)

/*! @brief Set the POL5 field to a new value. */
#define BW_FTM_POL_POL5(x, v) (HW_FTM_POL_WR(x, (HW_FTM_POL_RD(x) & ~BM_FTM_POL_POL5) | BF_FTM_POL_POL5(v)))
/*@}*/

/*!
 * @name Register FTM_POL, field POL6[6] (RW)
 *
 * Defines the polarity of the channel output. This field is write protected. It
 * can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The channel polarity is active high.
 * - 1 - The channel polarity is active low.
 */
/*@{*/
#define BP_FTM_POL_POL6      (6U)          /*!< Bit position for FTM_POL_POL6. */
#define BM_FTM_POL_POL6      (0x00000040U) /*!< Bit mask for FTM_POL_POL6. */
#define BS_FTM_POL_POL6      (1U)          /*!< Bit field size in bits for FTM_POL_POL6. */

/*! @brief Read current value of the FTM_POL_POL6 field. */
#define BR_FTM_POL_POL6(x)   (HW_FTM_POL(x).B.POL6)

/*! @brief Format value for bitfield FTM_POL_POL6. */
#define BF_FTM_POL_POL6(v)   ((uint32_t)((uint32_t)(v) << BP_FTM_POL_POL6) & BM_FTM_POL_POL6)

/*! @brief Set the POL6 field to a new value. */
#define BW_FTM_POL_POL6(x, v) (HW_FTM_POL_WR(x, (HW_FTM_POL_RD(x) & ~BM_FTM_POL_POL6) | BF_FTM_POL_POL6(v)))
/*@}*/

/*!
 * @name Register FTM_POL, field POL7[7] (RW)
 *
 * Defines the polarity of the channel output. This field is write protected. It
 * can be written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - The channel polarity is active high.
 * - 1 - The channel polarity is active low.
 */
/*@{*/
#define BP_FTM_POL_POL7      (7U)          /*!< Bit position for FTM_POL_POL7. */
#define BM_FTM_POL_POL7      (0x00000080U) /*!< Bit mask for FTM_POL_POL7. */
#define BS_FTM_POL_POL7      (1U)          /*!< Bit field size in bits for FTM_POL_POL7. */

/*! @brief Read current value of the FTM_POL_POL7 field. */
#define BR_FTM_POL_POL7(x)   (HW_FTM_POL(x).B.POL7)

/*! @brief Format value for bitfield FTM_POL_POL7. */
#define BF_FTM_POL_POL7(v)   ((uint32_t)((uint32_t)(v) << BP_FTM_POL_POL7) & BM_FTM_POL_POL7)

/*! @brief Set the POL7 field to a new value. */
#define BW_FTM_POL_POL7(x, v) (HW_FTM_POL_WR(x, (HW_FTM_POL_RD(x) & ~BM_FTM_POL_POL7) | BF_FTM_POL_POL7(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_FMS - Fault Mode Status
 ******************************************************************************/

/*!
 * @brief HW_FTM_FMS - Fault Mode Status (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the write protection enable bit.
 */
typedef union _hw_ftm_fms
{
    uint32_t U;
    struct _hw_ftm_fms_bitfields
    {
        uint32_t RESERVED0 : 6;        /*!< [5:0]  */
        uint32_t WPEN : 1;             /*!< [6] Write Protection Enable */
        uint32_t RESERVED1 : 25;       /*!< [31:7]  */
    } B;
} hw_ftm_fms_t;

/*!
 * @name Constants and macros for entire FTM_FMS register
 */
/*@{*/
#define HW_FTM_FMS_ADDR(x)       ((uintptr_t)(x) + 0x74U)

#define HW_FTM_FMS(x)            (*(__IO hw_ftm_fms_t *) HW_FTM_FMS_ADDR(x))
#define HW_FTM_FMS_RD(x)         (HW_FTM_FMS(x).U)
#define HW_FTM_FMS_WR(x, v)      (HW_FTM_FMS(x).U = (v))
#define HW_FTM_FMS_SET(x, v)     (HW_FTM_FMS_WR(x, HW_FTM_FMS_RD(x) |  (v)))
#define HW_FTM_FMS_CLR(x, v)     (HW_FTM_FMS_WR(x, HW_FTM_FMS_RD(x) & ~(v)))
#define HW_FTM_FMS_TOG(x, v)     (HW_FTM_FMS_WR(x, HW_FTM_FMS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_FMS bitfields
 */

/*!
 * @name Register FTM_FMS, field WPEN[6] (RW)
 *
 * The WPEN bit is the negation of the WPDIS bit. WPEN is set when 1 is written
 * to it. WPEN is cleared when WPEN bit is read as a 1 and then 1 is written to
 * WPDIS. Writing 0 to WPEN has no effect.
 *
 * Values:
 * - 0 - Write protection is disabled. Write protected bits can be written.
 * - 1 - Write protection is enabled. Write protected bits cannot be written.
 */
/*@{*/
#define BP_FTM_FMS_WPEN      (6U)          /*!< Bit position for FTM_FMS_WPEN. */
#define BM_FTM_FMS_WPEN      (0x00000040U) /*!< Bit mask for FTM_FMS_WPEN. */
#define BS_FTM_FMS_WPEN      (1U)          /*!< Bit field size in bits for FTM_FMS_WPEN. */

/*! @brief Read current value of the FTM_FMS_WPEN field. */
#define BR_FTM_FMS_WPEN(x)   (HW_FTM_FMS(x).B.WPEN)

/*! @brief Format value for bitfield FTM_FMS_WPEN. */
#define BF_FTM_FMS_WPEN(v)   ((uint32_t)((uint32_t)(v) << BP_FTM_FMS_WPEN) & BM_FTM_FMS_WPEN)

/*! @brief Set the WPEN field to a new value. */
#define BW_FTM_FMS_WPEN(x, v) (HW_FTM_FMS_WR(x, (HW_FTM_FMS_RD(x) & ~BM_FTM_FMS_WPEN) | BF_FTM_FMS_WPEN(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_FILTER - Input Capture Filter Control
 ******************************************************************************/

/*!
 * @brief HW_FTM_FILTER - Input Capture Filter Control (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register selects the filter value for the inputs of channels. Channels
 * 4, 5, 6 and 7 do not have an input filter. Writing to the FILTER register has
 * immediate effect and must be done only when the channels 0, 1, 2, and 3 are not
 * in input modes. Failure to do this could result in a missing valid signal.
 */
typedef union _hw_ftm_filter
{
    uint32_t U;
    struct _hw_ftm_filter_bitfields
    {
        uint32_t CH0FVAL : 4;          /*!< [3:0] Channel 0 Input Filter */
        uint32_t CH1FVAL : 4;          /*!< [7:4] Channel 1 Input Filter */
        uint32_t CH2FVAL : 4;          /*!< [11:8] Channel 2 Input Filter */
        uint32_t CH3FVAL : 4;          /*!< [15:12] Channel 3 Input Filter */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_ftm_filter_t;

/*!
 * @name Constants and macros for entire FTM_FILTER register
 */
/*@{*/
#define HW_FTM_FILTER_ADDR(x)    ((uintptr_t)(x) + 0x78U)

#define HW_FTM_FILTER(x)         (*(__IO hw_ftm_filter_t *) HW_FTM_FILTER_ADDR(x))
#define HW_FTM_FILTER_RD(x)      (HW_FTM_FILTER(x).U)
#define HW_FTM_FILTER_WR(x, v)   (HW_FTM_FILTER(x).U = (v))
#define HW_FTM_FILTER_SET(x, v)  (HW_FTM_FILTER_WR(x, HW_FTM_FILTER_RD(x) |  (v)))
#define HW_FTM_FILTER_CLR(x, v)  (HW_FTM_FILTER_WR(x, HW_FTM_FILTER_RD(x) & ~(v)))
#define HW_FTM_FILTER_TOG(x, v)  (HW_FTM_FILTER_WR(x, HW_FTM_FILTER_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_FILTER bitfields
 */

/*!
 * @name Register FTM_FILTER, field CH0FVAL[3:0] (RW)
 *
 * Selects the filter value for the channel input. The filter is disabled when
 * the value is zero.
 */
/*@{*/
#define BP_FTM_FILTER_CH0FVAL (0U)         /*!< Bit position for FTM_FILTER_CH0FVAL. */
#define BM_FTM_FILTER_CH0FVAL (0x0000000FU) /*!< Bit mask for FTM_FILTER_CH0FVAL. */
#define BS_FTM_FILTER_CH0FVAL (4U)         /*!< Bit field size in bits for FTM_FILTER_CH0FVAL. */

/*! @brief Read current value of the FTM_FILTER_CH0FVAL field. */
#define BR_FTM_FILTER_CH0FVAL(x) (HW_FTM_FILTER(x).B.CH0FVAL)

/*! @brief Format value for bitfield FTM_FILTER_CH0FVAL. */
#define BF_FTM_FILTER_CH0FVAL(v) ((uint32_t)((uint32_t)(v) << BP_FTM_FILTER_CH0FVAL) & BM_FTM_FILTER_CH0FVAL)

/*! @brief Set the CH0FVAL field to a new value. */
#define BW_FTM_FILTER_CH0FVAL(x, v) (HW_FTM_FILTER_WR(x, (HW_FTM_FILTER_RD(x) & ~BM_FTM_FILTER_CH0FVAL) | BF_FTM_FILTER_CH0FVAL(v)))
/*@}*/

/*!
 * @name Register FTM_FILTER, field CH1FVAL[7:4] (RW)
 *
 * Selects the filter value for the channel input. The filter is disabled when
 * the value is zero.
 */
/*@{*/
#define BP_FTM_FILTER_CH1FVAL (4U)         /*!< Bit position for FTM_FILTER_CH1FVAL. */
#define BM_FTM_FILTER_CH1FVAL (0x000000F0U) /*!< Bit mask for FTM_FILTER_CH1FVAL. */
#define BS_FTM_FILTER_CH1FVAL (4U)         /*!< Bit field size in bits for FTM_FILTER_CH1FVAL. */

/*! @brief Read current value of the FTM_FILTER_CH1FVAL field. */
#define BR_FTM_FILTER_CH1FVAL(x) (HW_FTM_FILTER(x).B.CH1FVAL)

/*! @brief Format value for bitfield FTM_FILTER_CH1FVAL. */
#define BF_FTM_FILTER_CH1FVAL(v) ((uint32_t)((uint32_t)(v) << BP_FTM_FILTER_CH1FVAL) & BM_FTM_FILTER_CH1FVAL)

/*! @brief Set the CH1FVAL field to a new value. */
#define BW_FTM_FILTER_CH1FVAL(x, v) (HW_FTM_FILTER_WR(x, (HW_FTM_FILTER_RD(x) & ~BM_FTM_FILTER_CH1FVAL) | BF_FTM_FILTER_CH1FVAL(v)))
/*@}*/

/*!
 * @name Register FTM_FILTER, field CH2FVAL[11:8] (RW)
 *
 * Selects the filter value for the channel input. The filter is disabled when
 * the value is zero.
 */
/*@{*/
#define BP_FTM_FILTER_CH2FVAL (8U)         /*!< Bit position for FTM_FILTER_CH2FVAL. */
#define BM_FTM_FILTER_CH2FVAL (0x00000F00U) /*!< Bit mask for FTM_FILTER_CH2FVAL. */
#define BS_FTM_FILTER_CH2FVAL (4U)         /*!< Bit field size in bits for FTM_FILTER_CH2FVAL. */

/*! @brief Read current value of the FTM_FILTER_CH2FVAL field. */
#define BR_FTM_FILTER_CH2FVAL(x) (HW_FTM_FILTER(x).B.CH2FVAL)

/*! @brief Format value for bitfield FTM_FILTER_CH2FVAL. */
#define BF_FTM_FILTER_CH2FVAL(v) ((uint32_t)((uint32_t)(v) << BP_FTM_FILTER_CH2FVAL) & BM_FTM_FILTER_CH2FVAL)

/*! @brief Set the CH2FVAL field to a new value. */
#define BW_FTM_FILTER_CH2FVAL(x, v) (HW_FTM_FILTER_WR(x, (HW_FTM_FILTER_RD(x) & ~BM_FTM_FILTER_CH2FVAL) | BF_FTM_FILTER_CH2FVAL(v)))
/*@}*/

/*!
 * @name Register FTM_FILTER, field CH3FVAL[15:12] (RW)
 *
 * Selects the filter value for the channel input. The filter is disabled when
 * the value is zero.
 */
/*@{*/
#define BP_FTM_FILTER_CH3FVAL (12U)        /*!< Bit position for FTM_FILTER_CH3FVAL. */
#define BM_FTM_FILTER_CH3FVAL (0x0000F000U) /*!< Bit mask for FTM_FILTER_CH3FVAL. */
#define BS_FTM_FILTER_CH3FVAL (4U)         /*!< Bit field size in bits for FTM_FILTER_CH3FVAL. */

/*! @brief Read current value of the FTM_FILTER_CH3FVAL field. */
#define BR_FTM_FILTER_CH3FVAL(x) (HW_FTM_FILTER(x).B.CH3FVAL)

/*! @brief Format value for bitfield FTM_FILTER_CH3FVAL. */
#define BF_FTM_FILTER_CH3FVAL(v) ((uint32_t)((uint32_t)(v) << BP_FTM_FILTER_CH3FVAL) & BM_FTM_FILTER_CH3FVAL)

/*! @brief Set the CH3FVAL field to a new value. */
#define BW_FTM_FILTER_CH3FVAL(x, v) (HW_FTM_FILTER_WR(x, (HW_FTM_FILTER_RD(x) & ~BM_FTM_FILTER_CH3FVAL) | BF_FTM_FILTER_CH3FVAL(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_QDCTRL - Quadrature Decoder Control And Status
 ******************************************************************************/

/*!
 * @brief HW_FTM_QDCTRL - Quadrature Decoder Control And Status (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register has the control and status bits for the Quadrature Decoder mode.
 */
typedef union _hw_ftm_qdctrl
{
    uint32_t U;
    struct _hw_ftm_qdctrl_bitfields
    {
        uint32_t QUADEN : 1;           /*!< [0] Quadrature Decoder Mode Enable */
        uint32_t TOFDIR : 1;           /*!< [1] Timer Overflow Direction In Quadrature
                                        * Decoder Mode */
        uint32_t QUADIR : 1;           /*!< [2] FTM Counter Direction In Quadrature
                                        * Decoder Mode */
        uint32_t QUADMODE : 1;         /*!< [3] Quadrature Decoder Mode */
        uint32_t PHBPOL : 1;           /*!< [4] Phase B Input Polarity */
        uint32_t PHAPOL : 1;           /*!< [5] Phase A Input Polarity */
        uint32_t PHBFLTREN : 1;        /*!< [6] Phase B Input Filter Enable */
        uint32_t PHAFLTREN : 1;        /*!< [7] Phase A Input Filter Enable */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_ftm_qdctrl_t;

/*!
 * @name Constants and macros for entire FTM_QDCTRL register
 */
/*@{*/
#define HW_FTM_QDCTRL_ADDR(x)    ((uintptr_t)(x) + 0x80U)

#define HW_FTM_QDCTRL(x)         (*(__IO hw_ftm_qdctrl_t *) HW_FTM_QDCTRL_ADDR(x))
#define HW_FTM_QDCTRL_RD(x)      (HW_FTM_QDCTRL(x).U)
#define HW_FTM_QDCTRL_WR(x, v)   (HW_FTM_QDCTRL(x).U = (v))
#define HW_FTM_QDCTRL_SET(x, v)  (HW_FTM_QDCTRL_WR(x, HW_FTM_QDCTRL_RD(x) |  (v)))
#define HW_FTM_QDCTRL_CLR(x, v)  (HW_FTM_QDCTRL_WR(x, HW_FTM_QDCTRL_RD(x) & ~(v)))
#define HW_FTM_QDCTRL_TOG(x, v)  (HW_FTM_QDCTRL_WR(x, HW_FTM_QDCTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_QDCTRL bitfields
 */

/*!
 * @name Register FTM_QDCTRL, field QUADEN[0] (RW)
 *
 * Enables the Quadrature Decoder mode. In this mode, the phase A and B input
 * signals control the FTM counter direction. The Quadrature Decoder mode has
 * precedence over the other modes. See . This field is write protected. It can be
 * written only when MODE[WPDIS] = 1.
 *
 * Values:
 * - 0 - Quadrature Decoder mode is disabled.
 * - 1 - Quadrature Decoder mode is enabled.
 */
/*@{*/
#define BP_FTM_QDCTRL_QUADEN (0U)          /*!< Bit position for FTM_QDCTRL_QUADEN. */
#define BM_FTM_QDCTRL_QUADEN (0x00000001U) /*!< Bit mask for FTM_QDCTRL_QUADEN. */
#define BS_FTM_QDCTRL_QUADEN (1U)          /*!< Bit field size in bits for FTM_QDCTRL_QUADEN. */

/*! @brief Read current value of the FTM_QDCTRL_QUADEN field. */
#define BR_FTM_QDCTRL_QUADEN(x) (HW_FTM_QDCTRL(x).B.QUADEN)

/*! @brief Format value for bitfield FTM_QDCTRL_QUADEN. */
#define BF_FTM_QDCTRL_QUADEN(v) ((uint32_t)((uint32_t)(v) << BP_FTM_QDCTRL_QUADEN) & BM_FTM_QDCTRL_QUADEN)

/*! @brief Set the QUADEN field to a new value. */
#define BW_FTM_QDCTRL_QUADEN(x, v) (HW_FTM_QDCTRL_WR(x, (HW_FTM_QDCTRL_RD(x) & ~BM_FTM_QDCTRL_QUADEN) | BF_FTM_QDCTRL_QUADEN(v)))
/*@}*/

/*!
 * @name Register FTM_QDCTRL, field TOFDIR[1] (RO)
 *
 * Indicates if the TOF bit was set on the top or the bottom of counting.
 *
 * Values:
 * - 0 - TOF bit was set on the bottom of counting. There was an FTM counter
 *     decrement and FTM counter changes from its minimum value (CNTIN register) to
 *     its maximum value (MOD register).
 * - 1 - TOF bit was set on the top of counting. There was an FTM counter
 *     increment and FTM counter changes from its maximum value (MOD register) to its
 *     minimum value (CNTIN register).
 */
/*@{*/
#define BP_FTM_QDCTRL_TOFDIR (1U)          /*!< Bit position for FTM_QDCTRL_TOFDIR. */
#define BM_FTM_QDCTRL_TOFDIR (0x00000002U) /*!< Bit mask for FTM_QDCTRL_TOFDIR. */
#define BS_FTM_QDCTRL_TOFDIR (1U)          /*!< Bit field size in bits for FTM_QDCTRL_TOFDIR. */

/*! @brief Read current value of the FTM_QDCTRL_TOFDIR field. */
#define BR_FTM_QDCTRL_TOFDIR(x) (HW_FTM_QDCTRL(x).B.TOFDIR)
/*@}*/

/*!
 * @name Register FTM_QDCTRL, field QUADIR[2] (RO)
 *
 * Indicates the counting direction.
 *
 * Values:
 * - 0 - Counting direction is decreasing (FTM counter decrement).
 * - 1 - Counting direction is increasing (FTM counter increment).
 */
/*@{*/
#define BP_FTM_QDCTRL_QUADIR (2U)          /*!< Bit position for FTM_QDCTRL_QUADIR. */
#define BM_FTM_QDCTRL_QUADIR (0x00000004U) /*!< Bit mask for FTM_QDCTRL_QUADIR. */
#define BS_FTM_QDCTRL_QUADIR (1U)          /*!< Bit field size in bits for FTM_QDCTRL_QUADIR. */

/*! @brief Read current value of the FTM_QDCTRL_QUADIR field. */
#define BR_FTM_QDCTRL_QUADIR(x) (HW_FTM_QDCTRL(x).B.QUADIR)
/*@}*/

/*!
 * @name Register FTM_QDCTRL, field QUADMODE[3] (RW)
 *
 * Selects the encoding mode used in the Quadrature Decoder mode.
 *
 * Values:
 * - 0 - Phase A and phase B encoding mode.
 * - 1 - Count and direction encoding mode.
 */
/*@{*/
#define BP_FTM_QDCTRL_QUADMODE (3U)        /*!< Bit position for FTM_QDCTRL_QUADMODE. */
#define BM_FTM_QDCTRL_QUADMODE (0x00000008U) /*!< Bit mask for FTM_QDCTRL_QUADMODE. */
#define BS_FTM_QDCTRL_QUADMODE (1U)        /*!< Bit field size in bits for FTM_QDCTRL_QUADMODE. */

/*! @brief Read current value of the FTM_QDCTRL_QUADMODE field. */
#define BR_FTM_QDCTRL_QUADMODE(x) (HW_FTM_QDCTRL(x).B.QUADMODE)

/*! @brief Format value for bitfield FTM_QDCTRL_QUADMODE. */
#define BF_FTM_QDCTRL_QUADMODE(v) ((uint32_t)((uint32_t)(v) << BP_FTM_QDCTRL_QUADMODE) & BM_FTM_QDCTRL_QUADMODE)

/*! @brief Set the QUADMODE field to a new value. */
#define BW_FTM_QDCTRL_QUADMODE(x, v) (HW_FTM_QDCTRL_WR(x, (HW_FTM_QDCTRL_RD(x) & ~BM_FTM_QDCTRL_QUADMODE) | BF_FTM_QDCTRL_QUADMODE(v)))
/*@}*/

/*!
 * @name Register FTM_QDCTRL, field PHBPOL[4] (RW)
 *
 * Selects the polarity for the quadrature decoder phase B input.
 *
 * Values:
 * - 0 - Normal polarity. Phase B input signal is not inverted before
 *     identifying the rising and falling edges of this signal.
 * - 1 - Inverted polarity. Phase B input signal is inverted before identifying
 *     the rising and falling edges of this signal.
 */
/*@{*/
#define BP_FTM_QDCTRL_PHBPOL (4U)          /*!< Bit position for FTM_QDCTRL_PHBPOL. */
#define BM_FTM_QDCTRL_PHBPOL (0x00000010U) /*!< Bit mask for FTM_QDCTRL_PHBPOL. */
#define BS_FTM_QDCTRL_PHBPOL (1U)          /*!< Bit field size in bits for FTM_QDCTRL_PHBPOL. */

/*! @brief Read current value of the FTM_QDCTRL_PHBPOL field. */
#define BR_FTM_QDCTRL_PHBPOL(x) (HW_FTM_QDCTRL(x).B.PHBPOL)

/*! @brief Format value for bitfield FTM_QDCTRL_PHBPOL. */
#define BF_FTM_QDCTRL_PHBPOL(v) ((uint32_t)((uint32_t)(v) << BP_FTM_QDCTRL_PHBPOL) & BM_FTM_QDCTRL_PHBPOL)

/*! @brief Set the PHBPOL field to a new value. */
#define BW_FTM_QDCTRL_PHBPOL(x, v) (HW_FTM_QDCTRL_WR(x, (HW_FTM_QDCTRL_RD(x) & ~BM_FTM_QDCTRL_PHBPOL) | BF_FTM_QDCTRL_PHBPOL(v)))
/*@}*/

/*!
 * @name Register FTM_QDCTRL, field PHAPOL[5] (RW)
 *
 * Selects the polarity for the quadrature decoder phase A input.
 *
 * Values:
 * - 0 - Normal polarity. Phase A input signal is not inverted before
 *     identifying the rising and falling edges of this signal.
 * - 1 - Inverted polarity. Phase A input signal is inverted before identifying
 *     the rising and falling edges of this signal.
 */
/*@{*/
#define BP_FTM_QDCTRL_PHAPOL (5U)          /*!< Bit position for FTM_QDCTRL_PHAPOL. */
#define BM_FTM_QDCTRL_PHAPOL (0x00000020U) /*!< Bit mask for FTM_QDCTRL_PHAPOL. */
#define BS_FTM_QDCTRL_PHAPOL (1U)          /*!< Bit field size in bits for FTM_QDCTRL_PHAPOL. */

/*! @brief Read current value of the FTM_QDCTRL_PHAPOL field. */
#define BR_FTM_QDCTRL_PHAPOL(x) (HW_FTM_QDCTRL(x).B.PHAPOL)

/*! @brief Format value for bitfield FTM_QDCTRL_PHAPOL. */
#define BF_FTM_QDCTRL_PHAPOL(v) ((uint32_t)((uint32_t)(v) << BP_FTM_QDCTRL_PHAPOL) & BM_FTM_QDCTRL_PHAPOL)

/*! @brief Set the PHAPOL field to a new value. */
#define BW_FTM_QDCTRL_PHAPOL(x, v) (HW_FTM_QDCTRL_WR(x, (HW_FTM_QDCTRL_RD(x) & ~BM_FTM_QDCTRL_PHAPOL) | BF_FTM_QDCTRL_PHAPOL(v)))
/*@}*/

/*!
 * @name Register FTM_QDCTRL, field PHBFLTREN[6] (RW)
 *
 * Enables the filter for the quadrature decoder phase B input. The filter value
 * for the phase B input is defined by the CH1FVAL field of FILTER. The phase B
 * filter is also disabled when CH1FVAL is zero.
 *
 * Values:
 * - 0 - Phase B input filter is disabled.
 * - 1 - Phase B input filter is enabled.
 */
/*@{*/
#define BP_FTM_QDCTRL_PHBFLTREN (6U)       /*!< Bit position for FTM_QDCTRL_PHBFLTREN. */
#define BM_FTM_QDCTRL_PHBFLTREN (0x00000040U) /*!< Bit mask for FTM_QDCTRL_PHBFLTREN. */
#define BS_FTM_QDCTRL_PHBFLTREN (1U)       /*!< Bit field size in bits for FTM_QDCTRL_PHBFLTREN. */

/*! @brief Read current value of the FTM_QDCTRL_PHBFLTREN field. */
#define BR_FTM_QDCTRL_PHBFLTREN(x) (HW_FTM_QDCTRL(x).B.PHBFLTREN)

/*! @brief Format value for bitfield FTM_QDCTRL_PHBFLTREN. */
#define BF_FTM_QDCTRL_PHBFLTREN(v) ((uint32_t)((uint32_t)(v) << BP_FTM_QDCTRL_PHBFLTREN) & BM_FTM_QDCTRL_PHBFLTREN)

/*! @brief Set the PHBFLTREN field to a new value. */
#define BW_FTM_QDCTRL_PHBFLTREN(x, v) (HW_FTM_QDCTRL_WR(x, (HW_FTM_QDCTRL_RD(x) & ~BM_FTM_QDCTRL_PHBFLTREN) | BF_FTM_QDCTRL_PHBFLTREN(v)))
/*@}*/

/*!
 * @name Register FTM_QDCTRL, field PHAFLTREN[7] (RW)
 *
 * Enables the filter for the quadrature decoder phase A input. The filter value
 * for the phase A input is defined by the CH0FVAL field of FILTER. The phase A
 * filter is also disabled when CH0FVAL is zero.
 *
 * Values:
 * - 0 - Phase A input filter is disabled.
 * - 1 - Phase A input filter is enabled.
 */
/*@{*/
#define BP_FTM_QDCTRL_PHAFLTREN (7U)       /*!< Bit position for FTM_QDCTRL_PHAFLTREN. */
#define BM_FTM_QDCTRL_PHAFLTREN (0x00000080U) /*!< Bit mask for FTM_QDCTRL_PHAFLTREN. */
#define BS_FTM_QDCTRL_PHAFLTREN (1U)       /*!< Bit field size in bits for FTM_QDCTRL_PHAFLTREN. */

/*! @brief Read current value of the FTM_QDCTRL_PHAFLTREN field. */
#define BR_FTM_QDCTRL_PHAFLTREN(x) (HW_FTM_QDCTRL(x).B.PHAFLTREN)

/*! @brief Format value for bitfield FTM_QDCTRL_PHAFLTREN. */
#define BF_FTM_QDCTRL_PHAFLTREN(v) ((uint32_t)((uint32_t)(v) << BP_FTM_QDCTRL_PHAFLTREN) & BM_FTM_QDCTRL_PHAFLTREN)

/*! @brief Set the PHAFLTREN field to a new value. */
#define BW_FTM_QDCTRL_PHAFLTREN(x, v) (HW_FTM_QDCTRL_WR(x, (HW_FTM_QDCTRL_RD(x) & ~BM_FTM_QDCTRL_PHAFLTREN) | BF_FTM_QDCTRL_PHAFLTREN(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_CONF - Configuration
 ******************************************************************************/

/*!
 * @brief HW_FTM_CONF - Configuration (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register selects the number of times that the FTM counter overflow
 * should occur before the TOF bit to be set, the FTM behavior in BDM modes, the use
 * of an external global time base, and the global time base signal generation.
 */
typedef union _hw_ftm_conf
{
    uint32_t U;
    struct _hw_ftm_conf_bitfields
    {
        uint32_t NUMTOF : 5;           /*!< [4:0] TOF Frequency */
        uint32_t RESERVED0 : 1;        /*!< [5]  */
        uint32_t BDMMODE : 2;          /*!< [7:6] BDM Mode */
        uint32_t RESERVED1 : 1;        /*!< [8]  */
        uint32_t GTBEEN : 1;           /*!< [9] Global Time Base Enable */
        uint32_t GTBEOUT : 1;          /*!< [10] Global Time Base Output */
        uint32_t RESERVED2 : 21;       /*!< [31:11]  */
    } B;
} hw_ftm_conf_t;

/*!
 * @name Constants and macros for entire FTM_CONF register
 */
/*@{*/
#define HW_FTM_CONF_ADDR(x)      ((uintptr_t)(x) + 0x84U)

#define HW_FTM_CONF(x)           (*(__IO hw_ftm_conf_t *) HW_FTM_CONF_ADDR(x))
#define HW_FTM_CONF_RD(x)        (HW_FTM_CONF(x).U)
#define HW_FTM_CONF_WR(x, v)     (HW_FTM_CONF(x).U = (v))
#define HW_FTM_CONF_SET(x, v)    (HW_FTM_CONF_WR(x, HW_FTM_CONF_RD(x) |  (v)))
#define HW_FTM_CONF_CLR(x, v)    (HW_FTM_CONF_WR(x, HW_FTM_CONF_RD(x) & ~(v)))
#define HW_FTM_CONF_TOG(x, v)    (HW_FTM_CONF_WR(x, HW_FTM_CONF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_CONF bitfields
 */

/*!
 * @name Register FTM_CONF, field NUMTOF[4:0] (RW)
 *
 * Selects the ratio between the number of counter overflows to the number of
 * times the TOF bit is set. NUMTOF = 0: The TOF bit is set for each counter
 * overflow. NUMTOF = 1: The TOF bit is set for the first counter overflow but not for
 * the next overflow. NUMTOF = 2: The TOF bit is set for the first counter
 * overflow but not for the next 2 overflows. NUMTOF = 3: The TOF bit is set for the
 * first counter overflow but not for the next 3 overflows. This pattern continues
 * up to a maximum of 31.
 */
/*@{*/
#define BP_FTM_CONF_NUMTOF   (0U)          /*!< Bit position for FTM_CONF_NUMTOF. */
#define BM_FTM_CONF_NUMTOF   (0x0000001FU) /*!< Bit mask for FTM_CONF_NUMTOF. */
#define BS_FTM_CONF_NUMTOF   (5U)          /*!< Bit field size in bits for FTM_CONF_NUMTOF. */

/*! @brief Read current value of the FTM_CONF_NUMTOF field. */
#define BR_FTM_CONF_NUMTOF(x) (HW_FTM_CONF(x).B.NUMTOF)

/*! @brief Format value for bitfield FTM_CONF_NUMTOF. */
#define BF_FTM_CONF_NUMTOF(v) ((uint32_t)((uint32_t)(v) << BP_FTM_CONF_NUMTOF) & BM_FTM_CONF_NUMTOF)

/*! @brief Set the NUMTOF field to a new value. */
#define BW_FTM_CONF_NUMTOF(x, v) (HW_FTM_CONF_WR(x, (HW_FTM_CONF_RD(x) & ~BM_FTM_CONF_NUMTOF) | BF_FTM_CONF_NUMTOF(v)))
/*@}*/

/*!
 * @name Register FTM_CONF, field BDMMODE[7:6] (RW)
 *
 * Selects the FTM behavior in BDM mode. See BDM mode.
 */
/*@{*/
#define BP_FTM_CONF_BDMMODE  (6U)          /*!< Bit position for FTM_CONF_BDMMODE. */
#define BM_FTM_CONF_BDMMODE  (0x000000C0U) /*!< Bit mask for FTM_CONF_BDMMODE. */
#define BS_FTM_CONF_BDMMODE  (2U)          /*!< Bit field size in bits for FTM_CONF_BDMMODE. */

/*! @brief Read current value of the FTM_CONF_BDMMODE field. */
#define BR_FTM_CONF_BDMMODE(x) (HW_FTM_CONF(x).B.BDMMODE)

/*! @brief Format value for bitfield FTM_CONF_BDMMODE. */
#define BF_FTM_CONF_BDMMODE(v) ((uint32_t)((uint32_t)(v) << BP_FTM_CONF_BDMMODE) & BM_FTM_CONF_BDMMODE)

/*! @brief Set the BDMMODE field to a new value. */
#define BW_FTM_CONF_BDMMODE(x, v) (HW_FTM_CONF_WR(x, (HW_FTM_CONF_RD(x) & ~BM_FTM_CONF_BDMMODE) | BF_FTM_CONF_BDMMODE(v)))
/*@}*/

/*!
 * @name Register FTM_CONF, field GTBEEN[9] (RW)
 *
 * Configures the FTM to use an external global time base signal that is
 * generated by another FTM.
 *
 * Values:
 * - 0 - Use of an external global time base is disabled.
 * - 1 - Use of an external global time base is enabled.
 */
/*@{*/
#define BP_FTM_CONF_GTBEEN   (9U)          /*!< Bit position for FTM_CONF_GTBEEN. */
#define BM_FTM_CONF_GTBEEN   (0x00000200U) /*!< Bit mask for FTM_CONF_GTBEEN. */
#define BS_FTM_CONF_GTBEEN   (1U)          /*!< Bit field size in bits for FTM_CONF_GTBEEN. */

/*! @brief Read current value of the FTM_CONF_GTBEEN field. */
#define BR_FTM_CONF_GTBEEN(x) (HW_FTM_CONF(x).B.GTBEEN)

/*! @brief Format value for bitfield FTM_CONF_GTBEEN. */
#define BF_FTM_CONF_GTBEEN(v) ((uint32_t)((uint32_t)(v) << BP_FTM_CONF_GTBEEN) & BM_FTM_CONF_GTBEEN)

/*! @brief Set the GTBEEN field to a new value. */
#define BW_FTM_CONF_GTBEEN(x, v) (HW_FTM_CONF_WR(x, (HW_FTM_CONF_RD(x) & ~BM_FTM_CONF_GTBEEN) | BF_FTM_CONF_GTBEEN(v)))
/*@}*/

/*!
 * @name Register FTM_CONF, field GTBEOUT[10] (RW)
 *
 * Enables the global time base signal generation to other FTMs.
 *
 * Values:
 * - 0 - A global time base signal generation is disabled.
 * - 1 - A global time base signal generation is enabled.
 */
/*@{*/
#define BP_FTM_CONF_GTBEOUT  (10U)         /*!< Bit position for FTM_CONF_GTBEOUT. */
#define BM_FTM_CONF_GTBEOUT  (0x00000400U) /*!< Bit mask for FTM_CONF_GTBEOUT. */
#define BS_FTM_CONF_GTBEOUT  (1U)          /*!< Bit field size in bits for FTM_CONF_GTBEOUT. */

/*! @brief Read current value of the FTM_CONF_GTBEOUT field. */
#define BR_FTM_CONF_GTBEOUT(x) (HW_FTM_CONF(x).B.GTBEOUT)

/*! @brief Format value for bitfield FTM_CONF_GTBEOUT. */
#define BF_FTM_CONF_GTBEOUT(v) ((uint32_t)((uint32_t)(v) << BP_FTM_CONF_GTBEOUT) & BM_FTM_CONF_GTBEOUT)

/*! @brief Set the GTBEOUT field to a new value. */
#define BW_FTM_CONF_GTBEOUT(x, v) (HW_FTM_CONF_WR(x, (HW_FTM_CONF_RD(x) & ~BM_FTM_CONF_GTBEOUT) | BF_FTM_CONF_GTBEOUT(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_SYNCONF - Synchronization Configuration
 ******************************************************************************/

/*!
 * @brief HW_FTM_SYNCONF - Synchronization Configuration (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register selects the PWM synchronization configuration, SWOCTRL, INVCTRL
 * and CNTIN registers synchronization, if FTM clears the TRIGj bit, where j =
 * 0, 1, 2, when the hardware trigger j is detected.
 */
typedef union _hw_ftm_synconf
{
    uint32_t U;
    struct _hw_ftm_synconf_bitfields
    {
        uint32_t HWTRIGMODE : 1;       /*!< [0] Hardware Trigger Mode */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t CNTINC : 1;           /*!< [2] CNTIN Register Synchronization */
        uint32_t RESERVED1 : 1;        /*!< [3]  */
        uint32_t INVC : 1;             /*!< [4] INVCTRL Register Synchronization */
        uint32_t SWOC : 1;             /*!< [5] SWOCTRL Register Synchronization */
        uint32_t RESERVED2 : 1;        /*!< [6]  */
        uint32_t SYNCMODE : 1;         /*!< [7] Synchronization Mode */
        uint32_t SWRSTCNT : 1;         /*!< [8]  */
        uint32_t SWWRBUF : 1;          /*!< [9]  */
        uint32_t SWOM : 1;             /*!< [10]  */
        uint32_t SWINVC : 1;           /*!< [11]  */
        uint32_t SWSOC : 1;            /*!< [12]  */
        uint32_t RESERVED3 : 3;        /*!< [15:13]  */
        uint32_t HWRSTCNT : 1;         /*!< [16]  */
        uint32_t HWWRBUF : 1;          /*!< [17]  */
        uint32_t HWOM : 1;             /*!< [18]  */
        uint32_t HWINVC : 1;           /*!< [19]  */
        uint32_t HWSOC : 1;            /*!< [20]  */
        uint32_t RESERVED4 : 11;       /*!< [31:21]  */
    } B;
} hw_ftm_synconf_t;

/*!
 * @name Constants and macros for entire FTM_SYNCONF register
 */
/*@{*/
#define HW_FTM_SYNCONF_ADDR(x)   ((uintptr_t)(x) + 0x8CU)

#define HW_FTM_SYNCONF(x)        (*(__IO hw_ftm_synconf_t *) HW_FTM_SYNCONF_ADDR(x))
#define HW_FTM_SYNCONF_RD(x)     (HW_FTM_SYNCONF(x).U)
#define HW_FTM_SYNCONF_WR(x, v)  (HW_FTM_SYNCONF(x).U = (v))
#define HW_FTM_SYNCONF_SET(x, v) (HW_FTM_SYNCONF_WR(x, HW_FTM_SYNCONF_RD(x) |  (v)))
#define HW_FTM_SYNCONF_CLR(x, v) (HW_FTM_SYNCONF_WR(x, HW_FTM_SYNCONF_RD(x) & ~(v)))
#define HW_FTM_SYNCONF_TOG(x, v) (HW_FTM_SYNCONF_WR(x, HW_FTM_SYNCONF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_SYNCONF bitfields
 */

/*!
 * @name Register FTM_SYNCONF, field HWTRIGMODE[0] (RW)
 *
 * Values:
 * - 0 - FTM clears the TRIGj bit when the hardware trigger j is detected, where
 *     j = 0, 1,2.
 * - 1 - FTM does not clear the TRIGj bit when the hardware trigger j is
 *     detected, where j = 0, 1,2.
 */
/*@{*/
#define BP_FTM_SYNCONF_HWTRIGMODE (0U)     /*!< Bit position for FTM_SYNCONF_HWTRIGMODE. */
#define BM_FTM_SYNCONF_HWTRIGMODE (0x00000001U) /*!< Bit mask for FTM_SYNCONF_HWTRIGMODE. */
#define BS_FTM_SYNCONF_HWTRIGMODE (1U)     /*!< Bit field size in bits for FTM_SYNCONF_HWTRIGMODE. */

/*! @brief Read current value of the FTM_SYNCONF_HWTRIGMODE field. */
#define BR_FTM_SYNCONF_HWTRIGMODE(x) (HW_FTM_SYNCONF(x).B.HWTRIGMODE)

/*! @brief Format value for bitfield FTM_SYNCONF_HWTRIGMODE. */
#define BF_FTM_SYNCONF_HWTRIGMODE(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNCONF_HWTRIGMODE) & BM_FTM_SYNCONF_HWTRIGMODE)

/*! @brief Set the HWTRIGMODE field to a new value. */
#define BW_FTM_SYNCONF_HWTRIGMODE(x, v) (HW_FTM_SYNCONF_WR(x, (HW_FTM_SYNCONF_RD(x) & ~BM_FTM_SYNCONF_HWTRIGMODE) | BF_FTM_SYNCONF_HWTRIGMODE(v)))
/*@}*/

/*!
 * @name Register FTM_SYNCONF, field CNTINC[2] (RW)
 *
 * Values:
 * - 0 - CNTIN register is updated with its buffer value at all rising edges of
 *     system clock.
 * - 1 - CNTIN register is updated with its buffer value by the PWM
 *     synchronization.
 */
/*@{*/
#define BP_FTM_SYNCONF_CNTINC (2U)         /*!< Bit position for FTM_SYNCONF_CNTINC. */
#define BM_FTM_SYNCONF_CNTINC (0x00000004U) /*!< Bit mask for FTM_SYNCONF_CNTINC. */
#define BS_FTM_SYNCONF_CNTINC (1U)         /*!< Bit field size in bits for FTM_SYNCONF_CNTINC. */

/*! @brief Read current value of the FTM_SYNCONF_CNTINC field. */
#define BR_FTM_SYNCONF_CNTINC(x) (HW_FTM_SYNCONF(x).B.CNTINC)

/*! @brief Format value for bitfield FTM_SYNCONF_CNTINC. */
#define BF_FTM_SYNCONF_CNTINC(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNCONF_CNTINC) & BM_FTM_SYNCONF_CNTINC)

/*! @brief Set the CNTINC field to a new value. */
#define BW_FTM_SYNCONF_CNTINC(x, v) (HW_FTM_SYNCONF_WR(x, (HW_FTM_SYNCONF_RD(x) & ~BM_FTM_SYNCONF_CNTINC) | BF_FTM_SYNCONF_CNTINC(v)))
/*@}*/

/*!
 * @name Register FTM_SYNCONF, field INVC[4] (RW)
 *
 * Values:
 * - 0 - INVCTRL register is updated with its buffer value at all rising edges
 *     of system clock.
 * - 1 - INVCTRL register is updated with its buffer value by the PWM
 *     synchronization.
 */
/*@{*/
#define BP_FTM_SYNCONF_INVC  (4U)          /*!< Bit position for FTM_SYNCONF_INVC. */
#define BM_FTM_SYNCONF_INVC  (0x00000010U) /*!< Bit mask for FTM_SYNCONF_INVC. */
#define BS_FTM_SYNCONF_INVC  (1U)          /*!< Bit field size in bits for FTM_SYNCONF_INVC. */

/*! @brief Read current value of the FTM_SYNCONF_INVC field. */
#define BR_FTM_SYNCONF_INVC(x) (HW_FTM_SYNCONF(x).B.INVC)

/*! @brief Format value for bitfield FTM_SYNCONF_INVC. */
#define BF_FTM_SYNCONF_INVC(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNCONF_INVC) & BM_FTM_SYNCONF_INVC)

/*! @brief Set the INVC field to a new value. */
#define BW_FTM_SYNCONF_INVC(x, v) (HW_FTM_SYNCONF_WR(x, (HW_FTM_SYNCONF_RD(x) & ~BM_FTM_SYNCONF_INVC) | BF_FTM_SYNCONF_INVC(v)))
/*@}*/

/*!
 * @name Register FTM_SYNCONF, field SWOC[5] (RW)
 *
 * Values:
 * - 0 - SWOCTRL register is updated with its buffer value at all rising edges
 *     of system clock.
 * - 1 - SWOCTRL register is updated with its buffer value by the PWM
 *     synchronization.
 */
/*@{*/
#define BP_FTM_SYNCONF_SWOC  (5U)          /*!< Bit position for FTM_SYNCONF_SWOC. */
#define BM_FTM_SYNCONF_SWOC  (0x00000020U) /*!< Bit mask for FTM_SYNCONF_SWOC. */
#define BS_FTM_SYNCONF_SWOC  (1U)          /*!< Bit field size in bits for FTM_SYNCONF_SWOC. */

/*! @brief Read current value of the FTM_SYNCONF_SWOC field. */
#define BR_FTM_SYNCONF_SWOC(x) (HW_FTM_SYNCONF(x).B.SWOC)

/*! @brief Format value for bitfield FTM_SYNCONF_SWOC. */
#define BF_FTM_SYNCONF_SWOC(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNCONF_SWOC) & BM_FTM_SYNCONF_SWOC)

/*! @brief Set the SWOC field to a new value. */
#define BW_FTM_SYNCONF_SWOC(x, v) (HW_FTM_SYNCONF_WR(x, (HW_FTM_SYNCONF_RD(x) & ~BM_FTM_SYNCONF_SWOC) | BF_FTM_SYNCONF_SWOC(v)))
/*@}*/

/*!
 * @name Register FTM_SYNCONF, field SYNCMODE[7] (RW)
 *
 * Selects the PWM Synchronization mode.
 *
 * Values:
 * - 0 - Legacy PWM synchronization is selected.
 * - 1 - Enhanced PWM synchronization is selected.
 */
/*@{*/
#define BP_FTM_SYNCONF_SYNCMODE (7U)       /*!< Bit position for FTM_SYNCONF_SYNCMODE. */
#define BM_FTM_SYNCONF_SYNCMODE (0x00000080U) /*!< Bit mask for FTM_SYNCONF_SYNCMODE. */
#define BS_FTM_SYNCONF_SYNCMODE (1U)       /*!< Bit field size in bits for FTM_SYNCONF_SYNCMODE. */

/*! @brief Read current value of the FTM_SYNCONF_SYNCMODE field. */
#define BR_FTM_SYNCONF_SYNCMODE(x) (HW_FTM_SYNCONF(x).B.SYNCMODE)

/*! @brief Format value for bitfield FTM_SYNCONF_SYNCMODE. */
#define BF_FTM_SYNCONF_SYNCMODE(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNCONF_SYNCMODE) & BM_FTM_SYNCONF_SYNCMODE)

/*! @brief Set the SYNCMODE field to a new value. */
#define BW_FTM_SYNCONF_SYNCMODE(x, v) (HW_FTM_SYNCONF_WR(x, (HW_FTM_SYNCONF_RD(x) & ~BM_FTM_SYNCONF_SYNCMODE) | BF_FTM_SYNCONF_SYNCMODE(v)))
/*@}*/

/*!
 * @name Register FTM_SYNCONF, field SWRSTCNT[8] (RW)
 *
 * FTM counter synchronization is activated by the software trigger.
 *
 * Values:
 * - 0 - The software trigger does not activate the FTM counter synchronization.
 * - 1 - The software trigger activates the FTM counter synchronization.
 */
/*@{*/
#define BP_FTM_SYNCONF_SWRSTCNT (8U)       /*!< Bit position for FTM_SYNCONF_SWRSTCNT. */
#define BM_FTM_SYNCONF_SWRSTCNT (0x00000100U) /*!< Bit mask for FTM_SYNCONF_SWRSTCNT. */
#define BS_FTM_SYNCONF_SWRSTCNT (1U)       /*!< Bit field size in bits for FTM_SYNCONF_SWRSTCNT. */

/*! @brief Read current value of the FTM_SYNCONF_SWRSTCNT field. */
#define BR_FTM_SYNCONF_SWRSTCNT(x) (HW_FTM_SYNCONF(x).B.SWRSTCNT)

/*! @brief Format value for bitfield FTM_SYNCONF_SWRSTCNT. */
#define BF_FTM_SYNCONF_SWRSTCNT(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNCONF_SWRSTCNT) & BM_FTM_SYNCONF_SWRSTCNT)

/*! @brief Set the SWRSTCNT field to a new value. */
#define BW_FTM_SYNCONF_SWRSTCNT(x, v) (HW_FTM_SYNCONF_WR(x, (HW_FTM_SYNCONF_RD(x) & ~BM_FTM_SYNCONF_SWRSTCNT) | BF_FTM_SYNCONF_SWRSTCNT(v)))
/*@}*/

/*!
 * @name Register FTM_SYNCONF, field SWWRBUF[9] (RW)
 *
 * MOD, CNTIN, and CV registers synchronization is activated by the software
 * trigger.
 *
 * Values:
 * - 0 - The software trigger does not activate MOD, CNTIN, and CV registers
 *     synchronization.
 * - 1 - The software trigger activates MOD, CNTIN, and CV registers
 *     synchronization.
 */
/*@{*/
#define BP_FTM_SYNCONF_SWWRBUF (9U)        /*!< Bit position for FTM_SYNCONF_SWWRBUF. */
#define BM_FTM_SYNCONF_SWWRBUF (0x00000200U) /*!< Bit mask for FTM_SYNCONF_SWWRBUF. */
#define BS_FTM_SYNCONF_SWWRBUF (1U)        /*!< Bit field size in bits for FTM_SYNCONF_SWWRBUF. */

/*! @brief Read current value of the FTM_SYNCONF_SWWRBUF field. */
#define BR_FTM_SYNCONF_SWWRBUF(x) (HW_FTM_SYNCONF(x).B.SWWRBUF)

/*! @brief Format value for bitfield FTM_SYNCONF_SWWRBUF. */
#define BF_FTM_SYNCONF_SWWRBUF(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNCONF_SWWRBUF) & BM_FTM_SYNCONF_SWWRBUF)

/*! @brief Set the SWWRBUF field to a new value. */
#define BW_FTM_SYNCONF_SWWRBUF(x, v) (HW_FTM_SYNCONF_WR(x, (HW_FTM_SYNCONF_RD(x) & ~BM_FTM_SYNCONF_SWWRBUF) | BF_FTM_SYNCONF_SWWRBUF(v)))
/*@}*/

/*!
 * @name Register FTM_SYNCONF, field SWOM[10] (RW)
 *
 * Output mask synchronization is activated by the software trigger.
 *
 * Values:
 * - 0 - The software trigger does not activate the OUTMASK register
 *     synchronization.
 * - 1 - The software trigger activates the OUTMASK register synchronization.
 */
/*@{*/
#define BP_FTM_SYNCONF_SWOM  (10U)         /*!< Bit position for FTM_SYNCONF_SWOM. */
#define BM_FTM_SYNCONF_SWOM  (0x00000400U) /*!< Bit mask for FTM_SYNCONF_SWOM. */
#define BS_FTM_SYNCONF_SWOM  (1U)          /*!< Bit field size in bits for FTM_SYNCONF_SWOM. */

/*! @brief Read current value of the FTM_SYNCONF_SWOM field. */
#define BR_FTM_SYNCONF_SWOM(x) (HW_FTM_SYNCONF(x).B.SWOM)

/*! @brief Format value for bitfield FTM_SYNCONF_SWOM. */
#define BF_FTM_SYNCONF_SWOM(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNCONF_SWOM) & BM_FTM_SYNCONF_SWOM)

/*! @brief Set the SWOM field to a new value. */
#define BW_FTM_SYNCONF_SWOM(x, v) (HW_FTM_SYNCONF_WR(x, (HW_FTM_SYNCONF_RD(x) & ~BM_FTM_SYNCONF_SWOM) | BF_FTM_SYNCONF_SWOM(v)))
/*@}*/

/*!
 * @name Register FTM_SYNCONF, field SWINVC[11] (RW)
 *
 * Inverting control synchronization is activated by the software trigger.
 *
 * Values:
 * - 0 - The software trigger does not activate the INVCTRL register
 *     synchronization.
 * - 1 - The software trigger activates the INVCTRL register synchronization.
 */
/*@{*/
#define BP_FTM_SYNCONF_SWINVC (11U)        /*!< Bit position for FTM_SYNCONF_SWINVC. */
#define BM_FTM_SYNCONF_SWINVC (0x00000800U) /*!< Bit mask for FTM_SYNCONF_SWINVC. */
#define BS_FTM_SYNCONF_SWINVC (1U)         /*!< Bit field size in bits for FTM_SYNCONF_SWINVC. */

/*! @brief Read current value of the FTM_SYNCONF_SWINVC field. */
#define BR_FTM_SYNCONF_SWINVC(x) (HW_FTM_SYNCONF(x).B.SWINVC)

/*! @brief Format value for bitfield FTM_SYNCONF_SWINVC. */
#define BF_FTM_SYNCONF_SWINVC(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNCONF_SWINVC) & BM_FTM_SYNCONF_SWINVC)

/*! @brief Set the SWINVC field to a new value. */
#define BW_FTM_SYNCONF_SWINVC(x, v) (HW_FTM_SYNCONF_WR(x, (HW_FTM_SYNCONF_RD(x) & ~BM_FTM_SYNCONF_SWINVC) | BF_FTM_SYNCONF_SWINVC(v)))
/*@}*/

/*!
 * @name Register FTM_SYNCONF, field SWSOC[12] (RW)
 *
 * Software output control synchronization is activated by the software trigger.
 *
 * Values:
 * - 0 - The software trigger does not activate the SWOCTRL register
 *     synchronization.
 * - 1 - The software trigger activates the SWOCTRL register synchronization.
 */
/*@{*/
#define BP_FTM_SYNCONF_SWSOC (12U)         /*!< Bit position for FTM_SYNCONF_SWSOC. */
#define BM_FTM_SYNCONF_SWSOC (0x00001000U) /*!< Bit mask for FTM_SYNCONF_SWSOC. */
#define BS_FTM_SYNCONF_SWSOC (1U)          /*!< Bit field size in bits for FTM_SYNCONF_SWSOC. */

/*! @brief Read current value of the FTM_SYNCONF_SWSOC field. */
#define BR_FTM_SYNCONF_SWSOC(x) (HW_FTM_SYNCONF(x).B.SWSOC)

/*! @brief Format value for bitfield FTM_SYNCONF_SWSOC. */
#define BF_FTM_SYNCONF_SWSOC(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNCONF_SWSOC) & BM_FTM_SYNCONF_SWSOC)

/*! @brief Set the SWSOC field to a new value. */
#define BW_FTM_SYNCONF_SWSOC(x, v) (HW_FTM_SYNCONF_WR(x, (HW_FTM_SYNCONF_RD(x) & ~BM_FTM_SYNCONF_SWSOC) | BF_FTM_SYNCONF_SWSOC(v)))
/*@}*/

/*!
 * @name Register FTM_SYNCONF, field HWRSTCNT[16] (RW)
 *
 * FTM counter synchronization is activated by a hardware trigger.
 *
 * Values:
 * - 0 - A hardware trigger does not activate the FTM counter synchronization.
 * - 1 - A hardware trigger activates the FTM counter synchronization.
 */
/*@{*/
#define BP_FTM_SYNCONF_HWRSTCNT (16U)      /*!< Bit position for FTM_SYNCONF_HWRSTCNT. */
#define BM_FTM_SYNCONF_HWRSTCNT (0x00010000U) /*!< Bit mask for FTM_SYNCONF_HWRSTCNT. */
#define BS_FTM_SYNCONF_HWRSTCNT (1U)       /*!< Bit field size in bits for FTM_SYNCONF_HWRSTCNT. */

/*! @brief Read current value of the FTM_SYNCONF_HWRSTCNT field. */
#define BR_FTM_SYNCONF_HWRSTCNT(x) (HW_FTM_SYNCONF(x).B.HWRSTCNT)

/*! @brief Format value for bitfield FTM_SYNCONF_HWRSTCNT. */
#define BF_FTM_SYNCONF_HWRSTCNT(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNCONF_HWRSTCNT) & BM_FTM_SYNCONF_HWRSTCNT)

/*! @brief Set the HWRSTCNT field to a new value. */
#define BW_FTM_SYNCONF_HWRSTCNT(x, v) (HW_FTM_SYNCONF_WR(x, (HW_FTM_SYNCONF_RD(x) & ~BM_FTM_SYNCONF_HWRSTCNT) | BF_FTM_SYNCONF_HWRSTCNT(v)))
/*@}*/

/*!
 * @name Register FTM_SYNCONF, field HWWRBUF[17] (RW)
 *
 * MOD, CNTIN, and CV registers synchronization is activated by a hardware
 * trigger.
 *
 * Values:
 * - 0 - A hardware trigger does not activate MOD, CNTIN, and CV registers
 *     synchronization.
 * - 1 - A hardware trigger activates MOD, CNTIN, and CV registers
 *     synchronization.
 */
/*@{*/
#define BP_FTM_SYNCONF_HWWRBUF (17U)       /*!< Bit position for FTM_SYNCONF_HWWRBUF. */
#define BM_FTM_SYNCONF_HWWRBUF (0x00020000U) /*!< Bit mask for FTM_SYNCONF_HWWRBUF. */
#define BS_FTM_SYNCONF_HWWRBUF (1U)        /*!< Bit field size in bits for FTM_SYNCONF_HWWRBUF. */

/*! @brief Read current value of the FTM_SYNCONF_HWWRBUF field. */
#define BR_FTM_SYNCONF_HWWRBUF(x) (HW_FTM_SYNCONF(x).B.HWWRBUF)

/*! @brief Format value for bitfield FTM_SYNCONF_HWWRBUF. */
#define BF_FTM_SYNCONF_HWWRBUF(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNCONF_HWWRBUF) & BM_FTM_SYNCONF_HWWRBUF)

/*! @brief Set the HWWRBUF field to a new value. */
#define BW_FTM_SYNCONF_HWWRBUF(x, v) (HW_FTM_SYNCONF_WR(x, (HW_FTM_SYNCONF_RD(x) & ~BM_FTM_SYNCONF_HWWRBUF) | BF_FTM_SYNCONF_HWWRBUF(v)))
/*@}*/

/*!
 * @name Register FTM_SYNCONF, field HWOM[18] (RW)
 *
 * Output mask synchronization is activated by a hardware trigger.
 *
 * Values:
 * - 0 - A hardware trigger does not activate the OUTMASK register
 *     synchronization.
 * - 1 - A hardware trigger activates the OUTMASK register synchronization.
 */
/*@{*/
#define BP_FTM_SYNCONF_HWOM  (18U)         /*!< Bit position for FTM_SYNCONF_HWOM. */
#define BM_FTM_SYNCONF_HWOM  (0x00040000U) /*!< Bit mask for FTM_SYNCONF_HWOM. */
#define BS_FTM_SYNCONF_HWOM  (1U)          /*!< Bit field size in bits for FTM_SYNCONF_HWOM. */

/*! @brief Read current value of the FTM_SYNCONF_HWOM field. */
#define BR_FTM_SYNCONF_HWOM(x) (HW_FTM_SYNCONF(x).B.HWOM)

/*! @brief Format value for bitfield FTM_SYNCONF_HWOM. */
#define BF_FTM_SYNCONF_HWOM(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNCONF_HWOM) & BM_FTM_SYNCONF_HWOM)

/*! @brief Set the HWOM field to a new value. */
#define BW_FTM_SYNCONF_HWOM(x, v) (HW_FTM_SYNCONF_WR(x, (HW_FTM_SYNCONF_RD(x) & ~BM_FTM_SYNCONF_HWOM) | BF_FTM_SYNCONF_HWOM(v)))
/*@}*/

/*!
 * @name Register FTM_SYNCONF, field HWINVC[19] (RW)
 *
 * Inverting control synchronization is activated by a hardware trigger.
 *
 * Values:
 * - 0 - A hardware trigger does not activate the INVCTRL register
 *     synchronization.
 * - 1 - A hardware trigger activates the INVCTRL register synchronization.
 */
/*@{*/
#define BP_FTM_SYNCONF_HWINVC (19U)        /*!< Bit position for FTM_SYNCONF_HWINVC. */
#define BM_FTM_SYNCONF_HWINVC (0x00080000U) /*!< Bit mask for FTM_SYNCONF_HWINVC. */
#define BS_FTM_SYNCONF_HWINVC (1U)         /*!< Bit field size in bits for FTM_SYNCONF_HWINVC. */

/*! @brief Read current value of the FTM_SYNCONF_HWINVC field. */
#define BR_FTM_SYNCONF_HWINVC(x) (HW_FTM_SYNCONF(x).B.HWINVC)

/*! @brief Format value for bitfield FTM_SYNCONF_HWINVC. */
#define BF_FTM_SYNCONF_HWINVC(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNCONF_HWINVC) & BM_FTM_SYNCONF_HWINVC)

/*! @brief Set the HWINVC field to a new value. */
#define BW_FTM_SYNCONF_HWINVC(x, v) (HW_FTM_SYNCONF_WR(x, (HW_FTM_SYNCONF_RD(x) & ~BM_FTM_SYNCONF_HWINVC) | BF_FTM_SYNCONF_HWINVC(v)))
/*@}*/

/*!
 * @name Register FTM_SYNCONF, field HWSOC[20] (RW)
 *
 * Software output control synchronization is activated by a hardware trigger.
 *
 * Values:
 * - 0 - A hardware trigger does not activate the SWOCTRL register
 *     synchronization.
 * - 1 - A hardware trigger activates the SWOCTRL register synchronization.
 */
/*@{*/
#define BP_FTM_SYNCONF_HWSOC (20U)         /*!< Bit position for FTM_SYNCONF_HWSOC. */
#define BM_FTM_SYNCONF_HWSOC (0x00100000U) /*!< Bit mask for FTM_SYNCONF_HWSOC. */
#define BS_FTM_SYNCONF_HWSOC (1U)          /*!< Bit field size in bits for FTM_SYNCONF_HWSOC. */

/*! @brief Read current value of the FTM_SYNCONF_HWSOC field. */
#define BR_FTM_SYNCONF_HWSOC(x) (HW_FTM_SYNCONF(x).B.HWSOC)

/*! @brief Format value for bitfield FTM_SYNCONF_HWSOC. */
#define BF_FTM_SYNCONF_HWSOC(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SYNCONF_HWSOC) & BM_FTM_SYNCONF_HWSOC)

/*! @brief Set the HWSOC field to a new value. */
#define BW_FTM_SYNCONF_HWSOC(x, v) (HW_FTM_SYNCONF_WR(x, (HW_FTM_SYNCONF_RD(x) & ~BM_FTM_SYNCONF_HWSOC) | BF_FTM_SYNCONF_HWSOC(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_INVCTRL - FTM Inverting Control
 ******************************************************************************/

/*!
 * @brief HW_FTM_INVCTRL - FTM Inverting Control (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register controls when the channel (n) output becomes the channel (n+1)
 * output, and channel (n+1) output becomes the channel (n) output. Each INVmEN
 * bit enables the inverting operation for the corresponding pair channels m. This
 * register has a write buffer. The INVmEN bit is updated by the INVCTRL
 * register synchronization.
 */
typedef union _hw_ftm_invctrl
{
    uint32_t U;
    struct _hw_ftm_invctrl_bitfields
    {
        uint32_t INV0EN : 1;           /*!< [0] Pair Channels 0 Inverting Enable */
        uint32_t INV1EN : 1;           /*!< [1] Pair Channels 1 Inverting Enable */
        uint32_t INV2EN : 1;           /*!< [2] Pair Channels 2 Inverting Enable */
        uint32_t INV3EN : 1;           /*!< [3] Pair Channels 3 Inverting Enable */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_ftm_invctrl_t;

/*!
 * @name Constants and macros for entire FTM_INVCTRL register
 */
/*@{*/
#define HW_FTM_INVCTRL_ADDR(x)   ((uintptr_t)(x) + 0x90U)

#define HW_FTM_INVCTRL(x)        (*(__IO hw_ftm_invctrl_t *) HW_FTM_INVCTRL_ADDR(x))
#define HW_FTM_INVCTRL_RD(x)     (HW_FTM_INVCTRL(x).U)
#define HW_FTM_INVCTRL_WR(x, v)  (HW_FTM_INVCTRL(x).U = (v))
#define HW_FTM_INVCTRL_SET(x, v) (HW_FTM_INVCTRL_WR(x, HW_FTM_INVCTRL_RD(x) |  (v)))
#define HW_FTM_INVCTRL_CLR(x, v) (HW_FTM_INVCTRL_WR(x, HW_FTM_INVCTRL_RD(x) & ~(v)))
#define HW_FTM_INVCTRL_TOG(x, v) (HW_FTM_INVCTRL_WR(x, HW_FTM_INVCTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_INVCTRL bitfields
 */

/*!
 * @name Register FTM_INVCTRL, field INV0EN[0] (RW)
 *
 * Values:
 * - 0 - Inverting is disabled.
 * - 1 - Inverting is enabled.
 */
/*@{*/
#define BP_FTM_INVCTRL_INV0EN (0U)         /*!< Bit position for FTM_INVCTRL_INV0EN. */
#define BM_FTM_INVCTRL_INV0EN (0x00000001U) /*!< Bit mask for FTM_INVCTRL_INV0EN. */
#define BS_FTM_INVCTRL_INV0EN (1U)         /*!< Bit field size in bits for FTM_INVCTRL_INV0EN. */

/*! @brief Read current value of the FTM_INVCTRL_INV0EN field. */
#define BR_FTM_INVCTRL_INV0EN(x) (HW_FTM_INVCTRL(x).B.INV0EN)

/*! @brief Format value for bitfield FTM_INVCTRL_INV0EN. */
#define BF_FTM_INVCTRL_INV0EN(v) ((uint32_t)((uint32_t)(v) << BP_FTM_INVCTRL_INV0EN) & BM_FTM_INVCTRL_INV0EN)

/*! @brief Set the INV0EN field to a new value. */
#define BW_FTM_INVCTRL_INV0EN(x, v) (HW_FTM_INVCTRL_WR(x, (HW_FTM_INVCTRL_RD(x) & ~BM_FTM_INVCTRL_INV0EN) | BF_FTM_INVCTRL_INV0EN(v)))
/*@}*/

/*!
 * @name Register FTM_INVCTRL, field INV1EN[1] (RW)
 *
 * Values:
 * - 0 - Inverting is disabled.
 * - 1 - Inverting is enabled.
 */
/*@{*/
#define BP_FTM_INVCTRL_INV1EN (1U)         /*!< Bit position for FTM_INVCTRL_INV1EN. */
#define BM_FTM_INVCTRL_INV1EN (0x00000002U) /*!< Bit mask for FTM_INVCTRL_INV1EN. */
#define BS_FTM_INVCTRL_INV1EN (1U)         /*!< Bit field size in bits for FTM_INVCTRL_INV1EN. */

/*! @brief Read current value of the FTM_INVCTRL_INV1EN field. */
#define BR_FTM_INVCTRL_INV1EN(x) (HW_FTM_INVCTRL(x).B.INV1EN)

/*! @brief Format value for bitfield FTM_INVCTRL_INV1EN. */
#define BF_FTM_INVCTRL_INV1EN(v) ((uint32_t)((uint32_t)(v) << BP_FTM_INVCTRL_INV1EN) & BM_FTM_INVCTRL_INV1EN)

/*! @brief Set the INV1EN field to a new value. */
#define BW_FTM_INVCTRL_INV1EN(x, v) (HW_FTM_INVCTRL_WR(x, (HW_FTM_INVCTRL_RD(x) & ~BM_FTM_INVCTRL_INV1EN) | BF_FTM_INVCTRL_INV1EN(v)))
/*@}*/

/*!
 * @name Register FTM_INVCTRL, field INV2EN[2] (RW)
 *
 * Values:
 * - 0 - Inverting is disabled.
 * - 1 - Inverting is enabled.
 */
/*@{*/
#define BP_FTM_INVCTRL_INV2EN (2U)         /*!< Bit position for FTM_INVCTRL_INV2EN. */
#define BM_FTM_INVCTRL_INV2EN (0x00000004U) /*!< Bit mask for FTM_INVCTRL_INV2EN. */
#define BS_FTM_INVCTRL_INV2EN (1U)         /*!< Bit field size in bits for FTM_INVCTRL_INV2EN. */

/*! @brief Read current value of the FTM_INVCTRL_INV2EN field. */
#define BR_FTM_INVCTRL_INV2EN(x) (HW_FTM_INVCTRL(x).B.INV2EN)

/*! @brief Format value for bitfield FTM_INVCTRL_INV2EN. */
#define BF_FTM_INVCTRL_INV2EN(v) ((uint32_t)((uint32_t)(v) << BP_FTM_INVCTRL_INV2EN) & BM_FTM_INVCTRL_INV2EN)

/*! @brief Set the INV2EN field to a new value. */
#define BW_FTM_INVCTRL_INV2EN(x, v) (HW_FTM_INVCTRL_WR(x, (HW_FTM_INVCTRL_RD(x) & ~BM_FTM_INVCTRL_INV2EN) | BF_FTM_INVCTRL_INV2EN(v)))
/*@}*/

/*!
 * @name Register FTM_INVCTRL, field INV3EN[3] (RW)
 *
 * Values:
 * - 0 - Inverting is disabled.
 * - 1 - Inverting is enabled.
 */
/*@{*/
#define BP_FTM_INVCTRL_INV3EN (3U)         /*!< Bit position for FTM_INVCTRL_INV3EN. */
#define BM_FTM_INVCTRL_INV3EN (0x00000008U) /*!< Bit mask for FTM_INVCTRL_INV3EN. */
#define BS_FTM_INVCTRL_INV3EN (1U)         /*!< Bit field size in bits for FTM_INVCTRL_INV3EN. */

/*! @brief Read current value of the FTM_INVCTRL_INV3EN field. */
#define BR_FTM_INVCTRL_INV3EN(x) (HW_FTM_INVCTRL(x).B.INV3EN)

/*! @brief Format value for bitfield FTM_INVCTRL_INV3EN. */
#define BF_FTM_INVCTRL_INV3EN(v) ((uint32_t)((uint32_t)(v) << BP_FTM_INVCTRL_INV3EN) & BM_FTM_INVCTRL_INV3EN)

/*! @brief Set the INV3EN field to a new value. */
#define BW_FTM_INVCTRL_INV3EN(x, v) (HW_FTM_INVCTRL_WR(x, (HW_FTM_INVCTRL_RD(x) & ~BM_FTM_INVCTRL_INV3EN) | BF_FTM_INVCTRL_INV3EN(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_SWOCTRL - FTM Software Output Control
 ******************************************************************************/

/*!
 * @brief HW_FTM_SWOCTRL - FTM Software Output Control (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register enables software control of channel (n) output and defines the
 * value forced to the channel (n) output: The CHnOC bits enable the control of
 * the corresponding channel (n) output by software. The CHnOCV bits select the
 * value that is forced at the corresponding channel (n) output. This register has
 * a write buffer. The fields are updated by the SWOCTRL register synchronization.
 */
typedef union _hw_ftm_swoctrl
{
    uint32_t U;
    struct _hw_ftm_swoctrl_bitfields
    {
        uint32_t CH0OC : 1;            /*!< [0] Channel 0 Software Output Control Enable
                                        * */
        uint32_t CH1OC : 1;            /*!< [1] Channel 1 Software Output Control Enable
                                        * */
        uint32_t CH2OC : 1;            /*!< [2] Channel 2 Software Output Control Enable
                                        * */
        uint32_t CH3OC : 1;            /*!< [3] Channel 3 Software Output Control Enable
                                        * */
        uint32_t CH4OC : 1;            /*!< [4] Channel 4 Software Output Control Enable
                                        * */
        uint32_t CH5OC : 1;            /*!< [5] Channel 5 Software Output Control Enable
                                        * */
        uint32_t CH6OC : 1;            /*!< [6] Channel 6 Software Output Control Enable
                                        * */
        uint32_t CH7OC : 1;            /*!< [7] Channel 7 Software Output Control Enable
                                        * */
        uint32_t CH0OCV : 1;           /*!< [8] Channel 0 Software Output Control Value
                                        * */
        uint32_t CH1OCV : 1;           /*!< [9] Channel 1 Software Output Control Value
                                        * */
        uint32_t CH2OCV : 1;           /*!< [10] Channel 2 Software Output Control
                                        * Value */
        uint32_t CH3OCV : 1;           /*!< [11] Channel 3 Software Output Control
                                        * Value */
        uint32_t CH4OCV : 1;           /*!< [12] Channel 4 Software Output Control
                                        * Value */
        uint32_t CH5OCV : 1;           /*!< [13] Channel 5 Software Output Control
                                        * Value */
        uint32_t CH6OCV : 1;           /*!< [14] Channel 6 Software Output Control
                                        * Value */
        uint32_t CH7OCV : 1;           /*!< [15] Channel 7 Software Output Control
                                        * Value */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_ftm_swoctrl_t;

/*!
 * @name Constants and macros for entire FTM_SWOCTRL register
 */
/*@{*/
#define HW_FTM_SWOCTRL_ADDR(x)   ((uintptr_t)(x) + 0x94U)

#define HW_FTM_SWOCTRL(x)        (*(__IO hw_ftm_swoctrl_t *) HW_FTM_SWOCTRL_ADDR(x))
#define HW_FTM_SWOCTRL_RD(x)     (HW_FTM_SWOCTRL(x).U)
#define HW_FTM_SWOCTRL_WR(x, v)  (HW_FTM_SWOCTRL(x).U = (v))
#define HW_FTM_SWOCTRL_SET(x, v) (HW_FTM_SWOCTRL_WR(x, HW_FTM_SWOCTRL_RD(x) |  (v)))
#define HW_FTM_SWOCTRL_CLR(x, v) (HW_FTM_SWOCTRL_WR(x, HW_FTM_SWOCTRL_RD(x) & ~(v)))
#define HW_FTM_SWOCTRL_TOG(x, v) (HW_FTM_SWOCTRL_WR(x, HW_FTM_SWOCTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_SWOCTRL bitfields
 */

/*!
 * @name Register FTM_SWOCTRL, field CH0OC[0] (RW)
 *
 * Values:
 * - 0 - The channel output is not affected by software output control.
 * - 1 - The channel output is affected by software output control.
 */
/*@{*/
#define BP_FTM_SWOCTRL_CH0OC (0U)          /*!< Bit position for FTM_SWOCTRL_CH0OC. */
#define BM_FTM_SWOCTRL_CH0OC (0x00000001U) /*!< Bit mask for FTM_SWOCTRL_CH0OC. */
#define BS_FTM_SWOCTRL_CH0OC (1U)          /*!< Bit field size in bits for FTM_SWOCTRL_CH0OC. */

/*! @brief Read current value of the FTM_SWOCTRL_CH0OC field. */
#define BR_FTM_SWOCTRL_CH0OC(x) (HW_FTM_SWOCTRL(x).B.CH0OC)

/*! @brief Format value for bitfield FTM_SWOCTRL_CH0OC. */
#define BF_FTM_SWOCTRL_CH0OC(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SWOCTRL_CH0OC) & BM_FTM_SWOCTRL_CH0OC)

/*! @brief Set the CH0OC field to a new value. */
#define BW_FTM_SWOCTRL_CH0OC(x, v) (HW_FTM_SWOCTRL_WR(x, (HW_FTM_SWOCTRL_RD(x) & ~BM_FTM_SWOCTRL_CH0OC) | BF_FTM_SWOCTRL_CH0OC(v)))
/*@}*/

/*!
 * @name Register FTM_SWOCTRL, field CH1OC[1] (RW)
 *
 * Values:
 * - 0 - The channel output is not affected by software output control.
 * - 1 - The channel output is affected by software output control.
 */
/*@{*/
#define BP_FTM_SWOCTRL_CH1OC (1U)          /*!< Bit position for FTM_SWOCTRL_CH1OC. */
#define BM_FTM_SWOCTRL_CH1OC (0x00000002U) /*!< Bit mask for FTM_SWOCTRL_CH1OC. */
#define BS_FTM_SWOCTRL_CH1OC (1U)          /*!< Bit field size in bits for FTM_SWOCTRL_CH1OC. */

/*! @brief Read current value of the FTM_SWOCTRL_CH1OC field. */
#define BR_FTM_SWOCTRL_CH1OC(x) (HW_FTM_SWOCTRL(x).B.CH1OC)

/*! @brief Format value for bitfield FTM_SWOCTRL_CH1OC. */
#define BF_FTM_SWOCTRL_CH1OC(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SWOCTRL_CH1OC) & BM_FTM_SWOCTRL_CH1OC)

/*! @brief Set the CH1OC field to a new value. */
#define BW_FTM_SWOCTRL_CH1OC(x, v) (HW_FTM_SWOCTRL_WR(x, (HW_FTM_SWOCTRL_RD(x) & ~BM_FTM_SWOCTRL_CH1OC) | BF_FTM_SWOCTRL_CH1OC(v)))
/*@}*/

/*!
 * @name Register FTM_SWOCTRL, field CH2OC[2] (RW)
 *
 * Values:
 * - 0 - The channel output is not affected by software output control.
 * - 1 - The channel output is affected by software output control.
 */
/*@{*/
#define BP_FTM_SWOCTRL_CH2OC (2U)          /*!< Bit position for FTM_SWOCTRL_CH2OC. */
#define BM_FTM_SWOCTRL_CH2OC (0x00000004U) /*!< Bit mask for FTM_SWOCTRL_CH2OC. */
#define BS_FTM_SWOCTRL_CH2OC (1U)          /*!< Bit field size in bits for FTM_SWOCTRL_CH2OC. */

/*! @brief Read current value of the FTM_SWOCTRL_CH2OC field. */
#define BR_FTM_SWOCTRL_CH2OC(x) (HW_FTM_SWOCTRL(x).B.CH2OC)

/*! @brief Format value for bitfield FTM_SWOCTRL_CH2OC. */
#define BF_FTM_SWOCTRL_CH2OC(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SWOCTRL_CH2OC) & BM_FTM_SWOCTRL_CH2OC)

/*! @brief Set the CH2OC field to a new value. */
#define BW_FTM_SWOCTRL_CH2OC(x, v) (HW_FTM_SWOCTRL_WR(x, (HW_FTM_SWOCTRL_RD(x) & ~BM_FTM_SWOCTRL_CH2OC) | BF_FTM_SWOCTRL_CH2OC(v)))
/*@}*/

/*!
 * @name Register FTM_SWOCTRL, field CH3OC[3] (RW)
 *
 * Values:
 * - 0 - The channel output is not affected by software output control.
 * - 1 - The channel output is affected by software output control.
 */
/*@{*/
#define BP_FTM_SWOCTRL_CH3OC (3U)          /*!< Bit position for FTM_SWOCTRL_CH3OC. */
#define BM_FTM_SWOCTRL_CH3OC (0x00000008U) /*!< Bit mask for FTM_SWOCTRL_CH3OC. */
#define BS_FTM_SWOCTRL_CH3OC (1U)          /*!< Bit field size in bits for FTM_SWOCTRL_CH3OC. */

/*! @brief Read current value of the FTM_SWOCTRL_CH3OC field. */
#define BR_FTM_SWOCTRL_CH3OC(x) (HW_FTM_SWOCTRL(x).B.CH3OC)

/*! @brief Format value for bitfield FTM_SWOCTRL_CH3OC. */
#define BF_FTM_SWOCTRL_CH3OC(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SWOCTRL_CH3OC) & BM_FTM_SWOCTRL_CH3OC)

/*! @brief Set the CH3OC field to a new value. */
#define BW_FTM_SWOCTRL_CH3OC(x, v) (HW_FTM_SWOCTRL_WR(x, (HW_FTM_SWOCTRL_RD(x) & ~BM_FTM_SWOCTRL_CH3OC) | BF_FTM_SWOCTRL_CH3OC(v)))
/*@}*/

/*!
 * @name Register FTM_SWOCTRL, field CH4OC[4] (RW)
 *
 * Values:
 * - 0 - The channel output is not affected by software output control.
 * - 1 - The channel output is affected by software output control.
 */
/*@{*/
#define BP_FTM_SWOCTRL_CH4OC (4U)          /*!< Bit position for FTM_SWOCTRL_CH4OC. */
#define BM_FTM_SWOCTRL_CH4OC (0x00000010U) /*!< Bit mask for FTM_SWOCTRL_CH4OC. */
#define BS_FTM_SWOCTRL_CH4OC (1U)          /*!< Bit field size in bits for FTM_SWOCTRL_CH4OC. */

/*! @brief Read current value of the FTM_SWOCTRL_CH4OC field. */
#define BR_FTM_SWOCTRL_CH4OC(x) (HW_FTM_SWOCTRL(x).B.CH4OC)

/*! @brief Format value for bitfield FTM_SWOCTRL_CH4OC. */
#define BF_FTM_SWOCTRL_CH4OC(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SWOCTRL_CH4OC) & BM_FTM_SWOCTRL_CH4OC)

/*! @brief Set the CH4OC field to a new value. */
#define BW_FTM_SWOCTRL_CH4OC(x, v) (HW_FTM_SWOCTRL_WR(x, (HW_FTM_SWOCTRL_RD(x) & ~BM_FTM_SWOCTRL_CH4OC) | BF_FTM_SWOCTRL_CH4OC(v)))
/*@}*/

/*!
 * @name Register FTM_SWOCTRL, field CH5OC[5] (RW)
 *
 * Values:
 * - 0 - The channel output is not affected by software output control.
 * - 1 - The channel output is affected by software output control.
 */
/*@{*/
#define BP_FTM_SWOCTRL_CH5OC (5U)          /*!< Bit position for FTM_SWOCTRL_CH5OC. */
#define BM_FTM_SWOCTRL_CH5OC (0x00000020U) /*!< Bit mask for FTM_SWOCTRL_CH5OC. */
#define BS_FTM_SWOCTRL_CH5OC (1U)          /*!< Bit field size in bits for FTM_SWOCTRL_CH5OC. */

/*! @brief Read current value of the FTM_SWOCTRL_CH5OC field. */
#define BR_FTM_SWOCTRL_CH5OC(x) (HW_FTM_SWOCTRL(x).B.CH5OC)

/*! @brief Format value for bitfield FTM_SWOCTRL_CH5OC. */
#define BF_FTM_SWOCTRL_CH5OC(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SWOCTRL_CH5OC) & BM_FTM_SWOCTRL_CH5OC)

/*! @brief Set the CH5OC field to a new value. */
#define BW_FTM_SWOCTRL_CH5OC(x, v) (HW_FTM_SWOCTRL_WR(x, (HW_FTM_SWOCTRL_RD(x) & ~BM_FTM_SWOCTRL_CH5OC) | BF_FTM_SWOCTRL_CH5OC(v)))
/*@}*/

/*!
 * @name Register FTM_SWOCTRL, field CH6OC[6] (RW)
 *
 * Values:
 * - 0 - The channel output is not affected by software output control.
 * - 1 - The channel output is affected by software output control.
 */
/*@{*/
#define BP_FTM_SWOCTRL_CH6OC (6U)          /*!< Bit position for FTM_SWOCTRL_CH6OC. */
#define BM_FTM_SWOCTRL_CH6OC (0x00000040U) /*!< Bit mask for FTM_SWOCTRL_CH6OC. */
#define BS_FTM_SWOCTRL_CH6OC (1U)          /*!< Bit field size in bits for FTM_SWOCTRL_CH6OC. */

/*! @brief Read current value of the FTM_SWOCTRL_CH6OC field. */
#define BR_FTM_SWOCTRL_CH6OC(x) (HW_FTM_SWOCTRL(x).B.CH6OC)

/*! @brief Format value for bitfield FTM_SWOCTRL_CH6OC. */
#define BF_FTM_SWOCTRL_CH6OC(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SWOCTRL_CH6OC) & BM_FTM_SWOCTRL_CH6OC)

/*! @brief Set the CH6OC field to a new value. */
#define BW_FTM_SWOCTRL_CH6OC(x, v) (HW_FTM_SWOCTRL_WR(x, (HW_FTM_SWOCTRL_RD(x) & ~BM_FTM_SWOCTRL_CH6OC) | BF_FTM_SWOCTRL_CH6OC(v)))
/*@}*/

/*!
 * @name Register FTM_SWOCTRL, field CH7OC[7] (RW)
 *
 * Values:
 * - 0 - The channel output is not affected by software output control.
 * - 1 - The channel output is affected by software output control.
 */
/*@{*/
#define BP_FTM_SWOCTRL_CH7OC (7U)          /*!< Bit position for FTM_SWOCTRL_CH7OC. */
#define BM_FTM_SWOCTRL_CH7OC (0x00000080U) /*!< Bit mask for FTM_SWOCTRL_CH7OC. */
#define BS_FTM_SWOCTRL_CH7OC (1U)          /*!< Bit field size in bits for FTM_SWOCTRL_CH7OC. */

/*! @brief Read current value of the FTM_SWOCTRL_CH7OC field. */
#define BR_FTM_SWOCTRL_CH7OC(x) (HW_FTM_SWOCTRL(x).B.CH7OC)

/*! @brief Format value for bitfield FTM_SWOCTRL_CH7OC. */
#define BF_FTM_SWOCTRL_CH7OC(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SWOCTRL_CH7OC) & BM_FTM_SWOCTRL_CH7OC)

/*! @brief Set the CH7OC field to a new value. */
#define BW_FTM_SWOCTRL_CH7OC(x, v) (HW_FTM_SWOCTRL_WR(x, (HW_FTM_SWOCTRL_RD(x) & ~BM_FTM_SWOCTRL_CH7OC) | BF_FTM_SWOCTRL_CH7OC(v)))
/*@}*/

/*!
 * @name Register FTM_SWOCTRL, field CH0OCV[8] (RW)
 *
 * Values:
 * - 0 - The software output control forces 0 to the channel output.
 * - 1 - The software output control forces 1 to the channel output.
 */
/*@{*/
#define BP_FTM_SWOCTRL_CH0OCV (8U)         /*!< Bit position for FTM_SWOCTRL_CH0OCV. */
#define BM_FTM_SWOCTRL_CH0OCV (0x00000100U) /*!< Bit mask for FTM_SWOCTRL_CH0OCV. */
#define BS_FTM_SWOCTRL_CH0OCV (1U)         /*!< Bit field size in bits for FTM_SWOCTRL_CH0OCV. */

/*! @brief Read current value of the FTM_SWOCTRL_CH0OCV field. */
#define BR_FTM_SWOCTRL_CH0OCV(x) (HW_FTM_SWOCTRL(x).B.CH0OCV)

/*! @brief Format value for bitfield FTM_SWOCTRL_CH0OCV. */
#define BF_FTM_SWOCTRL_CH0OCV(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SWOCTRL_CH0OCV) & BM_FTM_SWOCTRL_CH0OCV)

/*! @brief Set the CH0OCV field to a new value. */
#define BW_FTM_SWOCTRL_CH0OCV(x, v) (HW_FTM_SWOCTRL_WR(x, (HW_FTM_SWOCTRL_RD(x) & ~BM_FTM_SWOCTRL_CH0OCV) | BF_FTM_SWOCTRL_CH0OCV(v)))
/*@}*/

/*!
 * @name Register FTM_SWOCTRL, field CH1OCV[9] (RW)
 *
 * Values:
 * - 0 - The software output control forces 0 to the channel output.
 * - 1 - The software output control forces 1 to the channel output.
 */
/*@{*/
#define BP_FTM_SWOCTRL_CH1OCV (9U)         /*!< Bit position for FTM_SWOCTRL_CH1OCV. */
#define BM_FTM_SWOCTRL_CH1OCV (0x00000200U) /*!< Bit mask for FTM_SWOCTRL_CH1OCV. */
#define BS_FTM_SWOCTRL_CH1OCV (1U)         /*!< Bit field size in bits for FTM_SWOCTRL_CH1OCV. */

/*! @brief Read current value of the FTM_SWOCTRL_CH1OCV field. */
#define BR_FTM_SWOCTRL_CH1OCV(x) (HW_FTM_SWOCTRL(x).B.CH1OCV)

/*! @brief Format value for bitfield FTM_SWOCTRL_CH1OCV. */
#define BF_FTM_SWOCTRL_CH1OCV(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SWOCTRL_CH1OCV) & BM_FTM_SWOCTRL_CH1OCV)

/*! @brief Set the CH1OCV field to a new value. */
#define BW_FTM_SWOCTRL_CH1OCV(x, v) (HW_FTM_SWOCTRL_WR(x, (HW_FTM_SWOCTRL_RD(x) & ~BM_FTM_SWOCTRL_CH1OCV) | BF_FTM_SWOCTRL_CH1OCV(v)))
/*@}*/

/*!
 * @name Register FTM_SWOCTRL, field CH2OCV[10] (RW)
 *
 * Values:
 * - 0 - The software output control forces 0 to the channel output.
 * - 1 - The software output control forces 1 to the channel output.
 */
/*@{*/
#define BP_FTM_SWOCTRL_CH2OCV (10U)        /*!< Bit position for FTM_SWOCTRL_CH2OCV. */
#define BM_FTM_SWOCTRL_CH2OCV (0x00000400U) /*!< Bit mask for FTM_SWOCTRL_CH2OCV. */
#define BS_FTM_SWOCTRL_CH2OCV (1U)         /*!< Bit field size in bits for FTM_SWOCTRL_CH2OCV. */

/*! @brief Read current value of the FTM_SWOCTRL_CH2OCV field. */
#define BR_FTM_SWOCTRL_CH2OCV(x) (HW_FTM_SWOCTRL(x).B.CH2OCV)

/*! @brief Format value for bitfield FTM_SWOCTRL_CH2OCV. */
#define BF_FTM_SWOCTRL_CH2OCV(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SWOCTRL_CH2OCV) & BM_FTM_SWOCTRL_CH2OCV)

/*! @brief Set the CH2OCV field to a new value. */
#define BW_FTM_SWOCTRL_CH2OCV(x, v) (HW_FTM_SWOCTRL_WR(x, (HW_FTM_SWOCTRL_RD(x) & ~BM_FTM_SWOCTRL_CH2OCV) | BF_FTM_SWOCTRL_CH2OCV(v)))
/*@}*/

/*!
 * @name Register FTM_SWOCTRL, field CH3OCV[11] (RW)
 *
 * Values:
 * - 0 - The software output control forces 0 to the channel output.
 * - 1 - The software output control forces 1 to the channel output.
 */
/*@{*/
#define BP_FTM_SWOCTRL_CH3OCV (11U)        /*!< Bit position for FTM_SWOCTRL_CH3OCV. */
#define BM_FTM_SWOCTRL_CH3OCV (0x00000800U) /*!< Bit mask for FTM_SWOCTRL_CH3OCV. */
#define BS_FTM_SWOCTRL_CH3OCV (1U)         /*!< Bit field size in bits for FTM_SWOCTRL_CH3OCV. */

/*! @brief Read current value of the FTM_SWOCTRL_CH3OCV field. */
#define BR_FTM_SWOCTRL_CH3OCV(x) (HW_FTM_SWOCTRL(x).B.CH3OCV)

/*! @brief Format value for bitfield FTM_SWOCTRL_CH3OCV. */
#define BF_FTM_SWOCTRL_CH3OCV(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SWOCTRL_CH3OCV) & BM_FTM_SWOCTRL_CH3OCV)

/*! @brief Set the CH3OCV field to a new value. */
#define BW_FTM_SWOCTRL_CH3OCV(x, v) (HW_FTM_SWOCTRL_WR(x, (HW_FTM_SWOCTRL_RD(x) & ~BM_FTM_SWOCTRL_CH3OCV) | BF_FTM_SWOCTRL_CH3OCV(v)))
/*@}*/

/*!
 * @name Register FTM_SWOCTRL, field CH4OCV[12] (RW)
 *
 * Values:
 * - 0 - The software output control forces 0 to the channel output.
 * - 1 - The software output control forces 1 to the channel output.
 */
/*@{*/
#define BP_FTM_SWOCTRL_CH4OCV (12U)        /*!< Bit position for FTM_SWOCTRL_CH4OCV. */
#define BM_FTM_SWOCTRL_CH4OCV (0x00001000U) /*!< Bit mask for FTM_SWOCTRL_CH4OCV. */
#define BS_FTM_SWOCTRL_CH4OCV (1U)         /*!< Bit field size in bits for FTM_SWOCTRL_CH4OCV. */

/*! @brief Read current value of the FTM_SWOCTRL_CH4OCV field. */
#define BR_FTM_SWOCTRL_CH4OCV(x) (HW_FTM_SWOCTRL(x).B.CH4OCV)

/*! @brief Format value for bitfield FTM_SWOCTRL_CH4OCV. */
#define BF_FTM_SWOCTRL_CH4OCV(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SWOCTRL_CH4OCV) & BM_FTM_SWOCTRL_CH4OCV)

/*! @brief Set the CH4OCV field to a new value. */
#define BW_FTM_SWOCTRL_CH4OCV(x, v) (HW_FTM_SWOCTRL_WR(x, (HW_FTM_SWOCTRL_RD(x) & ~BM_FTM_SWOCTRL_CH4OCV) | BF_FTM_SWOCTRL_CH4OCV(v)))
/*@}*/

/*!
 * @name Register FTM_SWOCTRL, field CH5OCV[13] (RW)
 *
 * Values:
 * - 0 - The software output control forces 0 to the channel output.
 * - 1 - The software output control forces 1 to the channel output.
 */
/*@{*/
#define BP_FTM_SWOCTRL_CH5OCV (13U)        /*!< Bit position for FTM_SWOCTRL_CH5OCV. */
#define BM_FTM_SWOCTRL_CH5OCV (0x00002000U) /*!< Bit mask for FTM_SWOCTRL_CH5OCV. */
#define BS_FTM_SWOCTRL_CH5OCV (1U)         /*!< Bit field size in bits for FTM_SWOCTRL_CH5OCV. */

/*! @brief Read current value of the FTM_SWOCTRL_CH5OCV field. */
#define BR_FTM_SWOCTRL_CH5OCV(x) (HW_FTM_SWOCTRL(x).B.CH5OCV)

/*! @brief Format value for bitfield FTM_SWOCTRL_CH5OCV. */
#define BF_FTM_SWOCTRL_CH5OCV(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SWOCTRL_CH5OCV) & BM_FTM_SWOCTRL_CH5OCV)

/*! @brief Set the CH5OCV field to a new value. */
#define BW_FTM_SWOCTRL_CH5OCV(x, v) (HW_FTM_SWOCTRL_WR(x, (HW_FTM_SWOCTRL_RD(x) & ~BM_FTM_SWOCTRL_CH5OCV) | BF_FTM_SWOCTRL_CH5OCV(v)))
/*@}*/

/*!
 * @name Register FTM_SWOCTRL, field CH6OCV[14] (RW)
 *
 * Values:
 * - 0 - The software output control forces 0 to the channel output.
 * - 1 - The software output control forces 1 to the channel output.
 */
/*@{*/
#define BP_FTM_SWOCTRL_CH6OCV (14U)        /*!< Bit position for FTM_SWOCTRL_CH6OCV. */
#define BM_FTM_SWOCTRL_CH6OCV (0x00004000U) /*!< Bit mask for FTM_SWOCTRL_CH6OCV. */
#define BS_FTM_SWOCTRL_CH6OCV (1U)         /*!< Bit field size in bits for FTM_SWOCTRL_CH6OCV. */

/*! @brief Read current value of the FTM_SWOCTRL_CH6OCV field. */
#define BR_FTM_SWOCTRL_CH6OCV(x) (HW_FTM_SWOCTRL(x).B.CH6OCV)

/*! @brief Format value for bitfield FTM_SWOCTRL_CH6OCV. */
#define BF_FTM_SWOCTRL_CH6OCV(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SWOCTRL_CH6OCV) & BM_FTM_SWOCTRL_CH6OCV)

/*! @brief Set the CH6OCV field to a new value. */
#define BW_FTM_SWOCTRL_CH6OCV(x, v) (HW_FTM_SWOCTRL_WR(x, (HW_FTM_SWOCTRL_RD(x) & ~BM_FTM_SWOCTRL_CH6OCV) | BF_FTM_SWOCTRL_CH6OCV(v)))
/*@}*/

/*!
 * @name Register FTM_SWOCTRL, field CH7OCV[15] (RW)
 *
 * Values:
 * - 0 - The software output control forces 0 to the channel output.
 * - 1 - The software output control forces 1 to the channel output.
 */
/*@{*/
#define BP_FTM_SWOCTRL_CH7OCV (15U)        /*!< Bit position for FTM_SWOCTRL_CH7OCV. */
#define BM_FTM_SWOCTRL_CH7OCV (0x00008000U) /*!< Bit mask for FTM_SWOCTRL_CH7OCV. */
#define BS_FTM_SWOCTRL_CH7OCV (1U)         /*!< Bit field size in bits for FTM_SWOCTRL_CH7OCV. */

/*! @brief Read current value of the FTM_SWOCTRL_CH7OCV field. */
#define BR_FTM_SWOCTRL_CH7OCV(x) (HW_FTM_SWOCTRL(x).B.CH7OCV)

/*! @brief Format value for bitfield FTM_SWOCTRL_CH7OCV. */
#define BF_FTM_SWOCTRL_CH7OCV(v) ((uint32_t)((uint32_t)(v) << BP_FTM_SWOCTRL_CH7OCV) & BM_FTM_SWOCTRL_CH7OCV)

/*! @brief Set the CH7OCV field to a new value. */
#define BW_FTM_SWOCTRL_CH7OCV(x, v) (HW_FTM_SWOCTRL_WR(x, (HW_FTM_SWOCTRL_RD(x) & ~BM_FTM_SWOCTRL_CH7OCV) | BF_FTM_SWOCTRL_CH7OCV(v)))
/*@}*/

/*******************************************************************************
 * HW_FTM_PWMLOAD - FTM PWM Load
 ******************************************************************************/

/*!
 * @brief HW_FTM_PWMLOAD - FTM PWM Load (RW)
 *
 * Reset value: 0x00000000U
 *
 * Enables the loading of the MOD, CNTIN, C(n)V, and C(n+1)V registers with the
 * values of their write buffers when the FTM counter changes from the MOD
 * register value to its next value or when a channel (j) match occurs. A match occurs
 * for the channel (j) when FTM counter = C(j)V.
 */
typedef union _hw_ftm_pwmload
{
    uint32_t U;
    struct _hw_ftm_pwmload_bitfields
    {
        uint32_t CH0SEL : 1;           /*!< [0] Channel 0 Select */
        uint32_t CH1SEL : 1;           /*!< [1] Channel 1 Select */
        uint32_t CH2SEL : 1;           /*!< [2] Channel 2 Select */
        uint32_t CH3SEL : 1;           /*!< [3] Channel 3 Select */
        uint32_t CH4SEL : 1;           /*!< [4] Channel 4 Select */
        uint32_t CH5SEL : 1;           /*!< [5] Channel 5 Select */
        uint32_t CH6SEL : 1;           /*!< [6] Channel 6 Select */
        uint32_t CH7SEL : 1;           /*!< [7] Channel 7 Select */
        uint32_t RESERVED0 : 1;        /*!< [8]  */
        uint32_t LDOK : 1;             /*!< [9] Load Enable */
        uint32_t RESERVED1 : 22;       /*!< [31:10]  */
    } B;
} hw_ftm_pwmload_t;

/*!
 * @name Constants and macros for entire FTM_PWMLOAD register
 */
/*@{*/
#define HW_FTM_PWMLOAD_ADDR(x)   ((uintptr_t)(x) + 0x98U)

#define HW_FTM_PWMLOAD(x)        (*(__IO hw_ftm_pwmload_t *) HW_FTM_PWMLOAD_ADDR(x))
#define HW_FTM_PWMLOAD_RD(x)     (HW_FTM_PWMLOAD(x).U)
#define HW_FTM_PWMLOAD_WR(x, v)  (HW_FTM_PWMLOAD(x).U = (v))
#define HW_FTM_PWMLOAD_SET(x, v) (HW_FTM_PWMLOAD_WR(x, HW_FTM_PWMLOAD_RD(x) |  (v)))
#define HW_FTM_PWMLOAD_CLR(x, v) (HW_FTM_PWMLOAD_WR(x, HW_FTM_PWMLOAD_RD(x) & ~(v)))
#define HW_FTM_PWMLOAD_TOG(x, v) (HW_FTM_PWMLOAD_WR(x, HW_FTM_PWMLOAD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FTM_PWMLOAD bitfields
 */

/*!
 * @name Register FTM_PWMLOAD, field CH0SEL[0] (RW)
 *
 * Values:
 * - 0 - Do not include the channel in the matching process.
 * - 1 - Include the channel in the matching process.
 */
/*@{*/
#define BP_FTM_PWMLOAD_CH0SEL (0U)         /*!< Bit position for FTM_PWMLOAD_CH0SEL. */
#define BM_FTM_PWMLOAD_CH0SEL (0x00000001U) /*!< Bit mask for FTM_PWMLOAD_CH0SEL. */
#define BS_FTM_PWMLOAD_CH0SEL (1U)         /*!< Bit field size in bits for FTM_PWMLOAD_CH0SEL. */

/*! @brief Read current value of the FTM_PWMLOAD_CH0SEL field. */
#define BR_FTM_PWMLOAD_CH0SEL(x) (HW_FTM_PWMLOAD(x).B.CH0SEL)

/*! @brief Format value for bitfield FTM_PWMLOAD_CH0SEL. */
#define BF_FTM_PWMLOAD_CH0SEL(v) ((uint32_t)((uint32_t)(v) << BP_FTM_PWMLOAD_CH0SEL) & BM_FTM_PWMLOAD_CH0SEL)

/*! @brief Set the CH0SEL field to a new value. */
#define BW_FTM_PWMLOAD_CH0SEL(x, v) (HW_FTM_PWMLOAD_WR(x, (HW_FTM_PWMLOAD_RD(x) & ~BM_FTM_PWMLOAD_CH0SEL) | BF_FTM_PWMLOAD_CH0SEL(v)))
/*@}*/

/*!
 * @name Register FTM_PWMLOAD, field CH1SEL[1] (RW)
 *
 * Values:
 * - 0 - Do not include the channel in the matching process.
 * - 1 - Include the channel in the matching process.
 */
/*@{*/
#define BP_FTM_PWMLOAD_CH1SEL (1U)         /*!< Bit position for FTM_PWMLOAD_CH1SEL. */
#define BM_FTM_PWMLOAD_CH1SEL (0x00000002U) /*!< Bit mask for FTM_PWMLOAD_CH1SEL. */
#define BS_FTM_PWMLOAD_CH1SEL (1U)         /*!< Bit field size in bits for FTM_PWMLOAD_CH1SEL. */

/*! @brief Read current value of the FTM_PWMLOAD_CH1SEL field. */
#define BR_FTM_PWMLOAD_CH1SEL(x) (HW_FTM_PWMLOAD(x).B.CH1SEL)

/*! @brief Format value for bitfield FTM_PWMLOAD_CH1SEL. */
#define BF_FTM_PWMLOAD_CH1SEL(v) ((uint32_t)((uint32_t)(v) << BP_FTM_PWMLOAD_CH1SEL) & BM_FTM_PWMLOAD_CH1SEL)

/*! @brief Set the CH1SEL field to a new value. */
#define BW_FTM_PWMLOAD_CH1SEL(x, v) (HW_FTM_PWMLOAD_WR(x, (HW_FTM_PWMLOAD_RD(x) & ~BM_FTM_PWMLOAD_CH1SEL) | BF_FTM_PWMLOAD_CH1SEL(v)))
/*@}*/

/*!
 * @name Register FTM_PWMLOAD, field CH2SEL[2] (RW)
 *
 * Values:
 * - 0 - Do not include the channel in the matching process.
 * - 1 - Include the channel in the matching process.
 */
/*@{*/
#define BP_FTM_PWMLOAD_CH2SEL (2U)         /*!< Bit position for FTM_PWMLOAD_CH2SEL. */
#define BM_FTM_PWMLOAD_CH2SEL (0x00000004U) /*!< Bit mask for FTM_PWMLOAD_CH2SEL. */
#define BS_FTM_PWMLOAD_CH2SEL (1U)         /*!< Bit field size in bits for FTM_PWMLOAD_CH2SEL. */

/*! @brief Read current value of the FTM_PWMLOAD_CH2SEL field. */
#define BR_FTM_PWMLOAD_CH2SEL(x) (HW_FTM_PWMLOAD(x).B.CH2SEL)

/*! @brief Format value for bitfield FTM_PWMLOAD_CH2SEL. */
#define BF_FTM_PWMLOAD_CH2SEL(v) ((uint32_t)((uint32_t)(v) << BP_FTM_PWMLOAD_CH2SEL) & BM_FTM_PWMLOAD_CH2SEL)

/*! @brief Set the CH2SEL field to a new value. */
#define BW_FTM_PWMLOAD_CH2SEL(x, v) (HW_FTM_PWMLOAD_WR(x, (HW_FTM_PWMLOAD_RD(x) & ~BM_FTM_PWMLOAD_CH2SEL) | BF_FTM_PWMLOAD_CH2SEL(v)))
/*@}*/

/*!
 * @name Register FTM_PWMLOAD, field CH3SEL[3] (RW)
 *
 * Values:
 * - 0 - Do not include the channel in the matching process.
 * - 1 - Include the channel in the matching process.
 */
/*@{*/
#define BP_FTM_PWMLOAD_CH3SEL (3U)         /*!< Bit position for FTM_PWMLOAD_CH3SEL. */
#define BM_FTM_PWMLOAD_CH3SEL (0x00000008U) /*!< Bit mask for FTM_PWMLOAD_CH3SEL. */
#define BS_FTM_PWMLOAD_CH3SEL (1U)         /*!< Bit field size in bits for FTM_PWMLOAD_CH3SEL. */

/*! @brief Read current value of the FTM_PWMLOAD_CH3SEL field. */
#define BR_FTM_PWMLOAD_CH3SEL(x) (HW_FTM_PWMLOAD(x).B.CH3SEL)

/*! @brief Format value for bitfield FTM_PWMLOAD_CH3SEL. */
#define BF_FTM_PWMLOAD_CH3SEL(v) ((uint32_t)((uint32_t)(v) << BP_FTM_PWMLOAD_CH3SEL) & BM_FTM_PWMLOAD_CH3SEL)

/*! @brief Set the CH3SEL field to a new value. */
#define BW_FTM_PWMLOAD_CH3SEL(x, v) (HW_FTM_PWMLOAD_WR(x, (HW_FTM_PWMLOAD_RD(x) & ~BM_FTM_PWMLOAD_CH3SEL) | BF_FTM_PWMLOAD_CH3SEL(v)))
/*@}*/

/*!
 * @name Register FTM_PWMLOAD, field CH4SEL[4] (RW)
 *
 * Values:
 * - 0 - Do not include the channel in the matching process.
 * - 1 - Include the channel in the matching process.
 */
/*@{*/
#define BP_FTM_PWMLOAD_CH4SEL (4U)         /*!< Bit position for FTM_PWMLOAD_CH4SEL. */
#define BM_FTM_PWMLOAD_CH4SEL (0x00000010U) /*!< Bit mask for FTM_PWMLOAD_CH4SEL. */
#define BS_FTM_PWMLOAD_CH4SEL (1U)         /*!< Bit field size in bits for FTM_PWMLOAD_CH4SEL. */

/*! @brief Read current value of the FTM_PWMLOAD_CH4SEL field. */
#define BR_FTM_PWMLOAD_CH4SEL(x) (HW_FTM_PWMLOAD(x).B.CH4SEL)

/*! @brief Format value for bitfield FTM_PWMLOAD_CH4SEL. */
#define BF_FTM_PWMLOAD_CH4SEL(v) ((uint32_t)((uint32_t)(v) << BP_FTM_PWMLOAD_CH4SEL) & BM_FTM_PWMLOAD_CH4SEL)

/*! @brief Set the CH4SEL field to a new value. */
#define BW_FTM_PWMLOAD_CH4SEL(x, v) (HW_FTM_PWMLOAD_WR(x, (HW_FTM_PWMLOAD_RD(x) & ~BM_FTM_PWMLOAD_CH4SEL) | BF_FTM_PWMLOAD_CH4SEL(v)))
/*@}*/

/*!
 * @name Register FTM_PWMLOAD, field CH5SEL[5] (RW)
 *
 * Values:
 * - 0 - Do not include the channel in the matching process.
 * - 1 - Include the channel in the matching process.
 */
/*@{*/
#define BP_FTM_PWMLOAD_CH5SEL (5U)         /*!< Bit position for FTM_PWMLOAD_CH5SEL. */
#define BM_FTM_PWMLOAD_CH5SEL (0x00000020U) /*!< Bit mask for FTM_PWMLOAD_CH5SEL. */
#define BS_FTM_PWMLOAD_CH5SEL (1U)         /*!< Bit field size in bits for FTM_PWMLOAD_CH5SEL. */

/*! @brief Read current value of the FTM_PWMLOAD_CH5SEL field. */
#define BR_FTM_PWMLOAD_CH5SEL(x) (HW_FTM_PWMLOAD(x).B.CH5SEL)

/*! @brief Format value for bitfield FTM_PWMLOAD_CH5SEL. */
#define BF_FTM_PWMLOAD_CH5SEL(v) ((uint32_t)((uint32_t)(v) << BP_FTM_PWMLOAD_CH5SEL) & BM_FTM_PWMLOAD_CH5SEL)

/*! @brief Set the CH5SEL field to a new value. */
#define BW_FTM_PWMLOAD_CH5SEL(x, v) (HW_FTM_PWMLOAD_WR(x, (HW_FTM_PWMLOAD_RD(x) & ~BM_FTM_PWMLOAD_CH5SEL) | BF_FTM_PWMLOAD_CH5SEL(v)))
/*@}*/

/*!
 * @name Register FTM_PWMLOAD, field CH6SEL[6] (RW)
 *
 * Values:
 * - 0 - Do not include the channel in the matching process.
 * - 1 - Include the channel in the matching process.
 */
/*@{*/
#define BP_FTM_PWMLOAD_CH6SEL (6U)         /*!< Bit position for FTM_PWMLOAD_CH6SEL. */
#define BM_FTM_PWMLOAD_CH6SEL (0x00000040U) /*!< Bit mask for FTM_PWMLOAD_CH6SEL. */
#define BS_FTM_PWMLOAD_CH6SEL (1U)         /*!< Bit field size in bits for FTM_PWMLOAD_CH6SEL. */

/*! @brief Read current value of the FTM_PWMLOAD_CH6SEL field. */
#define BR_FTM_PWMLOAD_CH6SEL(x) (HW_FTM_PWMLOAD(x).B.CH6SEL)

/*! @brief Format value for bitfield FTM_PWMLOAD_CH6SEL. */
#define BF_FTM_PWMLOAD_CH6SEL(v) ((uint32_t)((uint32_t)(v) << BP_FTM_PWMLOAD_CH6SEL) & BM_FTM_PWMLOAD_CH6SEL)

/*! @brief Set the CH6SEL field to a new value. */
#define BW_FTM_PWMLOAD_CH6SEL(x, v) (HW_FTM_PWMLOAD_WR(x, (HW_FTM_PWMLOAD_RD(x) & ~BM_FTM_PWMLOAD_CH6SEL) | BF_FTM_PWMLOAD_CH6SEL(v)))
/*@}*/

/*!
 * @name Register FTM_PWMLOAD, field CH7SEL[7] (RW)
 *
 * Values:
 * - 0 - Do not include the channel in the matching process.
 * - 1 - Include the channel in the matching process.
 */
/*@{*/
#define BP_FTM_PWMLOAD_CH7SEL (7U)         /*!< Bit position for FTM_PWMLOAD_CH7SEL. */
#define BM_FTM_PWMLOAD_CH7SEL (0x00000080U) /*!< Bit mask for FTM_PWMLOAD_CH7SEL. */
#define BS_FTM_PWMLOAD_CH7SEL (1U)         /*!< Bit field size in bits for FTM_PWMLOAD_CH7SEL. */

/*! @brief Read current value of the FTM_PWMLOAD_CH7SEL field. */
#define BR_FTM_PWMLOAD_CH7SEL(x) (HW_FTM_PWMLOAD(x).B.CH7SEL)

/*! @brief Format value for bitfield FTM_PWMLOAD_CH7SEL. */
#define BF_FTM_PWMLOAD_CH7SEL(v) ((uint32_t)((uint32_t)(v) << BP_FTM_PWMLOAD_CH7SEL) & BM_FTM_PWMLOAD_CH7SEL)

/*! @brief Set the CH7SEL field to a new value. */
#define BW_FTM_PWMLOAD_CH7SEL(x, v) (HW_FTM_PWMLOAD_WR(x, (HW_FTM_PWMLOAD_RD(x) & ~BM_FTM_PWMLOAD_CH7SEL) | BF_FTM_PWMLOAD_CH7SEL(v)))
/*@}*/

/*!
 * @name Register FTM_PWMLOAD, field LDOK[9] (RW)
 *
 * Enables the loading of the MOD, CNTIN, and CV registers with the values of
 * their write buffers.
 *
 * Values:
 * - 0 - Loading updated values is disabled.
 * - 1 - Loading updated values is enabled.
 */
/*@{*/
#define BP_FTM_PWMLOAD_LDOK  (9U)          /*!< Bit position for FTM_PWMLOAD_LDOK. */
#define BM_FTM_PWMLOAD_LDOK  (0x00000200U) /*!< Bit mask for FTM_PWMLOAD_LDOK. */
#define BS_FTM_PWMLOAD_LDOK  (1U)          /*!< Bit field size in bits for FTM_PWMLOAD_LDOK. */

/*! @brief Read current value of the FTM_PWMLOAD_LDOK field. */
#define BR_FTM_PWMLOAD_LDOK(x) (HW_FTM_PWMLOAD(x).B.LDOK)

/*! @brief Format value for bitfield FTM_PWMLOAD_LDOK. */
#define BF_FTM_PWMLOAD_LDOK(v) ((uint32_t)((uint32_t)(v) << BP_FTM_PWMLOAD_LDOK) & BM_FTM_PWMLOAD_LDOK)

/*! @brief Set the LDOK field to a new value. */
#define BW_FTM_PWMLOAD_LDOK(x, v) (HW_FTM_PWMLOAD_WR(x, (HW_FTM_PWMLOAD_RD(x) & ~BM_FTM_PWMLOAD_LDOK) | BF_FTM_PWMLOAD_LDOK(v)))
/*@}*/

/*******************************************************************************
 * hw_ftm_t - module struct
 ******************************************************************************/
/*!
 * @brief All FTM module registers.
 */
#pragma pack(1)
typedef struct _hw_ftm
{
    __IO hw_ftm_sc_t SC;                   /*!< [0x0] Status And Control */
    __IO hw_ftm_cnt_t CNT;                 /*!< [0x4] Counter */
    __IO hw_ftm_mod_t MOD;                 /*!< [0x8] Modulo */
    struct {
        __IO hw_ftm_cnsc_t CnSC;           /*!< [0xC] Channel (n) Status And Control */
        __IO hw_ftm_cnv_t CnV;             /*!< [0x10] Channel (n) Value */
    } C[8];
    __IO hw_ftm_cntin_t CNTIN;             /*!< [0x4C] Counter Initial Value */
    __IO hw_ftm_status_t STATUS;           /*!< [0x50] Capture And Compare Status */
    __IO hw_ftm_mode_t MODE;               /*!< [0x54] Features Mode Selection */
    __IO hw_ftm_sync_t SYNC;               /*!< [0x58] Synchronization */
    __IO hw_ftm_outinit_t OUTINIT;         /*!< [0x5C] Initial State For Channels Output */
    __IO hw_ftm_outmask_t OUTMASK;         /*!< [0x60] Output Mask */
    __IO hw_ftm_combine_t COMBINE;         /*!< [0x64] Function For Linked Channels */
    __IO hw_ftm_deadtime_t DEADTIME;       /*!< [0x68] Deadtime Insertion Control */
    __IO hw_ftm_exttrig_t EXTTRIG;         /*!< [0x6C] FTM External Trigger */
    __IO hw_ftm_pol_t POL;                 /*!< [0x70] Channels Polarity */
    __IO hw_ftm_fms_t FMS;                 /*!< [0x74] Fault Mode Status */
    __IO hw_ftm_filter_t FILTER;           /*!< [0x78] Input Capture Filter Control */
    uint8_t _reserved0[4];
    __IO hw_ftm_qdctrl_t QDCTRL;           /*!< [0x80] Quadrature Decoder Control And Status */
    __IO hw_ftm_conf_t CONF;               /*!< [0x84] Configuration */
    uint8_t _reserved1[4];
    __IO hw_ftm_synconf_t SYNCONF;         /*!< [0x8C] Synchronization Configuration */
    __IO hw_ftm_invctrl_t INVCTRL;         /*!< [0x90] FTM Inverting Control */
    __IO hw_ftm_swoctrl_t SWOCTRL;         /*!< [0x94] FTM Software Output Control */
    __IO hw_ftm_pwmload_t PWMLOAD;         /*!< [0x98] FTM PWM Load */
} hw_ftm_t;
#pragma pack()

/*! @brief Macro to access all FTM registers. */
/*! @param x FTM module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_FTM_REGS(FTM1_BASE)</code>. */
#define HW_FTM_REGS(x) (*(hw_ftm_t *)(x))

/*
 * iMX7D GPC
 *
 * GPC
 *
 * Registers defined in this header file:
 * - HW_GPC_LPCR_A7_BSC - Basic Low power control register of A7 platform
 * - HW_GPC_LPCR_A7_AD - Advanced Low power control register of A7 platform
 * - HW_GPC_LPCR_M4 - Low power control register of CPU1
 * - HW_GPC_SLPCR - System low power control register
 * - HW_GPC_MLPCR - Memory low power control register
 * - HW_GPC_PGC_ACK_SEL_A7 - PGC acknowledge signal selection of A7 platform
 * - HW_GPC_PGC_ACK_SEL_M4 - PGC acknowledge signal selection of M4 platform
 * - HW_GPC_MISC - GPC Miscellaneous register
 * - HW_GPC_IMR1_CORE0_A7 - IRQ masking register 1 of A7 core0
 * - HW_GPC_IMR2_CORE0_A7 - IRQ masking register 2 of A7 core0
 * - HW_GPC_IMR3_CORE0_A7 - IRQ masking register 3 of A7 core0
 * - HW_GPC_IMR4_CORE0_A7 - IRQ masking register 4 of A7 core0
 * - HW_GPC_IMR1_CORE1_A7 - IRQ masking register 1 of A7 core1
 * - HW_GPC_IMR2_CORE1_A7 - IRQ masking register 2 of A7 core1
 * - HW_GPC_IMR3_CORE1_A7 - IRQ masking register 3 of A7 core1
 * - HW_GPC_IMR4_CORE1_A7 - IRQ masking register 4 of A7 core1
 * - HW_GPC_IMR1_M4 - IRQ masking register 1 of M4
 * - HW_GPC_IMR2_M4 - IRQ masking register 2 of M4
 * - HW_GPC_IMR3_M4 - IRQ masking register 3 of M4
 * - HW_GPC_IMR4_M4 - IRQ masking register 4 of M4
 * - HW_GPC_ISR1_A7 - IRQ status register 1 of A7
 * - HW_GPC_ISR2_A7 - IRQ status register 2 of A7
 * - HW_GPC_ISR3_A7 - IRQ status register 3 of A7
 * - HW_GPC_ISR4_A7 - IRQ status register 4 of A7
 * - HW_GPC_ISR1_M4 - IRQ status register 1 of M4
 * - HW_GPC_ISR2_M4 - IRQ status register 2 of M4
 * - HW_GPC_ISR3_M4 - IRQ status register 3 of M4
 * - HW_GPC_ISR4_M4 - IRQ status register 4 of M4
 * - HW_GPC_SLTn_CFG - Slot configure register
 * - HW_GPC_PGC_CPU_MAPPING - PGC CPU mapping
 * - HW_GPC_CPU_PGC_SW_PUP_REQ - CPU PGC software up trigger
 * - HW_GPC_PU_PGC_SW_PUP_REQ - PU PGC software up trigger
 * - HW_GPC_CPU_PGC_SW_PDN_REQ - CPU PGC software down trigger
 * - HW_GPC_PU_PGC_SW_PDN_REQ - PU PGC software down trigger
 * - HW_GPC_CPU_PGC_PUP_STATUS1 - CPU PGC software up trigger status1
 * - HW_GPC_A7_MIX_PGC_PUP_STATUSn - A7 MIX software up trigger status register
 * - HW_GPC_M4_MIX_PGC_PUP_STATUSn - M4 MIX PGC software up trigger status register
 * - HW_GPC_A7_PU_PGC_PUP_STATUSn - A7 PU software up trigger status register
 * - HW_GPC_M4_PU_PGC_PUP_STATUSn - M4 PU PGC software up trigger status register
 * - HW_GPC_CPU_PGC_PDN_STATUS1 - CPU PGC software dn trigger status1
 * - HW_GPC_A7_PU_PGC_PDN_STATUSn - A7 PU PGC software down trigger status
 * - HW_GPC_M4_PU_PGC_PDN_STATUSn - M4 PU PGC software down trigger status
 * - HW_GPC_A7_MIX_PDN_FLG - A7 MIX PDN FLG
 * - HW_GPC_A7_PU_PDN_FLG - A7 PU PDN FLG
 * - HW_GPC_M4_MIX_PDN_FLG - M4 MIX PDN FLG
 * - HW_GPC_M4_PU_PDN_FLG - M4 PU PDN FLG
 *
 * - hw_gpc_t - Struct containing all module registers.
 */

#define HW_GPC_INSTANCE_COUNT (1U) /*!< Number of instances of the GPC module. */
#define HW_GPC (0U) /*!< Instance number for GPC. */
#define GPC_BASE              (0x303A0000U) /*!< Base address for GPC. */
/*! Array initializer of GPC base addresses. */
#define GPC_BASE_ADDRS        { GPC_BASE }

/*******************************************************************************
 * HW_GPC_LPCR_A7_BSC - Basic Low power control register of A7 platform
 ******************************************************************************/

/*!
 * @brief HW_GPC_LPCR_A7_BSC - Basic Low power control register of A7 platform (RW)
 *
 * Reset value: 0x00003FF0U
 *
 * LPCR_A7_BSC[CPU_CLK_ON_LPM] should be set 1'b1 when using A7 low power debug
 * feature Always set LPM1/LPM0 with same value
 */
typedef union _hw_gpc_lpcr_a7_bsc
{
    uint32_t U;
    struct _hw_gpc_lpcr_a7_bsc_bitfields
    {
        uint32_t LPM0 : 2;             /*!< [1:0]  */
        uint32_t LPM1 : 2;             /*!< [3:2]  */
        uint32_t RESERVED0 : 10;       /*!< [13:4]  */
        uint32_t CPU_CLK_ON_LPM : 1;   /*!< [14]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t MASK_CORE0_WFI : 1;   /*!< [16]  */
        uint32_t MASK_CORE1_WFI : 1;   /*!< [17]  */
        uint32_t RESERVED2 : 8;        /*!< [25:18]  */
        uint32_t MASK_L2CC_WFI : 1;    /*!< [26]  */
        uint32_t RESERVED3 : 1;        /*!< [27]  */
        uint32_t IRQ_SRC_C0 : 1;       /*!< [28]  */
        uint32_t IRQ_SRC_C1 : 1;       /*!< [29]  */
        uint32_t IRQ_SRC_A7_WUP : 1;   /*!< [30]  */
        uint32_t MASK_DSM_TRIGGER : 1; /*!< [31]  */
    } B;
} hw_gpc_lpcr_a7_bsc_t;

/*!
 * @name Constants and macros for entire GPC_LPCR_A7_BSC register
 */
/*@{*/
#define HW_GPC_LPCR_A7_BSC_ADDR(x) ((uintptr_t)(x) + 0x0U)

#define HW_GPC_LPCR_A7_BSC(x)    (*(__IO hw_gpc_lpcr_a7_bsc_t *) HW_GPC_LPCR_A7_BSC_ADDR(x))
#define HW_GPC_LPCR_A7_BSC_RD(x) (HW_GPC_LPCR_A7_BSC(x).U)
#define HW_GPC_LPCR_A7_BSC_WR(x, v) (HW_GPC_LPCR_A7_BSC(x).U = (v))
#define HW_GPC_LPCR_A7_BSC_SET(x, v) (HW_GPC_LPCR_A7_BSC_WR(x, HW_GPC_LPCR_A7_BSC_RD(x) |  (v)))
#define HW_GPC_LPCR_A7_BSC_CLR(x, v) (HW_GPC_LPCR_A7_BSC_WR(x, HW_GPC_LPCR_A7_BSC_RD(x) & ~(v)))
#define HW_GPC_LPCR_A7_BSC_TOG(x, v) (HW_GPC_LPCR_A7_BSC_WR(x, HW_GPC_LPCR_A7_BSC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_LPCR_A7_BSC bitfields
 */

/*!
 * @name Register GPC_LPCR_A7_BSC, field LPM0[1:0] (RW)
 *
 * CORE0 Setting the low power mode that system will enter on next assertion of
 * dsm_request signal.
 *
 * Values:
 * - 00 - Remain in RUN mode
 * - 01 - Transfer to WAIT mode
 * - 10 - Transfer to STOP mode
 * - 11 - Reserved
 */
/*@{*/
#define BP_GPC_LPCR_A7_BSC_LPM0 (0U)       /*!< Bit position for GPC_LPCR_A7_BSC_LPM0. */
#define BM_GPC_LPCR_A7_BSC_LPM0 (0x00000003U) /*!< Bit mask for GPC_LPCR_A7_BSC_LPM0. */
#define BS_GPC_LPCR_A7_BSC_LPM0 (2U)       /*!< Bit field size in bits for GPC_LPCR_A7_BSC_LPM0. */

/*! @brief Read current value of the GPC_LPCR_A7_BSC_LPM0 field. */
#define BR_GPC_LPCR_A7_BSC_LPM0(x) (HW_GPC_LPCR_A7_BSC(x).B.LPM0)

/*! @brief Format value for bitfield GPC_LPCR_A7_BSC_LPM0. */
#define BF_GPC_LPCR_A7_BSC_LPM0(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_BSC_LPM0) & BM_GPC_LPCR_A7_BSC_LPM0)

/*! @brief Set the LPM0 field to a new value. */
#define BW_GPC_LPCR_A7_BSC_LPM0(x, v) (HW_GPC_LPCR_A7_BSC_WR(x, (HW_GPC_LPCR_A7_BSC_RD(x) & ~BM_GPC_LPCR_A7_BSC_LPM0) | BF_GPC_LPCR_A7_BSC_LPM0(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_A7_BSC, field LPM1[3:2] (RW)
 *
 * CORE1 Setting the low power mode that system will enter on next assertion of
 * dsm_request signal.
 *
 * Values:
 * - 00 - Remain in RUN mode
 * - 01 - Transfer to WAIT mode
 * - 10 - Transfer to STOP mode
 * - 11 - Reserved
 */
/*@{*/
#define BP_GPC_LPCR_A7_BSC_LPM1 (2U)       /*!< Bit position for GPC_LPCR_A7_BSC_LPM1. */
#define BM_GPC_LPCR_A7_BSC_LPM1 (0x0000000CU) /*!< Bit mask for GPC_LPCR_A7_BSC_LPM1. */
#define BS_GPC_LPCR_A7_BSC_LPM1 (2U)       /*!< Bit field size in bits for GPC_LPCR_A7_BSC_LPM1. */

/*! @brief Read current value of the GPC_LPCR_A7_BSC_LPM1 field. */
#define BR_GPC_LPCR_A7_BSC_LPM1(x) (HW_GPC_LPCR_A7_BSC(x).B.LPM1)

/*! @brief Format value for bitfield GPC_LPCR_A7_BSC_LPM1. */
#define BF_GPC_LPCR_A7_BSC_LPM1(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_BSC_LPM1) & BM_GPC_LPCR_A7_BSC_LPM1)

/*! @brief Set the LPM1 field to a new value. */
#define BW_GPC_LPCR_A7_BSC_LPM1(x, v) (HW_GPC_LPCR_A7_BSC_WR(x, (HW_GPC_LPCR_A7_BSC_RD(x) & ~BM_GPC_LPCR_A7_BSC_LPM1) | BF_GPC_LPCR_A7_BSC_LPM1(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_A7_BSC, field CPU_CLK_ON_LPM[14] (RW)
 *
 * Define if A7 clocks will be disabled on wait/stop mode.
 *
 * Values:
 * - 0 - A7 clock disabled on wait/stop mode
 * - 1 - A7 clock enabled on wait/stop mode
 */
/*@{*/
#define BP_GPC_LPCR_A7_BSC_CPU_CLK_ON_LPM (14U) /*!< Bit position for GPC_LPCR_A7_BSC_CPU_CLK_ON_LPM. */
#define BM_GPC_LPCR_A7_BSC_CPU_CLK_ON_LPM (0x00004000U) /*!< Bit mask for GPC_LPCR_A7_BSC_CPU_CLK_ON_LPM. */
#define BS_GPC_LPCR_A7_BSC_CPU_CLK_ON_LPM (1U) /*!< Bit field size in bits for GPC_LPCR_A7_BSC_CPU_CLK_ON_LPM. */

/*! @brief Read current value of the GPC_LPCR_A7_BSC_CPU_CLK_ON_LPM field. */
#define BR_GPC_LPCR_A7_BSC_CPU_CLK_ON_LPM(x) (HW_GPC_LPCR_A7_BSC(x).B.CPU_CLK_ON_LPM)

/*! @brief Format value for bitfield GPC_LPCR_A7_BSC_CPU_CLK_ON_LPM. */
#define BF_GPC_LPCR_A7_BSC_CPU_CLK_ON_LPM(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_BSC_CPU_CLK_ON_LPM) & BM_GPC_LPCR_A7_BSC_CPU_CLK_ON_LPM)

/*! @brief Set the CPU_CLK_ON_LPM field to a new value. */
#define BW_GPC_LPCR_A7_BSC_CPU_CLK_ON_LPM(x, v) (HW_GPC_LPCR_A7_BSC_WR(x, (HW_GPC_LPCR_A7_BSC_RD(x) & ~BM_GPC_LPCR_A7_BSC_CPU_CLK_ON_LPM) | BF_GPC_LPCR_A7_BSC_CPU_CLK_ON_LPM(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_A7_BSC, field MASK_CORE0_WFI[16] (RW)
 *
 * CORE0 Wait For Interrupt Mask
 *
 * Values:
 * - 0 - WFI for CORE0 is not masked
 * - 1 - WFI for CORE0 is masked
 */
/*@{*/
#define BP_GPC_LPCR_A7_BSC_MASK_CORE0_WFI (16U) /*!< Bit position for GPC_LPCR_A7_BSC_MASK_CORE0_WFI. */
#define BM_GPC_LPCR_A7_BSC_MASK_CORE0_WFI (0x00010000U) /*!< Bit mask for GPC_LPCR_A7_BSC_MASK_CORE0_WFI. */
#define BS_GPC_LPCR_A7_BSC_MASK_CORE0_WFI (1U) /*!< Bit field size in bits for GPC_LPCR_A7_BSC_MASK_CORE0_WFI. */

/*! @brief Read current value of the GPC_LPCR_A7_BSC_MASK_CORE0_WFI field. */
#define BR_GPC_LPCR_A7_BSC_MASK_CORE0_WFI(x) (HW_GPC_LPCR_A7_BSC(x).B.MASK_CORE0_WFI)

/*! @brief Format value for bitfield GPC_LPCR_A7_BSC_MASK_CORE0_WFI. */
#define BF_GPC_LPCR_A7_BSC_MASK_CORE0_WFI(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_BSC_MASK_CORE0_WFI) & BM_GPC_LPCR_A7_BSC_MASK_CORE0_WFI)

/*! @brief Set the MASK_CORE0_WFI field to a new value. */
#define BW_GPC_LPCR_A7_BSC_MASK_CORE0_WFI(x, v) (HW_GPC_LPCR_A7_BSC_WR(x, (HW_GPC_LPCR_A7_BSC_RD(x) & ~BM_GPC_LPCR_A7_BSC_MASK_CORE0_WFI) | BF_GPC_LPCR_A7_BSC_MASK_CORE0_WFI(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_A7_BSC, field MASK_CORE1_WFI[17] (RW)
 *
 * CORE1 Wait For Interrupt Mask
 *
 * Values:
 * - 0 - WFI for CORE1 is not masked
 * - 1 - WFI for CORE1 is masked
 */
/*@{*/
#define BP_GPC_LPCR_A7_BSC_MASK_CORE1_WFI (17U) /*!< Bit position for GPC_LPCR_A7_BSC_MASK_CORE1_WFI. */
#define BM_GPC_LPCR_A7_BSC_MASK_CORE1_WFI (0x00020000U) /*!< Bit mask for GPC_LPCR_A7_BSC_MASK_CORE1_WFI. */
#define BS_GPC_LPCR_A7_BSC_MASK_CORE1_WFI (1U) /*!< Bit field size in bits for GPC_LPCR_A7_BSC_MASK_CORE1_WFI. */

/*! @brief Read current value of the GPC_LPCR_A7_BSC_MASK_CORE1_WFI field. */
#define BR_GPC_LPCR_A7_BSC_MASK_CORE1_WFI(x) (HW_GPC_LPCR_A7_BSC(x).B.MASK_CORE1_WFI)

/*! @brief Format value for bitfield GPC_LPCR_A7_BSC_MASK_CORE1_WFI. */
#define BF_GPC_LPCR_A7_BSC_MASK_CORE1_WFI(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_BSC_MASK_CORE1_WFI) & BM_GPC_LPCR_A7_BSC_MASK_CORE1_WFI)

/*! @brief Set the MASK_CORE1_WFI field to a new value. */
#define BW_GPC_LPCR_A7_BSC_MASK_CORE1_WFI(x, v) (HW_GPC_LPCR_A7_BSC_WR(x, (HW_GPC_LPCR_A7_BSC_RD(x) & ~BM_GPC_LPCR_A7_BSC_MASK_CORE1_WFI) | BF_GPC_LPCR_A7_BSC_MASK_CORE1_WFI(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_A7_BSC, field MASK_L2CC_WFI[26] (RW)
 *
 * L2 cache controller Wait For Interrupt Mask Register
 *
 * Values:
 * - 0 - WFI for L2 cache controller is not masked
 * - 1 - WFI for L2 cache controller is masked
 */
/*@{*/
#define BP_GPC_LPCR_A7_BSC_MASK_L2CC_WFI (26U) /*!< Bit position for GPC_LPCR_A7_BSC_MASK_L2CC_WFI. */
#define BM_GPC_LPCR_A7_BSC_MASK_L2CC_WFI (0x04000000U) /*!< Bit mask for GPC_LPCR_A7_BSC_MASK_L2CC_WFI. */
#define BS_GPC_LPCR_A7_BSC_MASK_L2CC_WFI (1U) /*!< Bit field size in bits for GPC_LPCR_A7_BSC_MASK_L2CC_WFI. */

/*! @brief Read current value of the GPC_LPCR_A7_BSC_MASK_L2CC_WFI field. */
#define BR_GPC_LPCR_A7_BSC_MASK_L2CC_WFI(x) (HW_GPC_LPCR_A7_BSC(x).B.MASK_L2CC_WFI)

/*! @brief Format value for bitfield GPC_LPCR_A7_BSC_MASK_L2CC_WFI. */
#define BF_GPC_LPCR_A7_BSC_MASK_L2CC_WFI(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_BSC_MASK_L2CC_WFI) & BM_GPC_LPCR_A7_BSC_MASK_L2CC_WFI)

/*! @brief Set the MASK_L2CC_WFI field to a new value. */
#define BW_GPC_LPCR_A7_BSC_MASK_L2CC_WFI(x, v) (HW_GPC_LPCR_A7_BSC_WR(x, (HW_GPC_LPCR_A7_BSC_RD(x) & ~BM_GPC_LPCR_A7_BSC_MASK_L2CC_WFI) | BF_GPC_LPCR_A7_BSC_MASK_L2CC_WFI(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_A7_BSC, field IRQ_SRC_C0[28] (RW)
 *
 * LPCR_A7_BSC[IRQ_SRC_CO], LPCR_A7_BSC[IRQ_SRC_C1], and
 * LPCR_A7_BSC[IRQ_SRC_A7_WUP] work together to decide the wake up source for A7 LPM and core0/core1
 * power. Please refer to "Power up process for A7 platform" for more specific
 * information.
 *
 * Values:
 * - 0 - core0 wakeup source from external INT[127:0], masked by IMR0 refer to
 *     "Power up process for A7 platform" for more specific information
 * - 1 - core0 wakeup source from GIC(nFIQ[0]/nIRQ[0] ), SCU should not be power
 *     down during low power mode when this bit is set to 1'b1
 */
/*@{*/
#define BP_GPC_LPCR_A7_BSC_IRQ_SRC_C0 (28U) /*!< Bit position for GPC_LPCR_A7_BSC_IRQ_SRC_C0. */
#define BM_GPC_LPCR_A7_BSC_IRQ_SRC_C0 (0x10000000U) /*!< Bit mask for GPC_LPCR_A7_BSC_IRQ_SRC_C0. */
#define BS_GPC_LPCR_A7_BSC_IRQ_SRC_C0 (1U) /*!< Bit field size in bits for GPC_LPCR_A7_BSC_IRQ_SRC_C0. */

/*! @brief Read current value of the GPC_LPCR_A7_BSC_IRQ_SRC_C0 field. */
#define BR_GPC_LPCR_A7_BSC_IRQ_SRC_C0(x) (HW_GPC_LPCR_A7_BSC(x).B.IRQ_SRC_C0)

/*! @brief Format value for bitfield GPC_LPCR_A7_BSC_IRQ_SRC_C0. */
#define BF_GPC_LPCR_A7_BSC_IRQ_SRC_C0(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_BSC_IRQ_SRC_C0) & BM_GPC_LPCR_A7_BSC_IRQ_SRC_C0)

/*! @brief Set the IRQ_SRC_C0 field to a new value. */
#define BW_GPC_LPCR_A7_BSC_IRQ_SRC_C0(x, v) (HW_GPC_LPCR_A7_BSC_WR(x, (HW_GPC_LPCR_A7_BSC_RD(x) & ~BM_GPC_LPCR_A7_BSC_IRQ_SRC_C0) | BF_GPC_LPCR_A7_BSC_IRQ_SRC_C0(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_A7_BSC, field IRQ_SRC_C1[29] (RW)
 *
 * LPCR_A7_BSC[IRQ_SRC_CO], LPCR_A7_BSC[IRQ_SRC_C1], and
 * LPCR_A7_BSC[IRQ_SRC_A7_WUP] work together to decide the wake up source for A7 LPM and core0/core1
 * power. Please refer to "Power up process for A7 platform" for more specific
 * information.
 *
 * Values:
 * - 0 - core1 wakeup source from external INT[127:0], masked by IMR1 refer to
 *     "Power up process for A7 platform" for more specific information
 * - 1 - core1 wakeup source from GIC(nFIQ[1]/nIRQ[1] ), SCU should not be power
 *     down during low power mode when this bit is set to 1'b1
 */
/*@{*/
#define BP_GPC_LPCR_A7_BSC_IRQ_SRC_C1 (29U) /*!< Bit position for GPC_LPCR_A7_BSC_IRQ_SRC_C1. */
#define BM_GPC_LPCR_A7_BSC_IRQ_SRC_C1 (0x20000000U) /*!< Bit mask for GPC_LPCR_A7_BSC_IRQ_SRC_C1. */
#define BS_GPC_LPCR_A7_BSC_IRQ_SRC_C1 (1U) /*!< Bit field size in bits for GPC_LPCR_A7_BSC_IRQ_SRC_C1. */

/*! @brief Read current value of the GPC_LPCR_A7_BSC_IRQ_SRC_C1 field. */
#define BR_GPC_LPCR_A7_BSC_IRQ_SRC_C1(x) (HW_GPC_LPCR_A7_BSC(x).B.IRQ_SRC_C1)

/*! @brief Format value for bitfield GPC_LPCR_A7_BSC_IRQ_SRC_C1. */
#define BF_GPC_LPCR_A7_BSC_IRQ_SRC_C1(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_BSC_IRQ_SRC_C1) & BM_GPC_LPCR_A7_BSC_IRQ_SRC_C1)

/*! @brief Set the IRQ_SRC_C1 field to a new value. */
#define BW_GPC_LPCR_A7_BSC_IRQ_SRC_C1(x, v) (HW_GPC_LPCR_A7_BSC_WR(x, (HW_GPC_LPCR_A7_BSC_RD(x) & ~BM_GPC_LPCR_A7_BSC_IRQ_SRC_C1) | BF_GPC_LPCR_A7_BSC_IRQ_SRC_C1(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_A7_BSC, field IRQ_SRC_A7_WUP[30] (RW)
 *
 * LPCR_A7_BSC[IRQ_SRC_CO], LPCR_A7_BSC[IRQ_SRC_C1], and
 * LPCR_A7_BSC[IRQ_SRC_A7_WUP] work together to decide the wake up source for A7 LPM and core0/core1
 * power. Please refer to "Power up process for A7 platform" for more specific
 * information.
 *
 * Values:
 * - 0 - LPM wakeup source be "OR" result of
 *     LPCR_A7_BSC[IRQ_SRC_C0]/LPCR_A7_BSC[IRQ_SRC_C1] setting
 * - 1 - LPM wakeup source from external INT[127:0], masked by IMR0
 */
/*@{*/
#define BP_GPC_LPCR_A7_BSC_IRQ_SRC_A7_WUP (30U) /*!< Bit position for GPC_LPCR_A7_BSC_IRQ_SRC_A7_WUP. */
#define BM_GPC_LPCR_A7_BSC_IRQ_SRC_A7_WUP (0x40000000U) /*!< Bit mask for GPC_LPCR_A7_BSC_IRQ_SRC_A7_WUP. */
#define BS_GPC_LPCR_A7_BSC_IRQ_SRC_A7_WUP (1U) /*!< Bit field size in bits for GPC_LPCR_A7_BSC_IRQ_SRC_A7_WUP. */

/*! @brief Read current value of the GPC_LPCR_A7_BSC_IRQ_SRC_A7_WUP field. */
#define BR_GPC_LPCR_A7_BSC_IRQ_SRC_A7_WUP(x) (HW_GPC_LPCR_A7_BSC(x).B.IRQ_SRC_A7_WUP)

/*! @brief Format value for bitfield GPC_LPCR_A7_BSC_IRQ_SRC_A7_WUP. */
#define BF_GPC_LPCR_A7_BSC_IRQ_SRC_A7_WUP(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_BSC_IRQ_SRC_A7_WUP) & BM_GPC_LPCR_A7_BSC_IRQ_SRC_A7_WUP)

/*! @brief Set the IRQ_SRC_A7_WUP field to a new value. */
#define BW_GPC_LPCR_A7_BSC_IRQ_SRC_A7_WUP(x, v) (HW_GPC_LPCR_A7_BSC_WR(x, (HW_GPC_LPCR_A7_BSC_RD(x) & ~BM_GPC_LPCR_A7_BSC_IRQ_SRC_A7_WUP) | BF_GPC_LPCR_A7_BSC_IRQ_SRC_A7_WUP(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_A7_BSC, field MASK_DSM_TRIGGER[31] (RW)
 *
 * DSM Trigger Mask
 *
 * Values:
 * - 0 - DSM trigger of A7 platform will not be masked
 * - 1 - DSM trigger of A7 platform will be masked
 */
/*@{*/
#define BP_GPC_LPCR_A7_BSC_MASK_DSM_TRIGGER (31U) /*!< Bit position for GPC_LPCR_A7_BSC_MASK_DSM_TRIGGER. */
#define BM_GPC_LPCR_A7_BSC_MASK_DSM_TRIGGER (0x80000000U) /*!< Bit mask for GPC_LPCR_A7_BSC_MASK_DSM_TRIGGER. */
#define BS_GPC_LPCR_A7_BSC_MASK_DSM_TRIGGER (1U) /*!< Bit field size in bits for GPC_LPCR_A7_BSC_MASK_DSM_TRIGGER. */

/*! @brief Read current value of the GPC_LPCR_A7_BSC_MASK_DSM_TRIGGER field. */
#define BR_GPC_LPCR_A7_BSC_MASK_DSM_TRIGGER(x) (HW_GPC_LPCR_A7_BSC(x).B.MASK_DSM_TRIGGER)

/*! @brief Format value for bitfield GPC_LPCR_A7_BSC_MASK_DSM_TRIGGER. */
#define BF_GPC_LPCR_A7_BSC_MASK_DSM_TRIGGER(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_BSC_MASK_DSM_TRIGGER) & BM_GPC_LPCR_A7_BSC_MASK_DSM_TRIGGER)

/*! @brief Set the MASK_DSM_TRIGGER field to a new value. */
#define BW_GPC_LPCR_A7_BSC_MASK_DSM_TRIGGER(x, v) (HW_GPC_LPCR_A7_BSC_WR(x, (HW_GPC_LPCR_A7_BSC_RD(x) & ~BM_GPC_LPCR_A7_BSC_MASK_DSM_TRIGGER) | BF_GPC_LPCR_A7_BSC_MASK_DSM_TRIGGER(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_LPCR_A7_AD - Advanced Low power control register of A7 platform
 ******************************************************************************/

/*!
 * @brief HW_GPC_LPCR_A7_AD - Advanced Low power control register of A7 platform (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_lpcr_a7_ad
{
    uint32_t U;
    struct _hw_gpc_lpcr_a7_ad_bitfields
    {
        uint32_t EN_C0_WFI_PDN : 1;    /*!< [0]  */
        uint32_t EN_C0_PDN : 1;        /*!< [1]  */
        uint32_t EN_C1_WFI_PDN : 1;    /*!< [2]  */
        uint32_t EN_C1_PDN : 1;        /*!< [3]  */
        uint32_t EN_PLAT_PDN : 1;      /*!< [4]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t EN_C0_IRQ_PUP : 1;    /*!< [8]  */
        uint32_t EN_C0_PUP : 1;        /*!< [9]  */
        uint32_t EN_C1_IRQ_PUP : 1;    /*!< [10]  */
        uint32_t EN_C1_PUP : 1;        /*!< [11]  */
        uint32_t RESERVED1 : 4;        /*!< [15:12]  */
        uint32_t L2_PGE : 1;           /*!< [16]  */
        uint32_t RESERVED2 : 15;       /*!< [31:17]  */
    } B;
} hw_gpc_lpcr_a7_ad_t;

/*!
 * @name Constants and macros for entire GPC_LPCR_A7_AD register
 */
/*@{*/
#define HW_GPC_LPCR_A7_AD_ADDR(x) ((uintptr_t)(x) + 0x4U)

#define HW_GPC_LPCR_A7_AD(x)     (*(__IO hw_gpc_lpcr_a7_ad_t *) HW_GPC_LPCR_A7_AD_ADDR(x))
#define HW_GPC_LPCR_A7_AD_RD(x)  (HW_GPC_LPCR_A7_AD(x).U)
#define HW_GPC_LPCR_A7_AD_WR(x, v) (HW_GPC_LPCR_A7_AD(x).U = (v))
#define HW_GPC_LPCR_A7_AD_SET(x, v) (HW_GPC_LPCR_A7_AD_WR(x, HW_GPC_LPCR_A7_AD_RD(x) |  (v)))
#define HW_GPC_LPCR_A7_AD_CLR(x, v) (HW_GPC_LPCR_A7_AD_WR(x, HW_GPC_LPCR_A7_AD_RD(x) & ~(v)))
#define HW_GPC_LPCR_A7_AD_TOG(x, v) (HW_GPC_LPCR_A7_AD_WR(x, HW_GPC_LPCR_A7_AD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_LPCR_A7_AD bitfields
 */

/*!
 * @name Register GPC_LPCR_A7_AD, field EN_C0_WFI_PDN[0] (RW)
 *
 * Values:
 * - 0 - CORE0 will not be power down with WFI request
 * - 1 - CORE0 will be power down with WFI request
 */
/*@{*/
#define BP_GPC_LPCR_A7_AD_EN_C0_WFI_PDN (0U) /*!< Bit position for GPC_LPCR_A7_AD_EN_C0_WFI_PDN. */
#define BM_GPC_LPCR_A7_AD_EN_C0_WFI_PDN (0x00000001U) /*!< Bit mask for GPC_LPCR_A7_AD_EN_C0_WFI_PDN. */
#define BS_GPC_LPCR_A7_AD_EN_C0_WFI_PDN (1U) /*!< Bit field size in bits for GPC_LPCR_A7_AD_EN_C0_WFI_PDN. */

/*! @brief Read current value of the GPC_LPCR_A7_AD_EN_C0_WFI_PDN field. */
#define BR_GPC_LPCR_A7_AD_EN_C0_WFI_PDN(x) (HW_GPC_LPCR_A7_AD(x).B.EN_C0_WFI_PDN)

/*! @brief Format value for bitfield GPC_LPCR_A7_AD_EN_C0_WFI_PDN. */
#define BF_GPC_LPCR_A7_AD_EN_C0_WFI_PDN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_AD_EN_C0_WFI_PDN) & BM_GPC_LPCR_A7_AD_EN_C0_WFI_PDN)

/*! @brief Set the EN_C0_WFI_PDN field to a new value. */
#define BW_GPC_LPCR_A7_AD_EN_C0_WFI_PDN(x, v) (HW_GPC_LPCR_A7_AD_WR(x, (HW_GPC_LPCR_A7_AD_RD(x) & ~BM_GPC_LPCR_A7_AD_EN_C0_WFI_PDN) | BF_GPC_LPCR_A7_AD_EN_C0_WFI_PDN(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_A7_AD, field EN_C0_PDN[1] (RW)
 *
 * Values:
 * - 0 - CORE0 will not be power down with low power mode request
 * - 1 - CORE0 will be power down with low power mode request
 */
/*@{*/
#define BP_GPC_LPCR_A7_AD_EN_C0_PDN (1U)   /*!< Bit position for GPC_LPCR_A7_AD_EN_C0_PDN. */
#define BM_GPC_LPCR_A7_AD_EN_C0_PDN (0x00000002U) /*!< Bit mask for GPC_LPCR_A7_AD_EN_C0_PDN. */
#define BS_GPC_LPCR_A7_AD_EN_C0_PDN (1U)   /*!< Bit field size in bits for GPC_LPCR_A7_AD_EN_C0_PDN. */

/*! @brief Read current value of the GPC_LPCR_A7_AD_EN_C0_PDN field. */
#define BR_GPC_LPCR_A7_AD_EN_C0_PDN(x) (HW_GPC_LPCR_A7_AD(x).B.EN_C0_PDN)

/*! @brief Format value for bitfield GPC_LPCR_A7_AD_EN_C0_PDN. */
#define BF_GPC_LPCR_A7_AD_EN_C0_PDN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_AD_EN_C0_PDN) & BM_GPC_LPCR_A7_AD_EN_C0_PDN)

/*! @brief Set the EN_C0_PDN field to a new value. */
#define BW_GPC_LPCR_A7_AD_EN_C0_PDN(x, v) (HW_GPC_LPCR_A7_AD_WR(x, (HW_GPC_LPCR_A7_AD_RD(x) & ~BM_GPC_LPCR_A7_AD_EN_C0_PDN) | BF_GPC_LPCR_A7_AD_EN_C0_PDN(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_A7_AD, field EN_C1_WFI_PDN[2] (RW)
 *
 * Values:
 * - 0 - CORE1 will not be power down with WFI request
 * - 1 - CORE1 will be power down with WFI request
 */
/*@{*/
#define BP_GPC_LPCR_A7_AD_EN_C1_WFI_PDN (2U) /*!< Bit position for GPC_LPCR_A7_AD_EN_C1_WFI_PDN. */
#define BM_GPC_LPCR_A7_AD_EN_C1_WFI_PDN (0x00000004U) /*!< Bit mask for GPC_LPCR_A7_AD_EN_C1_WFI_PDN. */
#define BS_GPC_LPCR_A7_AD_EN_C1_WFI_PDN (1U) /*!< Bit field size in bits for GPC_LPCR_A7_AD_EN_C1_WFI_PDN. */

/*! @brief Read current value of the GPC_LPCR_A7_AD_EN_C1_WFI_PDN field. */
#define BR_GPC_LPCR_A7_AD_EN_C1_WFI_PDN(x) (HW_GPC_LPCR_A7_AD(x).B.EN_C1_WFI_PDN)

/*! @brief Format value for bitfield GPC_LPCR_A7_AD_EN_C1_WFI_PDN. */
#define BF_GPC_LPCR_A7_AD_EN_C1_WFI_PDN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_AD_EN_C1_WFI_PDN) & BM_GPC_LPCR_A7_AD_EN_C1_WFI_PDN)

/*! @brief Set the EN_C1_WFI_PDN field to a new value. */
#define BW_GPC_LPCR_A7_AD_EN_C1_WFI_PDN(x, v) (HW_GPC_LPCR_A7_AD_WR(x, (HW_GPC_LPCR_A7_AD_RD(x) & ~BM_GPC_LPCR_A7_AD_EN_C1_WFI_PDN) | BF_GPC_LPCR_A7_AD_EN_C1_WFI_PDN(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_A7_AD, field EN_C1_PDN[3] (RW)
 *
 * Values:
 * - 0 - CORE1 will not be power down with low power mode request
 * - 1 - CORE1 will be power down with low power mode request
 */
/*@{*/
#define BP_GPC_LPCR_A7_AD_EN_C1_PDN (3U)   /*!< Bit position for GPC_LPCR_A7_AD_EN_C1_PDN. */
#define BM_GPC_LPCR_A7_AD_EN_C1_PDN (0x00000008U) /*!< Bit mask for GPC_LPCR_A7_AD_EN_C1_PDN. */
#define BS_GPC_LPCR_A7_AD_EN_C1_PDN (1U)   /*!< Bit field size in bits for GPC_LPCR_A7_AD_EN_C1_PDN. */

/*! @brief Read current value of the GPC_LPCR_A7_AD_EN_C1_PDN field. */
#define BR_GPC_LPCR_A7_AD_EN_C1_PDN(x) (HW_GPC_LPCR_A7_AD(x).B.EN_C1_PDN)

/*! @brief Format value for bitfield GPC_LPCR_A7_AD_EN_C1_PDN. */
#define BF_GPC_LPCR_A7_AD_EN_C1_PDN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_AD_EN_C1_PDN) & BM_GPC_LPCR_A7_AD_EN_C1_PDN)

/*! @brief Set the EN_C1_PDN field to a new value. */
#define BW_GPC_LPCR_A7_AD_EN_C1_PDN(x, v) (HW_GPC_LPCR_A7_AD_WR(x, (HW_GPC_LPCR_A7_AD_RD(x) & ~BM_GPC_LPCR_A7_AD_EN_C1_PDN) | BF_GPC_LPCR_A7_AD_EN_C1_PDN(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_A7_AD, field EN_PLAT_PDN[4] (RW)
 *
 * Values:
 * - 0 - SCU and L2 cache RAM will not be power down with low power mode request
 * - 1 - SCU and L2 cache RAM will be power down with low power mode request
 */
/*@{*/
#define BP_GPC_LPCR_A7_AD_EN_PLAT_PDN (4U) /*!< Bit position for GPC_LPCR_A7_AD_EN_PLAT_PDN. */
#define BM_GPC_LPCR_A7_AD_EN_PLAT_PDN (0x00000010U) /*!< Bit mask for GPC_LPCR_A7_AD_EN_PLAT_PDN. */
#define BS_GPC_LPCR_A7_AD_EN_PLAT_PDN (1U) /*!< Bit field size in bits for GPC_LPCR_A7_AD_EN_PLAT_PDN. */

/*! @brief Read current value of the GPC_LPCR_A7_AD_EN_PLAT_PDN field. */
#define BR_GPC_LPCR_A7_AD_EN_PLAT_PDN(x) (HW_GPC_LPCR_A7_AD(x).B.EN_PLAT_PDN)

/*! @brief Format value for bitfield GPC_LPCR_A7_AD_EN_PLAT_PDN. */
#define BF_GPC_LPCR_A7_AD_EN_PLAT_PDN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_AD_EN_PLAT_PDN) & BM_GPC_LPCR_A7_AD_EN_PLAT_PDN)

/*! @brief Set the EN_PLAT_PDN field to a new value. */
#define BW_GPC_LPCR_A7_AD_EN_PLAT_PDN(x, v) (HW_GPC_LPCR_A7_AD_WR(x, (HW_GPC_LPCR_A7_AD_RD(x) & ~BM_GPC_LPCR_A7_AD_EN_PLAT_PDN) | BF_GPC_LPCR_A7_AD_EN_PLAT_PDN(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_A7_AD, field EN_C0_IRQ_PUP[8] (RW)
 *
 * Values:
 * - 0 - CORE0 will power up with IRQ request
 * - 1 - CORE0 will not power up with IRQ request
 */
/*@{*/
#define BP_GPC_LPCR_A7_AD_EN_C0_IRQ_PUP (8U) /*!< Bit position for GPC_LPCR_A7_AD_EN_C0_IRQ_PUP. */
#define BM_GPC_LPCR_A7_AD_EN_C0_IRQ_PUP (0x00000100U) /*!< Bit mask for GPC_LPCR_A7_AD_EN_C0_IRQ_PUP. */
#define BS_GPC_LPCR_A7_AD_EN_C0_IRQ_PUP (1U) /*!< Bit field size in bits for GPC_LPCR_A7_AD_EN_C0_IRQ_PUP. */

/*! @brief Read current value of the GPC_LPCR_A7_AD_EN_C0_IRQ_PUP field. */
#define BR_GPC_LPCR_A7_AD_EN_C0_IRQ_PUP(x) (HW_GPC_LPCR_A7_AD(x).B.EN_C0_IRQ_PUP)

/*! @brief Format value for bitfield GPC_LPCR_A7_AD_EN_C0_IRQ_PUP. */
#define BF_GPC_LPCR_A7_AD_EN_C0_IRQ_PUP(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_AD_EN_C0_IRQ_PUP) & BM_GPC_LPCR_A7_AD_EN_C0_IRQ_PUP)

/*! @brief Set the EN_C0_IRQ_PUP field to a new value. */
#define BW_GPC_LPCR_A7_AD_EN_C0_IRQ_PUP(x, v) (HW_GPC_LPCR_A7_AD_WR(x, (HW_GPC_LPCR_A7_AD_RD(x) & ~BM_GPC_LPCR_A7_AD_EN_C0_IRQ_PUP) | BF_GPC_LPCR_A7_AD_EN_C0_IRQ_PUP(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_A7_AD, field EN_C0_PUP[9] (RW)
 *
 * (only used wake up from CPU01_OFF mode)
 *
 * Values:
 * - 0 - CORE0 will power up with low power mode request
 * - 1 - CORE0 will not power up with low power mode request
 */
/*@{*/
#define BP_GPC_LPCR_A7_AD_EN_C0_PUP (9U)   /*!< Bit position for GPC_LPCR_A7_AD_EN_C0_PUP. */
#define BM_GPC_LPCR_A7_AD_EN_C0_PUP (0x00000200U) /*!< Bit mask for GPC_LPCR_A7_AD_EN_C0_PUP. */
#define BS_GPC_LPCR_A7_AD_EN_C0_PUP (1U)   /*!< Bit field size in bits for GPC_LPCR_A7_AD_EN_C0_PUP. */

/*! @brief Read current value of the GPC_LPCR_A7_AD_EN_C0_PUP field. */
#define BR_GPC_LPCR_A7_AD_EN_C0_PUP(x) (HW_GPC_LPCR_A7_AD(x).B.EN_C0_PUP)

/*! @brief Format value for bitfield GPC_LPCR_A7_AD_EN_C0_PUP. */
#define BF_GPC_LPCR_A7_AD_EN_C0_PUP(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_AD_EN_C0_PUP) & BM_GPC_LPCR_A7_AD_EN_C0_PUP)

/*! @brief Set the EN_C0_PUP field to a new value. */
#define BW_GPC_LPCR_A7_AD_EN_C0_PUP(x, v) (HW_GPC_LPCR_A7_AD_WR(x, (HW_GPC_LPCR_A7_AD_RD(x) & ~BM_GPC_LPCR_A7_AD_EN_C0_PUP) | BF_GPC_LPCR_A7_AD_EN_C0_PUP(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_A7_AD, field EN_C1_IRQ_PUP[10] (RW)
 *
 * Values:
 * - 0 - CORE1 will power up with IRQ request
 * - 1 - CORE1 will not power up with IRQ request
 */
/*@{*/
#define BP_GPC_LPCR_A7_AD_EN_C1_IRQ_PUP (10U) /*!< Bit position for GPC_LPCR_A7_AD_EN_C1_IRQ_PUP. */
#define BM_GPC_LPCR_A7_AD_EN_C1_IRQ_PUP (0x00000400U) /*!< Bit mask for GPC_LPCR_A7_AD_EN_C1_IRQ_PUP. */
#define BS_GPC_LPCR_A7_AD_EN_C1_IRQ_PUP (1U) /*!< Bit field size in bits for GPC_LPCR_A7_AD_EN_C1_IRQ_PUP. */

/*! @brief Read current value of the GPC_LPCR_A7_AD_EN_C1_IRQ_PUP field. */
#define BR_GPC_LPCR_A7_AD_EN_C1_IRQ_PUP(x) (HW_GPC_LPCR_A7_AD(x).B.EN_C1_IRQ_PUP)

/*! @brief Format value for bitfield GPC_LPCR_A7_AD_EN_C1_IRQ_PUP. */
#define BF_GPC_LPCR_A7_AD_EN_C1_IRQ_PUP(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_AD_EN_C1_IRQ_PUP) & BM_GPC_LPCR_A7_AD_EN_C1_IRQ_PUP)

/*! @brief Set the EN_C1_IRQ_PUP field to a new value. */
#define BW_GPC_LPCR_A7_AD_EN_C1_IRQ_PUP(x, v) (HW_GPC_LPCR_A7_AD_WR(x, (HW_GPC_LPCR_A7_AD_RD(x) & ~BM_GPC_LPCR_A7_AD_EN_C1_IRQ_PUP) | BF_GPC_LPCR_A7_AD_EN_C1_IRQ_PUP(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_A7_AD, field EN_C1_PUP[11] (RW)
 *
 * Values:
 * - 0 - CORE1 will power up with low power mode request
 * - 1 - CORE1 will not power up with low power mode request (only used wake up
 *     from CPU01_OFF mode)
 */
/*@{*/
#define BP_GPC_LPCR_A7_AD_EN_C1_PUP (11U)  /*!< Bit position for GPC_LPCR_A7_AD_EN_C1_PUP. */
#define BM_GPC_LPCR_A7_AD_EN_C1_PUP (0x00000800U) /*!< Bit mask for GPC_LPCR_A7_AD_EN_C1_PUP. */
#define BS_GPC_LPCR_A7_AD_EN_C1_PUP (1U)   /*!< Bit field size in bits for GPC_LPCR_A7_AD_EN_C1_PUP. */

/*! @brief Read current value of the GPC_LPCR_A7_AD_EN_C1_PUP field. */
#define BR_GPC_LPCR_A7_AD_EN_C1_PUP(x) (HW_GPC_LPCR_A7_AD(x).B.EN_C1_PUP)

/*! @brief Format value for bitfield GPC_LPCR_A7_AD_EN_C1_PUP. */
#define BF_GPC_LPCR_A7_AD_EN_C1_PUP(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_AD_EN_C1_PUP) & BM_GPC_LPCR_A7_AD_EN_C1_PUP)

/*! @brief Set the EN_C1_PUP field to a new value. */
#define BW_GPC_LPCR_A7_AD_EN_C1_PUP(x, v) (HW_GPC_LPCR_A7_AD_WR(x, (HW_GPC_LPCR_A7_AD_RD(x) & ~BM_GPC_LPCR_A7_AD_EN_C1_PUP) | BF_GPC_LPCR_A7_AD_EN_C1_PUP(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_A7_AD, field L2_PGE[16] (RW)
 *
 * Values:
 * - 0 - L2 cache RAM will power down with SCU power domain in A7 platform (used
 *     for ALL_OFF mode)
 * - 1 - L2 cache RAM will not power down with SCU power domain in A7 platform
 *     (used for L2 retention mode)
 */
/*@{*/
#define BP_GPC_LPCR_A7_AD_L2_PGE (16U)     /*!< Bit position for GPC_LPCR_A7_AD_L2_PGE. */
#define BM_GPC_LPCR_A7_AD_L2_PGE (0x00010000U) /*!< Bit mask for GPC_LPCR_A7_AD_L2_PGE. */
#define BS_GPC_LPCR_A7_AD_L2_PGE (1U)      /*!< Bit field size in bits for GPC_LPCR_A7_AD_L2_PGE. */

/*! @brief Read current value of the GPC_LPCR_A7_AD_L2_PGE field. */
#define BR_GPC_LPCR_A7_AD_L2_PGE(x) (HW_GPC_LPCR_A7_AD(x).B.L2_PGE)

/*! @brief Format value for bitfield GPC_LPCR_A7_AD_L2_PGE. */
#define BF_GPC_LPCR_A7_AD_L2_PGE(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_A7_AD_L2_PGE) & BM_GPC_LPCR_A7_AD_L2_PGE)

/*! @brief Set the L2_PGE field to a new value. */
#define BW_GPC_LPCR_A7_AD_L2_PGE(x, v) (HW_GPC_LPCR_A7_AD_WR(x, (HW_GPC_LPCR_A7_AD_RD(x) & ~BM_GPC_LPCR_A7_AD_L2_PGE) | BF_GPC_LPCR_A7_AD_L2_PGE(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_LPCR_M4 - Low power control register of CPU1
 ******************************************************************************/

/*!
 * @brief HW_GPC_LPCR_M4 - Low power control register of CPU1 (RW)
 *
 * Reset value: 0x00003FF0U
 *
 * LPCR_M4[CPU_CLK_ON_LPM] should be set 1'b0 if M4 goes to LPM without trigger
 * power down of related domains
 */
typedef union _hw_gpc_lpcr_m4
{
    uint32_t U;
    struct _hw_gpc_lpcr_m4_bitfields
    {
        uint32_t LPM0 : 2;             /*!< [1:0]  */
        uint32_t EN_M4_PDN : 1;        /*!< [2]  */
        uint32_t EN_M4_PUP : 1;        /*!< [3]  */
        uint32_t RESERVED0 : 10;       /*!< [13:4]  */
        uint32_t CPU_CLK_ON_LPM : 1;   /*!< [14]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t MASK_M4_WFI : 1;      /*!< [16]  */
        uint32_t RESERVED2 : 14;       /*!< [30:17]  */
        uint32_t MASK_DSM_TRIGGER : 1; /*!< [31]  */
    } B;
} hw_gpc_lpcr_m4_t;

/*!
 * @name Constants and macros for entire GPC_LPCR_M4 register
 */
/*@{*/
#define HW_GPC_LPCR_M4_ADDR(x)   ((uintptr_t)(x) + 0x8U)

#define HW_GPC_LPCR_M4(x)        (*(__IO hw_gpc_lpcr_m4_t *) HW_GPC_LPCR_M4_ADDR(x))
#define HW_GPC_LPCR_M4_RD(x)     (HW_GPC_LPCR_M4(x).U)
#define HW_GPC_LPCR_M4_WR(x, v)  (HW_GPC_LPCR_M4(x).U = (v))
#define HW_GPC_LPCR_M4_SET(x, v) (HW_GPC_LPCR_M4_WR(x, HW_GPC_LPCR_M4_RD(x) |  (v)))
#define HW_GPC_LPCR_M4_CLR(x, v) (HW_GPC_LPCR_M4_WR(x, HW_GPC_LPCR_M4_RD(x) & ~(v)))
#define HW_GPC_LPCR_M4_TOG(x, v) (HW_GPC_LPCR_M4_WR(x, HW_GPC_LPCR_M4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_LPCR_M4 bitfields
 */

/*!
 * @name Register GPC_LPCR_M4, field LPM0[1:0] (RW)
 *
 * Setting the low power mode that system will enter on next assertion of
 * dsm_request signal.
 *
 * Values:
 * - 00 - Remain in RUN mode
 * - 01 - Transfer to WAIT mode
 * - 10 - Transfer to STOP mode
 * - 11 - Reserved
 */
/*@{*/
#define BP_GPC_LPCR_M4_LPM0  (0U)          /*!< Bit position for GPC_LPCR_M4_LPM0. */
#define BM_GPC_LPCR_M4_LPM0  (0x00000003U) /*!< Bit mask for GPC_LPCR_M4_LPM0. */
#define BS_GPC_LPCR_M4_LPM0  (2U)          /*!< Bit field size in bits for GPC_LPCR_M4_LPM0. */

/*! @brief Read current value of the GPC_LPCR_M4_LPM0 field. */
#define BR_GPC_LPCR_M4_LPM0(x) (HW_GPC_LPCR_M4(x).B.LPM0)

/*! @brief Format value for bitfield GPC_LPCR_M4_LPM0. */
#define BF_GPC_LPCR_M4_LPM0(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_M4_LPM0) & BM_GPC_LPCR_M4_LPM0)

/*! @brief Set the LPM0 field to a new value. */
#define BW_GPC_LPCR_M4_LPM0(x, v) (HW_GPC_LPCR_M4_WR(x, (HW_GPC_LPCR_M4_RD(x) & ~BM_GPC_LPCR_M4_LPM0) | BF_GPC_LPCR_M4_LPM0(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_M4, field EN_M4_PDN[2] (RW)
 *
 * Enable m4 virtual PGC power down with LPM enter
 */
/*@{*/
#define BP_GPC_LPCR_M4_EN_M4_PDN (2U)      /*!< Bit position for GPC_LPCR_M4_EN_M4_PDN. */
#define BM_GPC_LPCR_M4_EN_M4_PDN (0x00000004U) /*!< Bit mask for GPC_LPCR_M4_EN_M4_PDN. */
#define BS_GPC_LPCR_M4_EN_M4_PDN (1U)      /*!< Bit field size in bits for GPC_LPCR_M4_EN_M4_PDN. */

/*! @brief Read current value of the GPC_LPCR_M4_EN_M4_PDN field. */
#define BR_GPC_LPCR_M4_EN_M4_PDN(x) (HW_GPC_LPCR_M4(x).B.EN_M4_PDN)

/*! @brief Format value for bitfield GPC_LPCR_M4_EN_M4_PDN. */
#define BF_GPC_LPCR_M4_EN_M4_PDN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_M4_EN_M4_PDN) & BM_GPC_LPCR_M4_EN_M4_PDN)

/*! @brief Set the EN_M4_PDN field to a new value. */
#define BW_GPC_LPCR_M4_EN_M4_PDN(x, v) (HW_GPC_LPCR_M4_WR(x, (HW_GPC_LPCR_M4_RD(x) & ~BM_GPC_LPCR_M4_EN_M4_PDN) | BF_GPC_LPCR_M4_EN_M4_PDN(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_M4, field EN_M4_PUP[3] (RW)
 *
 * Enable m4 virtual PGC power up with LPM enter
 */
/*@{*/
#define BP_GPC_LPCR_M4_EN_M4_PUP (3U)      /*!< Bit position for GPC_LPCR_M4_EN_M4_PUP. */
#define BM_GPC_LPCR_M4_EN_M4_PUP (0x00000008U) /*!< Bit mask for GPC_LPCR_M4_EN_M4_PUP. */
#define BS_GPC_LPCR_M4_EN_M4_PUP (1U)      /*!< Bit field size in bits for GPC_LPCR_M4_EN_M4_PUP. */

/*! @brief Read current value of the GPC_LPCR_M4_EN_M4_PUP field. */
#define BR_GPC_LPCR_M4_EN_M4_PUP(x) (HW_GPC_LPCR_M4(x).B.EN_M4_PUP)

/*! @brief Format value for bitfield GPC_LPCR_M4_EN_M4_PUP. */
#define BF_GPC_LPCR_M4_EN_M4_PUP(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_M4_EN_M4_PUP) & BM_GPC_LPCR_M4_EN_M4_PUP)

/*! @brief Set the EN_M4_PUP field to a new value. */
#define BW_GPC_LPCR_M4_EN_M4_PUP(x, v) (HW_GPC_LPCR_M4_WR(x, (HW_GPC_LPCR_M4_RD(x) & ~BM_GPC_LPCR_M4_EN_M4_PUP) | BF_GPC_LPCR_M4_EN_M4_PUP(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_M4, field CPU_CLK_ON_LPM[14] (RW)
 *
 * Define if M4 clocks will be disabled on wait/stop mode.
 *
 * Values:
 * - 0 - M4 clock disabled on wait/stop mode.
 * - 1 - M4 clock enabled on wait/stop mode.
 */
/*@{*/
#define BP_GPC_LPCR_M4_CPU_CLK_ON_LPM (14U) /*!< Bit position for GPC_LPCR_M4_CPU_CLK_ON_LPM. */
#define BM_GPC_LPCR_M4_CPU_CLK_ON_LPM (0x00004000U) /*!< Bit mask for GPC_LPCR_M4_CPU_CLK_ON_LPM. */
#define BS_GPC_LPCR_M4_CPU_CLK_ON_LPM (1U) /*!< Bit field size in bits for GPC_LPCR_M4_CPU_CLK_ON_LPM. */

/*! @brief Read current value of the GPC_LPCR_M4_CPU_CLK_ON_LPM field. */
#define BR_GPC_LPCR_M4_CPU_CLK_ON_LPM(x) (HW_GPC_LPCR_M4(x).B.CPU_CLK_ON_LPM)

/*! @brief Format value for bitfield GPC_LPCR_M4_CPU_CLK_ON_LPM. */
#define BF_GPC_LPCR_M4_CPU_CLK_ON_LPM(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_M4_CPU_CLK_ON_LPM) & BM_GPC_LPCR_M4_CPU_CLK_ON_LPM)

/*! @brief Set the CPU_CLK_ON_LPM field to a new value. */
#define BW_GPC_LPCR_M4_CPU_CLK_ON_LPM(x, v) (HW_GPC_LPCR_M4_WR(x, (HW_GPC_LPCR_M4_RD(x) & ~BM_GPC_LPCR_M4_CPU_CLK_ON_LPM) | BF_GPC_LPCR_M4_CPU_CLK_ON_LPM(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_M4, field MASK_M4_WFI[16] (RW)
 *
 * M4 WFI Mask
 *
 * Values:
 * - 0 - WFI for M4 is not masked
 * - 1 - WFI for M4 is masked
 */
/*@{*/
#define BP_GPC_LPCR_M4_MASK_M4_WFI (16U)   /*!< Bit position for GPC_LPCR_M4_MASK_M4_WFI. */
#define BM_GPC_LPCR_M4_MASK_M4_WFI (0x00010000U) /*!< Bit mask for GPC_LPCR_M4_MASK_M4_WFI. */
#define BS_GPC_LPCR_M4_MASK_M4_WFI (1U)    /*!< Bit field size in bits for GPC_LPCR_M4_MASK_M4_WFI. */

/*! @brief Read current value of the GPC_LPCR_M4_MASK_M4_WFI field. */
#define BR_GPC_LPCR_M4_MASK_M4_WFI(x) (HW_GPC_LPCR_M4(x).B.MASK_M4_WFI)

/*! @brief Format value for bitfield GPC_LPCR_M4_MASK_M4_WFI. */
#define BF_GPC_LPCR_M4_MASK_M4_WFI(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_M4_MASK_M4_WFI) & BM_GPC_LPCR_M4_MASK_M4_WFI)

/*! @brief Set the MASK_M4_WFI field to a new value. */
#define BW_GPC_LPCR_M4_MASK_M4_WFI(x, v) (HW_GPC_LPCR_M4_WR(x, (HW_GPC_LPCR_M4_RD(x) & ~BM_GPC_LPCR_M4_MASK_M4_WFI) | BF_GPC_LPCR_M4_MASK_M4_WFI(v)))
/*@}*/

/*!
 * @name Register GPC_LPCR_M4, field MASK_DSM_TRIGGER[31] (RW)
 *
 * M4 WFI Mask
 *
 * Values:
 * - 0 - DSM trigger of M4 platform will not be masked
 * - 1 - DSM trigger of M4 platform will be masked
 */
/*@{*/
#define BP_GPC_LPCR_M4_MASK_DSM_TRIGGER (31U) /*!< Bit position for GPC_LPCR_M4_MASK_DSM_TRIGGER. */
#define BM_GPC_LPCR_M4_MASK_DSM_TRIGGER (0x80000000U) /*!< Bit mask for GPC_LPCR_M4_MASK_DSM_TRIGGER. */
#define BS_GPC_LPCR_M4_MASK_DSM_TRIGGER (1U) /*!< Bit field size in bits for GPC_LPCR_M4_MASK_DSM_TRIGGER. */

/*! @brief Read current value of the GPC_LPCR_M4_MASK_DSM_TRIGGER field. */
#define BR_GPC_LPCR_M4_MASK_DSM_TRIGGER(x) (HW_GPC_LPCR_M4(x).B.MASK_DSM_TRIGGER)

/*! @brief Format value for bitfield GPC_LPCR_M4_MASK_DSM_TRIGGER. */
#define BF_GPC_LPCR_M4_MASK_DSM_TRIGGER(v) ((uint32_t)((uint32_t)(v) << BP_GPC_LPCR_M4_MASK_DSM_TRIGGER) & BM_GPC_LPCR_M4_MASK_DSM_TRIGGER)

/*! @brief Set the MASK_DSM_TRIGGER field to a new value. */
#define BW_GPC_LPCR_M4_MASK_DSM_TRIGGER(x, v) (HW_GPC_LPCR_M4_WR(x, (HW_GPC_LPCR_M4_RD(x) & ~BM_GPC_LPCR_M4_MASK_DSM_TRIGGER) | BF_GPC_LPCR_M4_MASK_DSM_TRIGGER(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_SLPCR - System low power control register
 ******************************************************************************/

/*!
 * @brief HW_GPC_SLPCR - System low power control register (RW)
 *
 * Reset value: 0x0000FF82U
 *
 * SLPCR[VSTBY] must be set to 1'b1 if SLPCR[RBC_EN] is set to 1'b1;
 * SLPCR[SBYOS] must be set to 1'b1 if SLPCR[VSTBY] is set to 1'b1.
 */
typedef union _hw_gpc_slpcr
{
    uint32_t U;
    struct _hw_gpc_slpcr_bitfields
    {
        uint32_t BYPASS_PMIC_READY : 1; /*!< [0]  */
        uint32_t SBYOS : 1;            /*!< [1]  */
        uint32_t VSTBY : 1;            /*!< [2]  */
        uint32_t STBY_COUNT : 3;       /*!< [5:3]  */
        uint32_t COSC_PWRDOWN : 1;     /*!< [6]  */
        uint32_t COSC_EN : 1;          /*!< [7]  */
        uint32_t OSCCNT : 8;           /*!< [15:8]  */
        uint32_t EN_A7_FASTWUP_WAIT_MODE : 1; /*!< [16]  */
        uint32_t EN_A7_FASTWUP_STOP_MODE : 1; /*!< [17]  */
        uint32_t EN_M4_FASTWUP_WAIT_MODE : 1; /*!< [18]  */
        uint32_t EN_M4_FASTWUP_STOP_MODE : 1; /*!< [19]  */
        uint32_t RESERVED0 : 3;        /*!< [22:20]  */
        uint32_t DISABLE_A7_IS_DSM : 1; /*!< [23]  */
        uint32_t REG_BYPASS_COUNT : 6; /*!< [29:24]  */
        uint32_t RBC_EN : 1;           /*!< [30]  */
        uint32_t EN_DSM : 1;           /*!< [31]  */
    } B;
} hw_gpc_slpcr_t;

/*!
 * @name Constants and macros for entire GPC_SLPCR register
 */
/*@{*/
#define HW_GPC_SLPCR_ADDR(x)     ((uintptr_t)(x) + 0x14U)

#define HW_GPC_SLPCR(x)          (*(__IO hw_gpc_slpcr_t *) HW_GPC_SLPCR_ADDR(x))
#define HW_GPC_SLPCR_RD(x)       (HW_GPC_SLPCR(x).U)
#define HW_GPC_SLPCR_WR(x, v)    (HW_GPC_SLPCR(x).U = (v))
#define HW_GPC_SLPCR_SET(x, v)   (HW_GPC_SLPCR_WR(x, HW_GPC_SLPCR_RD(x) |  (v)))
#define HW_GPC_SLPCR_CLR(x, v)   (HW_GPC_SLPCR_WR(x, HW_GPC_SLPCR_RD(x) & ~(v)))
#define HW_GPC_SLPCR_TOG(x, v)   (HW_GPC_SLPCR_WR(x, HW_GPC_SLPCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_SLPCR bitfields
 */

/*!
 * @name Register GPC_SLPCR, field BYPASS_PMIC_READY[0] (RW)
 *
 * By asserting this bit GPC will bypass waiting for PMIC_READY signal when
 * coming out of DSM. This should be used for PMIC's that don't support the
 * PMIC_READY signal.
 *
 * Values:
 * - 0 - Don't bypass the PMIC_READY signal - GPC will wait for its assertion
 *     during exit of low power mode if standby voltage was enabled
 * - 1 - Bypass the PMIC_READY signal - GPC will wait for its assertion during
 *     exit of low power mode if standby voltage was enabled
 */
/*@{*/
#define BP_GPC_SLPCR_BYPASS_PMIC_READY (0U) /*!< Bit position for GPC_SLPCR_BYPASS_PMIC_READY. */
#define BM_GPC_SLPCR_BYPASS_PMIC_READY (0x00000001U) /*!< Bit mask for GPC_SLPCR_BYPASS_PMIC_READY. */
#define BS_GPC_SLPCR_BYPASS_PMIC_READY (1U) /*!< Bit field size in bits for GPC_SLPCR_BYPASS_PMIC_READY. */

/*! @brief Read current value of the GPC_SLPCR_BYPASS_PMIC_READY field. */
#define BR_GPC_SLPCR_BYPASS_PMIC_READY(x) (HW_GPC_SLPCR(x).B.BYPASS_PMIC_READY)

/*! @brief Format value for bitfield GPC_SLPCR_BYPASS_PMIC_READY. */
#define BF_GPC_SLPCR_BYPASS_PMIC_READY(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLPCR_BYPASS_PMIC_READY) & BM_GPC_SLPCR_BYPASS_PMIC_READY)

/*! @brief Set the BYPASS_PMIC_READY field to a new value. */
#define BW_GPC_SLPCR_BYPASS_PMIC_READY(x, v) (HW_GPC_SLPCR_WR(x, (HW_GPC_SLPCR_RD(x) & ~BM_GPC_SLPCR_BYPASS_PMIC_READY) | BF_GPC_SLPCR_BYPASS_PMIC_READY(v)))
/*@}*/

/*!
 * @name Register GPC_SLPCR, field SBYOS[1] (RW)
 *
 * Standby clock oscillator bit. This bit defines if cosc_pwrdown, which power
 * down the on chip oscillator, will be asserted in DSM.
 *
 * Values:
 * - 0 - On chip oscillator will not be powered down, after next entrance to DSM.
 * - 1 - On chip oscillator will be powered down, after next entrance to DSM.
 *     When returning from DSM, external oscillator will be enabled again, on chip
 *     oscillator will return to oscillator mode , and after oscnt count GPC will
 *     continue with the exit from DSM process.
 */
/*@{*/
#define BP_GPC_SLPCR_SBYOS   (1U)          /*!< Bit position for GPC_SLPCR_SBYOS. */
#define BM_GPC_SLPCR_SBYOS   (0x00000002U) /*!< Bit mask for GPC_SLPCR_SBYOS. */
#define BS_GPC_SLPCR_SBYOS   (1U)          /*!< Bit field size in bits for GPC_SLPCR_SBYOS. */

/*! @brief Read current value of the GPC_SLPCR_SBYOS field. */
#define BR_GPC_SLPCR_SBYOS(x) (HW_GPC_SLPCR(x).B.SBYOS)

/*! @brief Format value for bitfield GPC_SLPCR_SBYOS. */
#define BF_GPC_SLPCR_SBYOS(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLPCR_SBYOS) & BM_GPC_SLPCR_SBYOS)

/*! @brief Set the SBYOS field to a new value. */
#define BW_GPC_SLPCR_SBYOS(x, v) (HW_GPC_SLPCR_WR(x, (HW_GPC_SLPCR_RD(x) & ~BM_GPC_SLPCR_SBYOS) | BF_GPC_SLPCR_SBYOS(v)))
/*@}*/

/*!
 * @name Register GPC_SLPCR, field VSTBY[2] (RW)
 *
 * Voltage standby request bit. This bit defines if PMIC_STBY_REQ pin, which
 * notifies external power management IC to move from functional voltage to standby
 * voltage, will be asserted in stop mode.
 *
 * Values:
 * - 0 - Voltage will not be changed to standby voltage after next entrance to
 *     stop mode. (PMIC_STBY_REQ will remain negated - '0')
 * - 1 - Voltage will be changed to standby voltage after next entrance to stop
 *     mode.
 */
/*@{*/
#define BP_GPC_SLPCR_VSTBY   (2U)          /*!< Bit position for GPC_SLPCR_VSTBY. */
#define BM_GPC_SLPCR_VSTBY   (0x00000004U) /*!< Bit mask for GPC_SLPCR_VSTBY. */
#define BS_GPC_SLPCR_VSTBY   (1U)          /*!< Bit field size in bits for GPC_SLPCR_VSTBY. */

/*! @brief Read current value of the GPC_SLPCR_VSTBY field. */
#define BR_GPC_SLPCR_VSTBY(x) (HW_GPC_SLPCR(x).B.VSTBY)

/*! @brief Format value for bitfield GPC_SLPCR_VSTBY. */
#define BF_GPC_SLPCR_VSTBY(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLPCR_VSTBY) & BM_GPC_SLPCR_VSTBY)

/*! @brief Set the VSTBY field to a new value. */
#define BW_GPC_SLPCR_VSTBY(x, v) (HW_GPC_SLPCR_WR(x, (HW_GPC_SLPCR_RD(x) & ~BM_GPC_SLPCR_VSTBY) | BF_GPC_SLPCR_VSTBY(v)))
/*@}*/

/*!
 * @name Register GPC_SLPCR, field STBY_COUNT[5:3] (RW)
 *
 * Standby counter definition. These two bits define, in the case of stop exit
 * (if VSTBY bit was set), the amount of time GPC will wait between PMIC_STBY_REQ
 * negation and the check of assertion of PMIC_READY.
 *
 * Values:
 * - 000 - GPC will wait 4 ckil clock cycles
 * - 001 - GPC will wait 8 ckil clock cycles
 * - 010 - GPC will wait 16 ckil clock cycles
 * - 011 - GPC will wait 32 ckil clock cycles
 * - 100 - GPC will wait 64 ckil clock cycles
 * - 101 - GPC will wait 128 ckil clock cycles
 * - 110 - GPC will wait 256 ckil clock cycles
 * - 111 - GPC will wait 512 ckil clock cycles
 */
/*@{*/
#define BP_GPC_SLPCR_STBY_COUNT (3U)       /*!< Bit position for GPC_SLPCR_STBY_COUNT. */
#define BM_GPC_SLPCR_STBY_COUNT (0x00000038U) /*!< Bit mask for GPC_SLPCR_STBY_COUNT. */
#define BS_GPC_SLPCR_STBY_COUNT (3U)       /*!< Bit field size in bits for GPC_SLPCR_STBY_COUNT. */

/*! @brief Read current value of the GPC_SLPCR_STBY_COUNT field. */
#define BR_GPC_SLPCR_STBY_COUNT(x) (HW_GPC_SLPCR(x).B.STBY_COUNT)

/*! @brief Format value for bitfield GPC_SLPCR_STBY_COUNT. */
#define BF_GPC_SLPCR_STBY_COUNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLPCR_STBY_COUNT) & BM_GPC_SLPCR_STBY_COUNT)

/*! @brief Set the STBY_COUNT field to a new value. */
#define BW_GPC_SLPCR_STBY_COUNT(x, v) (HW_GPC_SLPCR_WR(x, (HW_GPC_SLPCR_RD(x) & ~BM_GPC_SLPCR_STBY_COUNT) | BF_GPC_SLPCR_STBY_COUNT(v)))
/*@}*/

/*!
 * @name Register GPC_SLPCR, field COSC_PWRDOWN[6] (RW)
 *
 * In run mode, software can manually control powering down of on chip
 * oscillator, i.e. generating '1' on cosc_pwrdown signal. If software manually powered
 * down the on chip oscillator, then sbyos functionality for on-chip oscillator
 * will be bypassed. The manual closing of on-chip oscillator should be performed
 * only in case the reference oscilator is not the source of all the clocks
 * generation.
 *
 * Values:
 * - 0 - On-chip oscillator will not be powered down, i.e. cosc_pwrdown = 0
 * - 1 - On-chip oscillator will be powered down, i.e. cosc_pwrdown = 1
 */
/*@{*/
#define BP_GPC_SLPCR_COSC_PWRDOWN (6U)     /*!< Bit position for GPC_SLPCR_COSC_PWRDOWN. */
#define BM_GPC_SLPCR_COSC_PWRDOWN (0x00000040U) /*!< Bit mask for GPC_SLPCR_COSC_PWRDOWN. */
#define BS_GPC_SLPCR_COSC_PWRDOWN (1U)     /*!< Bit field size in bits for GPC_SLPCR_COSC_PWRDOWN. */

/*! @brief Read current value of the GPC_SLPCR_COSC_PWRDOWN field. */
#define BR_GPC_SLPCR_COSC_PWRDOWN(x) (HW_GPC_SLPCR(x).B.COSC_PWRDOWN)

/*! @brief Format value for bitfield GPC_SLPCR_COSC_PWRDOWN. */
#define BF_GPC_SLPCR_COSC_PWRDOWN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLPCR_COSC_PWRDOWN) & BM_GPC_SLPCR_COSC_PWRDOWN)

/*! @brief Set the COSC_PWRDOWN field to a new value. */
#define BW_GPC_SLPCR_COSC_PWRDOWN(x, v) (HW_GPC_SLPCR_WR(x, (HW_GPC_SLPCR_RD(x) & ~BM_GPC_SLPCR_COSC_PWRDOWN) | BF_GPC_SLPCR_COSC_PWRDOWN(v)))
/*@}*/

/*!
 * @name Register GPC_SLPCR, field COSC_EN[7] (RW)
 *
 * On-chip oscillator enable bit - this bit value is reflected on the output
 * cosc_en. The system will start with on-chip oscillator enabled to supply source
 * for the PLL's. Software can change this bit if a transition to the bypass PLL
 * clocks was performed for all the PLLs. In cases that this bit is changed from
 * '0' to '1' then GPC will enable the on-chip oscillator and after counting oscnt
 * ckil clock cycles before it notify CCM to open the relevant PLLs . The
 * cosc_en bit should be changed only when on-chip oscillator is not chosen as the
 * clock source.
 *
 * Values:
 * - 0 - Disable on-chip oscillator
 * - 1 - Enable on-chip oscillator
 */
/*@{*/
#define BP_GPC_SLPCR_COSC_EN (7U)          /*!< Bit position for GPC_SLPCR_COSC_EN. */
#define BM_GPC_SLPCR_COSC_EN (0x00000080U) /*!< Bit mask for GPC_SLPCR_COSC_EN. */
#define BS_GPC_SLPCR_COSC_EN (1U)          /*!< Bit field size in bits for GPC_SLPCR_COSC_EN. */

/*! @brief Read current value of the GPC_SLPCR_COSC_EN field. */
#define BR_GPC_SLPCR_COSC_EN(x) (HW_GPC_SLPCR(x).B.COSC_EN)

/*! @brief Format value for bitfield GPC_SLPCR_COSC_EN. */
#define BF_GPC_SLPCR_COSC_EN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLPCR_COSC_EN) & BM_GPC_SLPCR_COSC_EN)

/*! @brief Set the COSC_EN field to a new value. */
#define BW_GPC_SLPCR_COSC_EN(x, v) (HW_GPC_SLPCR_WR(x, (HW_GPC_SLPCR_RD(x) & ~BM_GPC_SLPCR_COSC_EN) | BF_GPC_SLPCR_COSC_EN(v)))
/*@}*/

/*!
 * @name Register GPC_SLPCR, field OSCCNT[15:8] (RW)
 *
 * Oscillator ready counter value. These bits define value of 32KHz counter,
 * that serve as counter for oscillator lock time. This is used for oscillator lock
 * time. Current estimation is ~5ms. This counter will be used in sequence out of
 * DSM and if sbyos bit was defined. GPC will wait the "OSCCNT" number of cycles
 * before it notify CCM to open the relevant PLLs.
 *
 * Values:
 * - 00000000 - count 1 ckil
 * - 11111111 - count 256 ckils
 */
/*@{*/
#define BP_GPC_SLPCR_OSCCNT  (8U)          /*!< Bit position for GPC_SLPCR_OSCCNT. */
#define BM_GPC_SLPCR_OSCCNT  (0x0000FF00U) /*!< Bit mask for GPC_SLPCR_OSCCNT. */
#define BS_GPC_SLPCR_OSCCNT  (8U)          /*!< Bit field size in bits for GPC_SLPCR_OSCCNT. */

/*! @brief Read current value of the GPC_SLPCR_OSCCNT field. */
#define BR_GPC_SLPCR_OSCCNT(x) (HW_GPC_SLPCR(x).B.OSCCNT)

/*! @brief Format value for bitfield GPC_SLPCR_OSCCNT. */
#define BF_GPC_SLPCR_OSCCNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLPCR_OSCCNT) & BM_GPC_SLPCR_OSCCNT)

/*! @brief Set the OSCCNT field to a new value. */
#define BW_GPC_SLPCR_OSCCNT(x, v) (HW_GPC_SLPCR_WR(x, (HW_GPC_SLPCR_RD(x) & ~BM_GPC_SLPCR_OSCCNT) | BF_GPC_SLPCR_OSCCNT(v)))
/*@}*/

/*!
 * @name Register GPC_SLPCR, field EN_A7_FASTWUP_WAIT_MODE[16] (RW)
 *
 * Enable A7 fast wake up wait mode, relevant PLLs will not be closed in this
 * mode.
 */
/*@{*/
#define BP_GPC_SLPCR_EN_A7_FASTWUP_WAIT_MODE (16U) /*!< Bit position for GPC_SLPCR_EN_A7_FASTWUP_WAIT_MODE. */
#define BM_GPC_SLPCR_EN_A7_FASTWUP_WAIT_MODE (0x00010000U) /*!< Bit mask for GPC_SLPCR_EN_A7_FASTWUP_WAIT_MODE. */
#define BS_GPC_SLPCR_EN_A7_FASTWUP_WAIT_MODE (1U) /*!< Bit field size in bits for GPC_SLPCR_EN_A7_FASTWUP_WAIT_MODE. */

/*! @brief Read current value of the GPC_SLPCR_EN_A7_FASTWUP_WAIT_MODE field. */
#define BR_GPC_SLPCR_EN_A7_FASTWUP_WAIT_MODE(x) (HW_GPC_SLPCR(x).B.EN_A7_FASTWUP_WAIT_MODE)

/*! @brief Format value for bitfield GPC_SLPCR_EN_A7_FASTWUP_WAIT_MODE. */
#define BF_GPC_SLPCR_EN_A7_FASTWUP_WAIT_MODE(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLPCR_EN_A7_FASTWUP_WAIT_MODE) & BM_GPC_SLPCR_EN_A7_FASTWUP_WAIT_MODE)

/*! @brief Set the EN_A7_FASTWUP_WAIT_MODE field to a new value. */
#define BW_GPC_SLPCR_EN_A7_FASTWUP_WAIT_MODE(x, v) (HW_GPC_SLPCR_WR(x, (HW_GPC_SLPCR_RD(x) & ~BM_GPC_SLPCR_EN_A7_FASTWUP_WAIT_MODE) | BF_GPC_SLPCR_EN_A7_FASTWUP_WAIT_MODE(v)))
/*@}*/

/*!
 * @name Register GPC_SLPCR, field EN_A7_FASTWUP_STOP_MODE[17] (RW)
 *
 * Enable A7 fast wake up stop mode, relevant PLLs will not be closed in this
 * mode.
 */
/*@{*/
#define BP_GPC_SLPCR_EN_A7_FASTWUP_STOP_MODE (17U) /*!< Bit position for GPC_SLPCR_EN_A7_FASTWUP_STOP_MODE. */
#define BM_GPC_SLPCR_EN_A7_FASTWUP_STOP_MODE (0x00020000U) /*!< Bit mask for GPC_SLPCR_EN_A7_FASTWUP_STOP_MODE. */
#define BS_GPC_SLPCR_EN_A7_FASTWUP_STOP_MODE (1U) /*!< Bit field size in bits for GPC_SLPCR_EN_A7_FASTWUP_STOP_MODE. */

/*! @brief Read current value of the GPC_SLPCR_EN_A7_FASTWUP_STOP_MODE field. */
#define BR_GPC_SLPCR_EN_A7_FASTWUP_STOP_MODE(x) (HW_GPC_SLPCR(x).B.EN_A7_FASTWUP_STOP_MODE)

/*! @brief Format value for bitfield GPC_SLPCR_EN_A7_FASTWUP_STOP_MODE. */
#define BF_GPC_SLPCR_EN_A7_FASTWUP_STOP_MODE(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLPCR_EN_A7_FASTWUP_STOP_MODE) & BM_GPC_SLPCR_EN_A7_FASTWUP_STOP_MODE)

/*! @brief Set the EN_A7_FASTWUP_STOP_MODE field to a new value. */
#define BW_GPC_SLPCR_EN_A7_FASTWUP_STOP_MODE(x, v) (HW_GPC_SLPCR_WR(x, (HW_GPC_SLPCR_RD(x) & ~BM_GPC_SLPCR_EN_A7_FASTWUP_STOP_MODE) | BF_GPC_SLPCR_EN_A7_FASTWUP_STOP_MODE(v)))
/*@}*/

/*!
 * @name Register GPC_SLPCR, field EN_M4_FASTWUP_WAIT_MODE[18] (RW)
 *
 * Enable M4 fast wake up wait mode, relevant PLLs will not be closed in this
 * mode.
 */
/*@{*/
#define BP_GPC_SLPCR_EN_M4_FASTWUP_WAIT_MODE (18U) /*!< Bit position for GPC_SLPCR_EN_M4_FASTWUP_WAIT_MODE. */
#define BM_GPC_SLPCR_EN_M4_FASTWUP_WAIT_MODE (0x00040000U) /*!< Bit mask for GPC_SLPCR_EN_M4_FASTWUP_WAIT_MODE. */
#define BS_GPC_SLPCR_EN_M4_FASTWUP_WAIT_MODE (1U) /*!< Bit field size in bits for GPC_SLPCR_EN_M4_FASTWUP_WAIT_MODE. */

/*! @brief Read current value of the GPC_SLPCR_EN_M4_FASTWUP_WAIT_MODE field. */
#define BR_GPC_SLPCR_EN_M4_FASTWUP_WAIT_MODE(x) (HW_GPC_SLPCR(x).B.EN_M4_FASTWUP_WAIT_MODE)

/*! @brief Format value for bitfield GPC_SLPCR_EN_M4_FASTWUP_WAIT_MODE. */
#define BF_GPC_SLPCR_EN_M4_FASTWUP_WAIT_MODE(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLPCR_EN_M4_FASTWUP_WAIT_MODE) & BM_GPC_SLPCR_EN_M4_FASTWUP_WAIT_MODE)

/*! @brief Set the EN_M4_FASTWUP_WAIT_MODE field to a new value. */
#define BW_GPC_SLPCR_EN_M4_FASTWUP_WAIT_MODE(x, v) (HW_GPC_SLPCR_WR(x, (HW_GPC_SLPCR_RD(x) & ~BM_GPC_SLPCR_EN_M4_FASTWUP_WAIT_MODE) | BF_GPC_SLPCR_EN_M4_FASTWUP_WAIT_MODE(v)))
/*@}*/

/*!
 * @name Register GPC_SLPCR, field EN_M4_FASTWUP_STOP_MODE[19] (RW)
 *
 * Enable M4 fast wake up stop mode, relevant PLLs will not be closed in this
 * mode.
 */
/*@{*/
#define BP_GPC_SLPCR_EN_M4_FASTWUP_STOP_MODE (19U) /*!< Bit position for GPC_SLPCR_EN_M4_FASTWUP_STOP_MODE. */
#define BM_GPC_SLPCR_EN_M4_FASTWUP_STOP_MODE (0x00080000U) /*!< Bit mask for GPC_SLPCR_EN_M4_FASTWUP_STOP_MODE. */
#define BS_GPC_SLPCR_EN_M4_FASTWUP_STOP_MODE (1U) /*!< Bit field size in bits for GPC_SLPCR_EN_M4_FASTWUP_STOP_MODE. */

/*! @brief Read current value of the GPC_SLPCR_EN_M4_FASTWUP_STOP_MODE field. */
#define BR_GPC_SLPCR_EN_M4_FASTWUP_STOP_MODE(x) (HW_GPC_SLPCR(x).B.EN_M4_FASTWUP_STOP_MODE)

/*! @brief Format value for bitfield GPC_SLPCR_EN_M4_FASTWUP_STOP_MODE. */
#define BF_GPC_SLPCR_EN_M4_FASTWUP_STOP_MODE(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLPCR_EN_M4_FASTWUP_STOP_MODE) & BM_GPC_SLPCR_EN_M4_FASTWUP_STOP_MODE)

/*! @brief Set the EN_M4_FASTWUP_STOP_MODE field to a new value. */
#define BW_GPC_SLPCR_EN_M4_FASTWUP_STOP_MODE(x, v) (HW_GPC_SLPCR_WR(x, (HW_GPC_SLPCR_RD(x) & ~BM_GPC_SLPCR_EN_M4_FASTWUP_STOP_MODE) | BF_GPC_SLPCR_EN_M4_FASTWUP_STOP_MODE(v)))
/*@}*/

/*!
 * @name Register GPC_SLPCR, field DISABLE_A7_IS_DSM[23] (RW)
 *
 * Values:
 * - 0 - Enable a7 isolation signal in DSM
 * - 1 - Disable a7 isolation signal in DSM
 */
/*@{*/
#define BP_GPC_SLPCR_DISABLE_A7_IS_DSM (23U) /*!< Bit position for GPC_SLPCR_DISABLE_A7_IS_DSM. */
#define BM_GPC_SLPCR_DISABLE_A7_IS_DSM (0x00800000U) /*!< Bit mask for GPC_SLPCR_DISABLE_A7_IS_DSM. */
#define BS_GPC_SLPCR_DISABLE_A7_IS_DSM (1U) /*!< Bit field size in bits for GPC_SLPCR_DISABLE_A7_IS_DSM. */

/*! @brief Read current value of the GPC_SLPCR_DISABLE_A7_IS_DSM field. */
#define BR_GPC_SLPCR_DISABLE_A7_IS_DSM(x) (HW_GPC_SLPCR(x).B.DISABLE_A7_IS_DSM)

/*! @brief Format value for bitfield GPC_SLPCR_DISABLE_A7_IS_DSM. */
#define BF_GPC_SLPCR_DISABLE_A7_IS_DSM(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLPCR_DISABLE_A7_IS_DSM) & BM_GPC_SLPCR_DISABLE_A7_IS_DSM)

/*! @brief Set the DISABLE_A7_IS_DSM field to a new value. */
#define BW_GPC_SLPCR_DISABLE_A7_IS_DSM(x, v) (HW_GPC_SLPCR_WR(x, (HW_GPC_SLPCR_RD(x) & ~BM_GPC_SLPCR_DISABLE_A7_IS_DSM) | BF_GPC_SLPCR_DISABLE_A7_IS_DSM(v)))
/*@}*/

/*!
 * @name Register GPC_SLPCR, field REG_BYPASS_COUNT[29:24] (RW)
 *
 * Counter for REG_BYPASS signal assertion after standby voltage request by
 * PMIC_STBY_REQ.
 *
 * Values:
 * - 000000 - no delay
 * - 000001 - 1 CKIL clock period delay
 * - 111111 - 63 CKIL clock period delay
 */
/*@{*/
#define BP_GPC_SLPCR_REG_BYPASS_COUNT (24U) /*!< Bit position for GPC_SLPCR_REG_BYPASS_COUNT. */
#define BM_GPC_SLPCR_REG_BYPASS_COUNT (0x3F000000U) /*!< Bit mask for GPC_SLPCR_REG_BYPASS_COUNT. */
#define BS_GPC_SLPCR_REG_BYPASS_COUNT (6U) /*!< Bit field size in bits for GPC_SLPCR_REG_BYPASS_COUNT. */

/*! @brief Read current value of the GPC_SLPCR_REG_BYPASS_COUNT field. */
#define BR_GPC_SLPCR_REG_BYPASS_COUNT(x) (HW_GPC_SLPCR(x).B.REG_BYPASS_COUNT)

/*! @brief Format value for bitfield GPC_SLPCR_REG_BYPASS_COUNT. */
#define BF_GPC_SLPCR_REG_BYPASS_COUNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLPCR_REG_BYPASS_COUNT) & BM_GPC_SLPCR_REG_BYPASS_COUNT)

/*! @brief Set the REG_BYPASS_COUNT field to a new value. */
#define BW_GPC_SLPCR_REG_BYPASS_COUNT(x, v) (HW_GPC_SLPCR_WR(x, (HW_GPC_SLPCR_RD(x) & ~BM_GPC_SLPCR_REG_BYPASS_COUNT) | BF_GPC_SLPCR_REG_BYPASS_COUNT(v)))
/*@}*/

/*!
 * @name Register GPC_SLPCR, field RBC_EN[30] (RW)
 *
 * Enable for REG_BYPASS_COUNTER. If enabled, REG_BYPASS signal will be asserted
 * after REG_BYPASS_COUNT clocks of CKIL, after standby voltage is requested. If
 * standby voltage is not requested REG_BYPASS won't be asserted, even if
 * counter is enabled.
 *
 * Values:
 * - 0 - REG_BYPASS_COUNTER disabled
 * - 1 - REG_BYPASS_COUNTER enabled
 */
/*@{*/
#define BP_GPC_SLPCR_RBC_EN  (30U)         /*!< Bit position for GPC_SLPCR_RBC_EN. */
#define BM_GPC_SLPCR_RBC_EN  (0x40000000U) /*!< Bit mask for GPC_SLPCR_RBC_EN. */
#define BS_GPC_SLPCR_RBC_EN  (1U)          /*!< Bit field size in bits for GPC_SLPCR_RBC_EN. */

/*! @brief Read current value of the GPC_SLPCR_RBC_EN field. */
#define BR_GPC_SLPCR_RBC_EN(x) (HW_GPC_SLPCR(x).B.RBC_EN)

/*! @brief Format value for bitfield GPC_SLPCR_RBC_EN. */
#define BF_GPC_SLPCR_RBC_EN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLPCR_RBC_EN) & BM_GPC_SLPCR_RBC_EN)

/*! @brief Set the RBC_EN field to a new value. */
#define BW_GPC_SLPCR_RBC_EN(x, v) (HW_GPC_SLPCR_WR(x, (HW_GPC_SLPCR_RD(x) & ~BM_GPC_SLPCR_RBC_EN) | BF_GPC_SLPCR_RBC_EN(v)))
/*@}*/

/*!
 * @name Register GPC_SLPCR, field EN_DSM[31] (RW)
 *
 * DSM enable
 *
 * Values:
 * - 0 - DSM disabled
 * - 1 - DSM enabled
 */
/*@{*/
#define BP_GPC_SLPCR_EN_DSM  (31U)         /*!< Bit position for GPC_SLPCR_EN_DSM. */
#define BM_GPC_SLPCR_EN_DSM  (0x80000000U) /*!< Bit mask for GPC_SLPCR_EN_DSM. */
#define BS_GPC_SLPCR_EN_DSM  (1U)          /*!< Bit field size in bits for GPC_SLPCR_EN_DSM. */

/*! @brief Read current value of the GPC_SLPCR_EN_DSM field. */
#define BR_GPC_SLPCR_EN_DSM(x) (HW_GPC_SLPCR(x).B.EN_DSM)

/*! @brief Format value for bitfield GPC_SLPCR_EN_DSM. */
#define BF_GPC_SLPCR_EN_DSM(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLPCR_EN_DSM) & BM_GPC_SLPCR_EN_DSM)

/*! @brief Set the EN_DSM field to a new value. */
#define BW_GPC_SLPCR_EN_DSM(x, v) (HW_GPC_SLPCR_WR(x, (HW_GPC_SLPCR_RD(x) & ~BM_GPC_SLPCR_EN_DSM) | BF_GPC_SLPCR_EN_DSM(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_MLPCR - Memory low power control register
 ******************************************************************************/

/*!
 * @brief HW_GPC_MLPCR - Memory low power control register (RW)
 *
 * Reset value: 0x00480100U
 */
typedef union _hw_gpc_mlpcr
{
    uint32_t U;
    struct _hw_gpc_mlpcr_bitfields
    {
        uint32_t MEMLP_CTL_DIS : 1;    /*!< [0]  */
        uint32_t MEMLP_RET_SEL : 1;    /*!< [1]  */
        uint32_t ROMLP_PDN_DIS : 1;    /*!< [2]  */
        uint32_t RESERVED0 : 5;        /*!< [7:3]  */
        uint32_t MEMLP_ENT_CNT : 8;    /*!< [15:8]  */
        uint32_t MEM_EXT_CNT : 8;      /*!< [23:16]  */
        uint32_t MEMLP_RET_PGEN : 8;   /*!< [31:24]  */
    } B;
} hw_gpc_mlpcr_t;

/*!
 * @name Constants and macros for entire GPC_MLPCR register
 */
/*@{*/
#define HW_GPC_MLPCR_ADDR(x)     ((uintptr_t)(x) + 0x20U)

#define HW_GPC_MLPCR(x)          (*(__IO hw_gpc_mlpcr_t *) HW_GPC_MLPCR_ADDR(x))
#define HW_GPC_MLPCR_RD(x)       (HW_GPC_MLPCR(x).U)
#define HW_GPC_MLPCR_WR(x, v)    (HW_GPC_MLPCR(x).U = (v))
#define HW_GPC_MLPCR_SET(x, v)   (HW_GPC_MLPCR_WR(x, HW_GPC_MLPCR_RD(x) |  (v)))
#define HW_GPC_MLPCR_CLR(x, v)   (HW_GPC_MLPCR_WR(x, HW_GPC_MLPCR_RD(x) & ~(v)))
#define HW_GPC_MLPCR_TOG(x, v)   (HW_GPC_MLPCR_WR(x, HW_GPC_MLPCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_MLPCR bitfields
 */

/*!
 * @name Register GPC_MLPCR, field MEMLP_CTL_DIS[0] (RW)
 *
 * RAM low-power control
 *
 * Values:
 * - 0 - Enable RAM low power control
 * - 1 - Disable RAM low power control
 */
/*@{*/
#define BP_GPC_MLPCR_MEMLP_CTL_DIS (0U)    /*!< Bit position for GPC_MLPCR_MEMLP_CTL_DIS. */
#define BM_GPC_MLPCR_MEMLP_CTL_DIS (0x00000001U) /*!< Bit mask for GPC_MLPCR_MEMLP_CTL_DIS. */
#define BS_GPC_MLPCR_MEMLP_CTL_DIS (1U)    /*!< Bit field size in bits for GPC_MLPCR_MEMLP_CTL_DIS. */

/*! @brief Read current value of the GPC_MLPCR_MEMLP_CTL_DIS field. */
#define BR_GPC_MLPCR_MEMLP_CTL_DIS(x) (HW_GPC_MLPCR(x).B.MEMLP_CTL_DIS)

/*! @brief Format value for bitfield GPC_MLPCR_MEMLP_CTL_DIS. */
#define BF_GPC_MLPCR_MEMLP_CTL_DIS(v) ((uint32_t)((uint32_t)(v) << BP_GPC_MLPCR_MEMLP_CTL_DIS) & BM_GPC_MLPCR_MEMLP_CTL_DIS)

/*! @brief Set the MEMLP_CTL_DIS field to a new value. */
#define BW_GPC_MLPCR_MEMLP_CTL_DIS(x, v) (HW_GPC_MLPCR_WR(x, (HW_GPC_MLPCR_RD(x) & ~BM_GPC_MLPCR_MEMLP_CTL_DIS) | BF_GPC_MLPCR_MEMLP_CTL_DIS(v)))
/*@}*/

/*!
 * @name Register GPC_MLPCR, field MEMLP_RET_SEL[1] (RW)
 *
 * Retention select
 *
 * Values:
 * - 0 - retention mode 2
 * - 1 - retention mode 1
 */
/*@{*/
#define BP_GPC_MLPCR_MEMLP_RET_SEL (1U)    /*!< Bit position for GPC_MLPCR_MEMLP_RET_SEL. */
#define BM_GPC_MLPCR_MEMLP_RET_SEL (0x00000002U) /*!< Bit mask for GPC_MLPCR_MEMLP_RET_SEL. */
#define BS_GPC_MLPCR_MEMLP_RET_SEL (1U)    /*!< Bit field size in bits for GPC_MLPCR_MEMLP_RET_SEL. */

/*! @brief Read current value of the GPC_MLPCR_MEMLP_RET_SEL field. */
#define BR_GPC_MLPCR_MEMLP_RET_SEL(x) (HW_GPC_MLPCR(x).B.MEMLP_RET_SEL)

/*! @brief Format value for bitfield GPC_MLPCR_MEMLP_RET_SEL. */
#define BF_GPC_MLPCR_MEMLP_RET_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_MLPCR_MEMLP_RET_SEL) & BM_GPC_MLPCR_MEMLP_RET_SEL)

/*! @brief Set the MEMLP_RET_SEL field to a new value. */
#define BW_GPC_MLPCR_MEMLP_RET_SEL(x, v) (HW_GPC_MLPCR_WR(x, (HW_GPC_MLPCR_RD(x) & ~BM_GPC_MLPCR_MEMLP_RET_SEL) | BF_GPC_MLPCR_MEMLP_RET_SEL(v)))
/*@}*/

/*!
 * @name Register GPC_MLPCR, field ROMLP_PDN_DIS[2] (RW)
 *
 * ROM shut down control
 *
 * Values:
 * - 0 - Enable ROM shut down control(should also enable RAM low power control);
 * - 1 - Disable ROM shut down control
 */
/*@{*/
#define BP_GPC_MLPCR_ROMLP_PDN_DIS (2U)    /*!< Bit position for GPC_MLPCR_ROMLP_PDN_DIS. */
#define BM_GPC_MLPCR_ROMLP_PDN_DIS (0x00000004U) /*!< Bit mask for GPC_MLPCR_ROMLP_PDN_DIS. */
#define BS_GPC_MLPCR_ROMLP_PDN_DIS (1U)    /*!< Bit field size in bits for GPC_MLPCR_ROMLP_PDN_DIS. */

/*! @brief Read current value of the GPC_MLPCR_ROMLP_PDN_DIS field. */
#define BR_GPC_MLPCR_ROMLP_PDN_DIS(x) (HW_GPC_MLPCR(x).B.ROMLP_PDN_DIS)

/*! @brief Format value for bitfield GPC_MLPCR_ROMLP_PDN_DIS. */
#define BF_GPC_MLPCR_ROMLP_PDN_DIS(v) ((uint32_t)((uint32_t)(v) << BP_GPC_MLPCR_ROMLP_PDN_DIS) & BM_GPC_MLPCR_ROMLP_PDN_DIS)

/*! @brief Set the ROMLP_PDN_DIS field to a new value. */
#define BW_GPC_MLPCR_ROMLP_PDN_DIS(x, v) (HW_GPC_MLPCR_WR(x, (HW_GPC_MLPCR_RD(x) & ~BM_GPC_MLPCR_ROMLP_PDN_DIS) | BF_GPC_MLPCR_ROMLP_PDN_DIS(v)))
/*@}*/

/*!
 * @name Register GPC_MLPCR, field MEMLP_ENT_CNT[15:8] (RW)
 *
 * Delay counter to make sure all clock off after pll_dis_req is issued by smc
 */
/*@{*/
#define BP_GPC_MLPCR_MEMLP_ENT_CNT (8U)    /*!< Bit position for GPC_MLPCR_MEMLP_ENT_CNT. */
#define BM_GPC_MLPCR_MEMLP_ENT_CNT (0x0000FF00U) /*!< Bit mask for GPC_MLPCR_MEMLP_ENT_CNT. */
#define BS_GPC_MLPCR_MEMLP_ENT_CNT (8U)    /*!< Bit field size in bits for GPC_MLPCR_MEMLP_ENT_CNT. */

/*! @brief Read current value of the GPC_MLPCR_MEMLP_ENT_CNT field. */
#define BR_GPC_MLPCR_MEMLP_ENT_CNT(x) (HW_GPC_MLPCR(x).B.MEMLP_ENT_CNT)

/*! @brief Format value for bitfield GPC_MLPCR_MEMLP_ENT_CNT. */
#define BF_GPC_MLPCR_MEMLP_ENT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_MLPCR_MEMLP_ENT_CNT) & BM_GPC_MLPCR_MEMLP_ENT_CNT)

/*! @brief Set the MEMLP_ENT_CNT field to a new value. */
#define BW_GPC_MLPCR_MEMLP_ENT_CNT(x, v) (HW_GPC_MLPCR_WR(x, (HW_GPC_MLPCR_RD(x) & ~BM_GPC_MLPCR_MEMLP_ENT_CNT) | BF_GPC_MLPCR_MEMLP_ENT_CNT(v)))
/*@}*/

/*!
 * @name Register GPC_MLPCR, field MEM_EXT_CNT[23:16] (RW)
 *
 * Delay counter to start existing from memory low power
 */
/*@{*/
#define BP_GPC_MLPCR_MEM_EXT_CNT (16U)     /*!< Bit position for GPC_MLPCR_MEM_EXT_CNT. */
#define BM_GPC_MLPCR_MEM_EXT_CNT (0x00FF0000U) /*!< Bit mask for GPC_MLPCR_MEM_EXT_CNT. */
#define BS_GPC_MLPCR_MEM_EXT_CNT (8U)      /*!< Bit field size in bits for GPC_MLPCR_MEM_EXT_CNT. */

/*! @brief Read current value of the GPC_MLPCR_MEM_EXT_CNT field. */
#define BR_GPC_MLPCR_MEM_EXT_CNT(x) (HW_GPC_MLPCR(x).B.MEM_EXT_CNT)

/*! @brief Format value for bitfield GPC_MLPCR_MEM_EXT_CNT. */
#define BF_GPC_MLPCR_MEM_EXT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_MLPCR_MEM_EXT_CNT) & BM_GPC_MLPCR_MEM_EXT_CNT)

/*! @brief Set the MEM_EXT_CNT field to a new value. */
#define BW_GPC_MLPCR_MEM_EXT_CNT(x, v) (HW_GPC_MLPCR_WR(x, (HW_GPC_MLPCR_RD(x) & ~BM_GPC_MLPCR_MEM_EXT_CNT) | BF_GPC_MLPCR_MEM_EXT_CNT(v)))
/*@}*/

/*!
 * @name Register GPC_MLPCR, field MEMLP_RET_PGEN[31:24] (RW)
 *
 * Delay conter for "retnx" and "pgen"
 */
/*@{*/
#define BP_GPC_MLPCR_MEMLP_RET_PGEN (24U)  /*!< Bit position for GPC_MLPCR_MEMLP_RET_PGEN. */
#define BM_GPC_MLPCR_MEMLP_RET_PGEN (0xFF000000U) /*!< Bit mask for GPC_MLPCR_MEMLP_RET_PGEN. */
#define BS_GPC_MLPCR_MEMLP_RET_PGEN (8U)   /*!< Bit field size in bits for GPC_MLPCR_MEMLP_RET_PGEN. */

/*! @brief Read current value of the GPC_MLPCR_MEMLP_RET_PGEN field. */
#define BR_GPC_MLPCR_MEMLP_RET_PGEN(x) (HW_GPC_MLPCR(x).B.MEMLP_RET_PGEN)

/*! @brief Format value for bitfield GPC_MLPCR_MEMLP_RET_PGEN. */
#define BF_GPC_MLPCR_MEMLP_RET_PGEN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_MLPCR_MEMLP_RET_PGEN) & BM_GPC_MLPCR_MEMLP_RET_PGEN)

/*! @brief Set the MEMLP_RET_PGEN field to a new value. */
#define BW_GPC_MLPCR_MEMLP_RET_PGEN(x, v) (HW_GPC_MLPCR_WR(x, (HW_GPC_MLPCR_RD(x) & ~BM_GPC_MLPCR_MEMLP_RET_PGEN) | BF_GPC_MLPCR_MEMLP_RET_PGEN(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_ACK_SEL_A7 - PGC acknowledge signal selection of A7 platform
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_ACK_SEL_A7 - PGC acknowledge signal selection of A7 platform (RW)
 *
 * Reset value: 0x08000800U
 *
 * The register can only be accessed by A7 platform
 */
typedef union _hw_gpc_pgc_ack_sel_a7
{
    uint32_t U;
    struct _hw_gpc_pgc_ack_sel_a7_bitfields
    {
        uint32_t A7_C0_PGC_PDN_ACK : 1; /*!< [0]  */
        uint32_t A7_C1_PGC_PDN_ACK : 1; /*!< [1]  */
        uint32_t A7_PLAT_PGC_PDN_ACK : 1; /*!< [2]  */
        uint32_t MF_PGC_PDN_ACK : 1;   /*!< [3]  */
        uint32_t MIPI_PGC_PDN_ACK : 1; /*!< [4]  */
        uint32_t PCIE_PGC_PDN_ACK : 1; /*!< [5]  */
        uint32_t USB_OTG1_PGC_PDN_ACK : 1; /*!< [6]  */
        uint32_t USB_OTG2_PGC_PDN_ACK : 1; /*!< [7]  */
        uint32_t USB_HSIC_PGC_PDN_ACK : 1; /*!< [8]  */
        uint32_t RESERVED0 : 6;        /*!< [14:9]  */
        uint32_t A7_PGC_PDN_ACK : 1;   /*!< [15]  */
        uint32_t A7_C0_PGC_PUP_ACK : 1; /*!< [16]  */
        uint32_t A7_C1_PGC_PUP_ACK : 1; /*!< [17]  */
        uint32_t A7_PLAT_PGC_PUP_ACK : 1; /*!< [18]  */
        uint32_t MF_PGC_PUP_ACK : 1;   /*!< [19]  */
        uint32_t MIPI_PGC_PUP_ACK : 1; /*!< [20]  */
        uint32_t PCIE_PGC_PUP_ACK : 1; /*!< [21]  */
        uint32_t USB_OTG1_PGC_PUP_ACK : 1; /*!< [22]  */
        uint32_t USB_OTG2_PGC_PUP_ACK : 1; /*!< [23]  */
        uint32_t USB_HSIC_PGC_PUP_ACK : 1; /*!< [24]  */
        uint32_t RESERVED1 : 6;        /*!< [30:25]  */
        uint32_t A7_PGC_PUP_ACK : 1;   /*!< [31]  */
    } B;
} hw_gpc_pgc_ack_sel_a7_t;

/*!
 * @name Constants and macros for entire GPC_PGC_ACK_SEL_A7 register
 */
/*@{*/
#define HW_GPC_PGC_ACK_SEL_A7_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_GPC_PGC_ACK_SEL_A7(x) (*(__IO hw_gpc_pgc_ack_sel_a7_t *) HW_GPC_PGC_ACK_SEL_A7_ADDR(x))
#define HW_GPC_PGC_ACK_SEL_A7_RD(x) (HW_GPC_PGC_ACK_SEL_A7(x).U)
#define HW_GPC_PGC_ACK_SEL_A7_WR(x, v) (HW_GPC_PGC_ACK_SEL_A7(x).U = (v))
#define HW_GPC_PGC_ACK_SEL_A7_SET(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, HW_GPC_PGC_ACK_SEL_A7_RD(x) |  (v)))
#define HW_GPC_PGC_ACK_SEL_A7_CLR(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~(v)))
#define HW_GPC_PGC_ACK_SEL_A7_TOG(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, HW_GPC_PGC_ACK_SEL_A7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_ACK_SEL_A7 bitfields
 */

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field A7_C0_PGC_PDN_ACK[0] (RW)
 *
 * Select power down acknowledge signal of A7 CORE0 PGC as the power down
 * acknowledge for A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PDN_ACK (0U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PDN_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PDN_ACK (0x00000001U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PDN_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PDN_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PDN_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PDN_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PDN_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.A7_C0_PGC_PDN_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PDN_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PDN_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PDN_ACK) & BM_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PDN_ACK)

/*! @brief Set the A7_C0_PGC_PDN_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PDN_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PDN_ACK) | BF_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PDN_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field A7_C1_PGC_PDN_ACK[1] (RW)
 *
 * Select power down acknowledge signal of A7 CORE1 PGC as the power down
 * acknowledge for A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PDN_ACK (1U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PDN_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PDN_ACK (0x00000002U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PDN_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PDN_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PDN_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PDN_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PDN_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.A7_C1_PGC_PDN_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PDN_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PDN_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PDN_ACK) & BM_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PDN_ACK)

/*! @brief Set the A7_C1_PGC_PDN_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PDN_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PDN_ACK) | BF_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PDN_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field A7_PLAT_PGC_PDN_ACK[2] (RW)
 *
 * Select power down acknowledge signal of A7 PLATFORM PGC as the power down
 * acknowledge for A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PDN_ACK (2U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PDN_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PDN_ACK (0x00000004U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PDN_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PDN_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PDN_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PDN_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PDN_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.A7_PLAT_PGC_PDN_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PDN_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PDN_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PDN_ACK) & BM_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PDN_ACK)

/*! @brief Set the A7_PLAT_PGC_PDN_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PDN_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PDN_ACK) | BF_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PDN_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field MF_PGC_PDN_ACK[3] (RW)
 *
 * Select power down acknowledge signal of MIX PGC as the power down acknowledge
 * for A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_MF_PGC_PDN_ACK (3U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_MF_PGC_PDN_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_MF_PGC_PDN_ACK (0x00000008U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_MF_PGC_PDN_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_MF_PGC_PDN_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_MF_PGC_PDN_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_MF_PGC_PDN_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_MF_PGC_PDN_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.MF_PGC_PDN_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_MF_PGC_PDN_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_MF_PGC_PDN_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_MF_PGC_PDN_ACK) & BM_GPC_PGC_ACK_SEL_A7_MF_PGC_PDN_ACK)

/*! @brief Set the MF_PGC_PDN_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_MF_PGC_PDN_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_MF_PGC_PDN_ACK) | BF_GPC_PGC_ACK_SEL_A7_MF_PGC_PDN_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field MIPI_PGC_PDN_ACK[4] (RW)
 *
 * Select power down acknowledge signal of MIPI PGC as the power down
 * acknowledge for A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PDN_ACK (4U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_MIPI_PGC_PDN_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PDN_ACK (0x00000010U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_MIPI_PGC_PDN_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PDN_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_MIPI_PGC_PDN_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_MIPI_PGC_PDN_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PDN_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.MIPI_PGC_PDN_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_MIPI_PGC_PDN_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PDN_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PDN_ACK) & BM_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PDN_ACK)

/*! @brief Set the MIPI_PGC_PDN_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PDN_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PDN_ACK) | BF_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PDN_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field PCIE_PGC_PDN_ACK[5] (RW)
 *
 * Select power down acknowledge signal of PCIE PGC as the power down
 * acknowledge for A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PDN_ACK (5U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_PCIE_PGC_PDN_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PDN_ACK (0x00000020U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_PCIE_PGC_PDN_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PDN_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_PCIE_PGC_PDN_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_PCIE_PGC_PDN_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PDN_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.PCIE_PGC_PDN_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_PCIE_PGC_PDN_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PDN_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PDN_ACK) & BM_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PDN_ACK)

/*! @brief Set the PCIE_PGC_PDN_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PDN_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PDN_ACK) | BF_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PDN_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field USB_OTG1_PGC_PDN_ACK[6] (RW)
 *
 * Select power down acknowledge signal of USB_OTG1 PGC as the power down
 * acknowledge for A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PDN_ACK (6U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PDN_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PDN_ACK (0x00000040U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PDN_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PDN_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PDN_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PDN_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PDN_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.USB_OTG1_PGC_PDN_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PDN_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PDN_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PDN_ACK) & BM_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PDN_ACK)

/*! @brief Set the USB_OTG1_PGC_PDN_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PDN_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PDN_ACK) | BF_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PDN_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field USB_OTG2_PGC_PDN_ACK[7] (RW)
 *
 * Select power down acknowledge signal of USB_OTG2 PGC as the power down
 * acknowledge for A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PDN_ACK (7U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PDN_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PDN_ACK (0x00000080U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PDN_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PDN_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PDN_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PDN_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PDN_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.USB_OTG2_PGC_PDN_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PDN_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PDN_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PDN_ACK) & BM_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PDN_ACK)

/*! @brief Set the USB_OTG2_PGC_PDN_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PDN_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PDN_ACK) | BF_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PDN_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field USB_HSIC_PGC_PDN_ACK[8] (RW)
 *
 * Select power down acknowledge signal of USB_HSIC PGC as the power down
 * acknowledge for A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PDN_ACK (8U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PDN_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PDN_ACK (0x00000100U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PDN_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PDN_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PDN_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PDN_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PDN_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.USB_HSIC_PGC_PDN_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PDN_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PDN_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PDN_ACK) & BM_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PDN_ACK)

/*! @brief Set the USB_HSIC_PGC_PDN_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PDN_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PDN_ACK) | BF_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PDN_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field A7_PGC_PDN_ACK[15] (RW)
 *
 * Select power down acknowledge signal of A7 (dummy) PGC as the power down
 * acknowledge for A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_A7_PGC_PDN_ACK (15U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_A7_PGC_PDN_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_A7_PGC_PDN_ACK (0x00008000U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_A7_PGC_PDN_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_A7_PGC_PDN_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_A7_PGC_PDN_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_A7_PGC_PDN_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_A7_PGC_PDN_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.A7_PGC_PDN_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_A7_PGC_PDN_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_A7_PGC_PDN_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_A7_PGC_PDN_ACK) & BM_GPC_PGC_ACK_SEL_A7_A7_PGC_PDN_ACK)

/*! @brief Set the A7_PGC_PDN_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_A7_PGC_PDN_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_A7_PGC_PDN_ACK) | BF_GPC_PGC_ACK_SEL_A7_A7_PGC_PDN_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field A7_C0_PGC_PUP_ACK[16] (RW)
 *
 * Select power up acknowledge signal of A7 CORE0 PGC as the power up
 * acknowledge for A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PUP_ACK (16U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PUP_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PUP_ACK (0x00010000U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PUP_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PUP_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PUP_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PUP_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PUP_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.A7_C0_PGC_PUP_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PUP_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PUP_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PUP_ACK) & BM_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PUP_ACK)

/*! @brief Set the A7_C0_PGC_PUP_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PUP_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PUP_ACK) | BF_GPC_PGC_ACK_SEL_A7_A7_C0_PGC_PUP_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field A7_C1_PGC_PUP_ACK[17] (RW)
 *
 * Select power up acknowledge signal of A7 CORE1 PGC as the power up
 * acknowledge for A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PUP_ACK (17U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PUP_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PUP_ACK (0x00020000U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PUP_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PUP_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PUP_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PUP_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PUP_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.A7_C1_PGC_PUP_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PUP_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PUP_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PUP_ACK) & BM_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PUP_ACK)

/*! @brief Set the A7_C1_PGC_PUP_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PUP_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PUP_ACK) | BF_GPC_PGC_ACK_SEL_A7_A7_C1_PGC_PUP_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field A7_PLAT_PGC_PUP_ACK[18] (RW)
 *
 * Select power up acknowledge signal of A7 PLATFORM PGC as the power up
 * acknowledge for A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PUP_ACK (18U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PUP_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PUP_ACK (0x00040000U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PUP_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PUP_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PUP_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PUP_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PUP_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.A7_PLAT_PGC_PUP_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PUP_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PUP_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PUP_ACK) & BM_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PUP_ACK)

/*! @brief Set the A7_PLAT_PGC_PUP_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PUP_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PUP_ACK) | BF_GPC_PGC_ACK_SEL_A7_A7_PLAT_PGC_PUP_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field MF_PGC_PUP_ACK[19] (RW)
 *
 * Select power up acknowledge signal of MF PGC as the power up acknowledge for
 * A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_MF_PGC_PUP_ACK (19U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_MF_PGC_PUP_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_MF_PGC_PUP_ACK (0x00080000U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_MF_PGC_PUP_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_MF_PGC_PUP_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_MF_PGC_PUP_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_MF_PGC_PUP_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_MF_PGC_PUP_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.MF_PGC_PUP_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_MF_PGC_PUP_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_MF_PGC_PUP_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_MF_PGC_PUP_ACK) & BM_GPC_PGC_ACK_SEL_A7_MF_PGC_PUP_ACK)

/*! @brief Set the MF_PGC_PUP_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_MF_PGC_PUP_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_MF_PGC_PUP_ACK) | BF_GPC_PGC_ACK_SEL_A7_MF_PGC_PUP_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field MIPI_PGC_PUP_ACK[20] (RW)
 *
 * Select power up acknowledge signal of MIPI PGC as the power up acknowledge
 * for A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PUP_ACK (20U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_MIPI_PGC_PUP_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PUP_ACK (0x00100000U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_MIPI_PGC_PUP_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PUP_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_MIPI_PGC_PUP_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_MIPI_PGC_PUP_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PUP_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.MIPI_PGC_PUP_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_MIPI_PGC_PUP_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PUP_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PUP_ACK) & BM_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PUP_ACK)

/*! @brief Set the MIPI_PGC_PUP_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PUP_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PUP_ACK) | BF_GPC_PGC_ACK_SEL_A7_MIPI_PGC_PUP_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field PCIE_PGC_PUP_ACK[21] (RW)
 *
 * Select power up acknowledge signal of PCIE PGC as the power up acknowledge
 * for A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PUP_ACK (21U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_PCIE_PGC_PUP_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PUP_ACK (0x00200000U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_PCIE_PGC_PUP_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PUP_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_PCIE_PGC_PUP_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_PCIE_PGC_PUP_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PUP_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.PCIE_PGC_PUP_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_PCIE_PGC_PUP_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PUP_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PUP_ACK) & BM_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PUP_ACK)

/*! @brief Set the PCIE_PGC_PUP_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PUP_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PUP_ACK) | BF_GPC_PGC_ACK_SEL_A7_PCIE_PGC_PUP_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field USB_OTG1_PGC_PUP_ACK[22] (RW)
 *
 * Select power up acknowledge signal of USB_OTG1 PGC as the power up
 * acknowledge for A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PUP_ACK (22U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PUP_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PUP_ACK (0x00400000U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PUP_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PUP_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PUP_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PUP_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PUP_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.USB_OTG1_PGC_PUP_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PUP_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PUP_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PUP_ACK) & BM_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PUP_ACK)

/*! @brief Set the USB_OTG1_PGC_PUP_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PUP_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PUP_ACK) | BF_GPC_PGC_ACK_SEL_A7_USB_OTG1_PGC_PUP_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field USB_OTG2_PGC_PUP_ACK[23] (RW)
 *
 * Select power up acknowledge signal of USB_OTG2 PGC as the power up
 * acknowledge for A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PUP_ACK (23U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PUP_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PUP_ACK (0x00800000U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PUP_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PUP_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PUP_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PUP_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PUP_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.USB_OTG2_PGC_PUP_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PUP_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PUP_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PUP_ACK) & BM_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PUP_ACK)

/*! @brief Set the USB_OTG2_PGC_PUP_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PUP_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PUP_ACK) | BF_GPC_PGC_ACK_SEL_A7_USB_OTG2_PGC_PUP_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field USB_HSIC_PGC_PUP_ACK[24] (RW)
 *
 * Select power up acknowledge signal of USB_HSIC PGC as the power up
 * acknowledge for A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PUP_ACK (24U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PUP_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PUP_ACK (0x01000000U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PUP_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PUP_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PUP_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PUP_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PUP_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.USB_HSIC_PGC_PUP_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PUP_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PUP_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PUP_ACK) & BM_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PUP_ACK)

/*! @brief Set the USB_HSIC_PGC_PUP_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PUP_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PUP_ACK) | BF_GPC_PGC_ACK_SEL_A7_USB_HSIC_PGC_PUP_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_A7, field A7_PGC_PUP_ACK[31] (RW)
 *
 * Select power up acknowledge signal of A7 (dummy) PGC as the power up
 * acknowledge for A7 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_A7_A7_PGC_PUP_ACK (31U) /*!< Bit position for GPC_PGC_ACK_SEL_A7_A7_PGC_PUP_ACK. */
#define BM_GPC_PGC_ACK_SEL_A7_A7_PGC_PUP_ACK (0x80000000U) /*!< Bit mask for GPC_PGC_ACK_SEL_A7_A7_PGC_PUP_ACK. */
#define BS_GPC_PGC_ACK_SEL_A7_A7_PGC_PUP_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_A7_A7_PGC_PUP_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_A7_A7_PGC_PUP_ACK field. */
#define BR_GPC_PGC_ACK_SEL_A7_A7_PGC_PUP_ACK(x) (HW_GPC_PGC_ACK_SEL_A7(x).B.A7_PGC_PUP_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_A7_A7_PGC_PUP_ACK. */
#define BF_GPC_PGC_ACK_SEL_A7_A7_PGC_PUP_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_A7_A7_PGC_PUP_ACK) & BM_GPC_PGC_ACK_SEL_A7_A7_PGC_PUP_ACK)

/*! @brief Set the A7_PGC_PUP_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_A7_A7_PGC_PUP_ACK(x, v) (HW_GPC_PGC_ACK_SEL_A7_WR(x, (HW_GPC_PGC_ACK_SEL_A7_RD(x) & ~BM_GPC_PGC_ACK_SEL_A7_A7_PGC_PUP_ACK) | BF_GPC_PGC_ACK_SEL_A7_A7_PGC_PUP_ACK(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_ACK_SEL_M4 - PGC acknowledge signal selection of M4 platform
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_ACK_SEL_M4 - PGC acknowledge signal selection of M4 platform (RW)
 *
 * Reset value: 0x08000800U
 *
 * This register can only be accessed by the M4 platform. "dummy" PGC cannot be
 * mapped to time slot control. "virtual" PGC can be mapped to time slot control.
 * When virtual PGC is used, below setting is required -
 * GPC_MISC[M4_PDN_REQ_MASK] should be set to 1'b1 and arrange virtual GPC in same slot with MIX.
 * power/up slot (See example code 3). MIX PGC may possibly power down later than A7
 * platform power down when virtual PGC is used.
 */
typedef union _hw_gpc_pgc_ack_sel_m4
{
    uint32_t U;
    struct _hw_gpc_pgc_ack_sel_m4_bitfields
    {
        uint32_t M4_VIRTUAL_PGC_PDN_ACK : 1; /*!< [0]  */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t MF_PGC_PDN_ACK : 1;   /*!< [3]  */
        uint32_t MIPI_PGC_PDN_ACK : 1; /*!< [4]  */
        uint32_t PCIE_PGC_PDN_ACK : 1; /*!< [5]  */
        uint32_t USB_OTG1_PGC_PDN_ACK : 1; /*!< [6]  */
        uint32_t USB_OTG2_PGC_PDN_ACK : 1; /*!< [7]  */
        uint32_t USB_HSIC_PGC_PDN_ACK : 1; /*!< [8]  */
        uint32_t RESERVED1 : 6;        /*!< [14:9]  */
        uint32_t M4_DUMMY_PGC_PDN_ACK : 1; /*!< [15]  */
        uint32_t M4_VIRTUAL_PGC_PUP_ACK : 1; /*!< [16]  */
        uint32_t RESERVED2 : 2;        /*!< [18:17]  */
        uint32_t MF_PGC_PUP_ACK : 1;   /*!< [19]  */
        uint32_t MIPI_PGC_PUP_ACK : 1; /*!< [20]  */
        uint32_t PCIE_PGC_PUP_ACK : 1; /*!< [21]  */
        uint32_t USB_OTG1_PGC_PUP_ACK : 1; /*!< [22]  */
        uint32_t USB_OTG2_PGC_PUP_ACK : 1; /*!< [23]  */
        uint32_t USB_HSIC_PGC_PUP_ACK : 1; /*!< [24]  */
        uint32_t RESERVED3 : 6;        /*!< [30:25]  */
        uint32_t M4_DUMMY_PGC_PUP_ACK : 1; /*!< [31]  */
    } B;
} hw_gpc_pgc_ack_sel_m4_t;

/*!
 * @name Constants and macros for entire GPC_PGC_ACK_SEL_M4 register
 */
/*@{*/
#define HW_GPC_PGC_ACK_SEL_M4_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_GPC_PGC_ACK_SEL_M4(x) (*(__IO hw_gpc_pgc_ack_sel_m4_t *) HW_GPC_PGC_ACK_SEL_M4_ADDR(x))
#define HW_GPC_PGC_ACK_SEL_M4_RD(x) (HW_GPC_PGC_ACK_SEL_M4(x).U)
#define HW_GPC_PGC_ACK_SEL_M4_WR(x, v) (HW_GPC_PGC_ACK_SEL_M4(x).U = (v))
#define HW_GPC_PGC_ACK_SEL_M4_SET(x, v) (HW_GPC_PGC_ACK_SEL_M4_WR(x, HW_GPC_PGC_ACK_SEL_M4_RD(x) |  (v)))
#define HW_GPC_PGC_ACK_SEL_M4_CLR(x, v) (HW_GPC_PGC_ACK_SEL_M4_WR(x, HW_GPC_PGC_ACK_SEL_M4_RD(x) & ~(v)))
#define HW_GPC_PGC_ACK_SEL_M4_TOG(x, v) (HW_GPC_PGC_ACK_SEL_M4_WR(x, HW_GPC_PGC_ACK_SEL_M4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_ACK_SEL_M4 bitfields
 */

/*!
 * @name Register GPC_PGC_ACK_SEL_M4, field M4_VIRTUAL_PGC_PDN_ACK[0] (RW)
 *
 * Select power down acknowledge signal of M4 virtual PGC as the power down
 * acknowledge for M4 LPM. M4 virtual PGC only acknowledge power down request in the
 * end of current slot time
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PDN_ACK (0U) /*!< Bit position for GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PDN_ACK. */
#define BM_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PDN_ACK (0x00000001U) /*!< Bit mask for GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PDN_ACK. */
#define BS_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PDN_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PDN_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PDN_ACK field. */
#define BR_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PDN_ACK(x) (HW_GPC_PGC_ACK_SEL_M4(x).B.M4_VIRTUAL_PGC_PDN_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PDN_ACK. */
#define BF_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PDN_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PDN_ACK) & BM_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PDN_ACK)

/*! @brief Set the M4_VIRTUAL_PGC_PDN_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PDN_ACK(x, v) (HW_GPC_PGC_ACK_SEL_M4_WR(x, (HW_GPC_PGC_ACK_SEL_M4_RD(x) & ~BM_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PDN_ACK) | BF_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PDN_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_M4, field MF_PGC_PDN_ACK[3] (RW)
 *
 * Select power down acknowledge signal of MIX PGC as the power down acknowledge
 * for M4 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_M4_MF_PGC_PDN_ACK (3U) /*!< Bit position for GPC_PGC_ACK_SEL_M4_MF_PGC_PDN_ACK. */
#define BM_GPC_PGC_ACK_SEL_M4_MF_PGC_PDN_ACK (0x00000008U) /*!< Bit mask for GPC_PGC_ACK_SEL_M4_MF_PGC_PDN_ACK. */
#define BS_GPC_PGC_ACK_SEL_M4_MF_PGC_PDN_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_M4_MF_PGC_PDN_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_M4_MF_PGC_PDN_ACK field. */
#define BR_GPC_PGC_ACK_SEL_M4_MF_PGC_PDN_ACK(x) (HW_GPC_PGC_ACK_SEL_M4(x).B.MF_PGC_PDN_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_M4_MF_PGC_PDN_ACK. */
#define BF_GPC_PGC_ACK_SEL_M4_MF_PGC_PDN_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_M4_MF_PGC_PDN_ACK) & BM_GPC_PGC_ACK_SEL_M4_MF_PGC_PDN_ACK)

/*! @brief Set the MF_PGC_PDN_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_M4_MF_PGC_PDN_ACK(x, v) (HW_GPC_PGC_ACK_SEL_M4_WR(x, (HW_GPC_PGC_ACK_SEL_M4_RD(x) & ~BM_GPC_PGC_ACK_SEL_M4_MF_PGC_PDN_ACK) | BF_GPC_PGC_ACK_SEL_M4_MF_PGC_PDN_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_M4, field MIPI_PGC_PDN_ACK[4] (RW)
 *
 * Select power down acknowledge signal of MIPI PGC as the power down
 * acknowledge for M4 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PDN_ACK (4U) /*!< Bit position for GPC_PGC_ACK_SEL_M4_MIPI_PGC_PDN_ACK. */
#define BM_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PDN_ACK (0x00000010U) /*!< Bit mask for GPC_PGC_ACK_SEL_M4_MIPI_PGC_PDN_ACK. */
#define BS_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PDN_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_M4_MIPI_PGC_PDN_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_M4_MIPI_PGC_PDN_ACK field. */
#define BR_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PDN_ACK(x) (HW_GPC_PGC_ACK_SEL_M4(x).B.MIPI_PGC_PDN_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_M4_MIPI_PGC_PDN_ACK. */
#define BF_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PDN_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PDN_ACK) & BM_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PDN_ACK)

/*! @brief Set the MIPI_PGC_PDN_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PDN_ACK(x, v) (HW_GPC_PGC_ACK_SEL_M4_WR(x, (HW_GPC_PGC_ACK_SEL_M4_RD(x) & ~BM_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PDN_ACK) | BF_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PDN_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_M4, field PCIE_PGC_PDN_ACK[5] (RW)
 *
 * Select power down acknowledge signal of PCIE PGC as the power down
 * acknowledge for M4 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PDN_ACK (5U) /*!< Bit position for GPC_PGC_ACK_SEL_M4_PCIE_PGC_PDN_ACK. */
#define BM_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PDN_ACK (0x00000020U) /*!< Bit mask for GPC_PGC_ACK_SEL_M4_PCIE_PGC_PDN_ACK. */
#define BS_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PDN_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_M4_PCIE_PGC_PDN_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_M4_PCIE_PGC_PDN_ACK field. */
#define BR_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PDN_ACK(x) (HW_GPC_PGC_ACK_SEL_M4(x).B.PCIE_PGC_PDN_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_M4_PCIE_PGC_PDN_ACK. */
#define BF_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PDN_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PDN_ACK) & BM_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PDN_ACK)

/*! @brief Set the PCIE_PGC_PDN_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PDN_ACK(x, v) (HW_GPC_PGC_ACK_SEL_M4_WR(x, (HW_GPC_PGC_ACK_SEL_M4_RD(x) & ~BM_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PDN_ACK) | BF_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PDN_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_M4, field USB_OTG1_PGC_PDN_ACK[6] (RW)
 *
 * Select power down acknowledge signal of USB_OTG1 PGC as the power down
 * acknowledge for M4 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PDN_ACK (6U) /*!< Bit position for GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PDN_ACK. */
#define BM_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PDN_ACK (0x00000040U) /*!< Bit mask for GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PDN_ACK. */
#define BS_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PDN_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PDN_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PDN_ACK field. */
#define BR_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PDN_ACK(x) (HW_GPC_PGC_ACK_SEL_M4(x).B.USB_OTG1_PGC_PDN_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PDN_ACK. */
#define BF_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PDN_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PDN_ACK) & BM_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PDN_ACK)

/*! @brief Set the USB_OTG1_PGC_PDN_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PDN_ACK(x, v) (HW_GPC_PGC_ACK_SEL_M4_WR(x, (HW_GPC_PGC_ACK_SEL_M4_RD(x) & ~BM_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PDN_ACK) | BF_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PDN_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_M4, field USB_OTG2_PGC_PDN_ACK[7] (RW)
 *
 * Select power down acknowledge signal of USB_OTG2 PGC as the power down
 * acknowledge for M4 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PDN_ACK (7U) /*!< Bit position for GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PDN_ACK. */
#define BM_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PDN_ACK (0x00000080U) /*!< Bit mask for GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PDN_ACK. */
#define BS_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PDN_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PDN_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PDN_ACK field. */
#define BR_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PDN_ACK(x) (HW_GPC_PGC_ACK_SEL_M4(x).B.USB_OTG2_PGC_PDN_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PDN_ACK. */
#define BF_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PDN_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PDN_ACK) & BM_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PDN_ACK)

/*! @brief Set the USB_OTG2_PGC_PDN_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PDN_ACK(x, v) (HW_GPC_PGC_ACK_SEL_M4_WR(x, (HW_GPC_PGC_ACK_SEL_M4_RD(x) & ~BM_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PDN_ACK) | BF_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PDN_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_M4, field USB_HSIC_PGC_PDN_ACK[8] (RW)
 *
 * Select power down acknowledge signal of USB_HSIC PGC as the power down
 * acknowledge for M4 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PDN_ACK (8U) /*!< Bit position for GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PDN_ACK. */
#define BM_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PDN_ACK (0x00000100U) /*!< Bit mask for GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PDN_ACK. */
#define BS_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PDN_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PDN_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PDN_ACK field. */
#define BR_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PDN_ACK(x) (HW_GPC_PGC_ACK_SEL_M4(x).B.USB_HSIC_PGC_PDN_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PDN_ACK. */
#define BF_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PDN_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PDN_ACK) & BM_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PDN_ACK)

/*! @brief Set the USB_HSIC_PGC_PDN_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PDN_ACK(x, v) (HW_GPC_PGC_ACK_SEL_M4_WR(x, (HW_GPC_PGC_ACK_SEL_M4_RD(x) & ~BM_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PDN_ACK) | BF_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PDN_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_M4, field M4_DUMMY_PGC_PDN_ACK[15] (RW)
 *
 * Select power down acknowledge signal of M4 (dummy) PGC as the power down
 * acknowledge for M4 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PDN_ACK (15U) /*!< Bit position for GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PDN_ACK. */
#define BM_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PDN_ACK (0x00008000U) /*!< Bit mask for GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PDN_ACK. */
#define BS_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PDN_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PDN_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PDN_ACK field. */
#define BR_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PDN_ACK(x) (HW_GPC_PGC_ACK_SEL_M4(x).B.M4_DUMMY_PGC_PDN_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PDN_ACK. */
#define BF_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PDN_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PDN_ACK) & BM_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PDN_ACK)

/*! @brief Set the M4_DUMMY_PGC_PDN_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PDN_ACK(x, v) (HW_GPC_PGC_ACK_SEL_M4_WR(x, (HW_GPC_PGC_ACK_SEL_M4_RD(x) & ~BM_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PDN_ACK) | BF_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PDN_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_M4, field M4_VIRTUAL_PGC_PUP_ACK[16] (RW)
 *
 * Select power up acknowledge signal of M4 virtual PGC as the power up
 * acknowledge for M4 LPM. M4 virtual PGC only acknowledge power up request in the end of
 * current slot time
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PUP_ACK (16U) /*!< Bit position for GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PUP_ACK. */
#define BM_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PUP_ACK (0x00010000U) /*!< Bit mask for GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PUP_ACK. */
#define BS_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PUP_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PUP_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PUP_ACK field. */
#define BR_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PUP_ACK(x) (HW_GPC_PGC_ACK_SEL_M4(x).B.M4_VIRTUAL_PGC_PUP_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PUP_ACK. */
#define BF_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PUP_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PUP_ACK) & BM_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PUP_ACK)

/*! @brief Set the M4_VIRTUAL_PGC_PUP_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PUP_ACK(x, v) (HW_GPC_PGC_ACK_SEL_M4_WR(x, (HW_GPC_PGC_ACK_SEL_M4_RD(x) & ~BM_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PUP_ACK) | BF_GPC_PGC_ACK_SEL_M4_M4_VIRTUAL_PGC_PUP_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_M4, field MF_PGC_PUP_ACK[19] (RW)
 *
 * Select power up acknowledge signal of MF PGC as the power up acknowledge for
 * M4 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_M4_MF_PGC_PUP_ACK (19U) /*!< Bit position for GPC_PGC_ACK_SEL_M4_MF_PGC_PUP_ACK. */
#define BM_GPC_PGC_ACK_SEL_M4_MF_PGC_PUP_ACK (0x00080000U) /*!< Bit mask for GPC_PGC_ACK_SEL_M4_MF_PGC_PUP_ACK. */
#define BS_GPC_PGC_ACK_SEL_M4_MF_PGC_PUP_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_M4_MF_PGC_PUP_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_M4_MF_PGC_PUP_ACK field. */
#define BR_GPC_PGC_ACK_SEL_M4_MF_PGC_PUP_ACK(x) (HW_GPC_PGC_ACK_SEL_M4(x).B.MF_PGC_PUP_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_M4_MF_PGC_PUP_ACK. */
#define BF_GPC_PGC_ACK_SEL_M4_MF_PGC_PUP_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_M4_MF_PGC_PUP_ACK) & BM_GPC_PGC_ACK_SEL_M4_MF_PGC_PUP_ACK)

/*! @brief Set the MF_PGC_PUP_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_M4_MF_PGC_PUP_ACK(x, v) (HW_GPC_PGC_ACK_SEL_M4_WR(x, (HW_GPC_PGC_ACK_SEL_M4_RD(x) & ~BM_GPC_PGC_ACK_SEL_M4_MF_PGC_PUP_ACK) | BF_GPC_PGC_ACK_SEL_M4_MF_PGC_PUP_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_M4, field MIPI_PGC_PUP_ACK[20] (RW)
 *
 * Select power up acknowledge signal of MIPI PGC as the power up acknowledge
 * for M4 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PUP_ACK (20U) /*!< Bit position for GPC_PGC_ACK_SEL_M4_MIPI_PGC_PUP_ACK. */
#define BM_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PUP_ACK (0x00100000U) /*!< Bit mask for GPC_PGC_ACK_SEL_M4_MIPI_PGC_PUP_ACK. */
#define BS_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PUP_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_M4_MIPI_PGC_PUP_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_M4_MIPI_PGC_PUP_ACK field. */
#define BR_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PUP_ACK(x) (HW_GPC_PGC_ACK_SEL_M4(x).B.MIPI_PGC_PUP_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_M4_MIPI_PGC_PUP_ACK. */
#define BF_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PUP_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PUP_ACK) & BM_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PUP_ACK)

/*! @brief Set the MIPI_PGC_PUP_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PUP_ACK(x, v) (HW_GPC_PGC_ACK_SEL_M4_WR(x, (HW_GPC_PGC_ACK_SEL_M4_RD(x) & ~BM_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PUP_ACK) | BF_GPC_PGC_ACK_SEL_M4_MIPI_PGC_PUP_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_M4, field PCIE_PGC_PUP_ACK[21] (RW)
 *
 * Select power up acknowledge signal of PCIE PGC as the power up acknowledge
 * for M4 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PUP_ACK (21U) /*!< Bit position for GPC_PGC_ACK_SEL_M4_PCIE_PGC_PUP_ACK. */
#define BM_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PUP_ACK (0x00200000U) /*!< Bit mask for GPC_PGC_ACK_SEL_M4_PCIE_PGC_PUP_ACK. */
#define BS_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PUP_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_M4_PCIE_PGC_PUP_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_M4_PCIE_PGC_PUP_ACK field. */
#define BR_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PUP_ACK(x) (HW_GPC_PGC_ACK_SEL_M4(x).B.PCIE_PGC_PUP_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_M4_PCIE_PGC_PUP_ACK. */
#define BF_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PUP_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PUP_ACK) & BM_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PUP_ACK)

/*! @brief Set the PCIE_PGC_PUP_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PUP_ACK(x, v) (HW_GPC_PGC_ACK_SEL_M4_WR(x, (HW_GPC_PGC_ACK_SEL_M4_RD(x) & ~BM_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PUP_ACK) | BF_GPC_PGC_ACK_SEL_M4_PCIE_PGC_PUP_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_M4, field USB_OTG1_PGC_PUP_ACK[22] (RW)
 *
 * Select power up acknowledge signal of USB_OTG1 PGC as the power up
 * acknowledge for M4 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PUP_ACK (22U) /*!< Bit position for GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PUP_ACK. */
#define BM_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PUP_ACK (0x00400000U) /*!< Bit mask for GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PUP_ACK. */
#define BS_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PUP_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PUP_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PUP_ACK field. */
#define BR_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PUP_ACK(x) (HW_GPC_PGC_ACK_SEL_M4(x).B.USB_OTG1_PGC_PUP_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PUP_ACK. */
#define BF_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PUP_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PUP_ACK) & BM_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PUP_ACK)

/*! @brief Set the USB_OTG1_PGC_PUP_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PUP_ACK(x, v) (HW_GPC_PGC_ACK_SEL_M4_WR(x, (HW_GPC_PGC_ACK_SEL_M4_RD(x) & ~BM_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PUP_ACK) | BF_GPC_PGC_ACK_SEL_M4_USB_OTG1_PGC_PUP_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_M4, field USB_OTG2_PGC_PUP_ACK[23] (RW)
 *
 * Select power up acknowledge signal of USB_OTG2 PGC as the power up
 * acknowledge for M4 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PUP_ACK (23U) /*!< Bit position for GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PUP_ACK. */
#define BM_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PUP_ACK (0x00800000U) /*!< Bit mask for GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PUP_ACK. */
#define BS_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PUP_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PUP_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PUP_ACK field. */
#define BR_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PUP_ACK(x) (HW_GPC_PGC_ACK_SEL_M4(x).B.USB_OTG2_PGC_PUP_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PUP_ACK. */
#define BF_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PUP_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PUP_ACK) & BM_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PUP_ACK)

/*! @brief Set the USB_OTG2_PGC_PUP_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PUP_ACK(x, v) (HW_GPC_PGC_ACK_SEL_M4_WR(x, (HW_GPC_PGC_ACK_SEL_M4_RD(x) & ~BM_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PUP_ACK) | BF_GPC_PGC_ACK_SEL_M4_USB_OTG2_PGC_PUP_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_M4, field USB_HSIC_PGC_PUP_ACK[24] (RW)
 *
 * Select power up acknowledge signal of USB_HSIC PGC as the power up
 * acknowledge for M4 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PUP_ACK (24U) /*!< Bit position for GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PUP_ACK. */
#define BM_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PUP_ACK (0x01000000U) /*!< Bit mask for GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PUP_ACK. */
#define BS_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PUP_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PUP_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PUP_ACK field. */
#define BR_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PUP_ACK(x) (HW_GPC_PGC_ACK_SEL_M4(x).B.USB_HSIC_PGC_PUP_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PUP_ACK. */
#define BF_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PUP_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PUP_ACK) & BM_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PUP_ACK)

/*! @brief Set the USB_HSIC_PGC_PUP_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PUP_ACK(x, v) (HW_GPC_PGC_ACK_SEL_M4_WR(x, (HW_GPC_PGC_ACK_SEL_M4_RD(x) & ~BM_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PUP_ACK) | BF_GPC_PGC_ACK_SEL_M4_USB_HSIC_PGC_PUP_ACK(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_ACK_SEL_M4, field M4_DUMMY_PGC_PUP_ACK[31] (RW)
 *
 * Select power up acknowledge signal of M4 (dummy) PGC as the power up
 * acknowledge for M4 LPM.
 */
/*@{*/
#define BP_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PUP_ACK (31U) /*!< Bit position for GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PUP_ACK. */
#define BM_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PUP_ACK (0x80000000U) /*!< Bit mask for GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PUP_ACK. */
#define BS_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PUP_ACK (1U) /*!< Bit field size in bits for GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PUP_ACK. */

/*! @brief Read current value of the GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PUP_ACK field. */
#define BR_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PUP_ACK(x) (HW_GPC_PGC_ACK_SEL_M4(x).B.M4_DUMMY_PGC_PUP_ACK)

/*! @brief Format value for bitfield GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PUP_ACK. */
#define BF_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PUP_ACK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PUP_ACK) & BM_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PUP_ACK)

/*! @brief Set the M4_DUMMY_PGC_PUP_ACK field to a new value. */
#define BW_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PUP_ACK(x, v) (HW_GPC_PGC_ACK_SEL_M4_WR(x, (HW_GPC_PGC_ACK_SEL_M4_RD(x) & ~BM_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PUP_ACK) | BF_GPC_PGC_ACK_SEL_M4_M4_DUMMY_PGC_PUP_ACK(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_MISC - GPC Miscellaneous register
 ******************************************************************************/

/*!
 * @brief HW_GPC_MISC - GPC Miscellaneous register (RW)
 *
 * Reset value: 0x00000002U
 */
typedef union _hw_gpc_misc
{
    uint32_t U;
    struct _hw_gpc_misc_bitfields
    {
        uint32_t M4_SLEEP_HOLD_REQ_B : 1; /*!< [0]  */
        uint32_t RESERVED0 : 4;        /*!< [4:1]  */
        uint32_t GPC_IRQ_MASK : 1;     /*!< [5]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t M4_PDN_REQ_MASK : 1;  /*!< [8]  */
        uint32_t RESERVED2 : 23;       /*!< [31:9]  */
    } B;
} hw_gpc_misc_t;

/*!
 * @name Constants and macros for entire GPC_MISC register
 */
/*@{*/
#define HW_GPC_MISC_ADDR(x)      ((uintptr_t)(x) + 0x2CU)

#define HW_GPC_MISC(x)           (*(__IO hw_gpc_misc_t *) HW_GPC_MISC_ADDR(x))
#define HW_GPC_MISC_RD(x)        (HW_GPC_MISC(x).U)
#define HW_GPC_MISC_WR(x, v)     (HW_GPC_MISC(x).U = (v))
#define HW_GPC_MISC_SET(x, v)    (HW_GPC_MISC_WR(x, HW_GPC_MISC_RD(x) |  (v)))
#define HW_GPC_MISC_CLR(x, v)    (HW_GPC_MISC_WR(x, HW_GPC_MISC_RD(x) & ~(v)))
#define HW_GPC_MISC_TOG(x, v)    (HW_GPC_MISC_WR(x, HW_GPC_MISC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_MISC bitfields
 */

/*!
 * @name Register GPC_MISC, field M4_SLEEP_HOLD_REQ_B[0] (RW)
 *
 * M4 sleep hold
 *
 * Values:
 * - 0 - Hold M4 platform in sleep mode. This bit is a software control bit to
 *     M4 platform.
 * - 1 - Don't hold M4 platform in sleep mode.
 */
/*@{*/
#define BP_GPC_MISC_M4_SLEEP_HOLD_REQ_B (0U) /*!< Bit position for GPC_MISC_M4_SLEEP_HOLD_REQ_B. */
#define BM_GPC_MISC_M4_SLEEP_HOLD_REQ_B (0x00000001U) /*!< Bit mask for GPC_MISC_M4_SLEEP_HOLD_REQ_B. */
#define BS_GPC_MISC_M4_SLEEP_HOLD_REQ_B (1U) /*!< Bit field size in bits for GPC_MISC_M4_SLEEP_HOLD_REQ_B. */

/*! @brief Read current value of the GPC_MISC_M4_SLEEP_HOLD_REQ_B field. */
#define BR_GPC_MISC_M4_SLEEP_HOLD_REQ_B(x) (HW_GPC_MISC(x).B.M4_SLEEP_HOLD_REQ_B)

/*! @brief Format value for bitfield GPC_MISC_M4_SLEEP_HOLD_REQ_B. */
#define BF_GPC_MISC_M4_SLEEP_HOLD_REQ_B(v) ((uint32_t)((uint32_t)(v) << BP_GPC_MISC_M4_SLEEP_HOLD_REQ_B) & BM_GPC_MISC_M4_SLEEP_HOLD_REQ_B)

/*! @brief Set the M4_SLEEP_HOLD_REQ_B field to a new value. */
#define BW_GPC_MISC_M4_SLEEP_HOLD_REQ_B(x, v) (HW_GPC_MISC_WR(x, (HW_GPC_MISC_RD(x) & ~BM_GPC_MISC_M4_SLEEP_HOLD_REQ_B) | BF_GPC_MISC_M4_SLEEP_HOLD_REQ_B(v)))
/*@}*/

/*!
 * @name Register GPC_MISC, field GPC_IRQ_MASK[5] (RW)
 *
 * GPC interrupt/event masking
 *
 * Values:
 * - 0 - Not masked
 * - 1 - Interrupt / event is masked
 */
/*@{*/
#define BP_GPC_MISC_GPC_IRQ_MASK (5U)      /*!< Bit position for GPC_MISC_GPC_IRQ_MASK. */
#define BM_GPC_MISC_GPC_IRQ_MASK (0x00000020U) /*!< Bit mask for GPC_MISC_GPC_IRQ_MASK. */
#define BS_GPC_MISC_GPC_IRQ_MASK (1U)      /*!< Bit field size in bits for GPC_MISC_GPC_IRQ_MASK. */

/*! @brief Read current value of the GPC_MISC_GPC_IRQ_MASK field. */
#define BR_GPC_MISC_GPC_IRQ_MASK(x) (HW_GPC_MISC(x).B.GPC_IRQ_MASK)

/*! @brief Format value for bitfield GPC_MISC_GPC_IRQ_MASK. */
#define BF_GPC_MISC_GPC_IRQ_MASK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_MISC_GPC_IRQ_MASK) & BM_GPC_MISC_GPC_IRQ_MASK)

/*! @brief Set the GPC_IRQ_MASK field to a new value. */
#define BW_GPC_MISC_GPC_IRQ_MASK(x, v) (HW_GPC_MISC_WR(x, (HW_GPC_MISC_RD(x) & ~BM_GPC_MISC_GPC_IRQ_MASK) | BF_GPC_MISC_GPC_IRQ_MASK(v)))
/*@}*/

/*!
 * @name Register GPC_MISC, field M4_PDN_REQ_MASK[8] (RW)
 *
 * M4 power-down mask
 *
 * Values:
 * - 0 - M4 power down request to virtual M4 PGC will be masked.
 * - 1 - M4 power down request to virtual M4 PGC will not be masked. Set this
 *     bit to 1'b1 when M4 virtual PGC is used.
 */
/*@{*/
#define BP_GPC_MISC_M4_PDN_REQ_MASK (8U)   /*!< Bit position for GPC_MISC_M4_PDN_REQ_MASK. */
#define BM_GPC_MISC_M4_PDN_REQ_MASK (0x00000100U) /*!< Bit mask for GPC_MISC_M4_PDN_REQ_MASK. */
#define BS_GPC_MISC_M4_PDN_REQ_MASK (1U)   /*!< Bit field size in bits for GPC_MISC_M4_PDN_REQ_MASK. */

/*! @brief Read current value of the GPC_MISC_M4_PDN_REQ_MASK field. */
#define BR_GPC_MISC_M4_PDN_REQ_MASK(x) (HW_GPC_MISC(x).B.M4_PDN_REQ_MASK)

/*! @brief Format value for bitfield GPC_MISC_M4_PDN_REQ_MASK. */
#define BF_GPC_MISC_M4_PDN_REQ_MASK(v) ((uint32_t)((uint32_t)(v) << BP_GPC_MISC_M4_PDN_REQ_MASK) & BM_GPC_MISC_M4_PDN_REQ_MASK)

/*! @brief Set the M4_PDN_REQ_MASK field to a new value. */
#define BW_GPC_MISC_M4_PDN_REQ_MASK(x, v) (HW_GPC_MISC_WR(x, (HW_GPC_MISC_RD(x) & ~BM_GPC_MISC_M4_PDN_REQ_MASK) | BF_GPC_MISC_M4_PDN_REQ_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_IMR1_CORE0_A7 - IRQ masking register 1 of A7 core0
 ******************************************************************************/

/*!
 * @brief HW_GPC_IMR1_CORE0_A7 - IRQ masking register 1 of A7 core0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The four IMRn_CORE0_A7 (n = 1,2,3,4) registers are used as interrupt mask for
 * A7 core0.
 */
typedef union _hw_gpc_imr1_core0_a7
{
    uint32_t U;
    struct _hw_gpc_imr1_core0_a7_bitfields
    {
        uint32_t IMR1_CORE0_A7 : 32;   /*!< [31:0]  */
    } B;
} hw_gpc_imr1_core0_a7_t;

/*!
 * @name Constants and macros for entire GPC_IMR1_CORE0_A7 register
 */
/*@{*/
#define HW_GPC_IMR1_CORE0_A7_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_GPC_IMR1_CORE0_A7(x)  (*(__IO hw_gpc_imr1_core0_a7_t *) HW_GPC_IMR1_CORE0_A7_ADDR(x))
#define HW_GPC_IMR1_CORE0_A7_RD(x) (HW_GPC_IMR1_CORE0_A7(x).U)
#define HW_GPC_IMR1_CORE0_A7_WR(x, v) (HW_GPC_IMR1_CORE0_A7(x).U = (v))
#define HW_GPC_IMR1_CORE0_A7_SET(x, v) (HW_GPC_IMR1_CORE0_A7_WR(x, HW_GPC_IMR1_CORE0_A7_RD(x) |  (v)))
#define HW_GPC_IMR1_CORE0_A7_CLR(x, v) (HW_GPC_IMR1_CORE0_A7_WR(x, HW_GPC_IMR1_CORE0_A7_RD(x) & ~(v)))
#define HW_GPC_IMR1_CORE0_A7_TOG(x, v) (HW_GPC_IMR1_CORE0_A7_WR(x, HW_GPC_IMR1_CORE0_A7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_IMR1_CORE0_A7 bitfields
 */

/*!
 * @name Register GPC_IMR1_CORE0_A7, field IMR1_CORE0_A7[31:0] (RW)
 *
 * A7 core0 IRQ[31:0] masking bits:
 *
 * Values:
 * - 0 - IRQ not masked
 * - 1 - IRQ masked
 */
/*@{*/
#define BP_GPC_IMR1_CORE0_A7_IMR1_CORE0_A7 (0U) /*!< Bit position for GPC_IMR1_CORE0_A7_IMR1_CORE0_A7. */
#define BM_GPC_IMR1_CORE0_A7_IMR1_CORE0_A7 (0xFFFFFFFFU) /*!< Bit mask for GPC_IMR1_CORE0_A7_IMR1_CORE0_A7. */
#define BS_GPC_IMR1_CORE0_A7_IMR1_CORE0_A7 (32U) /*!< Bit field size in bits for GPC_IMR1_CORE0_A7_IMR1_CORE0_A7. */

/*! @brief Read current value of the GPC_IMR1_CORE0_A7_IMR1_CORE0_A7 field. */
#define BR_GPC_IMR1_CORE0_A7_IMR1_CORE0_A7(x) (HW_GPC_IMR1_CORE0_A7(x).U)

/*! @brief Format value for bitfield GPC_IMR1_CORE0_A7_IMR1_CORE0_A7. */
#define BF_GPC_IMR1_CORE0_A7_IMR1_CORE0_A7(v) ((uint32_t)((uint32_t)(v) << BP_GPC_IMR1_CORE0_A7_IMR1_CORE0_A7) & BM_GPC_IMR1_CORE0_A7_IMR1_CORE0_A7)

/*! @brief Set the IMR1_CORE0_A7 field to a new value. */
#define BW_GPC_IMR1_CORE0_A7_IMR1_CORE0_A7(x, v) (HW_GPC_IMR1_CORE0_A7_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPC_IMR2_CORE0_A7 - IRQ masking register 2 of A7 core0
 ******************************************************************************/

/*!
 * @brief HW_GPC_IMR2_CORE0_A7 - IRQ masking register 2 of A7 core0 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_imr2_core0_a7
{
    uint32_t U;
    struct _hw_gpc_imr2_core0_a7_bitfields
    {
        uint32_t IMR2_CORE0_A7 : 32;   /*!< [31:0]  */
    } B;
} hw_gpc_imr2_core0_a7_t;

/*!
 * @name Constants and macros for entire GPC_IMR2_CORE0_A7 register
 */
/*@{*/
#define HW_GPC_IMR2_CORE0_A7_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_GPC_IMR2_CORE0_A7(x)  (*(__IO hw_gpc_imr2_core0_a7_t *) HW_GPC_IMR2_CORE0_A7_ADDR(x))
#define HW_GPC_IMR2_CORE0_A7_RD(x) (HW_GPC_IMR2_CORE0_A7(x).U)
#define HW_GPC_IMR2_CORE0_A7_WR(x, v) (HW_GPC_IMR2_CORE0_A7(x).U = (v))
#define HW_GPC_IMR2_CORE0_A7_SET(x, v) (HW_GPC_IMR2_CORE0_A7_WR(x, HW_GPC_IMR2_CORE0_A7_RD(x) |  (v)))
#define HW_GPC_IMR2_CORE0_A7_CLR(x, v) (HW_GPC_IMR2_CORE0_A7_WR(x, HW_GPC_IMR2_CORE0_A7_RD(x) & ~(v)))
#define HW_GPC_IMR2_CORE0_A7_TOG(x, v) (HW_GPC_IMR2_CORE0_A7_WR(x, HW_GPC_IMR2_CORE0_A7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_IMR2_CORE0_A7 bitfields
 */

/*!
 * @name Register GPC_IMR2_CORE0_A7, field IMR2_CORE0_A7[31:0] (RW)
 *
 * A7 core0 IRQ[63:32] masking bits:
 *
 * Values:
 * - 0 - IRQ not masked
 * - 1 - IRQ masked
 */
/*@{*/
#define BP_GPC_IMR2_CORE0_A7_IMR2_CORE0_A7 (0U) /*!< Bit position for GPC_IMR2_CORE0_A7_IMR2_CORE0_A7. */
#define BM_GPC_IMR2_CORE0_A7_IMR2_CORE0_A7 (0xFFFFFFFFU) /*!< Bit mask for GPC_IMR2_CORE0_A7_IMR2_CORE0_A7. */
#define BS_GPC_IMR2_CORE0_A7_IMR2_CORE0_A7 (32U) /*!< Bit field size in bits for GPC_IMR2_CORE0_A7_IMR2_CORE0_A7. */

/*! @brief Read current value of the GPC_IMR2_CORE0_A7_IMR2_CORE0_A7 field. */
#define BR_GPC_IMR2_CORE0_A7_IMR2_CORE0_A7(x) (HW_GPC_IMR2_CORE0_A7(x).U)

/*! @brief Format value for bitfield GPC_IMR2_CORE0_A7_IMR2_CORE0_A7. */
#define BF_GPC_IMR2_CORE0_A7_IMR2_CORE0_A7(v) ((uint32_t)((uint32_t)(v) << BP_GPC_IMR2_CORE0_A7_IMR2_CORE0_A7) & BM_GPC_IMR2_CORE0_A7_IMR2_CORE0_A7)

/*! @brief Set the IMR2_CORE0_A7 field to a new value. */
#define BW_GPC_IMR2_CORE0_A7_IMR2_CORE0_A7(x, v) (HW_GPC_IMR2_CORE0_A7_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPC_IMR3_CORE0_A7 - IRQ masking register 3 of A7 core0
 ******************************************************************************/

/*!
 * @brief HW_GPC_IMR3_CORE0_A7 - IRQ masking register 3 of A7 core0 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_imr3_core0_a7
{
    uint32_t U;
    struct _hw_gpc_imr3_core0_a7_bitfields
    {
        uint32_t IMR3_CORE0_A7 : 32;   /*!< [31:0]  */
    } B;
} hw_gpc_imr3_core0_a7_t;

/*!
 * @name Constants and macros for entire GPC_IMR3_CORE0_A7 register
 */
/*@{*/
#define HW_GPC_IMR3_CORE0_A7_ADDR(x) ((uintptr_t)(x) + 0x38U)

#define HW_GPC_IMR3_CORE0_A7(x)  (*(__IO hw_gpc_imr3_core0_a7_t *) HW_GPC_IMR3_CORE0_A7_ADDR(x))
#define HW_GPC_IMR3_CORE0_A7_RD(x) (HW_GPC_IMR3_CORE0_A7(x).U)
#define HW_GPC_IMR3_CORE0_A7_WR(x, v) (HW_GPC_IMR3_CORE0_A7(x).U = (v))
#define HW_GPC_IMR3_CORE0_A7_SET(x, v) (HW_GPC_IMR3_CORE0_A7_WR(x, HW_GPC_IMR3_CORE0_A7_RD(x) |  (v)))
#define HW_GPC_IMR3_CORE0_A7_CLR(x, v) (HW_GPC_IMR3_CORE0_A7_WR(x, HW_GPC_IMR3_CORE0_A7_RD(x) & ~(v)))
#define HW_GPC_IMR3_CORE0_A7_TOG(x, v) (HW_GPC_IMR3_CORE0_A7_WR(x, HW_GPC_IMR3_CORE0_A7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_IMR3_CORE0_A7 bitfields
 */

/*!
 * @name Register GPC_IMR3_CORE0_A7, field IMR3_CORE0_A7[31:0] (RW)
 *
 * A7 core0 IRQ[95:64] masking bits:
 *
 * Values:
 * - 0 - IRQ not masked
 * - 1 - IRQ masked
 */
/*@{*/
#define BP_GPC_IMR3_CORE0_A7_IMR3_CORE0_A7 (0U) /*!< Bit position for GPC_IMR3_CORE0_A7_IMR3_CORE0_A7. */
#define BM_GPC_IMR3_CORE0_A7_IMR3_CORE0_A7 (0xFFFFFFFFU) /*!< Bit mask for GPC_IMR3_CORE0_A7_IMR3_CORE0_A7. */
#define BS_GPC_IMR3_CORE0_A7_IMR3_CORE0_A7 (32U) /*!< Bit field size in bits for GPC_IMR3_CORE0_A7_IMR3_CORE0_A7. */

/*! @brief Read current value of the GPC_IMR3_CORE0_A7_IMR3_CORE0_A7 field. */
#define BR_GPC_IMR3_CORE0_A7_IMR3_CORE0_A7(x) (HW_GPC_IMR3_CORE0_A7(x).U)

/*! @brief Format value for bitfield GPC_IMR3_CORE0_A7_IMR3_CORE0_A7. */
#define BF_GPC_IMR3_CORE0_A7_IMR3_CORE0_A7(v) ((uint32_t)((uint32_t)(v) << BP_GPC_IMR3_CORE0_A7_IMR3_CORE0_A7) & BM_GPC_IMR3_CORE0_A7_IMR3_CORE0_A7)

/*! @brief Set the IMR3_CORE0_A7 field to a new value. */
#define BW_GPC_IMR3_CORE0_A7_IMR3_CORE0_A7(x, v) (HW_GPC_IMR3_CORE0_A7_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPC_IMR4_CORE0_A7 - IRQ masking register 4 of A7 core0
 ******************************************************************************/

/*!
 * @brief HW_GPC_IMR4_CORE0_A7 - IRQ masking register 4 of A7 core0 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_imr4_core0_a7
{
    uint32_t U;
    struct _hw_gpc_imr4_core0_a7_bitfields
    {
        uint32_t IMR4_CORE0_A7 : 32;   /*!< [31:0]  */
    } B;
} hw_gpc_imr4_core0_a7_t;

/*!
 * @name Constants and macros for entire GPC_IMR4_CORE0_A7 register
 */
/*@{*/
#define HW_GPC_IMR4_CORE0_A7_ADDR(x) ((uintptr_t)(x) + 0x3CU)

#define HW_GPC_IMR4_CORE0_A7(x)  (*(__IO hw_gpc_imr4_core0_a7_t *) HW_GPC_IMR4_CORE0_A7_ADDR(x))
#define HW_GPC_IMR4_CORE0_A7_RD(x) (HW_GPC_IMR4_CORE0_A7(x).U)
#define HW_GPC_IMR4_CORE0_A7_WR(x, v) (HW_GPC_IMR4_CORE0_A7(x).U = (v))
#define HW_GPC_IMR4_CORE0_A7_SET(x, v) (HW_GPC_IMR4_CORE0_A7_WR(x, HW_GPC_IMR4_CORE0_A7_RD(x) |  (v)))
#define HW_GPC_IMR4_CORE0_A7_CLR(x, v) (HW_GPC_IMR4_CORE0_A7_WR(x, HW_GPC_IMR4_CORE0_A7_RD(x) & ~(v)))
#define HW_GPC_IMR4_CORE0_A7_TOG(x, v) (HW_GPC_IMR4_CORE0_A7_WR(x, HW_GPC_IMR4_CORE0_A7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_IMR4_CORE0_A7 bitfields
 */

/*!
 * @name Register GPC_IMR4_CORE0_A7, field IMR4_CORE0_A7[31:0] (RW)
 *
 * A7 core0 IRQ[127:96] masking bits:
 *
 * Values:
 * - 0 - IRQ not masked
 * - 1 - IRQ masked
 */
/*@{*/
#define BP_GPC_IMR4_CORE0_A7_IMR4_CORE0_A7 (0U) /*!< Bit position for GPC_IMR4_CORE0_A7_IMR4_CORE0_A7. */
#define BM_GPC_IMR4_CORE0_A7_IMR4_CORE0_A7 (0xFFFFFFFFU) /*!< Bit mask for GPC_IMR4_CORE0_A7_IMR4_CORE0_A7. */
#define BS_GPC_IMR4_CORE0_A7_IMR4_CORE0_A7 (32U) /*!< Bit field size in bits for GPC_IMR4_CORE0_A7_IMR4_CORE0_A7. */

/*! @brief Read current value of the GPC_IMR4_CORE0_A7_IMR4_CORE0_A7 field. */
#define BR_GPC_IMR4_CORE0_A7_IMR4_CORE0_A7(x) (HW_GPC_IMR4_CORE0_A7(x).U)

/*! @brief Format value for bitfield GPC_IMR4_CORE0_A7_IMR4_CORE0_A7. */
#define BF_GPC_IMR4_CORE0_A7_IMR4_CORE0_A7(v) ((uint32_t)((uint32_t)(v) << BP_GPC_IMR4_CORE0_A7_IMR4_CORE0_A7) & BM_GPC_IMR4_CORE0_A7_IMR4_CORE0_A7)

/*! @brief Set the IMR4_CORE0_A7 field to a new value. */
#define BW_GPC_IMR4_CORE0_A7_IMR4_CORE0_A7(x, v) (HW_GPC_IMR4_CORE0_A7_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPC_IMR1_CORE1_A7 - IRQ masking register 1 of A7 core1
 ******************************************************************************/

/*!
 * @brief HW_GPC_IMR1_CORE1_A7 - IRQ masking register 1 of A7 core1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The four IMRn_CORE1_A7 (n = 1,2,3,4) registers are used as interrupt mask for
 * A7 core1.
 */
typedef union _hw_gpc_imr1_core1_a7
{
    uint32_t U;
    struct _hw_gpc_imr1_core1_a7_bitfields
    {
        uint32_t IMR1_CORE1_A7 : 32;   /*!< [31:0]  */
    } B;
} hw_gpc_imr1_core1_a7_t;

/*!
 * @name Constants and macros for entire GPC_IMR1_CORE1_A7 register
 */
/*@{*/
#define HW_GPC_IMR1_CORE1_A7_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_GPC_IMR1_CORE1_A7(x)  (*(__IO hw_gpc_imr1_core1_a7_t *) HW_GPC_IMR1_CORE1_A7_ADDR(x))
#define HW_GPC_IMR1_CORE1_A7_RD(x) (HW_GPC_IMR1_CORE1_A7(x).U)
#define HW_GPC_IMR1_CORE1_A7_WR(x, v) (HW_GPC_IMR1_CORE1_A7(x).U = (v))
#define HW_GPC_IMR1_CORE1_A7_SET(x, v) (HW_GPC_IMR1_CORE1_A7_WR(x, HW_GPC_IMR1_CORE1_A7_RD(x) |  (v)))
#define HW_GPC_IMR1_CORE1_A7_CLR(x, v) (HW_GPC_IMR1_CORE1_A7_WR(x, HW_GPC_IMR1_CORE1_A7_RD(x) & ~(v)))
#define HW_GPC_IMR1_CORE1_A7_TOG(x, v) (HW_GPC_IMR1_CORE1_A7_WR(x, HW_GPC_IMR1_CORE1_A7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_IMR1_CORE1_A7 bitfields
 */

/*!
 * @name Register GPC_IMR1_CORE1_A7, field IMR1_CORE1_A7[31:0] (RW)
 *
 * A7 core1 IRQ[31:0] masking bits:
 *
 * Values:
 * - 0 - IRQ not masked
 * - 1 - IRQ masked
 */
/*@{*/
#define BP_GPC_IMR1_CORE1_A7_IMR1_CORE1_A7 (0U) /*!< Bit position for GPC_IMR1_CORE1_A7_IMR1_CORE1_A7. */
#define BM_GPC_IMR1_CORE1_A7_IMR1_CORE1_A7 (0xFFFFFFFFU) /*!< Bit mask for GPC_IMR1_CORE1_A7_IMR1_CORE1_A7. */
#define BS_GPC_IMR1_CORE1_A7_IMR1_CORE1_A7 (32U) /*!< Bit field size in bits for GPC_IMR1_CORE1_A7_IMR1_CORE1_A7. */

/*! @brief Read current value of the GPC_IMR1_CORE1_A7_IMR1_CORE1_A7 field. */
#define BR_GPC_IMR1_CORE1_A7_IMR1_CORE1_A7(x) (HW_GPC_IMR1_CORE1_A7(x).U)

/*! @brief Format value for bitfield GPC_IMR1_CORE1_A7_IMR1_CORE1_A7. */
#define BF_GPC_IMR1_CORE1_A7_IMR1_CORE1_A7(v) ((uint32_t)((uint32_t)(v) << BP_GPC_IMR1_CORE1_A7_IMR1_CORE1_A7) & BM_GPC_IMR1_CORE1_A7_IMR1_CORE1_A7)

/*! @brief Set the IMR1_CORE1_A7 field to a new value. */
#define BW_GPC_IMR1_CORE1_A7_IMR1_CORE1_A7(x, v) (HW_GPC_IMR1_CORE1_A7_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPC_IMR2_CORE1_A7 - IRQ masking register 2 of A7 core1
 ******************************************************************************/

/*!
 * @brief HW_GPC_IMR2_CORE1_A7 - IRQ masking register 2 of A7 core1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_imr2_core1_a7
{
    uint32_t U;
    struct _hw_gpc_imr2_core1_a7_bitfields
    {
        uint32_t IMR2_CORE1_A7 : 32;   /*!< [31:0]  */
    } B;
} hw_gpc_imr2_core1_a7_t;

/*!
 * @name Constants and macros for entire GPC_IMR2_CORE1_A7 register
 */
/*@{*/
#define HW_GPC_IMR2_CORE1_A7_ADDR(x) ((uintptr_t)(x) + 0x44U)

#define HW_GPC_IMR2_CORE1_A7(x)  (*(__IO hw_gpc_imr2_core1_a7_t *) HW_GPC_IMR2_CORE1_A7_ADDR(x))
#define HW_GPC_IMR2_CORE1_A7_RD(x) (HW_GPC_IMR2_CORE1_A7(x).U)
#define HW_GPC_IMR2_CORE1_A7_WR(x, v) (HW_GPC_IMR2_CORE1_A7(x).U = (v))
#define HW_GPC_IMR2_CORE1_A7_SET(x, v) (HW_GPC_IMR2_CORE1_A7_WR(x, HW_GPC_IMR2_CORE1_A7_RD(x) |  (v)))
#define HW_GPC_IMR2_CORE1_A7_CLR(x, v) (HW_GPC_IMR2_CORE1_A7_WR(x, HW_GPC_IMR2_CORE1_A7_RD(x) & ~(v)))
#define HW_GPC_IMR2_CORE1_A7_TOG(x, v) (HW_GPC_IMR2_CORE1_A7_WR(x, HW_GPC_IMR2_CORE1_A7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_IMR2_CORE1_A7 bitfields
 */

/*!
 * @name Register GPC_IMR2_CORE1_A7, field IMR2_CORE1_A7[31:0] (RW)
 *
 * A7 core1 IRQ[63:32] masking bits:
 *
 * Values:
 * - 0 - IRQ not masked
 * - 1 - IRQ masked
 */
/*@{*/
#define BP_GPC_IMR2_CORE1_A7_IMR2_CORE1_A7 (0U) /*!< Bit position for GPC_IMR2_CORE1_A7_IMR2_CORE1_A7. */
#define BM_GPC_IMR2_CORE1_A7_IMR2_CORE1_A7 (0xFFFFFFFFU) /*!< Bit mask for GPC_IMR2_CORE1_A7_IMR2_CORE1_A7. */
#define BS_GPC_IMR2_CORE1_A7_IMR2_CORE1_A7 (32U) /*!< Bit field size in bits for GPC_IMR2_CORE1_A7_IMR2_CORE1_A7. */

/*! @brief Read current value of the GPC_IMR2_CORE1_A7_IMR2_CORE1_A7 field. */
#define BR_GPC_IMR2_CORE1_A7_IMR2_CORE1_A7(x) (HW_GPC_IMR2_CORE1_A7(x).U)

/*! @brief Format value for bitfield GPC_IMR2_CORE1_A7_IMR2_CORE1_A7. */
#define BF_GPC_IMR2_CORE1_A7_IMR2_CORE1_A7(v) ((uint32_t)((uint32_t)(v) << BP_GPC_IMR2_CORE1_A7_IMR2_CORE1_A7) & BM_GPC_IMR2_CORE1_A7_IMR2_CORE1_A7)

/*! @brief Set the IMR2_CORE1_A7 field to a new value. */
#define BW_GPC_IMR2_CORE1_A7_IMR2_CORE1_A7(x, v) (HW_GPC_IMR2_CORE1_A7_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPC_IMR3_CORE1_A7 - IRQ masking register 3 of A7 core1
 ******************************************************************************/

/*!
 * @brief HW_GPC_IMR3_CORE1_A7 - IRQ masking register 3 of A7 core1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_imr3_core1_a7
{
    uint32_t U;
    struct _hw_gpc_imr3_core1_a7_bitfields
    {
        uint32_t IMR3_CORE1_A7 : 32;   /*!< [31:0]  */
    } B;
} hw_gpc_imr3_core1_a7_t;

/*!
 * @name Constants and macros for entire GPC_IMR3_CORE1_A7 register
 */
/*@{*/
#define HW_GPC_IMR3_CORE1_A7_ADDR(x) ((uintptr_t)(x) + 0x48U)

#define HW_GPC_IMR3_CORE1_A7(x)  (*(__IO hw_gpc_imr3_core1_a7_t *) HW_GPC_IMR3_CORE1_A7_ADDR(x))
#define HW_GPC_IMR3_CORE1_A7_RD(x) (HW_GPC_IMR3_CORE1_A7(x).U)
#define HW_GPC_IMR3_CORE1_A7_WR(x, v) (HW_GPC_IMR3_CORE1_A7(x).U = (v))
#define HW_GPC_IMR3_CORE1_A7_SET(x, v) (HW_GPC_IMR3_CORE1_A7_WR(x, HW_GPC_IMR3_CORE1_A7_RD(x) |  (v)))
#define HW_GPC_IMR3_CORE1_A7_CLR(x, v) (HW_GPC_IMR3_CORE1_A7_WR(x, HW_GPC_IMR3_CORE1_A7_RD(x) & ~(v)))
#define HW_GPC_IMR3_CORE1_A7_TOG(x, v) (HW_GPC_IMR3_CORE1_A7_WR(x, HW_GPC_IMR3_CORE1_A7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_IMR3_CORE1_A7 bitfields
 */

/*!
 * @name Register GPC_IMR3_CORE1_A7, field IMR3_CORE1_A7[31:0] (RW)
 *
 * A7 core1 IRQ[95:64] masking bits:
 *
 * Values:
 * - 0 - IRQ not masked
 * - 1 - IRQ masked
 */
/*@{*/
#define BP_GPC_IMR3_CORE1_A7_IMR3_CORE1_A7 (0U) /*!< Bit position for GPC_IMR3_CORE1_A7_IMR3_CORE1_A7. */
#define BM_GPC_IMR3_CORE1_A7_IMR3_CORE1_A7 (0xFFFFFFFFU) /*!< Bit mask for GPC_IMR3_CORE1_A7_IMR3_CORE1_A7. */
#define BS_GPC_IMR3_CORE1_A7_IMR3_CORE1_A7 (32U) /*!< Bit field size in bits for GPC_IMR3_CORE1_A7_IMR3_CORE1_A7. */

/*! @brief Read current value of the GPC_IMR3_CORE1_A7_IMR3_CORE1_A7 field. */
#define BR_GPC_IMR3_CORE1_A7_IMR3_CORE1_A7(x) (HW_GPC_IMR3_CORE1_A7(x).U)

/*! @brief Format value for bitfield GPC_IMR3_CORE1_A7_IMR3_CORE1_A7. */
#define BF_GPC_IMR3_CORE1_A7_IMR3_CORE1_A7(v) ((uint32_t)((uint32_t)(v) << BP_GPC_IMR3_CORE1_A7_IMR3_CORE1_A7) & BM_GPC_IMR3_CORE1_A7_IMR3_CORE1_A7)

/*! @brief Set the IMR3_CORE1_A7 field to a new value. */
#define BW_GPC_IMR3_CORE1_A7_IMR3_CORE1_A7(x, v) (HW_GPC_IMR3_CORE1_A7_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPC_IMR4_CORE1_A7 - IRQ masking register 4 of A7 core1
 ******************************************************************************/

/*!
 * @brief HW_GPC_IMR4_CORE1_A7 - IRQ masking register 4 of A7 core1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_imr4_core1_a7
{
    uint32_t U;
    struct _hw_gpc_imr4_core1_a7_bitfields
    {
        uint32_t IMR4_CORE1_A7 : 32;   /*!< [31:0]  */
    } B;
} hw_gpc_imr4_core1_a7_t;

/*!
 * @name Constants and macros for entire GPC_IMR4_CORE1_A7 register
 */
/*@{*/
#define HW_GPC_IMR4_CORE1_A7_ADDR(x) ((uintptr_t)(x) + 0x4CU)

#define HW_GPC_IMR4_CORE1_A7(x)  (*(__IO hw_gpc_imr4_core1_a7_t *) HW_GPC_IMR4_CORE1_A7_ADDR(x))
#define HW_GPC_IMR4_CORE1_A7_RD(x) (HW_GPC_IMR4_CORE1_A7(x).U)
#define HW_GPC_IMR4_CORE1_A7_WR(x, v) (HW_GPC_IMR4_CORE1_A7(x).U = (v))
#define HW_GPC_IMR4_CORE1_A7_SET(x, v) (HW_GPC_IMR4_CORE1_A7_WR(x, HW_GPC_IMR4_CORE1_A7_RD(x) |  (v)))
#define HW_GPC_IMR4_CORE1_A7_CLR(x, v) (HW_GPC_IMR4_CORE1_A7_WR(x, HW_GPC_IMR4_CORE1_A7_RD(x) & ~(v)))
#define HW_GPC_IMR4_CORE1_A7_TOG(x, v) (HW_GPC_IMR4_CORE1_A7_WR(x, HW_GPC_IMR4_CORE1_A7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_IMR4_CORE1_A7 bitfields
 */

/*!
 * @name Register GPC_IMR4_CORE1_A7, field IMR4_CORE1_A7[31:0] (RW)
 *
 * A7 core1 IRQ[127:96] masking bits:
 *
 * Values:
 * - 0 - IRQ not masked
 * - 1 - IRQ masked
 */
/*@{*/
#define BP_GPC_IMR4_CORE1_A7_IMR4_CORE1_A7 (0U) /*!< Bit position for GPC_IMR4_CORE1_A7_IMR4_CORE1_A7. */
#define BM_GPC_IMR4_CORE1_A7_IMR4_CORE1_A7 (0xFFFFFFFFU) /*!< Bit mask for GPC_IMR4_CORE1_A7_IMR4_CORE1_A7. */
#define BS_GPC_IMR4_CORE1_A7_IMR4_CORE1_A7 (32U) /*!< Bit field size in bits for GPC_IMR4_CORE1_A7_IMR4_CORE1_A7. */

/*! @brief Read current value of the GPC_IMR4_CORE1_A7_IMR4_CORE1_A7 field. */
#define BR_GPC_IMR4_CORE1_A7_IMR4_CORE1_A7(x) (HW_GPC_IMR4_CORE1_A7(x).U)

/*! @brief Format value for bitfield GPC_IMR4_CORE1_A7_IMR4_CORE1_A7. */
#define BF_GPC_IMR4_CORE1_A7_IMR4_CORE1_A7(v) ((uint32_t)((uint32_t)(v) << BP_GPC_IMR4_CORE1_A7_IMR4_CORE1_A7) & BM_GPC_IMR4_CORE1_A7_IMR4_CORE1_A7)

/*! @brief Set the IMR4_CORE1_A7 field to a new value. */
#define BW_GPC_IMR4_CORE1_A7_IMR4_CORE1_A7(x, v) (HW_GPC_IMR4_CORE1_A7_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPC_IMR1_M4 - IRQ masking register 1 of M4
 ******************************************************************************/

/*!
 * @brief HW_GPC_IMR1_M4 - IRQ masking register 1 of M4 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The four IMRn_M4 (n = 1,2,3,4) registers are used as interrupt mask for M4.
 */
typedef union _hw_gpc_imr1_m4
{
    uint32_t U;
    struct _hw_gpc_imr1_m4_bitfields
    {
        uint32_t IMR1_M4 : 32;         /*!< [31:0]  */
    } B;
} hw_gpc_imr1_m4_t;

/*!
 * @name Constants and macros for entire GPC_IMR1_M4 register
 */
/*@{*/
#define HW_GPC_IMR1_M4_ADDR(x)   ((uintptr_t)(x) + 0x50U)

#define HW_GPC_IMR1_M4(x)        (*(__IO hw_gpc_imr1_m4_t *) HW_GPC_IMR1_M4_ADDR(x))
#define HW_GPC_IMR1_M4_RD(x)     (HW_GPC_IMR1_M4(x).U)
#define HW_GPC_IMR1_M4_WR(x, v)  (HW_GPC_IMR1_M4(x).U = (v))
#define HW_GPC_IMR1_M4_SET(x, v) (HW_GPC_IMR1_M4_WR(x, HW_GPC_IMR1_M4_RD(x) |  (v)))
#define HW_GPC_IMR1_M4_CLR(x, v) (HW_GPC_IMR1_M4_WR(x, HW_GPC_IMR1_M4_RD(x) & ~(v)))
#define HW_GPC_IMR1_M4_TOG(x, v) (HW_GPC_IMR1_M4_WR(x, HW_GPC_IMR1_M4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_IMR1_M4 bitfields
 */

/*!
 * @name Register GPC_IMR1_M4, field IMR1_M4[31:0] (RW)
 *
 * M4 IRQ[31:0] masking bits:
 *
 * Values:
 * - 0 - IRQ not masked
 * - 1 - IRQ masked
 */
/*@{*/
#define BP_GPC_IMR1_M4_IMR1_M4 (0U)        /*!< Bit position for GPC_IMR1_M4_IMR1_M4. */
#define BM_GPC_IMR1_M4_IMR1_M4 (0xFFFFFFFFU) /*!< Bit mask for GPC_IMR1_M4_IMR1_M4. */
#define BS_GPC_IMR1_M4_IMR1_M4 (32U)       /*!< Bit field size in bits for GPC_IMR1_M4_IMR1_M4. */

/*! @brief Read current value of the GPC_IMR1_M4_IMR1_M4 field. */
#define BR_GPC_IMR1_M4_IMR1_M4(x) (HW_GPC_IMR1_M4(x).U)

/*! @brief Format value for bitfield GPC_IMR1_M4_IMR1_M4. */
#define BF_GPC_IMR1_M4_IMR1_M4(v) ((uint32_t)((uint32_t)(v) << BP_GPC_IMR1_M4_IMR1_M4) & BM_GPC_IMR1_M4_IMR1_M4)

/*! @brief Set the IMR1_M4 field to a new value. */
#define BW_GPC_IMR1_M4_IMR1_M4(x, v) (HW_GPC_IMR1_M4_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPC_IMR2_M4 - IRQ masking register 2 of M4
 ******************************************************************************/

/*!
 * @brief HW_GPC_IMR2_M4 - IRQ masking register 2 of M4 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_imr2_m4
{
    uint32_t U;
    struct _hw_gpc_imr2_m4_bitfields
    {
        uint32_t IMR2_M4 : 32;         /*!< [31:0]  */
    } B;
} hw_gpc_imr2_m4_t;

/*!
 * @name Constants and macros for entire GPC_IMR2_M4 register
 */
/*@{*/
#define HW_GPC_IMR2_M4_ADDR(x)   ((uintptr_t)(x) + 0x54U)

#define HW_GPC_IMR2_M4(x)        (*(__IO hw_gpc_imr2_m4_t *) HW_GPC_IMR2_M4_ADDR(x))
#define HW_GPC_IMR2_M4_RD(x)     (HW_GPC_IMR2_M4(x).U)
#define HW_GPC_IMR2_M4_WR(x, v)  (HW_GPC_IMR2_M4(x).U = (v))
#define HW_GPC_IMR2_M4_SET(x, v) (HW_GPC_IMR2_M4_WR(x, HW_GPC_IMR2_M4_RD(x) |  (v)))
#define HW_GPC_IMR2_M4_CLR(x, v) (HW_GPC_IMR2_M4_WR(x, HW_GPC_IMR2_M4_RD(x) & ~(v)))
#define HW_GPC_IMR2_M4_TOG(x, v) (HW_GPC_IMR2_M4_WR(x, HW_GPC_IMR2_M4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_IMR2_M4 bitfields
 */

/*!
 * @name Register GPC_IMR2_M4, field IMR2_M4[31:0] (RW)
 *
 * M4 IRQ[63:32] masking bits:
 *
 * Values:
 * - 0 - IRQ not masked
 * - 1 - IRQ masked
 */
/*@{*/
#define BP_GPC_IMR2_M4_IMR2_M4 (0U)        /*!< Bit position for GPC_IMR2_M4_IMR2_M4. */
#define BM_GPC_IMR2_M4_IMR2_M4 (0xFFFFFFFFU) /*!< Bit mask for GPC_IMR2_M4_IMR2_M4. */
#define BS_GPC_IMR2_M4_IMR2_M4 (32U)       /*!< Bit field size in bits for GPC_IMR2_M4_IMR2_M4. */

/*! @brief Read current value of the GPC_IMR2_M4_IMR2_M4 field. */
#define BR_GPC_IMR2_M4_IMR2_M4(x) (HW_GPC_IMR2_M4(x).U)

/*! @brief Format value for bitfield GPC_IMR2_M4_IMR2_M4. */
#define BF_GPC_IMR2_M4_IMR2_M4(v) ((uint32_t)((uint32_t)(v) << BP_GPC_IMR2_M4_IMR2_M4) & BM_GPC_IMR2_M4_IMR2_M4)

/*! @brief Set the IMR2_M4 field to a new value. */
#define BW_GPC_IMR2_M4_IMR2_M4(x, v) (HW_GPC_IMR2_M4_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPC_IMR3_M4 - IRQ masking register 3 of M4
 ******************************************************************************/

/*!
 * @brief HW_GPC_IMR3_M4 - IRQ masking register 3 of M4 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_imr3_m4
{
    uint32_t U;
    struct _hw_gpc_imr3_m4_bitfields
    {
        uint32_t IMR3_M4 : 32;         /*!< [31:0]  */
    } B;
} hw_gpc_imr3_m4_t;

/*!
 * @name Constants and macros for entire GPC_IMR3_M4 register
 */
/*@{*/
#define HW_GPC_IMR3_M4_ADDR(x)   ((uintptr_t)(x) + 0x58U)

#define HW_GPC_IMR3_M4(x)        (*(__IO hw_gpc_imr3_m4_t *) HW_GPC_IMR3_M4_ADDR(x))
#define HW_GPC_IMR3_M4_RD(x)     (HW_GPC_IMR3_M4(x).U)
#define HW_GPC_IMR3_M4_WR(x, v)  (HW_GPC_IMR3_M4(x).U = (v))
#define HW_GPC_IMR3_M4_SET(x, v) (HW_GPC_IMR3_M4_WR(x, HW_GPC_IMR3_M4_RD(x) |  (v)))
#define HW_GPC_IMR3_M4_CLR(x, v) (HW_GPC_IMR3_M4_WR(x, HW_GPC_IMR3_M4_RD(x) & ~(v)))
#define HW_GPC_IMR3_M4_TOG(x, v) (HW_GPC_IMR3_M4_WR(x, HW_GPC_IMR3_M4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_IMR3_M4 bitfields
 */

/*!
 * @name Register GPC_IMR3_M4, field IMR3_M4[31:0] (RW)
 *
 * M4 IRQ[95:64] masking bits:
 *
 * Values:
 * - 0 - IRQ not masked
 * - 1 - IRQ masked
 */
/*@{*/
#define BP_GPC_IMR3_M4_IMR3_M4 (0U)        /*!< Bit position for GPC_IMR3_M4_IMR3_M4. */
#define BM_GPC_IMR3_M4_IMR3_M4 (0xFFFFFFFFU) /*!< Bit mask for GPC_IMR3_M4_IMR3_M4. */
#define BS_GPC_IMR3_M4_IMR3_M4 (32U)       /*!< Bit field size in bits for GPC_IMR3_M4_IMR3_M4. */

/*! @brief Read current value of the GPC_IMR3_M4_IMR3_M4 field. */
#define BR_GPC_IMR3_M4_IMR3_M4(x) (HW_GPC_IMR3_M4(x).U)

/*! @brief Format value for bitfield GPC_IMR3_M4_IMR3_M4. */
#define BF_GPC_IMR3_M4_IMR3_M4(v) ((uint32_t)((uint32_t)(v) << BP_GPC_IMR3_M4_IMR3_M4) & BM_GPC_IMR3_M4_IMR3_M4)

/*! @brief Set the IMR3_M4 field to a new value. */
#define BW_GPC_IMR3_M4_IMR3_M4(x, v) (HW_GPC_IMR3_M4_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPC_IMR4_M4 - IRQ masking register 4 of M4
 ******************************************************************************/

/*!
 * @brief HW_GPC_IMR4_M4 - IRQ masking register 4 of M4 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_imr4_m4
{
    uint32_t U;
    struct _hw_gpc_imr4_m4_bitfields
    {
        uint32_t IMR4_M4 : 32;         /*!< [31:0]  */
    } B;
} hw_gpc_imr4_m4_t;

/*!
 * @name Constants and macros for entire GPC_IMR4_M4 register
 */
/*@{*/
#define HW_GPC_IMR4_M4_ADDR(x)   ((uintptr_t)(x) + 0x5CU)

#define HW_GPC_IMR4_M4(x)        (*(__IO hw_gpc_imr4_m4_t *) HW_GPC_IMR4_M4_ADDR(x))
#define HW_GPC_IMR4_M4_RD(x)     (HW_GPC_IMR4_M4(x).U)
#define HW_GPC_IMR4_M4_WR(x, v)  (HW_GPC_IMR4_M4(x).U = (v))
#define HW_GPC_IMR4_M4_SET(x, v) (HW_GPC_IMR4_M4_WR(x, HW_GPC_IMR4_M4_RD(x) |  (v)))
#define HW_GPC_IMR4_M4_CLR(x, v) (HW_GPC_IMR4_M4_WR(x, HW_GPC_IMR4_M4_RD(x) & ~(v)))
#define HW_GPC_IMR4_M4_TOG(x, v) (HW_GPC_IMR4_M4_WR(x, HW_GPC_IMR4_M4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_IMR4_M4 bitfields
 */

/*!
 * @name Register GPC_IMR4_M4, field IMR4_M4[31:0] (RW)
 *
 * M4 IRQ[127:96] masking bits:
 *
 * Values:
 * - 0 - IRQ not masked
 * - 1 - IRQ masked
 */
/*@{*/
#define BP_GPC_IMR4_M4_IMR4_M4 (0U)        /*!< Bit position for GPC_IMR4_M4_IMR4_M4. */
#define BM_GPC_IMR4_M4_IMR4_M4 (0xFFFFFFFFU) /*!< Bit mask for GPC_IMR4_M4_IMR4_M4. */
#define BS_GPC_IMR4_M4_IMR4_M4 (32U)       /*!< Bit field size in bits for GPC_IMR4_M4_IMR4_M4. */

/*! @brief Read current value of the GPC_IMR4_M4_IMR4_M4 field. */
#define BR_GPC_IMR4_M4_IMR4_M4(x) (HW_GPC_IMR4_M4(x).U)

/*! @brief Format value for bitfield GPC_IMR4_M4_IMR4_M4. */
#define BF_GPC_IMR4_M4_IMR4_M4(v) ((uint32_t)((uint32_t)(v) << BP_GPC_IMR4_M4_IMR4_M4) & BM_GPC_IMR4_M4_IMR4_M4)

/*! @brief Set the IMR4_M4 field to a new value. */
#define BW_GPC_IMR4_M4_IMR4_M4(x, v) (HW_GPC_IMR4_M4_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPC_ISR1_A7 - IRQ status register 1 of A7
 ******************************************************************************/

/*!
 * @brief HW_GPC_ISR1_A7 - IRQ status register 1 of A7 (RO)
 *
 * Reset value: 0x00000000U
 *
 * The four ISRn_A7 (n = 1,2,3,4) registers, all of them are read only register
 */
typedef union _hw_gpc_isr1_a7
{
    uint32_t U;
    struct _hw_gpc_isr1_a7_bitfields
    {
        uint32_t ISR1_A7 : 32;         /*!< [31:0]  */
    } B;
} hw_gpc_isr1_a7_t;

/*!
 * @name Constants and macros for entire GPC_ISR1_A7 register
 */
/*@{*/
#define HW_GPC_ISR1_A7_ADDR(x)   ((uintptr_t)(x) + 0x70U)

#define HW_GPC_ISR1_A7(x)        (*(__I hw_gpc_isr1_a7_t *) HW_GPC_ISR1_A7_ADDR(x))
#define HW_GPC_ISR1_A7_RD(x)     (HW_GPC_ISR1_A7(x).U)
/*@}*/

/*
 * Constants & macros for individual GPC_ISR1_A7 bitfields
 */

/*!
 * @name Register GPC_ISR1_A7, field ISR1_A7[31:0] (RO)
 *
 * A7 IRQ[31:0] status
 */
/*@{*/
#define BP_GPC_ISR1_A7_ISR1_A7 (0U)        /*!< Bit position for GPC_ISR1_A7_ISR1_A7. */
#define BM_GPC_ISR1_A7_ISR1_A7 (0xFFFFFFFFU) /*!< Bit mask for GPC_ISR1_A7_ISR1_A7. */
#define BS_GPC_ISR1_A7_ISR1_A7 (32U)       /*!< Bit field size in bits for GPC_ISR1_A7_ISR1_A7. */

/*! @brief Read current value of the GPC_ISR1_A7_ISR1_A7 field. */
#define BR_GPC_ISR1_A7_ISR1_A7(x) (HW_GPC_ISR1_A7(x).U)
/*@}*/

/*******************************************************************************
 * HW_GPC_ISR2_A7 - IRQ status register 2 of A7
 ******************************************************************************/

/*!
 * @brief HW_GPC_ISR2_A7 - IRQ status register 2 of A7 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_isr2_a7
{
    uint32_t U;
    struct _hw_gpc_isr2_a7_bitfields
    {
        uint32_t ISR2_A7 : 32;         /*!< [31:0]  */
    } B;
} hw_gpc_isr2_a7_t;

/*!
 * @name Constants and macros for entire GPC_ISR2_A7 register
 */
/*@{*/
#define HW_GPC_ISR2_A7_ADDR(x)   ((uintptr_t)(x) + 0x74U)

#define HW_GPC_ISR2_A7(x)        (*(__I hw_gpc_isr2_a7_t *) HW_GPC_ISR2_A7_ADDR(x))
#define HW_GPC_ISR2_A7_RD(x)     (HW_GPC_ISR2_A7(x).U)
/*@}*/

/*
 * Constants & macros for individual GPC_ISR2_A7 bitfields
 */

/*!
 * @name Register GPC_ISR2_A7, field ISR2_A7[31:0] (RO)
 *
 * A7 IRQ[63:32] status
 */
/*@{*/
#define BP_GPC_ISR2_A7_ISR2_A7 (0U)        /*!< Bit position for GPC_ISR2_A7_ISR2_A7. */
#define BM_GPC_ISR2_A7_ISR2_A7 (0xFFFFFFFFU) /*!< Bit mask for GPC_ISR2_A7_ISR2_A7. */
#define BS_GPC_ISR2_A7_ISR2_A7 (32U)       /*!< Bit field size in bits for GPC_ISR2_A7_ISR2_A7. */

/*! @brief Read current value of the GPC_ISR2_A7_ISR2_A7 field. */
#define BR_GPC_ISR2_A7_ISR2_A7(x) (HW_GPC_ISR2_A7(x).U)
/*@}*/

/*******************************************************************************
 * HW_GPC_ISR3_A7 - IRQ status register 3 of A7
 ******************************************************************************/

/*!
 * @brief HW_GPC_ISR3_A7 - IRQ status register 3 of A7 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_isr3_a7
{
    uint32_t U;
    struct _hw_gpc_isr3_a7_bitfields
    {
        uint32_t ISR3_A7 : 32;         /*!< [31:0]  */
    } B;
} hw_gpc_isr3_a7_t;

/*!
 * @name Constants and macros for entire GPC_ISR3_A7 register
 */
/*@{*/
#define HW_GPC_ISR3_A7_ADDR(x)   ((uintptr_t)(x) + 0x78U)

#define HW_GPC_ISR3_A7(x)        (*(__I hw_gpc_isr3_a7_t *) HW_GPC_ISR3_A7_ADDR(x))
#define HW_GPC_ISR3_A7_RD(x)     (HW_GPC_ISR3_A7(x).U)
/*@}*/

/*
 * Constants & macros for individual GPC_ISR3_A7 bitfields
 */

/*!
 * @name Register GPC_ISR3_A7, field ISR3_A7[31:0] (RO)
 *
 * A7 IRQ[95:64] status
 */
/*@{*/
#define BP_GPC_ISR3_A7_ISR3_A7 (0U)        /*!< Bit position for GPC_ISR3_A7_ISR3_A7. */
#define BM_GPC_ISR3_A7_ISR3_A7 (0xFFFFFFFFU) /*!< Bit mask for GPC_ISR3_A7_ISR3_A7. */
#define BS_GPC_ISR3_A7_ISR3_A7 (32U)       /*!< Bit field size in bits for GPC_ISR3_A7_ISR3_A7. */

/*! @brief Read current value of the GPC_ISR3_A7_ISR3_A7 field. */
#define BR_GPC_ISR3_A7_ISR3_A7(x) (HW_GPC_ISR3_A7(x).U)
/*@}*/

/*******************************************************************************
 * HW_GPC_ISR4_A7 - IRQ status register 4 of A7
 ******************************************************************************/

/*!
 * @brief HW_GPC_ISR4_A7 - IRQ status register 4 of A7 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_isr4_a7
{
    uint32_t U;
    struct _hw_gpc_isr4_a7_bitfields
    {
        uint32_t ISR4_A7 : 32;         /*!< [31:0]  */
    } B;
} hw_gpc_isr4_a7_t;

/*!
 * @name Constants and macros for entire GPC_ISR4_A7 register
 */
/*@{*/
#define HW_GPC_ISR4_A7_ADDR(x)   ((uintptr_t)(x) + 0x7CU)

#define HW_GPC_ISR4_A7(x)        (*(__I hw_gpc_isr4_a7_t *) HW_GPC_ISR4_A7_ADDR(x))
#define HW_GPC_ISR4_A7_RD(x)     (HW_GPC_ISR4_A7(x).U)
/*@}*/

/*
 * Constants & macros for individual GPC_ISR4_A7 bitfields
 */

/*!
 * @name Register GPC_ISR4_A7, field ISR4_A7[31:0] (RO)
 *
 * A7 IRQ[127:96] status
 */
/*@{*/
#define BP_GPC_ISR4_A7_ISR4_A7 (0U)        /*!< Bit position for GPC_ISR4_A7_ISR4_A7. */
#define BM_GPC_ISR4_A7_ISR4_A7 (0xFFFFFFFFU) /*!< Bit mask for GPC_ISR4_A7_ISR4_A7. */
#define BS_GPC_ISR4_A7_ISR4_A7 (32U)       /*!< Bit field size in bits for GPC_ISR4_A7_ISR4_A7. */

/*! @brief Read current value of the GPC_ISR4_A7_ISR4_A7 field. */
#define BR_GPC_ISR4_A7_ISR4_A7(x) (HW_GPC_ISR4_A7(x).U)
/*@}*/

/*******************************************************************************
 * HW_GPC_ISR1_M4 - IRQ status register 1 of M4
 ******************************************************************************/

/*!
 * @brief HW_GPC_ISR1_M4 - IRQ status register 1 of M4 (RO)
 *
 * Reset value: 0x00000000U
 *
 * The four ISRn_M4 (n = 1,2,3,4) registers, all of them are read only register
 */
typedef union _hw_gpc_isr1_m4
{
    uint32_t U;
    struct _hw_gpc_isr1_m4_bitfields
    {
        uint32_t ISR1_M4 : 32;         /*!< [31:0]  */
    } B;
} hw_gpc_isr1_m4_t;

/*!
 * @name Constants and macros for entire GPC_ISR1_M4 register
 */
/*@{*/
#define HW_GPC_ISR1_M4_ADDR(x)   ((uintptr_t)(x) + 0x80U)

#define HW_GPC_ISR1_M4(x)        (*(__I hw_gpc_isr1_m4_t *) HW_GPC_ISR1_M4_ADDR(x))
#define HW_GPC_ISR1_M4_RD(x)     (HW_GPC_ISR1_M4(x).U)
/*@}*/

/*
 * Constants & macros for individual GPC_ISR1_M4 bitfields
 */

/*!
 * @name Register GPC_ISR1_M4, field ISR1_M4[31:0] (RO)
 *
 * M4 IRQ[31:0] status
 */
/*@{*/
#define BP_GPC_ISR1_M4_ISR1_M4 (0U)        /*!< Bit position for GPC_ISR1_M4_ISR1_M4. */
#define BM_GPC_ISR1_M4_ISR1_M4 (0xFFFFFFFFU) /*!< Bit mask for GPC_ISR1_M4_ISR1_M4. */
#define BS_GPC_ISR1_M4_ISR1_M4 (32U)       /*!< Bit field size in bits for GPC_ISR1_M4_ISR1_M4. */

/*! @brief Read current value of the GPC_ISR1_M4_ISR1_M4 field. */
#define BR_GPC_ISR1_M4_ISR1_M4(x) (HW_GPC_ISR1_M4(x).U)
/*@}*/

/*******************************************************************************
 * HW_GPC_ISR2_M4 - IRQ status register 2 of M4
 ******************************************************************************/

/*!
 * @brief HW_GPC_ISR2_M4 - IRQ status register 2 of M4 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_isr2_m4
{
    uint32_t U;
    struct _hw_gpc_isr2_m4_bitfields
    {
        uint32_t ISR2_M4 : 32;         /*!< [31:0]  */
    } B;
} hw_gpc_isr2_m4_t;

/*!
 * @name Constants and macros for entire GPC_ISR2_M4 register
 */
/*@{*/
#define HW_GPC_ISR2_M4_ADDR(x)   ((uintptr_t)(x) + 0x84U)

#define HW_GPC_ISR2_M4(x)        (*(__I hw_gpc_isr2_m4_t *) HW_GPC_ISR2_M4_ADDR(x))
#define HW_GPC_ISR2_M4_RD(x)     (HW_GPC_ISR2_M4(x).U)
/*@}*/

/*
 * Constants & macros for individual GPC_ISR2_M4 bitfields
 */

/*!
 * @name Register GPC_ISR2_M4, field ISR2_M4[31:0] (RO)
 *
 * M4 IRQ[63:32] status
 */
/*@{*/
#define BP_GPC_ISR2_M4_ISR2_M4 (0U)        /*!< Bit position for GPC_ISR2_M4_ISR2_M4. */
#define BM_GPC_ISR2_M4_ISR2_M4 (0xFFFFFFFFU) /*!< Bit mask for GPC_ISR2_M4_ISR2_M4. */
#define BS_GPC_ISR2_M4_ISR2_M4 (32U)       /*!< Bit field size in bits for GPC_ISR2_M4_ISR2_M4. */

/*! @brief Read current value of the GPC_ISR2_M4_ISR2_M4 field. */
#define BR_GPC_ISR2_M4_ISR2_M4(x) (HW_GPC_ISR2_M4(x).U)
/*@}*/

/*******************************************************************************
 * HW_GPC_ISR3_M4 - IRQ status register 3 of M4
 ******************************************************************************/

/*!
 * @brief HW_GPC_ISR3_M4 - IRQ status register 3 of M4 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_isr3_m4
{
    uint32_t U;
    struct _hw_gpc_isr3_m4_bitfields
    {
        uint32_t ISR3_M4 : 32;         /*!< [31:0]  */
    } B;
} hw_gpc_isr3_m4_t;

/*!
 * @name Constants and macros for entire GPC_ISR3_M4 register
 */
/*@{*/
#define HW_GPC_ISR3_M4_ADDR(x)   ((uintptr_t)(x) + 0x88U)

#define HW_GPC_ISR3_M4(x)        (*(__I hw_gpc_isr3_m4_t *) HW_GPC_ISR3_M4_ADDR(x))
#define HW_GPC_ISR3_M4_RD(x)     (HW_GPC_ISR3_M4(x).U)
/*@}*/

/*
 * Constants & macros for individual GPC_ISR3_M4 bitfields
 */

/*!
 * @name Register GPC_ISR3_M4, field ISR3_M4[31:0] (RO)
 *
 * M4 IRQ[95:64] status
 */
/*@{*/
#define BP_GPC_ISR3_M4_ISR3_M4 (0U)        /*!< Bit position for GPC_ISR3_M4_ISR3_M4. */
#define BM_GPC_ISR3_M4_ISR3_M4 (0xFFFFFFFFU) /*!< Bit mask for GPC_ISR3_M4_ISR3_M4. */
#define BS_GPC_ISR3_M4_ISR3_M4 (32U)       /*!< Bit field size in bits for GPC_ISR3_M4_ISR3_M4. */

/*! @brief Read current value of the GPC_ISR3_M4_ISR3_M4 field. */
#define BR_GPC_ISR3_M4_ISR3_M4(x) (HW_GPC_ISR3_M4(x).U)
/*@}*/

/*******************************************************************************
 * HW_GPC_ISR4_M4 - IRQ status register 4 of M4
 ******************************************************************************/

/*!
 * @brief HW_GPC_ISR4_M4 - IRQ status register 4 of M4 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_isr4_m4
{
    uint32_t U;
    struct _hw_gpc_isr4_m4_bitfields
    {
        uint32_t ISR4_M4 : 32;         /*!< [31:0]  */
    } B;
} hw_gpc_isr4_m4_t;

/*!
 * @name Constants and macros for entire GPC_ISR4_M4 register
 */
/*@{*/
#define HW_GPC_ISR4_M4_ADDR(x)   ((uintptr_t)(x) + 0x8CU)

#define HW_GPC_ISR4_M4(x)        (*(__I hw_gpc_isr4_m4_t *) HW_GPC_ISR4_M4_ADDR(x))
#define HW_GPC_ISR4_M4_RD(x)     (HW_GPC_ISR4_M4(x).U)
/*@}*/

/*
 * Constants & macros for individual GPC_ISR4_M4 bitfields
 */

/*!
 * @name Register GPC_ISR4_M4, field ISR4_M4[31:0] (RO)
 *
 * M4 IRQ[127:96] status
 */
/*@{*/
#define BP_GPC_ISR4_M4_ISR4_M4 (0U)        /*!< Bit position for GPC_ISR4_M4_ISR4_M4. */
#define BM_GPC_ISR4_M4_ISR4_M4 (0xFFFFFFFFU) /*!< Bit mask for GPC_ISR4_M4_ISR4_M4. */
#define BS_GPC_ISR4_M4_ISR4_M4 (32U)       /*!< Bit field size in bits for GPC_ISR4_M4_ISR4_M4. */

/*! @brief Read current value of the GPC_ISR4_M4_ISR4_M4 field. */
#define BR_GPC_ISR4_M4_ISR4_M4(x) (HW_GPC_ISR4_M4(x).U)
/*@}*/

/*******************************************************************************
 * HW_GPC_SLTn_CFG - Slot configure register
 ******************************************************************************/

/*!
 * @brief HW_GPC_SLTn_CFG - Slot configure register (RW)
 *
 * Reset value: 0x00000000U
 *
 * There are 10 slots in each SLTn_CFG(n = 0~9) will define the power up or
 * power down behavior of one or more PGC in that each slot. In each "SLTn_cfg", 2
 * bits (slt_cfg[1:0])are reserved for each PGC: 2'b01 (slot controller will power
 * down relevant PGC in corresponding slot if hardware power down request
 * asserted) 2'b10 (slot controller will power up relevant PGC in corresponding slot if
 * hardware power up request asserted) 2'b00 or 2'b11 (not power down or power up
 * behavior in relevant slot) The specific bits assignment for each PGC is shown
 * in the table below. PGCx PGCx-1 .. PGC2 PGC1 PGC0 SLT0_CFG slt_cfg[1:0]
 * slt_cfg[1:0] slt_cfg[1:0] slt_cfg[1:0] slt_cfg[1:0] slt_cfg[1:0] SLT1_CFG
 * slt_cfg[1:0] slt_cfg[1:0] slt_cfg[1:0] slt_cfg[1:0] slt_cfg[1:0] slt_cfg[1:0] :
 * slt_cfg[1:0] slt_cfg[1:0] slt_cfg[1:0] slt_cfg[1:0] slt_cfg[1:0] slt_cfg[1:0]
 * SLTn_CFG slt_cfg[1:0] slt_cfg[1:0] slt_cfg[1:0] slt_cfg[1:0] slt_cfg[1:0] slt_cfg[1:0]
 */
typedef union _hw_gpc_sltn_cfg
{
    uint32_t U;
    struct _hw_gpc_sltn_cfg_bitfields
    {
        uint32_t CORE0_A7_PDN_SLOT_CONTROL : 1; /*!< [0]  */
        uint32_t CORE0_A7_PUP_SLOT_CONTROL : 1; /*!< [1]  */
        uint32_t CORE1_A7_PDN_SLOT_CONTROL : 1; /*!< [2]  */
        uint32_t CORE1_A7_PUP_SLOT_CONTROL : 1; /*!< [3]  */
        uint32_t SCU_PDN_SLOT_CONTROL : 1; /*!< [4]  */
        uint32_t SCU_PUP_SLOT_CONTROL : 1; /*!< [5]  */
        uint32_t FASTMEGA_PDN_SLOT_CONTROL : 1; /*!< [6]  */
        uint32_t FASTMEGA_PUP_SLOT_CONTROL : 1; /*!< [7]  */
        uint32_t MIPI_PHY_PDN_SLOT_CONTROL : 1; /*!< [8]  */
        uint32_t MIPI_PHY_PUP_SLOT_CONTROL : 1; /*!< [9]  */
        uint32_t PCIE_PHY_PDN_SLOT_CONTROL : 1; /*!< [10]  */
        uint32_t PCIE_PHY_PUP_SLOT_CONTROL : 1; /*!< [11]  */
        uint32_t USB_OTG1_PDN_SLOT_CONTROL : 1; /*!< [12]  */
        uint32_t USB_OTG1_PUP_SLOT_CONTROL : 1; /*!< [13]  */
        uint32_t USB_OTG2_PDN_SLOT_CONTROL : 1; /*!< [14]  */
        uint32_t USB_OTG2_PUP_SLOT_CONTROL : 1; /*!< [15]  */
        uint32_t USB_HSIC_PDN_SLOT_CONTROL : 1; /*!< [16]  */
        uint32_t USB_HSIC_PUP_SLOT_CONTROL : 1; /*!< [17]  */
        uint32_t M4_VIRTUAL_PDN_SLOT_CONTROL : 1; /*!< [18]  */
        uint32_t M4_VIRTUAL_PUP_SLOT_CONTROL : 1; /*!< [19]  */
        uint32_t RESERVED0 : 12;       /*!< [31:20]  */
    } B;
} hw_gpc_sltn_cfg_t;

/*!
 * @name Constants and macros for entire GPC_SLTn_CFG register
 */
/*@{*/
#define HW_GPC_SLTn_CFG_COUNT (10U)

#define HW_GPC_SLTn_CFG_ADDR(x, n) ((uintptr_t)(x) + 0xB0U + (0x4U * (n)))

#define HW_GPC_SLTn_CFG(x, n)    (*(__IO hw_gpc_sltn_cfg_t *) HW_GPC_SLTn_CFG_ADDR(x, n))
#define HW_GPC_SLTn_CFG_RD(x, n) (HW_GPC_SLTn_CFG(x, n).U)
#define HW_GPC_SLTn_CFG_WR(x, n, v) (HW_GPC_SLTn_CFG(x, n).U = (v))
#define HW_GPC_SLTn_CFG_SET(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, HW_GPC_SLTn_CFG_RD(x, n) |  (v)))
#define HW_GPC_SLTn_CFG_CLR(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, HW_GPC_SLTn_CFG_RD(x, n) & ~(v)))
#define HW_GPC_SLTn_CFG_TOG(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, HW_GPC_SLTn_CFG_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_SLTn_CFG bitfields
 */

/*!
 * @name Register GPC_SLTn_CFG, field CORE0_A7_PDN_SLOT_CONTROL[0] (RW)
 *
 * CORE0 A7 Power-down slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_CORE0_A7_PDN_SLOT_CONTROL (0U) /*!< Bit position for GPC_SLTn_CFG_CORE0_A7_PDN_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_CORE0_A7_PDN_SLOT_CONTROL (0x00000001U) /*!< Bit mask for GPC_SLTn_CFG_CORE0_A7_PDN_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_CORE0_A7_PDN_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_CORE0_A7_PDN_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_CORE0_A7_PDN_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_CORE0_A7_PDN_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.CORE0_A7_PDN_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_CORE0_A7_PDN_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_CORE0_A7_PDN_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_CORE0_A7_PDN_SLOT_CONTROL) & BM_GPC_SLTn_CFG_CORE0_A7_PDN_SLOT_CONTROL)

/*! @brief Set the CORE0_A7_PDN_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_CORE0_A7_PDN_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_CORE0_A7_PDN_SLOT_CONTROL) | BF_GPC_SLTn_CFG_CORE0_A7_PDN_SLOT_CONTROL(v)))
/*@}*/

/*!
 * @name Register GPC_SLTn_CFG, field CORE0_A7_PUP_SLOT_CONTROL[1] (RW)
 *
 * CORE0 A7 Power-up slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_CORE0_A7_PUP_SLOT_CONTROL (1U) /*!< Bit position for GPC_SLTn_CFG_CORE0_A7_PUP_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_CORE0_A7_PUP_SLOT_CONTROL (0x00000002U) /*!< Bit mask for GPC_SLTn_CFG_CORE0_A7_PUP_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_CORE0_A7_PUP_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_CORE0_A7_PUP_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_CORE0_A7_PUP_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_CORE0_A7_PUP_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.CORE0_A7_PUP_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_CORE0_A7_PUP_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_CORE0_A7_PUP_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_CORE0_A7_PUP_SLOT_CONTROL) & BM_GPC_SLTn_CFG_CORE0_A7_PUP_SLOT_CONTROL)

/*! @brief Set the CORE0_A7_PUP_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_CORE0_A7_PUP_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_CORE0_A7_PUP_SLOT_CONTROL) | BF_GPC_SLTn_CFG_CORE0_A7_PUP_SLOT_CONTROL(v)))
/*@}*/

/*!
 * @name Register GPC_SLTn_CFG, field CORE1_A7_PDN_SLOT_CONTROL[2] (RW)
 *
 * CORE1 A7 Power-down slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_CORE1_A7_PDN_SLOT_CONTROL (2U) /*!< Bit position for GPC_SLTn_CFG_CORE1_A7_PDN_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_CORE1_A7_PDN_SLOT_CONTROL (0x00000004U) /*!< Bit mask for GPC_SLTn_CFG_CORE1_A7_PDN_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_CORE1_A7_PDN_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_CORE1_A7_PDN_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_CORE1_A7_PDN_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_CORE1_A7_PDN_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.CORE1_A7_PDN_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_CORE1_A7_PDN_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_CORE1_A7_PDN_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_CORE1_A7_PDN_SLOT_CONTROL) & BM_GPC_SLTn_CFG_CORE1_A7_PDN_SLOT_CONTROL)

/*! @brief Set the CORE1_A7_PDN_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_CORE1_A7_PDN_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_CORE1_A7_PDN_SLOT_CONTROL) | BF_GPC_SLTn_CFG_CORE1_A7_PDN_SLOT_CONTROL(v)))
/*@}*/

/*!
 * @name Register GPC_SLTn_CFG, field CORE1_A7_PUP_SLOT_CONTROL[3] (RW)
 *
 * CORE1 A7 Power-up slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_CORE1_A7_PUP_SLOT_CONTROL (3U) /*!< Bit position for GPC_SLTn_CFG_CORE1_A7_PUP_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_CORE1_A7_PUP_SLOT_CONTROL (0x00000008U) /*!< Bit mask for GPC_SLTn_CFG_CORE1_A7_PUP_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_CORE1_A7_PUP_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_CORE1_A7_PUP_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_CORE1_A7_PUP_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_CORE1_A7_PUP_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.CORE1_A7_PUP_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_CORE1_A7_PUP_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_CORE1_A7_PUP_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_CORE1_A7_PUP_SLOT_CONTROL) & BM_GPC_SLTn_CFG_CORE1_A7_PUP_SLOT_CONTROL)

/*! @brief Set the CORE1_A7_PUP_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_CORE1_A7_PUP_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_CORE1_A7_PUP_SLOT_CONTROL) | BF_GPC_SLTn_CFG_CORE1_A7_PUP_SLOT_CONTROL(v)))
/*@}*/

/*!
 * @name Register GPC_SLTn_CFG, field SCU_PDN_SLOT_CONTROL[4] (RW)
 *
 * SCU Power-down slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_SCU_PDN_SLOT_CONTROL (4U) /*!< Bit position for GPC_SLTn_CFG_SCU_PDN_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_SCU_PDN_SLOT_CONTROL (0x00000010U) /*!< Bit mask for GPC_SLTn_CFG_SCU_PDN_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_SCU_PDN_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_SCU_PDN_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_SCU_PDN_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_SCU_PDN_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.SCU_PDN_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_SCU_PDN_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_SCU_PDN_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_SCU_PDN_SLOT_CONTROL) & BM_GPC_SLTn_CFG_SCU_PDN_SLOT_CONTROL)

/*! @brief Set the SCU_PDN_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_SCU_PDN_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_SCU_PDN_SLOT_CONTROL) | BF_GPC_SLTn_CFG_SCU_PDN_SLOT_CONTROL(v)))
/*@}*/

/*!
 * @name Register GPC_SLTn_CFG, field SCU_PUP_SLOT_CONTROL[5] (RW)
 *
 * SCU Power-up slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_SCU_PUP_SLOT_CONTROL (5U) /*!< Bit position for GPC_SLTn_CFG_SCU_PUP_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_SCU_PUP_SLOT_CONTROL (0x00000020U) /*!< Bit mask for GPC_SLTn_CFG_SCU_PUP_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_SCU_PUP_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_SCU_PUP_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_SCU_PUP_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_SCU_PUP_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.SCU_PUP_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_SCU_PUP_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_SCU_PUP_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_SCU_PUP_SLOT_CONTROL) & BM_GPC_SLTn_CFG_SCU_PUP_SLOT_CONTROL)

/*! @brief Set the SCU_PUP_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_SCU_PUP_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_SCU_PUP_SLOT_CONTROL) | BF_GPC_SLTn_CFG_SCU_PUP_SLOT_CONTROL(v)))
/*@}*/

/*!
 * @name Register GPC_SLTn_CFG, field FASTMEGA_PDN_SLOT_CONTROL[6] (RW)
 *
 * FASTMEGA Power-down slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_FASTMEGA_PDN_SLOT_CONTROL (6U) /*!< Bit position for GPC_SLTn_CFG_FASTMEGA_PDN_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_FASTMEGA_PDN_SLOT_CONTROL (0x00000040U) /*!< Bit mask for GPC_SLTn_CFG_FASTMEGA_PDN_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_FASTMEGA_PDN_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_FASTMEGA_PDN_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_FASTMEGA_PDN_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_FASTMEGA_PDN_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.FASTMEGA_PDN_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_FASTMEGA_PDN_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_FASTMEGA_PDN_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_FASTMEGA_PDN_SLOT_CONTROL) & BM_GPC_SLTn_CFG_FASTMEGA_PDN_SLOT_CONTROL)

/*! @brief Set the FASTMEGA_PDN_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_FASTMEGA_PDN_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_FASTMEGA_PDN_SLOT_CONTROL) | BF_GPC_SLTn_CFG_FASTMEGA_PDN_SLOT_CONTROL(v)))
/*@}*/

/*!
 * @name Register GPC_SLTn_CFG, field FASTMEGA_PUP_SLOT_CONTROL[7] (RW)
 *
 * FASTMEGA Power-up slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_FASTMEGA_PUP_SLOT_CONTROL (7U) /*!< Bit position for GPC_SLTn_CFG_FASTMEGA_PUP_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_FASTMEGA_PUP_SLOT_CONTROL (0x00000080U) /*!< Bit mask for GPC_SLTn_CFG_FASTMEGA_PUP_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_FASTMEGA_PUP_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_FASTMEGA_PUP_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_FASTMEGA_PUP_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_FASTMEGA_PUP_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.FASTMEGA_PUP_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_FASTMEGA_PUP_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_FASTMEGA_PUP_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_FASTMEGA_PUP_SLOT_CONTROL) & BM_GPC_SLTn_CFG_FASTMEGA_PUP_SLOT_CONTROL)

/*! @brief Set the FASTMEGA_PUP_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_FASTMEGA_PUP_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_FASTMEGA_PUP_SLOT_CONTROL) | BF_GPC_SLTn_CFG_FASTMEGA_PUP_SLOT_CONTROL(v)))
/*@}*/

/*!
 * @name Register GPC_SLTn_CFG, field MIPI_PHY_PDN_SLOT_CONTROL[8] (RW)
 *
 * MIPI_PHY Power-down slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_MIPI_PHY_PDN_SLOT_CONTROL (8U) /*!< Bit position for GPC_SLTn_CFG_MIPI_PHY_PDN_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_MIPI_PHY_PDN_SLOT_CONTROL (0x00000100U) /*!< Bit mask for GPC_SLTn_CFG_MIPI_PHY_PDN_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_MIPI_PHY_PDN_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_MIPI_PHY_PDN_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_MIPI_PHY_PDN_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_MIPI_PHY_PDN_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.MIPI_PHY_PDN_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_MIPI_PHY_PDN_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_MIPI_PHY_PDN_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_MIPI_PHY_PDN_SLOT_CONTROL) & BM_GPC_SLTn_CFG_MIPI_PHY_PDN_SLOT_CONTROL)

/*! @brief Set the MIPI_PHY_PDN_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_MIPI_PHY_PDN_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_MIPI_PHY_PDN_SLOT_CONTROL) | BF_GPC_SLTn_CFG_MIPI_PHY_PDN_SLOT_CONTROL(v)))
/*@}*/

/*!
 * @name Register GPC_SLTn_CFG, field MIPI_PHY_PUP_SLOT_CONTROL[9] (RW)
 *
 * MIPI_PHY Power-up slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_MIPI_PHY_PUP_SLOT_CONTROL (9U) /*!< Bit position for GPC_SLTn_CFG_MIPI_PHY_PUP_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_MIPI_PHY_PUP_SLOT_CONTROL (0x00000200U) /*!< Bit mask for GPC_SLTn_CFG_MIPI_PHY_PUP_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_MIPI_PHY_PUP_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_MIPI_PHY_PUP_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_MIPI_PHY_PUP_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_MIPI_PHY_PUP_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.MIPI_PHY_PUP_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_MIPI_PHY_PUP_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_MIPI_PHY_PUP_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_MIPI_PHY_PUP_SLOT_CONTROL) & BM_GPC_SLTn_CFG_MIPI_PHY_PUP_SLOT_CONTROL)

/*! @brief Set the MIPI_PHY_PUP_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_MIPI_PHY_PUP_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_MIPI_PHY_PUP_SLOT_CONTROL) | BF_GPC_SLTn_CFG_MIPI_PHY_PUP_SLOT_CONTROL(v)))
/*@}*/

/*!
 * @name Register GPC_SLTn_CFG, field PCIE_PHY_PDN_SLOT_CONTROL[10] (RW)
 *
 * PCIE_PHY Power-down slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_PCIE_PHY_PDN_SLOT_CONTROL (10U) /*!< Bit position for GPC_SLTn_CFG_PCIE_PHY_PDN_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_PCIE_PHY_PDN_SLOT_CONTROL (0x00000400U) /*!< Bit mask for GPC_SLTn_CFG_PCIE_PHY_PDN_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_PCIE_PHY_PDN_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_PCIE_PHY_PDN_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_PCIE_PHY_PDN_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_PCIE_PHY_PDN_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.PCIE_PHY_PDN_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_PCIE_PHY_PDN_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_PCIE_PHY_PDN_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_PCIE_PHY_PDN_SLOT_CONTROL) & BM_GPC_SLTn_CFG_PCIE_PHY_PDN_SLOT_CONTROL)

/*! @brief Set the PCIE_PHY_PDN_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_PCIE_PHY_PDN_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_PCIE_PHY_PDN_SLOT_CONTROL) | BF_GPC_SLTn_CFG_PCIE_PHY_PDN_SLOT_CONTROL(v)))
/*@}*/

/*!
 * @name Register GPC_SLTn_CFG, field PCIE_PHY_PUP_SLOT_CONTROL[11] (RW)
 *
 * PCIE_PHY Power-up slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_PCIE_PHY_PUP_SLOT_CONTROL (11U) /*!< Bit position for GPC_SLTn_CFG_PCIE_PHY_PUP_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_PCIE_PHY_PUP_SLOT_CONTROL (0x00000800U) /*!< Bit mask for GPC_SLTn_CFG_PCIE_PHY_PUP_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_PCIE_PHY_PUP_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_PCIE_PHY_PUP_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_PCIE_PHY_PUP_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_PCIE_PHY_PUP_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.PCIE_PHY_PUP_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_PCIE_PHY_PUP_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_PCIE_PHY_PUP_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_PCIE_PHY_PUP_SLOT_CONTROL) & BM_GPC_SLTn_CFG_PCIE_PHY_PUP_SLOT_CONTROL)

/*! @brief Set the PCIE_PHY_PUP_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_PCIE_PHY_PUP_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_PCIE_PHY_PUP_SLOT_CONTROL) | BF_GPC_SLTn_CFG_PCIE_PHY_PUP_SLOT_CONTROL(v)))
/*@}*/

/*!
 * @name Register GPC_SLTn_CFG, field USB_OTG1_PDN_SLOT_CONTROL[12] (RW)
 *
 * USB_OTG1 Power-down slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_USB_OTG1_PDN_SLOT_CONTROL (12U) /*!< Bit position for GPC_SLTn_CFG_USB_OTG1_PDN_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_USB_OTG1_PDN_SLOT_CONTROL (0x00001000U) /*!< Bit mask for GPC_SLTn_CFG_USB_OTG1_PDN_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_USB_OTG1_PDN_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_USB_OTG1_PDN_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_USB_OTG1_PDN_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_USB_OTG1_PDN_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.USB_OTG1_PDN_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_USB_OTG1_PDN_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_USB_OTG1_PDN_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_USB_OTG1_PDN_SLOT_CONTROL) & BM_GPC_SLTn_CFG_USB_OTG1_PDN_SLOT_CONTROL)

/*! @brief Set the USB_OTG1_PDN_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_USB_OTG1_PDN_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_USB_OTG1_PDN_SLOT_CONTROL) | BF_GPC_SLTn_CFG_USB_OTG1_PDN_SLOT_CONTROL(v)))
/*@}*/

/*!
 * @name Register GPC_SLTn_CFG, field USB_OTG1_PUP_SLOT_CONTROL[13] (RW)
 *
 * USB_OTG1 Power-up slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_USB_OTG1_PUP_SLOT_CONTROL (13U) /*!< Bit position for GPC_SLTn_CFG_USB_OTG1_PUP_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_USB_OTG1_PUP_SLOT_CONTROL (0x00002000U) /*!< Bit mask for GPC_SLTn_CFG_USB_OTG1_PUP_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_USB_OTG1_PUP_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_USB_OTG1_PUP_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_USB_OTG1_PUP_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_USB_OTG1_PUP_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.USB_OTG1_PUP_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_USB_OTG1_PUP_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_USB_OTG1_PUP_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_USB_OTG1_PUP_SLOT_CONTROL) & BM_GPC_SLTn_CFG_USB_OTG1_PUP_SLOT_CONTROL)

/*! @brief Set the USB_OTG1_PUP_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_USB_OTG1_PUP_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_USB_OTG1_PUP_SLOT_CONTROL) | BF_GPC_SLTn_CFG_USB_OTG1_PUP_SLOT_CONTROL(v)))
/*@}*/

/*!
 * @name Register GPC_SLTn_CFG, field USB_OTG2_PDN_SLOT_CONTROL[14] (RW)
 *
 * USB_OTG2 Power-down slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_USB_OTG2_PDN_SLOT_CONTROL (14U) /*!< Bit position for GPC_SLTn_CFG_USB_OTG2_PDN_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_USB_OTG2_PDN_SLOT_CONTROL (0x00004000U) /*!< Bit mask for GPC_SLTn_CFG_USB_OTG2_PDN_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_USB_OTG2_PDN_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_USB_OTG2_PDN_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_USB_OTG2_PDN_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_USB_OTG2_PDN_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.USB_OTG2_PDN_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_USB_OTG2_PDN_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_USB_OTG2_PDN_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_USB_OTG2_PDN_SLOT_CONTROL) & BM_GPC_SLTn_CFG_USB_OTG2_PDN_SLOT_CONTROL)

/*! @brief Set the USB_OTG2_PDN_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_USB_OTG2_PDN_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_USB_OTG2_PDN_SLOT_CONTROL) | BF_GPC_SLTn_CFG_USB_OTG2_PDN_SLOT_CONTROL(v)))
/*@}*/

/*!
 * @name Register GPC_SLTn_CFG, field USB_OTG2_PUP_SLOT_CONTROL[15] (RW)
 *
 * USB_OTG2 Power-up slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_USB_OTG2_PUP_SLOT_CONTROL (15U) /*!< Bit position for GPC_SLTn_CFG_USB_OTG2_PUP_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_USB_OTG2_PUP_SLOT_CONTROL (0x00008000U) /*!< Bit mask for GPC_SLTn_CFG_USB_OTG2_PUP_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_USB_OTG2_PUP_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_USB_OTG2_PUP_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_USB_OTG2_PUP_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_USB_OTG2_PUP_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.USB_OTG2_PUP_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_USB_OTG2_PUP_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_USB_OTG2_PUP_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_USB_OTG2_PUP_SLOT_CONTROL) & BM_GPC_SLTn_CFG_USB_OTG2_PUP_SLOT_CONTROL)

/*! @brief Set the USB_OTG2_PUP_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_USB_OTG2_PUP_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_USB_OTG2_PUP_SLOT_CONTROL) | BF_GPC_SLTn_CFG_USB_OTG2_PUP_SLOT_CONTROL(v)))
/*@}*/

/*!
 * @name Register GPC_SLTn_CFG, field USB_HSIC_PDN_SLOT_CONTROL[16] (RW)
 *
 * USB_HSIC Power-down slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_USB_HSIC_PDN_SLOT_CONTROL (16U) /*!< Bit position for GPC_SLTn_CFG_USB_HSIC_PDN_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_USB_HSIC_PDN_SLOT_CONTROL (0x00010000U) /*!< Bit mask for GPC_SLTn_CFG_USB_HSIC_PDN_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_USB_HSIC_PDN_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_USB_HSIC_PDN_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_USB_HSIC_PDN_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_USB_HSIC_PDN_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.USB_HSIC_PDN_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_USB_HSIC_PDN_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_USB_HSIC_PDN_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_USB_HSIC_PDN_SLOT_CONTROL) & BM_GPC_SLTn_CFG_USB_HSIC_PDN_SLOT_CONTROL)

/*! @brief Set the USB_HSIC_PDN_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_USB_HSIC_PDN_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_USB_HSIC_PDN_SLOT_CONTROL) | BF_GPC_SLTn_CFG_USB_HSIC_PDN_SLOT_CONTROL(v)))
/*@}*/

/*!
 * @name Register GPC_SLTn_CFG, field USB_HSIC_PUP_SLOT_CONTROL[17] (RW)
 *
 * USB_HSIC Power-up slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_USB_HSIC_PUP_SLOT_CONTROL (17U) /*!< Bit position for GPC_SLTn_CFG_USB_HSIC_PUP_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_USB_HSIC_PUP_SLOT_CONTROL (0x00020000U) /*!< Bit mask for GPC_SLTn_CFG_USB_HSIC_PUP_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_USB_HSIC_PUP_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_USB_HSIC_PUP_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_USB_HSIC_PUP_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_USB_HSIC_PUP_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.USB_HSIC_PUP_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_USB_HSIC_PUP_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_USB_HSIC_PUP_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_USB_HSIC_PUP_SLOT_CONTROL) & BM_GPC_SLTn_CFG_USB_HSIC_PUP_SLOT_CONTROL)

/*! @brief Set the USB_HSIC_PUP_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_USB_HSIC_PUP_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_USB_HSIC_PUP_SLOT_CONTROL) | BF_GPC_SLTn_CFG_USB_HSIC_PUP_SLOT_CONTROL(v)))
/*@}*/

/*!
 * @name Register GPC_SLTn_CFG, field M4_VIRTUAL_PDN_SLOT_CONTROL[18] (RW)
 *
 * M4_VIRTUAL Power-down slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL (18U) /*!< Bit position for GPC_SLTn_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL (0x00040000U) /*!< Bit mask for GPC_SLTn_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.M4_VIRTUAL_PDN_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL) & BM_GPC_SLTn_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL)

/*! @brief Set the M4_VIRTUAL_PDN_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL) | BF_GPC_SLTn_CFG_M4_VIRTUAL_PDN_SLOT_CONTROL(v)))
/*@}*/

/*!
 * @name Register GPC_SLTn_CFG, field M4_VIRTUAL_PUP_SLOT_CONTROL[19] (RW)
 *
 * M4_VIRTUAL Power-up slot control
 */
/*@{*/
#define BP_GPC_SLTn_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL (19U) /*!< Bit position for GPC_SLTn_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL. */
#define BM_GPC_SLTn_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL (0x00080000U) /*!< Bit mask for GPC_SLTn_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL. */
#define BS_GPC_SLTn_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL (1U) /*!< Bit field size in bits for GPC_SLTn_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL. */

/*! @brief Read current value of the GPC_SLTn_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL field. */
#define BR_GPC_SLTn_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL(x, n) (HW_GPC_SLTn_CFG(x, n).B.M4_VIRTUAL_PUP_SLOT_CONTROL)

/*! @brief Format value for bitfield GPC_SLTn_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL. */
#define BF_GPC_SLTn_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_SLTn_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL) & BM_GPC_SLTn_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL)

/*! @brief Set the M4_VIRTUAL_PUP_SLOT_CONTROL field to a new value. */
#define BW_GPC_SLTn_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL(x, n, v) (HW_GPC_SLTn_CFG_WR(x, n, (HW_GPC_SLTn_CFG_RD(x, n) & ~BM_GPC_SLTn_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL) | BF_GPC_SLTn_CFG_M4_VIRTUAL_PUP_SLOT_CONTROL(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_CPU_MAPPING - PGC CPU mapping
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_CPU_MAPPING - PGC CPU mapping (RW)
 *
 * Reset value: 0x00000000U
 *
 * The byte0 can only be accessed by A7 platform, byte1 can only be accessed by
 * M4 platform.
 */
typedef union _hw_gpc_pgc_cpu_mapping
{
    uint32_t U;
    struct _hw_gpc_pgc_cpu_mapping_bitfields
    {
        uint32_t FASTMEGA_A7_DOMAIN : 1; /*!< [0]  */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t MIPI_PHY_A7_DOMAIN : 1; /*!< [2]  */
        uint32_t PCIE_PHY_A7_DOMAIN : 1; /*!< [3]  */
        uint32_t USB_OTG1_PHY_A7_DOMAIN : 1; /*!< [4]  */
        uint32_t USB_OTG2_PHY_A7_DOMAIN : 1; /*!< [5]  */
        uint32_t USB_HSIC_PHY_A7_DOMAIN : 1; /*!< [6]  */
        uint32_t RESERVED1 : 1;        /*!< [7]  */
        uint32_t FASTMEGA_M4_DOMAIN : 1; /*!< [8]  */
        uint32_t RESERVED2 : 1;        /*!< [9]  */
        uint32_t MIPI_PHY_M4_DOMAIN : 1; /*!< [10]  */
        uint32_t PCIE_PHY_M4_DOMAIN : 1; /*!< [11]  */
        uint32_t USB_OTG1_PHY_M4_DOMAIN : 1; /*!< [12]  */
        uint32_t USB_OTG2_PHY_M4_DOMAIN : 1; /*!< [13]  */
        uint32_t USB_HSIC_PHY_M4_DOMAIN : 1; /*!< [14]  */
        uint32_t RESERVED3 : 17;       /*!< [31:15]  */
    } B;
} hw_gpc_pgc_cpu_mapping_t;

/*!
 * @name Constants and macros for entire GPC_PGC_CPU_MAPPING register
 */
/*@{*/
#define HW_GPC_PGC_CPU_MAPPING_ADDR(x) ((uintptr_t)(x) + 0xECU)

#define HW_GPC_PGC_CPU_MAPPING(x) (*(__IO hw_gpc_pgc_cpu_mapping_t *) HW_GPC_PGC_CPU_MAPPING_ADDR(x))
#define HW_GPC_PGC_CPU_MAPPING_RD(x) (HW_GPC_PGC_CPU_MAPPING(x).U)
#define HW_GPC_PGC_CPU_MAPPING_WR(x, v) (HW_GPC_PGC_CPU_MAPPING(x).U = (v))
#define HW_GPC_PGC_CPU_MAPPING_SET(x, v) (HW_GPC_PGC_CPU_MAPPING_WR(x, HW_GPC_PGC_CPU_MAPPING_RD(x) |  (v)))
#define HW_GPC_PGC_CPU_MAPPING_CLR(x, v) (HW_GPC_PGC_CPU_MAPPING_WR(x, HW_GPC_PGC_CPU_MAPPING_RD(x) & ~(v)))
#define HW_GPC_PGC_CPU_MAPPING_TOG(x, v) (HW_GPC_PGC_CPU_MAPPING_WR(x, HW_GPC_PGC_CPU_MAPPING_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_CPU_MAPPING bitfields
 */

/*!
 * @name Register GPC_PGC_CPU_MAPPING, field FASTMEGA_A7_DOMAIN[0] (RW)
 *
 * FAST/MEGA mapping
 *
 * Values:
 * - 0 - Don't map FAST/MEGA to A7 domain
 * - 1 - Map FAST/MEGA to A7 domain
 */
/*@{*/
#define BP_GPC_PGC_CPU_MAPPING_FASTMEGA_A7_DOMAIN (0U) /*!< Bit position for GPC_PGC_CPU_MAPPING_FASTMEGA_A7_DOMAIN. */
#define BM_GPC_PGC_CPU_MAPPING_FASTMEGA_A7_DOMAIN (0x00000001U) /*!< Bit mask for GPC_PGC_CPU_MAPPING_FASTMEGA_A7_DOMAIN. */
#define BS_GPC_PGC_CPU_MAPPING_FASTMEGA_A7_DOMAIN (1U) /*!< Bit field size in bits for GPC_PGC_CPU_MAPPING_FASTMEGA_A7_DOMAIN. */

/*! @brief Read current value of the GPC_PGC_CPU_MAPPING_FASTMEGA_A7_DOMAIN field. */
#define BR_GPC_PGC_CPU_MAPPING_FASTMEGA_A7_DOMAIN(x) (HW_GPC_PGC_CPU_MAPPING(x).B.FASTMEGA_A7_DOMAIN)

/*! @brief Format value for bitfield GPC_PGC_CPU_MAPPING_FASTMEGA_A7_DOMAIN. */
#define BF_GPC_PGC_CPU_MAPPING_FASTMEGA_A7_DOMAIN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_CPU_MAPPING_FASTMEGA_A7_DOMAIN) & BM_GPC_PGC_CPU_MAPPING_FASTMEGA_A7_DOMAIN)

/*! @brief Set the FASTMEGA_A7_DOMAIN field to a new value. */
#define BW_GPC_PGC_CPU_MAPPING_FASTMEGA_A7_DOMAIN(x, v) (HW_GPC_PGC_CPU_MAPPING_WR(x, (HW_GPC_PGC_CPU_MAPPING_RD(x) & ~BM_GPC_PGC_CPU_MAPPING_FASTMEGA_A7_DOMAIN) | BF_GPC_PGC_CPU_MAPPING_FASTMEGA_A7_DOMAIN(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_CPU_MAPPING, field MIPI_PHY_A7_DOMAIN[2] (RW)
 *
 * MIPI_PHY mapping
 *
 * Values:
 * - 0 - Don't map MIPI_PHY to A7 domain
 * - 1 - Map MIPI_PHY to A7 domain
 */
/*@{*/
#define BP_GPC_PGC_CPU_MAPPING_MIPI_PHY_A7_DOMAIN (2U) /*!< Bit position for GPC_PGC_CPU_MAPPING_MIPI_PHY_A7_DOMAIN. */
#define BM_GPC_PGC_CPU_MAPPING_MIPI_PHY_A7_DOMAIN (0x00000004U) /*!< Bit mask for GPC_PGC_CPU_MAPPING_MIPI_PHY_A7_DOMAIN. */
#define BS_GPC_PGC_CPU_MAPPING_MIPI_PHY_A7_DOMAIN (1U) /*!< Bit field size in bits for GPC_PGC_CPU_MAPPING_MIPI_PHY_A7_DOMAIN. */

/*! @brief Read current value of the GPC_PGC_CPU_MAPPING_MIPI_PHY_A7_DOMAIN field. */
#define BR_GPC_PGC_CPU_MAPPING_MIPI_PHY_A7_DOMAIN(x) (HW_GPC_PGC_CPU_MAPPING(x).B.MIPI_PHY_A7_DOMAIN)

/*! @brief Format value for bitfield GPC_PGC_CPU_MAPPING_MIPI_PHY_A7_DOMAIN. */
#define BF_GPC_PGC_CPU_MAPPING_MIPI_PHY_A7_DOMAIN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_CPU_MAPPING_MIPI_PHY_A7_DOMAIN) & BM_GPC_PGC_CPU_MAPPING_MIPI_PHY_A7_DOMAIN)

/*! @brief Set the MIPI_PHY_A7_DOMAIN field to a new value. */
#define BW_GPC_PGC_CPU_MAPPING_MIPI_PHY_A7_DOMAIN(x, v) (HW_GPC_PGC_CPU_MAPPING_WR(x, (HW_GPC_PGC_CPU_MAPPING_RD(x) & ~BM_GPC_PGC_CPU_MAPPING_MIPI_PHY_A7_DOMAIN) | BF_GPC_PGC_CPU_MAPPING_MIPI_PHY_A7_DOMAIN(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_CPU_MAPPING, field PCIE_PHY_A7_DOMAIN[3] (RW)
 *
 * MIPI_PHY mapping
 *
 * Values:
 * - 0 - Don't map PCIE_PHY to A7 domain
 * - 1 - Map PCIE_PHY to A7 domain
 */
/*@{*/
#define BP_GPC_PGC_CPU_MAPPING_PCIE_PHY_A7_DOMAIN (3U) /*!< Bit position for GPC_PGC_CPU_MAPPING_PCIE_PHY_A7_DOMAIN. */
#define BM_GPC_PGC_CPU_MAPPING_PCIE_PHY_A7_DOMAIN (0x00000008U) /*!< Bit mask for GPC_PGC_CPU_MAPPING_PCIE_PHY_A7_DOMAIN. */
#define BS_GPC_PGC_CPU_MAPPING_PCIE_PHY_A7_DOMAIN (1U) /*!< Bit field size in bits for GPC_PGC_CPU_MAPPING_PCIE_PHY_A7_DOMAIN. */

/*! @brief Read current value of the GPC_PGC_CPU_MAPPING_PCIE_PHY_A7_DOMAIN field. */
#define BR_GPC_PGC_CPU_MAPPING_PCIE_PHY_A7_DOMAIN(x) (HW_GPC_PGC_CPU_MAPPING(x).B.PCIE_PHY_A7_DOMAIN)

/*! @brief Format value for bitfield GPC_PGC_CPU_MAPPING_PCIE_PHY_A7_DOMAIN. */
#define BF_GPC_PGC_CPU_MAPPING_PCIE_PHY_A7_DOMAIN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_CPU_MAPPING_PCIE_PHY_A7_DOMAIN) & BM_GPC_PGC_CPU_MAPPING_PCIE_PHY_A7_DOMAIN)

/*! @brief Set the PCIE_PHY_A7_DOMAIN field to a new value. */
#define BW_GPC_PGC_CPU_MAPPING_PCIE_PHY_A7_DOMAIN(x, v) (HW_GPC_PGC_CPU_MAPPING_WR(x, (HW_GPC_PGC_CPU_MAPPING_RD(x) & ~BM_GPC_PGC_CPU_MAPPING_PCIE_PHY_A7_DOMAIN) | BF_GPC_PGC_CPU_MAPPING_PCIE_PHY_A7_DOMAIN(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_CPU_MAPPING, field USB_OTG1_PHY_A7_DOMAIN[4] (RW)
 *
 * USB_OTG1_PHY mapping
 *
 * Values:
 * - 0 - Don't map USB_OTG1_PHY to A7 domain
 * - 1 - Map USB_OTG1_PHY to A7 domain
 */
/*@{*/
#define BP_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_A7_DOMAIN (4U) /*!< Bit position for GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_A7_DOMAIN. */
#define BM_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_A7_DOMAIN (0x00000010U) /*!< Bit mask for GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_A7_DOMAIN. */
#define BS_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_A7_DOMAIN (1U) /*!< Bit field size in bits for GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_A7_DOMAIN. */

/*! @brief Read current value of the GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_A7_DOMAIN field. */
#define BR_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_A7_DOMAIN(x) (HW_GPC_PGC_CPU_MAPPING(x).B.USB_OTG1_PHY_A7_DOMAIN)

/*! @brief Format value for bitfield GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_A7_DOMAIN. */
#define BF_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_A7_DOMAIN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_A7_DOMAIN) & BM_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_A7_DOMAIN)

/*! @brief Set the USB_OTG1_PHY_A7_DOMAIN field to a new value. */
#define BW_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_A7_DOMAIN(x, v) (HW_GPC_PGC_CPU_MAPPING_WR(x, (HW_GPC_PGC_CPU_MAPPING_RD(x) & ~BM_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_A7_DOMAIN) | BF_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_A7_DOMAIN(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_CPU_MAPPING, field USB_OTG2_PHY_A7_DOMAIN[5] (RW)
 *
 * USB_OTG2_PHY mapping
 *
 * Values:
 * - 0 - Don't map USB_OTG2_PHY to A7 domain
 * - 1 - Map USB_OTG2_PHY to A7 domain
 */
/*@{*/
#define BP_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_A7_DOMAIN (5U) /*!< Bit position for GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_A7_DOMAIN. */
#define BM_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_A7_DOMAIN (0x00000020U) /*!< Bit mask for GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_A7_DOMAIN. */
#define BS_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_A7_DOMAIN (1U) /*!< Bit field size in bits for GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_A7_DOMAIN. */

/*! @brief Read current value of the GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_A7_DOMAIN field. */
#define BR_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_A7_DOMAIN(x) (HW_GPC_PGC_CPU_MAPPING(x).B.USB_OTG2_PHY_A7_DOMAIN)

/*! @brief Format value for bitfield GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_A7_DOMAIN. */
#define BF_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_A7_DOMAIN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_A7_DOMAIN) & BM_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_A7_DOMAIN)

/*! @brief Set the USB_OTG2_PHY_A7_DOMAIN field to a new value. */
#define BW_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_A7_DOMAIN(x, v) (HW_GPC_PGC_CPU_MAPPING_WR(x, (HW_GPC_PGC_CPU_MAPPING_RD(x) & ~BM_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_A7_DOMAIN) | BF_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_A7_DOMAIN(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_CPU_MAPPING, field USB_HSIC_PHY_A7_DOMAIN[6] (RW)
 *
 * USB_HSIC_PHY mapping
 *
 * Values:
 * - 0 - Don't map USB_HSIC_PHY to A7 domain
 * - 1 - Map USB_HSIC_PHY to A7 domain
 */
/*@{*/
#define BP_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_A7_DOMAIN (6U) /*!< Bit position for GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_A7_DOMAIN. */
#define BM_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_A7_DOMAIN (0x00000040U) /*!< Bit mask for GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_A7_DOMAIN. */
#define BS_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_A7_DOMAIN (1U) /*!< Bit field size in bits for GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_A7_DOMAIN. */

/*! @brief Read current value of the GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_A7_DOMAIN field. */
#define BR_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_A7_DOMAIN(x) (HW_GPC_PGC_CPU_MAPPING(x).B.USB_HSIC_PHY_A7_DOMAIN)

/*! @brief Format value for bitfield GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_A7_DOMAIN. */
#define BF_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_A7_DOMAIN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_A7_DOMAIN) & BM_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_A7_DOMAIN)

/*! @brief Set the USB_HSIC_PHY_A7_DOMAIN field to a new value. */
#define BW_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_A7_DOMAIN(x, v) (HW_GPC_PGC_CPU_MAPPING_WR(x, (HW_GPC_PGC_CPU_MAPPING_RD(x) & ~BM_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_A7_DOMAIN) | BF_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_A7_DOMAIN(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_CPU_MAPPING, field FASTMEGA_M4_DOMAIN[8] (RW)
 *
 * FAST/MEGA mapping
 *
 * Values:
 * - 0 - Don't map FAST/MEGA to M4 domain
 * - 1 - Map FAST/MEGA to M4 domain
 */
/*@{*/
#define BP_GPC_PGC_CPU_MAPPING_FASTMEGA_M4_DOMAIN (8U) /*!< Bit position for GPC_PGC_CPU_MAPPING_FASTMEGA_M4_DOMAIN. */
#define BM_GPC_PGC_CPU_MAPPING_FASTMEGA_M4_DOMAIN (0x00000100U) /*!< Bit mask for GPC_PGC_CPU_MAPPING_FASTMEGA_M4_DOMAIN. */
#define BS_GPC_PGC_CPU_MAPPING_FASTMEGA_M4_DOMAIN (1U) /*!< Bit field size in bits for GPC_PGC_CPU_MAPPING_FASTMEGA_M4_DOMAIN. */

/*! @brief Read current value of the GPC_PGC_CPU_MAPPING_FASTMEGA_M4_DOMAIN field. */
#define BR_GPC_PGC_CPU_MAPPING_FASTMEGA_M4_DOMAIN(x) (HW_GPC_PGC_CPU_MAPPING(x).B.FASTMEGA_M4_DOMAIN)

/*! @brief Format value for bitfield GPC_PGC_CPU_MAPPING_FASTMEGA_M4_DOMAIN. */
#define BF_GPC_PGC_CPU_MAPPING_FASTMEGA_M4_DOMAIN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_CPU_MAPPING_FASTMEGA_M4_DOMAIN) & BM_GPC_PGC_CPU_MAPPING_FASTMEGA_M4_DOMAIN)

/*! @brief Set the FASTMEGA_M4_DOMAIN field to a new value. */
#define BW_GPC_PGC_CPU_MAPPING_FASTMEGA_M4_DOMAIN(x, v) (HW_GPC_PGC_CPU_MAPPING_WR(x, (HW_GPC_PGC_CPU_MAPPING_RD(x) & ~BM_GPC_PGC_CPU_MAPPING_FASTMEGA_M4_DOMAIN) | BF_GPC_PGC_CPU_MAPPING_FASTMEGA_M4_DOMAIN(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_CPU_MAPPING, field MIPI_PHY_M4_DOMAIN[10] (RW)
 *
 * MIPI_PHY mapping
 *
 * Values:
 * - 0 - Don't map MIPI_PHY to M4 domain
 * - 1 - Map MIPI_PHY to M4 domain
 */
/*@{*/
#define BP_GPC_PGC_CPU_MAPPING_MIPI_PHY_M4_DOMAIN (10U) /*!< Bit position for GPC_PGC_CPU_MAPPING_MIPI_PHY_M4_DOMAIN. */
#define BM_GPC_PGC_CPU_MAPPING_MIPI_PHY_M4_DOMAIN (0x00000400U) /*!< Bit mask for GPC_PGC_CPU_MAPPING_MIPI_PHY_M4_DOMAIN. */
#define BS_GPC_PGC_CPU_MAPPING_MIPI_PHY_M4_DOMAIN (1U) /*!< Bit field size in bits for GPC_PGC_CPU_MAPPING_MIPI_PHY_M4_DOMAIN. */

/*! @brief Read current value of the GPC_PGC_CPU_MAPPING_MIPI_PHY_M4_DOMAIN field. */
#define BR_GPC_PGC_CPU_MAPPING_MIPI_PHY_M4_DOMAIN(x) (HW_GPC_PGC_CPU_MAPPING(x).B.MIPI_PHY_M4_DOMAIN)

/*! @brief Format value for bitfield GPC_PGC_CPU_MAPPING_MIPI_PHY_M4_DOMAIN. */
#define BF_GPC_PGC_CPU_MAPPING_MIPI_PHY_M4_DOMAIN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_CPU_MAPPING_MIPI_PHY_M4_DOMAIN) & BM_GPC_PGC_CPU_MAPPING_MIPI_PHY_M4_DOMAIN)

/*! @brief Set the MIPI_PHY_M4_DOMAIN field to a new value. */
#define BW_GPC_PGC_CPU_MAPPING_MIPI_PHY_M4_DOMAIN(x, v) (HW_GPC_PGC_CPU_MAPPING_WR(x, (HW_GPC_PGC_CPU_MAPPING_RD(x) & ~BM_GPC_PGC_CPU_MAPPING_MIPI_PHY_M4_DOMAIN) | BF_GPC_PGC_CPU_MAPPING_MIPI_PHY_M4_DOMAIN(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_CPU_MAPPING, field PCIE_PHY_M4_DOMAIN[11] (RW)
 *
 * MIPI_PHY mapping
 *
 * Values:
 * - 0 - Don't map PCIE_PHY to M4 domain
 * - 1 - Map PCIE_PHY to M4 domain
 */
/*@{*/
#define BP_GPC_PGC_CPU_MAPPING_PCIE_PHY_M4_DOMAIN (11U) /*!< Bit position for GPC_PGC_CPU_MAPPING_PCIE_PHY_M4_DOMAIN. */
#define BM_GPC_PGC_CPU_MAPPING_PCIE_PHY_M4_DOMAIN (0x00000800U) /*!< Bit mask for GPC_PGC_CPU_MAPPING_PCIE_PHY_M4_DOMAIN. */
#define BS_GPC_PGC_CPU_MAPPING_PCIE_PHY_M4_DOMAIN (1U) /*!< Bit field size in bits for GPC_PGC_CPU_MAPPING_PCIE_PHY_M4_DOMAIN. */

/*! @brief Read current value of the GPC_PGC_CPU_MAPPING_PCIE_PHY_M4_DOMAIN field. */
#define BR_GPC_PGC_CPU_MAPPING_PCIE_PHY_M4_DOMAIN(x) (HW_GPC_PGC_CPU_MAPPING(x).B.PCIE_PHY_M4_DOMAIN)

/*! @brief Format value for bitfield GPC_PGC_CPU_MAPPING_PCIE_PHY_M4_DOMAIN. */
#define BF_GPC_PGC_CPU_MAPPING_PCIE_PHY_M4_DOMAIN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_CPU_MAPPING_PCIE_PHY_M4_DOMAIN) & BM_GPC_PGC_CPU_MAPPING_PCIE_PHY_M4_DOMAIN)

/*! @brief Set the PCIE_PHY_M4_DOMAIN field to a new value. */
#define BW_GPC_PGC_CPU_MAPPING_PCIE_PHY_M4_DOMAIN(x, v) (HW_GPC_PGC_CPU_MAPPING_WR(x, (HW_GPC_PGC_CPU_MAPPING_RD(x) & ~BM_GPC_PGC_CPU_MAPPING_PCIE_PHY_M4_DOMAIN) | BF_GPC_PGC_CPU_MAPPING_PCIE_PHY_M4_DOMAIN(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_CPU_MAPPING, field USB_OTG1_PHY_M4_DOMAIN[12] (RW)
 *
 * USB_OTG1_PHY mapping
 *
 * Values:
 * - 0 - Don't map USB_OTG1_PHY to M4 domain
 * - 1 - Map USB_OTG1_PHY to M4 domain
 */
/*@{*/
#define BP_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_M4_DOMAIN (12U) /*!< Bit position for GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_M4_DOMAIN. */
#define BM_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_M4_DOMAIN (0x00001000U) /*!< Bit mask for GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_M4_DOMAIN. */
#define BS_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_M4_DOMAIN (1U) /*!< Bit field size in bits for GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_M4_DOMAIN. */

/*! @brief Read current value of the GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_M4_DOMAIN field. */
#define BR_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_M4_DOMAIN(x) (HW_GPC_PGC_CPU_MAPPING(x).B.USB_OTG1_PHY_M4_DOMAIN)

/*! @brief Format value for bitfield GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_M4_DOMAIN. */
#define BF_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_M4_DOMAIN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_M4_DOMAIN) & BM_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_M4_DOMAIN)

/*! @brief Set the USB_OTG1_PHY_M4_DOMAIN field to a new value. */
#define BW_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_M4_DOMAIN(x, v) (HW_GPC_PGC_CPU_MAPPING_WR(x, (HW_GPC_PGC_CPU_MAPPING_RD(x) & ~BM_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_M4_DOMAIN) | BF_GPC_PGC_CPU_MAPPING_USB_OTG1_PHY_M4_DOMAIN(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_CPU_MAPPING, field USB_OTG2_PHY_M4_DOMAIN[13] (RW)
 *
 * USB_OTG2_PHY mapping
 *
 * Values:
 * - 0 - Don't map USB_OTG2_PHY to M4 domain
 * - 1 - Map USB_OTG2_PHY to M4 domain
 */
/*@{*/
#define BP_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_M4_DOMAIN (13U) /*!< Bit position for GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_M4_DOMAIN. */
#define BM_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_M4_DOMAIN (0x00002000U) /*!< Bit mask for GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_M4_DOMAIN. */
#define BS_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_M4_DOMAIN (1U) /*!< Bit field size in bits for GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_M4_DOMAIN. */

/*! @brief Read current value of the GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_M4_DOMAIN field. */
#define BR_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_M4_DOMAIN(x) (HW_GPC_PGC_CPU_MAPPING(x).B.USB_OTG2_PHY_M4_DOMAIN)

/*! @brief Format value for bitfield GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_M4_DOMAIN. */
#define BF_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_M4_DOMAIN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_M4_DOMAIN) & BM_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_M4_DOMAIN)

/*! @brief Set the USB_OTG2_PHY_M4_DOMAIN field to a new value. */
#define BW_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_M4_DOMAIN(x, v) (HW_GPC_PGC_CPU_MAPPING_WR(x, (HW_GPC_PGC_CPU_MAPPING_RD(x) & ~BM_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_M4_DOMAIN) | BF_GPC_PGC_CPU_MAPPING_USB_OTG2_PHY_M4_DOMAIN(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_CPU_MAPPING, field USB_HSIC_PHY_M4_DOMAIN[14] (RW)
 *
 * USB_HSIC_PHY mapping
 *
 * Values:
 * - 0 - Don't map USB_HSIC_PHY to M4 domain
 * - 1 - Map USB_HSIC_PHY to M4 domain
 */
/*@{*/
#define BP_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_M4_DOMAIN (14U) /*!< Bit position for GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_M4_DOMAIN. */
#define BM_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_M4_DOMAIN (0x00004000U) /*!< Bit mask for GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_M4_DOMAIN. */
#define BS_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_M4_DOMAIN (1U) /*!< Bit field size in bits for GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_M4_DOMAIN. */

/*! @brief Read current value of the GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_M4_DOMAIN field. */
#define BR_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_M4_DOMAIN(x) (HW_GPC_PGC_CPU_MAPPING(x).B.USB_HSIC_PHY_M4_DOMAIN)

/*! @brief Format value for bitfield GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_M4_DOMAIN. */
#define BF_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_M4_DOMAIN(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_M4_DOMAIN) & BM_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_M4_DOMAIN)

/*! @brief Set the USB_HSIC_PHY_M4_DOMAIN field to a new value. */
#define BW_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_M4_DOMAIN(x, v) (HW_GPC_PGC_CPU_MAPPING_WR(x, (HW_GPC_PGC_CPU_MAPPING_RD(x) & ~BM_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_M4_DOMAIN) | BF_GPC_PGC_CPU_MAPPING_USB_HSIC_PHY_M4_DOMAIN(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_CPU_PGC_SW_PUP_REQ - CPU PGC software up trigger
 ******************************************************************************/

/*!
 * @brief HW_GPC_CPU_PGC_SW_PUP_REQ - CPU PGC software up trigger (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_cpu_pgc_sw_pup_req
{
    uint32_t U;
    struct _hw_gpc_cpu_pgc_sw_pup_req_bitfields
    {
        uint32_t CORE0_A7_SW_PUP_REQ : 1; /*!< [0]  */
        uint32_t CORE1_A7_SW_PUP_REQ : 1; /*!< [1]  */
        uint32_t SCU_A7_SW_PUP_REQ : 1; /*!< [2]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_gpc_cpu_pgc_sw_pup_req_t;

/*!
 * @name Constants and macros for entire GPC_CPU_PGC_SW_PUP_REQ register
 */
/*@{*/
#define HW_GPC_CPU_PGC_SW_PUP_REQ_ADDR(x) ((uintptr_t)(x) + 0xF0U)

#define HW_GPC_CPU_PGC_SW_PUP_REQ(x) (*(__IO hw_gpc_cpu_pgc_sw_pup_req_t *) HW_GPC_CPU_PGC_SW_PUP_REQ_ADDR(x))
#define HW_GPC_CPU_PGC_SW_PUP_REQ_RD(x) (HW_GPC_CPU_PGC_SW_PUP_REQ(x).U)
#define HW_GPC_CPU_PGC_SW_PUP_REQ_WR(x, v) (HW_GPC_CPU_PGC_SW_PUP_REQ(x).U = (v))
#define HW_GPC_CPU_PGC_SW_PUP_REQ_SET(x, v) (HW_GPC_CPU_PGC_SW_PUP_REQ_WR(x, HW_GPC_CPU_PGC_SW_PUP_REQ_RD(x) |  (v)))
#define HW_GPC_CPU_PGC_SW_PUP_REQ_CLR(x, v) (HW_GPC_CPU_PGC_SW_PUP_REQ_WR(x, HW_GPC_CPU_PGC_SW_PUP_REQ_RD(x) & ~(v)))
#define HW_GPC_CPU_PGC_SW_PUP_REQ_TOG(x, v) (HW_GPC_CPU_PGC_SW_PUP_REQ_WR(x, HW_GPC_CPU_PGC_SW_PUP_REQ_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_CPU_PGC_SW_PUP_REQ bitfields
 */

/*!
 * @name Register GPC_CPU_PGC_SW_PUP_REQ, field CORE0_A7_SW_PUP_REQ[0] (RW)
 *
 * Software power up trigger for Core0 A7 PGC
 */
/*@{*/
#define BP_GPC_CPU_PGC_SW_PUP_REQ_CORE0_A7_SW_PUP_REQ (0U) /*!< Bit position for GPC_CPU_PGC_SW_PUP_REQ_CORE0_A7_SW_PUP_REQ. */
#define BM_GPC_CPU_PGC_SW_PUP_REQ_CORE0_A7_SW_PUP_REQ (0x00000001U) /*!< Bit mask for GPC_CPU_PGC_SW_PUP_REQ_CORE0_A7_SW_PUP_REQ. */
#define BS_GPC_CPU_PGC_SW_PUP_REQ_CORE0_A7_SW_PUP_REQ (1U) /*!< Bit field size in bits for GPC_CPU_PGC_SW_PUP_REQ_CORE0_A7_SW_PUP_REQ. */

/*! @brief Read current value of the GPC_CPU_PGC_SW_PUP_REQ_CORE0_A7_SW_PUP_REQ field. */
#define BR_GPC_CPU_PGC_SW_PUP_REQ_CORE0_A7_SW_PUP_REQ(x) (HW_GPC_CPU_PGC_SW_PUP_REQ(x).B.CORE0_A7_SW_PUP_REQ)

/*! @brief Format value for bitfield GPC_CPU_PGC_SW_PUP_REQ_CORE0_A7_SW_PUP_REQ. */
#define BF_GPC_CPU_PGC_SW_PUP_REQ_CORE0_A7_SW_PUP_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_CPU_PGC_SW_PUP_REQ_CORE0_A7_SW_PUP_REQ) & BM_GPC_CPU_PGC_SW_PUP_REQ_CORE0_A7_SW_PUP_REQ)

/*! @brief Set the CORE0_A7_SW_PUP_REQ field to a new value. */
#define BW_GPC_CPU_PGC_SW_PUP_REQ_CORE0_A7_SW_PUP_REQ(x, v) (HW_GPC_CPU_PGC_SW_PUP_REQ_WR(x, (HW_GPC_CPU_PGC_SW_PUP_REQ_RD(x) & ~BM_GPC_CPU_PGC_SW_PUP_REQ_CORE0_A7_SW_PUP_REQ) | BF_GPC_CPU_PGC_SW_PUP_REQ_CORE0_A7_SW_PUP_REQ(v)))
/*@}*/

/*!
 * @name Register GPC_CPU_PGC_SW_PUP_REQ, field CORE1_A7_SW_PUP_REQ[1] (RW)
 *
 * Software power up trigger for Core1 A7 PGC
 */
/*@{*/
#define BP_GPC_CPU_PGC_SW_PUP_REQ_CORE1_A7_SW_PUP_REQ (1U) /*!< Bit position for GPC_CPU_PGC_SW_PUP_REQ_CORE1_A7_SW_PUP_REQ. */
#define BM_GPC_CPU_PGC_SW_PUP_REQ_CORE1_A7_SW_PUP_REQ (0x00000002U) /*!< Bit mask for GPC_CPU_PGC_SW_PUP_REQ_CORE1_A7_SW_PUP_REQ. */
#define BS_GPC_CPU_PGC_SW_PUP_REQ_CORE1_A7_SW_PUP_REQ (1U) /*!< Bit field size in bits for GPC_CPU_PGC_SW_PUP_REQ_CORE1_A7_SW_PUP_REQ. */

/*! @brief Read current value of the GPC_CPU_PGC_SW_PUP_REQ_CORE1_A7_SW_PUP_REQ field. */
#define BR_GPC_CPU_PGC_SW_PUP_REQ_CORE1_A7_SW_PUP_REQ(x) (HW_GPC_CPU_PGC_SW_PUP_REQ(x).B.CORE1_A7_SW_PUP_REQ)

/*! @brief Format value for bitfield GPC_CPU_PGC_SW_PUP_REQ_CORE1_A7_SW_PUP_REQ. */
#define BF_GPC_CPU_PGC_SW_PUP_REQ_CORE1_A7_SW_PUP_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_CPU_PGC_SW_PUP_REQ_CORE1_A7_SW_PUP_REQ) & BM_GPC_CPU_PGC_SW_PUP_REQ_CORE1_A7_SW_PUP_REQ)

/*! @brief Set the CORE1_A7_SW_PUP_REQ field to a new value. */
#define BW_GPC_CPU_PGC_SW_PUP_REQ_CORE1_A7_SW_PUP_REQ(x, v) (HW_GPC_CPU_PGC_SW_PUP_REQ_WR(x, (HW_GPC_CPU_PGC_SW_PUP_REQ_RD(x) & ~BM_GPC_CPU_PGC_SW_PUP_REQ_CORE1_A7_SW_PUP_REQ) | BF_GPC_CPU_PGC_SW_PUP_REQ_CORE1_A7_SW_PUP_REQ(v)))
/*@}*/

/*!
 * @name Register GPC_CPU_PGC_SW_PUP_REQ, field SCU_A7_SW_PUP_REQ[2] (RW)
 *
 * Software power up trigger for SCU A7
 */
/*@{*/
#define BP_GPC_CPU_PGC_SW_PUP_REQ_SCU_A7_SW_PUP_REQ (2U) /*!< Bit position for GPC_CPU_PGC_SW_PUP_REQ_SCU_A7_SW_PUP_REQ. */
#define BM_GPC_CPU_PGC_SW_PUP_REQ_SCU_A7_SW_PUP_REQ (0x00000004U) /*!< Bit mask for GPC_CPU_PGC_SW_PUP_REQ_SCU_A7_SW_PUP_REQ. */
#define BS_GPC_CPU_PGC_SW_PUP_REQ_SCU_A7_SW_PUP_REQ (1U) /*!< Bit field size in bits for GPC_CPU_PGC_SW_PUP_REQ_SCU_A7_SW_PUP_REQ. */

/*! @brief Read current value of the GPC_CPU_PGC_SW_PUP_REQ_SCU_A7_SW_PUP_REQ field. */
#define BR_GPC_CPU_PGC_SW_PUP_REQ_SCU_A7_SW_PUP_REQ(x) (HW_GPC_CPU_PGC_SW_PUP_REQ(x).B.SCU_A7_SW_PUP_REQ)

/*! @brief Format value for bitfield GPC_CPU_PGC_SW_PUP_REQ_SCU_A7_SW_PUP_REQ. */
#define BF_GPC_CPU_PGC_SW_PUP_REQ_SCU_A7_SW_PUP_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_CPU_PGC_SW_PUP_REQ_SCU_A7_SW_PUP_REQ) & BM_GPC_CPU_PGC_SW_PUP_REQ_SCU_A7_SW_PUP_REQ)

/*! @brief Set the SCU_A7_SW_PUP_REQ field to a new value. */
#define BW_GPC_CPU_PGC_SW_PUP_REQ_SCU_A7_SW_PUP_REQ(x, v) (HW_GPC_CPU_PGC_SW_PUP_REQ_WR(x, (HW_GPC_CPU_PGC_SW_PUP_REQ_RD(x) & ~BM_GPC_CPU_PGC_SW_PUP_REQ_SCU_A7_SW_PUP_REQ) | BF_GPC_CPU_PGC_SW_PUP_REQ_SCU_A7_SW_PUP_REQ(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PU_PGC_SW_PUP_REQ - PU PGC software up trigger
 ******************************************************************************/

/*!
 * @brief HW_GPC_PU_PGC_SW_PUP_REQ - PU PGC software up trigger (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_pu_pgc_sw_pup_req
{
    uint32_t U;
    struct _hw_gpc_pu_pgc_sw_pup_req_bitfields
    {
        uint32_t MIPI_PHY_SW_PUP_REQ : 1; /*!< [0]  */
        uint32_t PCIE_PHY_SW_PUP_REQ : 1; /*!< [1]  */
        uint32_t USB_OTG1_PHY_SW_PUP_REQ : 1; /*!< [2]  */
        uint32_t USB_OTG2_PHY_SW_PUP_REQ : 1; /*!< [3]  */
        uint32_t USB_HSIC_PHY_SW_PUP_REQ : 1; /*!< [4]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_gpc_pu_pgc_sw_pup_req_t;

/*!
 * @name Constants and macros for entire GPC_PU_PGC_SW_PUP_REQ register
 */
/*@{*/
#define HW_GPC_PU_PGC_SW_PUP_REQ_ADDR(x) ((uintptr_t)(x) + 0xF8U)

#define HW_GPC_PU_PGC_SW_PUP_REQ(x) (*(__IO hw_gpc_pu_pgc_sw_pup_req_t *) HW_GPC_PU_PGC_SW_PUP_REQ_ADDR(x))
#define HW_GPC_PU_PGC_SW_PUP_REQ_RD(x) (HW_GPC_PU_PGC_SW_PUP_REQ(x).U)
#define HW_GPC_PU_PGC_SW_PUP_REQ_WR(x, v) (HW_GPC_PU_PGC_SW_PUP_REQ(x).U = (v))
#define HW_GPC_PU_PGC_SW_PUP_REQ_SET(x, v) (HW_GPC_PU_PGC_SW_PUP_REQ_WR(x, HW_GPC_PU_PGC_SW_PUP_REQ_RD(x) |  (v)))
#define HW_GPC_PU_PGC_SW_PUP_REQ_CLR(x, v) (HW_GPC_PU_PGC_SW_PUP_REQ_WR(x, HW_GPC_PU_PGC_SW_PUP_REQ_RD(x) & ~(v)))
#define HW_GPC_PU_PGC_SW_PUP_REQ_TOG(x, v) (HW_GPC_PU_PGC_SW_PUP_REQ_WR(x, HW_GPC_PU_PGC_SW_PUP_REQ_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PU_PGC_SW_PUP_REQ bitfields
 */

/*!
 * @name Register GPC_PU_PGC_SW_PUP_REQ, field MIPI_PHY_SW_PUP_REQ[0] (RW)
 *
 * Software power up trigger for MIPI_PHY
 */
/*@{*/
#define BP_GPC_PU_PGC_SW_PUP_REQ_MIPI_PHY_SW_PUP_REQ (0U) /*!< Bit position for GPC_PU_PGC_SW_PUP_REQ_MIPI_PHY_SW_PUP_REQ. */
#define BM_GPC_PU_PGC_SW_PUP_REQ_MIPI_PHY_SW_PUP_REQ (0x00000001U) /*!< Bit mask for GPC_PU_PGC_SW_PUP_REQ_MIPI_PHY_SW_PUP_REQ. */
#define BS_GPC_PU_PGC_SW_PUP_REQ_MIPI_PHY_SW_PUP_REQ (1U) /*!< Bit field size in bits for GPC_PU_PGC_SW_PUP_REQ_MIPI_PHY_SW_PUP_REQ. */

/*! @brief Read current value of the GPC_PU_PGC_SW_PUP_REQ_MIPI_PHY_SW_PUP_REQ field. */
#define BR_GPC_PU_PGC_SW_PUP_REQ_MIPI_PHY_SW_PUP_REQ(x) (HW_GPC_PU_PGC_SW_PUP_REQ(x).B.MIPI_PHY_SW_PUP_REQ)

/*! @brief Format value for bitfield GPC_PU_PGC_SW_PUP_REQ_MIPI_PHY_SW_PUP_REQ. */
#define BF_GPC_PU_PGC_SW_PUP_REQ_MIPI_PHY_SW_PUP_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PU_PGC_SW_PUP_REQ_MIPI_PHY_SW_PUP_REQ) & BM_GPC_PU_PGC_SW_PUP_REQ_MIPI_PHY_SW_PUP_REQ)

/*! @brief Set the MIPI_PHY_SW_PUP_REQ field to a new value. */
#define BW_GPC_PU_PGC_SW_PUP_REQ_MIPI_PHY_SW_PUP_REQ(x, v) (HW_GPC_PU_PGC_SW_PUP_REQ_WR(x, (HW_GPC_PU_PGC_SW_PUP_REQ_RD(x) & ~BM_GPC_PU_PGC_SW_PUP_REQ_MIPI_PHY_SW_PUP_REQ) | BF_GPC_PU_PGC_SW_PUP_REQ_MIPI_PHY_SW_PUP_REQ(v)))
/*@}*/

/*!
 * @name Register GPC_PU_PGC_SW_PUP_REQ, field PCIE_PHY_SW_PUP_REQ[1] (RW)
 *
 * Software power up trigger for PCIE_PHY
 */
/*@{*/
#define BP_GPC_PU_PGC_SW_PUP_REQ_PCIE_PHY_SW_PUP_REQ (1U) /*!< Bit position for GPC_PU_PGC_SW_PUP_REQ_PCIE_PHY_SW_PUP_REQ. */
#define BM_GPC_PU_PGC_SW_PUP_REQ_PCIE_PHY_SW_PUP_REQ (0x00000002U) /*!< Bit mask for GPC_PU_PGC_SW_PUP_REQ_PCIE_PHY_SW_PUP_REQ. */
#define BS_GPC_PU_PGC_SW_PUP_REQ_PCIE_PHY_SW_PUP_REQ (1U) /*!< Bit field size in bits for GPC_PU_PGC_SW_PUP_REQ_PCIE_PHY_SW_PUP_REQ. */

/*! @brief Read current value of the GPC_PU_PGC_SW_PUP_REQ_PCIE_PHY_SW_PUP_REQ field. */
#define BR_GPC_PU_PGC_SW_PUP_REQ_PCIE_PHY_SW_PUP_REQ(x) (HW_GPC_PU_PGC_SW_PUP_REQ(x).B.PCIE_PHY_SW_PUP_REQ)

/*! @brief Format value for bitfield GPC_PU_PGC_SW_PUP_REQ_PCIE_PHY_SW_PUP_REQ. */
#define BF_GPC_PU_PGC_SW_PUP_REQ_PCIE_PHY_SW_PUP_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PU_PGC_SW_PUP_REQ_PCIE_PHY_SW_PUP_REQ) & BM_GPC_PU_PGC_SW_PUP_REQ_PCIE_PHY_SW_PUP_REQ)

/*! @brief Set the PCIE_PHY_SW_PUP_REQ field to a new value. */
#define BW_GPC_PU_PGC_SW_PUP_REQ_PCIE_PHY_SW_PUP_REQ(x, v) (HW_GPC_PU_PGC_SW_PUP_REQ_WR(x, (HW_GPC_PU_PGC_SW_PUP_REQ_RD(x) & ~BM_GPC_PU_PGC_SW_PUP_REQ_PCIE_PHY_SW_PUP_REQ) | BF_GPC_PU_PGC_SW_PUP_REQ_PCIE_PHY_SW_PUP_REQ(v)))
/*@}*/

/*!
 * @name Register GPC_PU_PGC_SW_PUP_REQ, field USB_OTG1_PHY_SW_PUP_REQ[2] (RW)
 *
 * Software power up trigger for USB_OTG1_PHY
 */
/*@{*/
#define BP_GPC_PU_PGC_SW_PUP_REQ_USB_OTG1_PHY_SW_PUP_REQ (2U) /*!< Bit position for GPC_PU_PGC_SW_PUP_REQ_USB_OTG1_PHY_SW_PUP_REQ. */
#define BM_GPC_PU_PGC_SW_PUP_REQ_USB_OTG1_PHY_SW_PUP_REQ (0x00000004U) /*!< Bit mask for GPC_PU_PGC_SW_PUP_REQ_USB_OTG1_PHY_SW_PUP_REQ. */
#define BS_GPC_PU_PGC_SW_PUP_REQ_USB_OTG1_PHY_SW_PUP_REQ (1U) /*!< Bit field size in bits for GPC_PU_PGC_SW_PUP_REQ_USB_OTG1_PHY_SW_PUP_REQ. */

/*! @brief Read current value of the GPC_PU_PGC_SW_PUP_REQ_USB_OTG1_PHY_SW_PUP_REQ field. */
#define BR_GPC_PU_PGC_SW_PUP_REQ_USB_OTG1_PHY_SW_PUP_REQ(x) (HW_GPC_PU_PGC_SW_PUP_REQ(x).B.USB_OTG1_PHY_SW_PUP_REQ)

/*! @brief Format value for bitfield GPC_PU_PGC_SW_PUP_REQ_USB_OTG1_PHY_SW_PUP_REQ. */
#define BF_GPC_PU_PGC_SW_PUP_REQ_USB_OTG1_PHY_SW_PUP_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PU_PGC_SW_PUP_REQ_USB_OTG1_PHY_SW_PUP_REQ) & BM_GPC_PU_PGC_SW_PUP_REQ_USB_OTG1_PHY_SW_PUP_REQ)

/*! @brief Set the USB_OTG1_PHY_SW_PUP_REQ field to a new value. */
#define BW_GPC_PU_PGC_SW_PUP_REQ_USB_OTG1_PHY_SW_PUP_REQ(x, v) (HW_GPC_PU_PGC_SW_PUP_REQ_WR(x, (HW_GPC_PU_PGC_SW_PUP_REQ_RD(x) & ~BM_GPC_PU_PGC_SW_PUP_REQ_USB_OTG1_PHY_SW_PUP_REQ) | BF_GPC_PU_PGC_SW_PUP_REQ_USB_OTG1_PHY_SW_PUP_REQ(v)))
/*@}*/

/*!
 * @name Register GPC_PU_PGC_SW_PUP_REQ, field USB_OTG2_PHY_SW_PUP_REQ[3] (RW)
 *
 * Software power up trigger for USB_OTG2_PHY
 */
/*@{*/
#define BP_GPC_PU_PGC_SW_PUP_REQ_USB_OTG2_PHY_SW_PUP_REQ (3U) /*!< Bit position for GPC_PU_PGC_SW_PUP_REQ_USB_OTG2_PHY_SW_PUP_REQ. */
#define BM_GPC_PU_PGC_SW_PUP_REQ_USB_OTG2_PHY_SW_PUP_REQ (0x00000008U) /*!< Bit mask for GPC_PU_PGC_SW_PUP_REQ_USB_OTG2_PHY_SW_PUP_REQ. */
#define BS_GPC_PU_PGC_SW_PUP_REQ_USB_OTG2_PHY_SW_PUP_REQ (1U) /*!< Bit field size in bits for GPC_PU_PGC_SW_PUP_REQ_USB_OTG2_PHY_SW_PUP_REQ. */

/*! @brief Read current value of the GPC_PU_PGC_SW_PUP_REQ_USB_OTG2_PHY_SW_PUP_REQ field. */
#define BR_GPC_PU_PGC_SW_PUP_REQ_USB_OTG2_PHY_SW_PUP_REQ(x) (HW_GPC_PU_PGC_SW_PUP_REQ(x).B.USB_OTG2_PHY_SW_PUP_REQ)

/*! @brief Format value for bitfield GPC_PU_PGC_SW_PUP_REQ_USB_OTG2_PHY_SW_PUP_REQ. */
#define BF_GPC_PU_PGC_SW_PUP_REQ_USB_OTG2_PHY_SW_PUP_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PU_PGC_SW_PUP_REQ_USB_OTG2_PHY_SW_PUP_REQ) & BM_GPC_PU_PGC_SW_PUP_REQ_USB_OTG2_PHY_SW_PUP_REQ)

/*! @brief Set the USB_OTG2_PHY_SW_PUP_REQ field to a new value. */
#define BW_GPC_PU_PGC_SW_PUP_REQ_USB_OTG2_PHY_SW_PUP_REQ(x, v) (HW_GPC_PU_PGC_SW_PUP_REQ_WR(x, (HW_GPC_PU_PGC_SW_PUP_REQ_RD(x) & ~BM_GPC_PU_PGC_SW_PUP_REQ_USB_OTG2_PHY_SW_PUP_REQ) | BF_GPC_PU_PGC_SW_PUP_REQ_USB_OTG2_PHY_SW_PUP_REQ(v)))
/*@}*/

/*!
 * @name Register GPC_PU_PGC_SW_PUP_REQ, field USB_HSIC_PHY_SW_PUP_REQ[4] (RW)
 *
 * Software power up trigger for USB_HSIC_PHY
 */
/*@{*/
#define BP_GPC_PU_PGC_SW_PUP_REQ_USB_HSIC_PHY_SW_PUP_REQ (4U) /*!< Bit position for GPC_PU_PGC_SW_PUP_REQ_USB_HSIC_PHY_SW_PUP_REQ. */
#define BM_GPC_PU_PGC_SW_PUP_REQ_USB_HSIC_PHY_SW_PUP_REQ (0x00000010U) /*!< Bit mask for GPC_PU_PGC_SW_PUP_REQ_USB_HSIC_PHY_SW_PUP_REQ. */
#define BS_GPC_PU_PGC_SW_PUP_REQ_USB_HSIC_PHY_SW_PUP_REQ (1U) /*!< Bit field size in bits for GPC_PU_PGC_SW_PUP_REQ_USB_HSIC_PHY_SW_PUP_REQ. */

/*! @brief Read current value of the GPC_PU_PGC_SW_PUP_REQ_USB_HSIC_PHY_SW_PUP_REQ field. */
#define BR_GPC_PU_PGC_SW_PUP_REQ_USB_HSIC_PHY_SW_PUP_REQ(x) (HW_GPC_PU_PGC_SW_PUP_REQ(x).B.USB_HSIC_PHY_SW_PUP_REQ)

/*! @brief Format value for bitfield GPC_PU_PGC_SW_PUP_REQ_USB_HSIC_PHY_SW_PUP_REQ. */
#define BF_GPC_PU_PGC_SW_PUP_REQ_USB_HSIC_PHY_SW_PUP_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PU_PGC_SW_PUP_REQ_USB_HSIC_PHY_SW_PUP_REQ) & BM_GPC_PU_PGC_SW_PUP_REQ_USB_HSIC_PHY_SW_PUP_REQ)

/*! @brief Set the USB_HSIC_PHY_SW_PUP_REQ field to a new value. */
#define BW_GPC_PU_PGC_SW_PUP_REQ_USB_HSIC_PHY_SW_PUP_REQ(x, v) (HW_GPC_PU_PGC_SW_PUP_REQ_WR(x, (HW_GPC_PU_PGC_SW_PUP_REQ_RD(x) & ~BM_GPC_PU_PGC_SW_PUP_REQ_USB_HSIC_PHY_SW_PUP_REQ) | BF_GPC_PU_PGC_SW_PUP_REQ_USB_HSIC_PHY_SW_PUP_REQ(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_CPU_PGC_SW_PDN_REQ - CPU PGC software down trigger
 ******************************************************************************/

/*!
 * @brief HW_GPC_CPU_PGC_SW_PDN_REQ - CPU PGC software down trigger (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_cpu_pgc_sw_pdn_req
{
    uint32_t U;
    struct _hw_gpc_cpu_pgc_sw_pdn_req_bitfields
    {
        uint32_t CORE0_A7_SW_PDN_REQ : 1; /*!< [0]  */
        uint32_t CORE1_A7_SW_PDN_REQ : 1; /*!< [1]  */
        uint32_t SCU_A7_SW_PDN_REQ : 1; /*!< [2]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_gpc_cpu_pgc_sw_pdn_req_t;

/*!
 * @name Constants and macros for entire GPC_CPU_PGC_SW_PDN_REQ register
 */
/*@{*/
#define HW_GPC_CPU_PGC_SW_PDN_REQ_ADDR(x) ((uintptr_t)(x) + 0xFCU)

#define HW_GPC_CPU_PGC_SW_PDN_REQ(x) (*(__IO hw_gpc_cpu_pgc_sw_pdn_req_t *) HW_GPC_CPU_PGC_SW_PDN_REQ_ADDR(x))
#define HW_GPC_CPU_PGC_SW_PDN_REQ_RD(x) (HW_GPC_CPU_PGC_SW_PDN_REQ(x).U)
#define HW_GPC_CPU_PGC_SW_PDN_REQ_WR(x, v) (HW_GPC_CPU_PGC_SW_PDN_REQ(x).U = (v))
#define HW_GPC_CPU_PGC_SW_PDN_REQ_SET(x, v) (HW_GPC_CPU_PGC_SW_PDN_REQ_WR(x, HW_GPC_CPU_PGC_SW_PDN_REQ_RD(x) |  (v)))
#define HW_GPC_CPU_PGC_SW_PDN_REQ_CLR(x, v) (HW_GPC_CPU_PGC_SW_PDN_REQ_WR(x, HW_GPC_CPU_PGC_SW_PDN_REQ_RD(x) & ~(v)))
#define HW_GPC_CPU_PGC_SW_PDN_REQ_TOG(x, v) (HW_GPC_CPU_PGC_SW_PDN_REQ_WR(x, HW_GPC_CPU_PGC_SW_PDN_REQ_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_CPU_PGC_SW_PDN_REQ bitfields
 */

/*!
 * @name Register GPC_CPU_PGC_SW_PDN_REQ, field CORE0_A7_SW_PDN_REQ[0] (RW)
 *
 * Software power down trigger for Core0 A7 PGC
 */
/*@{*/
#define BP_GPC_CPU_PGC_SW_PDN_REQ_CORE0_A7_SW_PDN_REQ (0U) /*!< Bit position for GPC_CPU_PGC_SW_PDN_REQ_CORE0_A7_SW_PDN_REQ. */
#define BM_GPC_CPU_PGC_SW_PDN_REQ_CORE0_A7_SW_PDN_REQ (0x00000001U) /*!< Bit mask for GPC_CPU_PGC_SW_PDN_REQ_CORE0_A7_SW_PDN_REQ. */
#define BS_GPC_CPU_PGC_SW_PDN_REQ_CORE0_A7_SW_PDN_REQ (1U) /*!< Bit field size in bits for GPC_CPU_PGC_SW_PDN_REQ_CORE0_A7_SW_PDN_REQ. */

/*! @brief Read current value of the GPC_CPU_PGC_SW_PDN_REQ_CORE0_A7_SW_PDN_REQ field. */
#define BR_GPC_CPU_PGC_SW_PDN_REQ_CORE0_A7_SW_PDN_REQ(x) (HW_GPC_CPU_PGC_SW_PDN_REQ(x).B.CORE0_A7_SW_PDN_REQ)

/*! @brief Format value for bitfield GPC_CPU_PGC_SW_PDN_REQ_CORE0_A7_SW_PDN_REQ. */
#define BF_GPC_CPU_PGC_SW_PDN_REQ_CORE0_A7_SW_PDN_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_CPU_PGC_SW_PDN_REQ_CORE0_A7_SW_PDN_REQ) & BM_GPC_CPU_PGC_SW_PDN_REQ_CORE0_A7_SW_PDN_REQ)

/*! @brief Set the CORE0_A7_SW_PDN_REQ field to a new value. */
#define BW_GPC_CPU_PGC_SW_PDN_REQ_CORE0_A7_SW_PDN_REQ(x, v) (HW_GPC_CPU_PGC_SW_PDN_REQ_WR(x, (HW_GPC_CPU_PGC_SW_PDN_REQ_RD(x) & ~BM_GPC_CPU_PGC_SW_PDN_REQ_CORE0_A7_SW_PDN_REQ) | BF_GPC_CPU_PGC_SW_PDN_REQ_CORE0_A7_SW_PDN_REQ(v)))
/*@}*/

/*!
 * @name Register GPC_CPU_PGC_SW_PDN_REQ, field CORE1_A7_SW_PDN_REQ[1] (RW)
 *
 * Software power down trigger for Core1 A7 PGC
 */
/*@{*/
#define BP_GPC_CPU_PGC_SW_PDN_REQ_CORE1_A7_SW_PDN_REQ (1U) /*!< Bit position for GPC_CPU_PGC_SW_PDN_REQ_CORE1_A7_SW_PDN_REQ. */
#define BM_GPC_CPU_PGC_SW_PDN_REQ_CORE1_A7_SW_PDN_REQ (0x00000002U) /*!< Bit mask for GPC_CPU_PGC_SW_PDN_REQ_CORE1_A7_SW_PDN_REQ. */
#define BS_GPC_CPU_PGC_SW_PDN_REQ_CORE1_A7_SW_PDN_REQ (1U) /*!< Bit field size in bits for GPC_CPU_PGC_SW_PDN_REQ_CORE1_A7_SW_PDN_REQ. */

/*! @brief Read current value of the GPC_CPU_PGC_SW_PDN_REQ_CORE1_A7_SW_PDN_REQ field. */
#define BR_GPC_CPU_PGC_SW_PDN_REQ_CORE1_A7_SW_PDN_REQ(x) (HW_GPC_CPU_PGC_SW_PDN_REQ(x).B.CORE1_A7_SW_PDN_REQ)

/*! @brief Format value for bitfield GPC_CPU_PGC_SW_PDN_REQ_CORE1_A7_SW_PDN_REQ. */
#define BF_GPC_CPU_PGC_SW_PDN_REQ_CORE1_A7_SW_PDN_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_CPU_PGC_SW_PDN_REQ_CORE1_A7_SW_PDN_REQ) & BM_GPC_CPU_PGC_SW_PDN_REQ_CORE1_A7_SW_PDN_REQ)

/*! @brief Set the CORE1_A7_SW_PDN_REQ field to a new value. */
#define BW_GPC_CPU_PGC_SW_PDN_REQ_CORE1_A7_SW_PDN_REQ(x, v) (HW_GPC_CPU_PGC_SW_PDN_REQ_WR(x, (HW_GPC_CPU_PGC_SW_PDN_REQ_RD(x) & ~BM_GPC_CPU_PGC_SW_PDN_REQ_CORE1_A7_SW_PDN_REQ) | BF_GPC_CPU_PGC_SW_PDN_REQ_CORE1_A7_SW_PDN_REQ(v)))
/*@}*/

/*!
 * @name Register GPC_CPU_PGC_SW_PDN_REQ, field SCU_A7_SW_PDN_REQ[2] (RW)
 *
 * Software power down trigger for SCU A7
 */
/*@{*/
#define BP_GPC_CPU_PGC_SW_PDN_REQ_SCU_A7_SW_PDN_REQ (2U) /*!< Bit position for GPC_CPU_PGC_SW_PDN_REQ_SCU_A7_SW_PDN_REQ. */
#define BM_GPC_CPU_PGC_SW_PDN_REQ_SCU_A7_SW_PDN_REQ (0x00000004U) /*!< Bit mask for GPC_CPU_PGC_SW_PDN_REQ_SCU_A7_SW_PDN_REQ. */
#define BS_GPC_CPU_PGC_SW_PDN_REQ_SCU_A7_SW_PDN_REQ (1U) /*!< Bit field size in bits for GPC_CPU_PGC_SW_PDN_REQ_SCU_A7_SW_PDN_REQ. */

/*! @brief Read current value of the GPC_CPU_PGC_SW_PDN_REQ_SCU_A7_SW_PDN_REQ field. */
#define BR_GPC_CPU_PGC_SW_PDN_REQ_SCU_A7_SW_PDN_REQ(x) (HW_GPC_CPU_PGC_SW_PDN_REQ(x).B.SCU_A7_SW_PDN_REQ)

/*! @brief Format value for bitfield GPC_CPU_PGC_SW_PDN_REQ_SCU_A7_SW_PDN_REQ. */
#define BF_GPC_CPU_PGC_SW_PDN_REQ_SCU_A7_SW_PDN_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_CPU_PGC_SW_PDN_REQ_SCU_A7_SW_PDN_REQ) & BM_GPC_CPU_PGC_SW_PDN_REQ_SCU_A7_SW_PDN_REQ)

/*! @brief Set the SCU_A7_SW_PDN_REQ field to a new value. */
#define BW_GPC_CPU_PGC_SW_PDN_REQ_SCU_A7_SW_PDN_REQ(x, v) (HW_GPC_CPU_PGC_SW_PDN_REQ_WR(x, (HW_GPC_CPU_PGC_SW_PDN_REQ_RD(x) & ~BM_GPC_CPU_PGC_SW_PDN_REQ_SCU_A7_SW_PDN_REQ) | BF_GPC_CPU_PGC_SW_PDN_REQ_SCU_A7_SW_PDN_REQ(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PU_PGC_SW_PDN_REQ - PU PGC software down trigger
 ******************************************************************************/

/*!
 * @brief HW_GPC_PU_PGC_SW_PDN_REQ - PU PGC software down trigger (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_gpc_pu_pgc_sw_pdn_req
{
    uint32_t U;
    struct _hw_gpc_pu_pgc_sw_pdn_req_bitfields
    {
        uint32_t MIPI_PHY_SW_PDN_REQ : 1; /*!< [0]  */
        uint32_t PCIE_PHY_SW_PDN_REQ : 1; /*!< [1]  */
        uint32_t USB_OTG1_PHY_SW_PDN_REQ : 1; /*!< [2]  */
        uint32_t USB_OTG2_PHY_SW_PDN_REQ : 1; /*!< [3]  */
        uint32_t USB_HSIC_PHY_SW_PDN_REQ : 1; /*!< [4]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_gpc_pu_pgc_sw_pdn_req_t;

/*!
 * @name Constants and macros for entire GPC_PU_PGC_SW_PDN_REQ register
 */
/*@{*/
#define HW_GPC_PU_PGC_SW_PDN_REQ_ADDR(x) ((uintptr_t)(x) + 0x104U)

#define HW_GPC_PU_PGC_SW_PDN_REQ(x) (*(__IO hw_gpc_pu_pgc_sw_pdn_req_t *) HW_GPC_PU_PGC_SW_PDN_REQ_ADDR(x))
#define HW_GPC_PU_PGC_SW_PDN_REQ_RD(x) (HW_GPC_PU_PGC_SW_PDN_REQ(x).U)
#define HW_GPC_PU_PGC_SW_PDN_REQ_WR(x, v) (HW_GPC_PU_PGC_SW_PDN_REQ(x).U = (v))
#define HW_GPC_PU_PGC_SW_PDN_REQ_SET(x, v) (HW_GPC_PU_PGC_SW_PDN_REQ_WR(x, HW_GPC_PU_PGC_SW_PDN_REQ_RD(x) |  (v)))
#define HW_GPC_PU_PGC_SW_PDN_REQ_CLR(x, v) (HW_GPC_PU_PGC_SW_PDN_REQ_WR(x, HW_GPC_PU_PGC_SW_PDN_REQ_RD(x) & ~(v)))
#define HW_GPC_PU_PGC_SW_PDN_REQ_TOG(x, v) (HW_GPC_PU_PGC_SW_PDN_REQ_WR(x, HW_GPC_PU_PGC_SW_PDN_REQ_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PU_PGC_SW_PDN_REQ bitfields
 */

/*!
 * @name Register GPC_PU_PGC_SW_PDN_REQ, field MIPI_PHY_SW_PDN_REQ[0] (RW)
 *
 * Software power down trigger for MIPI_PHY
 */
/*@{*/
#define BP_GPC_PU_PGC_SW_PDN_REQ_MIPI_PHY_SW_PDN_REQ (0U) /*!< Bit position for GPC_PU_PGC_SW_PDN_REQ_MIPI_PHY_SW_PDN_REQ. */
#define BM_GPC_PU_PGC_SW_PDN_REQ_MIPI_PHY_SW_PDN_REQ (0x00000001U) /*!< Bit mask for GPC_PU_PGC_SW_PDN_REQ_MIPI_PHY_SW_PDN_REQ. */
#define BS_GPC_PU_PGC_SW_PDN_REQ_MIPI_PHY_SW_PDN_REQ (1U) /*!< Bit field size in bits for GPC_PU_PGC_SW_PDN_REQ_MIPI_PHY_SW_PDN_REQ. */

/*! @brief Read current value of the GPC_PU_PGC_SW_PDN_REQ_MIPI_PHY_SW_PDN_REQ field. */
#define BR_GPC_PU_PGC_SW_PDN_REQ_MIPI_PHY_SW_PDN_REQ(x) (HW_GPC_PU_PGC_SW_PDN_REQ(x).B.MIPI_PHY_SW_PDN_REQ)

/*! @brief Format value for bitfield GPC_PU_PGC_SW_PDN_REQ_MIPI_PHY_SW_PDN_REQ. */
#define BF_GPC_PU_PGC_SW_PDN_REQ_MIPI_PHY_SW_PDN_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PU_PGC_SW_PDN_REQ_MIPI_PHY_SW_PDN_REQ) & BM_GPC_PU_PGC_SW_PDN_REQ_MIPI_PHY_SW_PDN_REQ)

/*! @brief Set the MIPI_PHY_SW_PDN_REQ field to a new value. */
#define BW_GPC_PU_PGC_SW_PDN_REQ_MIPI_PHY_SW_PDN_REQ(x, v) (HW_GPC_PU_PGC_SW_PDN_REQ_WR(x, (HW_GPC_PU_PGC_SW_PDN_REQ_RD(x) & ~BM_GPC_PU_PGC_SW_PDN_REQ_MIPI_PHY_SW_PDN_REQ) | BF_GPC_PU_PGC_SW_PDN_REQ_MIPI_PHY_SW_PDN_REQ(v)))
/*@}*/

/*!
 * @name Register GPC_PU_PGC_SW_PDN_REQ, field PCIE_PHY_SW_PDN_REQ[1] (RW)
 *
 * Software power down trigger for PCIE_PHY
 */
/*@{*/
#define BP_GPC_PU_PGC_SW_PDN_REQ_PCIE_PHY_SW_PDN_REQ (1U) /*!< Bit position for GPC_PU_PGC_SW_PDN_REQ_PCIE_PHY_SW_PDN_REQ. */
#define BM_GPC_PU_PGC_SW_PDN_REQ_PCIE_PHY_SW_PDN_REQ (0x00000002U) /*!< Bit mask for GPC_PU_PGC_SW_PDN_REQ_PCIE_PHY_SW_PDN_REQ. */
#define BS_GPC_PU_PGC_SW_PDN_REQ_PCIE_PHY_SW_PDN_REQ (1U) /*!< Bit field size in bits for GPC_PU_PGC_SW_PDN_REQ_PCIE_PHY_SW_PDN_REQ. */

/*! @brief Read current value of the GPC_PU_PGC_SW_PDN_REQ_PCIE_PHY_SW_PDN_REQ field. */
#define BR_GPC_PU_PGC_SW_PDN_REQ_PCIE_PHY_SW_PDN_REQ(x) (HW_GPC_PU_PGC_SW_PDN_REQ(x).B.PCIE_PHY_SW_PDN_REQ)

/*! @brief Format value for bitfield GPC_PU_PGC_SW_PDN_REQ_PCIE_PHY_SW_PDN_REQ. */
#define BF_GPC_PU_PGC_SW_PDN_REQ_PCIE_PHY_SW_PDN_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PU_PGC_SW_PDN_REQ_PCIE_PHY_SW_PDN_REQ) & BM_GPC_PU_PGC_SW_PDN_REQ_PCIE_PHY_SW_PDN_REQ)

/*! @brief Set the PCIE_PHY_SW_PDN_REQ field to a new value. */
#define BW_GPC_PU_PGC_SW_PDN_REQ_PCIE_PHY_SW_PDN_REQ(x, v) (HW_GPC_PU_PGC_SW_PDN_REQ_WR(x, (HW_GPC_PU_PGC_SW_PDN_REQ_RD(x) & ~BM_GPC_PU_PGC_SW_PDN_REQ_PCIE_PHY_SW_PDN_REQ) | BF_GPC_PU_PGC_SW_PDN_REQ_PCIE_PHY_SW_PDN_REQ(v)))
/*@}*/

/*!
 * @name Register GPC_PU_PGC_SW_PDN_REQ, field USB_OTG1_PHY_SW_PDN_REQ[2] (RW)
 *
 * Software power down trigger for USB_OTG1_PHY
 */
/*@{*/
#define BP_GPC_PU_PGC_SW_PDN_REQ_USB_OTG1_PHY_SW_PDN_REQ (2U) /*!< Bit position for GPC_PU_PGC_SW_PDN_REQ_USB_OTG1_PHY_SW_PDN_REQ. */
#define BM_GPC_PU_PGC_SW_PDN_REQ_USB_OTG1_PHY_SW_PDN_REQ (0x00000004U) /*!< Bit mask for GPC_PU_PGC_SW_PDN_REQ_USB_OTG1_PHY_SW_PDN_REQ. */
#define BS_GPC_PU_PGC_SW_PDN_REQ_USB_OTG1_PHY_SW_PDN_REQ (1U) /*!< Bit field size in bits for GPC_PU_PGC_SW_PDN_REQ_USB_OTG1_PHY_SW_PDN_REQ. */

/*! @brief Read current value of the GPC_PU_PGC_SW_PDN_REQ_USB_OTG1_PHY_SW_PDN_REQ field. */
#define BR_GPC_PU_PGC_SW_PDN_REQ_USB_OTG1_PHY_SW_PDN_REQ(x) (HW_GPC_PU_PGC_SW_PDN_REQ(x).B.USB_OTG1_PHY_SW_PDN_REQ)

/*! @brief Format value for bitfield GPC_PU_PGC_SW_PDN_REQ_USB_OTG1_PHY_SW_PDN_REQ. */
#define BF_GPC_PU_PGC_SW_PDN_REQ_USB_OTG1_PHY_SW_PDN_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PU_PGC_SW_PDN_REQ_USB_OTG1_PHY_SW_PDN_REQ) & BM_GPC_PU_PGC_SW_PDN_REQ_USB_OTG1_PHY_SW_PDN_REQ)

/*! @brief Set the USB_OTG1_PHY_SW_PDN_REQ field to a new value. */
#define BW_GPC_PU_PGC_SW_PDN_REQ_USB_OTG1_PHY_SW_PDN_REQ(x, v) (HW_GPC_PU_PGC_SW_PDN_REQ_WR(x, (HW_GPC_PU_PGC_SW_PDN_REQ_RD(x) & ~BM_GPC_PU_PGC_SW_PDN_REQ_USB_OTG1_PHY_SW_PDN_REQ) | BF_GPC_PU_PGC_SW_PDN_REQ_USB_OTG1_PHY_SW_PDN_REQ(v)))
/*@}*/

/*!
 * @name Register GPC_PU_PGC_SW_PDN_REQ, field USB_OTG2_PHY_SW_PDN_REQ[3] (RW)
 *
 * Software power down trigger for USB_OTG2_PHY
 */
/*@{*/
#define BP_GPC_PU_PGC_SW_PDN_REQ_USB_OTG2_PHY_SW_PDN_REQ (3U) /*!< Bit position for GPC_PU_PGC_SW_PDN_REQ_USB_OTG2_PHY_SW_PDN_REQ. */
#define BM_GPC_PU_PGC_SW_PDN_REQ_USB_OTG2_PHY_SW_PDN_REQ (0x00000008U) /*!< Bit mask for GPC_PU_PGC_SW_PDN_REQ_USB_OTG2_PHY_SW_PDN_REQ. */
#define BS_GPC_PU_PGC_SW_PDN_REQ_USB_OTG2_PHY_SW_PDN_REQ (1U) /*!< Bit field size in bits for GPC_PU_PGC_SW_PDN_REQ_USB_OTG2_PHY_SW_PDN_REQ. */

/*! @brief Read current value of the GPC_PU_PGC_SW_PDN_REQ_USB_OTG2_PHY_SW_PDN_REQ field. */
#define BR_GPC_PU_PGC_SW_PDN_REQ_USB_OTG2_PHY_SW_PDN_REQ(x) (HW_GPC_PU_PGC_SW_PDN_REQ(x).B.USB_OTG2_PHY_SW_PDN_REQ)

/*! @brief Format value for bitfield GPC_PU_PGC_SW_PDN_REQ_USB_OTG2_PHY_SW_PDN_REQ. */
#define BF_GPC_PU_PGC_SW_PDN_REQ_USB_OTG2_PHY_SW_PDN_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PU_PGC_SW_PDN_REQ_USB_OTG2_PHY_SW_PDN_REQ) & BM_GPC_PU_PGC_SW_PDN_REQ_USB_OTG2_PHY_SW_PDN_REQ)

/*! @brief Set the USB_OTG2_PHY_SW_PDN_REQ field to a new value. */
#define BW_GPC_PU_PGC_SW_PDN_REQ_USB_OTG2_PHY_SW_PDN_REQ(x, v) (HW_GPC_PU_PGC_SW_PDN_REQ_WR(x, (HW_GPC_PU_PGC_SW_PDN_REQ_RD(x) & ~BM_GPC_PU_PGC_SW_PDN_REQ_USB_OTG2_PHY_SW_PDN_REQ) | BF_GPC_PU_PGC_SW_PDN_REQ_USB_OTG2_PHY_SW_PDN_REQ(v)))
/*@}*/

/*!
 * @name Register GPC_PU_PGC_SW_PDN_REQ, field USB_HSIC_PHY_SW_PDN_REQ[4] (RW)
 *
 * Software power down trigger for USB_HSIC_PHY
 */
/*@{*/
#define BP_GPC_PU_PGC_SW_PDN_REQ_USB_HSIC_PHY_SW_PDN_REQ (4U) /*!< Bit position for GPC_PU_PGC_SW_PDN_REQ_USB_HSIC_PHY_SW_PDN_REQ. */
#define BM_GPC_PU_PGC_SW_PDN_REQ_USB_HSIC_PHY_SW_PDN_REQ (0x00000010U) /*!< Bit mask for GPC_PU_PGC_SW_PDN_REQ_USB_HSIC_PHY_SW_PDN_REQ. */
#define BS_GPC_PU_PGC_SW_PDN_REQ_USB_HSIC_PHY_SW_PDN_REQ (1U) /*!< Bit field size in bits for GPC_PU_PGC_SW_PDN_REQ_USB_HSIC_PHY_SW_PDN_REQ. */

/*! @brief Read current value of the GPC_PU_PGC_SW_PDN_REQ_USB_HSIC_PHY_SW_PDN_REQ field. */
#define BR_GPC_PU_PGC_SW_PDN_REQ_USB_HSIC_PHY_SW_PDN_REQ(x) (HW_GPC_PU_PGC_SW_PDN_REQ(x).B.USB_HSIC_PHY_SW_PDN_REQ)

/*! @brief Format value for bitfield GPC_PU_PGC_SW_PDN_REQ_USB_HSIC_PHY_SW_PDN_REQ. */
#define BF_GPC_PU_PGC_SW_PDN_REQ_USB_HSIC_PHY_SW_PDN_REQ(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PU_PGC_SW_PDN_REQ_USB_HSIC_PHY_SW_PDN_REQ) & BM_GPC_PU_PGC_SW_PDN_REQ_USB_HSIC_PHY_SW_PDN_REQ)

/*! @brief Set the USB_HSIC_PHY_SW_PDN_REQ field to a new value. */
#define BW_GPC_PU_PGC_SW_PDN_REQ_USB_HSIC_PHY_SW_PDN_REQ(x, v) (HW_GPC_PU_PGC_SW_PDN_REQ_WR(x, (HW_GPC_PU_PGC_SW_PDN_REQ_RD(x) & ~BM_GPC_PU_PGC_SW_PDN_REQ_USB_HSIC_PHY_SW_PDN_REQ) | BF_GPC_PU_PGC_SW_PDN_REQ_USB_HSIC_PHY_SW_PDN_REQ(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_CPU_PGC_PUP_STATUS1 - CPU PGC software up trigger status1
 ******************************************************************************/

/*!
 * @brief HW_GPC_CPU_PGC_PUP_STATUS1 - CPU PGC software up trigger status1 (RO)
 *
 * Reset value: 0x00000000U
 *
 * CPU_PGC_PUP_STATUS1 is a read only register, represents the results for power
 * up software trigger for CPU type PGCs. The field description is show in table
 * below, the value of "1'b1" represent the software power up trigger failed
 * because the relevant PGC is in a power down process. The relevant bit will be
 * cleared after a success operation of power up software trigger for CPU type PGCs.
 */
typedef union _hw_gpc_cpu_pgc_pup_status1
{
    uint32_t U;
    struct _hw_gpc_cpu_pgc_pup_status1_bitfields
    {
        uint32_t CORE0_A7_PUP_STATUS : 1; /*!< [0]  */
        uint32_t CORE1_A7_PUP_STATUS : 1; /*!< [1]  */
        uint32_t SCU_A7_PUP_STATUS : 1; /*!< [2]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_gpc_cpu_pgc_pup_status1_t;

/*!
 * @name Constants and macros for entire GPC_CPU_PGC_PUP_STATUS1 register
 */
/*@{*/
#define HW_GPC_CPU_PGC_PUP_STATUS1_ADDR(x) ((uintptr_t)(x) + 0x130U)

#define HW_GPC_CPU_PGC_PUP_STATUS1(x) (*(__I hw_gpc_cpu_pgc_pup_status1_t *) HW_GPC_CPU_PGC_PUP_STATUS1_ADDR(x))
#define HW_GPC_CPU_PGC_PUP_STATUS1_RD(x) (HW_GPC_CPU_PGC_PUP_STATUS1(x).U)
/*@}*/

/*
 * Constants & macros for individual GPC_CPU_PGC_PUP_STATUS1 bitfields
 */

/*!
 * @name Register GPC_CPU_PGC_PUP_STATUS1, field CORE0_A7_PUP_STATUS[0] (RO)
 */
/*@{*/
#define BP_GPC_CPU_PGC_PUP_STATUS1_CORE0_A7_PUP_STATUS (0U) /*!< Bit position for GPC_CPU_PGC_PUP_STATUS1_CORE0_A7_PUP_STATUS. */
#define BM_GPC_CPU_PGC_PUP_STATUS1_CORE0_A7_PUP_STATUS (0x00000001U) /*!< Bit mask for GPC_CPU_PGC_PUP_STATUS1_CORE0_A7_PUP_STATUS. */
#define BS_GPC_CPU_PGC_PUP_STATUS1_CORE0_A7_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_CPU_PGC_PUP_STATUS1_CORE0_A7_PUP_STATUS. */

/*! @brief Read current value of the GPC_CPU_PGC_PUP_STATUS1_CORE0_A7_PUP_STATUS field. */
#define BR_GPC_CPU_PGC_PUP_STATUS1_CORE0_A7_PUP_STATUS(x) (HW_GPC_CPU_PGC_PUP_STATUS1(x).B.CORE0_A7_PUP_STATUS)
/*@}*/

/*!
 * @name Register GPC_CPU_PGC_PUP_STATUS1, field CORE1_A7_PUP_STATUS[1] (RO)
 */
/*@{*/
#define BP_GPC_CPU_PGC_PUP_STATUS1_CORE1_A7_PUP_STATUS (1U) /*!< Bit position for GPC_CPU_PGC_PUP_STATUS1_CORE1_A7_PUP_STATUS. */
#define BM_GPC_CPU_PGC_PUP_STATUS1_CORE1_A7_PUP_STATUS (0x00000002U) /*!< Bit mask for GPC_CPU_PGC_PUP_STATUS1_CORE1_A7_PUP_STATUS. */
#define BS_GPC_CPU_PGC_PUP_STATUS1_CORE1_A7_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_CPU_PGC_PUP_STATUS1_CORE1_A7_PUP_STATUS. */

/*! @brief Read current value of the GPC_CPU_PGC_PUP_STATUS1_CORE1_A7_PUP_STATUS field. */
#define BR_GPC_CPU_PGC_PUP_STATUS1_CORE1_A7_PUP_STATUS(x) (HW_GPC_CPU_PGC_PUP_STATUS1(x).B.CORE1_A7_PUP_STATUS)
/*@}*/

/*!
 * @name Register GPC_CPU_PGC_PUP_STATUS1, field SCU_A7_PUP_STATUS[2] (RO)
 */
/*@{*/
#define BP_GPC_CPU_PGC_PUP_STATUS1_SCU_A7_PUP_STATUS (2U) /*!< Bit position for GPC_CPU_PGC_PUP_STATUS1_SCU_A7_PUP_STATUS. */
#define BM_GPC_CPU_PGC_PUP_STATUS1_SCU_A7_PUP_STATUS (0x00000004U) /*!< Bit mask for GPC_CPU_PGC_PUP_STATUS1_SCU_A7_PUP_STATUS. */
#define BS_GPC_CPU_PGC_PUP_STATUS1_SCU_A7_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_CPU_PGC_PUP_STATUS1_SCU_A7_PUP_STATUS. */

/*! @brief Read current value of the GPC_CPU_PGC_PUP_STATUS1_SCU_A7_PUP_STATUS field. */
#define BR_GPC_CPU_PGC_PUP_STATUS1_SCU_A7_PUP_STATUS(x) (HW_GPC_CPU_PGC_PUP_STATUS1(x).B.SCU_A7_PUP_STATUS)
/*@}*/

/*******************************************************************************
 * HW_GPC_A7_MIX_PGC_PUP_STATUSn - A7 MIX software up trigger status register
 ******************************************************************************/

/*!
 * @brief HW_GPC_A7_MIX_PGC_PUP_STATUSn - A7 MIX software up trigger status register (RO)
 *
 * Reset value: 0x00000000U
 *
 * A7_MIX_PGC_PUP_STATUSn (n = 0,1,2) are a read only register, represents the
 * results for power up software trigger from A7 platform to MIX type PGCs.
 * A7_MIX_PGC_PUP_STATUS0: value of "1'b1" represent the software power up trigger
 * failed because domain control condition. The relevant bit will be cleared after a
 * success operation of power up software trigger for MIX type PGCs.
 * A7_MIX_PGC_PUP_STATUS1: value of "1'b1" represent the software power up trigger failed
 * because the relevant PGC is in a power up process. The relevant bit will be
 * cleared after a success operation of power up software trigger for MIX type PGCs.
 * A7_MIX_PGC_PUP_STATUS2: value of "1'b1" represent the software power up trigger
 * failed because time slot control is busy. The relevant bit will be cleared
 * after a success operation of power up software trigger for MIX type PGCs.
 */
typedef union _hw_gpc_a7_mix_pgc_pup_statusn
{
    uint32_t U;
    struct _hw_gpc_a7_mix_pgc_pup_statusn_bitfields
    {
        uint32_t A7_MIPI_PHY_PGC_PUP_STATUS : 1; /*!< [0]  */
        uint32_t A7_PCIE_PHY_PGC_PUP_STATUS : 1; /*!< [1]  */
        uint32_t A7_USB_OTG1_PHY_PGC_PUP_STATUS : 1; /*!< [2]  */
        uint32_t A7_USB_OTG2_PHY_PGC_PUP_STATUS : 1; /*!< [3]  */
        uint32_t A7_USB_HSIC_PHY_PGC_PUP_STATUS : 1; /*!< [4]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_gpc_a7_mix_pgc_pup_statusn_t;

/*!
 * @name Constants and macros for entire GPC_A7_MIX_PGC_PUP_STATUSn register
 */
/*@{*/
#define HW_GPC_A7_MIX_PGC_PUP_STATUSn_COUNT (3U)

#define HW_GPC_A7_MIX_PGC_PUP_STATUSn_ADDR(x, n) ((uintptr_t)(x) + 0x134U + (0x4U * (n)))

#define HW_GPC_A7_MIX_PGC_PUP_STATUSn(x, n) (*(__I hw_gpc_a7_mix_pgc_pup_statusn_t *) HW_GPC_A7_MIX_PGC_PUP_STATUSn_ADDR(x, n))
#define HW_GPC_A7_MIX_PGC_PUP_STATUSn_RD(x, n) (HW_GPC_A7_MIX_PGC_PUP_STATUSn(x, n).U)
/*@}*/

/*
 * Constants & macros for individual GPC_A7_MIX_PGC_PUP_STATUSn bitfields
 */

/*!
 * @name Register GPC_A7_MIX_PGC_PUP_STATUSn, field A7_MIPI_PHY_PGC_PUP_STATUS[0] (RO)
 */
/*@{*/
#define BP_GPC_A7_MIX_PGC_PUP_STATUSn_A7_MIPI_PHY_PGC_PUP_STATUS (0U) /*!< Bit position for GPC_A7_MIX_PGC_PUP_STATUSn_A7_MIPI_PHY_PGC_PUP_STATUS. */
#define BM_GPC_A7_MIX_PGC_PUP_STATUSn_A7_MIPI_PHY_PGC_PUP_STATUS (0x00000001U) /*!< Bit mask for GPC_A7_MIX_PGC_PUP_STATUSn_A7_MIPI_PHY_PGC_PUP_STATUS. */
#define BS_GPC_A7_MIX_PGC_PUP_STATUSn_A7_MIPI_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_A7_MIX_PGC_PUP_STATUSn_A7_MIPI_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_A7_MIX_PGC_PUP_STATUSn_A7_MIPI_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_A7_MIX_PGC_PUP_STATUSn_A7_MIPI_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_A7_MIX_PGC_PUP_STATUSn(x, n).B.A7_MIPI_PHY_PGC_PUP_STATUS)
/*@}*/

/*!
 * @name Register GPC_A7_MIX_PGC_PUP_STATUSn, field A7_PCIE_PHY_PGC_PUP_STATUS[1] (RO)
 */
/*@{*/
#define BP_GPC_A7_MIX_PGC_PUP_STATUSn_A7_PCIE_PHY_PGC_PUP_STATUS (1U) /*!< Bit position for GPC_A7_MIX_PGC_PUP_STATUSn_A7_PCIE_PHY_PGC_PUP_STATUS. */
#define BM_GPC_A7_MIX_PGC_PUP_STATUSn_A7_PCIE_PHY_PGC_PUP_STATUS (0x00000002U) /*!< Bit mask for GPC_A7_MIX_PGC_PUP_STATUSn_A7_PCIE_PHY_PGC_PUP_STATUS. */
#define BS_GPC_A7_MIX_PGC_PUP_STATUSn_A7_PCIE_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_A7_MIX_PGC_PUP_STATUSn_A7_PCIE_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_A7_MIX_PGC_PUP_STATUSn_A7_PCIE_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_A7_MIX_PGC_PUP_STATUSn_A7_PCIE_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_A7_MIX_PGC_PUP_STATUSn(x, n).B.A7_PCIE_PHY_PGC_PUP_STATUS)
/*@}*/

/*!
 * @name Register GPC_A7_MIX_PGC_PUP_STATUSn, field A7_USB_OTG1_PHY_PGC_PUP_STATUS[2] (RO)
 */
/*@{*/
#define BP_GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_OTG1_PHY_PGC_PUP_STATUS (2U) /*!< Bit position for GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_OTG1_PHY_PGC_PUP_STATUS. */
#define BM_GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_OTG1_PHY_PGC_PUP_STATUS (0x00000004U) /*!< Bit mask for GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_OTG1_PHY_PGC_PUP_STATUS. */
#define BS_GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_OTG1_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_OTG1_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_OTG1_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_OTG1_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_A7_MIX_PGC_PUP_STATUSn(x, n).B.A7_USB_OTG1_PHY_PGC_PUP_STATUS)
/*@}*/

/*!
 * @name Register GPC_A7_MIX_PGC_PUP_STATUSn, field A7_USB_OTG2_PHY_PGC_PUP_STATUS[3] (RO)
 */
/*@{*/
#define BP_GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_OTG2_PHY_PGC_PUP_STATUS (3U) /*!< Bit position for GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_OTG2_PHY_PGC_PUP_STATUS. */
#define BM_GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_OTG2_PHY_PGC_PUP_STATUS (0x00000008U) /*!< Bit mask for GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_OTG2_PHY_PGC_PUP_STATUS. */
#define BS_GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_OTG2_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_OTG2_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_OTG2_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_OTG2_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_A7_MIX_PGC_PUP_STATUSn(x, n).B.A7_USB_OTG2_PHY_PGC_PUP_STATUS)
/*@}*/

/*!
 * @name Register GPC_A7_MIX_PGC_PUP_STATUSn, field A7_USB_HSIC_PHY_PGC_PUP_STATUS[4] (RO)
 */
/*@{*/
#define BP_GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_HSIC_PHY_PGC_PUP_STATUS (4U) /*!< Bit position for GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_HSIC_PHY_PGC_PUP_STATUS. */
#define BM_GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_HSIC_PHY_PGC_PUP_STATUS (0x00000010U) /*!< Bit mask for GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_HSIC_PHY_PGC_PUP_STATUS. */
#define BS_GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_HSIC_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_HSIC_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_HSIC_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_A7_MIX_PGC_PUP_STATUSn_A7_USB_HSIC_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_A7_MIX_PGC_PUP_STATUSn(x, n).B.A7_USB_HSIC_PHY_PGC_PUP_STATUS)
/*@}*/

/*******************************************************************************
 * HW_GPC_M4_MIX_PGC_PUP_STATUSn - M4 MIX PGC software up trigger status register
 ******************************************************************************/

/*!
 * @brief HW_GPC_M4_MIX_PGC_PUP_STATUSn - M4 MIX PGC software up trigger status register (RO)
 *
 * Reset value: 0x00000000U
 *
 * M4_MIX_PGC_PUP_STATUSn (n = 0,1,2) are a read only register, represents the
 * results for power up software trigger from M4 platform to MIX type PGCs.
 * M4_MIX_PGC_PUP_STATUS0: value of "1'b1" represent the software power up trigger
 * failed because domain control condition. The relevant bit will be cleared after a
 * success operation of power up software trigger for MIX type PGCs.
 * M4_MIX_PGC_PUP_STATUS1: value of "1'b1" represent the software power up trigger failed
 * because the relevant PGC is in a power up process. The relevant bit will be
 * cleared after a success operation of power up software trigger for MIX type PGCs.
 * M4_MIX_PGC_PUP_STATUS2: value of "1'b1" represent the software power up trigger
 * failed because time slot control is busy. The relevant bit will be cleared
 * after a success operation of power up software trigger for MIX type PGCs.
 */
typedef union _hw_gpc_m4_mix_pgc_pup_statusn
{
    uint32_t U;
    struct _hw_gpc_m4_mix_pgc_pup_statusn_bitfields
    {
        uint32_t M4_MIPI_PHY_PGC_PUP_STATUS : 1; /*!< [0]  */
        uint32_t M4_PCIE_PHY_PGC_PUP_STATUS : 1; /*!< [1]  */
        uint32_t M4_USB_OTG1_PHY_PGC_PUP_STATUS : 1; /*!< [2]  */
        uint32_t M4_USB_OTG2_PHY_PGC_PUP_STATUS : 1; /*!< [3]  */
        uint32_t M4_USB_HSIC_PHY_PGC_PUP_STATUS : 1; /*!< [4]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_gpc_m4_mix_pgc_pup_statusn_t;

/*!
 * @name Constants and macros for entire GPC_M4_MIX_PGC_PUP_STATUSn register
 */
/*@{*/
#define HW_GPC_M4_MIX_PGC_PUP_STATUSn_COUNT (3U)

#define HW_GPC_M4_MIX_PGC_PUP_STATUSn_ADDR(x, n) ((uintptr_t)(x) + 0x140U + (0x4U * (n)))

#define HW_GPC_M4_MIX_PGC_PUP_STATUSn(x, n) (*(__I hw_gpc_m4_mix_pgc_pup_statusn_t *) HW_GPC_M4_MIX_PGC_PUP_STATUSn_ADDR(x, n))
#define HW_GPC_M4_MIX_PGC_PUP_STATUSn_RD(x, n) (HW_GPC_M4_MIX_PGC_PUP_STATUSn(x, n).U)
/*@}*/

/*
 * Constants & macros for individual GPC_M4_MIX_PGC_PUP_STATUSn bitfields
 */

/*!
 * @name Register GPC_M4_MIX_PGC_PUP_STATUSn, field M4_MIPI_PHY_PGC_PUP_STATUS[0] (RO)
 */
/*@{*/
#define BP_GPC_M4_MIX_PGC_PUP_STATUSn_M4_MIPI_PHY_PGC_PUP_STATUS (0U) /*!< Bit position for GPC_M4_MIX_PGC_PUP_STATUSn_M4_MIPI_PHY_PGC_PUP_STATUS. */
#define BM_GPC_M4_MIX_PGC_PUP_STATUSn_M4_MIPI_PHY_PGC_PUP_STATUS (0x00000001U) /*!< Bit mask for GPC_M4_MIX_PGC_PUP_STATUSn_M4_MIPI_PHY_PGC_PUP_STATUS. */
#define BS_GPC_M4_MIX_PGC_PUP_STATUSn_M4_MIPI_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_M4_MIX_PGC_PUP_STATUSn_M4_MIPI_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_M4_MIX_PGC_PUP_STATUSn_M4_MIPI_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_M4_MIX_PGC_PUP_STATUSn_M4_MIPI_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_M4_MIX_PGC_PUP_STATUSn(x, n).B.M4_MIPI_PHY_PGC_PUP_STATUS)
/*@}*/

/*!
 * @name Register GPC_M4_MIX_PGC_PUP_STATUSn, field M4_PCIE_PHY_PGC_PUP_STATUS[1] (RO)
 */
/*@{*/
#define BP_GPC_M4_MIX_PGC_PUP_STATUSn_M4_PCIE_PHY_PGC_PUP_STATUS (1U) /*!< Bit position for GPC_M4_MIX_PGC_PUP_STATUSn_M4_PCIE_PHY_PGC_PUP_STATUS. */
#define BM_GPC_M4_MIX_PGC_PUP_STATUSn_M4_PCIE_PHY_PGC_PUP_STATUS (0x00000002U) /*!< Bit mask for GPC_M4_MIX_PGC_PUP_STATUSn_M4_PCIE_PHY_PGC_PUP_STATUS. */
#define BS_GPC_M4_MIX_PGC_PUP_STATUSn_M4_PCIE_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_M4_MIX_PGC_PUP_STATUSn_M4_PCIE_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_M4_MIX_PGC_PUP_STATUSn_M4_PCIE_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_M4_MIX_PGC_PUP_STATUSn_M4_PCIE_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_M4_MIX_PGC_PUP_STATUSn(x, n).B.M4_PCIE_PHY_PGC_PUP_STATUS)
/*@}*/

/*!
 * @name Register GPC_M4_MIX_PGC_PUP_STATUSn, field M4_USB_OTG1_PHY_PGC_PUP_STATUS[2] (RO)
 */
/*@{*/
#define BP_GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_OTG1_PHY_PGC_PUP_STATUS (2U) /*!< Bit position for GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_OTG1_PHY_PGC_PUP_STATUS. */
#define BM_GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_OTG1_PHY_PGC_PUP_STATUS (0x00000004U) /*!< Bit mask for GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_OTG1_PHY_PGC_PUP_STATUS. */
#define BS_GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_OTG1_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_OTG1_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_OTG1_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_OTG1_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_M4_MIX_PGC_PUP_STATUSn(x, n).B.M4_USB_OTG1_PHY_PGC_PUP_STATUS)
/*@}*/

/*!
 * @name Register GPC_M4_MIX_PGC_PUP_STATUSn, field M4_USB_OTG2_PHY_PGC_PUP_STATUS[3] (RO)
 */
/*@{*/
#define BP_GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_OTG2_PHY_PGC_PUP_STATUS (3U) /*!< Bit position for GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_OTG2_PHY_PGC_PUP_STATUS. */
#define BM_GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_OTG2_PHY_PGC_PUP_STATUS (0x00000008U) /*!< Bit mask for GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_OTG2_PHY_PGC_PUP_STATUS. */
#define BS_GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_OTG2_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_OTG2_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_OTG2_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_OTG2_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_M4_MIX_PGC_PUP_STATUSn(x, n).B.M4_USB_OTG2_PHY_PGC_PUP_STATUS)
/*@}*/

/*!
 * @name Register GPC_M4_MIX_PGC_PUP_STATUSn, field M4_USB_HSIC_PHY_PGC_PUP_STATUS[4] (RO)
 */
/*@{*/
#define BP_GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_HSIC_PHY_PGC_PUP_STATUS (4U) /*!< Bit position for GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_HSIC_PHY_PGC_PUP_STATUS. */
#define BM_GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_HSIC_PHY_PGC_PUP_STATUS (0x00000010U) /*!< Bit mask for GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_HSIC_PHY_PGC_PUP_STATUS. */
#define BS_GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_HSIC_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_HSIC_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_HSIC_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_M4_MIX_PGC_PUP_STATUSn_M4_USB_HSIC_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_M4_MIX_PGC_PUP_STATUSn(x, n).B.M4_USB_HSIC_PHY_PGC_PUP_STATUS)
/*@}*/

/*******************************************************************************
 * HW_GPC_A7_PU_PGC_PUP_STATUSn - A7 PU software up trigger status register
 ******************************************************************************/

/*!
 * @brief HW_GPC_A7_PU_PGC_PUP_STATUSn - A7 PU software up trigger status register (RO)
 *
 * Reset value: 0x00000000U
 *
 * A7_PU_PGC_PUP_STATUSn (n = 0,1,2) are a read only register, represents the
 * results for power up software trigger from A7 platform to PU type PGCs.
 * A7_PU_PGC_PUP_STATUS0: value of "1'b1" represent the software power up trigger failed
 * because domain control condition. The relevant bit will be cleared after a
 * success operation of power up software trigger for PU type PGCs.
 * A7_PU_PGC_PUP_STATUS1: value of "1'b1" represent the software power up trigger failed because
 * the relevant PGC is in a power up process. The relevant bit will be cleared
 * after a success operation of power up software trigger for PU type PGCs.
 * A7_PU_PGC_PUP_STATUS2: value of "1'b1" represent the software power up trigger failed
 * because time slot control is busy. The relevant bit will be cleared after a
 * success operation of power up software trigger for PU type PGCs.
 */
typedef union _hw_gpc_a7_pu_pgc_pup_statusn
{
    uint32_t U;
    struct _hw_gpc_a7_pu_pgc_pup_statusn_bitfields
    {
        uint32_t A7_MIPI_PHY_PGC_PUP_STATUS : 1; /*!< [0]  */
        uint32_t A7_PCIE_PHY_PGC_PUP_STATUS : 1; /*!< [1]  */
        uint32_t A7_USB_OTG1_PHY_PGC_PUP_STATUS : 1; /*!< [2]  */
        uint32_t A7_USB_OTG2_PHY_PGC_PUP_STATUS : 1; /*!< [3]  */
        uint32_t A7_USB_HSIC_PHY_PGC_PUP_STATUS : 1; /*!< [4]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_gpc_a7_pu_pgc_pup_statusn_t;

/*!
 * @name Constants and macros for entire GPC_A7_PU_PGC_PUP_STATUSn register
 */
/*@{*/
#define HW_GPC_A7_PU_PGC_PUP_STATUSn_COUNT (3U)

#define HW_GPC_A7_PU_PGC_PUP_STATUSn_ADDR(x, n) ((uintptr_t)(x) + 0x14CU + (0x4U * (n)))

#define HW_GPC_A7_PU_PGC_PUP_STATUSn(x, n) (*(__I hw_gpc_a7_pu_pgc_pup_statusn_t *) HW_GPC_A7_PU_PGC_PUP_STATUSn_ADDR(x, n))
#define HW_GPC_A7_PU_PGC_PUP_STATUSn_RD(x, n) (HW_GPC_A7_PU_PGC_PUP_STATUSn(x, n).U)
/*@}*/

/*
 * Constants & macros for individual GPC_A7_PU_PGC_PUP_STATUSn bitfields
 */

/*!
 * @name Register GPC_A7_PU_PGC_PUP_STATUSn, field A7_MIPI_PHY_PGC_PUP_STATUS[0] (RO)
 */
/*@{*/
#define BP_GPC_A7_PU_PGC_PUP_STATUSn_A7_MIPI_PHY_PGC_PUP_STATUS (0U) /*!< Bit position for GPC_A7_PU_PGC_PUP_STATUSn_A7_MIPI_PHY_PGC_PUP_STATUS. */
#define BM_GPC_A7_PU_PGC_PUP_STATUSn_A7_MIPI_PHY_PGC_PUP_STATUS (0x00000001U) /*!< Bit mask for GPC_A7_PU_PGC_PUP_STATUSn_A7_MIPI_PHY_PGC_PUP_STATUS. */
#define BS_GPC_A7_PU_PGC_PUP_STATUSn_A7_MIPI_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_A7_PU_PGC_PUP_STATUSn_A7_MIPI_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_A7_PU_PGC_PUP_STATUSn_A7_MIPI_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_A7_PU_PGC_PUP_STATUSn_A7_MIPI_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_A7_PU_PGC_PUP_STATUSn(x, n).B.A7_MIPI_PHY_PGC_PUP_STATUS)
/*@}*/

/*!
 * @name Register GPC_A7_PU_PGC_PUP_STATUSn, field A7_PCIE_PHY_PGC_PUP_STATUS[1] (RO)
 */
/*@{*/
#define BP_GPC_A7_PU_PGC_PUP_STATUSn_A7_PCIE_PHY_PGC_PUP_STATUS (1U) /*!< Bit position for GPC_A7_PU_PGC_PUP_STATUSn_A7_PCIE_PHY_PGC_PUP_STATUS. */
#define BM_GPC_A7_PU_PGC_PUP_STATUSn_A7_PCIE_PHY_PGC_PUP_STATUS (0x00000002U) /*!< Bit mask for GPC_A7_PU_PGC_PUP_STATUSn_A7_PCIE_PHY_PGC_PUP_STATUS. */
#define BS_GPC_A7_PU_PGC_PUP_STATUSn_A7_PCIE_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_A7_PU_PGC_PUP_STATUSn_A7_PCIE_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_A7_PU_PGC_PUP_STATUSn_A7_PCIE_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_A7_PU_PGC_PUP_STATUSn_A7_PCIE_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_A7_PU_PGC_PUP_STATUSn(x, n).B.A7_PCIE_PHY_PGC_PUP_STATUS)
/*@}*/

/*!
 * @name Register GPC_A7_PU_PGC_PUP_STATUSn, field A7_USB_OTG1_PHY_PGC_PUP_STATUS[2] (RO)
 */
/*@{*/
#define BP_GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_OTG1_PHY_PGC_PUP_STATUS (2U) /*!< Bit position for GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_OTG1_PHY_PGC_PUP_STATUS. */
#define BM_GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_OTG1_PHY_PGC_PUP_STATUS (0x00000004U) /*!< Bit mask for GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_OTG1_PHY_PGC_PUP_STATUS. */
#define BS_GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_OTG1_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_OTG1_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_OTG1_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_OTG1_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_A7_PU_PGC_PUP_STATUSn(x, n).B.A7_USB_OTG1_PHY_PGC_PUP_STATUS)
/*@}*/

/*!
 * @name Register GPC_A7_PU_PGC_PUP_STATUSn, field A7_USB_OTG2_PHY_PGC_PUP_STATUS[3] (RO)
 */
/*@{*/
#define BP_GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_OTG2_PHY_PGC_PUP_STATUS (3U) /*!< Bit position for GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_OTG2_PHY_PGC_PUP_STATUS. */
#define BM_GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_OTG2_PHY_PGC_PUP_STATUS (0x00000008U) /*!< Bit mask for GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_OTG2_PHY_PGC_PUP_STATUS. */
#define BS_GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_OTG2_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_OTG2_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_OTG2_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_OTG2_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_A7_PU_PGC_PUP_STATUSn(x, n).B.A7_USB_OTG2_PHY_PGC_PUP_STATUS)
/*@}*/

/*!
 * @name Register GPC_A7_PU_PGC_PUP_STATUSn, field A7_USB_HSIC_PHY_PGC_PUP_STATUS[4] (RO)
 */
/*@{*/
#define BP_GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_HSIC_PHY_PGC_PUP_STATUS (4U) /*!< Bit position for GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_HSIC_PHY_PGC_PUP_STATUS. */
#define BM_GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_HSIC_PHY_PGC_PUP_STATUS (0x00000010U) /*!< Bit mask for GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_HSIC_PHY_PGC_PUP_STATUS. */
#define BS_GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_HSIC_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_HSIC_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_HSIC_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_A7_PU_PGC_PUP_STATUSn_A7_USB_HSIC_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_A7_PU_PGC_PUP_STATUSn(x, n).B.A7_USB_HSIC_PHY_PGC_PUP_STATUS)
/*@}*/

/*******************************************************************************
 * HW_GPC_M4_PU_PGC_PUP_STATUSn - M4 PU PGC software up trigger status register
 ******************************************************************************/

/*!
 * @brief HW_GPC_M4_PU_PGC_PUP_STATUSn - M4 PU PGC software up trigger status register (RO)
 *
 * Reset value: 0x00000000U
 *
 * M4_PU_PGC_PUP_STATUSn (n = 0,1,2) are a read only register, represents the
 * results for power up software trigger from M4 platform to PU type PGCs.
 * M4_PU_PGC_PUP_STATUS0: value of "1'b1" represent the software power up trigger failed
 * because domain control condition. The relevant bit will be cleared after a
 * success operation of power up software trigger for PU type PGCs.
 * M4_PU_PGC_PUP_STATUS1: value of "1'b1" represent the software power up trigger failed because
 * the relevant PGC is in a power up process. The relevant bit will be cleared
 * after a success operation of power up software trigger for PU type PGCs.
 * M4_PU_PGC_PUP_STATUS2: value of "1'b1" represent the software power up trigger failed
 * because time slot control is busy. The relevant bit will be cleared after a
 * success operation of power up software trigger for PU type PGCs.
 */
typedef union _hw_gpc_m4_pu_pgc_pup_statusn
{
    uint32_t U;
    struct _hw_gpc_m4_pu_pgc_pup_statusn_bitfields
    {
        uint32_t M4_MIPI_PHY_PGC_PUP_STATUS : 1; /*!< [0]  */
        uint32_t M4_PCIE_PHY_PGC_PUP_STATUS : 1; /*!< [1]  */
        uint32_t M4_USB_OTG1_PHY_PGC_PUP_STATUS : 1; /*!< [2]  */
        uint32_t M4_USB_OTG2_PHY_PGC_PUP_STATUS : 1; /*!< [3]  */
        uint32_t M4_USB_HSIC_PHY_PGC_PUP_STATUS : 1; /*!< [4]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_gpc_m4_pu_pgc_pup_statusn_t;

/*!
 * @name Constants and macros for entire GPC_M4_PU_PGC_PUP_STATUSn register
 */
/*@{*/
#define HW_GPC_M4_PU_PGC_PUP_STATUSn_COUNT (3U)

#define HW_GPC_M4_PU_PGC_PUP_STATUSn_ADDR(x, n) ((uintptr_t)(x) + 0x158U + (0x4U * (n)))

#define HW_GPC_M4_PU_PGC_PUP_STATUSn(x, n) (*(__I hw_gpc_m4_pu_pgc_pup_statusn_t *) HW_GPC_M4_PU_PGC_PUP_STATUSn_ADDR(x, n))
#define HW_GPC_M4_PU_PGC_PUP_STATUSn_RD(x, n) (HW_GPC_M4_PU_PGC_PUP_STATUSn(x, n).U)
/*@}*/

/*
 * Constants & macros for individual GPC_M4_PU_PGC_PUP_STATUSn bitfields
 */

/*!
 * @name Register GPC_M4_PU_PGC_PUP_STATUSn, field M4_MIPI_PHY_PGC_PUP_STATUS[0] (RO)
 */
/*@{*/
#define BP_GPC_M4_PU_PGC_PUP_STATUSn_M4_MIPI_PHY_PGC_PUP_STATUS (0U) /*!< Bit position for GPC_M4_PU_PGC_PUP_STATUSn_M4_MIPI_PHY_PGC_PUP_STATUS. */
#define BM_GPC_M4_PU_PGC_PUP_STATUSn_M4_MIPI_PHY_PGC_PUP_STATUS (0x00000001U) /*!< Bit mask for GPC_M4_PU_PGC_PUP_STATUSn_M4_MIPI_PHY_PGC_PUP_STATUS. */
#define BS_GPC_M4_PU_PGC_PUP_STATUSn_M4_MIPI_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_M4_PU_PGC_PUP_STATUSn_M4_MIPI_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_M4_PU_PGC_PUP_STATUSn_M4_MIPI_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_M4_PU_PGC_PUP_STATUSn_M4_MIPI_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_M4_PU_PGC_PUP_STATUSn(x, n).B.M4_MIPI_PHY_PGC_PUP_STATUS)
/*@}*/

/*!
 * @name Register GPC_M4_PU_PGC_PUP_STATUSn, field M4_PCIE_PHY_PGC_PUP_STATUS[1] (RO)
 */
/*@{*/
#define BP_GPC_M4_PU_PGC_PUP_STATUSn_M4_PCIE_PHY_PGC_PUP_STATUS (1U) /*!< Bit position for GPC_M4_PU_PGC_PUP_STATUSn_M4_PCIE_PHY_PGC_PUP_STATUS. */
#define BM_GPC_M4_PU_PGC_PUP_STATUSn_M4_PCIE_PHY_PGC_PUP_STATUS (0x00000002U) /*!< Bit mask for GPC_M4_PU_PGC_PUP_STATUSn_M4_PCIE_PHY_PGC_PUP_STATUS. */
#define BS_GPC_M4_PU_PGC_PUP_STATUSn_M4_PCIE_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_M4_PU_PGC_PUP_STATUSn_M4_PCIE_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_M4_PU_PGC_PUP_STATUSn_M4_PCIE_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_M4_PU_PGC_PUP_STATUSn_M4_PCIE_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_M4_PU_PGC_PUP_STATUSn(x, n).B.M4_PCIE_PHY_PGC_PUP_STATUS)
/*@}*/

/*!
 * @name Register GPC_M4_PU_PGC_PUP_STATUSn, field M4_USB_OTG1_PHY_PGC_PUP_STATUS[2] (RO)
 */
/*@{*/
#define BP_GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_OTG1_PHY_PGC_PUP_STATUS (2U) /*!< Bit position for GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_OTG1_PHY_PGC_PUP_STATUS. */
#define BM_GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_OTG1_PHY_PGC_PUP_STATUS (0x00000004U) /*!< Bit mask for GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_OTG1_PHY_PGC_PUP_STATUS. */
#define BS_GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_OTG1_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_OTG1_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_OTG1_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_OTG1_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_M4_PU_PGC_PUP_STATUSn(x, n).B.M4_USB_OTG1_PHY_PGC_PUP_STATUS)
/*@}*/

/*!
 * @name Register GPC_M4_PU_PGC_PUP_STATUSn, field M4_USB_OTG2_PHY_PGC_PUP_STATUS[3] (RO)
 */
/*@{*/
#define BP_GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_OTG2_PHY_PGC_PUP_STATUS (3U) /*!< Bit position for GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_OTG2_PHY_PGC_PUP_STATUS. */
#define BM_GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_OTG2_PHY_PGC_PUP_STATUS (0x00000008U) /*!< Bit mask for GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_OTG2_PHY_PGC_PUP_STATUS. */
#define BS_GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_OTG2_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_OTG2_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_OTG2_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_OTG2_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_M4_PU_PGC_PUP_STATUSn(x, n).B.M4_USB_OTG2_PHY_PGC_PUP_STATUS)
/*@}*/

/*!
 * @name Register GPC_M4_PU_PGC_PUP_STATUSn, field M4_USB_HSIC_PHY_PGC_PUP_STATUS[4] (RO)
 */
/*@{*/
#define BP_GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_HSIC_PHY_PGC_PUP_STATUS (4U) /*!< Bit position for GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_HSIC_PHY_PGC_PUP_STATUS. */
#define BM_GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_HSIC_PHY_PGC_PUP_STATUS (0x00000010U) /*!< Bit mask for GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_HSIC_PHY_PGC_PUP_STATUS. */
#define BS_GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_HSIC_PHY_PGC_PUP_STATUS (1U) /*!< Bit field size in bits for GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_HSIC_PHY_PGC_PUP_STATUS. */

/*! @brief Read current value of the GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_HSIC_PHY_PGC_PUP_STATUS field. */
#define BR_GPC_M4_PU_PGC_PUP_STATUSn_M4_USB_HSIC_PHY_PGC_PUP_STATUS(x, n) (HW_GPC_M4_PU_PGC_PUP_STATUSn(x, n).B.M4_USB_HSIC_PHY_PGC_PUP_STATUS)
/*@}*/

/*******************************************************************************
 * HW_GPC_CPU_PGC_PDN_STATUS1 - CPU PGC software dn trigger status1
 ******************************************************************************/

/*!
 * @brief HW_GPC_CPU_PGC_PDN_STATUS1 - CPU PGC software dn trigger status1 (RO)
 *
 * Reset value: 0x00000000U
 *
 * CPU_PGC_PDN_STATUS1 is a read only register, represents the results for power
 * DN software trigger for CPU type PGCs. The field description is show in table
 * below, the value of "1'b1" represent the software power DN trigger failed
 * because the relevant PGC is in a power down process. The relevant bit will be
 * cleared after a success operation of power DN software trigger for CPU type PGCs.
 */
typedef union _hw_gpc_cpu_pgc_pdn_status1
{
    uint32_t U;
    struct _hw_gpc_cpu_pgc_pdn_status1_bitfields
    {
        uint32_t CORE0_A7_PDN_STATUS : 1; /*!< [0]  */
        uint32_t CORE1_A7_PDN_STATUS : 1; /*!< [1]  */
        uint32_t SCU_A7_PDN_STATUS : 1; /*!< [2]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_gpc_cpu_pgc_pdn_status1_t;

/*!
 * @name Constants and macros for entire GPC_CPU_PGC_PDN_STATUS1 register
 */
/*@{*/
#define HW_GPC_CPU_PGC_PDN_STATUS1_ADDR(x) ((uintptr_t)(x) + 0x170U)

#define HW_GPC_CPU_PGC_PDN_STATUS1(x) (*(__I hw_gpc_cpu_pgc_pdn_status1_t *) HW_GPC_CPU_PGC_PDN_STATUS1_ADDR(x))
#define HW_GPC_CPU_PGC_PDN_STATUS1_RD(x) (HW_GPC_CPU_PGC_PDN_STATUS1(x).U)
/*@}*/

/*
 * Constants & macros for individual GPC_CPU_PGC_PDN_STATUS1 bitfields
 */

/*!
 * @name Register GPC_CPU_PGC_PDN_STATUS1, field CORE0_A7_PDN_STATUS[0] (RO)
 */
/*@{*/
#define BP_GPC_CPU_PGC_PDN_STATUS1_CORE0_A7_PDN_STATUS (0U) /*!< Bit position for GPC_CPU_PGC_PDN_STATUS1_CORE0_A7_PDN_STATUS. */
#define BM_GPC_CPU_PGC_PDN_STATUS1_CORE0_A7_PDN_STATUS (0x00000001U) /*!< Bit mask for GPC_CPU_PGC_PDN_STATUS1_CORE0_A7_PDN_STATUS. */
#define BS_GPC_CPU_PGC_PDN_STATUS1_CORE0_A7_PDN_STATUS (1U) /*!< Bit field size in bits for GPC_CPU_PGC_PDN_STATUS1_CORE0_A7_PDN_STATUS. */

/*! @brief Read current value of the GPC_CPU_PGC_PDN_STATUS1_CORE0_A7_PDN_STATUS field. */
#define BR_GPC_CPU_PGC_PDN_STATUS1_CORE0_A7_PDN_STATUS(x) (HW_GPC_CPU_PGC_PDN_STATUS1(x).B.CORE0_A7_PDN_STATUS)
/*@}*/

/*!
 * @name Register GPC_CPU_PGC_PDN_STATUS1, field CORE1_A7_PDN_STATUS[1] (RO)
 */
/*@{*/
#define BP_GPC_CPU_PGC_PDN_STATUS1_CORE1_A7_PDN_STATUS (1U) /*!< Bit position for GPC_CPU_PGC_PDN_STATUS1_CORE1_A7_PDN_STATUS. */
#define BM_GPC_CPU_PGC_PDN_STATUS1_CORE1_A7_PDN_STATUS (0x00000002U) /*!< Bit mask for GPC_CPU_PGC_PDN_STATUS1_CORE1_A7_PDN_STATUS. */
#define BS_GPC_CPU_PGC_PDN_STATUS1_CORE1_A7_PDN_STATUS (1U) /*!< Bit field size in bits for GPC_CPU_PGC_PDN_STATUS1_CORE1_A7_PDN_STATUS. */

/*! @brief Read current value of the GPC_CPU_PGC_PDN_STATUS1_CORE1_A7_PDN_STATUS field. */
#define BR_GPC_CPU_PGC_PDN_STATUS1_CORE1_A7_PDN_STATUS(x) (HW_GPC_CPU_PGC_PDN_STATUS1(x).B.CORE1_A7_PDN_STATUS)
/*@}*/

/*!
 * @name Register GPC_CPU_PGC_PDN_STATUS1, field SCU_A7_PDN_STATUS[2] (RO)
 */
/*@{*/
#define BP_GPC_CPU_PGC_PDN_STATUS1_SCU_A7_PDN_STATUS (2U) /*!< Bit position for GPC_CPU_PGC_PDN_STATUS1_SCU_A7_PDN_STATUS. */
#define BM_GPC_CPU_PGC_PDN_STATUS1_SCU_A7_PDN_STATUS (0x00000004U) /*!< Bit mask for GPC_CPU_PGC_PDN_STATUS1_SCU_A7_PDN_STATUS. */
#define BS_GPC_CPU_PGC_PDN_STATUS1_SCU_A7_PDN_STATUS (1U) /*!< Bit field size in bits for GPC_CPU_PGC_PDN_STATUS1_SCU_A7_PDN_STATUS. */

/*! @brief Read current value of the GPC_CPU_PGC_PDN_STATUS1_SCU_A7_PDN_STATUS field. */
#define BR_GPC_CPU_PGC_PDN_STATUS1_SCU_A7_PDN_STATUS(x) (HW_GPC_CPU_PGC_PDN_STATUS1(x).B.SCU_A7_PDN_STATUS)
/*@}*/

/*******************************************************************************
 * HW_GPC_A7_PU_PGC_PDN_STATUSn - A7 PU PGC software down trigger status
 ******************************************************************************/

/*!
 * @brief HW_GPC_A7_PU_PGC_PDN_STATUSn - A7 PU PGC software down trigger status (RO)
 *
 * Reset value: 0x00000000U
 *
 * A7_PU_PGC_PDN_STATUSn (n = 0,1,2) are a read only register, represents the
 * results for power DN software trigger from A7 platform to PU type PGCs.
 * A7_PU_PGC_PDN_STATUS0: value of "1'b1" represent the software power DN trigger failed
 * because domain control condition. The relevant bit will be cleared after a
 * success operation of power DN software trigger for PU type PGCs.
 * A7_PU_PGC_PDN_STATUS1: value of "1'b1" represent the software power DN trigger failed because
 * the relevant PGC is in a power DN process. The relevant bit will be cleared
 * after a success operation of power DN software trigger for PU type PGCs.
 * A7_PU_PGC_PDN_STATUS2: value of "1'b1" represent the software power DN trigger failed
 * because time slot control is busy. The relevant bit will be cleared after a
 * success operation of power DN software trigger for PU type PGCs.
 */
typedef union _hw_gpc_a7_pu_pgc_pdn_statusn
{
    uint32_t U;
    struct _hw_gpc_a7_pu_pgc_pdn_statusn_bitfields
    {
        uint32_t CORE0_A7_PDN_STATUS : 1; /*!< [0]  */
        uint32_t CORE1_A7_PDN_STATUS : 1; /*!< [1]  */
        uint32_t SCU_A7_PDN_STATUS : 1; /*!< [2]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_gpc_a7_pu_pgc_pdn_statusn_t;

/*!
 * @name Constants and macros for entire GPC_A7_PU_PGC_PDN_STATUSn register
 */
/*@{*/
#define HW_GPC_A7_PU_PGC_PDN_STATUSn_COUNT (3U)

#define HW_GPC_A7_PU_PGC_PDN_STATUSn_ADDR(x, n) ((uintptr_t)(x) + 0x18CU + (0x4U * (n)))

#define HW_GPC_A7_PU_PGC_PDN_STATUSn(x, n) (*(__I hw_gpc_a7_pu_pgc_pdn_statusn_t *) HW_GPC_A7_PU_PGC_PDN_STATUSn_ADDR(x, n))
#define HW_GPC_A7_PU_PGC_PDN_STATUSn_RD(x, n) (HW_GPC_A7_PU_PGC_PDN_STATUSn(x, n).U)
/*@}*/

/*
 * Constants & macros for individual GPC_A7_PU_PGC_PDN_STATUSn bitfields
 */

/*!
 * @name Register GPC_A7_PU_PGC_PDN_STATUSn, field CORE0_A7_PDN_STATUS[0] (RO)
 */
/*@{*/
#define BP_GPC_A7_PU_PGC_PDN_STATUSn_CORE0_A7_PDN_STATUS (0U) /*!< Bit position for GPC_A7_PU_PGC_PDN_STATUSn_CORE0_A7_PDN_STATUS. */
#define BM_GPC_A7_PU_PGC_PDN_STATUSn_CORE0_A7_PDN_STATUS (0x00000001U) /*!< Bit mask for GPC_A7_PU_PGC_PDN_STATUSn_CORE0_A7_PDN_STATUS. */
#define BS_GPC_A7_PU_PGC_PDN_STATUSn_CORE0_A7_PDN_STATUS (1U) /*!< Bit field size in bits for GPC_A7_PU_PGC_PDN_STATUSn_CORE0_A7_PDN_STATUS. */

/*! @brief Read current value of the GPC_A7_PU_PGC_PDN_STATUSn_CORE0_A7_PDN_STATUS field. */
#define BR_GPC_A7_PU_PGC_PDN_STATUSn_CORE0_A7_PDN_STATUS(x, n) (HW_GPC_A7_PU_PGC_PDN_STATUSn(x, n).B.CORE0_A7_PDN_STATUS)
/*@}*/

/*!
 * @name Register GPC_A7_PU_PGC_PDN_STATUSn, field CORE1_A7_PDN_STATUS[1] (RO)
 */
/*@{*/
#define BP_GPC_A7_PU_PGC_PDN_STATUSn_CORE1_A7_PDN_STATUS (1U) /*!< Bit position for GPC_A7_PU_PGC_PDN_STATUSn_CORE1_A7_PDN_STATUS. */
#define BM_GPC_A7_PU_PGC_PDN_STATUSn_CORE1_A7_PDN_STATUS (0x00000002U) /*!< Bit mask for GPC_A7_PU_PGC_PDN_STATUSn_CORE1_A7_PDN_STATUS. */
#define BS_GPC_A7_PU_PGC_PDN_STATUSn_CORE1_A7_PDN_STATUS (1U) /*!< Bit field size in bits for GPC_A7_PU_PGC_PDN_STATUSn_CORE1_A7_PDN_STATUS. */

/*! @brief Read current value of the GPC_A7_PU_PGC_PDN_STATUSn_CORE1_A7_PDN_STATUS field. */
#define BR_GPC_A7_PU_PGC_PDN_STATUSn_CORE1_A7_PDN_STATUS(x, n) (HW_GPC_A7_PU_PGC_PDN_STATUSn(x, n).B.CORE1_A7_PDN_STATUS)
/*@}*/

/*!
 * @name Register GPC_A7_PU_PGC_PDN_STATUSn, field SCU_A7_PDN_STATUS[2] (RO)
 */
/*@{*/
#define BP_GPC_A7_PU_PGC_PDN_STATUSn_SCU_A7_PDN_STATUS (2U) /*!< Bit position for GPC_A7_PU_PGC_PDN_STATUSn_SCU_A7_PDN_STATUS. */
#define BM_GPC_A7_PU_PGC_PDN_STATUSn_SCU_A7_PDN_STATUS (0x00000004U) /*!< Bit mask for GPC_A7_PU_PGC_PDN_STATUSn_SCU_A7_PDN_STATUS. */
#define BS_GPC_A7_PU_PGC_PDN_STATUSn_SCU_A7_PDN_STATUS (1U) /*!< Bit field size in bits for GPC_A7_PU_PGC_PDN_STATUSn_SCU_A7_PDN_STATUS. */

/*! @brief Read current value of the GPC_A7_PU_PGC_PDN_STATUSn_SCU_A7_PDN_STATUS field. */
#define BR_GPC_A7_PU_PGC_PDN_STATUSn_SCU_A7_PDN_STATUS(x, n) (HW_GPC_A7_PU_PGC_PDN_STATUSn(x, n).B.SCU_A7_PDN_STATUS)
/*@}*/

/*******************************************************************************
 * HW_GPC_M4_PU_PGC_PDN_STATUSn - M4 PU PGC software down trigger status
 ******************************************************************************/

/*!
 * @brief HW_GPC_M4_PU_PGC_PDN_STATUSn - M4 PU PGC software down trigger status (RO)
 *
 * Reset value: 0x00000000U
 *
 * M4_PU_PGC_PDN_STATUSn (n = 0,1,2) are a read only register, represents the
 * results for power DN software trigger from M4 platform to PU type PGCs.
 * M4_PU_PGC_PDN_STATUS0: value of "1'b1" represent the software power DN trigger failed
 * because domain control condition. The relevant bit will be cleared after a
 * success operation of power DN software trigger for PU type PGCs.
 * M4_PU_PGC_PDN_STATUS1: value of "1'b1" represent the software power DN trigger failed because
 * the relevant PGC is in a power DN process. The relevant bit will be cleared
 * after a success operation of power DN software trigger for PU type PGCs.
 * M4_PU_PGC_PDN_STATUS2: value of "1'b1" represent the software power DN trigger failed
 * because time slot control is busy. The relevant bit will be cleared after a
 * success operation of power DN software trigger for PU type PGCs.
 */
typedef union _hw_gpc_m4_pu_pgc_pdn_statusn
{
    uint32_t U;
    struct _hw_gpc_m4_pu_pgc_pdn_statusn_bitfields
    {
        uint32_t A7_MIPI_PHY_PGC_PDN_STATUS : 1; /*!< [0]  */
        uint32_t A7_PCIE_PHY_PGC_PDN_STATUS : 1; /*!< [1]  */
        uint32_t A7_USB_OTG1_PHY_PGC_PDN_STATUS : 1; /*!< [2]  */
        uint32_t A7_USB_OTG2_PHY_PGC_PDN_STATUS : 1; /*!< [3]  */
        uint32_t A7_USB_HSIC_PHY_PGC_PDN_STATUS : 1; /*!< [4]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_gpc_m4_pu_pgc_pdn_statusn_t;

/*!
 * @name Constants and macros for entire GPC_M4_PU_PGC_PDN_STATUSn register
 */
/*@{*/
#define HW_GPC_M4_PU_PGC_PDN_STATUSn_COUNT (3U)

#define HW_GPC_M4_PU_PGC_PDN_STATUSn_ADDR(x, n) ((uintptr_t)(x) + 0x198U + (0x4U * (n)))

#define HW_GPC_M4_PU_PGC_PDN_STATUSn(x, n) (*(__I hw_gpc_m4_pu_pgc_pdn_statusn_t *) HW_GPC_M4_PU_PGC_PDN_STATUSn_ADDR(x, n))
#define HW_GPC_M4_PU_PGC_PDN_STATUSn_RD(x, n) (HW_GPC_M4_PU_PGC_PDN_STATUSn(x, n).U)
/*@}*/

/*
 * Constants & macros for individual GPC_M4_PU_PGC_PDN_STATUSn bitfields
 */

/*!
 * @name Register GPC_M4_PU_PGC_PDN_STATUSn, field A7_MIPI_PHY_PGC_PDN_STATUS[0] (RO)
 */
/*@{*/
#define BP_GPC_M4_PU_PGC_PDN_STATUSn_A7_MIPI_PHY_PGC_PDN_STATUS (0U) /*!< Bit position for GPC_M4_PU_PGC_PDN_STATUSn_A7_MIPI_PHY_PGC_PDN_STATUS. */
#define BM_GPC_M4_PU_PGC_PDN_STATUSn_A7_MIPI_PHY_PGC_PDN_STATUS (0x00000001U) /*!< Bit mask for GPC_M4_PU_PGC_PDN_STATUSn_A7_MIPI_PHY_PGC_PDN_STATUS. */
#define BS_GPC_M4_PU_PGC_PDN_STATUSn_A7_MIPI_PHY_PGC_PDN_STATUS (1U) /*!< Bit field size in bits for GPC_M4_PU_PGC_PDN_STATUSn_A7_MIPI_PHY_PGC_PDN_STATUS. */

/*! @brief Read current value of the GPC_M4_PU_PGC_PDN_STATUSn_A7_MIPI_PHY_PGC_PDN_STATUS field. */
#define BR_GPC_M4_PU_PGC_PDN_STATUSn_A7_MIPI_PHY_PGC_PDN_STATUS(x, n) (HW_GPC_M4_PU_PGC_PDN_STATUSn(x, n).B.A7_MIPI_PHY_PGC_PDN_STATUS)
/*@}*/

/*!
 * @name Register GPC_M4_PU_PGC_PDN_STATUSn, field A7_PCIE_PHY_PGC_PDN_STATUS[1] (RO)
 */
/*@{*/
#define BP_GPC_M4_PU_PGC_PDN_STATUSn_A7_PCIE_PHY_PGC_PDN_STATUS (1U) /*!< Bit position for GPC_M4_PU_PGC_PDN_STATUSn_A7_PCIE_PHY_PGC_PDN_STATUS. */
#define BM_GPC_M4_PU_PGC_PDN_STATUSn_A7_PCIE_PHY_PGC_PDN_STATUS (0x00000002U) /*!< Bit mask for GPC_M4_PU_PGC_PDN_STATUSn_A7_PCIE_PHY_PGC_PDN_STATUS. */
#define BS_GPC_M4_PU_PGC_PDN_STATUSn_A7_PCIE_PHY_PGC_PDN_STATUS (1U) /*!< Bit field size in bits for GPC_M4_PU_PGC_PDN_STATUSn_A7_PCIE_PHY_PGC_PDN_STATUS. */

/*! @brief Read current value of the GPC_M4_PU_PGC_PDN_STATUSn_A7_PCIE_PHY_PGC_PDN_STATUS field. */
#define BR_GPC_M4_PU_PGC_PDN_STATUSn_A7_PCIE_PHY_PGC_PDN_STATUS(x, n) (HW_GPC_M4_PU_PGC_PDN_STATUSn(x, n).B.A7_PCIE_PHY_PGC_PDN_STATUS)
/*@}*/

/*!
 * @name Register GPC_M4_PU_PGC_PDN_STATUSn, field A7_USB_OTG1_PHY_PGC_PDN_STATUS[2] (RO)
 */
/*@{*/
#define BP_GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_OTG1_PHY_PGC_PDN_STATUS (2U) /*!< Bit position for GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_OTG1_PHY_PGC_PDN_STATUS. */
#define BM_GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_OTG1_PHY_PGC_PDN_STATUS (0x00000004U) /*!< Bit mask for GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_OTG1_PHY_PGC_PDN_STATUS. */
#define BS_GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_OTG1_PHY_PGC_PDN_STATUS (1U) /*!< Bit field size in bits for GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_OTG1_PHY_PGC_PDN_STATUS. */

/*! @brief Read current value of the GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_OTG1_PHY_PGC_PDN_STATUS field. */
#define BR_GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_OTG1_PHY_PGC_PDN_STATUS(x, n) (HW_GPC_M4_PU_PGC_PDN_STATUSn(x, n).B.A7_USB_OTG1_PHY_PGC_PDN_STATUS)
/*@}*/

/*!
 * @name Register GPC_M4_PU_PGC_PDN_STATUSn, field A7_USB_OTG2_PHY_PGC_PDN_STATUS[3] (RO)
 */
/*@{*/
#define BP_GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_OTG2_PHY_PGC_PDN_STATUS (3U) /*!< Bit position for GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_OTG2_PHY_PGC_PDN_STATUS. */
#define BM_GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_OTG2_PHY_PGC_PDN_STATUS (0x00000008U) /*!< Bit mask for GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_OTG2_PHY_PGC_PDN_STATUS. */
#define BS_GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_OTG2_PHY_PGC_PDN_STATUS (1U) /*!< Bit field size in bits for GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_OTG2_PHY_PGC_PDN_STATUS. */

/*! @brief Read current value of the GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_OTG2_PHY_PGC_PDN_STATUS field. */
#define BR_GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_OTG2_PHY_PGC_PDN_STATUS(x, n) (HW_GPC_M4_PU_PGC_PDN_STATUSn(x, n).B.A7_USB_OTG2_PHY_PGC_PDN_STATUS)
/*@}*/

/*!
 * @name Register GPC_M4_PU_PGC_PDN_STATUSn, field A7_USB_HSIC_PHY_PGC_PDN_STATUS[4] (RO)
 */
/*@{*/
#define BP_GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_HSIC_PHY_PGC_PDN_STATUS (4U) /*!< Bit position for GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_HSIC_PHY_PGC_PDN_STATUS. */
#define BM_GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_HSIC_PHY_PGC_PDN_STATUS (0x00000010U) /*!< Bit mask for GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_HSIC_PHY_PGC_PDN_STATUS. */
#define BS_GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_HSIC_PHY_PGC_PDN_STATUS (1U) /*!< Bit field size in bits for GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_HSIC_PHY_PGC_PDN_STATUS. */

/*! @brief Read current value of the GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_HSIC_PHY_PGC_PDN_STATUS field. */
#define BR_GPC_M4_PU_PGC_PDN_STATUSn_A7_USB_HSIC_PHY_PGC_PDN_STATUS(x, n) (HW_GPC_M4_PU_PGC_PDN_STATUSn(x, n).B.A7_USB_HSIC_PHY_PGC_PDN_STATUS)
/*@}*/

/*******************************************************************************
 * HW_GPC_A7_MIX_PDN_FLG - A7 MIX PDN FLG
 ******************************************************************************/

/*!
 * @brief HW_GPC_A7_MIX_PDN_FLG - A7 MIX PDN FLG (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is flag bit relevant domain control, represents A7 CPU platform wants to
 * power down MIX PGC. The register can only be accessed by A7 platform.
 */
typedef union _hw_gpc_a7_mix_pdn_flg
{
    uint32_t U;
    struct _hw_gpc_a7_mix_pdn_flg_bitfields
    {
        uint32_t A7_MIX_PDN_FLAG : 1;  /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_gpc_a7_mix_pdn_flg_t;

/*!
 * @name Constants and macros for entire GPC_A7_MIX_PDN_FLG register
 */
/*@{*/
#define HW_GPC_A7_MIX_PDN_FLG_ADDR(x) ((uintptr_t)(x) + 0x1B0U)

#define HW_GPC_A7_MIX_PDN_FLG(x) (*(__IO hw_gpc_a7_mix_pdn_flg_t *) HW_GPC_A7_MIX_PDN_FLG_ADDR(x))
#define HW_GPC_A7_MIX_PDN_FLG_RD(x) (HW_GPC_A7_MIX_PDN_FLG(x).U)
#define HW_GPC_A7_MIX_PDN_FLG_WR(x, v) (HW_GPC_A7_MIX_PDN_FLG(x).U = (v))
#define HW_GPC_A7_MIX_PDN_FLG_SET(x, v) (HW_GPC_A7_MIX_PDN_FLG_WR(x, HW_GPC_A7_MIX_PDN_FLG_RD(x) |  (v)))
#define HW_GPC_A7_MIX_PDN_FLG_CLR(x, v) (HW_GPC_A7_MIX_PDN_FLG_WR(x, HW_GPC_A7_MIX_PDN_FLG_RD(x) & ~(v)))
#define HW_GPC_A7_MIX_PDN_FLG_TOG(x, v) (HW_GPC_A7_MIX_PDN_FLG_WR(x, HW_GPC_A7_MIX_PDN_FLG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_A7_MIX_PDN_FLG bitfields
 */

/*!
 * @name Register GPC_A7_MIX_PDN_FLG, field A7_MIX_PDN_FLAG[0] (RW)
 *
 * A7 MIX power-down flag
 */
/*@{*/
#define BP_GPC_A7_MIX_PDN_FLG_A7_MIX_PDN_FLAG (0U) /*!< Bit position for GPC_A7_MIX_PDN_FLG_A7_MIX_PDN_FLAG. */
#define BM_GPC_A7_MIX_PDN_FLG_A7_MIX_PDN_FLAG (0x00000001U) /*!< Bit mask for GPC_A7_MIX_PDN_FLG_A7_MIX_PDN_FLAG. */
#define BS_GPC_A7_MIX_PDN_FLG_A7_MIX_PDN_FLAG (1U) /*!< Bit field size in bits for GPC_A7_MIX_PDN_FLG_A7_MIX_PDN_FLAG. */

/*! @brief Read current value of the GPC_A7_MIX_PDN_FLG_A7_MIX_PDN_FLAG field. */
#define BR_GPC_A7_MIX_PDN_FLG_A7_MIX_PDN_FLAG(x) (HW_GPC_A7_MIX_PDN_FLG(x).B.A7_MIX_PDN_FLAG)

/*! @brief Format value for bitfield GPC_A7_MIX_PDN_FLG_A7_MIX_PDN_FLAG. */
#define BF_GPC_A7_MIX_PDN_FLG_A7_MIX_PDN_FLAG(v) ((uint32_t)((uint32_t)(v) << BP_GPC_A7_MIX_PDN_FLG_A7_MIX_PDN_FLAG) & BM_GPC_A7_MIX_PDN_FLG_A7_MIX_PDN_FLAG)

/*! @brief Set the A7_MIX_PDN_FLAG field to a new value. */
#define BW_GPC_A7_MIX_PDN_FLG_A7_MIX_PDN_FLAG(x, v) (HW_GPC_A7_MIX_PDN_FLG_WR(x, (HW_GPC_A7_MIX_PDN_FLG_RD(x) & ~BM_GPC_A7_MIX_PDN_FLG_A7_MIX_PDN_FLAG) | BF_GPC_A7_MIX_PDN_FLG_A7_MIX_PDN_FLAG(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_A7_PU_PDN_FLG - A7 PU PDN FLG
 ******************************************************************************/

/*!
 * @brief HW_GPC_A7_PU_PDN_FLG - A7 PU PDN FLG (RW)
 *
 * Reset value: 0x00000000U
 *
 * The register field is show in the table below. The 1'b1 represents A7 CPU
 * platform wants to power down certain PU PGC. The register is a read only
 * register. The register bits will be set when corresponding A7 software power down
 * trigger happens and will be clear when corresponding A7 software power up trigger
 * happens.
 */
typedef union _hw_gpc_a7_pu_pdn_flg
{
    uint32_t U;
    struct _hw_gpc_a7_pu_pdn_flg_bitfields
    {
        uint32_t A7_MIPI_PHY_PGC_PDN_FLG : 1; /*!< [0]  */
        uint32_t A7_PCIE_PHY_PGC_PDN_FLG : 1; /*!< [1]  */
        uint32_t A7_USB_OTG1_PHY_PGC_PDN_FLG : 1; /*!< [2]  */
        uint32_t A7_USB_OTG2_PHY_PGC_PDN_FLG : 1; /*!< [3]  */
        uint32_t A7_USB_HSIC_PHY_PGC_PDN_FLG : 1; /*!< [4]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_gpc_a7_pu_pdn_flg_t;

/*!
 * @name Constants and macros for entire GPC_A7_PU_PDN_FLG register
 */
/*@{*/
#define HW_GPC_A7_PU_PDN_FLG_ADDR(x) ((uintptr_t)(x) + 0x1B4U)

#define HW_GPC_A7_PU_PDN_FLG(x)  (*(__IO hw_gpc_a7_pu_pdn_flg_t *) HW_GPC_A7_PU_PDN_FLG_ADDR(x))
#define HW_GPC_A7_PU_PDN_FLG_RD(x) (HW_GPC_A7_PU_PDN_FLG(x).U)
#define HW_GPC_A7_PU_PDN_FLG_WR(x, v) (HW_GPC_A7_PU_PDN_FLG(x).U = (v))
#define HW_GPC_A7_PU_PDN_FLG_SET(x, v) (HW_GPC_A7_PU_PDN_FLG_WR(x, HW_GPC_A7_PU_PDN_FLG_RD(x) |  (v)))
#define HW_GPC_A7_PU_PDN_FLG_CLR(x, v) (HW_GPC_A7_PU_PDN_FLG_WR(x, HW_GPC_A7_PU_PDN_FLG_RD(x) & ~(v)))
#define HW_GPC_A7_PU_PDN_FLG_TOG(x, v) (HW_GPC_A7_PU_PDN_FLG_WR(x, HW_GPC_A7_PU_PDN_FLG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_A7_PU_PDN_FLG bitfields
 */

/*!
 * @name Register GPC_A7_PU_PDN_FLG, field A7_MIPI_PHY_PGC_PDN_FLG[0] (RW)
 *
 * MIPI_PHY PGC power-down flag
 */
/*@{*/
#define BP_GPC_A7_PU_PDN_FLG_A7_MIPI_PHY_PGC_PDN_FLG (0U) /*!< Bit position for GPC_A7_PU_PDN_FLG_A7_MIPI_PHY_PGC_PDN_FLG. */
#define BM_GPC_A7_PU_PDN_FLG_A7_MIPI_PHY_PGC_PDN_FLG (0x00000001U) /*!< Bit mask for GPC_A7_PU_PDN_FLG_A7_MIPI_PHY_PGC_PDN_FLG. */
#define BS_GPC_A7_PU_PDN_FLG_A7_MIPI_PHY_PGC_PDN_FLG (1U) /*!< Bit field size in bits for GPC_A7_PU_PDN_FLG_A7_MIPI_PHY_PGC_PDN_FLG. */

/*! @brief Read current value of the GPC_A7_PU_PDN_FLG_A7_MIPI_PHY_PGC_PDN_FLG field. */
#define BR_GPC_A7_PU_PDN_FLG_A7_MIPI_PHY_PGC_PDN_FLG(x) (HW_GPC_A7_PU_PDN_FLG(x).B.A7_MIPI_PHY_PGC_PDN_FLG)

/*! @brief Format value for bitfield GPC_A7_PU_PDN_FLG_A7_MIPI_PHY_PGC_PDN_FLG. */
#define BF_GPC_A7_PU_PDN_FLG_A7_MIPI_PHY_PGC_PDN_FLG(v) ((uint32_t)((uint32_t)(v) << BP_GPC_A7_PU_PDN_FLG_A7_MIPI_PHY_PGC_PDN_FLG) & BM_GPC_A7_PU_PDN_FLG_A7_MIPI_PHY_PGC_PDN_FLG)

/*! @brief Set the A7_MIPI_PHY_PGC_PDN_FLG field to a new value. */
#define BW_GPC_A7_PU_PDN_FLG_A7_MIPI_PHY_PGC_PDN_FLG(x, v) (HW_GPC_A7_PU_PDN_FLG_WR(x, (HW_GPC_A7_PU_PDN_FLG_RD(x) & ~BM_GPC_A7_PU_PDN_FLG_A7_MIPI_PHY_PGC_PDN_FLG) | BF_GPC_A7_PU_PDN_FLG_A7_MIPI_PHY_PGC_PDN_FLG(v)))
/*@}*/

/*!
 * @name Register GPC_A7_PU_PDN_FLG, field A7_PCIE_PHY_PGC_PDN_FLG[1] (RW)
 *
 * PCIE_PHY PGC power-down flag
 */
/*@{*/
#define BP_GPC_A7_PU_PDN_FLG_A7_PCIE_PHY_PGC_PDN_FLG (1U) /*!< Bit position for GPC_A7_PU_PDN_FLG_A7_PCIE_PHY_PGC_PDN_FLG. */
#define BM_GPC_A7_PU_PDN_FLG_A7_PCIE_PHY_PGC_PDN_FLG (0x00000002U) /*!< Bit mask for GPC_A7_PU_PDN_FLG_A7_PCIE_PHY_PGC_PDN_FLG. */
#define BS_GPC_A7_PU_PDN_FLG_A7_PCIE_PHY_PGC_PDN_FLG (1U) /*!< Bit field size in bits for GPC_A7_PU_PDN_FLG_A7_PCIE_PHY_PGC_PDN_FLG. */

/*! @brief Read current value of the GPC_A7_PU_PDN_FLG_A7_PCIE_PHY_PGC_PDN_FLG field. */
#define BR_GPC_A7_PU_PDN_FLG_A7_PCIE_PHY_PGC_PDN_FLG(x) (HW_GPC_A7_PU_PDN_FLG(x).B.A7_PCIE_PHY_PGC_PDN_FLG)

/*! @brief Format value for bitfield GPC_A7_PU_PDN_FLG_A7_PCIE_PHY_PGC_PDN_FLG. */
#define BF_GPC_A7_PU_PDN_FLG_A7_PCIE_PHY_PGC_PDN_FLG(v) ((uint32_t)((uint32_t)(v) << BP_GPC_A7_PU_PDN_FLG_A7_PCIE_PHY_PGC_PDN_FLG) & BM_GPC_A7_PU_PDN_FLG_A7_PCIE_PHY_PGC_PDN_FLG)

/*! @brief Set the A7_PCIE_PHY_PGC_PDN_FLG field to a new value. */
#define BW_GPC_A7_PU_PDN_FLG_A7_PCIE_PHY_PGC_PDN_FLG(x, v) (HW_GPC_A7_PU_PDN_FLG_WR(x, (HW_GPC_A7_PU_PDN_FLG_RD(x) & ~BM_GPC_A7_PU_PDN_FLG_A7_PCIE_PHY_PGC_PDN_FLG) | BF_GPC_A7_PU_PDN_FLG_A7_PCIE_PHY_PGC_PDN_FLG(v)))
/*@}*/

/*!
 * @name Register GPC_A7_PU_PDN_FLG, field A7_USB_OTG1_PHY_PGC_PDN_FLG[2] (RW)
 *
 * USB_OTG1 PGC power-down flag
 */
/*@{*/
#define BP_GPC_A7_PU_PDN_FLG_A7_USB_OTG1_PHY_PGC_PDN_FLG (2U) /*!< Bit position for GPC_A7_PU_PDN_FLG_A7_USB_OTG1_PHY_PGC_PDN_FLG. */
#define BM_GPC_A7_PU_PDN_FLG_A7_USB_OTG1_PHY_PGC_PDN_FLG (0x00000004U) /*!< Bit mask for GPC_A7_PU_PDN_FLG_A7_USB_OTG1_PHY_PGC_PDN_FLG. */
#define BS_GPC_A7_PU_PDN_FLG_A7_USB_OTG1_PHY_PGC_PDN_FLG (1U) /*!< Bit field size in bits for GPC_A7_PU_PDN_FLG_A7_USB_OTG1_PHY_PGC_PDN_FLG. */

/*! @brief Read current value of the GPC_A7_PU_PDN_FLG_A7_USB_OTG1_PHY_PGC_PDN_FLG field. */
#define BR_GPC_A7_PU_PDN_FLG_A7_USB_OTG1_PHY_PGC_PDN_FLG(x) (HW_GPC_A7_PU_PDN_FLG(x).B.A7_USB_OTG1_PHY_PGC_PDN_FLG)

/*! @brief Format value for bitfield GPC_A7_PU_PDN_FLG_A7_USB_OTG1_PHY_PGC_PDN_FLG. */
#define BF_GPC_A7_PU_PDN_FLG_A7_USB_OTG1_PHY_PGC_PDN_FLG(v) ((uint32_t)((uint32_t)(v) << BP_GPC_A7_PU_PDN_FLG_A7_USB_OTG1_PHY_PGC_PDN_FLG) & BM_GPC_A7_PU_PDN_FLG_A7_USB_OTG1_PHY_PGC_PDN_FLG)

/*! @brief Set the A7_USB_OTG1_PHY_PGC_PDN_FLG field to a new value. */
#define BW_GPC_A7_PU_PDN_FLG_A7_USB_OTG1_PHY_PGC_PDN_FLG(x, v) (HW_GPC_A7_PU_PDN_FLG_WR(x, (HW_GPC_A7_PU_PDN_FLG_RD(x) & ~BM_GPC_A7_PU_PDN_FLG_A7_USB_OTG1_PHY_PGC_PDN_FLG) | BF_GPC_A7_PU_PDN_FLG_A7_USB_OTG1_PHY_PGC_PDN_FLG(v)))
/*@}*/

/*!
 * @name Register GPC_A7_PU_PDN_FLG, field A7_USB_OTG2_PHY_PGC_PDN_FLG[3] (RW)
 *
 * USB_OTG2 PGC power-down flag
 */
/*@{*/
#define BP_GPC_A7_PU_PDN_FLG_A7_USB_OTG2_PHY_PGC_PDN_FLG (3U) /*!< Bit position for GPC_A7_PU_PDN_FLG_A7_USB_OTG2_PHY_PGC_PDN_FLG. */
#define BM_GPC_A7_PU_PDN_FLG_A7_USB_OTG2_PHY_PGC_PDN_FLG (0x00000008U) /*!< Bit mask for GPC_A7_PU_PDN_FLG_A7_USB_OTG2_PHY_PGC_PDN_FLG. */
#define BS_GPC_A7_PU_PDN_FLG_A7_USB_OTG2_PHY_PGC_PDN_FLG (1U) /*!< Bit field size in bits for GPC_A7_PU_PDN_FLG_A7_USB_OTG2_PHY_PGC_PDN_FLG. */

/*! @brief Read current value of the GPC_A7_PU_PDN_FLG_A7_USB_OTG2_PHY_PGC_PDN_FLG field. */
#define BR_GPC_A7_PU_PDN_FLG_A7_USB_OTG2_PHY_PGC_PDN_FLG(x) (HW_GPC_A7_PU_PDN_FLG(x).B.A7_USB_OTG2_PHY_PGC_PDN_FLG)

/*! @brief Format value for bitfield GPC_A7_PU_PDN_FLG_A7_USB_OTG2_PHY_PGC_PDN_FLG. */
#define BF_GPC_A7_PU_PDN_FLG_A7_USB_OTG2_PHY_PGC_PDN_FLG(v) ((uint32_t)((uint32_t)(v) << BP_GPC_A7_PU_PDN_FLG_A7_USB_OTG2_PHY_PGC_PDN_FLG) & BM_GPC_A7_PU_PDN_FLG_A7_USB_OTG2_PHY_PGC_PDN_FLG)

/*! @brief Set the A7_USB_OTG2_PHY_PGC_PDN_FLG field to a new value. */
#define BW_GPC_A7_PU_PDN_FLG_A7_USB_OTG2_PHY_PGC_PDN_FLG(x, v) (HW_GPC_A7_PU_PDN_FLG_WR(x, (HW_GPC_A7_PU_PDN_FLG_RD(x) & ~BM_GPC_A7_PU_PDN_FLG_A7_USB_OTG2_PHY_PGC_PDN_FLG) | BF_GPC_A7_PU_PDN_FLG_A7_USB_OTG2_PHY_PGC_PDN_FLG(v)))
/*@}*/

/*!
 * @name Register GPC_A7_PU_PDN_FLG, field A7_USB_HSIC_PHY_PGC_PDN_FLG[4] (RW)
 *
 * USB_HSIC PGC power-down flag
 */
/*@{*/
#define BP_GPC_A7_PU_PDN_FLG_A7_USB_HSIC_PHY_PGC_PDN_FLG (4U) /*!< Bit position for GPC_A7_PU_PDN_FLG_A7_USB_HSIC_PHY_PGC_PDN_FLG. */
#define BM_GPC_A7_PU_PDN_FLG_A7_USB_HSIC_PHY_PGC_PDN_FLG (0x00000010U) /*!< Bit mask for GPC_A7_PU_PDN_FLG_A7_USB_HSIC_PHY_PGC_PDN_FLG. */
#define BS_GPC_A7_PU_PDN_FLG_A7_USB_HSIC_PHY_PGC_PDN_FLG (1U) /*!< Bit field size in bits for GPC_A7_PU_PDN_FLG_A7_USB_HSIC_PHY_PGC_PDN_FLG. */

/*! @brief Read current value of the GPC_A7_PU_PDN_FLG_A7_USB_HSIC_PHY_PGC_PDN_FLG field. */
#define BR_GPC_A7_PU_PDN_FLG_A7_USB_HSIC_PHY_PGC_PDN_FLG(x) (HW_GPC_A7_PU_PDN_FLG(x).B.A7_USB_HSIC_PHY_PGC_PDN_FLG)

/*! @brief Format value for bitfield GPC_A7_PU_PDN_FLG_A7_USB_HSIC_PHY_PGC_PDN_FLG. */
#define BF_GPC_A7_PU_PDN_FLG_A7_USB_HSIC_PHY_PGC_PDN_FLG(v) ((uint32_t)((uint32_t)(v) << BP_GPC_A7_PU_PDN_FLG_A7_USB_HSIC_PHY_PGC_PDN_FLG) & BM_GPC_A7_PU_PDN_FLG_A7_USB_HSIC_PHY_PGC_PDN_FLG)

/*! @brief Set the A7_USB_HSIC_PHY_PGC_PDN_FLG field to a new value. */
#define BW_GPC_A7_PU_PDN_FLG_A7_USB_HSIC_PHY_PGC_PDN_FLG(x, v) (HW_GPC_A7_PU_PDN_FLG_WR(x, (HW_GPC_A7_PU_PDN_FLG_RD(x) & ~BM_GPC_A7_PU_PDN_FLG_A7_USB_HSIC_PHY_PGC_PDN_FLG) | BF_GPC_A7_PU_PDN_FLG_A7_USB_HSIC_PHY_PGC_PDN_FLG(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_M4_MIX_PDN_FLG - M4 MIX PDN FLG
 ******************************************************************************/

/*!
 * @brief HW_GPC_M4_MIX_PDN_FLG - M4 MIX PDN FLG (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is flag bit relevant domain control, represents M4 CPU platform wants to
 * power down MIX PGC. The register can only be accessed by M4 platform.
 */
typedef union _hw_gpc_m4_mix_pdn_flg
{
    uint32_t U;
    struct _hw_gpc_m4_mix_pdn_flg_bitfields
    {
        uint32_t M4_MIX_PDN_FLAG : 1;  /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_gpc_m4_mix_pdn_flg_t;

/*!
 * @name Constants and macros for entire GPC_M4_MIX_PDN_FLG register
 */
/*@{*/
#define HW_GPC_M4_MIX_PDN_FLG_ADDR(x) ((uintptr_t)(x) + 0x1B8U)

#define HW_GPC_M4_MIX_PDN_FLG(x) (*(__IO hw_gpc_m4_mix_pdn_flg_t *) HW_GPC_M4_MIX_PDN_FLG_ADDR(x))
#define HW_GPC_M4_MIX_PDN_FLG_RD(x) (HW_GPC_M4_MIX_PDN_FLG(x).U)
#define HW_GPC_M4_MIX_PDN_FLG_WR(x, v) (HW_GPC_M4_MIX_PDN_FLG(x).U = (v))
#define HW_GPC_M4_MIX_PDN_FLG_SET(x, v) (HW_GPC_M4_MIX_PDN_FLG_WR(x, HW_GPC_M4_MIX_PDN_FLG_RD(x) |  (v)))
#define HW_GPC_M4_MIX_PDN_FLG_CLR(x, v) (HW_GPC_M4_MIX_PDN_FLG_WR(x, HW_GPC_M4_MIX_PDN_FLG_RD(x) & ~(v)))
#define HW_GPC_M4_MIX_PDN_FLG_TOG(x, v) (HW_GPC_M4_MIX_PDN_FLG_WR(x, HW_GPC_M4_MIX_PDN_FLG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_M4_MIX_PDN_FLG bitfields
 */

/*!
 * @name Register GPC_M4_MIX_PDN_FLG, field M4_MIX_PDN_FLAG[0] (RW)
 *
 * M4_MIX power-down flag
 */
/*@{*/
#define BP_GPC_M4_MIX_PDN_FLG_M4_MIX_PDN_FLAG (0U) /*!< Bit position for GPC_M4_MIX_PDN_FLG_M4_MIX_PDN_FLAG. */
#define BM_GPC_M4_MIX_PDN_FLG_M4_MIX_PDN_FLAG (0x00000001U) /*!< Bit mask for GPC_M4_MIX_PDN_FLG_M4_MIX_PDN_FLAG. */
#define BS_GPC_M4_MIX_PDN_FLG_M4_MIX_PDN_FLAG (1U) /*!< Bit field size in bits for GPC_M4_MIX_PDN_FLG_M4_MIX_PDN_FLAG. */

/*! @brief Read current value of the GPC_M4_MIX_PDN_FLG_M4_MIX_PDN_FLAG field. */
#define BR_GPC_M4_MIX_PDN_FLG_M4_MIX_PDN_FLAG(x) (HW_GPC_M4_MIX_PDN_FLG(x).B.M4_MIX_PDN_FLAG)

/*! @brief Format value for bitfield GPC_M4_MIX_PDN_FLG_M4_MIX_PDN_FLAG. */
#define BF_GPC_M4_MIX_PDN_FLG_M4_MIX_PDN_FLAG(v) ((uint32_t)((uint32_t)(v) << BP_GPC_M4_MIX_PDN_FLG_M4_MIX_PDN_FLAG) & BM_GPC_M4_MIX_PDN_FLG_M4_MIX_PDN_FLAG)

/*! @brief Set the M4_MIX_PDN_FLAG field to a new value. */
#define BW_GPC_M4_MIX_PDN_FLG_M4_MIX_PDN_FLAG(x, v) (HW_GPC_M4_MIX_PDN_FLG_WR(x, (HW_GPC_M4_MIX_PDN_FLG_RD(x) & ~BM_GPC_M4_MIX_PDN_FLG_M4_MIX_PDN_FLAG) | BF_GPC_M4_MIX_PDN_FLG_M4_MIX_PDN_FLAG(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_M4_PU_PDN_FLG - M4 PU PDN FLG
 ******************************************************************************/

/*!
 * @brief HW_GPC_M4_PU_PDN_FLG - M4 PU PDN FLG (RW)
 *
 * Reset value: 0x00000000U
 *
 * The register field is show in the table below. The 1'b1 represents M4 CPU
 * platform wants to power down certain PU PGC. The register is a read only
 * register. The register bits will be set when corresponding M4 software power down
 * trigger happens and will be clear when corresponding M4 software power up trigger
 * happens.
 */
typedef union _hw_gpc_m4_pu_pdn_flg
{
    uint32_t U;
    struct _hw_gpc_m4_pu_pdn_flg_bitfields
    {
        uint32_t M4_MIPI_PHY_PGC_PDN_FLG : 1; /*!< [0]  */
        uint32_t M4_PCIE_PHY_PGC_PDN_FLG : 1; /*!< [1]  */
        uint32_t M4_USB_OTG1_PHY_PGC_PDN_FLG : 1; /*!< [2]  */
        uint32_t M4_USB_OTG2_PHY_PGC_PDN_FLG : 1; /*!< [3]  */
        uint32_t M4_USB_HSIC_PHY_PGC_PDN_FLG : 1; /*!< [4]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_gpc_m4_pu_pdn_flg_t;

/*!
 * @name Constants and macros for entire GPC_M4_PU_PDN_FLG register
 */
/*@{*/
#define HW_GPC_M4_PU_PDN_FLG_ADDR(x) ((uintptr_t)(x) + 0x1BCU)

#define HW_GPC_M4_PU_PDN_FLG(x)  (*(__IO hw_gpc_m4_pu_pdn_flg_t *) HW_GPC_M4_PU_PDN_FLG_ADDR(x))
#define HW_GPC_M4_PU_PDN_FLG_RD(x) (HW_GPC_M4_PU_PDN_FLG(x).U)
#define HW_GPC_M4_PU_PDN_FLG_WR(x, v) (HW_GPC_M4_PU_PDN_FLG(x).U = (v))
#define HW_GPC_M4_PU_PDN_FLG_SET(x, v) (HW_GPC_M4_PU_PDN_FLG_WR(x, HW_GPC_M4_PU_PDN_FLG_RD(x) |  (v)))
#define HW_GPC_M4_PU_PDN_FLG_CLR(x, v) (HW_GPC_M4_PU_PDN_FLG_WR(x, HW_GPC_M4_PU_PDN_FLG_RD(x) & ~(v)))
#define HW_GPC_M4_PU_PDN_FLG_TOG(x, v) (HW_GPC_M4_PU_PDN_FLG_WR(x, HW_GPC_M4_PU_PDN_FLG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_M4_PU_PDN_FLG bitfields
 */

/*!
 * @name Register GPC_M4_PU_PDN_FLG, field M4_MIPI_PHY_PGC_PDN_FLG[0] (RW)
 *
 * MIPI_PHY PGC power-down flag
 */
/*@{*/
#define BP_GPC_M4_PU_PDN_FLG_M4_MIPI_PHY_PGC_PDN_FLG (0U) /*!< Bit position for GPC_M4_PU_PDN_FLG_M4_MIPI_PHY_PGC_PDN_FLG. */
#define BM_GPC_M4_PU_PDN_FLG_M4_MIPI_PHY_PGC_PDN_FLG (0x00000001U) /*!< Bit mask for GPC_M4_PU_PDN_FLG_M4_MIPI_PHY_PGC_PDN_FLG. */
#define BS_GPC_M4_PU_PDN_FLG_M4_MIPI_PHY_PGC_PDN_FLG (1U) /*!< Bit field size in bits for GPC_M4_PU_PDN_FLG_M4_MIPI_PHY_PGC_PDN_FLG. */

/*! @brief Read current value of the GPC_M4_PU_PDN_FLG_M4_MIPI_PHY_PGC_PDN_FLG field. */
#define BR_GPC_M4_PU_PDN_FLG_M4_MIPI_PHY_PGC_PDN_FLG(x) (HW_GPC_M4_PU_PDN_FLG(x).B.M4_MIPI_PHY_PGC_PDN_FLG)

/*! @brief Format value for bitfield GPC_M4_PU_PDN_FLG_M4_MIPI_PHY_PGC_PDN_FLG. */
#define BF_GPC_M4_PU_PDN_FLG_M4_MIPI_PHY_PGC_PDN_FLG(v) ((uint32_t)((uint32_t)(v) << BP_GPC_M4_PU_PDN_FLG_M4_MIPI_PHY_PGC_PDN_FLG) & BM_GPC_M4_PU_PDN_FLG_M4_MIPI_PHY_PGC_PDN_FLG)

/*! @brief Set the M4_MIPI_PHY_PGC_PDN_FLG field to a new value. */
#define BW_GPC_M4_PU_PDN_FLG_M4_MIPI_PHY_PGC_PDN_FLG(x, v) (HW_GPC_M4_PU_PDN_FLG_WR(x, (HW_GPC_M4_PU_PDN_FLG_RD(x) & ~BM_GPC_M4_PU_PDN_FLG_M4_MIPI_PHY_PGC_PDN_FLG) | BF_GPC_M4_PU_PDN_FLG_M4_MIPI_PHY_PGC_PDN_FLG(v)))
/*@}*/

/*!
 * @name Register GPC_M4_PU_PDN_FLG, field M4_PCIE_PHY_PGC_PDN_FLG[1] (RW)
 *
 * PCIE_PHY PGC power-down flag
 */
/*@{*/
#define BP_GPC_M4_PU_PDN_FLG_M4_PCIE_PHY_PGC_PDN_FLG (1U) /*!< Bit position for GPC_M4_PU_PDN_FLG_M4_PCIE_PHY_PGC_PDN_FLG. */
#define BM_GPC_M4_PU_PDN_FLG_M4_PCIE_PHY_PGC_PDN_FLG (0x00000002U) /*!< Bit mask for GPC_M4_PU_PDN_FLG_M4_PCIE_PHY_PGC_PDN_FLG. */
#define BS_GPC_M4_PU_PDN_FLG_M4_PCIE_PHY_PGC_PDN_FLG (1U) /*!< Bit field size in bits for GPC_M4_PU_PDN_FLG_M4_PCIE_PHY_PGC_PDN_FLG. */

/*! @brief Read current value of the GPC_M4_PU_PDN_FLG_M4_PCIE_PHY_PGC_PDN_FLG field. */
#define BR_GPC_M4_PU_PDN_FLG_M4_PCIE_PHY_PGC_PDN_FLG(x) (HW_GPC_M4_PU_PDN_FLG(x).B.M4_PCIE_PHY_PGC_PDN_FLG)

/*! @brief Format value for bitfield GPC_M4_PU_PDN_FLG_M4_PCIE_PHY_PGC_PDN_FLG. */
#define BF_GPC_M4_PU_PDN_FLG_M4_PCIE_PHY_PGC_PDN_FLG(v) ((uint32_t)((uint32_t)(v) << BP_GPC_M4_PU_PDN_FLG_M4_PCIE_PHY_PGC_PDN_FLG) & BM_GPC_M4_PU_PDN_FLG_M4_PCIE_PHY_PGC_PDN_FLG)

/*! @brief Set the M4_PCIE_PHY_PGC_PDN_FLG field to a new value. */
#define BW_GPC_M4_PU_PDN_FLG_M4_PCIE_PHY_PGC_PDN_FLG(x, v) (HW_GPC_M4_PU_PDN_FLG_WR(x, (HW_GPC_M4_PU_PDN_FLG_RD(x) & ~BM_GPC_M4_PU_PDN_FLG_M4_PCIE_PHY_PGC_PDN_FLG) | BF_GPC_M4_PU_PDN_FLG_M4_PCIE_PHY_PGC_PDN_FLG(v)))
/*@}*/

/*!
 * @name Register GPC_M4_PU_PDN_FLG, field M4_USB_OTG1_PHY_PGC_PDN_FLG[2] (RW)
 *
 * USB_OTG1 PGC power-down flag
 */
/*@{*/
#define BP_GPC_M4_PU_PDN_FLG_M4_USB_OTG1_PHY_PGC_PDN_FLG (2U) /*!< Bit position for GPC_M4_PU_PDN_FLG_M4_USB_OTG1_PHY_PGC_PDN_FLG. */
#define BM_GPC_M4_PU_PDN_FLG_M4_USB_OTG1_PHY_PGC_PDN_FLG (0x00000004U) /*!< Bit mask for GPC_M4_PU_PDN_FLG_M4_USB_OTG1_PHY_PGC_PDN_FLG. */
#define BS_GPC_M4_PU_PDN_FLG_M4_USB_OTG1_PHY_PGC_PDN_FLG (1U) /*!< Bit field size in bits for GPC_M4_PU_PDN_FLG_M4_USB_OTG1_PHY_PGC_PDN_FLG. */

/*! @brief Read current value of the GPC_M4_PU_PDN_FLG_M4_USB_OTG1_PHY_PGC_PDN_FLG field. */
#define BR_GPC_M4_PU_PDN_FLG_M4_USB_OTG1_PHY_PGC_PDN_FLG(x) (HW_GPC_M4_PU_PDN_FLG(x).B.M4_USB_OTG1_PHY_PGC_PDN_FLG)

/*! @brief Format value for bitfield GPC_M4_PU_PDN_FLG_M4_USB_OTG1_PHY_PGC_PDN_FLG. */
#define BF_GPC_M4_PU_PDN_FLG_M4_USB_OTG1_PHY_PGC_PDN_FLG(v) ((uint32_t)((uint32_t)(v) << BP_GPC_M4_PU_PDN_FLG_M4_USB_OTG1_PHY_PGC_PDN_FLG) & BM_GPC_M4_PU_PDN_FLG_M4_USB_OTG1_PHY_PGC_PDN_FLG)

/*! @brief Set the M4_USB_OTG1_PHY_PGC_PDN_FLG field to a new value. */
#define BW_GPC_M4_PU_PDN_FLG_M4_USB_OTG1_PHY_PGC_PDN_FLG(x, v) (HW_GPC_M4_PU_PDN_FLG_WR(x, (HW_GPC_M4_PU_PDN_FLG_RD(x) & ~BM_GPC_M4_PU_PDN_FLG_M4_USB_OTG1_PHY_PGC_PDN_FLG) | BF_GPC_M4_PU_PDN_FLG_M4_USB_OTG1_PHY_PGC_PDN_FLG(v)))
/*@}*/

/*!
 * @name Register GPC_M4_PU_PDN_FLG, field M4_USB_OTG2_PHY_PGC_PDN_FLG[3] (RW)
 *
 * USB_OTG2 PGC power-down flag
 */
/*@{*/
#define BP_GPC_M4_PU_PDN_FLG_M4_USB_OTG2_PHY_PGC_PDN_FLG (3U) /*!< Bit position for GPC_M4_PU_PDN_FLG_M4_USB_OTG2_PHY_PGC_PDN_FLG. */
#define BM_GPC_M4_PU_PDN_FLG_M4_USB_OTG2_PHY_PGC_PDN_FLG (0x00000008U) /*!< Bit mask for GPC_M4_PU_PDN_FLG_M4_USB_OTG2_PHY_PGC_PDN_FLG. */
#define BS_GPC_M4_PU_PDN_FLG_M4_USB_OTG2_PHY_PGC_PDN_FLG (1U) /*!< Bit field size in bits for GPC_M4_PU_PDN_FLG_M4_USB_OTG2_PHY_PGC_PDN_FLG. */

/*! @brief Read current value of the GPC_M4_PU_PDN_FLG_M4_USB_OTG2_PHY_PGC_PDN_FLG field. */
#define BR_GPC_M4_PU_PDN_FLG_M4_USB_OTG2_PHY_PGC_PDN_FLG(x) (HW_GPC_M4_PU_PDN_FLG(x).B.M4_USB_OTG2_PHY_PGC_PDN_FLG)

/*! @brief Format value for bitfield GPC_M4_PU_PDN_FLG_M4_USB_OTG2_PHY_PGC_PDN_FLG. */
#define BF_GPC_M4_PU_PDN_FLG_M4_USB_OTG2_PHY_PGC_PDN_FLG(v) ((uint32_t)((uint32_t)(v) << BP_GPC_M4_PU_PDN_FLG_M4_USB_OTG2_PHY_PGC_PDN_FLG) & BM_GPC_M4_PU_PDN_FLG_M4_USB_OTG2_PHY_PGC_PDN_FLG)

/*! @brief Set the M4_USB_OTG2_PHY_PGC_PDN_FLG field to a new value. */
#define BW_GPC_M4_PU_PDN_FLG_M4_USB_OTG2_PHY_PGC_PDN_FLG(x, v) (HW_GPC_M4_PU_PDN_FLG_WR(x, (HW_GPC_M4_PU_PDN_FLG_RD(x) & ~BM_GPC_M4_PU_PDN_FLG_M4_USB_OTG2_PHY_PGC_PDN_FLG) | BF_GPC_M4_PU_PDN_FLG_M4_USB_OTG2_PHY_PGC_PDN_FLG(v)))
/*@}*/

/*!
 * @name Register GPC_M4_PU_PDN_FLG, field M4_USB_HSIC_PHY_PGC_PDN_FLG[4] (RW)
 *
 * USB_HSIC PGC power-down flag
 */
/*@{*/
#define BP_GPC_M4_PU_PDN_FLG_M4_USB_HSIC_PHY_PGC_PDN_FLG (4U) /*!< Bit position for GPC_M4_PU_PDN_FLG_M4_USB_HSIC_PHY_PGC_PDN_FLG. */
#define BM_GPC_M4_PU_PDN_FLG_M4_USB_HSIC_PHY_PGC_PDN_FLG (0x00000010U) /*!< Bit mask for GPC_M4_PU_PDN_FLG_M4_USB_HSIC_PHY_PGC_PDN_FLG. */
#define BS_GPC_M4_PU_PDN_FLG_M4_USB_HSIC_PHY_PGC_PDN_FLG (1U) /*!< Bit field size in bits for GPC_M4_PU_PDN_FLG_M4_USB_HSIC_PHY_PGC_PDN_FLG. */

/*! @brief Read current value of the GPC_M4_PU_PDN_FLG_M4_USB_HSIC_PHY_PGC_PDN_FLG field. */
#define BR_GPC_M4_PU_PDN_FLG_M4_USB_HSIC_PHY_PGC_PDN_FLG(x) (HW_GPC_M4_PU_PDN_FLG(x).B.M4_USB_HSIC_PHY_PGC_PDN_FLG)

/*! @brief Format value for bitfield GPC_M4_PU_PDN_FLG_M4_USB_HSIC_PHY_PGC_PDN_FLG. */
#define BF_GPC_M4_PU_PDN_FLG_M4_USB_HSIC_PHY_PGC_PDN_FLG(v) ((uint32_t)((uint32_t)(v) << BP_GPC_M4_PU_PDN_FLG_M4_USB_HSIC_PHY_PGC_PDN_FLG) & BM_GPC_M4_PU_PDN_FLG_M4_USB_HSIC_PHY_PGC_PDN_FLG)

/*! @brief Set the M4_USB_HSIC_PHY_PGC_PDN_FLG field to a new value. */
#define BW_GPC_M4_PU_PDN_FLG_M4_USB_HSIC_PHY_PGC_PDN_FLG(x, v) (HW_GPC_M4_PU_PDN_FLG_WR(x, (HW_GPC_M4_PU_PDN_FLG_RD(x) & ~BM_GPC_M4_PU_PDN_FLG_M4_USB_HSIC_PHY_PGC_PDN_FLG) | BF_GPC_M4_PU_PDN_FLG_M4_USB_HSIC_PHY_PGC_PDN_FLG(v)))
/*@}*/

/*******************************************************************************
 * hw_gpc_t - module struct
 ******************************************************************************/
/*!
 * @brief All GPC module registers.
 */
#pragma pack(1)
typedef struct _hw_gpc
{
    __IO hw_gpc_lpcr_a7_bsc_t LPCR_A7_BSC; /*!< [0x0] Basic Low power control register of A7 platform */
    __IO hw_gpc_lpcr_a7_ad_t LPCR_A7_AD;   /*!< [0x4] Advanced Low power control register of A7 platform */
    __IO hw_gpc_lpcr_m4_t LPCR_M4;         /*!< [0x8] Low power control register of CPU1 */
    uint8_t _reserved0[8];
    __IO hw_gpc_slpcr_t SLPCR;             /*!< [0x14] System low power control register */
    uint8_t _reserved1[8];
    __IO hw_gpc_mlpcr_t MLPCR;             /*!< [0x20] Memory low power control register */
    __IO hw_gpc_pgc_ack_sel_a7_t PGC_ACK_SEL_A7; /*!< [0x24] PGC acknowledge signal selection of A7 platform */
    __IO hw_gpc_pgc_ack_sel_m4_t PGC_ACK_SEL_M4; /*!< [0x28] PGC acknowledge signal selection of M4 platform */
    __IO hw_gpc_misc_t MISC;               /*!< [0x2C] GPC Miscellaneous register */
    __IO hw_gpc_imr1_core0_a7_t IMR1_CORE0_A7; /*!< [0x30] IRQ masking register 1 of A7 core0 */
    __IO hw_gpc_imr2_core0_a7_t IMR2_CORE0_A7; /*!< [0x34] IRQ masking register 2 of A7 core0 */
    __IO hw_gpc_imr3_core0_a7_t IMR3_CORE0_A7; /*!< [0x38] IRQ masking register 3 of A7 core0 */
    __IO hw_gpc_imr4_core0_a7_t IMR4_CORE0_A7; /*!< [0x3C] IRQ masking register 4 of A7 core0 */
    __IO hw_gpc_imr1_core1_a7_t IMR1_CORE1_A7; /*!< [0x40] IRQ masking register 1 of A7 core1 */
    __IO hw_gpc_imr2_core1_a7_t IMR2_CORE1_A7; /*!< [0x44] IRQ masking register 2 of A7 core1 */
    __IO hw_gpc_imr3_core1_a7_t IMR3_CORE1_A7; /*!< [0x48] IRQ masking register 3 of A7 core1 */
    __IO hw_gpc_imr4_core1_a7_t IMR4_CORE1_A7; /*!< [0x4C] IRQ masking register 4 of A7 core1 */
    __IO hw_gpc_imr1_m4_t IMR1_M4;         /*!< [0x50] IRQ masking register 1 of M4 */
    __IO hw_gpc_imr2_m4_t IMR2_M4;         /*!< [0x54] IRQ masking register 2 of M4 */
    __IO hw_gpc_imr3_m4_t IMR3_M4;         /*!< [0x58] IRQ masking register 3 of M4 */
    __IO hw_gpc_imr4_m4_t IMR4_M4;         /*!< [0x5C] IRQ masking register 4 of M4 */
    uint8_t _reserved2[16];
    __I hw_gpc_isr1_a7_t ISR1_A7;          /*!< [0x70] IRQ status register 1 of A7 */
    __I hw_gpc_isr2_a7_t ISR2_A7;          /*!< [0x74] IRQ status register 2 of A7 */
    __I hw_gpc_isr3_a7_t ISR3_A7;          /*!< [0x78] IRQ status register 3 of A7 */
    __I hw_gpc_isr4_a7_t ISR4_A7;          /*!< [0x7C] IRQ status register 4 of A7 */
    __I hw_gpc_isr1_m4_t ISR1_M4;          /*!< [0x80] IRQ status register 1 of M4 */
    __I hw_gpc_isr2_m4_t ISR2_M4;          /*!< [0x84] IRQ status register 2 of M4 */
    __I hw_gpc_isr3_m4_t ISR3_M4;          /*!< [0x88] IRQ status register 3 of M4 */
    __I hw_gpc_isr4_m4_t ISR4_M4;          /*!< [0x8C] IRQ status register 4 of M4 */
    uint8_t _reserved3[32];
    __IO hw_gpc_sltn_cfg_t SLTn_CFG[10];   /*!< [0xB0] Slot configure register */
    uint8_t _reserved4[20];
    __IO hw_gpc_pgc_cpu_mapping_t PGC_CPU_MAPPING; /*!< [0xEC] PGC CPU mapping */
    __IO hw_gpc_cpu_pgc_sw_pup_req_t CPU_PGC_SW_PUP_REQ; /*!< [0xF0] CPU PGC software up trigger */
    uint8_t _reserved5[4];
    __IO hw_gpc_pu_pgc_sw_pup_req_t PU_PGC_SW_PUP_REQ; /*!< [0xF8] PU PGC software up trigger */
    __IO hw_gpc_cpu_pgc_sw_pdn_req_t CPU_PGC_SW_PDN_REQ; /*!< [0xFC] CPU PGC software down trigger */
    uint8_t _reserved6[4];
    __IO hw_gpc_pu_pgc_sw_pdn_req_t PU_PGC_SW_PDN_REQ; /*!< [0x104] PU PGC software down trigger */
    uint8_t _reserved7[40];
    __I hw_gpc_cpu_pgc_pup_status1_t CPU_PGC_PUP_STATUS1; /*!< [0x130] CPU PGC software up trigger status1 */
    __I hw_gpc_a7_mix_pgc_pup_statusn_t A7_MIX_PGC_PUP_STATUSn[3]; /*!< [0x134] A7 MIX software up trigger status register */
    __I hw_gpc_m4_mix_pgc_pup_statusn_t M4_MIX_PGC_PUP_STATUSn[3]; /*!< [0x140] M4 MIX PGC software up trigger status register */
    __I hw_gpc_a7_pu_pgc_pup_statusn_t A7_PU_PGC_PUP_STATUSn[3]; /*!< [0x14C] A7 PU software up trigger status register */
    __I hw_gpc_m4_pu_pgc_pup_statusn_t M4_PU_PGC_PUP_STATUSn[3]; /*!< [0x158] M4 PU PGC software up trigger status register */
    uint8_t _reserved8[12];
    __I hw_gpc_cpu_pgc_pdn_status1_t CPU_PGC_PDN_STATUS1; /*!< [0x170] CPU PGC software dn trigger status1 */
    uint8_t _reserved9[24];
    __I hw_gpc_a7_pu_pgc_pdn_statusn_t A7_PU_PGC_PDN_STATUSn[3]; /*!< [0x18C] A7 PU PGC software down trigger status */
    __I hw_gpc_m4_pu_pgc_pdn_statusn_t M4_PU_PGC_PDN_STATUSn[3]; /*!< [0x198] M4 PU PGC software down trigger status */
    uint8_t _reserved10[12];
    __IO hw_gpc_a7_mix_pdn_flg_t A7_MIX_PDN_FLG; /*!< [0x1B0] A7 MIX PDN FLG */
    __IO hw_gpc_a7_pu_pdn_flg_t A7_PU_PDN_FLG; /*!< [0x1B4] A7 PU PDN FLG */
    __IO hw_gpc_m4_mix_pdn_flg_t M4_MIX_PDN_FLG; /*!< [0x1B8] M4 MIX PDN FLG */
    __IO hw_gpc_m4_pu_pdn_flg_t M4_PU_PDN_FLG; /*!< [0x1BC] M4 PU PDN FLG */
} hw_gpc_t;
#pragma pack()

/*! @brief Macro to access all GPC registers. */
/*! @param x GPC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_GPC_REGS(GPC_BASE)</code>. */
#define HW_GPC_REGS(x) (*(hw_gpc_t *)(x))

/*
 * iMX7D GPC_PGC
 *
 * GPC_PGC
 *
 * Registers defined in this header file:
 * - HW_GPC_PGC_A7CORE0_CTRL - GPC PGC Control Register
 * - HW_GPC_PGC_A7CORE0_PUPSCR - GPC PGC Up Sequence Control Register
 * - HW_GPC_PGC_A7CORE0_PDNSCR - GPC PGC Down Sequence Control Register
 * - HW_GPC_PGC_A7CORE0_SR - GPC PGC Status Register
 * - HW_GPC_PGC_A7CORE1_CTRL - GPC PGC Control Register
 * - HW_GPC_PGC_A7CORE1_PUPSCR - GPC PGC Up Sequence Control Register
 * - HW_GPC_PGC_A7CORE1_PDNSCR - GPC PGC Down Sequence Control Register
 * - HW_GPC_PGC_A7CORE1_SR - GPC PGC Status Register
 * - HW_GPC_PGC_A7SCU_CTRL - GPC PGC Control Register
 * - HW_GPC_PGC_A7SCU_PUPSCR - GPC PGC Up Sequence Control Register
 * - HW_GPC_PGC_A7SCU_PDNSCR - GPC PGC Down Sequence Control Register
 * - HW_GPC_PGC_A7SCU_SR - GPC PGC Status Register
 * - HW_GPC_PGC_SCU_AUXSW - GPC PGC Auxiliary Power Switch SCU Control Register
 * - HW_GPC_PGC_MIX_CTRL - GPC PGC Control Register
 * - HW_GPC_PGC_MIX_PUPSCR - GPC PGC Up Sequence Control Register
 * - HW_GPC_PGC_MIX_PDNSCR - GPC PGC Down Sequence Control Register
 * - HW_GPC_PGC_MIX_SR - GPC PGC Status Register
 * - HW_GPC_PGC_MIPI_CTRL - GPC PGC Control Register
 * - HW_GPC_PGC_MIPI_PUPSCR - GPC PGC Up Sequence Control Register
 * - HW_GPC_PGC_MIPI_PDNSCR - GPC PGC Down Sequence Control Register
 * - HW_GPC_PGC_MIPI_SR - GPC PGC Status Register
 * - HW_GPC_PGC_PCIE_CTRL - GPC PGC Control Register
 * - HW_GPC_PGC_PCIE_PUPSCR - GPC PGC Up Sequence Control Register
 * - HW_GPC_PGC_PCIE_PDNSCR - GPC PGC Down Sequence Control Register
 * - HW_GPC_PGC_PCIE_SR - GPC PGC Status Register
 * - HW_GPC_PGC_MIPI_AUXSW - GPC PGC Auxiliary Power Switch Control Register
 * - HW_GPC_PGC_PCIE_AUXSW - GPC PGC Auxiliary Power Switch Control Register
 * - HW_GPC_PGC_HSIC_CTRL - GPC PGC Control Register
 * - HW_GPC_PGC_HSIC_PUPSCR - GPC PGC Up Sequence Control Register
 * - HW_GPC_PGC_HSIC_PDNSCR - GPC PGC Down Sequence Control Register
 * - HW_GPC_PGC_HSIC_SR - GPC PGC Status Register
 *
 * - hw_gpc_pgc_t - Struct containing all module registers.
 */

#define HW_GPC_PGC_INSTANCE_COUNT (1U) /*!< Number of instances of the GPC_PGC module. */
#define HW_GPC_PGC (0U) /*!< Instance number for GPC_PGC. */
#define GPC_PGC_BASE          (0x303A0800U) /*!< Base address for GPC_PGC. */
/*! Array initializer of GPC_PGC base addresses. */
#define GPC_PGC_BASE_ADDRS    { GPC_PGC_BASE }

/*******************************************************************************
 * HW_GPC_PGC_A7CORE0_CTRL - GPC PGC Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_A7CORE0_CTRL - GPC PGC Control Register (RW)
 *
 * Reset value: 0x06040202U
 *
 * GPC PGC Control Register
 */
typedef union _hw_gpc_pgc_a7core0_ctrl
{
    uint32_t U;
    struct _hw_gpc_pgc_a7core0_ctrl_bitfields
    {
        uint32_t PCR : 1;              /*!< [0]  */
        uint32_t L2RSTDIS : 6;         /*!< [6:1]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t DFTRAM_TCD1 : 6;      /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t L2RETN_TCD1_TDR : 6;  /*!< [21:16]  */
        uint32_t RESERVED2 : 2;        /*!< [23:22]  */
        uint32_t MEMPWR_TCD1_TDR_TRM : 6; /*!< [29:24]  */
        uint32_t RESERVED3 : 2;        /*!< [31:30]  */
    } B;
} hw_gpc_pgc_a7core0_ctrl_t;

/*!
 * @name Constants and macros for entire GPC_PGC_A7CORE0_CTRL register
 */
/*@{*/
#define HW_GPC_PGC_A7CORE0_CTRL_ADDR(x) ((uintptr_t)(x) + 0x0U)

#define HW_GPC_PGC_A7CORE0_CTRL(x) (*(__IO hw_gpc_pgc_a7core0_ctrl_t *) HW_GPC_PGC_A7CORE0_CTRL_ADDR(x))
#define HW_GPC_PGC_A7CORE0_CTRL_RD(x) (HW_GPC_PGC_A7CORE0_CTRL(x).U)
#define HW_GPC_PGC_A7CORE0_CTRL_WR(x, v) (HW_GPC_PGC_A7CORE0_CTRL(x).U = (v))
#define HW_GPC_PGC_A7CORE0_CTRL_SET(x, v) (HW_GPC_PGC_A7CORE0_CTRL_WR(x, HW_GPC_PGC_A7CORE0_CTRL_RD(x) |  (v)))
#define HW_GPC_PGC_A7CORE0_CTRL_CLR(x, v) (HW_GPC_PGC_A7CORE0_CTRL_WR(x, HW_GPC_PGC_A7CORE0_CTRL_RD(x) & ~(v)))
#define HW_GPC_PGC_A7CORE0_CTRL_TOG(x, v) (HW_GPC_PGC_A7CORE0_CTRL_WR(x, HW_GPC_PGC_A7CORE0_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_A7CORE0_CTRL bitfields
 */

/*!
 * @name Register GPC_PGC_A7CORE0_CTRL, field PCR[0] (RW)
 *
 * Power ControlPCR must not change from power-down request (pdn_req) assertion
 * until the target subsystem is completely powered up.
 *
 * Values:
 * - 0 - Do not switch off power even if pdn_req is asserted.
 * - 1 - Switch off power when pdn_req is asserted.
 */
/*@{*/
#define BP_GPC_PGC_A7CORE0_CTRL_PCR (0U)   /*!< Bit position for GPC_PGC_A7CORE0_CTRL_PCR. */
#define BM_GPC_PGC_A7CORE0_CTRL_PCR (0x00000001U) /*!< Bit mask for GPC_PGC_A7CORE0_CTRL_PCR. */
#define BS_GPC_PGC_A7CORE0_CTRL_PCR (1U)   /*!< Bit field size in bits for GPC_PGC_A7CORE0_CTRL_PCR. */

/*! @brief Read current value of the GPC_PGC_A7CORE0_CTRL_PCR field. */
#define BR_GPC_PGC_A7CORE0_CTRL_PCR(x) (HW_GPC_PGC_A7CORE0_CTRL(x).B.PCR)

/*! @brief Format value for bitfield GPC_PGC_A7CORE0_CTRL_PCR. */
#define BF_GPC_PGC_A7CORE0_CTRL_PCR(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE0_CTRL_PCR) & BM_GPC_PGC_A7CORE0_CTRL_PCR)

/*! @brief Set the PCR field to a new value. */
#define BW_GPC_PGC_A7CORE0_CTRL_PCR(x, v) (HW_GPC_PGC_A7CORE0_CTRL_WR(x, (HW_GPC_PGC_A7CORE0_CTRL_RD(x) & ~BM_GPC_PGC_A7CORE0_CTRL_PCR) | BF_GPC_PGC_A7CORE0_CTRL_PCR(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE0_CTRL, field L2RSTDIS[6:1] (RW)
 *
 * After scu pdn_req, count this value to assert A7 l2rstdis to 1'b1, it will be
 * clear automatically once any of A7 core0/core1 is wakeup Can't be programmed
 * to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7CORE0_CTRL_L2RSTDIS (1U) /*!< Bit position for GPC_PGC_A7CORE0_CTRL_L2RSTDIS. */
#define BM_GPC_PGC_A7CORE0_CTRL_L2RSTDIS (0x0000007EU) /*!< Bit mask for GPC_PGC_A7CORE0_CTRL_L2RSTDIS. */
#define BS_GPC_PGC_A7CORE0_CTRL_L2RSTDIS (6U) /*!< Bit field size in bits for GPC_PGC_A7CORE0_CTRL_L2RSTDIS. */

/*! @brief Read current value of the GPC_PGC_A7CORE0_CTRL_L2RSTDIS field. */
#define BR_GPC_PGC_A7CORE0_CTRL_L2RSTDIS(x) (HW_GPC_PGC_A7CORE0_CTRL(x).B.L2RSTDIS)

/*! @brief Format value for bitfield GPC_PGC_A7CORE0_CTRL_L2RSTDIS. */
#define BF_GPC_PGC_A7CORE0_CTRL_L2RSTDIS(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE0_CTRL_L2RSTDIS) & BM_GPC_PGC_A7CORE0_CTRL_L2RSTDIS)

/*! @brief Set the L2RSTDIS field to a new value. */
#define BW_GPC_PGC_A7CORE0_CTRL_L2RSTDIS(x, v) (HW_GPC_PGC_A7CORE0_CTRL_WR(x, (HW_GPC_PGC_A7CORE0_CTRL_RD(x) & ~BM_GPC_PGC_A7CORE0_CTRL_L2RSTDIS) | BF_GPC_PGC_A7CORE0_CTRL_L2RSTDIS(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE0_CTRL, field DFTRAM_TCD1[13:8] (RW)
 *
 * After scu pdn_req, count this value to assert A7 dftram to 1'b1 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1 (8U) /*!< Bit position for GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1. */
#define BM_GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1 (0x00003F00U) /*!< Bit mask for GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1. */
#define BS_GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1 (6U) /*!< Bit field size in bits for GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1. */

/*! @brief Read current value of the GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1 field. */
#define BR_GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1(x) (HW_GPC_PGC_A7CORE0_CTRL(x).B.DFTRAM_TCD1)

/*! @brief Format value for bitfield GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1. */
#define BF_GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1) & BM_GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1)

/*! @brief Set the DFTRAM_TCD1 field to a new value. */
#define BW_GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1(x, v) (HW_GPC_PGC_A7CORE0_CTRL_WR(x, (HW_GPC_PGC_A7CORE0_CTRL_RD(x) & ~BM_GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1) | BF_GPC_PGC_A7CORE0_CTRL_DFTRAM_TCD1(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE0_CTRL, field L2RETN_TCD1_TDR[21:16] (RW)
 *
 * After scu pdn_req, count this value to assert A7 l2retn to 1'b0 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR (16U) /*!< Bit position for GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR. */
#define BM_GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR (0x003F0000U) /*!< Bit mask for GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR. */
#define BS_GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR (6U) /*!< Bit field size in bits for GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR. */

/*! @brief Read current value of the GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR field. */
#define BR_GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR(x) (HW_GPC_PGC_A7CORE0_CTRL(x).B.L2RETN_TCD1_TDR)

/*! @brief Format value for bitfield GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR. */
#define BF_GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR) & BM_GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR)

/*! @brief Set the L2RETN_TCD1_TDR field to a new value. */
#define BW_GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR(x, v) (HW_GPC_PGC_A7CORE0_CTRL_WR(x, (HW_GPC_PGC_A7CORE0_CTRL_RD(x) & ~BM_GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR) | BF_GPC_PGC_A7CORE0_CTRL_L2RETN_TCD1_TDR(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE0_CTRL, field MEMPWR_TCD1_TDR_TRM[29:24] (RW)
 *
 * After scu pdn_req, count this value to assert A7 mempwr to 1'b1 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM (24U) /*!< Bit position for GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BM_GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM (0x3F000000U) /*!< Bit mask for GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BS_GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM (6U) /*!< Bit field size in bits for GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM. */

/*! @brief Read current value of the GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM field. */
#define BR_GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM(x) (HW_GPC_PGC_A7CORE0_CTRL(x).B.MEMPWR_TCD1_TDR_TRM)

/*! @brief Format value for bitfield GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BF_GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM) & BM_GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM)

/*! @brief Set the MEMPWR_TCD1_TDR_TRM field to a new value. */
#define BW_GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM(x, v) (HW_GPC_PGC_A7CORE0_CTRL_WR(x, (HW_GPC_PGC_A7CORE0_CTRL_RD(x) & ~BM_GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM) | BF_GPC_PGC_A7CORE0_CTRL_MEMPWR_TCD1_TDR_TRM(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_A7CORE0_PUPSCR - GPC PGC Up Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_A7CORE0_PUPSCR - GPC PGC Up Sequence Control Register (RW)
 *
 * Reset value: 0x000997C1U
 *
 * GPC PGC Up Sequence Control Register
 */
typedef union _hw_gpc_pgc_a7core0_pupscr
{
    uint32_t U;
    struct _hw_gpc_pgc_a7core0_pupscr_bitfields
    {
        uint32_t SW : 6;               /*!< [5:0]  */
        uint32_t PUP_WAIT_SCALL_OUT : 1; /*!< [6]  */
        uint32_t SW2ISO : 16;          /*!< [22:7]  */
        uint32_t PUP_SCALL_SCALLOUT_CNT : 9; /*!< [31:23]  */
    } B;
} hw_gpc_pgc_a7core0_pupscr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_A7CORE0_PUPSCR register
 */
/*@{*/
#define HW_GPC_PGC_A7CORE0_PUPSCR_ADDR(x) ((uintptr_t)(x) + 0x4U)

#define HW_GPC_PGC_A7CORE0_PUPSCR(x) (*(__IO hw_gpc_pgc_a7core0_pupscr_t *) HW_GPC_PGC_A7CORE0_PUPSCR_ADDR(x))
#define HW_GPC_PGC_A7CORE0_PUPSCR_RD(x) (HW_GPC_PGC_A7CORE0_PUPSCR(x).U)
#define HW_GPC_PGC_A7CORE0_PUPSCR_WR(x, v) (HW_GPC_PGC_A7CORE0_PUPSCR(x).U = (v))
#define HW_GPC_PGC_A7CORE0_PUPSCR_SET(x, v) (HW_GPC_PGC_A7CORE0_PUPSCR_WR(x, HW_GPC_PGC_A7CORE0_PUPSCR_RD(x) |  (v)))
#define HW_GPC_PGC_A7CORE0_PUPSCR_CLR(x, v) (HW_GPC_PGC_A7CORE0_PUPSCR_WR(x, HW_GPC_PGC_A7CORE0_PUPSCR_RD(x) & ~(v)))
#define HW_GPC_PGC_A7CORE0_PUPSCR_TOG(x, v) (HW_GPC_PGC_A7CORE0_PUPSCR_WR(x, HW_GPC_PGC_A7CORE0_PUPSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_A7CORE0_PUPSCR bitfields
 */

/*!
 * @name Register GPC_PGC_A7CORE0_PUPSCR, field SW[5:0] (RW)
 *
 * After a power-up request (pup_req assertion), the PGC waits a number of
 * clocks equal to the value of SW before asserting switch_b SW must not be programmed
 * to zero.
 */
/*@{*/
#define BP_GPC_PGC_A7CORE0_PUPSCR_SW (0U)  /*!< Bit position for GPC_PGC_A7CORE0_PUPSCR_SW. */
#define BM_GPC_PGC_A7CORE0_PUPSCR_SW (0x0000003FU) /*!< Bit mask for GPC_PGC_A7CORE0_PUPSCR_SW. */
#define BS_GPC_PGC_A7CORE0_PUPSCR_SW (6U)  /*!< Bit field size in bits for GPC_PGC_A7CORE0_PUPSCR_SW. */

/*! @brief Read current value of the GPC_PGC_A7CORE0_PUPSCR_SW field. */
#define BR_GPC_PGC_A7CORE0_PUPSCR_SW(x) (HW_GPC_PGC_A7CORE0_PUPSCR(x).B.SW)

/*! @brief Format value for bitfield GPC_PGC_A7CORE0_PUPSCR_SW. */
#define BF_GPC_PGC_A7CORE0_PUPSCR_SW(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE0_PUPSCR_SW) & BM_GPC_PGC_A7CORE0_PUPSCR_SW)

/*! @brief Set the SW field to a new value. */
#define BW_GPC_PGC_A7CORE0_PUPSCR_SW(x, v) (HW_GPC_PGC_A7CORE0_PUPSCR_WR(x, (HW_GPC_PGC_A7CORE0_PUPSCR_RD(x) & ~BM_GPC_PGC_A7CORE0_PUPSCR_SW) | BF_GPC_PGC_A7CORE0_PUPSCR_SW(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE0_PUPSCR, field PUP_WAIT_SCALL_OUT[6] (RW)
 *
 * After SCALL asserting to 1'b0, wait handshake signal SCALL_OUT to return to
 * 1'b0 (This register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7CORE0_PUPSCR_PUP_WAIT_SCALL_OUT (6U) /*!< Bit position for GPC_PGC_A7CORE0_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BM_GPC_PGC_A7CORE0_PUPSCR_PUP_WAIT_SCALL_OUT (0x00000040U) /*!< Bit mask for GPC_PGC_A7CORE0_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BS_GPC_PGC_A7CORE0_PUPSCR_PUP_WAIT_SCALL_OUT (1U) /*!< Bit field size in bits for GPC_PGC_A7CORE0_PUPSCR_PUP_WAIT_SCALL_OUT. */

/*! @brief Read current value of the GPC_PGC_A7CORE0_PUPSCR_PUP_WAIT_SCALL_OUT field. */
#define BR_GPC_PGC_A7CORE0_PUPSCR_PUP_WAIT_SCALL_OUT(x) (HW_GPC_PGC_A7CORE0_PUPSCR(x).B.PUP_WAIT_SCALL_OUT)

/*! @brief Format value for bitfield GPC_PGC_A7CORE0_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BF_GPC_PGC_A7CORE0_PUPSCR_PUP_WAIT_SCALL_OUT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE0_PUPSCR_PUP_WAIT_SCALL_OUT) & BM_GPC_PGC_A7CORE0_PUPSCR_PUP_WAIT_SCALL_OUT)

/*! @brief Set the PUP_WAIT_SCALL_OUT field to a new value. */
#define BW_GPC_PGC_A7CORE0_PUPSCR_PUP_WAIT_SCALL_OUT(x, v) (HW_GPC_PGC_A7CORE0_PUPSCR_WR(x, (HW_GPC_PGC_A7CORE0_PUPSCR_RD(x) & ~BM_GPC_PGC_A7CORE0_PUPSCR_PUP_WAIT_SCALL_OUT) | BF_GPC_PGC_A7CORE0_PUPSCR_PUP_WAIT_SCALL_OUT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE0_PUPSCR, field SW2ISO[22:7] (RW)
 *
 * After asserting switch_b, the PGC waits a number of clocks equal to the value
 * of SW2ISO before negating isolation.
 */
/*@{*/
#define BP_GPC_PGC_A7CORE0_PUPSCR_SW2ISO (7U) /*!< Bit position for GPC_PGC_A7CORE0_PUPSCR_SW2ISO. */
#define BM_GPC_PGC_A7CORE0_PUPSCR_SW2ISO (0x007FFF80U) /*!< Bit mask for GPC_PGC_A7CORE0_PUPSCR_SW2ISO. */
#define BS_GPC_PGC_A7CORE0_PUPSCR_SW2ISO (16U) /*!< Bit field size in bits for GPC_PGC_A7CORE0_PUPSCR_SW2ISO. */

/*! @brief Read current value of the GPC_PGC_A7CORE0_PUPSCR_SW2ISO field. */
#define BR_GPC_PGC_A7CORE0_PUPSCR_SW2ISO(x) (HW_GPC_PGC_A7CORE0_PUPSCR(x).B.SW2ISO)

/*! @brief Format value for bitfield GPC_PGC_A7CORE0_PUPSCR_SW2ISO. */
#define BF_GPC_PGC_A7CORE0_PUPSCR_SW2ISO(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE0_PUPSCR_SW2ISO) & BM_GPC_PGC_A7CORE0_PUPSCR_SW2ISO)

/*! @brief Set the SW2ISO field to a new value. */
#define BW_GPC_PGC_A7CORE0_PUPSCR_SW2ISO(x, v) (HW_GPC_PGC_A7CORE0_PUPSCR_WR(x, (HW_GPC_PGC_A7CORE0_PUPSCR_RD(x) & ~BM_GPC_PGC_A7CORE0_PUPSCR_SW2ISO) | BF_GPC_PGC_A7CORE0_PUPSCR_SW2ISO(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE0_PUPSCR, field PUP_SCALL_SCALLOUT_CNT[31:23] (RW)
 *
 * After SCALL asserting to 1'b0, count this value to complete switch power up
 * Only valid when pup_wait_scall_out is set to 1'b0. Can't be programmed to zero
 * (This register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT (23U) /*!< Bit position for GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */
#define BM_GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT (0xFF800000U) /*!< Bit mask for GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */
#define BS_GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT (9U) /*!< Bit field size in bits for GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */

/*! @brief Read current value of the GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT field. */
#define BR_GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT(x) (HW_GPC_PGC_A7CORE0_PUPSCR(x).B.PUP_SCALL_SCALLOUT_CNT)

/*! @brief Format value for bitfield GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */
#define BF_GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT) & BM_GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT)

/*! @brief Set the PUP_SCALL_SCALLOUT_CNT field to a new value. */
#define BW_GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT(x, v) (HW_GPC_PGC_A7CORE0_PUPSCR_WR(x, (HW_GPC_PGC_A7CORE0_PUPSCR_RD(x) & ~BM_GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT) | BF_GPC_PGC_A7CORE0_PUPSCR_PUP_SCALL_SCALLOUT_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_A7CORE0_PDNSCR - GPC PGC Down Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_A7CORE0_PDNSCR - GPC PGC Down Sequence Control Register (RW)
 *
 * Reset value: 0x21000801U
 *
 * GPC PGC Down Sequence Control Register
 */
typedef union _hw_gpc_pgc_a7core0_pdnscr
{
    uint32_t U;
    struct _hw_gpc_pgc_a7core0_pdnscr_bitfields
    {
        uint32_t ISO : 6;              /*!< [5:0]  */
        uint32_t RESERVED0 : 1;        /*!< [6]  */
        uint32_t PDN_WAIT_SCALL_OUT : 1; /*!< [7] Default 1'b0 */
        uint32_t ISO2SW : 6;           /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t PDN_SCALL_SCALLOUT_CNT : 8; /*!< [23:16]  */
        uint32_t PUP_SCPRE_SCALL_CNT : 8; /*!< [31:24]  */
    } B;
} hw_gpc_pgc_a7core0_pdnscr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_A7CORE0_PDNSCR register
 */
/*@{*/
#define HW_GPC_PGC_A7CORE0_PDNSCR_ADDR(x) ((uintptr_t)(x) + 0x8U)

#define HW_GPC_PGC_A7CORE0_PDNSCR(x) (*(__IO hw_gpc_pgc_a7core0_pdnscr_t *) HW_GPC_PGC_A7CORE0_PDNSCR_ADDR(x))
#define HW_GPC_PGC_A7CORE0_PDNSCR_RD(x) (HW_GPC_PGC_A7CORE0_PDNSCR(x).U)
#define HW_GPC_PGC_A7CORE0_PDNSCR_WR(x, v) (HW_GPC_PGC_A7CORE0_PDNSCR(x).U = (v))
#define HW_GPC_PGC_A7CORE0_PDNSCR_SET(x, v) (HW_GPC_PGC_A7CORE0_PDNSCR_WR(x, HW_GPC_PGC_A7CORE0_PDNSCR_RD(x) |  (v)))
#define HW_GPC_PGC_A7CORE0_PDNSCR_CLR(x, v) (HW_GPC_PGC_A7CORE0_PDNSCR_WR(x, HW_GPC_PGC_A7CORE0_PDNSCR_RD(x) & ~(v)))
#define HW_GPC_PGC_A7CORE0_PDNSCR_TOG(x, v) (HW_GPC_PGC_A7CORE0_PDNSCR_WR(x, HW_GPC_PGC_A7CORE0_PDNSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_A7CORE0_PDNSCR bitfields
 */

/*!
 * @name Register GPC_PGC_A7CORE0_PDNSCR, field ISO[5:0] (RW)
 *
 * Aafte a power-down request (pdn_req assertion), the PGC waits a number of
 * clocks equal to the value of ISO before asserting isolation ISO must not be
 * programmed to zero.
 */
/*@{*/
#define BP_GPC_PGC_A7CORE0_PDNSCR_ISO (0U) /*!< Bit position for GPC_PGC_A7CORE0_PDNSCR_ISO. */
#define BM_GPC_PGC_A7CORE0_PDNSCR_ISO (0x0000003FU) /*!< Bit mask for GPC_PGC_A7CORE0_PDNSCR_ISO. */
#define BS_GPC_PGC_A7CORE0_PDNSCR_ISO (6U) /*!< Bit field size in bits for GPC_PGC_A7CORE0_PDNSCR_ISO. */

/*! @brief Read current value of the GPC_PGC_A7CORE0_PDNSCR_ISO field. */
#define BR_GPC_PGC_A7CORE0_PDNSCR_ISO(x) (HW_GPC_PGC_A7CORE0_PDNSCR(x).B.ISO)

/*! @brief Format value for bitfield GPC_PGC_A7CORE0_PDNSCR_ISO. */
#define BF_GPC_PGC_A7CORE0_PDNSCR_ISO(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE0_PDNSCR_ISO) & BM_GPC_PGC_A7CORE0_PDNSCR_ISO)

/*! @brief Set the ISO field to a new value. */
#define BW_GPC_PGC_A7CORE0_PDNSCR_ISO(x, v) (HW_GPC_PGC_A7CORE0_PDNSCR_WR(x, (HW_GPC_PGC_A7CORE0_PDNSCR_RD(x) & ~BM_GPC_PGC_A7CORE0_PDNSCR_ISO) | BF_GPC_PGC_A7CORE0_PDNSCR_ISO(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE0_PDNSCR, field PDN_WAIT_SCALL_OUT[7] (RW)
 *
 * If set to 1'b1, after SCALL asserting to 1'b1, wait handshake signal
 * SCALL_OUT to change to 1'b1. This register control is only for MIX Type PGC.
 */
/*@{*/
#define BP_GPC_PGC_A7CORE0_PDNSCR_PDN_WAIT_SCALL_OUT (7U) /*!< Bit position for GPC_PGC_A7CORE0_PDNSCR_PDN_WAIT_SCALL_OUT. */
#define BM_GPC_PGC_A7CORE0_PDNSCR_PDN_WAIT_SCALL_OUT (0x00000080U) /*!< Bit mask for GPC_PGC_A7CORE0_PDNSCR_PDN_WAIT_SCALL_OUT. */
#define BS_GPC_PGC_A7CORE0_PDNSCR_PDN_WAIT_SCALL_OUT (1U) /*!< Bit field size in bits for GPC_PGC_A7CORE0_PDNSCR_PDN_WAIT_SCALL_OUT. */

/*! @brief Read current value of the GPC_PGC_A7CORE0_PDNSCR_PDN_WAIT_SCALL_OUT field. */
#define BR_GPC_PGC_A7CORE0_PDNSCR_PDN_WAIT_SCALL_OUT(x) (HW_GPC_PGC_A7CORE0_PDNSCR(x).B.PDN_WAIT_SCALL_OUT)

/*! @brief Format value for bitfield GPC_PGC_A7CORE0_PDNSCR_PDN_WAIT_SCALL_OUT. */
#define BF_GPC_PGC_A7CORE0_PDNSCR_PDN_WAIT_SCALL_OUT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE0_PDNSCR_PDN_WAIT_SCALL_OUT) & BM_GPC_PGC_A7CORE0_PDNSCR_PDN_WAIT_SCALL_OUT)

/*! @brief Set the PDN_WAIT_SCALL_OUT field to a new value. */
#define BW_GPC_PGC_A7CORE0_PDNSCR_PDN_WAIT_SCALL_OUT(x, v) (HW_GPC_PGC_A7CORE0_PDNSCR_WR(x, (HW_GPC_PGC_A7CORE0_PDNSCR_RD(x) & ~BM_GPC_PGC_A7CORE0_PDNSCR_PDN_WAIT_SCALL_OUT) | BF_GPC_PGC_A7CORE0_PDNSCR_PDN_WAIT_SCALL_OUT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE0_PDNSCR, field ISO2SW[13:8] (RW)
 *
 * After asserting isolation(by pdn_req assertion), the PGC waits a number of
 * clocks equal to the value of ISO2SW before negating switch_b ISO2SW must not be
 * programmed to zero.
 */
/*@{*/
#define BP_GPC_PGC_A7CORE0_PDNSCR_ISO2SW (8U) /*!< Bit position for GPC_PGC_A7CORE0_PDNSCR_ISO2SW. */
#define BM_GPC_PGC_A7CORE0_PDNSCR_ISO2SW (0x00003F00U) /*!< Bit mask for GPC_PGC_A7CORE0_PDNSCR_ISO2SW. */
#define BS_GPC_PGC_A7CORE0_PDNSCR_ISO2SW (6U) /*!< Bit field size in bits for GPC_PGC_A7CORE0_PDNSCR_ISO2SW. */

/*! @brief Read current value of the GPC_PGC_A7CORE0_PDNSCR_ISO2SW field. */
#define BR_GPC_PGC_A7CORE0_PDNSCR_ISO2SW(x) (HW_GPC_PGC_A7CORE0_PDNSCR(x).B.ISO2SW)

/*! @brief Format value for bitfield GPC_PGC_A7CORE0_PDNSCR_ISO2SW. */
#define BF_GPC_PGC_A7CORE0_PDNSCR_ISO2SW(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE0_PDNSCR_ISO2SW) & BM_GPC_PGC_A7CORE0_PDNSCR_ISO2SW)

/*! @brief Set the ISO2SW field to a new value. */
#define BW_GPC_PGC_A7CORE0_PDNSCR_ISO2SW(x, v) (HW_GPC_PGC_A7CORE0_PDNSCR_WR(x, (HW_GPC_PGC_A7CORE0_PDNSCR_RD(x) & ~BM_GPC_PGC_A7CORE0_PDNSCR_ISO2SW) | BF_GPC_PGC_A7CORE0_PDNSCR_ISO2SW(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE0_PDNSCR, field PDN_SCALL_SCALLOUT_CNT[23:16] (RW)
 *
 * Default 8'h0. After SCALL asserting to 1'b1, count this value to complete
 * switch power down. This control is only valid when pdn_wait_scall_out is set to
 * 1'b0. It can be programmed to zero. (This register control only for MIX Type
 * PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT (16U) /*!< Bit position for GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */
#define BM_GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT (0x00FF0000U) /*!< Bit mask for GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */
#define BS_GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT (8U) /*!< Bit field size in bits for GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */

/*! @brief Read current value of the GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT field. */
#define BR_GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT(x) (HW_GPC_PGC_A7CORE0_PDNSCR(x).B.PDN_SCALL_SCALLOUT_CNT)

/*! @brief Format value for bitfield GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */
#define BF_GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT) & BM_GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT)

/*! @brief Set the PDN_SCALL_SCALLOUT_CNT field to a new value. */
#define BW_GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT(x, v) (HW_GPC_PGC_A7CORE0_PDNSCR_WR(x, (HW_GPC_PGC_A7CORE0_PDNSCR_RD(x) & ~BM_GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT) | BF_GPC_PGC_A7CORE0_PDNSCR_PDN_SCALL_SCALLOUT_CNT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE0_PDNSCR, field PUP_SCPRE_SCALL_CNT[31:24] (RW)
 *
 * After SCPRE asserting to 1'b0, count this value to assert SCALL to 1'b0 (This
 * register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT (24U) /*!< Bit position for GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BM_GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT (0xFF000000U) /*!< Bit mask for GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BS_GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT (8U) /*!< Bit field size in bits for GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT. */

/*! @brief Read current value of the GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT field. */
#define BR_GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT(x) (HW_GPC_PGC_A7CORE0_PDNSCR(x).B.PUP_SCPRE_SCALL_CNT)

/*! @brief Format value for bitfield GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BF_GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT) & BM_GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT)

/*! @brief Set the PUP_SCPRE_SCALL_CNT field to a new value. */
#define BW_GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT(x, v) (HW_GPC_PGC_A7CORE0_PDNSCR_WR(x, (HW_GPC_PGC_A7CORE0_PDNSCR_RD(x) & ~BM_GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT) | BF_GPC_PGC_A7CORE0_PDNSCR_PUP_SCPRE_SCALL_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_A7CORE0_SR - GPC PGC Status Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_A7CORE0_SR - GPC PGC Status Register (RW)
 *
 * Reset value: 0x00001000U
 *
 * GPC PGC Status Register
 */
typedef union _hw_gpc_pgc_a7core0_sr
{
    uint32_t U;
    struct _hw_gpc_pgc_a7core0_sr_bitfields
    {
        uint32_t PSR : 1;              /*!< [0]  */
        uint32_t L2RETN_FLAG : 1;      /*!< [1]  */
        uint32_t ALLOFF_FLAG : 1;      /*!< [2]  */
        uint32_t PUP_CLK_DIV_SEL : 4;  /*!< [6:3]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t L2RSTDIS_DEASSERT_CNT : 10; /*!< [17:8]  */
        uint32_t RESERVED1 : 14;       /*!< [31:18]  */
    } B;
} hw_gpc_pgc_a7core0_sr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_A7CORE0_SR register
 */
/*@{*/
#define HW_GPC_PGC_A7CORE0_SR_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_GPC_PGC_A7CORE0_SR(x) (*(__IO hw_gpc_pgc_a7core0_sr_t *) HW_GPC_PGC_A7CORE0_SR_ADDR(x))
#define HW_GPC_PGC_A7CORE0_SR_RD(x) (HW_GPC_PGC_A7CORE0_SR(x).U)
#define HW_GPC_PGC_A7CORE0_SR_WR(x, v) (HW_GPC_PGC_A7CORE0_SR(x).U = (v))
#define HW_GPC_PGC_A7CORE0_SR_SET(x, v) (HW_GPC_PGC_A7CORE0_SR_WR(x, HW_GPC_PGC_A7CORE0_SR_RD(x) |  (v)))
#define HW_GPC_PGC_A7CORE0_SR_CLR(x, v) (HW_GPC_PGC_A7CORE0_SR_WR(x, HW_GPC_PGC_A7CORE0_SR_RD(x) & ~(v)))
#define HW_GPC_PGC_A7CORE0_SR_TOG(x, v) (HW_GPC_PGC_A7CORE0_SR_WR(x, HW_GPC_PGC_A7CORE0_SR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_A7CORE0_SR bitfields
 */

/*!
 * @name Register GPC_PGC_A7CORE0_SR, field PSR[0] (RO)
 *
 * Power status. When in functional (or software-controlled debug) mode, PGC
 * hardware sets PSR as soon as any of the power control output changes its state to
 * one. Write one to clear this bit. Software should clear this bit after power
 * up; otherwise, PSR continues to reflect the power status of the initial power
 * down.
 *
 * Values:
 * - 0 - The target subsystem was not powered down for the previous power-down
 *     request.
 * - 1 - The target subsystem was powered down for the previous power-down
 *     request.
 */
/*@{*/
#define BP_GPC_PGC_A7CORE0_SR_PSR (0U)     /*!< Bit position for GPC_PGC_A7CORE0_SR_PSR. */
#define BM_GPC_PGC_A7CORE0_SR_PSR (0x00000001U) /*!< Bit mask for GPC_PGC_A7CORE0_SR_PSR. */
#define BS_GPC_PGC_A7CORE0_SR_PSR (1U)     /*!< Bit field size in bits for GPC_PGC_A7CORE0_SR_PSR. */

/*! @brief Read current value of the GPC_PGC_A7CORE0_SR_PSR field. */
#define BR_GPC_PGC_A7CORE0_SR_PSR(x) (HW_GPC_PGC_A7CORE0_SR(x).B.PSR)
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE0_SR, field L2RETN_FLAG[1] (RO)
 *
 * L2 Retention Flag Software should write "1" to clear this flag after A7 is
 * wakeup from L2 retention mode, otherwise it will always keep to 1 (This register
 * control only for SCU Type PGC)
 *
 * Values:
 * - 0 - A7 is not wakeup from L2 retention mode.
 * - 1 - A7 is wakeup from L2 retention mode.
 */
/*@{*/
#define BP_GPC_PGC_A7CORE0_SR_L2RETN_FLAG (1U) /*!< Bit position for GPC_PGC_A7CORE0_SR_L2RETN_FLAG. */
#define BM_GPC_PGC_A7CORE0_SR_L2RETN_FLAG (0x00000002U) /*!< Bit mask for GPC_PGC_A7CORE0_SR_L2RETN_FLAG. */
#define BS_GPC_PGC_A7CORE0_SR_L2RETN_FLAG (1U) /*!< Bit field size in bits for GPC_PGC_A7CORE0_SR_L2RETN_FLAG. */

/*! @brief Read current value of the GPC_PGC_A7CORE0_SR_L2RETN_FLAG field. */
#define BR_GPC_PGC_A7CORE0_SR_L2RETN_FLAG(x) (HW_GPC_PGC_A7CORE0_SR(x).B.L2RETN_FLAG)
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE0_SR, field ALLOFF_FLAG[2] (RO)
 *
 * All-off flag. Software should write "1" to clear this flag after A7 is wakeup
 * from ALL_OFF mode, otherwise, it will always keep to 1 (This register control
 * only for SCU Type PGC)
 *
 * Values:
 * - 0 - A7 is not wakeup from ALL_OFF mode.
 * - 1 - A7 is wakeup from ALL_OFF mode.
 */
/*@{*/
#define BP_GPC_PGC_A7CORE0_SR_ALLOFF_FLAG (2U) /*!< Bit position for GPC_PGC_A7CORE0_SR_ALLOFF_FLAG. */
#define BM_GPC_PGC_A7CORE0_SR_ALLOFF_FLAG (0x00000004U) /*!< Bit mask for GPC_PGC_A7CORE0_SR_ALLOFF_FLAG. */
#define BS_GPC_PGC_A7CORE0_SR_ALLOFF_FLAG (1U) /*!< Bit field size in bits for GPC_PGC_A7CORE0_SR_ALLOFF_FLAG. */

/*! @brief Read current value of the GPC_PGC_A7CORE0_SR_ALLOFF_FLAG field. */
#define BR_GPC_PGC_A7CORE0_SR_ALLOFF_FLAG(x) (HW_GPC_PGC_A7CORE0_SR(x).B.ALLOFF_FLAG)
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE0_SR, field PUP_CLK_DIV_SEL[6:3] (RW)
 *
 * Clock divider select for the clock of power up counter(count_clk is 32KHz for
 * CPU/SCU type PGC, ipg_clk(66MHz) for MIX/PU Type PGC)
 *
 * Values:
 * - 0000 - 1
 * - 0001 - 1/2 count_clk
 * - 0010 - 1/4 count_clk
 * - 0011 - 1/8 count_clk
 * - 0100 - 1/16 count_clk
 * - 0101 - 1/32 count_clk
 * - 0110 - 1/64 count_clk
 * - 0111 - 1/128 count_clk
 * - 1000 - 1/256 count_clk
 * - 1001 - 1/512 count_clk
 * - 1010 - 1/1024 count_clk
 * - 1011 - 1/2056 count_clk
 * - 1100 - 1/4096 count_clk
 * - 1101 - 1/8192 count_clk
 * - 1110 - 1/16384 count_clk
 * - 1111 - 1/32768 count_clk
 */
/*@{*/
#define BP_GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL (3U) /*!< Bit position for GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL. */
#define BM_GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL (0x00000078U) /*!< Bit mask for GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL. */
#define BS_GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL (4U) /*!< Bit field size in bits for GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL. */

/*! @brief Read current value of the GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL field. */
#define BR_GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL(x) (HW_GPC_PGC_A7CORE0_SR(x).B.PUP_CLK_DIV_SEL)

/*! @brief Format value for bitfield GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL. */
#define BF_GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL) & BM_GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL)

/*! @brief Set the PUP_CLK_DIV_SEL field to a new value. */
#define BW_GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL(x, v) (HW_GPC_PGC_A7CORE0_SR_WR(x, (HW_GPC_PGC_A7CORE0_SR_RD(x) & ~BM_GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL) | BF_GPC_PGC_A7CORE0_SR_PUP_CLK_DIV_SEL(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE0_SR, field L2RSTDIS_DEASSERT_CNT[17:8] (RW)
 *
 * Count this value to de-assert L2RSTDISABLE to LOW after CPU0 or CPU1 power up
 * This value can't be programmed to zero (This register control only for SCU
 * Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT (8U) /*!< Bit position for GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT. */
#define BM_GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT (0x0003FF00U) /*!< Bit mask for GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT. */
#define BS_GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT (10U) /*!< Bit field size in bits for GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT. */

/*! @brief Read current value of the GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT field. */
#define BR_GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT(x) (HW_GPC_PGC_A7CORE0_SR(x).B.L2RSTDIS_DEASSERT_CNT)

/*! @brief Format value for bitfield GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT. */
#define BF_GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT) & BM_GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT)

/*! @brief Set the L2RSTDIS_DEASSERT_CNT field to a new value. */
#define BW_GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT(x, v) (HW_GPC_PGC_A7CORE0_SR_WR(x, (HW_GPC_PGC_A7CORE0_SR_RD(x) & ~BM_GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT) | BF_GPC_PGC_A7CORE0_SR_L2RSTDIS_DEASSERT_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_A7CORE1_CTRL - GPC PGC Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_A7CORE1_CTRL - GPC PGC Control Register (RW)
 *
 * Reset value: 0x06040202U
 *
 * GPC PGC Control Register
 */
typedef union _hw_gpc_pgc_a7core1_ctrl
{
    uint32_t U;
    struct _hw_gpc_pgc_a7core1_ctrl_bitfields
    {
        uint32_t PCR : 1;              /*!< [0]  */
        uint32_t L2RSTDIS : 6;         /*!< [6:1]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t DFTRAM_TCD1 : 6;      /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t L2RETN_TCD1_TDR : 6;  /*!< [21:16]  */
        uint32_t RESERVED2 : 2;        /*!< [23:22]  */
        uint32_t MEMPWR_TCD1_TDR_TRM : 6; /*!< [29:24]  */
        uint32_t RESERVED3 : 2;        /*!< [31:30]  */
    } B;
} hw_gpc_pgc_a7core1_ctrl_t;

/*!
 * @name Constants and macros for entire GPC_PGC_A7CORE1_CTRL register
 */
/*@{*/
#define HW_GPC_PGC_A7CORE1_CTRL_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_GPC_PGC_A7CORE1_CTRL(x) (*(__IO hw_gpc_pgc_a7core1_ctrl_t *) HW_GPC_PGC_A7CORE1_CTRL_ADDR(x))
#define HW_GPC_PGC_A7CORE1_CTRL_RD(x) (HW_GPC_PGC_A7CORE1_CTRL(x).U)
#define HW_GPC_PGC_A7CORE1_CTRL_WR(x, v) (HW_GPC_PGC_A7CORE1_CTRL(x).U = (v))
#define HW_GPC_PGC_A7CORE1_CTRL_SET(x, v) (HW_GPC_PGC_A7CORE1_CTRL_WR(x, HW_GPC_PGC_A7CORE1_CTRL_RD(x) |  (v)))
#define HW_GPC_PGC_A7CORE1_CTRL_CLR(x, v) (HW_GPC_PGC_A7CORE1_CTRL_WR(x, HW_GPC_PGC_A7CORE1_CTRL_RD(x) & ~(v)))
#define HW_GPC_PGC_A7CORE1_CTRL_TOG(x, v) (HW_GPC_PGC_A7CORE1_CTRL_WR(x, HW_GPC_PGC_A7CORE1_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_A7CORE1_CTRL bitfields
 */

/*!
 * @name Register GPC_PGC_A7CORE1_CTRL, field PCR[0] (RW)
 *
 * Power ControlPCR must not change from power-down request (pdn_req) assertion
 * until the target subsystem is completely powered up.
 *
 * Values:
 * - 0 - Do not switch off power even if pdn_req is asserted.
 * - 1 - Switch off power when pdn_req is asserted.
 */
/*@{*/
#define BP_GPC_PGC_A7CORE1_CTRL_PCR (0U)   /*!< Bit position for GPC_PGC_A7CORE1_CTRL_PCR. */
#define BM_GPC_PGC_A7CORE1_CTRL_PCR (0x00000001U) /*!< Bit mask for GPC_PGC_A7CORE1_CTRL_PCR. */
#define BS_GPC_PGC_A7CORE1_CTRL_PCR (1U)   /*!< Bit field size in bits for GPC_PGC_A7CORE1_CTRL_PCR. */

/*! @brief Read current value of the GPC_PGC_A7CORE1_CTRL_PCR field. */
#define BR_GPC_PGC_A7CORE1_CTRL_PCR(x) (HW_GPC_PGC_A7CORE1_CTRL(x).B.PCR)

/*! @brief Format value for bitfield GPC_PGC_A7CORE1_CTRL_PCR. */
#define BF_GPC_PGC_A7CORE1_CTRL_PCR(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE1_CTRL_PCR) & BM_GPC_PGC_A7CORE1_CTRL_PCR)

/*! @brief Set the PCR field to a new value. */
#define BW_GPC_PGC_A7CORE1_CTRL_PCR(x, v) (HW_GPC_PGC_A7CORE1_CTRL_WR(x, (HW_GPC_PGC_A7CORE1_CTRL_RD(x) & ~BM_GPC_PGC_A7CORE1_CTRL_PCR) | BF_GPC_PGC_A7CORE1_CTRL_PCR(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE1_CTRL, field L2RSTDIS[6:1] (RW)
 *
 * After scu pdn_req, count this value to assert A7 l2rstdis to 1'b1, it will be
 * clear automatically once any of A7 core0/core1 is wakeup Can't be programmed
 * to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7CORE1_CTRL_L2RSTDIS (1U) /*!< Bit position for GPC_PGC_A7CORE1_CTRL_L2RSTDIS. */
#define BM_GPC_PGC_A7CORE1_CTRL_L2RSTDIS (0x0000007EU) /*!< Bit mask for GPC_PGC_A7CORE1_CTRL_L2RSTDIS. */
#define BS_GPC_PGC_A7CORE1_CTRL_L2RSTDIS (6U) /*!< Bit field size in bits for GPC_PGC_A7CORE1_CTRL_L2RSTDIS. */

/*! @brief Read current value of the GPC_PGC_A7CORE1_CTRL_L2RSTDIS field. */
#define BR_GPC_PGC_A7CORE1_CTRL_L2RSTDIS(x) (HW_GPC_PGC_A7CORE1_CTRL(x).B.L2RSTDIS)

/*! @brief Format value for bitfield GPC_PGC_A7CORE1_CTRL_L2RSTDIS. */
#define BF_GPC_PGC_A7CORE1_CTRL_L2RSTDIS(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE1_CTRL_L2RSTDIS) & BM_GPC_PGC_A7CORE1_CTRL_L2RSTDIS)

/*! @brief Set the L2RSTDIS field to a new value. */
#define BW_GPC_PGC_A7CORE1_CTRL_L2RSTDIS(x, v) (HW_GPC_PGC_A7CORE1_CTRL_WR(x, (HW_GPC_PGC_A7CORE1_CTRL_RD(x) & ~BM_GPC_PGC_A7CORE1_CTRL_L2RSTDIS) | BF_GPC_PGC_A7CORE1_CTRL_L2RSTDIS(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE1_CTRL, field DFTRAM_TCD1[13:8] (RW)
 *
 * After scu pdn_req, count this value to assert A7 dftram to 1'b1 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1 (8U) /*!< Bit position for GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1. */
#define BM_GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1 (0x00003F00U) /*!< Bit mask for GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1. */
#define BS_GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1 (6U) /*!< Bit field size in bits for GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1. */

/*! @brief Read current value of the GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1 field. */
#define BR_GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1(x) (HW_GPC_PGC_A7CORE1_CTRL(x).B.DFTRAM_TCD1)

/*! @brief Format value for bitfield GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1. */
#define BF_GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1) & BM_GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1)

/*! @brief Set the DFTRAM_TCD1 field to a new value. */
#define BW_GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1(x, v) (HW_GPC_PGC_A7CORE1_CTRL_WR(x, (HW_GPC_PGC_A7CORE1_CTRL_RD(x) & ~BM_GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1) | BF_GPC_PGC_A7CORE1_CTRL_DFTRAM_TCD1(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE1_CTRL, field L2RETN_TCD1_TDR[21:16] (RW)
 *
 * After scu pdn_req, count this value to assert A7 l2retn to 1'b0 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR (16U) /*!< Bit position for GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR. */
#define BM_GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR (0x003F0000U) /*!< Bit mask for GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR. */
#define BS_GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR (6U) /*!< Bit field size in bits for GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR. */

/*! @brief Read current value of the GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR field. */
#define BR_GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR(x) (HW_GPC_PGC_A7CORE1_CTRL(x).B.L2RETN_TCD1_TDR)

/*! @brief Format value for bitfield GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR. */
#define BF_GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR) & BM_GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR)

/*! @brief Set the L2RETN_TCD1_TDR field to a new value. */
#define BW_GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR(x, v) (HW_GPC_PGC_A7CORE1_CTRL_WR(x, (HW_GPC_PGC_A7CORE1_CTRL_RD(x) & ~BM_GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR) | BF_GPC_PGC_A7CORE1_CTRL_L2RETN_TCD1_TDR(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE1_CTRL, field MEMPWR_TCD1_TDR_TRM[29:24] (RW)
 *
 * After scu pdn_req, count this value to assert A7 mempwr to 1'b1 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM (24U) /*!< Bit position for GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BM_GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM (0x3F000000U) /*!< Bit mask for GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BS_GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM (6U) /*!< Bit field size in bits for GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM. */

/*! @brief Read current value of the GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM field. */
#define BR_GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM(x) (HW_GPC_PGC_A7CORE1_CTRL(x).B.MEMPWR_TCD1_TDR_TRM)

/*! @brief Format value for bitfield GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BF_GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM) & BM_GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM)

/*! @brief Set the MEMPWR_TCD1_TDR_TRM field to a new value. */
#define BW_GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM(x, v) (HW_GPC_PGC_A7CORE1_CTRL_WR(x, (HW_GPC_PGC_A7CORE1_CTRL_RD(x) & ~BM_GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM) | BF_GPC_PGC_A7CORE1_CTRL_MEMPWR_TCD1_TDR_TRM(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_A7CORE1_PUPSCR - GPC PGC Up Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_A7CORE1_PUPSCR - GPC PGC Up Sequence Control Register (RW)
 *
 * Reset value: 0x000997C1U
 *
 * GPC PGC Up Sequence Control Register
 */
typedef union _hw_gpc_pgc_a7core1_pupscr
{
    uint32_t U;
    struct _hw_gpc_pgc_a7core1_pupscr_bitfields
    {
        uint32_t SW : 6;               /*!< [5:0]  */
        uint32_t PUP_WAIT_SCALL_OUT : 1; /*!< [6]  */
        uint32_t SW2ISO : 16;          /*!< [22:7]  */
        uint32_t PUP_SCALL_SCALLOUT_CNT : 9; /*!< [31:23]  */
    } B;
} hw_gpc_pgc_a7core1_pupscr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_A7CORE1_PUPSCR register
 */
/*@{*/
#define HW_GPC_PGC_A7CORE1_PUPSCR_ADDR(x) ((uintptr_t)(x) + 0x44U)

#define HW_GPC_PGC_A7CORE1_PUPSCR(x) (*(__IO hw_gpc_pgc_a7core1_pupscr_t *) HW_GPC_PGC_A7CORE1_PUPSCR_ADDR(x))
#define HW_GPC_PGC_A7CORE1_PUPSCR_RD(x) (HW_GPC_PGC_A7CORE1_PUPSCR(x).U)
#define HW_GPC_PGC_A7CORE1_PUPSCR_WR(x, v) (HW_GPC_PGC_A7CORE1_PUPSCR(x).U = (v))
#define HW_GPC_PGC_A7CORE1_PUPSCR_SET(x, v) (HW_GPC_PGC_A7CORE1_PUPSCR_WR(x, HW_GPC_PGC_A7CORE1_PUPSCR_RD(x) |  (v)))
#define HW_GPC_PGC_A7CORE1_PUPSCR_CLR(x, v) (HW_GPC_PGC_A7CORE1_PUPSCR_WR(x, HW_GPC_PGC_A7CORE1_PUPSCR_RD(x) & ~(v)))
#define HW_GPC_PGC_A7CORE1_PUPSCR_TOG(x, v) (HW_GPC_PGC_A7CORE1_PUPSCR_WR(x, HW_GPC_PGC_A7CORE1_PUPSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_A7CORE1_PUPSCR bitfields
 */

/*!
 * @name Register GPC_PGC_A7CORE1_PUPSCR, field SW[5:0] (RW)
 *
 * After a power-up request (pup_req assertion), the PGC waits a number of
 * clocks equal to the value of SW before asserting switch_b SW must not be programmed
 * to zero.
 */
/*@{*/
#define BP_GPC_PGC_A7CORE1_PUPSCR_SW (0U)  /*!< Bit position for GPC_PGC_A7CORE1_PUPSCR_SW. */
#define BM_GPC_PGC_A7CORE1_PUPSCR_SW (0x0000003FU) /*!< Bit mask for GPC_PGC_A7CORE1_PUPSCR_SW. */
#define BS_GPC_PGC_A7CORE1_PUPSCR_SW (6U)  /*!< Bit field size in bits for GPC_PGC_A7CORE1_PUPSCR_SW. */

/*! @brief Read current value of the GPC_PGC_A7CORE1_PUPSCR_SW field. */
#define BR_GPC_PGC_A7CORE1_PUPSCR_SW(x) (HW_GPC_PGC_A7CORE1_PUPSCR(x).B.SW)

/*! @brief Format value for bitfield GPC_PGC_A7CORE1_PUPSCR_SW. */
#define BF_GPC_PGC_A7CORE1_PUPSCR_SW(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE1_PUPSCR_SW) & BM_GPC_PGC_A7CORE1_PUPSCR_SW)

/*! @brief Set the SW field to a new value. */
#define BW_GPC_PGC_A7CORE1_PUPSCR_SW(x, v) (HW_GPC_PGC_A7CORE1_PUPSCR_WR(x, (HW_GPC_PGC_A7CORE1_PUPSCR_RD(x) & ~BM_GPC_PGC_A7CORE1_PUPSCR_SW) | BF_GPC_PGC_A7CORE1_PUPSCR_SW(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE1_PUPSCR, field PUP_WAIT_SCALL_OUT[6] (RW)
 *
 * After SCALL asserting to 1'b0, wait handshake signal SCALL_OUT to return to
 * 1'b0 (This register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7CORE1_PUPSCR_PUP_WAIT_SCALL_OUT (6U) /*!< Bit position for GPC_PGC_A7CORE1_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BM_GPC_PGC_A7CORE1_PUPSCR_PUP_WAIT_SCALL_OUT (0x00000040U) /*!< Bit mask for GPC_PGC_A7CORE1_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BS_GPC_PGC_A7CORE1_PUPSCR_PUP_WAIT_SCALL_OUT (1U) /*!< Bit field size in bits for GPC_PGC_A7CORE1_PUPSCR_PUP_WAIT_SCALL_OUT. */

/*! @brief Read current value of the GPC_PGC_A7CORE1_PUPSCR_PUP_WAIT_SCALL_OUT field. */
#define BR_GPC_PGC_A7CORE1_PUPSCR_PUP_WAIT_SCALL_OUT(x) (HW_GPC_PGC_A7CORE1_PUPSCR(x).B.PUP_WAIT_SCALL_OUT)

/*! @brief Format value for bitfield GPC_PGC_A7CORE1_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BF_GPC_PGC_A7CORE1_PUPSCR_PUP_WAIT_SCALL_OUT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE1_PUPSCR_PUP_WAIT_SCALL_OUT) & BM_GPC_PGC_A7CORE1_PUPSCR_PUP_WAIT_SCALL_OUT)

/*! @brief Set the PUP_WAIT_SCALL_OUT field to a new value. */
#define BW_GPC_PGC_A7CORE1_PUPSCR_PUP_WAIT_SCALL_OUT(x, v) (HW_GPC_PGC_A7CORE1_PUPSCR_WR(x, (HW_GPC_PGC_A7CORE1_PUPSCR_RD(x) & ~BM_GPC_PGC_A7CORE1_PUPSCR_PUP_WAIT_SCALL_OUT) | BF_GPC_PGC_A7CORE1_PUPSCR_PUP_WAIT_SCALL_OUT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE1_PUPSCR, field SW2ISO[22:7] (RW)
 *
 * After asserting switch_b, the PGC waits a number of clocks equal to the value
 * of SW2ISO before negating isolation.
 */
/*@{*/
#define BP_GPC_PGC_A7CORE1_PUPSCR_SW2ISO (7U) /*!< Bit position for GPC_PGC_A7CORE1_PUPSCR_SW2ISO. */
#define BM_GPC_PGC_A7CORE1_PUPSCR_SW2ISO (0x007FFF80U) /*!< Bit mask for GPC_PGC_A7CORE1_PUPSCR_SW2ISO. */
#define BS_GPC_PGC_A7CORE1_PUPSCR_SW2ISO (16U) /*!< Bit field size in bits for GPC_PGC_A7CORE1_PUPSCR_SW2ISO. */

/*! @brief Read current value of the GPC_PGC_A7CORE1_PUPSCR_SW2ISO field. */
#define BR_GPC_PGC_A7CORE1_PUPSCR_SW2ISO(x) (HW_GPC_PGC_A7CORE1_PUPSCR(x).B.SW2ISO)

/*! @brief Format value for bitfield GPC_PGC_A7CORE1_PUPSCR_SW2ISO. */
#define BF_GPC_PGC_A7CORE1_PUPSCR_SW2ISO(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE1_PUPSCR_SW2ISO) & BM_GPC_PGC_A7CORE1_PUPSCR_SW2ISO)

/*! @brief Set the SW2ISO field to a new value. */
#define BW_GPC_PGC_A7CORE1_PUPSCR_SW2ISO(x, v) (HW_GPC_PGC_A7CORE1_PUPSCR_WR(x, (HW_GPC_PGC_A7CORE1_PUPSCR_RD(x) & ~BM_GPC_PGC_A7CORE1_PUPSCR_SW2ISO) | BF_GPC_PGC_A7CORE1_PUPSCR_SW2ISO(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE1_PUPSCR, field PUP_SCALL_SCALLOUT_CNT[31:23] (RW)
 *
 * After SCALL asserting to 1'b0, count this value to complete switch power up
 * Only valid when pup_wait_scall_out is set to 1'b0. Can't be programmed to zero
 * (This register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT (23U) /*!< Bit position for GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */
#define BM_GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT (0xFF800000U) /*!< Bit mask for GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */
#define BS_GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT (9U) /*!< Bit field size in bits for GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */

/*! @brief Read current value of the GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT field. */
#define BR_GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT(x) (HW_GPC_PGC_A7CORE1_PUPSCR(x).B.PUP_SCALL_SCALLOUT_CNT)

/*! @brief Format value for bitfield GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */
#define BF_GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT) & BM_GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT)

/*! @brief Set the PUP_SCALL_SCALLOUT_CNT field to a new value. */
#define BW_GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT(x, v) (HW_GPC_PGC_A7CORE1_PUPSCR_WR(x, (HW_GPC_PGC_A7CORE1_PUPSCR_RD(x) & ~BM_GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT) | BF_GPC_PGC_A7CORE1_PUPSCR_PUP_SCALL_SCALLOUT_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_A7CORE1_PDNSCR - GPC PGC Down Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_A7CORE1_PDNSCR - GPC PGC Down Sequence Control Register (RW)
 *
 * Reset value: 0x21000801U
 *
 * GPC PGC Down Sequence Control Register
 */
typedef union _hw_gpc_pgc_a7core1_pdnscr
{
    uint32_t U;
    struct _hw_gpc_pgc_a7core1_pdnscr_bitfields
    {
        uint32_t ISO : 6;              /*!< [5:0]  */
        uint32_t RESERVED0 : 1;        /*!< [6]  */
        uint32_t PDN_WAIT_SCALL_OUT : 1; /*!< [7] Default 1'b0 */
        uint32_t ISO2SW : 6;           /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t PDN_SCALL_SCALLOUT_CNT : 8; /*!< [23:16]  */
        uint32_t PUP_SCPRE_SCALL_CNT : 8; /*!< [31:24]  */
    } B;
} hw_gpc_pgc_a7core1_pdnscr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_A7CORE1_PDNSCR register
 */
/*@{*/
#define HW_GPC_PGC_A7CORE1_PDNSCR_ADDR(x) ((uintptr_t)(x) + 0x48U)

#define HW_GPC_PGC_A7CORE1_PDNSCR(x) (*(__IO hw_gpc_pgc_a7core1_pdnscr_t *) HW_GPC_PGC_A7CORE1_PDNSCR_ADDR(x))
#define HW_GPC_PGC_A7CORE1_PDNSCR_RD(x) (HW_GPC_PGC_A7CORE1_PDNSCR(x).U)
#define HW_GPC_PGC_A7CORE1_PDNSCR_WR(x, v) (HW_GPC_PGC_A7CORE1_PDNSCR(x).U = (v))
#define HW_GPC_PGC_A7CORE1_PDNSCR_SET(x, v) (HW_GPC_PGC_A7CORE1_PDNSCR_WR(x, HW_GPC_PGC_A7CORE1_PDNSCR_RD(x) |  (v)))
#define HW_GPC_PGC_A7CORE1_PDNSCR_CLR(x, v) (HW_GPC_PGC_A7CORE1_PDNSCR_WR(x, HW_GPC_PGC_A7CORE1_PDNSCR_RD(x) & ~(v)))
#define HW_GPC_PGC_A7CORE1_PDNSCR_TOG(x, v) (HW_GPC_PGC_A7CORE1_PDNSCR_WR(x, HW_GPC_PGC_A7CORE1_PDNSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_A7CORE1_PDNSCR bitfields
 */

/*!
 * @name Register GPC_PGC_A7CORE1_PDNSCR, field ISO[5:0] (RW)
 *
 * Aafte a power-down request (pdn_req assertion), the PGC waits a number of
 * clocks equal to the value of ISO before asserting isolation ISO must not be
 * programmed to zero.
 */
/*@{*/
#define BP_GPC_PGC_A7CORE1_PDNSCR_ISO (0U) /*!< Bit position for GPC_PGC_A7CORE1_PDNSCR_ISO. */
#define BM_GPC_PGC_A7CORE1_PDNSCR_ISO (0x0000003FU) /*!< Bit mask for GPC_PGC_A7CORE1_PDNSCR_ISO. */
#define BS_GPC_PGC_A7CORE1_PDNSCR_ISO (6U) /*!< Bit field size in bits for GPC_PGC_A7CORE1_PDNSCR_ISO. */

/*! @brief Read current value of the GPC_PGC_A7CORE1_PDNSCR_ISO field. */
#define BR_GPC_PGC_A7CORE1_PDNSCR_ISO(x) (HW_GPC_PGC_A7CORE1_PDNSCR(x).B.ISO)

/*! @brief Format value for bitfield GPC_PGC_A7CORE1_PDNSCR_ISO. */
#define BF_GPC_PGC_A7CORE1_PDNSCR_ISO(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE1_PDNSCR_ISO) & BM_GPC_PGC_A7CORE1_PDNSCR_ISO)

/*! @brief Set the ISO field to a new value. */
#define BW_GPC_PGC_A7CORE1_PDNSCR_ISO(x, v) (HW_GPC_PGC_A7CORE1_PDNSCR_WR(x, (HW_GPC_PGC_A7CORE1_PDNSCR_RD(x) & ~BM_GPC_PGC_A7CORE1_PDNSCR_ISO) | BF_GPC_PGC_A7CORE1_PDNSCR_ISO(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE1_PDNSCR, field PDN_WAIT_SCALL_OUT[7] (RW)
 *
 * If set to 1'b1, after SCALL asserting to 1'b1, wait handshake signal
 * SCALL_OUT to change to 1'b1. This register control is only for MIX Type PGC.
 */
/*@{*/
#define BP_GPC_PGC_A7CORE1_PDNSCR_PDN_WAIT_SCALL_OUT (7U) /*!< Bit position for GPC_PGC_A7CORE1_PDNSCR_PDN_WAIT_SCALL_OUT. */
#define BM_GPC_PGC_A7CORE1_PDNSCR_PDN_WAIT_SCALL_OUT (0x00000080U) /*!< Bit mask for GPC_PGC_A7CORE1_PDNSCR_PDN_WAIT_SCALL_OUT. */
#define BS_GPC_PGC_A7CORE1_PDNSCR_PDN_WAIT_SCALL_OUT (1U) /*!< Bit field size in bits for GPC_PGC_A7CORE1_PDNSCR_PDN_WAIT_SCALL_OUT. */

/*! @brief Read current value of the GPC_PGC_A7CORE1_PDNSCR_PDN_WAIT_SCALL_OUT field. */
#define BR_GPC_PGC_A7CORE1_PDNSCR_PDN_WAIT_SCALL_OUT(x) (HW_GPC_PGC_A7CORE1_PDNSCR(x).B.PDN_WAIT_SCALL_OUT)

/*! @brief Format value for bitfield GPC_PGC_A7CORE1_PDNSCR_PDN_WAIT_SCALL_OUT. */
#define BF_GPC_PGC_A7CORE1_PDNSCR_PDN_WAIT_SCALL_OUT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE1_PDNSCR_PDN_WAIT_SCALL_OUT) & BM_GPC_PGC_A7CORE1_PDNSCR_PDN_WAIT_SCALL_OUT)

/*! @brief Set the PDN_WAIT_SCALL_OUT field to a new value. */
#define BW_GPC_PGC_A7CORE1_PDNSCR_PDN_WAIT_SCALL_OUT(x, v) (HW_GPC_PGC_A7CORE1_PDNSCR_WR(x, (HW_GPC_PGC_A7CORE1_PDNSCR_RD(x) & ~BM_GPC_PGC_A7CORE1_PDNSCR_PDN_WAIT_SCALL_OUT) | BF_GPC_PGC_A7CORE1_PDNSCR_PDN_WAIT_SCALL_OUT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE1_PDNSCR, field ISO2SW[13:8] (RW)
 *
 * After asserting isolation(by pdn_req assertion), the PGC waits a number of
 * clocks equal to the value of ISO2SW before negating switch_b ISO2SW must not be
 * programmed to zero.
 */
/*@{*/
#define BP_GPC_PGC_A7CORE1_PDNSCR_ISO2SW (8U) /*!< Bit position for GPC_PGC_A7CORE1_PDNSCR_ISO2SW. */
#define BM_GPC_PGC_A7CORE1_PDNSCR_ISO2SW (0x00003F00U) /*!< Bit mask for GPC_PGC_A7CORE1_PDNSCR_ISO2SW. */
#define BS_GPC_PGC_A7CORE1_PDNSCR_ISO2SW (6U) /*!< Bit field size in bits for GPC_PGC_A7CORE1_PDNSCR_ISO2SW. */

/*! @brief Read current value of the GPC_PGC_A7CORE1_PDNSCR_ISO2SW field. */
#define BR_GPC_PGC_A7CORE1_PDNSCR_ISO2SW(x) (HW_GPC_PGC_A7CORE1_PDNSCR(x).B.ISO2SW)

/*! @brief Format value for bitfield GPC_PGC_A7CORE1_PDNSCR_ISO2SW. */
#define BF_GPC_PGC_A7CORE1_PDNSCR_ISO2SW(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE1_PDNSCR_ISO2SW) & BM_GPC_PGC_A7CORE1_PDNSCR_ISO2SW)

/*! @brief Set the ISO2SW field to a new value. */
#define BW_GPC_PGC_A7CORE1_PDNSCR_ISO2SW(x, v) (HW_GPC_PGC_A7CORE1_PDNSCR_WR(x, (HW_GPC_PGC_A7CORE1_PDNSCR_RD(x) & ~BM_GPC_PGC_A7CORE1_PDNSCR_ISO2SW) | BF_GPC_PGC_A7CORE1_PDNSCR_ISO2SW(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE1_PDNSCR, field PDN_SCALL_SCALLOUT_CNT[23:16] (RW)
 *
 * Default 8'h0. After SCALL asserting to 1'b1, count this value to complete
 * switch power down. This control is only valid when pdn_wait_scall_out is set to
 * 1'b0. It can be programmed to zero. (This register control only for MIX Type
 * PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT (16U) /*!< Bit position for GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */
#define BM_GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT (0x00FF0000U) /*!< Bit mask for GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */
#define BS_GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT (8U) /*!< Bit field size in bits for GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */

/*! @brief Read current value of the GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT field. */
#define BR_GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT(x) (HW_GPC_PGC_A7CORE1_PDNSCR(x).B.PDN_SCALL_SCALLOUT_CNT)

/*! @brief Format value for bitfield GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */
#define BF_GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT) & BM_GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT)

/*! @brief Set the PDN_SCALL_SCALLOUT_CNT field to a new value. */
#define BW_GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT(x, v) (HW_GPC_PGC_A7CORE1_PDNSCR_WR(x, (HW_GPC_PGC_A7CORE1_PDNSCR_RD(x) & ~BM_GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT) | BF_GPC_PGC_A7CORE1_PDNSCR_PDN_SCALL_SCALLOUT_CNT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE1_PDNSCR, field PUP_SCPRE_SCALL_CNT[31:24] (RW)
 *
 * After SCPRE asserting to 1'b0, count this value to assert SCALL to 1'b0 (This
 * register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT (24U) /*!< Bit position for GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BM_GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT (0xFF000000U) /*!< Bit mask for GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BS_GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT (8U) /*!< Bit field size in bits for GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT. */

/*! @brief Read current value of the GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT field. */
#define BR_GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT(x) (HW_GPC_PGC_A7CORE1_PDNSCR(x).B.PUP_SCPRE_SCALL_CNT)

/*! @brief Format value for bitfield GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BF_GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT) & BM_GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT)

/*! @brief Set the PUP_SCPRE_SCALL_CNT field to a new value. */
#define BW_GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT(x, v) (HW_GPC_PGC_A7CORE1_PDNSCR_WR(x, (HW_GPC_PGC_A7CORE1_PDNSCR_RD(x) & ~BM_GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT) | BF_GPC_PGC_A7CORE1_PDNSCR_PUP_SCPRE_SCALL_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_A7CORE1_SR - GPC PGC Status Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_A7CORE1_SR - GPC PGC Status Register (RW)
 *
 * Reset value: 0x00001000U
 *
 * GPC PGC Status Register
 */
typedef union _hw_gpc_pgc_a7core1_sr
{
    uint32_t U;
    struct _hw_gpc_pgc_a7core1_sr_bitfields
    {
        uint32_t PSR : 1;              /*!< [0]  */
        uint32_t L2RETN_FLAG : 1;      /*!< [1]  */
        uint32_t ALLOFF_FLAG : 1;      /*!< [2]  */
        uint32_t PUP_CLK_DIV_SEL : 4;  /*!< [6:3]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t L2RSTDIS_DEASSERT_CNT : 10; /*!< [17:8]  */
        uint32_t RESERVED1 : 14;       /*!< [31:18]  */
    } B;
} hw_gpc_pgc_a7core1_sr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_A7CORE1_SR register
 */
/*@{*/
#define HW_GPC_PGC_A7CORE1_SR_ADDR(x) ((uintptr_t)(x) + 0x4CU)

#define HW_GPC_PGC_A7CORE1_SR(x) (*(__IO hw_gpc_pgc_a7core1_sr_t *) HW_GPC_PGC_A7CORE1_SR_ADDR(x))
#define HW_GPC_PGC_A7CORE1_SR_RD(x) (HW_GPC_PGC_A7CORE1_SR(x).U)
#define HW_GPC_PGC_A7CORE1_SR_WR(x, v) (HW_GPC_PGC_A7CORE1_SR(x).U = (v))
#define HW_GPC_PGC_A7CORE1_SR_SET(x, v) (HW_GPC_PGC_A7CORE1_SR_WR(x, HW_GPC_PGC_A7CORE1_SR_RD(x) |  (v)))
#define HW_GPC_PGC_A7CORE1_SR_CLR(x, v) (HW_GPC_PGC_A7CORE1_SR_WR(x, HW_GPC_PGC_A7CORE1_SR_RD(x) & ~(v)))
#define HW_GPC_PGC_A7CORE1_SR_TOG(x, v) (HW_GPC_PGC_A7CORE1_SR_WR(x, HW_GPC_PGC_A7CORE1_SR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_A7CORE1_SR bitfields
 */

/*!
 * @name Register GPC_PGC_A7CORE1_SR, field PSR[0] (RO)
 *
 * Power status. When in functional (or software-controlled debug) mode, PGC
 * hardware sets PSR as soon as any of the power control output changes its state to
 * one. Write one to clear this bit. Software should clear this bit after power
 * up; otherwise, PSR continues to reflect the power status of the initial power
 * down.
 *
 * Values:
 * - 0 - The target subsystem was not powered down for the previous power-down
 *     request.
 * - 1 - The target subsystem was powered down for the previous power-down
 *     request.
 */
/*@{*/
#define BP_GPC_PGC_A7CORE1_SR_PSR (0U)     /*!< Bit position for GPC_PGC_A7CORE1_SR_PSR. */
#define BM_GPC_PGC_A7CORE1_SR_PSR (0x00000001U) /*!< Bit mask for GPC_PGC_A7CORE1_SR_PSR. */
#define BS_GPC_PGC_A7CORE1_SR_PSR (1U)     /*!< Bit field size in bits for GPC_PGC_A7CORE1_SR_PSR. */

/*! @brief Read current value of the GPC_PGC_A7CORE1_SR_PSR field. */
#define BR_GPC_PGC_A7CORE1_SR_PSR(x) (HW_GPC_PGC_A7CORE1_SR(x).B.PSR)
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE1_SR, field L2RETN_FLAG[1] (RO)
 *
 * L2 Retention Flag Software should write "1" to clear this flag after A7 is
 * wakeup from L2 retention mode, otherwise it will always keep to 1 (This register
 * control only for SCU Type PGC)
 *
 * Values:
 * - 0 - A7 is not wakeup from L2 retention mode.
 * - 1 - A7 is wakeup from L2 retention mode.
 */
/*@{*/
#define BP_GPC_PGC_A7CORE1_SR_L2RETN_FLAG (1U) /*!< Bit position for GPC_PGC_A7CORE1_SR_L2RETN_FLAG. */
#define BM_GPC_PGC_A7CORE1_SR_L2RETN_FLAG (0x00000002U) /*!< Bit mask for GPC_PGC_A7CORE1_SR_L2RETN_FLAG. */
#define BS_GPC_PGC_A7CORE1_SR_L2RETN_FLAG (1U) /*!< Bit field size in bits for GPC_PGC_A7CORE1_SR_L2RETN_FLAG. */

/*! @brief Read current value of the GPC_PGC_A7CORE1_SR_L2RETN_FLAG field. */
#define BR_GPC_PGC_A7CORE1_SR_L2RETN_FLAG(x) (HW_GPC_PGC_A7CORE1_SR(x).B.L2RETN_FLAG)
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE1_SR, field ALLOFF_FLAG[2] (RO)
 *
 * All-off flag. Software should write "1" to clear this flag after A7 is wakeup
 * from ALL_OFF mode, otherwise, it will always keep to 1 (This register control
 * only for SCU Type PGC)
 *
 * Values:
 * - 0 - A7 is not wakeup from ALL_OFF mode.
 * - 1 - A7 is wakeup from ALL_OFF mode.
 */
/*@{*/
#define BP_GPC_PGC_A7CORE1_SR_ALLOFF_FLAG (2U) /*!< Bit position for GPC_PGC_A7CORE1_SR_ALLOFF_FLAG. */
#define BM_GPC_PGC_A7CORE1_SR_ALLOFF_FLAG (0x00000004U) /*!< Bit mask for GPC_PGC_A7CORE1_SR_ALLOFF_FLAG. */
#define BS_GPC_PGC_A7CORE1_SR_ALLOFF_FLAG (1U) /*!< Bit field size in bits for GPC_PGC_A7CORE1_SR_ALLOFF_FLAG. */

/*! @brief Read current value of the GPC_PGC_A7CORE1_SR_ALLOFF_FLAG field. */
#define BR_GPC_PGC_A7CORE1_SR_ALLOFF_FLAG(x) (HW_GPC_PGC_A7CORE1_SR(x).B.ALLOFF_FLAG)
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE1_SR, field PUP_CLK_DIV_SEL[6:3] (RW)
 *
 * Clock divider select for the clock of power up counter(count_clk is 32KHz for
 * CPU/SCU type PGC, ipg_clk(66MHz) for MIX/PU Type PGC)
 *
 * Values:
 * - 0000 - 1
 * - 0001 - 1/2 count_clk
 * - 0010 - 1/4 count_clk
 * - 0011 - 1/8 count_clk
 * - 0100 - 1/16 count_clk
 * - 0101 - 1/32 count_clk
 * - 0110 - 1/64 count_clk
 * - 0111 - 1/128 count_clk
 * - 1000 - 1/256 count_clk
 * - 1001 - 1/512 count_clk
 * - 1010 - 1/1024 count_clk
 * - 1011 - 1/2056 count_clk
 * - 1100 - 1/4096 count_clk
 * - 1101 - 1/8192 count_clk
 * - 1110 - 1/16384 count_clk
 * - 1111 - 1/32768 count_clk
 */
/*@{*/
#define BP_GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL (3U) /*!< Bit position for GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL. */
#define BM_GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL (0x00000078U) /*!< Bit mask for GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL. */
#define BS_GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL (4U) /*!< Bit field size in bits for GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL. */

/*! @brief Read current value of the GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL field. */
#define BR_GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL(x) (HW_GPC_PGC_A7CORE1_SR(x).B.PUP_CLK_DIV_SEL)

/*! @brief Format value for bitfield GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL. */
#define BF_GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL) & BM_GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL)

/*! @brief Set the PUP_CLK_DIV_SEL field to a new value. */
#define BW_GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL(x, v) (HW_GPC_PGC_A7CORE1_SR_WR(x, (HW_GPC_PGC_A7CORE1_SR_RD(x) & ~BM_GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL) | BF_GPC_PGC_A7CORE1_SR_PUP_CLK_DIV_SEL(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7CORE1_SR, field L2RSTDIS_DEASSERT_CNT[17:8] (RW)
 *
 * Count this value to de-assert L2RSTDISABLE to LOW after CPU0 or CPU1 power up
 * This value can't be programmed to zero (This register control only for SCU
 * Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT (8U) /*!< Bit position for GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT. */
#define BM_GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT (0x0003FF00U) /*!< Bit mask for GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT. */
#define BS_GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT (10U) /*!< Bit field size in bits for GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT. */

/*! @brief Read current value of the GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT field. */
#define BR_GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT(x) (HW_GPC_PGC_A7CORE1_SR(x).B.L2RSTDIS_DEASSERT_CNT)

/*! @brief Format value for bitfield GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT. */
#define BF_GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT) & BM_GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT)

/*! @brief Set the L2RSTDIS_DEASSERT_CNT field to a new value. */
#define BW_GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT(x, v) (HW_GPC_PGC_A7CORE1_SR_WR(x, (HW_GPC_PGC_A7CORE1_SR_RD(x) & ~BM_GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT) | BF_GPC_PGC_A7CORE1_SR_L2RSTDIS_DEASSERT_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_A7SCU_CTRL - GPC PGC Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_A7SCU_CTRL - GPC PGC Control Register (RW)
 *
 * Reset value: 0x06040202U
 *
 * GPC PGC Control Register
 */
typedef union _hw_gpc_pgc_a7scu_ctrl
{
    uint32_t U;
    struct _hw_gpc_pgc_a7scu_ctrl_bitfields
    {
        uint32_t PCR : 1;              /*!< [0]  */
        uint32_t L2RSTDIS : 6;         /*!< [6:1]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t DFTRAM_TCD1 : 6;      /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t L2RETN_TCD1_TDR : 6;  /*!< [21:16]  */
        uint32_t RESERVED2 : 2;        /*!< [23:22]  */
        uint32_t MEMPWR_TCD1_TDR_TRM : 6; /*!< [29:24]  */
        uint32_t RESERVED3 : 2;        /*!< [31:30]  */
    } B;
} hw_gpc_pgc_a7scu_ctrl_t;

/*!
 * @name Constants and macros for entire GPC_PGC_A7SCU_CTRL register
 */
/*@{*/
#define HW_GPC_PGC_A7SCU_CTRL_ADDR(x) ((uintptr_t)(x) + 0x80U)

#define HW_GPC_PGC_A7SCU_CTRL(x) (*(__IO hw_gpc_pgc_a7scu_ctrl_t *) HW_GPC_PGC_A7SCU_CTRL_ADDR(x))
#define HW_GPC_PGC_A7SCU_CTRL_RD(x) (HW_GPC_PGC_A7SCU_CTRL(x).U)
#define HW_GPC_PGC_A7SCU_CTRL_WR(x, v) (HW_GPC_PGC_A7SCU_CTRL(x).U = (v))
#define HW_GPC_PGC_A7SCU_CTRL_SET(x, v) (HW_GPC_PGC_A7SCU_CTRL_WR(x, HW_GPC_PGC_A7SCU_CTRL_RD(x) |  (v)))
#define HW_GPC_PGC_A7SCU_CTRL_CLR(x, v) (HW_GPC_PGC_A7SCU_CTRL_WR(x, HW_GPC_PGC_A7SCU_CTRL_RD(x) & ~(v)))
#define HW_GPC_PGC_A7SCU_CTRL_TOG(x, v) (HW_GPC_PGC_A7SCU_CTRL_WR(x, HW_GPC_PGC_A7SCU_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_A7SCU_CTRL bitfields
 */

/*!
 * @name Register GPC_PGC_A7SCU_CTRL, field PCR[0] (RW)
 *
 * Power ControlPCR must not change from power-down request (pdn_req) assertion
 * until the target subsystem is completely powered up.
 *
 * Values:
 * - 0 - Do not switch off power even if pdn_req is asserted.
 * - 1 - Switch off power when pdn_req is asserted.
 */
/*@{*/
#define BP_GPC_PGC_A7SCU_CTRL_PCR (0U)     /*!< Bit position for GPC_PGC_A7SCU_CTRL_PCR. */
#define BM_GPC_PGC_A7SCU_CTRL_PCR (0x00000001U) /*!< Bit mask for GPC_PGC_A7SCU_CTRL_PCR. */
#define BS_GPC_PGC_A7SCU_CTRL_PCR (1U)     /*!< Bit field size in bits for GPC_PGC_A7SCU_CTRL_PCR. */

/*! @brief Read current value of the GPC_PGC_A7SCU_CTRL_PCR field. */
#define BR_GPC_PGC_A7SCU_CTRL_PCR(x) (HW_GPC_PGC_A7SCU_CTRL(x).B.PCR)

/*! @brief Format value for bitfield GPC_PGC_A7SCU_CTRL_PCR. */
#define BF_GPC_PGC_A7SCU_CTRL_PCR(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7SCU_CTRL_PCR) & BM_GPC_PGC_A7SCU_CTRL_PCR)

/*! @brief Set the PCR field to a new value. */
#define BW_GPC_PGC_A7SCU_CTRL_PCR(x, v) (HW_GPC_PGC_A7SCU_CTRL_WR(x, (HW_GPC_PGC_A7SCU_CTRL_RD(x) & ~BM_GPC_PGC_A7SCU_CTRL_PCR) | BF_GPC_PGC_A7SCU_CTRL_PCR(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7SCU_CTRL, field L2RSTDIS[6:1] (RW)
 *
 * After scu pdn_req, count this value to assert A7 l2rstdis to 1'b1, it will be
 * clear automatically once any of A7 core0/core1 is wakeup Can't be programmed
 * to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7SCU_CTRL_L2RSTDIS (1U) /*!< Bit position for GPC_PGC_A7SCU_CTRL_L2RSTDIS. */
#define BM_GPC_PGC_A7SCU_CTRL_L2RSTDIS (0x0000007EU) /*!< Bit mask for GPC_PGC_A7SCU_CTRL_L2RSTDIS. */
#define BS_GPC_PGC_A7SCU_CTRL_L2RSTDIS (6U) /*!< Bit field size in bits for GPC_PGC_A7SCU_CTRL_L2RSTDIS. */

/*! @brief Read current value of the GPC_PGC_A7SCU_CTRL_L2RSTDIS field. */
#define BR_GPC_PGC_A7SCU_CTRL_L2RSTDIS(x) (HW_GPC_PGC_A7SCU_CTRL(x).B.L2RSTDIS)

/*! @brief Format value for bitfield GPC_PGC_A7SCU_CTRL_L2RSTDIS. */
#define BF_GPC_PGC_A7SCU_CTRL_L2RSTDIS(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7SCU_CTRL_L2RSTDIS) & BM_GPC_PGC_A7SCU_CTRL_L2RSTDIS)

/*! @brief Set the L2RSTDIS field to a new value. */
#define BW_GPC_PGC_A7SCU_CTRL_L2RSTDIS(x, v) (HW_GPC_PGC_A7SCU_CTRL_WR(x, (HW_GPC_PGC_A7SCU_CTRL_RD(x) & ~BM_GPC_PGC_A7SCU_CTRL_L2RSTDIS) | BF_GPC_PGC_A7SCU_CTRL_L2RSTDIS(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7SCU_CTRL, field DFTRAM_TCD1[13:8] (RW)
 *
 * After scu pdn_req, count this value to assert A7 dftram to 1'b1 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1 (8U) /*!< Bit position for GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1. */
#define BM_GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1 (0x00003F00U) /*!< Bit mask for GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1. */
#define BS_GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1 (6U) /*!< Bit field size in bits for GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1. */

/*! @brief Read current value of the GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1 field. */
#define BR_GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1(x) (HW_GPC_PGC_A7SCU_CTRL(x).B.DFTRAM_TCD1)

/*! @brief Format value for bitfield GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1. */
#define BF_GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1) & BM_GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1)

/*! @brief Set the DFTRAM_TCD1 field to a new value. */
#define BW_GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1(x, v) (HW_GPC_PGC_A7SCU_CTRL_WR(x, (HW_GPC_PGC_A7SCU_CTRL_RD(x) & ~BM_GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1) | BF_GPC_PGC_A7SCU_CTRL_DFTRAM_TCD1(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7SCU_CTRL, field L2RETN_TCD1_TDR[21:16] (RW)
 *
 * After scu pdn_req, count this value to assert A7 l2retn to 1'b0 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR (16U) /*!< Bit position for GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR. */
#define BM_GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR (0x003F0000U) /*!< Bit mask for GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR. */
#define BS_GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR (6U) /*!< Bit field size in bits for GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR. */

/*! @brief Read current value of the GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR field. */
#define BR_GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR(x) (HW_GPC_PGC_A7SCU_CTRL(x).B.L2RETN_TCD1_TDR)

/*! @brief Format value for bitfield GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR. */
#define BF_GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR) & BM_GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR)

/*! @brief Set the L2RETN_TCD1_TDR field to a new value. */
#define BW_GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR(x, v) (HW_GPC_PGC_A7SCU_CTRL_WR(x, (HW_GPC_PGC_A7SCU_CTRL_RD(x) & ~BM_GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR) | BF_GPC_PGC_A7SCU_CTRL_L2RETN_TCD1_TDR(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7SCU_CTRL, field MEMPWR_TCD1_TDR_TRM[29:24] (RW)
 *
 * After scu pdn_req, count this value to assert A7 mempwr to 1'b1 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM (24U) /*!< Bit position for GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BM_GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM (0x3F000000U) /*!< Bit mask for GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BS_GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM (6U) /*!< Bit field size in bits for GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM. */

/*! @brief Read current value of the GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM field. */
#define BR_GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM(x) (HW_GPC_PGC_A7SCU_CTRL(x).B.MEMPWR_TCD1_TDR_TRM)

/*! @brief Format value for bitfield GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BF_GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM) & BM_GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM)

/*! @brief Set the MEMPWR_TCD1_TDR_TRM field to a new value. */
#define BW_GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM(x, v) (HW_GPC_PGC_A7SCU_CTRL_WR(x, (HW_GPC_PGC_A7SCU_CTRL_RD(x) & ~BM_GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM) | BF_GPC_PGC_A7SCU_CTRL_MEMPWR_TCD1_TDR_TRM(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_A7SCU_PUPSCR - GPC PGC Up Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_A7SCU_PUPSCR - GPC PGC Up Sequence Control Register (RW)
 *
 * Reset value: 0x000997C1U
 *
 * GPC PGC Up Sequence Control Register
 */
typedef union _hw_gpc_pgc_a7scu_pupscr
{
    uint32_t U;
    struct _hw_gpc_pgc_a7scu_pupscr_bitfields
    {
        uint32_t SW : 6;               /*!< [5:0]  */
        uint32_t PUP_WAIT_SCALL_OUT : 1; /*!< [6]  */
        uint32_t SW2ISO : 16;          /*!< [22:7]  */
        uint32_t PUP_SCALL_SCALLOUT_CNT : 9; /*!< [31:23]  */
    } B;
} hw_gpc_pgc_a7scu_pupscr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_A7SCU_PUPSCR register
 */
/*@{*/
#define HW_GPC_PGC_A7SCU_PUPSCR_ADDR(x) ((uintptr_t)(x) + 0x84U)

#define HW_GPC_PGC_A7SCU_PUPSCR(x) (*(__IO hw_gpc_pgc_a7scu_pupscr_t *) HW_GPC_PGC_A7SCU_PUPSCR_ADDR(x))
#define HW_GPC_PGC_A7SCU_PUPSCR_RD(x) (HW_GPC_PGC_A7SCU_PUPSCR(x).U)
#define HW_GPC_PGC_A7SCU_PUPSCR_WR(x, v) (HW_GPC_PGC_A7SCU_PUPSCR(x).U = (v))
#define HW_GPC_PGC_A7SCU_PUPSCR_SET(x, v) (HW_GPC_PGC_A7SCU_PUPSCR_WR(x, HW_GPC_PGC_A7SCU_PUPSCR_RD(x) |  (v)))
#define HW_GPC_PGC_A7SCU_PUPSCR_CLR(x, v) (HW_GPC_PGC_A7SCU_PUPSCR_WR(x, HW_GPC_PGC_A7SCU_PUPSCR_RD(x) & ~(v)))
#define HW_GPC_PGC_A7SCU_PUPSCR_TOG(x, v) (HW_GPC_PGC_A7SCU_PUPSCR_WR(x, HW_GPC_PGC_A7SCU_PUPSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_A7SCU_PUPSCR bitfields
 */

/*!
 * @name Register GPC_PGC_A7SCU_PUPSCR, field SW[5:0] (RW)
 *
 * After a power-up request (pup_req assertion), the PGC waits a number of
 * clocks equal to the value of SW before asserting switch_b SW must not be programmed
 * to zero.
 */
/*@{*/
#define BP_GPC_PGC_A7SCU_PUPSCR_SW (0U)    /*!< Bit position for GPC_PGC_A7SCU_PUPSCR_SW. */
#define BM_GPC_PGC_A7SCU_PUPSCR_SW (0x0000003FU) /*!< Bit mask for GPC_PGC_A7SCU_PUPSCR_SW. */
#define BS_GPC_PGC_A7SCU_PUPSCR_SW (6U)    /*!< Bit field size in bits for GPC_PGC_A7SCU_PUPSCR_SW. */

/*! @brief Read current value of the GPC_PGC_A7SCU_PUPSCR_SW field. */
#define BR_GPC_PGC_A7SCU_PUPSCR_SW(x) (HW_GPC_PGC_A7SCU_PUPSCR(x).B.SW)

/*! @brief Format value for bitfield GPC_PGC_A7SCU_PUPSCR_SW. */
#define BF_GPC_PGC_A7SCU_PUPSCR_SW(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7SCU_PUPSCR_SW) & BM_GPC_PGC_A7SCU_PUPSCR_SW)

/*! @brief Set the SW field to a new value. */
#define BW_GPC_PGC_A7SCU_PUPSCR_SW(x, v) (HW_GPC_PGC_A7SCU_PUPSCR_WR(x, (HW_GPC_PGC_A7SCU_PUPSCR_RD(x) & ~BM_GPC_PGC_A7SCU_PUPSCR_SW) | BF_GPC_PGC_A7SCU_PUPSCR_SW(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7SCU_PUPSCR, field PUP_WAIT_SCALL_OUT[6] (RW)
 *
 * After SCALL asserting to 1'b0, wait handshake signal SCALL_OUT to return to
 * 1'b0 (This register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7SCU_PUPSCR_PUP_WAIT_SCALL_OUT (6U) /*!< Bit position for GPC_PGC_A7SCU_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BM_GPC_PGC_A7SCU_PUPSCR_PUP_WAIT_SCALL_OUT (0x00000040U) /*!< Bit mask for GPC_PGC_A7SCU_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BS_GPC_PGC_A7SCU_PUPSCR_PUP_WAIT_SCALL_OUT (1U) /*!< Bit field size in bits for GPC_PGC_A7SCU_PUPSCR_PUP_WAIT_SCALL_OUT. */

/*! @brief Read current value of the GPC_PGC_A7SCU_PUPSCR_PUP_WAIT_SCALL_OUT field. */
#define BR_GPC_PGC_A7SCU_PUPSCR_PUP_WAIT_SCALL_OUT(x) (HW_GPC_PGC_A7SCU_PUPSCR(x).B.PUP_WAIT_SCALL_OUT)

/*! @brief Format value for bitfield GPC_PGC_A7SCU_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BF_GPC_PGC_A7SCU_PUPSCR_PUP_WAIT_SCALL_OUT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7SCU_PUPSCR_PUP_WAIT_SCALL_OUT) & BM_GPC_PGC_A7SCU_PUPSCR_PUP_WAIT_SCALL_OUT)

/*! @brief Set the PUP_WAIT_SCALL_OUT field to a new value. */
#define BW_GPC_PGC_A7SCU_PUPSCR_PUP_WAIT_SCALL_OUT(x, v) (HW_GPC_PGC_A7SCU_PUPSCR_WR(x, (HW_GPC_PGC_A7SCU_PUPSCR_RD(x) & ~BM_GPC_PGC_A7SCU_PUPSCR_PUP_WAIT_SCALL_OUT) | BF_GPC_PGC_A7SCU_PUPSCR_PUP_WAIT_SCALL_OUT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7SCU_PUPSCR, field SW2ISO[22:7] (RW)
 *
 * After asserting switch_b, the PGC waits a number of clocks equal to the value
 * of SW2ISO before negating isolation.
 */
/*@{*/
#define BP_GPC_PGC_A7SCU_PUPSCR_SW2ISO (7U) /*!< Bit position for GPC_PGC_A7SCU_PUPSCR_SW2ISO. */
#define BM_GPC_PGC_A7SCU_PUPSCR_SW2ISO (0x007FFF80U) /*!< Bit mask for GPC_PGC_A7SCU_PUPSCR_SW2ISO. */
#define BS_GPC_PGC_A7SCU_PUPSCR_SW2ISO (16U) /*!< Bit field size in bits for GPC_PGC_A7SCU_PUPSCR_SW2ISO. */

/*! @brief Read current value of the GPC_PGC_A7SCU_PUPSCR_SW2ISO field. */
#define BR_GPC_PGC_A7SCU_PUPSCR_SW2ISO(x) (HW_GPC_PGC_A7SCU_PUPSCR(x).B.SW2ISO)

/*! @brief Format value for bitfield GPC_PGC_A7SCU_PUPSCR_SW2ISO. */
#define BF_GPC_PGC_A7SCU_PUPSCR_SW2ISO(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7SCU_PUPSCR_SW2ISO) & BM_GPC_PGC_A7SCU_PUPSCR_SW2ISO)

/*! @brief Set the SW2ISO field to a new value. */
#define BW_GPC_PGC_A7SCU_PUPSCR_SW2ISO(x, v) (HW_GPC_PGC_A7SCU_PUPSCR_WR(x, (HW_GPC_PGC_A7SCU_PUPSCR_RD(x) & ~BM_GPC_PGC_A7SCU_PUPSCR_SW2ISO) | BF_GPC_PGC_A7SCU_PUPSCR_SW2ISO(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7SCU_PUPSCR, field PUP_SCALL_SCALLOUT_CNT[31:23] (RW)
 *
 * After SCALL asserting to 1'b0, count this value to complete switch power up
 * Only valid when pup_wait_scall_out is set to 1'b0. Can't be programmed to zero
 * (This register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT (23U) /*!< Bit position for GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */
#define BM_GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT (0xFF800000U) /*!< Bit mask for GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */
#define BS_GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT (9U) /*!< Bit field size in bits for GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */

/*! @brief Read current value of the GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT field. */
#define BR_GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT(x) (HW_GPC_PGC_A7SCU_PUPSCR(x).B.PUP_SCALL_SCALLOUT_CNT)

/*! @brief Format value for bitfield GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */
#define BF_GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT) & BM_GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT)

/*! @brief Set the PUP_SCALL_SCALLOUT_CNT field to a new value. */
#define BW_GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT(x, v) (HW_GPC_PGC_A7SCU_PUPSCR_WR(x, (HW_GPC_PGC_A7SCU_PUPSCR_RD(x) & ~BM_GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT) | BF_GPC_PGC_A7SCU_PUPSCR_PUP_SCALL_SCALLOUT_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_A7SCU_PDNSCR - GPC PGC Down Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_A7SCU_PDNSCR - GPC PGC Down Sequence Control Register (RW)
 *
 * Reset value: 0x21000801U
 *
 * GPC PGC Down Sequence Control Register
 */
typedef union _hw_gpc_pgc_a7scu_pdnscr
{
    uint32_t U;
    struct _hw_gpc_pgc_a7scu_pdnscr_bitfields
    {
        uint32_t ISO : 6;              /*!< [5:0]  */
        uint32_t RESERVED0 : 1;        /*!< [6]  */
        uint32_t PDN_WAIT_SCALL_OUT : 1; /*!< [7] Default 1'b0 */
        uint32_t ISO2SW : 6;           /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t PDN_SCALL_SCALLOUT_CNT : 8; /*!< [23:16]  */
        uint32_t PUP_SCPRE_SCALL_CNT : 8; /*!< [31:24]  */
    } B;
} hw_gpc_pgc_a7scu_pdnscr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_A7SCU_PDNSCR register
 */
/*@{*/
#define HW_GPC_PGC_A7SCU_PDNSCR_ADDR(x) ((uintptr_t)(x) + 0x88U)

#define HW_GPC_PGC_A7SCU_PDNSCR(x) (*(__IO hw_gpc_pgc_a7scu_pdnscr_t *) HW_GPC_PGC_A7SCU_PDNSCR_ADDR(x))
#define HW_GPC_PGC_A7SCU_PDNSCR_RD(x) (HW_GPC_PGC_A7SCU_PDNSCR(x).U)
#define HW_GPC_PGC_A7SCU_PDNSCR_WR(x, v) (HW_GPC_PGC_A7SCU_PDNSCR(x).U = (v))
#define HW_GPC_PGC_A7SCU_PDNSCR_SET(x, v) (HW_GPC_PGC_A7SCU_PDNSCR_WR(x, HW_GPC_PGC_A7SCU_PDNSCR_RD(x) |  (v)))
#define HW_GPC_PGC_A7SCU_PDNSCR_CLR(x, v) (HW_GPC_PGC_A7SCU_PDNSCR_WR(x, HW_GPC_PGC_A7SCU_PDNSCR_RD(x) & ~(v)))
#define HW_GPC_PGC_A7SCU_PDNSCR_TOG(x, v) (HW_GPC_PGC_A7SCU_PDNSCR_WR(x, HW_GPC_PGC_A7SCU_PDNSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_A7SCU_PDNSCR bitfields
 */

/*!
 * @name Register GPC_PGC_A7SCU_PDNSCR, field ISO[5:0] (RW)
 *
 * Aafte a power-down request (pdn_req assertion), the PGC waits a number of
 * clocks equal to the value of ISO before asserting isolation ISO must not be
 * programmed to zero.
 */
/*@{*/
#define BP_GPC_PGC_A7SCU_PDNSCR_ISO (0U)   /*!< Bit position for GPC_PGC_A7SCU_PDNSCR_ISO. */
#define BM_GPC_PGC_A7SCU_PDNSCR_ISO (0x0000003FU) /*!< Bit mask for GPC_PGC_A7SCU_PDNSCR_ISO. */
#define BS_GPC_PGC_A7SCU_PDNSCR_ISO (6U)   /*!< Bit field size in bits for GPC_PGC_A7SCU_PDNSCR_ISO. */

/*! @brief Read current value of the GPC_PGC_A7SCU_PDNSCR_ISO field. */
#define BR_GPC_PGC_A7SCU_PDNSCR_ISO(x) (HW_GPC_PGC_A7SCU_PDNSCR(x).B.ISO)

/*! @brief Format value for bitfield GPC_PGC_A7SCU_PDNSCR_ISO. */
#define BF_GPC_PGC_A7SCU_PDNSCR_ISO(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7SCU_PDNSCR_ISO) & BM_GPC_PGC_A7SCU_PDNSCR_ISO)

/*! @brief Set the ISO field to a new value. */
#define BW_GPC_PGC_A7SCU_PDNSCR_ISO(x, v) (HW_GPC_PGC_A7SCU_PDNSCR_WR(x, (HW_GPC_PGC_A7SCU_PDNSCR_RD(x) & ~BM_GPC_PGC_A7SCU_PDNSCR_ISO) | BF_GPC_PGC_A7SCU_PDNSCR_ISO(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7SCU_PDNSCR, field PDN_WAIT_SCALL_OUT[7] (RW)
 *
 * If set to 1'b1, after SCALL asserting to 1'b1, wait handshake signal
 * SCALL_OUT to change to 1'b1. This register control is only for MIX Type PGC.
 */
/*@{*/
#define BP_GPC_PGC_A7SCU_PDNSCR_PDN_WAIT_SCALL_OUT (7U) /*!< Bit position for GPC_PGC_A7SCU_PDNSCR_PDN_WAIT_SCALL_OUT. */
#define BM_GPC_PGC_A7SCU_PDNSCR_PDN_WAIT_SCALL_OUT (0x00000080U) /*!< Bit mask for GPC_PGC_A7SCU_PDNSCR_PDN_WAIT_SCALL_OUT. */
#define BS_GPC_PGC_A7SCU_PDNSCR_PDN_WAIT_SCALL_OUT (1U) /*!< Bit field size in bits for GPC_PGC_A7SCU_PDNSCR_PDN_WAIT_SCALL_OUT. */

/*! @brief Read current value of the GPC_PGC_A7SCU_PDNSCR_PDN_WAIT_SCALL_OUT field. */
#define BR_GPC_PGC_A7SCU_PDNSCR_PDN_WAIT_SCALL_OUT(x) (HW_GPC_PGC_A7SCU_PDNSCR(x).B.PDN_WAIT_SCALL_OUT)

/*! @brief Format value for bitfield GPC_PGC_A7SCU_PDNSCR_PDN_WAIT_SCALL_OUT. */
#define BF_GPC_PGC_A7SCU_PDNSCR_PDN_WAIT_SCALL_OUT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7SCU_PDNSCR_PDN_WAIT_SCALL_OUT) & BM_GPC_PGC_A7SCU_PDNSCR_PDN_WAIT_SCALL_OUT)

/*! @brief Set the PDN_WAIT_SCALL_OUT field to a new value. */
#define BW_GPC_PGC_A7SCU_PDNSCR_PDN_WAIT_SCALL_OUT(x, v) (HW_GPC_PGC_A7SCU_PDNSCR_WR(x, (HW_GPC_PGC_A7SCU_PDNSCR_RD(x) & ~BM_GPC_PGC_A7SCU_PDNSCR_PDN_WAIT_SCALL_OUT) | BF_GPC_PGC_A7SCU_PDNSCR_PDN_WAIT_SCALL_OUT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7SCU_PDNSCR, field ISO2SW[13:8] (RW)
 *
 * After asserting isolation(by pdn_req assertion), the PGC waits a number of
 * clocks equal to the value of ISO2SW before negating switch_b ISO2SW must not be
 * programmed to zero.
 */
/*@{*/
#define BP_GPC_PGC_A7SCU_PDNSCR_ISO2SW (8U) /*!< Bit position for GPC_PGC_A7SCU_PDNSCR_ISO2SW. */
#define BM_GPC_PGC_A7SCU_PDNSCR_ISO2SW (0x00003F00U) /*!< Bit mask for GPC_PGC_A7SCU_PDNSCR_ISO2SW. */
#define BS_GPC_PGC_A7SCU_PDNSCR_ISO2SW (6U) /*!< Bit field size in bits for GPC_PGC_A7SCU_PDNSCR_ISO2SW. */

/*! @brief Read current value of the GPC_PGC_A7SCU_PDNSCR_ISO2SW field. */
#define BR_GPC_PGC_A7SCU_PDNSCR_ISO2SW(x) (HW_GPC_PGC_A7SCU_PDNSCR(x).B.ISO2SW)

/*! @brief Format value for bitfield GPC_PGC_A7SCU_PDNSCR_ISO2SW. */
#define BF_GPC_PGC_A7SCU_PDNSCR_ISO2SW(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7SCU_PDNSCR_ISO2SW) & BM_GPC_PGC_A7SCU_PDNSCR_ISO2SW)

/*! @brief Set the ISO2SW field to a new value. */
#define BW_GPC_PGC_A7SCU_PDNSCR_ISO2SW(x, v) (HW_GPC_PGC_A7SCU_PDNSCR_WR(x, (HW_GPC_PGC_A7SCU_PDNSCR_RD(x) & ~BM_GPC_PGC_A7SCU_PDNSCR_ISO2SW) | BF_GPC_PGC_A7SCU_PDNSCR_ISO2SW(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7SCU_PDNSCR, field PDN_SCALL_SCALLOUT_CNT[23:16] (RW)
 *
 * Default 8'h0. After SCALL asserting to 1'b1, count this value to complete
 * switch power down. This control is only valid when pdn_wait_scall_out is set to
 * 1'b0. It can be programmed to zero. (This register control only for MIX Type
 * PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT (16U) /*!< Bit position for GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */
#define BM_GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT (0x00FF0000U) /*!< Bit mask for GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */
#define BS_GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT (8U) /*!< Bit field size in bits for GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */

/*! @brief Read current value of the GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT field. */
#define BR_GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT(x) (HW_GPC_PGC_A7SCU_PDNSCR(x).B.PDN_SCALL_SCALLOUT_CNT)

/*! @brief Format value for bitfield GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */
#define BF_GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT) & BM_GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT)

/*! @brief Set the PDN_SCALL_SCALLOUT_CNT field to a new value. */
#define BW_GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT(x, v) (HW_GPC_PGC_A7SCU_PDNSCR_WR(x, (HW_GPC_PGC_A7SCU_PDNSCR_RD(x) & ~BM_GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT) | BF_GPC_PGC_A7SCU_PDNSCR_PDN_SCALL_SCALLOUT_CNT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7SCU_PDNSCR, field PUP_SCPRE_SCALL_CNT[31:24] (RW)
 *
 * After SCPRE asserting to 1'b0, count this value to assert SCALL to 1'b0 (This
 * register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT (24U) /*!< Bit position for GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BM_GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT (0xFF000000U) /*!< Bit mask for GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BS_GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT (8U) /*!< Bit field size in bits for GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT. */

/*! @brief Read current value of the GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT field. */
#define BR_GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT(x) (HW_GPC_PGC_A7SCU_PDNSCR(x).B.PUP_SCPRE_SCALL_CNT)

/*! @brief Format value for bitfield GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BF_GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT) & BM_GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT)

/*! @brief Set the PUP_SCPRE_SCALL_CNT field to a new value. */
#define BW_GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT(x, v) (HW_GPC_PGC_A7SCU_PDNSCR_WR(x, (HW_GPC_PGC_A7SCU_PDNSCR_RD(x) & ~BM_GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT) | BF_GPC_PGC_A7SCU_PDNSCR_PUP_SCPRE_SCALL_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_A7SCU_SR - GPC PGC Status Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_A7SCU_SR - GPC PGC Status Register (RW)
 *
 * Reset value: 0x00001000U
 *
 * GPC PGC Status Register
 */
typedef union _hw_gpc_pgc_a7scu_sr
{
    uint32_t U;
    struct _hw_gpc_pgc_a7scu_sr_bitfields
    {
        uint32_t PSR : 1;              /*!< [0]  */
        uint32_t L2RETN_FLAG : 1;      /*!< [1]  */
        uint32_t ALLOFF_FLAG : 1;      /*!< [2]  */
        uint32_t PUP_CLK_DIV_SEL : 4;  /*!< [6:3]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t L2RSTDIS_DEASSERT_CNT : 10; /*!< [17:8]  */
        uint32_t RESERVED1 : 14;       /*!< [31:18]  */
    } B;
} hw_gpc_pgc_a7scu_sr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_A7SCU_SR register
 */
/*@{*/
#define HW_GPC_PGC_A7SCU_SR_ADDR(x) ((uintptr_t)(x) + 0x8CU)

#define HW_GPC_PGC_A7SCU_SR(x)   (*(__IO hw_gpc_pgc_a7scu_sr_t *) HW_GPC_PGC_A7SCU_SR_ADDR(x))
#define HW_GPC_PGC_A7SCU_SR_RD(x) (HW_GPC_PGC_A7SCU_SR(x).U)
#define HW_GPC_PGC_A7SCU_SR_WR(x, v) (HW_GPC_PGC_A7SCU_SR(x).U = (v))
#define HW_GPC_PGC_A7SCU_SR_SET(x, v) (HW_GPC_PGC_A7SCU_SR_WR(x, HW_GPC_PGC_A7SCU_SR_RD(x) |  (v)))
#define HW_GPC_PGC_A7SCU_SR_CLR(x, v) (HW_GPC_PGC_A7SCU_SR_WR(x, HW_GPC_PGC_A7SCU_SR_RD(x) & ~(v)))
#define HW_GPC_PGC_A7SCU_SR_TOG(x, v) (HW_GPC_PGC_A7SCU_SR_WR(x, HW_GPC_PGC_A7SCU_SR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_A7SCU_SR bitfields
 */

/*!
 * @name Register GPC_PGC_A7SCU_SR, field PSR[0] (RO)
 *
 * Power status. When in functional (or software-controlled debug) mode, PGC
 * hardware sets PSR as soon as any of the power control output changes its state to
 * one. Write one to clear this bit. Software should clear this bit after power
 * up; otherwise, PSR continues to reflect the power status of the initial power
 * down.
 *
 * Values:
 * - 0 - The target subsystem was not powered down for the previous power-down
 *     request.
 * - 1 - The target subsystem was powered down for the previous power-down
 *     request.
 */
/*@{*/
#define BP_GPC_PGC_A7SCU_SR_PSR (0U)       /*!< Bit position for GPC_PGC_A7SCU_SR_PSR. */
#define BM_GPC_PGC_A7SCU_SR_PSR (0x00000001U) /*!< Bit mask for GPC_PGC_A7SCU_SR_PSR. */
#define BS_GPC_PGC_A7SCU_SR_PSR (1U)       /*!< Bit field size in bits for GPC_PGC_A7SCU_SR_PSR. */

/*! @brief Read current value of the GPC_PGC_A7SCU_SR_PSR field. */
#define BR_GPC_PGC_A7SCU_SR_PSR(x) (HW_GPC_PGC_A7SCU_SR(x).B.PSR)
/*@}*/

/*!
 * @name Register GPC_PGC_A7SCU_SR, field L2RETN_FLAG[1] (RO)
 *
 * L2 Retention Flag Software should write "1" to clear this flag after A7 is
 * wakeup from L2 retention mode, otherwise it will always keep to 1 (This register
 * control only for SCU Type PGC)
 *
 * Values:
 * - 0 - A7 is not wakeup from L2 retention mode.
 * - 1 - A7 is wakeup from L2 retention mode.
 */
/*@{*/
#define BP_GPC_PGC_A7SCU_SR_L2RETN_FLAG (1U) /*!< Bit position for GPC_PGC_A7SCU_SR_L2RETN_FLAG. */
#define BM_GPC_PGC_A7SCU_SR_L2RETN_FLAG (0x00000002U) /*!< Bit mask for GPC_PGC_A7SCU_SR_L2RETN_FLAG. */
#define BS_GPC_PGC_A7SCU_SR_L2RETN_FLAG (1U) /*!< Bit field size in bits for GPC_PGC_A7SCU_SR_L2RETN_FLAG. */

/*! @brief Read current value of the GPC_PGC_A7SCU_SR_L2RETN_FLAG field. */
#define BR_GPC_PGC_A7SCU_SR_L2RETN_FLAG(x) (HW_GPC_PGC_A7SCU_SR(x).B.L2RETN_FLAG)
/*@}*/

/*!
 * @name Register GPC_PGC_A7SCU_SR, field ALLOFF_FLAG[2] (RO)
 *
 * All-off flag. Software should write "1" to clear this flag after A7 is wakeup
 * from ALL_OFF mode, otherwise, it will always keep to 1 (This register control
 * only for SCU Type PGC)
 *
 * Values:
 * - 0 - A7 is not wakeup from ALL_OFF mode.
 * - 1 - A7 is wakeup from ALL_OFF mode.
 */
/*@{*/
#define BP_GPC_PGC_A7SCU_SR_ALLOFF_FLAG (2U) /*!< Bit position for GPC_PGC_A7SCU_SR_ALLOFF_FLAG. */
#define BM_GPC_PGC_A7SCU_SR_ALLOFF_FLAG (0x00000004U) /*!< Bit mask for GPC_PGC_A7SCU_SR_ALLOFF_FLAG. */
#define BS_GPC_PGC_A7SCU_SR_ALLOFF_FLAG (1U) /*!< Bit field size in bits for GPC_PGC_A7SCU_SR_ALLOFF_FLAG. */

/*! @brief Read current value of the GPC_PGC_A7SCU_SR_ALLOFF_FLAG field. */
#define BR_GPC_PGC_A7SCU_SR_ALLOFF_FLAG(x) (HW_GPC_PGC_A7SCU_SR(x).B.ALLOFF_FLAG)
/*@}*/

/*!
 * @name Register GPC_PGC_A7SCU_SR, field PUP_CLK_DIV_SEL[6:3] (RW)
 *
 * Clock divider select for the clock of power up counter(count_clk is 32KHz for
 * CPU/SCU type PGC, ipg_clk(66MHz) for MIX/PU Type PGC)
 *
 * Values:
 * - 0000 - 1
 * - 0001 - 1/2 count_clk
 * - 0010 - 1/4 count_clk
 * - 0011 - 1/8 count_clk
 * - 0100 - 1/16 count_clk
 * - 0101 - 1/32 count_clk
 * - 0110 - 1/64 count_clk
 * - 0111 - 1/128 count_clk
 * - 1000 - 1/256 count_clk
 * - 1001 - 1/512 count_clk
 * - 1010 - 1/1024 count_clk
 * - 1011 - 1/2056 count_clk
 * - 1100 - 1/4096 count_clk
 * - 1101 - 1/8192 count_clk
 * - 1110 - 1/16384 count_clk
 * - 1111 - 1/32768 count_clk
 */
/*@{*/
#define BP_GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL (3U) /*!< Bit position for GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL. */
#define BM_GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL (0x00000078U) /*!< Bit mask for GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL. */
#define BS_GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL (4U) /*!< Bit field size in bits for GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL. */

/*! @brief Read current value of the GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL field. */
#define BR_GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL(x) (HW_GPC_PGC_A7SCU_SR(x).B.PUP_CLK_DIV_SEL)

/*! @brief Format value for bitfield GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL. */
#define BF_GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL) & BM_GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL)

/*! @brief Set the PUP_CLK_DIV_SEL field to a new value. */
#define BW_GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL(x, v) (HW_GPC_PGC_A7SCU_SR_WR(x, (HW_GPC_PGC_A7SCU_SR_RD(x) & ~BM_GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL) | BF_GPC_PGC_A7SCU_SR_PUP_CLK_DIV_SEL(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_A7SCU_SR, field L2RSTDIS_DEASSERT_CNT[17:8] (RW)
 *
 * Count this value to de-assert L2RSTDISABLE to LOW after CPU0 or CPU1 power up
 * This value can't be programmed to zero (This register control only for SCU
 * Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT (8U) /*!< Bit position for GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT. */
#define BM_GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT (0x0003FF00U) /*!< Bit mask for GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT. */
#define BS_GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT (10U) /*!< Bit field size in bits for GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT. */

/*! @brief Read current value of the GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT field. */
#define BR_GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT(x) (HW_GPC_PGC_A7SCU_SR(x).B.L2RSTDIS_DEASSERT_CNT)

/*! @brief Format value for bitfield GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT. */
#define BF_GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT) & BM_GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT)

/*! @brief Set the L2RSTDIS_DEASSERT_CNT field to a new value. */
#define BW_GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT(x, v) (HW_GPC_PGC_A7SCU_SR_WR(x, (HW_GPC_PGC_A7SCU_SR_RD(x) & ~BM_GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT) | BF_GPC_PGC_A7SCU_SR_L2RSTDIS_DEASSERT_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_SCU_AUXSW - GPC PGC Auxiliary Power Switch SCU Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_SCU_AUXSW - GPC PGC Auxiliary Power Switch SCU Control Register (RO)
 *
 * Reset value: 0x0020240BU
 *
 * GPC PGC Auxiliary Power Switch Control Register. The register has different
 * field definition for PCIE/MIPI PGC and SCU Type PGC. The value of
 * mempwr_tRC1_tMC/ l2retn_tRC1_tMC_tMR/ dftram_tRC1_tMC_tMR_tCD2 should be programmed to
 * 0x51/0x59/0x5B. That's required for A7 SCU power up timing.
 */
typedef union _hw_gpc_pgc_scu_auxsw
{
    uint32_t U;
    struct _hw_gpc_pgc_scu_auxsw_bitfields
    {
        uint32_t DFTRAM_TRC1_TMC_TMR_TCD2 : 10; /*!< [9:0]  */
        uint32_t L2RETN_TRC1_TMC_TMR : 10; /*!< [19:10]  */
        uint32_t MEMPWR_TRC1_TMC : 10; /*!< [29:20]  */
        uint32_t RESERVED0 : 2;        /*!< [31:30]  */
    } B;
} hw_gpc_pgc_scu_auxsw_t;

/*!
 * @name Constants and macros for entire GPC_PGC_SCU_AUXSW register
 */
/*@{*/
#define HW_GPC_PGC_SCU_AUXSW_ADDR(x) ((uintptr_t)(x) + 0x90U)

#define HW_GPC_PGC_SCU_AUXSW(x)  (*(__I hw_gpc_pgc_scu_auxsw_t *) HW_GPC_PGC_SCU_AUXSW_ADDR(x))
#define HW_GPC_PGC_SCU_AUXSW_RD(x) (HW_GPC_PGC_SCU_AUXSW(x).U)
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_SCU_AUXSW bitfields
 */

/*!
 * @name Register GPC_PGC_SCU_AUXSW, field DFTRAM_TRC1_TMC_TMR_TCD2[9:0] (RO)
 *
 * After scu start pup reset, count this value to assert A7 dftram to 1'b0
 * Cannot be programmed to zero.
 */
/*@{*/
#define BP_GPC_PGC_SCU_AUXSW_DFTRAM_TRC1_TMC_TMR_TCD2 (0U) /*!< Bit position for GPC_PGC_SCU_AUXSW_DFTRAM_TRC1_TMC_TMR_TCD2. */
#define BM_GPC_PGC_SCU_AUXSW_DFTRAM_TRC1_TMC_TMR_TCD2 (0x000003FFU) /*!< Bit mask for GPC_PGC_SCU_AUXSW_DFTRAM_TRC1_TMC_TMR_TCD2. */
#define BS_GPC_PGC_SCU_AUXSW_DFTRAM_TRC1_TMC_TMR_TCD2 (10U) /*!< Bit field size in bits for GPC_PGC_SCU_AUXSW_DFTRAM_TRC1_TMC_TMR_TCD2. */

/*! @brief Read current value of the GPC_PGC_SCU_AUXSW_DFTRAM_TRC1_TMC_TMR_TCD2 field. */
#define BR_GPC_PGC_SCU_AUXSW_DFTRAM_TRC1_TMC_TMR_TCD2(x) (HW_GPC_PGC_SCU_AUXSW(x).B.DFTRAM_TRC1_TMC_TMR_TCD2)
/*@}*/

/*!
 * @name Register GPC_PGC_SCU_AUXSW, field L2RETN_TRC1_TMC_TMR[19:10] (RO)
 *
 * After scu start pup reset, count this value to assert A7 l2retn to 1'b1
 * Cannot be programmed to zero.
 */
/*@{*/
#define BP_GPC_PGC_SCU_AUXSW_L2RETN_TRC1_TMC_TMR (10U) /*!< Bit position for GPC_PGC_SCU_AUXSW_L2RETN_TRC1_TMC_TMR. */
#define BM_GPC_PGC_SCU_AUXSW_L2RETN_TRC1_TMC_TMR (0x000FFC00U) /*!< Bit mask for GPC_PGC_SCU_AUXSW_L2RETN_TRC1_TMC_TMR. */
#define BS_GPC_PGC_SCU_AUXSW_L2RETN_TRC1_TMC_TMR (10U) /*!< Bit field size in bits for GPC_PGC_SCU_AUXSW_L2RETN_TRC1_TMC_TMR. */

/*! @brief Read current value of the GPC_PGC_SCU_AUXSW_L2RETN_TRC1_TMC_TMR field. */
#define BR_GPC_PGC_SCU_AUXSW_L2RETN_TRC1_TMC_TMR(x) (HW_GPC_PGC_SCU_AUXSW(x).B.L2RETN_TRC1_TMC_TMR)
/*@}*/

/*!
 * @name Register GPC_PGC_SCU_AUXSW, field MEMPWR_TRC1_TMC[29:20] (RO)
 *
 * After scu start pup reset, count this value to assert A7 mempwr to 1'b0
 * Cannot be programmed to zero.
 *
 * Values:
 * - 0 - A7 is not wakeup from ALL_OFF mode.
 * - 1 - A7 is wakeup from ALL_OFF mode.
 */
/*@{*/
#define BP_GPC_PGC_SCU_AUXSW_MEMPWR_TRC1_TMC (20U) /*!< Bit position for GPC_PGC_SCU_AUXSW_MEMPWR_TRC1_TMC. */
#define BM_GPC_PGC_SCU_AUXSW_MEMPWR_TRC1_TMC (0x3FF00000U) /*!< Bit mask for GPC_PGC_SCU_AUXSW_MEMPWR_TRC1_TMC. */
#define BS_GPC_PGC_SCU_AUXSW_MEMPWR_TRC1_TMC (10U) /*!< Bit field size in bits for GPC_PGC_SCU_AUXSW_MEMPWR_TRC1_TMC. */

/*! @brief Read current value of the GPC_PGC_SCU_AUXSW_MEMPWR_TRC1_TMC field. */
#define BR_GPC_PGC_SCU_AUXSW_MEMPWR_TRC1_TMC(x) (HW_GPC_PGC_SCU_AUXSW(x).B.MEMPWR_TRC1_TMC)
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_MIX_CTRL - GPC PGC Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_MIX_CTRL - GPC PGC Control Register (RW)
 *
 * Reset value: 0x06040202U
 *
 * GPC PGC Control Register
 */
typedef union _hw_gpc_pgc_mix_ctrl
{
    uint32_t U;
    struct _hw_gpc_pgc_mix_ctrl_bitfields
    {
        uint32_t PCR : 1;              /*!< [0]  */
        uint32_t L2RSTDIS : 6;         /*!< [6:1]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t DFTRAM_TCD1 : 6;      /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t L2RETN_TCD1_TDR : 6;  /*!< [21:16]  */
        uint32_t RESERVED2 : 2;        /*!< [23:22]  */
        uint32_t MEMPWR_TCD1_TDR_TRM : 6; /*!< [29:24]  */
        uint32_t RESERVED3 : 2;        /*!< [31:30]  */
    } B;
} hw_gpc_pgc_mix_ctrl_t;

/*!
 * @name Constants and macros for entire GPC_PGC_MIX_CTRL register
 */
/*@{*/
#define HW_GPC_PGC_MIX_CTRL_ADDR(x) ((uintptr_t)(x) + 0xC0U)

#define HW_GPC_PGC_MIX_CTRL(x)   (*(__IO hw_gpc_pgc_mix_ctrl_t *) HW_GPC_PGC_MIX_CTRL_ADDR(x))
#define HW_GPC_PGC_MIX_CTRL_RD(x) (HW_GPC_PGC_MIX_CTRL(x).U)
#define HW_GPC_PGC_MIX_CTRL_WR(x, v) (HW_GPC_PGC_MIX_CTRL(x).U = (v))
#define HW_GPC_PGC_MIX_CTRL_SET(x, v) (HW_GPC_PGC_MIX_CTRL_WR(x, HW_GPC_PGC_MIX_CTRL_RD(x) |  (v)))
#define HW_GPC_PGC_MIX_CTRL_CLR(x, v) (HW_GPC_PGC_MIX_CTRL_WR(x, HW_GPC_PGC_MIX_CTRL_RD(x) & ~(v)))
#define HW_GPC_PGC_MIX_CTRL_TOG(x, v) (HW_GPC_PGC_MIX_CTRL_WR(x, HW_GPC_PGC_MIX_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_MIX_CTRL bitfields
 */

/*!
 * @name Register GPC_PGC_MIX_CTRL, field PCR[0] (RW)
 *
 * Power ControlPCR must not change from power-down request (pdn_req) assertion
 * until the target subsystem is completely powered up.
 *
 * Values:
 * - 0 - Do not switch off power even if pdn_req is asserted.
 * - 1 - Switch off power when pdn_req is asserted.
 */
/*@{*/
#define BP_GPC_PGC_MIX_CTRL_PCR (0U)       /*!< Bit position for GPC_PGC_MIX_CTRL_PCR. */
#define BM_GPC_PGC_MIX_CTRL_PCR (0x00000001U) /*!< Bit mask for GPC_PGC_MIX_CTRL_PCR. */
#define BS_GPC_PGC_MIX_CTRL_PCR (1U)       /*!< Bit field size in bits for GPC_PGC_MIX_CTRL_PCR. */

/*! @brief Read current value of the GPC_PGC_MIX_CTRL_PCR field. */
#define BR_GPC_PGC_MIX_CTRL_PCR(x) (HW_GPC_PGC_MIX_CTRL(x).B.PCR)

/*! @brief Format value for bitfield GPC_PGC_MIX_CTRL_PCR. */
#define BF_GPC_PGC_MIX_CTRL_PCR(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIX_CTRL_PCR) & BM_GPC_PGC_MIX_CTRL_PCR)

/*! @brief Set the PCR field to a new value. */
#define BW_GPC_PGC_MIX_CTRL_PCR(x, v) (HW_GPC_PGC_MIX_CTRL_WR(x, (HW_GPC_PGC_MIX_CTRL_RD(x) & ~BM_GPC_PGC_MIX_CTRL_PCR) | BF_GPC_PGC_MIX_CTRL_PCR(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIX_CTRL, field L2RSTDIS[6:1] (RW)
 *
 * After scu pdn_req, count this value to assert A7 l2rstdis to 1'b1, it will be
 * clear automatically once any of A7 core0/core1 is wakeup Can't be programmed
 * to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_MIX_CTRL_L2RSTDIS (1U)  /*!< Bit position for GPC_PGC_MIX_CTRL_L2RSTDIS. */
#define BM_GPC_PGC_MIX_CTRL_L2RSTDIS (0x0000007EU) /*!< Bit mask for GPC_PGC_MIX_CTRL_L2RSTDIS. */
#define BS_GPC_PGC_MIX_CTRL_L2RSTDIS (6U)  /*!< Bit field size in bits for GPC_PGC_MIX_CTRL_L2RSTDIS. */

/*! @brief Read current value of the GPC_PGC_MIX_CTRL_L2RSTDIS field. */
#define BR_GPC_PGC_MIX_CTRL_L2RSTDIS(x) (HW_GPC_PGC_MIX_CTRL(x).B.L2RSTDIS)

/*! @brief Format value for bitfield GPC_PGC_MIX_CTRL_L2RSTDIS. */
#define BF_GPC_PGC_MIX_CTRL_L2RSTDIS(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIX_CTRL_L2RSTDIS) & BM_GPC_PGC_MIX_CTRL_L2RSTDIS)

/*! @brief Set the L2RSTDIS field to a new value. */
#define BW_GPC_PGC_MIX_CTRL_L2RSTDIS(x, v) (HW_GPC_PGC_MIX_CTRL_WR(x, (HW_GPC_PGC_MIX_CTRL_RD(x) & ~BM_GPC_PGC_MIX_CTRL_L2RSTDIS) | BF_GPC_PGC_MIX_CTRL_L2RSTDIS(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIX_CTRL, field DFTRAM_TCD1[13:8] (RW)
 *
 * After scu pdn_req, count this value to assert A7 dftram to 1'b1 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_MIX_CTRL_DFTRAM_TCD1 (8U) /*!< Bit position for GPC_PGC_MIX_CTRL_DFTRAM_TCD1. */
#define BM_GPC_PGC_MIX_CTRL_DFTRAM_TCD1 (0x00003F00U) /*!< Bit mask for GPC_PGC_MIX_CTRL_DFTRAM_TCD1. */
#define BS_GPC_PGC_MIX_CTRL_DFTRAM_TCD1 (6U) /*!< Bit field size in bits for GPC_PGC_MIX_CTRL_DFTRAM_TCD1. */

/*! @brief Read current value of the GPC_PGC_MIX_CTRL_DFTRAM_TCD1 field. */
#define BR_GPC_PGC_MIX_CTRL_DFTRAM_TCD1(x) (HW_GPC_PGC_MIX_CTRL(x).B.DFTRAM_TCD1)

/*! @brief Format value for bitfield GPC_PGC_MIX_CTRL_DFTRAM_TCD1. */
#define BF_GPC_PGC_MIX_CTRL_DFTRAM_TCD1(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIX_CTRL_DFTRAM_TCD1) & BM_GPC_PGC_MIX_CTRL_DFTRAM_TCD1)

/*! @brief Set the DFTRAM_TCD1 field to a new value. */
#define BW_GPC_PGC_MIX_CTRL_DFTRAM_TCD1(x, v) (HW_GPC_PGC_MIX_CTRL_WR(x, (HW_GPC_PGC_MIX_CTRL_RD(x) & ~BM_GPC_PGC_MIX_CTRL_DFTRAM_TCD1) | BF_GPC_PGC_MIX_CTRL_DFTRAM_TCD1(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIX_CTRL, field L2RETN_TCD1_TDR[21:16] (RW)
 *
 * After scu pdn_req, count this value to assert A7 l2retn to 1'b0 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR (16U) /*!< Bit position for GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR. */
#define BM_GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR (0x003F0000U) /*!< Bit mask for GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR. */
#define BS_GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR (6U) /*!< Bit field size in bits for GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR. */

/*! @brief Read current value of the GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR field. */
#define BR_GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR(x) (HW_GPC_PGC_MIX_CTRL(x).B.L2RETN_TCD1_TDR)

/*! @brief Format value for bitfield GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR. */
#define BF_GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR) & BM_GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR)

/*! @brief Set the L2RETN_TCD1_TDR field to a new value. */
#define BW_GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR(x, v) (HW_GPC_PGC_MIX_CTRL_WR(x, (HW_GPC_PGC_MIX_CTRL_RD(x) & ~BM_GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR) | BF_GPC_PGC_MIX_CTRL_L2RETN_TCD1_TDR(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIX_CTRL, field MEMPWR_TCD1_TDR_TRM[29:24] (RW)
 *
 * After scu pdn_req, count this value to assert A7 mempwr to 1'b1 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM (24U) /*!< Bit position for GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BM_GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM (0x3F000000U) /*!< Bit mask for GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BS_GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM (6U) /*!< Bit field size in bits for GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM. */

/*! @brief Read current value of the GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM field. */
#define BR_GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM(x) (HW_GPC_PGC_MIX_CTRL(x).B.MEMPWR_TCD1_TDR_TRM)

/*! @brief Format value for bitfield GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BF_GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM) & BM_GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM)

/*! @brief Set the MEMPWR_TCD1_TDR_TRM field to a new value. */
#define BW_GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM(x, v) (HW_GPC_PGC_MIX_CTRL_WR(x, (HW_GPC_PGC_MIX_CTRL_RD(x) & ~BM_GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM) | BF_GPC_PGC_MIX_CTRL_MEMPWR_TCD1_TDR_TRM(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_MIX_PUPSCR - GPC PGC Up Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_MIX_PUPSCR - GPC PGC Up Sequence Control Register (RW)
 *
 * Reset value: 0x000997C1U
 *
 * GPC PGC Up Sequence Control Register
 */
typedef union _hw_gpc_pgc_mix_pupscr
{
    uint32_t U;
    struct _hw_gpc_pgc_mix_pupscr_bitfields
    {
        uint32_t SW : 6;               /*!< [5:0]  */
        uint32_t PUP_WAIT_SCALL_OUT : 1; /*!< [6]  */
        uint32_t SW2ISO : 16;          /*!< [22:7]  */
        uint32_t PUP_SCALL_SCALLOUT_CNT : 9; /*!< [31:23]  */
    } B;
} hw_gpc_pgc_mix_pupscr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_MIX_PUPSCR register
 */
/*@{*/
#define HW_GPC_PGC_MIX_PUPSCR_ADDR(x) ((uintptr_t)(x) + 0xC4U)

#define HW_GPC_PGC_MIX_PUPSCR(x) (*(__IO hw_gpc_pgc_mix_pupscr_t *) HW_GPC_PGC_MIX_PUPSCR_ADDR(x))
#define HW_GPC_PGC_MIX_PUPSCR_RD(x) (HW_GPC_PGC_MIX_PUPSCR(x).U)
#define HW_GPC_PGC_MIX_PUPSCR_WR(x, v) (HW_GPC_PGC_MIX_PUPSCR(x).U = (v))
#define HW_GPC_PGC_MIX_PUPSCR_SET(x, v) (HW_GPC_PGC_MIX_PUPSCR_WR(x, HW_GPC_PGC_MIX_PUPSCR_RD(x) |  (v)))
#define HW_GPC_PGC_MIX_PUPSCR_CLR(x, v) (HW_GPC_PGC_MIX_PUPSCR_WR(x, HW_GPC_PGC_MIX_PUPSCR_RD(x) & ~(v)))
#define HW_GPC_PGC_MIX_PUPSCR_TOG(x, v) (HW_GPC_PGC_MIX_PUPSCR_WR(x, HW_GPC_PGC_MIX_PUPSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_MIX_PUPSCR bitfields
 */

/*!
 * @name Register GPC_PGC_MIX_PUPSCR, field SW[5:0] (RW)
 *
 * After a power-up request (pup_req assertion), the PGC waits a number of
 * clocks equal to the value of SW before asserting switch_b SW must not be programmed
 * to zero.
 */
/*@{*/
#define BP_GPC_PGC_MIX_PUPSCR_SW (0U)      /*!< Bit position for GPC_PGC_MIX_PUPSCR_SW. */
#define BM_GPC_PGC_MIX_PUPSCR_SW (0x0000003FU) /*!< Bit mask for GPC_PGC_MIX_PUPSCR_SW. */
#define BS_GPC_PGC_MIX_PUPSCR_SW (6U)      /*!< Bit field size in bits for GPC_PGC_MIX_PUPSCR_SW. */

/*! @brief Read current value of the GPC_PGC_MIX_PUPSCR_SW field. */
#define BR_GPC_PGC_MIX_PUPSCR_SW(x) (HW_GPC_PGC_MIX_PUPSCR(x).B.SW)

/*! @brief Format value for bitfield GPC_PGC_MIX_PUPSCR_SW. */
#define BF_GPC_PGC_MIX_PUPSCR_SW(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIX_PUPSCR_SW) & BM_GPC_PGC_MIX_PUPSCR_SW)

/*! @brief Set the SW field to a new value. */
#define BW_GPC_PGC_MIX_PUPSCR_SW(x, v) (HW_GPC_PGC_MIX_PUPSCR_WR(x, (HW_GPC_PGC_MIX_PUPSCR_RD(x) & ~BM_GPC_PGC_MIX_PUPSCR_SW) | BF_GPC_PGC_MIX_PUPSCR_SW(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIX_PUPSCR, field PUP_WAIT_SCALL_OUT[6] (RW)
 *
 * After SCALL asserting to 1'b0, wait handshake signal SCALL_OUT to return to
 * 1'b0 (This register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_MIX_PUPSCR_PUP_WAIT_SCALL_OUT (6U) /*!< Bit position for GPC_PGC_MIX_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BM_GPC_PGC_MIX_PUPSCR_PUP_WAIT_SCALL_OUT (0x00000040U) /*!< Bit mask for GPC_PGC_MIX_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BS_GPC_PGC_MIX_PUPSCR_PUP_WAIT_SCALL_OUT (1U) /*!< Bit field size in bits for GPC_PGC_MIX_PUPSCR_PUP_WAIT_SCALL_OUT. */

/*! @brief Read current value of the GPC_PGC_MIX_PUPSCR_PUP_WAIT_SCALL_OUT field. */
#define BR_GPC_PGC_MIX_PUPSCR_PUP_WAIT_SCALL_OUT(x) (HW_GPC_PGC_MIX_PUPSCR(x).B.PUP_WAIT_SCALL_OUT)

/*! @brief Format value for bitfield GPC_PGC_MIX_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BF_GPC_PGC_MIX_PUPSCR_PUP_WAIT_SCALL_OUT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIX_PUPSCR_PUP_WAIT_SCALL_OUT) & BM_GPC_PGC_MIX_PUPSCR_PUP_WAIT_SCALL_OUT)

/*! @brief Set the PUP_WAIT_SCALL_OUT field to a new value. */
#define BW_GPC_PGC_MIX_PUPSCR_PUP_WAIT_SCALL_OUT(x, v) (HW_GPC_PGC_MIX_PUPSCR_WR(x, (HW_GPC_PGC_MIX_PUPSCR_RD(x) & ~BM_GPC_PGC_MIX_PUPSCR_PUP_WAIT_SCALL_OUT) | BF_GPC_PGC_MIX_PUPSCR_PUP_WAIT_SCALL_OUT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIX_PUPSCR, field SW2ISO[22:7] (RW)
 *
 * After asserting switch_b, the PGC waits a number of clocks equal to the value
 * of SW2ISO before negating isolation.
 */
/*@{*/
#define BP_GPC_PGC_MIX_PUPSCR_SW2ISO (7U)  /*!< Bit position for GPC_PGC_MIX_PUPSCR_SW2ISO. */
#define BM_GPC_PGC_MIX_PUPSCR_SW2ISO (0x007FFF80U) /*!< Bit mask for GPC_PGC_MIX_PUPSCR_SW2ISO. */
#define BS_GPC_PGC_MIX_PUPSCR_SW2ISO (16U) /*!< Bit field size in bits for GPC_PGC_MIX_PUPSCR_SW2ISO. */

/*! @brief Read current value of the GPC_PGC_MIX_PUPSCR_SW2ISO field. */
#define BR_GPC_PGC_MIX_PUPSCR_SW2ISO(x) (HW_GPC_PGC_MIX_PUPSCR(x).B.SW2ISO)

/*! @brief Format value for bitfield GPC_PGC_MIX_PUPSCR_SW2ISO. */
#define BF_GPC_PGC_MIX_PUPSCR_SW2ISO(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIX_PUPSCR_SW2ISO) & BM_GPC_PGC_MIX_PUPSCR_SW2ISO)

/*! @brief Set the SW2ISO field to a new value. */
#define BW_GPC_PGC_MIX_PUPSCR_SW2ISO(x, v) (HW_GPC_PGC_MIX_PUPSCR_WR(x, (HW_GPC_PGC_MIX_PUPSCR_RD(x) & ~BM_GPC_PGC_MIX_PUPSCR_SW2ISO) | BF_GPC_PGC_MIX_PUPSCR_SW2ISO(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIX_PUPSCR, field PUP_SCALL_SCALLOUT_CNT[31:23] (RW)
 *
 * After SCALL asserting to 1'b0, count this value to complete switch power up
 * Only valid when pup_wait_scall_out is set to 1'b0. Can't be programmed to zero
 * (This register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT (23U) /*!< Bit position for GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */
#define BM_GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT (0xFF800000U) /*!< Bit mask for GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */
#define BS_GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT (9U) /*!< Bit field size in bits for GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */

/*! @brief Read current value of the GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT field. */
#define BR_GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT(x) (HW_GPC_PGC_MIX_PUPSCR(x).B.PUP_SCALL_SCALLOUT_CNT)

/*! @brief Format value for bitfield GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */
#define BF_GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT) & BM_GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT)

/*! @brief Set the PUP_SCALL_SCALLOUT_CNT field to a new value. */
#define BW_GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT(x, v) (HW_GPC_PGC_MIX_PUPSCR_WR(x, (HW_GPC_PGC_MIX_PUPSCR_RD(x) & ~BM_GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT) | BF_GPC_PGC_MIX_PUPSCR_PUP_SCALL_SCALLOUT_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_MIX_PDNSCR - GPC PGC Down Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_MIX_PDNSCR - GPC PGC Down Sequence Control Register (RW)
 *
 * Reset value: 0x21000801U
 *
 * GPC PGC Down Sequence Control Register
 */
typedef union _hw_gpc_pgc_mix_pdnscr
{
    uint32_t U;
    struct _hw_gpc_pgc_mix_pdnscr_bitfields
    {
        uint32_t ISO : 6;              /*!< [5:0]  */
        uint32_t RESERVED0 : 1;        /*!< [6]  */
        uint32_t PDN_WAIT_SCALL_OUT : 1; /*!< [7] Default 1'b0 */
        uint32_t ISO2SW : 6;           /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t PDN_SCALL_SCALLOUT_CNT : 8; /*!< [23:16]  */
        uint32_t PUP_SCPRE_SCALL_CNT : 8; /*!< [31:24]  */
    } B;
} hw_gpc_pgc_mix_pdnscr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_MIX_PDNSCR register
 */
/*@{*/
#define HW_GPC_PGC_MIX_PDNSCR_ADDR(x) ((uintptr_t)(x) + 0xC8U)

#define HW_GPC_PGC_MIX_PDNSCR(x) (*(__IO hw_gpc_pgc_mix_pdnscr_t *) HW_GPC_PGC_MIX_PDNSCR_ADDR(x))
#define HW_GPC_PGC_MIX_PDNSCR_RD(x) (HW_GPC_PGC_MIX_PDNSCR(x).U)
#define HW_GPC_PGC_MIX_PDNSCR_WR(x, v) (HW_GPC_PGC_MIX_PDNSCR(x).U = (v))
#define HW_GPC_PGC_MIX_PDNSCR_SET(x, v) (HW_GPC_PGC_MIX_PDNSCR_WR(x, HW_GPC_PGC_MIX_PDNSCR_RD(x) |  (v)))
#define HW_GPC_PGC_MIX_PDNSCR_CLR(x, v) (HW_GPC_PGC_MIX_PDNSCR_WR(x, HW_GPC_PGC_MIX_PDNSCR_RD(x) & ~(v)))
#define HW_GPC_PGC_MIX_PDNSCR_TOG(x, v) (HW_GPC_PGC_MIX_PDNSCR_WR(x, HW_GPC_PGC_MIX_PDNSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_MIX_PDNSCR bitfields
 */

/*!
 * @name Register GPC_PGC_MIX_PDNSCR, field ISO[5:0] (RW)
 *
 * Aafte a power-down request (pdn_req assertion), the PGC waits a number of
 * clocks equal to the value of ISO before asserting isolation ISO must not be
 * programmed to zero.
 */
/*@{*/
#define BP_GPC_PGC_MIX_PDNSCR_ISO (0U)     /*!< Bit position for GPC_PGC_MIX_PDNSCR_ISO. */
#define BM_GPC_PGC_MIX_PDNSCR_ISO (0x0000003FU) /*!< Bit mask for GPC_PGC_MIX_PDNSCR_ISO. */
#define BS_GPC_PGC_MIX_PDNSCR_ISO (6U)     /*!< Bit field size in bits for GPC_PGC_MIX_PDNSCR_ISO. */

/*! @brief Read current value of the GPC_PGC_MIX_PDNSCR_ISO field. */
#define BR_GPC_PGC_MIX_PDNSCR_ISO(x) (HW_GPC_PGC_MIX_PDNSCR(x).B.ISO)

/*! @brief Format value for bitfield GPC_PGC_MIX_PDNSCR_ISO. */
#define BF_GPC_PGC_MIX_PDNSCR_ISO(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIX_PDNSCR_ISO) & BM_GPC_PGC_MIX_PDNSCR_ISO)

/*! @brief Set the ISO field to a new value. */
#define BW_GPC_PGC_MIX_PDNSCR_ISO(x, v) (HW_GPC_PGC_MIX_PDNSCR_WR(x, (HW_GPC_PGC_MIX_PDNSCR_RD(x) & ~BM_GPC_PGC_MIX_PDNSCR_ISO) | BF_GPC_PGC_MIX_PDNSCR_ISO(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIX_PDNSCR, field PDN_WAIT_SCALL_OUT[7] (RW)
 *
 * If set to 1'b1, after SCALL asserting to 1'b1, wait handshake signal
 * SCALL_OUT to change to 1'b1. This register control is only for MIX Type PGC.
 */
/*@{*/
#define BP_GPC_PGC_MIX_PDNSCR_PDN_WAIT_SCALL_OUT (7U) /*!< Bit position for GPC_PGC_MIX_PDNSCR_PDN_WAIT_SCALL_OUT. */
#define BM_GPC_PGC_MIX_PDNSCR_PDN_WAIT_SCALL_OUT (0x00000080U) /*!< Bit mask for GPC_PGC_MIX_PDNSCR_PDN_WAIT_SCALL_OUT. */
#define BS_GPC_PGC_MIX_PDNSCR_PDN_WAIT_SCALL_OUT (1U) /*!< Bit field size in bits for GPC_PGC_MIX_PDNSCR_PDN_WAIT_SCALL_OUT. */

/*! @brief Read current value of the GPC_PGC_MIX_PDNSCR_PDN_WAIT_SCALL_OUT field. */
#define BR_GPC_PGC_MIX_PDNSCR_PDN_WAIT_SCALL_OUT(x) (HW_GPC_PGC_MIX_PDNSCR(x).B.PDN_WAIT_SCALL_OUT)

/*! @brief Format value for bitfield GPC_PGC_MIX_PDNSCR_PDN_WAIT_SCALL_OUT. */
#define BF_GPC_PGC_MIX_PDNSCR_PDN_WAIT_SCALL_OUT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIX_PDNSCR_PDN_WAIT_SCALL_OUT) & BM_GPC_PGC_MIX_PDNSCR_PDN_WAIT_SCALL_OUT)

/*! @brief Set the PDN_WAIT_SCALL_OUT field to a new value. */
#define BW_GPC_PGC_MIX_PDNSCR_PDN_WAIT_SCALL_OUT(x, v) (HW_GPC_PGC_MIX_PDNSCR_WR(x, (HW_GPC_PGC_MIX_PDNSCR_RD(x) & ~BM_GPC_PGC_MIX_PDNSCR_PDN_WAIT_SCALL_OUT) | BF_GPC_PGC_MIX_PDNSCR_PDN_WAIT_SCALL_OUT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIX_PDNSCR, field ISO2SW[13:8] (RW)
 *
 * After asserting isolation(by pdn_req assertion), the PGC waits a number of
 * clocks equal to the value of ISO2SW before negating switch_b ISO2SW must not be
 * programmed to zero.
 */
/*@{*/
#define BP_GPC_PGC_MIX_PDNSCR_ISO2SW (8U)  /*!< Bit position for GPC_PGC_MIX_PDNSCR_ISO2SW. */
#define BM_GPC_PGC_MIX_PDNSCR_ISO2SW (0x00003F00U) /*!< Bit mask for GPC_PGC_MIX_PDNSCR_ISO2SW. */
#define BS_GPC_PGC_MIX_PDNSCR_ISO2SW (6U)  /*!< Bit field size in bits for GPC_PGC_MIX_PDNSCR_ISO2SW. */

/*! @brief Read current value of the GPC_PGC_MIX_PDNSCR_ISO2SW field. */
#define BR_GPC_PGC_MIX_PDNSCR_ISO2SW(x) (HW_GPC_PGC_MIX_PDNSCR(x).B.ISO2SW)

/*! @brief Format value for bitfield GPC_PGC_MIX_PDNSCR_ISO2SW. */
#define BF_GPC_PGC_MIX_PDNSCR_ISO2SW(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIX_PDNSCR_ISO2SW) & BM_GPC_PGC_MIX_PDNSCR_ISO2SW)

/*! @brief Set the ISO2SW field to a new value. */
#define BW_GPC_PGC_MIX_PDNSCR_ISO2SW(x, v) (HW_GPC_PGC_MIX_PDNSCR_WR(x, (HW_GPC_PGC_MIX_PDNSCR_RD(x) & ~BM_GPC_PGC_MIX_PDNSCR_ISO2SW) | BF_GPC_PGC_MIX_PDNSCR_ISO2SW(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIX_PDNSCR, field PDN_SCALL_SCALLOUT_CNT[23:16] (RW)
 *
 * Default 8'h0. After SCALL asserting to 1'b1, count this value to complete
 * switch power down. This control is only valid when pdn_wait_scall_out is set to
 * 1'b0. It can be programmed to zero. (This register control only for MIX Type
 * PGC)
 */
/*@{*/
#define BP_GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT (16U) /*!< Bit position for GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */
#define BM_GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT (0x00FF0000U) /*!< Bit mask for GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */
#define BS_GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT (8U) /*!< Bit field size in bits for GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */

/*! @brief Read current value of the GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT field. */
#define BR_GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT(x) (HW_GPC_PGC_MIX_PDNSCR(x).B.PDN_SCALL_SCALLOUT_CNT)

/*! @brief Format value for bitfield GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */
#define BF_GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT) & BM_GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT)

/*! @brief Set the PDN_SCALL_SCALLOUT_CNT field to a new value. */
#define BW_GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT(x, v) (HW_GPC_PGC_MIX_PDNSCR_WR(x, (HW_GPC_PGC_MIX_PDNSCR_RD(x) & ~BM_GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT) | BF_GPC_PGC_MIX_PDNSCR_PDN_SCALL_SCALLOUT_CNT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIX_PDNSCR, field PUP_SCPRE_SCALL_CNT[31:24] (RW)
 *
 * After SCPRE asserting to 1'b0, count this value to assert SCALL to 1'b0 (This
 * register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT (24U) /*!< Bit position for GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BM_GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT (0xFF000000U) /*!< Bit mask for GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BS_GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT (8U) /*!< Bit field size in bits for GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT. */

/*! @brief Read current value of the GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT field. */
#define BR_GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT(x) (HW_GPC_PGC_MIX_PDNSCR(x).B.PUP_SCPRE_SCALL_CNT)

/*! @brief Format value for bitfield GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BF_GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT) & BM_GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT)

/*! @brief Set the PUP_SCPRE_SCALL_CNT field to a new value. */
#define BW_GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT(x, v) (HW_GPC_PGC_MIX_PDNSCR_WR(x, (HW_GPC_PGC_MIX_PDNSCR_RD(x) & ~BM_GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT) | BF_GPC_PGC_MIX_PDNSCR_PUP_SCPRE_SCALL_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_MIX_SR - GPC PGC Status Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_MIX_SR - GPC PGC Status Register (RW)
 *
 * Reset value: 0x00001000U
 *
 * GPC PGC Status Register
 */
typedef union _hw_gpc_pgc_mix_sr
{
    uint32_t U;
    struct _hw_gpc_pgc_mix_sr_bitfields
    {
        uint32_t PSR : 1;              /*!< [0]  */
        uint32_t L2RETN_FLAG : 1;      /*!< [1]  */
        uint32_t ALLOFF_FLAG : 1;      /*!< [2]  */
        uint32_t PUP_CLK_DIV_SEL : 4;  /*!< [6:3]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t L2RSTDIS_DEASSERT_CNT : 10; /*!< [17:8]  */
        uint32_t RESERVED1 : 14;       /*!< [31:18]  */
    } B;
} hw_gpc_pgc_mix_sr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_MIX_SR register
 */
/*@{*/
#define HW_GPC_PGC_MIX_SR_ADDR(x) ((uintptr_t)(x) + 0xCCU)

#define HW_GPC_PGC_MIX_SR(x)     (*(__IO hw_gpc_pgc_mix_sr_t *) HW_GPC_PGC_MIX_SR_ADDR(x))
#define HW_GPC_PGC_MIX_SR_RD(x)  (HW_GPC_PGC_MIX_SR(x).U)
#define HW_GPC_PGC_MIX_SR_WR(x, v) (HW_GPC_PGC_MIX_SR(x).U = (v))
#define HW_GPC_PGC_MIX_SR_SET(x, v) (HW_GPC_PGC_MIX_SR_WR(x, HW_GPC_PGC_MIX_SR_RD(x) |  (v)))
#define HW_GPC_PGC_MIX_SR_CLR(x, v) (HW_GPC_PGC_MIX_SR_WR(x, HW_GPC_PGC_MIX_SR_RD(x) & ~(v)))
#define HW_GPC_PGC_MIX_SR_TOG(x, v) (HW_GPC_PGC_MIX_SR_WR(x, HW_GPC_PGC_MIX_SR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_MIX_SR bitfields
 */

/*!
 * @name Register GPC_PGC_MIX_SR, field PSR[0] (RO)
 *
 * Power status. When in functional (or software-controlled debug) mode, PGC
 * hardware sets PSR as soon as any of the power control output changes its state to
 * one. Write one to clear this bit. Software should clear this bit after power
 * up; otherwise, PSR continues to reflect the power status of the initial power
 * down.
 *
 * Values:
 * - 0 - The target subsystem was not powered down for the previous power-down
 *     request.
 * - 1 - The target subsystem was powered down for the previous power-down
 *     request.
 */
/*@{*/
#define BP_GPC_PGC_MIX_SR_PSR (0U)         /*!< Bit position for GPC_PGC_MIX_SR_PSR. */
#define BM_GPC_PGC_MIX_SR_PSR (0x00000001U) /*!< Bit mask for GPC_PGC_MIX_SR_PSR. */
#define BS_GPC_PGC_MIX_SR_PSR (1U)         /*!< Bit field size in bits for GPC_PGC_MIX_SR_PSR. */

/*! @brief Read current value of the GPC_PGC_MIX_SR_PSR field. */
#define BR_GPC_PGC_MIX_SR_PSR(x) (HW_GPC_PGC_MIX_SR(x).B.PSR)
/*@}*/

/*!
 * @name Register GPC_PGC_MIX_SR, field L2RETN_FLAG[1] (RO)
 *
 * L2 Retention Flag Software should write "1" to clear this flag after A7 is
 * wakeup from L2 retention mode, otherwise it will always keep to 1 (This register
 * control only for SCU Type PGC)
 *
 * Values:
 * - 0 - A7 is not wakeup from L2 retention mode.
 * - 1 - A7 is wakeup from L2 retention mode.
 */
/*@{*/
#define BP_GPC_PGC_MIX_SR_L2RETN_FLAG (1U) /*!< Bit position for GPC_PGC_MIX_SR_L2RETN_FLAG. */
#define BM_GPC_PGC_MIX_SR_L2RETN_FLAG (0x00000002U) /*!< Bit mask for GPC_PGC_MIX_SR_L2RETN_FLAG. */
#define BS_GPC_PGC_MIX_SR_L2RETN_FLAG (1U) /*!< Bit field size in bits for GPC_PGC_MIX_SR_L2RETN_FLAG. */

/*! @brief Read current value of the GPC_PGC_MIX_SR_L2RETN_FLAG field. */
#define BR_GPC_PGC_MIX_SR_L2RETN_FLAG(x) (HW_GPC_PGC_MIX_SR(x).B.L2RETN_FLAG)
/*@}*/

/*!
 * @name Register GPC_PGC_MIX_SR, field ALLOFF_FLAG[2] (RO)
 *
 * All-off flag. Software should write "1" to clear this flag after A7 is wakeup
 * from ALL_OFF mode, otherwise, it will always keep to 1 (This register control
 * only for SCU Type PGC)
 *
 * Values:
 * - 0 - A7 is not wakeup from ALL_OFF mode.
 * - 1 - A7 is wakeup from ALL_OFF mode.
 */
/*@{*/
#define BP_GPC_PGC_MIX_SR_ALLOFF_FLAG (2U) /*!< Bit position for GPC_PGC_MIX_SR_ALLOFF_FLAG. */
#define BM_GPC_PGC_MIX_SR_ALLOFF_FLAG (0x00000004U) /*!< Bit mask for GPC_PGC_MIX_SR_ALLOFF_FLAG. */
#define BS_GPC_PGC_MIX_SR_ALLOFF_FLAG (1U) /*!< Bit field size in bits for GPC_PGC_MIX_SR_ALLOFF_FLAG. */

/*! @brief Read current value of the GPC_PGC_MIX_SR_ALLOFF_FLAG field. */
#define BR_GPC_PGC_MIX_SR_ALLOFF_FLAG(x) (HW_GPC_PGC_MIX_SR(x).B.ALLOFF_FLAG)
/*@}*/

/*!
 * @name Register GPC_PGC_MIX_SR, field PUP_CLK_DIV_SEL[6:3] (RW)
 *
 * Clock divider select for the clock of power up counter(count_clk is 32KHz for
 * CPU/SCU type PGC, ipg_clk(66MHz) for MIX/PU Type PGC)
 *
 * Values:
 * - 0000 - 1
 * - 0001 - 1/2 count_clk
 * - 0010 - 1/4 count_clk
 * - 0011 - 1/8 count_clk
 * - 0100 - 1/16 count_clk
 * - 0101 - 1/32 count_clk
 * - 0110 - 1/64 count_clk
 * - 0111 - 1/128 count_clk
 * - 1000 - 1/256 count_clk
 * - 1001 - 1/512 count_clk
 * - 1010 - 1/1024 count_clk
 * - 1011 - 1/2056 count_clk
 * - 1100 - 1/4096 count_clk
 * - 1101 - 1/8192 count_clk
 * - 1110 - 1/16384 count_clk
 * - 1111 - 1/32768 count_clk
 */
/*@{*/
#define BP_GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL (3U) /*!< Bit position for GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL. */
#define BM_GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL (0x00000078U) /*!< Bit mask for GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL. */
#define BS_GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL (4U) /*!< Bit field size in bits for GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL. */

/*! @brief Read current value of the GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL field. */
#define BR_GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL(x) (HW_GPC_PGC_MIX_SR(x).B.PUP_CLK_DIV_SEL)

/*! @brief Format value for bitfield GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL. */
#define BF_GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL) & BM_GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL)

/*! @brief Set the PUP_CLK_DIV_SEL field to a new value. */
#define BW_GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL(x, v) (HW_GPC_PGC_MIX_SR_WR(x, (HW_GPC_PGC_MIX_SR_RD(x) & ~BM_GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL) | BF_GPC_PGC_MIX_SR_PUP_CLK_DIV_SEL(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIX_SR, field L2RSTDIS_DEASSERT_CNT[17:8] (RW)
 *
 * Count this value to de-assert L2RSTDISABLE to LOW after CPU0 or CPU1 power up
 * This value can't be programmed to zero (This register control only for SCU
 * Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT (8U) /*!< Bit position for GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT. */
#define BM_GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT (0x0003FF00U) /*!< Bit mask for GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT. */
#define BS_GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT (10U) /*!< Bit field size in bits for GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT. */

/*! @brief Read current value of the GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT field. */
#define BR_GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT(x) (HW_GPC_PGC_MIX_SR(x).B.L2RSTDIS_DEASSERT_CNT)

/*! @brief Format value for bitfield GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT. */
#define BF_GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT) & BM_GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT)

/*! @brief Set the L2RSTDIS_DEASSERT_CNT field to a new value. */
#define BW_GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT(x, v) (HW_GPC_PGC_MIX_SR_WR(x, (HW_GPC_PGC_MIX_SR_RD(x) & ~BM_GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT) | BF_GPC_PGC_MIX_SR_L2RSTDIS_DEASSERT_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_MIPI_CTRL - GPC PGC Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_MIPI_CTRL - GPC PGC Control Register (RW)
 *
 * Reset value: 0x06040202U
 *
 * GPC PGC Control Register
 */
typedef union _hw_gpc_pgc_mipi_ctrl
{
    uint32_t U;
    struct _hw_gpc_pgc_mipi_ctrl_bitfields
    {
        uint32_t PCR : 1;              /*!< [0]  */
        uint32_t L2RSTDIS : 6;         /*!< [6:1]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t DFTRAM_TCD1 : 6;      /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t L2RETN_TCD1_TDR : 6;  /*!< [21:16]  */
        uint32_t RESERVED2 : 2;        /*!< [23:22]  */
        uint32_t MEMPWR_TCD1_TDR_TRM : 6; /*!< [29:24]  */
        uint32_t RESERVED3 : 2;        /*!< [31:30]  */
    } B;
} hw_gpc_pgc_mipi_ctrl_t;

/*!
 * @name Constants and macros for entire GPC_PGC_MIPI_CTRL register
 */
/*@{*/
#define HW_GPC_PGC_MIPI_CTRL_ADDR(x) ((uintptr_t)(x) + 0x100U)

#define HW_GPC_PGC_MIPI_CTRL(x)  (*(__IO hw_gpc_pgc_mipi_ctrl_t *) HW_GPC_PGC_MIPI_CTRL_ADDR(x))
#define HW_GPC_PGC_MIPI_CTRL_RD(x) (HW_GPC_PGC_MIPI_CTRL(x).U)
#define HW_GPC_PGC_MIPI_CTRL_WR(x, v) (HW_GPC_PGC_MIPI_CTRL(x).U = (v))
#define HW_GPC_PGC_MIPI_CTRL_SET(x, v) (HW_GPC_PGC_MIPI_CTRL_WR(x, HW_GPC_PGC_MIPI_CTRL_RD(x) |  (v)))
#define HW_GPC_PGC_MIPI_CTRL_CLR(x, v) (HW_GPC_PGC_MIPI_CTRL_WR(x, HW_GPC_PGC_MIPI_CTRL_RD(x) & ~(v)))
#define HW_GPC_PGC_MIPI_CTRL_TOG(x, v) (HW_GPC_PGC_MIPI_CTRL_WR(x, HW_GPC_PGC_MIPI_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_MIPI_CTRL bitfields
 */

/*!
 * @name Register GPC_PGC_MIPI_CTRL, field PCR[0] (RW)
 *
 * Power ControlPCR must not change from power-down request (pdn_req) assertion
 * until the target subsystem is completely powered up.
 *
 * Values:
 * - 0 - Do not switch off power even if pdn_req is asserted.
 * - 1 - Switch off power when pdn_req is asserted.
 */
/*@{*/
#define BP_GPC_PGC_MIPI_CTRL_PCR (0U)      /*!< Bit position for GPC_PGC_MIPI_CTRL_PCR. */
#define BM_GPC_PGC_MIPI_CTRL_PCR (0x00000001U) /*!< Bit mask for GPC_PGC_MIPI_CTRL_PCR. */
#define BS_GPC_PGC_MIPI_CTRL_PCR (1U)      /*!< Bit field size in bits for GPC_PGC_MIPI_CTRL_PCR. */

/*! @brief Read current value of the GPC_PGC_MIPI_CTRL_PCR field. */
#define BR_GPC_PGC_MIPI_CTRL_PCR(x) (HW_GPC_PGC_MIPI_CTRL(x).B.PCR)

/*! @brief Format value for bitfield GPC_PGC_MIPI_CTRL_PCR. */
#define BF_GPC_PGC_MIPI_CTRL_PCR(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIPI_CTRL_PCR) & BM_GPC_PGC_MIPI_CTRL_PCR)

/*! @brief Set the PCR field to a new value. */
#define BW_GPC_PGC_MIPI_CTRL_PCR(x, v) (HW_GPC_PGC_MIPI_CTRL_WR(x, (HW_GPC_PGC_MIPI_CTRL_RD(x) & ~BM_GPC_PGC_MIPI_CTRL_PCR) | BF_GPC_PGC_MIPI_CTRL_PCR(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIPI_CTRL, field L2RSTDIS[6:1] (RW)
 *
 * After scu pdn_req, count this value to assert A7 l2rstdis to 1'b1, it will be
 * clear automatically once any of A7 core0/core1 is wakeup Can't be programmed
 * to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_MIPI_CTRL_L2RSTDIS (1U) /*!< Bit position for GPC_PGC_MIPI_CTRL_L2RSTDIS. */
#define BM_GPC_PGC_MIPI_CTRL_L2RSTDIS (0x0000007EU) /*!< Bit mask for GPC_PGC_MIPI_CTRL_L2RSTDIS. */
#define BS_GPC_PGC_MIPI_CTRL_L2RSTDIS (6U) /*!< Bit field size in bits for GPC_PGC_MIPI_CTRL_L2RSTDIS. */

/*! @brief Read current value of the GPC_PGC_MIPI_CTRL_L2RSTDIS field. */
#define BR_GPC_PGC_MIPI_CTRL_L2RSTDIS(x) (HW_GPC_PGC_MIPI_CTRL(x).B.L2RSTDIS)

/*! @brief Format value for bitfield GPC_PGC_MIPI_CTRL_L2RSTDIS. */
#define BF_GPC_PGC_MIPI_CTRL_L2RSTDIS(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIPI_CTRL_L2RSTDIS) & BM_GPC_PGC_MIPI_CTRL_L2RSTDIS)

/*! @brief Set the L2RSTDIS field to a new value. */
#define BW_GPC_PGC_MIPI_CTRL_L2RSTDIS(x, v) (HW_GPC_PGC_MIPI_CTRL_WR(x, (HW_GPC_PGC_MIPI_CTRL_RD(x) & ~BM_GPC_PGC_MIPI_CTRL_L2RSTDIS) | BF_GPC_PGC_MIPI_CTRL_L2RSTDIS(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIPI_CTRL, field DFTRAM_TCD1[13:8] (RW)
 *
 * After scu pdn_req, count this value to assert A7 dftram to 1'b1 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_MIPI_CTRL_DFTRAM_TCD1 (8U) /*!< Bit position for GPC_PGC_MIPI_CTRL_DFTRAM_TCD1. */
#define BM_GPC_PGC_MIPI_CTRL_DFTRAM_TCD1 (0x00003F00U) /*!< Bit mask for GPC_PGC_MIPI_CTRL_DFTRAM_TCD1. */
#define BS_GPC_PGC_MIPI_CTRL_DFTRAM_TCD1 (6U) /*!< Bit field size in bits for GPC_PGC_MIPI_CTRL_DFTRAM_TCD1. */

/*! @brief Read current value of the GPC_PGC_MIPI_CTRL_DFTRAM_TCD1 field. */
#define BR_GPC_PGC_MIPI_CTRL_DFTRAM_TCD1(x) (HW_GPC_PGC_MIPI_CTRL(x).B.DFTRAM_TCD1)

/*! @brief Format value for bitfield GPC_PGC_MIPI_CTRL_DFTRAM_TCD1. */
#define BF_GPC_PGC_MIPI_CTRL_DFTRAM_TCD1(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIPI_CTRL_DFTRAM_TCD1) & BM_GPC_PGC_MIPI_CTRL_DFTRAM_TCD1)

/*! @brief Set the DFTRAM_TCD1 field to a new value. */
#define BW_GPC_PGC_MIPI_CTRL_DFTRAM_TCD1(x, v) (HW_GPC_PGC_MIPI_CTRL_WR(x, (HW_GPC_PGC_MIPI_CTRL_RD(x) & ~BM_GPC_PGC_MIPI_CTRL_DFTRAM_TCD1) | BF_GPC_PGC_MIPI_CTRL_DFTRAM_TCD1(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIPI_CTRL, field L2RETN_TCD1_TDR[21:16] (RW)
 *
 * After scu pdn_req, count this value to assert A7 l2retn to 1'b0 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR (16U) /*!< Bit position for GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR. */
#define BM_GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR (0x003F0000U) /*!< Bit mask for GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR. */
#define BS_GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR (6U) /*!< Bit field size in bits for GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR. */

/*! @brief Read current value of the GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR field. */
#define BR_GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR(x) (HW_GPC_PGC_MIPI_CTRL(x).B.L2RETN_TCD1_TDR)

/*! @brief Format value for bitfield GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR. */
#define BF_GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR) & BM_GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR)

/*! @brief Set the L2RETN_TCD1_TDR field to a new value. */
#define BW_GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR(x, v) (HW_GPC_PGC_MIPI_CTRL_WR(x, (HW_GPC_PGC_MIPI_CTRL_RD(x) & ~BM_GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR) | BF_GPC_PGC_MIPI_CTRL_L2RETN_TCD1_TDR(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIPI_CTRL, field MEMPWR_TCD1_TDR_TRM[29:24] (RW)
 *
 * After scu pdn_req, count this value to assert A7 mempwr to 1'b1 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM (24U) /*!< Bit position for GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BM_GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM (0x3F000000U) /*!< Bit mask for GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BS_GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM (6U) /*!< Bit field size in bits for GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM. */

/*! @brief Read current value of the GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM field. */
#define BR_GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM(x) (HW_GPC_PGC_MIPI_CTRL(x).B.MEMPWR_TCD1_TDR_TRM)

/*! @brief Format value for bitfield GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BF_GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM) & BM_GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM)

/*! @brief Set the MEMPWR_TCD1_TDR_TRM field to a new value. */
#define BW_GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM(x, v) (HW_GPC_PGC_MIPI_CTRL_WR(x, (HW_GPC_PGC_MIPI_CTRL_RD(x) & ~BM_GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM) | BF_GPC_PGC_MIPI_CTRL_MEMPWR_TCD1_TDR_TRM(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_MIPI_PUPSCR - GPC PGC Up Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_MIPI_PUPSCR - GPC PGC Up Sequence Control Register (RW)
 *
 * Reset value: 0x000997C1U
 *
 * GPC PGC Up Sequence Control Register
 */
typedef union _hw_gpc_pgc_mipi_pupscr
{
    uint32_t U;
    struct _hw_gpc_pgc_mipi_pupscr_bitfields
    {
        uint32_t SW : 6;               /*!< [5:0]  */
        uint32_t PUP_WAIT_SCALL_OUT : 1; /*!< [6]  */
        uint32_t SW2ISO : 16;          /*!< [22:7]  */
        uint32_t PUP_SCALL_SCALLOUT_CNT : 9; /*!< [31:23]  */
    } B;
} hw_gpc_pgc_mipi_pupscr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_MIPI_PUPSCR register
 */
/*@{*/
#define HW_GPC_PGC_MIPI_PUPSCR_ADDR(x) ((uintptr_t)(x) + 0x104U)

#define HW_GPC_PGC_MIPI_PUPSCR(x) (*(__IO hw_gpc_pgc_mipi_pupscr_t *) HW_GPC_PGC_MIPI_PUPSCR_ADDR(x))
#define HW_GPC_PGC_MIPI_PUPSCR_RD(x) (HW_GPC_PGC_MIPI_PUPSCR(x).U)
#define HW_GPC_PGC_MIPI_PUPSCR_WR(x, v) (HW_GPC_PGC_MIPI_PUPSCR(x).U = (v))
#define HW_GPC_PGC_MIPI_PUPSCR_SET(x, v) (HW_GPC_PGC_MIPI_PUPSCR_WR(x, HW_GPC_PGC_MIPI_PUPSCR_RD(x) |  (v)))
#define HW_GPC_PGC_MIPI_PUPSCR_CLR(x, v) (HW_GPC_PGC_MIPI_PUPSCR_WR(x, HW_GPC_PGC_MIPI_PUPSCR_RD(x) & ~(v)))
#define HW_GPC_PGC_MIPI_PUPSCR_TOG(x, v) (HW_GPC_PGC_MIPI_PUPSCR_WR(x, HW_GPC_PGC_MIPI_PUPSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_MIPI_PUPSCR bitfields
 */

/*!
 * @name Register GPC_PGC_MIPI_PUPSCR, field SW[5:0] (RW)
 *
 * After a power-up request (pup_req assertion), the PGC waits a number of
 * clocks equal to the value of SW before asserting switch_b SW must not be programmed
 * to zero.
 */
/*@{*/
#define BP_GPC_PGC_MIPI_PUPSCR_SW (0U)     /*!< Bit position for GPC_PGC_MIPI_PUPSCR_SW. */
#define BM_GPC_PGC_MIPI_PUPSCR_SW (0x0000003FU) /*!< Bit mask for GPC_PGC_MIPI_PUPSCR_SW. */
#define BS_GPC_PGC_MIPI_PUPSCR_SW (6U)     /*!< Bit field size in bits for GPC_PGC_MIPI_PUPSCR_SW. */

/*! @brief Read current value of the GPC_PGC_MIPI_PUPSCR_SW field. */
#define BR_GPC_PGC_MIPI_PUPSCR_SW(x) (HW_GPC_PGC_MIPI_PUPSCR(x).B.SW)

/*! @brief Format value for bitfield GPC_PGC_MIPI_PUPSCR_SW. */
#define BF_GPC_PGC_MIPI_PUPSCR_SW(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIPI_PUPSCR_SW) & BM_GPC_PGC_MIPI_PUPSCR_SW)

/*! @brief Set the SW field to a new value. */
#define BW_GPC_PGC_MIPI_PUPSCR_SW(x, v) (HW_GPC_PGC_MIPI_PUPSCR_WR(x, (HW_GPC_PGC_MIPI_PUPSCR_RD(x) & ~BM_GPC_PGC_MIPI_PUPSCR_SW) | BF_GPC_PGC_MIPI_PUPSCR_SW(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIPI_PUPSCR, field PUP_WAIT_SCALL_OUT[6] (RW)
 *
 * After SCALL asserting to 1'b0, wait handshake signal SCALL_OUT to return to
 * 1'b0 (This register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_MIPI_PUPSCR_PUP_WAIT_SCALL_OUT (6U) /*!< Bit position for GPC_PGC_MIPI_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BM_GPC_PGC_MIPI_PUPSCR_PUP_WAIT_SCALL_OUT (0x00000040U) /*!< Bit mask for GPC_PGC_MIPI_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BS_GPC_PGC_MIPI_PUPSCR_PUP_WAIT_SCALL_OUT (1U) /*!< Bit field size in bits for GPC_PGC_MIPI_PUPSCR_PUP_WAIT_SCALL_OUT. */

/*! @brief Read current value of the GPC_PGC_MIPI_PUPSCR_PUP_WAIT_SCALL_OUT field. */
#define BR_GPC_PGC_MIPI_PUPSCR_PUP_WAIT_SCALL_OUT(x) (HW_GPC_PGC_MIPI_PUPSCR(x).B.PUP_WAIT_SCALL_OUT)

/*! @brief Format value for bitfield GPC_PGC_MIPI_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BF_GPC_PGC_MIPI_PUPSCR_PUP_WAIT_SCALL_OUT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIPI_PUPSCR_PUP_WAIT_SCALL_OUT) & BM_GPC_PGC_MIPI_PUPSCR_PUP_WAIT_SCALL_OUT)

/*! @brief Set the PUP_WAIT_SCALL_OUT field to a new value. */
#define BW_GPC_PGC_MIPI_PUPSCR_PUP_WAIT_SCALL_OUT(x, v) (HW_GPC_PGC_MIPI_PUPSCR_WR(x, (HW_GPC_PGC_MIPI_PUPSCR_RD(x) & ~BM_GPC_PGC_MIPI_PUPSCR_PUP_WAIT_SCALL_OUT) | BF_GPC_PGC_MIPI_PUPSCR_PUP_WAIT_SCALL_OUT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIPI_PUPSCR, field SW2ISO[22:7] (RW)
 *
 * After asserting switch_b, the PGC waits a number of clocks equal to the value
 * of SW2ISO before negating isolation.
 */
/*@{*/
#define BP_GPC_PGC_MIPI_PUPSCR_SW2ISO (7U) /*!< Bit position for GPC_PGC_MIPI_PUPSCR_SW2ISO. */
#define BM_GPC_PGC_MIPI_PUPSCR_SW2ISO (0x007FFF80U) /*!< Bit mask for GPC_PGC_MIPI_PUPSCR_SW2ISO. */
#define BS_GPC_PGC_MIPI_PUPSCR_SW2ISO (16U) /*!< Bit field size in bits for GPC_PGC_MIPI_PUPSCR_SW2ISO. */

/*! @brief Read current value of the GPC_PGC_MIPI_PUPSCR_SW2ISO field. */
#define BR_GPC_PGC_MIPI_PUPSCR_SW2ISO(x) (HW_GPC_PGC_MIPI_PUPSCR(x).B.SW2ISO)

/*! @brief Format value for bitfield GPC_PGC_MIPI_PUPSCR_SW2ISO. */
#define BF_GPC_PGC_MIPI_PUPSCR_SW2ISO(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIPI_PUPSCR_SW2ISO) & BM_GPC_PGC_MIPI_PUPSCR_SW2ISO)

/*! @brief Set the SW2ISO field to a new value. */
#define BW_GPC_PGC_MIPI_PUPSCR_SW2ISO(x, v) (HW_GPC_PGC_MIPI_PUPSCR_WR(x, (HW_GPC_PGC_MIPI_PUPSCR_RD(x) & ~BM_GPC_PGC_MIPI_PUPSCR_SW2ISO) | BF_GPC_PGC_MIPI_PUPSCR_SW2ISO(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIPI_PUPSCR, field PUP_SCALL_SCALLOUT_CNT[31:23] (RW)
 *
 * After SCALL asserting to 1'b0, count this value to complete switch power up
 * Only valid when pup_wait_scall_out is set to 1'b0. Can't be programmed to zero
 * (This register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT (23U) /*!< Bit position for GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */
#define BM_GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT (0xFF800000U) /*!< Bit mask for GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */
#define BS_GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT (9U) /*!< Bit field size in bits for GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */

/*! @brief Read current value of the GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT field. */
#define BR_GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT(x) (HW_GPC_PGC_MIPI_PUPSCR(x).B.PUP_SCALL_SCALLOUT_CNT)

/*! @brief Format value for bitfield GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */
#define BF_GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT) & BM_GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT)

/*! @brief Set the PUP_SCALL_SCALLOUT_CNT field to a new value. */
#define BW_GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT(x, v) (HW_GPC_PGC_MIPI_PUPSCR_WR(x, (HW_GPC_PGC_MIPI_PUPSCR_RD(x) & ~BM_GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT) | BF_GPC_PGC_MIPI_PUPSCR_PUP_SCALL_SCALLOUT_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_MIPI_PDNSCR - GPC PGC Down Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_MIPI_PDNSCR - GPC PGC Down Sequence Control Register (RW)
 *
 * Reset value: 0x21000801U
 *
 * GPC PGC Down Sequence Control Register
 */
typedef union _hw_gpc_pgc_mipi_pdnscr
{
    uint32_t U;
    struct _hw_gpc_pgc_mipi_pdnscr_bitfields
    {
        uint32_t ISO : 6;              /*!< [5:0]  */
        uint32_t RESERVED0 : 1;        /*!< [6]  */
        uint32_t PDN_WAIT_SCALL_OUT : 1; /*!< [7] Default 1'b0 */
        uint32_t ISO2SW : 6;           /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t PDN_SCALL_SCALLOUT_CNT : 8; /*!< [23:16]  */
        uint32_t PUP_SCPRE_SCALL_CNT : 8; /*!< [31:24]  */
    } B;
} hw_gpc_pgc_mipi_pdnscr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_MIPI_PDNSCR register
 */
/*@{*/
#define HW_GPC_PGC_MIPI_PDNSCR_ADDR(x) ((uintptr_t)(x) + 0x108U)

#define HW_GPC_PGC_MIPI_PDNSCR(x) (*(__IO hw_gpc_pgc_mipi_pdnscr_t *) HW_GPC_PGC_MIPI_PDNSCR_ADDR(x))
#define HW_GPC_PGC_MIPI_PDNSCR_RD(x) (HW_GPC_PGC_MIPI_PDNSCR(x).U)
#define HW_GPC_PGC_MIPI_PDNSCR_WR(x, v) (HW_GPC_PGC_MIPI_PDNSCR(x).U = (v))
#define HW_GPC_PGC_MIPI_PDNSCR_SET(x, v) (HW_GPC_PGC_MIPI_PDNSCR_WR(x, HW_GPC_PGC_MIPI_PDNSCR_RD(x) |  (v)))
#define HW_GPC_PGC_MIPI_PDNSCR_CLR(x, v) (HW_GPC_PGC_MIPI_PDNSCR_WR(x, HW_GPC_PGC_MIPI_PDNSCR_RD(x) & ~(v)))
#define HW_GPC_PGC_MIPI_PDNSCR_TOG(x, v) (HW_GPC_PGC_MIPI_PDNSCR_WR(x, HW_GPC_PGC_MIPI_PDNSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_MIPI_PDNSCR bitfields
 */

/*!
 * @name Register GPC_PGC_MIPI_PDNSCR, field ISO[5:0] (RW)
 *
 * Aafte a power-down request (pdn_req assertion), the PGC waits a number of
 * clocks equal to the value of ISO before asserting isolation ISO must not be
 * programmed to zero.
 */
/*@{*/
#define BP_GPC_PGC_MIPI_PDNSCR_ISO (0U)    /*!< Bit position for GPC_PGC_MIPI_PDNSCR_ISO. */
#define BM_GPC_PGC_MIPI_PDNSCR_ISO (0x0000003FU) /*!< Bit mask for GPC_PGC_MIPI_PDNSCR_ISO. */
#define BS_GPC_PGC_MIPI_PDNSCR_ISO (6U)    /*!< Bit field size in bits for GPC_PGC_MIPI_PDNSCR_ISO. */

/*! @brief Read current value of the GPC_PGC_MIPI_PDNSCR_ISO field. */
#define BR_GPC_PGC_MIPI_PDNSCR_ISO(x) (HW_GPC_PGC_MIPI_PDNSCR(x).B.ISO)

/*! @brief Format value for bitfield GPC_PGC_MIPI_PDNSCR_ISO. */
#define BF_GPC_PGC_MIPI_PDNSCR_ISO(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIPI_PDNSCR_ISO) & BM_GPC_PGC_MIPI_PDNSCR_ISO)

/*! @brief Set the ISO field to a new value. */
#define BW_GPC_PGC_MIPI_PDNSCR_ISO(x, v) (HW_GPC_PGC_MIPI_PDNSCR_WR(x, (HW_GPC_PGC_MIPI_PDNSCR_RD(x) & ~BM_GPC_PGC_MIPI_PDNSCR_ISO) | BF_GPC_PGC_MIPI_PDNSCR_ISO(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIPI_PDNSCR, field PDN_WAIT_SCALL_OUT[7] (RW)
 *
 * If set to 1'b1, after SCALL asserting to 1'b1, wait handshake signal
 * SCALL_OUT to change to 1'b1. This register control is only for MIX Type PGC.
 */
/*@{*/
#define BP_GPC_PGC_MIPI_PDNSCR_PDN_WAIT_SCALL_OUT (7U) /*!< Bit position for GPC_PGC_MIPI_PDNSCR_PDN_WAIT_SCALL_OUT. */
#define BM_GPC_PGC_MIPI_PDNSCR_PDN_WAIT_SCALL_OUT (0x00000080U) /*!< Bit mask for GPC_PGC_MIPI_PDNSCR_PDN_WAIT_SCALL_OUT. */
#define BS_GPC_PGC_MIPI_PDNSCR_PDN_WAIT_SCALL_OUT (1U) /*!< Bit field size in bits for GPC_PGC_MIPI_PDNSCR_PDN_WAIT_SCALL_OUT. */

/*! @brief Read current value of the GPC_PGC_MIPI_PDNSCR_PDN_WAIT_SCALL_OUT field. */
#define BR_GPC_PGC_MIPI_PDNSCR_PDN_WAIT_SCALL_OUT(x) (HW_GPC_PGC_MIPI_PDNSCR(x).B.PDN_WAIT_SCALL_OUT)

/*! @brief Format value for bitfield GPC_PGC_MIPI_PDNSCR_PDN_WAIT_SCALL_OUT. */
#define BF_GPC_PGC_MIPI_PDNSCR_PDN_WAIT_SCALL_OUT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIPI_PDNSCR_PDN_WAIT_SCALL_OUT) & BM_GPC_PGC_MIPI_PDNSCR_PDN_WAIT_SCALL_OUT)

/*! @brief Set the PDN_WAIT_SCALL_OUT field to a new value. */
#define BW_GPC_PGC_MIPI_PDNSCR_PDN_WAIT_SCALL_OUT(x, v) (HW_GPC_PGC_MIPI_PDNSCR_WR(x, (HW_GPC_PGC_MIPI_PDNSCR_RD(x) & ~BM_GPC_PGC_MIPI_PDNSCR_PDN_WAIT_SCALL_OUT) | BF_GPC_PGC_MIPI_PDNSCR_PDN_WAIT_SCALL_OUT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIPI_PDNSCR, field ISO2SW[13:8] (RW)
 *
 * After asserting isolation(by pdn_req assertion), the PGC waits a number of
 * clocks equal to the value of ISO2SW before negating switch_b ISO2SW must not be
 * programmed to zero.
 */
/*@{*/
#define BP_GPC_PGC_MIPI_PDNSCR_ISO2SW (8U) /*!< Bit position for GPC_PGC_MIPI_PDNSCR_ISO2SW. */
#define BM_GPC_PGC_MIPI_PDNSCR_ISO2SW (0x00003F00U) /*!< Bit mask for GPC_PGC_MIPI_PDNSCR_ISO2SW. */
#define BS_GPC_PGC_MIPI_PDNSCR_ISO2SW (6U) /*!< Bit field size in bits for GPC_PGC_MIPI_PDNSCR_ISO2SW. */

/*! @brief Read current value of the GPC_PGC_MIPI_PDNSCR_ISO2SW field. */
#define BR_GPC_PGC_MIPI_PDNSCR_ISO2SW(x) (HW_GPC_PGC_MIPI_PDNSCR(x).B.ISO2SW)

/*! @brief Format value for bitfield GPC_PGC_MIPI_PDNSCR_ISO2SW. */
#define BF_GPC_PGC_MIPI_PDNSCR_ISO2SW(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIPI_PDNSCR_ISO2SW) & BM_GPC_PGC_MIPI_PDNSCR_ISO2SW)

/*! @brief Set the ISO2SW field to a new value. */
#define BW_GPC_PGC_MIPI_PDNSCR_ISO2SW(x, v) (HW_GPC_PGC_MIPI_PDNSCR_WR(x, (HW_GPC_PGC_MIPI_PDNSCR_RD(x) & ~BM_GPC_PGC_MIPI_PDNSCR_ISO2SW) | BF_GPC_PGC_MIPI_PDNSCR_ISO2SW(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIPI_PDNSCR, field PDN_SCALL_SCALLOUT_CNT[23:16] (RW)
 *
 * Default 8'h0. After SCALL asserting to 1'b1, count this value to complete
 * switch power down. This control is only valid when pdn_wait_scall_out is set to
 * 1'b0. It can be programmed to zero. (This register control only for MIX Type
 * PGC)
 */
/*@{*/
#define BP_GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT (16U) /*!< Bit position for GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */
#define BM_GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT (0x00FF0000U) /*!< Bit mask for GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */
#define BS_GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT (8U) /*!< Bit field size in bits for GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */

/*! @brief Read current value of the GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT field. */
#define BR_GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT(x) (HW_GPC_PGC_MIPI_PDNSCR(x).B.PDN_SCALL_SCALLOUT_CNT)

/*! @brief Format value for bitfield GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */
#define BF_GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT) & BM_GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT)

/*! @brief Set the PDN_SCALL_SCALLOUT_CNT field to a new value. */
#define BW_GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT(x, v) (HW_GPC_PGC_MIPI_PDNSCR_WR(x, (HW_GPC_PGC_MIPI_PDNSCR_RD(x) & ~BM_GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT) | BF_GPC_PGC_MIPI_PDNSCR_PDN_SCALL_SCALLOUT_CNT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIPI_PDNSCR, field PUP_SCPRE_SCALL_CNT[31:24] (RW)
 *
 * After SCPRE asserting to 1'b0, count this value to assert SCALL to 1'b0 (This
 * register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT (24U) /*!< Bit position for GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BM_GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT (0xFF000000U) /*!< Bit mask for GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BS_GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT (8U) /*!< Bit field size in bits for GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT. */

/*! @brief Read current value of the GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT field. */
#define BR_GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT(x) (HW_GPC_PGC_MIPI_PDNSCR(x).B.PUP_SCPRE_SCALL_CNT)

/*! @brief Format value for bitfield GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BF_GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT) & BM_GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT)

/*! @brief Set the PUP_SCPRE_SCALL_CNT field to a new value. */
#define BW_GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT(x, v) (HW_GPC_PGC_MIPI_PDNSCR_WR(x, (HW_GPC_PGC_MIPI_PDNSCR_RD(x) & ~BM_GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT) | BF_GPC_PGC_MIPI_PDNSCR_PUP_SCPRE_SCALL_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_MIPI_SR - GPC PGC Status Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_MIPI_SR - GPC PGC Status Register (RW)
 *
 * Reset value: 0x00001000U
 *
 * GPC PGC Status Register
 */
typedef union _hw_gpc_pgc_mipi_sr
{
    uint32_t U;
    struct _hw_gpc_pgc_mipi_sr_bitfields
    {
        uint32_t PSR : 1;              /*!< [0]  */
        uint32_t L2RETN_FLAG : 1;      /*!< [1]  */
        uint32_t ALLOFF_FLAG : 1;      /*!< [2]  */
        uint32_t PUP_CLK_DIV_SEL : 4;  /*!< [6:3]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t L2RSTDIS_DEASSERT_CNT : 10; /*!< [17:8]  */
        uint32_t RESERVED1 : 14;       /*!< [31:18]  */
    } B;
} hw_gpc_pgc_mipi_sr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_MIPI_SR register
 */
/*@{*/
#define HW_GPC_PGC_MIPI_SR_ADDR(x) ((uintptr_t)(x) + 0x10CU)

#define HW_GPC_PGC_MIPI_SR(x)    (*(__IO hw_gpc_pgc_mipi_sr_t *) HW_GPC_PGC_MIPI_SR_ADDR(x))
#define HW_GPC_PGC_MIPI_SR_RD(x) (HW_GPC_PGC_MIPI_SR(x).U)
#define HW_GPC_PGC_MIPI_SR_WR(x, v) (HW_GPC_PGC_MIPI_SR(x).U = (v))
#define HW_GPC_PGC_MIPI_SR_SET(x, v) (HW_GPC_PGC_MIPI_SR_WR(x, HW_GPC_PGC_MIPI_SR_RD(x) |  (v)))
#define HW_GPC_PGC_MIPI_SR_CLR(x, v) (HW_GPC_PGC_MIPI_SR_WR(x, HW_GPC_PGC_MIPI_SR_RD(x) & ~(v)))
#define HW_GPC_PGC_MIPI_SR_TOG(x, v) (HW_GPC_PGC_MIPI_SR_WR(x, HW_GPC_PGC_MIPI_SR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_MIPI_SR bitfields
 */

/*!
 * @name Register GPC_PGC_MIPI_SR, field PSR[0] (RO)
 *
 * Power status. When in functional (or software-controlled debug) mode, PGC
 * hardware sets PSR as soon as any of the power control output changes its state to
 * one. Write one to clear this bit. Software should clear this bit after power
 * up; otherwise, PSR continues to reflect the power status of the initial power
 * down.
 *
 * Values:
 * - 0 - The target subsystem was not powered down for the previous power-down
 *     request.
 * - 1 - The target subsystem was powered down for the previous power-down
 *     request.
 */
/*@{*/
#define BP_GPC_PGC_MIPI_SR_PSR (0U)        /*!< Bit position for GPC_PGC_MIPI_SR_PSR. */
#define BM_GPC_PGC_MIPI_SR_PSR (0x00000001U) /*!< Bit mask for GPC_PGC_MIPI_SR_PSR. */
#define BS_GPC_PGC_MIPI_SR_PSR (1U)        /*!< Bit field size in bits for GPC_PGC_MIPI_SR_PSR. */

/*! @brief Read current value of the GPC_PGC_MIPI_SR_PSR field. */
#define BR_GPC_PGC_MIPI_SR_PSR(x) (HW_GPC_PGC_MIPI_SR(x).B.PSR)
/*@}*/

/*!
 * @name Register GPC_PGC_MIPI_SR, field L2RETN_FLAG[1] (RO)
 *
 * L2 Retention Flag Software should write "1" to clear this flag after A7 is
 * wakeup from L2 retention mode, otherwise it will always keep to 1 (This register
 * control only for SCU Type PGC)
 *
 * Values:
 * - 0 - A7 is not wakeup from L2 retention mode.
 * - 1 - A7 is wakeup from L2 retention mode.
 */
/*@{*/
#define BP_GPC_PGC_MIPI_SR_L2RETN_FLAG (1U) /*!< Bit position for GPC_PGC_MIPI_SR_L2RETN_FLAG. */
#define BM_GPC_PGC_MIPI_SR_L2RETN_FLAG (0x00000002U) /*!< Bit mask for GPC_PGC_MIPI_SR_L2RETN_FLAG. */
#define BS_GPC_PGC_MIPI_SR_L2RETN_FLAG (1U) /*!< Bit field size in bits for GPC_PGC_MIPI_SR_L2RETN_FLAG. */

/*! @brief Read current value of the GPC_PGC_MIPI_SR_L2RETN_FLAG field. */
#define BR_GPC_PGC_MIPI_SR_L2RETN_FLAG(x) (HW_GPC_PGC_MIPI_SR(x).B.L2RETN_FLAG)
/*@}*/

/*!
 * @name Register GPC_PGC_MIPI_SR, field ALLOFF_FLAG[2] (RO)
 *
 * All-off flag. Software should write "1" to clear this flag after A7 is wakeup
 * from ALL_OFF mode, otherwise, it will always keep to 1 (This register control
 * only for SCU Type PGC)
 *
 * Values:
 * - 0 - A7 is not wakeup from ALL_OFF mode.
 * - 1 - A7 is wakeup from ALL_OFF mode.
 */
/*@{*/
#define BP_GPC_PGC_MIPI_SR_ALLOFF_FLAG (2U) /*!< Bit position for GPC_PGC_MIPI_SR_ALLOFF_FLAG. */
#define BM_GPC_PGC_MIPI_SR_ALLOFF_FLAG (0x00000004U) /*!< Bit mask for GPC_PGC_MIPI_SR_ALLOFF_FLAG. */
#define BS_GPC_PGC_MIPI_SR_ALLOFF_FLAG (1U) /*!< Bit field size in bits for GPC_PGC_MIPI_SR_ALLOFF_FLAG. */

/*! @brief Read current value of the GPC_PGC_MIPI_SR_ALLOFF_FLAG field. */
#define BR_GPC_PGC_MIPI_SR_ALLOFF_FLAG(x) (HW_GPC_PGC_MIPI_SR(x).B.ALLOFF_FLAG)
/*@}*/

/*!
 * @name Register GPC_PGC_MIPI_SR, field PUP_CLK_DIV_SEL[6:3] (RW)
 *
 * Clock divider select for the clock of power up counter(count_clk is 32KHz for
 * CPU/SCU type PGC, ipg_clk(66MHz) for MIX/PU Type PGC)
 *
 * Values:
 * - 0000 - 1
 * - 0001 - 1/2 count_clk
 * - 0010 - 1/4 count_clk
 * - 0011 - 1/8 count_clk
 * - 0100 - 1/16 count_clk
 * - 0101 - 1/32 count_clk
 * - 0110 - 1/64 count_clk
 * - 0111 - 1/128 count_clk
 * - 1000 - 1/256 count_clk
 * - 1001 - 1/512 count_clk
 * - 1010 - 1/1024 count_clk
 * - 1011 - 1/2056 count_clk
 * - 1100 - 1/4096 count_clk
 * - 1101 - 1/8192 count_clk
 * - 1110 - 1/16384 count_clk
 * - 1111 - 1/32768 count_clk
 */
/*@{*/
#define BP_GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL (3U) /*!< Bit position for GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL. */
#define BM_GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL (0x00000078U) /*!< Bit mask for GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL. */
#define BS_GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL (4U) /*!< Bit field size in bits for GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL. */

/*! @brief Read current value of the GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL field. */
#define BR_GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL(x) (HW_GPC_PGC_MIPI_SR(x).B.PUP_CLK_DIV_SEL)

/*! @brief Format value for bitfield GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL. */
#define BF_GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL) & BM_GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL)

/*! @brief Set the PUP_CLK_DIV_SEL field to a new value. */
#define BW_GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL(x, v) (HW_GPC_PGC_MIPI_SR_WR(x, (HW_GPC_PGC_MIPI_SR_RD(x) & ~BM_GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL) | BF_GPC_PGC_MIPI_SR_PUP_CLK_DIV_SEL(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIPI_SR, field L2RSTDIS_DEASSERT_CNT[17:8] (RW)
 *
 * Count this value to de-assert L2RSTDISABLE to LOW after CPU0 or CPU1 power up
 * This value can't be programmed to zero (This register control only for SCU
 * Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT (8U) /*!< Bit position for GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT. */
#define BM_GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT (0x0003FF00U) /*!< Bit mask for GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT. */
#define BS_GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT (10U) /*!< Bit field size in bits for GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT. */

/*! @brief Read current value of the GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT field. */
#define BR_GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT(x) (HW_GPC_PGC_MIPI_SR(x).B.L2RSTDIS_DEASSERT_CNT)

/*! @brief Format value for bitfield GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT. */
#define BF_GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT) & BM_GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT)

/*! @brief Set the L2RSTDIS_DEASSERT_CNT field to a new value. */
#define BW_GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT(x, v) (HW_GPC_PGC_MIPI_SR_WR(x, (HW_GPC_PGC_MIPI_SR_RD(x) & ~BM_GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT) | BF_GPC_PGC_MIPI_SR_L2RSTDIS_DEASSERT_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_PCIE_CTRL - GPC PGC Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_PCIE_CTRL - GPC PGC Control Register (RW)
 *
 * Reset value: 0x06040202U
 *
 * GPC PGC Control Register
 */
typedef union _hw_gpc_pgc_pcie_ctrl
{
    uint32_t U;
    struct _hw_gpc_pgc_pcie_ctrl_bitfields
    {
        uint32_t PCR : 1;              /*!< [0]  */
        uint32_t L2RSTDIS : 6;         /*!< [6:1]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t DFTRAM_TCD1 : 6;      /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t L2RETN_TCD1_TDR : 6;  /*!< [21:16]  */
        uint32_t RESERVED2 : 2;        /*!< [23:22]  */
        uint32_t MEMPWR_TCD1_TDR_TRM : 6; /*!< [29:24]  */
        uint32_t RESERVED3 : 2;        /*!< [31:30]  */
    } B;
} hw_gpc_pgc_pcie_ctrl_t;

/*!
 * @name Constants and macros for entire GPC_PGC_PCIE_CTRL register
 */
/*@{*/
#define HW_GPC_PGC_PCIE_CTRL_ADDR(x) ((uintptr_t)(x) + 0x140U)

#define HW_GPC_PGC_PCIE_CTRL(x)  (*(__IO hw_gpc_pgc_pcie_ctrl_t *) HW_GPC_PGC_PCIE_CTRL_ADDR(x))
#define HW_GPC_PGC_PCIE_CTRL_RD(x) (HW_GPC_PGC_PCIE_CTRL(x).U)
#define HW_GPC_PGC_PCIE_CTRL_WR(x, v) (HW_GPC_PGC_PCIE_CTRL(x).U = (v))
#define HW_GPC_PGC_PCIE_CTRL_SET(x, v) (HW_GPC_PGC_PCIE_CTRL_WR(x, HW_GPC_PGC_PCIE_CTRL_RD(x) |  (v)))
#define HW_GPC_PGC_PCIE_CTRL_CLR(x, v) (HW_GPC_PGC_PCIE_CTRL_WR(x, HW_GPC_PGC_PCIE_CTRL_RD(x) & ~(v)))
#define HW_GPC_PGC_PCIE_CTRL_TOG(x, v) (HW_GPC_PGC_PCIE_CTRL_WR(x, HW_GPC_PGC_PCIE_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_PCIE_CTRL bitfields
 */

/*!
 * @name Register GPC_PGC_PCIE_CTRL, field PCR[0] (RW)
 *
 * Power ControlPCR must not change from power-down request (pdn_req) assertion
 * until the target subsystem is completely powered up.
 *
 * Values:
 * - 0 - Do not switch off power even if pdn_req is asserted.
 * - 1 - Switch off power when pdn_req is asserted.
 */
/*@{*/
#define BP_GPC_PGC_PCIE_CTRL_PCR (0U)      /*!< Bit position for GPC_PGC_PCIE_CTRL_PCR. */
#define BM_GPC_PGC_PCIE_CTRL_PCR (0x00000001U) /*!< Bit mask for GPC_PGC_PCIE_CTRL_PCR. */
#define BS_GPC_PGC_PCIE_CTRL_PCR (1U)      /*!< Bit field size in bits for GPC_PGC_PCIE_CTRL_PCR. */

/*! @brief Read current value of the GPC_PGC_PCIE_CTRL_PCR field. */
#define BR_GPC_PGC_PCIE_CTRL_PCR(x) (HW_GPC_PGC_PCIE_CTRL(x).B.PCR)

/*! @brief Format value for bitfield GPC_PGC_PCIE_CTRL_PCR. */
#define BF_GPC_PGC_PCIE_CTRL_PCR(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_PCIE_CTRL_PCR) & BM_GPC_PGC_PCIE_CTRL_PCR)

/*! @brief Set the PCR field to a new value. */
#define BW_GPC_PGC_PCIE_CTRL_PCR(x, v) (HW_GPC_PGC_PCIE_CTRL_WR(x, (HW_GPC_PGC_PCIE_CTRL_RD(x) & ~BM_GPC_PGC_PCIE_CTRL_PCR) | BF_GPC_PGC_PCIE_CTRL_PCR(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_PCIE_CTRL, field L2RSTDIS[6:1] (RW)
 *
 * After scu pdn_req, count this value to assert A7 l2rstdis to 1'b1, it will be
 * clear automatically once any of A7 core0/core1 is wakeup Can't be programmed
 * to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_PCIE_CTRL_L2RSTDIS (1U) /*!< Bit position for GPC_PGC_PCIE_CTRL_L2RSTDIS. */
#define BM_GPC_PGC_PCIE_CTRL_L2RSTDIS (0x0000007EU) /*!< Bit mask for GPC_PGC_PCIE_CTRL_L2RSTDIS. */
#define BS_GPC_PGC_PCIE_CTRL_L2RSTDIS (6U) /*!< Bit field size in bits for GPC_PGC_PCIE_CTRL_L2RSTDIS. */

/*! @brief Read current value of the GPC_PGC_PCIE_CTRL_L2RSTDIS field. */
#define BR_GPC_PGC_PCIE_CTRL_L2RSTDIS(x) (HW_GPC_PGC_PCIE_CTRL(x).B.L2RSTDIS)

/*! @brief Format value for bitfield GPC_PGC_PCIE_CTRL_L2RSTDIS. */
#define BF_GPC_PGC_PCIE_CTRL_L2RSTDIS(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_PCIE_CTRL_L2RSTDIS) & BM_GPC_PGC_PCIE_CTRL_L2RSTDIS)

/*! @brief Set the L2RSTDIS field to a new value. */
#define BW_GPC_PGC_PCIE_CTRL_L2RSTDIS(x, v) (HW_GPC_PGC_PCIE_CTRL_WR(x, (HW_GPC_PGC_PCIE_CTRL_RD(x) & ~BM_GPC_PGC_PCIE_CTRL_L2RSTDIS) | BF_GPC_PGC_PCIE_CTRL_L2RSTDIS(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_PCIE_CTRL, field DFTRAM_TCD1[13:8] (RW)
 *
 * After scu pdn_req, count this value to assert A7 dftram to 1'b1 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_PCIE_CTRL_DFTRAM_TCD1 (8U) /*!< Bit position for GPC_PGC_PCIE_CTRL_DFTRAM_TCD1. */
#define BM_GPC_PGC_PCIE_CTRL_DFTRAM_TCD1 (0x00003F00U) /*!< Bit mask for GPC_PGC_PCIE_CTRL_DFTRAM_TCD1. */
#define BS_GPC_PGC_PCIE_CTRL_DFTRAM_TCD1 (6U) /*!< Bit field size in bits for GPC_PGC_PCIE_CTRL_DFTRAM_TCD1. */

/*! @brief Read current value of the GPC_PGC_PCIE_CTRL_DFTRAM_TCD1 field. */
#define BR_GPC_PGC_PCIE_CTRL_DFTRAM_TCD1(x) (HW_GPC_PGC_PCIE_CTRL(x).B.DFTRAM_TCD1)

/*! @brief Format value for bitfield GPC_PGC_PCIE_CTRL_DFTRAM_TCD1. */
#define BF_GPC_PGC_PCIE_CTRL_DFTRAM_TCD1(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_PCIE_CTRL_DFTRAM_TCD1) & BM_GPC_PGC_PCIE_CTRL_DFTRAM_TCD1)

/*! @brief Set the DFTRAM_TCD1 field to a new value. */
#define BW_GPC_PGC_PCIE_CTRL_DFTRAM_TCD1(x, v) (HW_GPC_PGC_PCIE_CTRL_WR(x, (HW_GPC_PGC_PCIE_CTRL_RD(x) & ~BM_GPC_PGC_PCIE_CTRL_DFTRAM_TCD1) | BF_GPC_PGC_PCIE_CTRL_DFTRAM_TCD1(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_PCIE_CTRL, field L2RETN_TCD1_TDR[21:16] (RW)
 *
 * After scu pdn_req, count this value to assert A7 l2retn to 1'b0 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR (16U) /*!< Bit position for GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR. */
#define BM_GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR (0x003F0000U) /*!< Bit mask for GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR. */
#define BS_GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR (6U) /*!< Bit field size in bits for GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR. */

/*! @brief Read current value of the GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR field. */
#define BR_GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR(x) (HW_GPC_PGC_PCIE_CTRL(x).B.L2RETN_TCD1_TDR)

/*! @brief Format value for bitfield GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR. */
#define BF_GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR) & BM_GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR)

/*! @brief Set the L2RETN_TCD1_TDR field to a new value. */
#define BW_GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR(x, v) (HW_GPC_PGC_PCIE_CTRL_WR(x, (HW_GPC_PGC_PCIE_CTRL_RD(x) & ~BM_GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR) | BF_GPC_PGC_PCIE_CTRL_L2RETN_TCD1_TDR(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_PCIE_CTRL, field MEMPWR_TCD1_TDR_TRM[29:24] (RW)
 *
 * After scu pdn_req, count this value to assert A7 mempwr to 1'b1 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM (24U) /*!< Bit position for GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BM_GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM (0x3F000000U) /*!< Bit mask for GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BS_GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM (6U) /*!< Bit field size in bits for GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM. */

/*! @brief Read current value of the GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM field. */
#define BR_GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM(x) (HW_GPC_PGC_PCIE_CTRL(x).B.MEMPWR_TCD1_TDR_TRM)

/*! @brief Format value for bitfield GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BF_GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM) & BM_GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM)

/*! @brief Set the MEMPWR_TCD1_TDR_TRM field to a new value. */
#define BW_GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM(x, v) (HW_GPC_PGC_PCIE_CTRL_WR(x, (HW_GPC_PGC_PCIE_CTRL_RD(x) & ~BM_GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM) | BF_GPC_PGC_PCIE_CTRL_MEMPWR_TCD1_TDR_TRM(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_PCIE_PUPSCR - GPC PGC Up Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_PCIE_PUPSCR - GPC PGC Up Sequence Control Register (RW)
 *
 * Reset value: 0x000997C1U
 *
 * GPC PGC Up Sequence Control Register
 */
typedef union _hw_gpc_pgc_pcie_pupscr
{
    uint32_t U;
    struct _hw_gpc_pgc_pcie_pupscr_bitfields
    {
        uint32_t SW : 6;               /*!< [5:0]  */
        uint32_t PUP_WAIT_SCALL_OUT : 1; /*!< [6]  */
        uint32_t SW2ISO : 16;          /*!< [22:7]  */
        uint32_t PUP_SCALL_SCALLOUT_CNT : 9; /*!< [31:23]  */
    } B;
} hw_gpc_pgc_pcie_pupscr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_PCIE_PUPSCR register
 */
/*@{*/
#define HW_GPC_PGC_PCIE_PUPSCR_ADDR(x) ((uintptr_t)(x) + 0x144U)

#define HW_GPC_PGC_PCIE_PUPSCR(x) (*(__IO hw_gpc_pgc_pcie_pupscr_t *) HW_GPC_PGC_PCIE_PUPSCR_ADDR(x))
#define HW_GPC_PGC_PCIE_PUPSCR_RD(x) (HW_GPC_PGC_PCIE_PUPSCR(x).U)
#define HW_GPC_PGC_PCIE_PUPSCR_WR(x, v) (HW_GPC_PGC_PCIE_PUPSCR(x).U = (v))
#define HW_GPC_PGC_PCIE_PUPSCR_SET(x, v) (HW_GPC_PGC_PCIE_PUPSCR_WR(x, HW_GPC_PGC_PCIE_PUPSCR_RD(x) |  (v)))
#define HW_GPC_PGC_PCIE_PUPSCR_CLR(x, v) (HW_GPC_PGC_PCIE_PUPSCR_WR(x, HW_GPC_PGC_PCIE_PUPSCR_RD(x) & ~(v)))
#define HW_GPC_PGC_PCIE_PUPSCR_TOG(x, v) (HW_GPC_PGC_PCIE_PUPSCR_WR(x, HW_GPC_PGC_PCIE_PUPSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_PCIE_PUPSCR bitfields
 */

/*!
 * @name Register GPC_PGC_PCIE_PUPSCR, field SW[5:0] (RW)
 *
 * After a power-up request (pup_req assertion), the PGC waits a number of
 * clocks equal to the value of SW before asserting switch_b SW must not be programmed
 * to zero.
 */
/*@{*/
#define BP_GPC_PGC_PCIE_PUPSCR_SW (0U)     /*!< Bit position for GPC_PGC_PCIE_PUPSCR_SW. */
#define BM_GPC_PGC_PCIE_PUPSCR_SW (0x0000003FU) /*!< Bit mask for GPC_PGC_PCIE_PUPSCR_SW. */
#define BS_GPC_PGC_PCIE_PUPSCR_SW (6U)     /*!< Bit field size in bits for GPC_PGC_PCIE_PUPSCR_SW. */

/*! @brief Read current value of the GPC_PGC_PCIE_PUPSCR_SW field. */
#define BR_GPC_PGC_PCIE_PUPSCR_SW(x) (HW_GPC_PGC_PCIE_PUPSCR(x).B.SW)

/*! @brief Format value for bitfield GPC_PGC_PCIE_PUPSCR_SW. */
#define BF_GPC_PGC_PCIE_PUPSCR_SW(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_PCIE_PUPSCR_SW) & BM_GPC_PGC_PCIE_PUPSCR_SW)

/*! @brief Set the SW field to a new value. */
#define BW_GPC_PGC_PCIE_PUPSCR_SW(x, v) (HW_GPC_PGC_PCIE_PUPSCR_WR(x, (HW_GPC_PGC_PCIE_PUPSCR_RD(x) & ~BM_GPC_PGC_PCIE_PUPSCR_SW) | BF_GPC_PGC_PCIE_PUPSCR_SW(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_PCIE_PUPSCR, field PUP_WAIT_SCALL_OUT[6] (RW)
 *
 * After SCALL asserting to 1'b0, wait handshake signal SCALL_OUT to return to
 * 1'b0 (This register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_PCIE_PUPSCR_PUP_WAIT_SCALL_OUT (6U) /*!< Bit position for GPC_PGC_PCIE_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BM_GPC_PGC_PCIE_PUPSCR_PUP_WAIT_SCALL_OUT (0x00000040U) /*!< Bit mask for GPC_PGC_PCIE_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BS_GPC_PGC_PCIE_PUPSCR_PUP_WAIT_SCALL_OUT (1U) /*!< Bit field size in bits for GPC_PGC_PCIE_PUPSCR_PUP_WAIT_SCALL_OUT. */

/*! @brief Read current value of the GPC_PGC_PCIE_PUPSCR_PUP_WAIT_SCALL_OUT field. */
#define BR_GPC_PGC_PCIE_PUPSCR_PUP_WAIT_SCALL_OUT(x) (HW_GPC_PGC_PCIE_PUPSCR(x).B.PUP_WAIT_SCALL_OUT)

/*! @brief Format value for bitfield GPC_PGC_PCIE_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BF_GPC_PGC_PCIE_PUPSCR_PUP_WAIT_SCALL_OUT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_PCIE_PUPSCR_PUP_WAIT_SCALL_OUT) & BM_GPC_PGC_PCIE_PUPSCR_PUP_WAIT_SCALL_OUT)

/*! @brief Set the PUP_WAIT_SCALL_OUT field to a new value. */
#define BW_GPC_PGC_PCIE_PUPSCR_PUP_WAIT_SCALL_OUT(x, v) (HW_GPC_PGC_PCIE_PUPSCR_WR(x, (HW_GPC_PGC_PCIE_PUPSCR_RD(x) & ~BM_GPC_PGC_PCIE_PUPSCR_PUP_WAIT_SCALL_OUT) | BF_GPC_PGC_PCIE_PUPSCR_PUP_WAIT_SCALL_OUT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_PCIE_PUPSCR, field SW2ISO[22:7] (RW)
 *
 * After asserting switch_b, the PGC waits a number of clocks equal to the value
 * of SW2ISO before negating isolation.
 */
/*@{*/
#define BP_GPC_PGC_PCIE_PUPSCR_SW2ISO (7U) /*!< Bit position for GPC_PGC_PCIE_PUPSCR_SW2ISO. */
#define BM_GPC_PGC_PCIE_PUPSCR_SW2ISO (0x007FFF80U) /*!< Bit mask for GPC_PGC_PCIE_PUPSCR_SW2ISO. */
#define BS_GPC_PGC_PCIE_PUPSCR_SW2ISO (16U) /*!< Bit field size in bits for GPC_PGC_PCIE_PUPSCR_SW2ISO. */

/*! @brief Read current value of the GPC_PGC_PCIE_PUPSCR_SW2ISO field. */
#define BR_GPC_PGC_PCIE_PUPSCR_SW2ISO(x) (HW_GPC_PGC_PCIE_PUPSCR(x).B.SW2ISO)

/*! @brief Format value for bitfield GPC_PGC_PCIE_PUPSCR_SW2ISO. */
#define BF_GPC_PGC_PCIE_PUPSCR_SW2ISO(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_PCIE_PUPSCR_SW2ISO) & BM_GPC_PGC_PCIE_PUPSCR_SW2ISO)

/*! @brief Set the SW2ISO field to a new value. */
#define BW_GPC_PGC_PCIE_PUPSCR_SW2ISO(x, v) (HW_GPC_PGC_PCIE_PUPSCR_WR(x, (HW_GPC_PGC_PCIE_PUPSCR_RD(x) & ~BM_GPC_PGC_PCIE_PUPSCR_SW2ISO) | BF_GPC_PGC_PCIE_PUPSCR_SW2ISO(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_PCIE_PUPSCR, field PUP_SCALL_SCALLOUT_CNT[31:23] (RW)
 *
 * After SCALL asserting to 1'b0, count this value to complete switch power up
 * Only valid when pup_wait_scall_out is set to 1'b0. Can't be programmed to zero
 * (This register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT (23U) /*!< Bit position for GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */
#define BM_GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT (0xFF800000U) /*!< Bit mask for GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */
#define BS_GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT (9U) /*!< Bit field size in bits for GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */

/*! @brief Read current value of the GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT field. */
#define BR_GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT(x) (HW_GPC_PGC_PCIE_PUPSCR(x).B.PUP_SCALL_SCALLOUT_CNT)

/*! @brief Format value for bitfield GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT. */
#define BF_GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT) & BM_GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT)

/*! @brief Set the PUP_SCALL_SCALLOUT_CNT field to a new value. */
#define BW_GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT(x, v) (HW_GPC_PGC_PCIE_PUPSCR_WR(x, (HW_GPC_PGC_PCIE_PUPSCR_RD(x) & ~BM_GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT) | BF_GPC_PGC_PCIE_PUPSCR_PUP_SCALL_SCALLOUT_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_PCIE_PDNSCR - GPC PGC Down Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_PCIE_PDNSCR - GPC PGC Down Sequence Control Register (RW)
 *
 * Reset value: 0x21000801U
 *
 * GPC PGC Down Sequence Control Register
 */
typedef union _hw_gpc_pgc_pcie_pdnscr
{
    uint32_t U;
    struct _hw_gpc_pgc_pcie_pdnscr_bitfields
    {
        uint32_t ISO : 6;              /*!< [5:0]  */
        uint32_t RESERVED0 : 1;        /*!< [6]  */
        uint32_t PDN_WAIT_SCALL_OUT : 1; /*!< [7] Default 1'b0 */
        uint32_t ISO2SW : 6;           /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t PDN_SCALL_SCALLOUT_CNT : 8; /*!< [23:16]  */
        uint32_t PUP_SCPRE_SCALL_CNT : 8; /*!< [31:24]  */
    } B;
} hw_gpc_pgc_pcie_pdnscr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_PCIE_PDNSCR register
 */
/*@{*/
#define HW_GPC_PGC_PCIE_PDNSCR_ADDR(x) ((uintptr_t)(x) + 0x148U)

#define HW_GPC_PGC_PCIE_PDNSCR(x) (*(__IO hw_gpc_pgc_pcie_pdnscr_t *) HW_GPC_PGC_PCIE_PDNSCR_ADDR(x))
#define HW_GPC_PGC_PCIE_PDNSCR_RD(x) (HW_GPC_PGC_PCIE_PDNSCR(x).U)
#define HW_GPC_PGC_PCIE_PDNSCR_WR(x, v) (HW_GPC_PGC_PCIE_PDNSCR(x).U = (v))
#define HW_GPC_PGC_PCIE_PDNSCR_SET(x, v) (HW_GPC_PGC_PCIE_PDNSCR_WR(x, HW_GPC_PGC_PCIE_PDNSCR_RD(x) |  (v)))
#define HW_GPC_PGC_PCIE_PDNSCR_CLR(x, v) (HW_GPC_PGC_PCIE_PDNSCR_WR(x, HW_GPC_PGC_PCIE_PDNSCR_RD(x) & ~(v)))
#define HW_GPC_PGC_PCIE_PDNSCR_TOG(x, v) (HW_GPC_PGC_PCIE_PDNSCR_WR(x, HW_GPC_PGC_PCIE_PDNSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_PCIE_PDNSCR bitfields
 */

/*!
 * @name Register GPC_PGC_PCIE_PDNSCR, field ISO[5:0] (RW)
 *
 * Aafte a power-down request (pdn_req assertion), the PGC waits a number of
 * clocks equal to the value of ISO before asserting isolation ISO must not be
 * programmed to zero.
 */
/*@{*/
#define BP_GPC_PGC_PCIE_PDNSCR_ISO (0U)    /*!< Bit position for GPC_PGC_PCIE_PDNSCR_ISO. */
#define BM_GPC_PGC_PCIE_PDNSCR_ISO (0x0000003FU) /*!< Bit mask for GPC_PGC_PCIE_PDNSCR_ISO. */
#define BS_GPC_PGC_PCIE_PDNSCR_ISO (6U)    /*!< Bit field size in bits for GPC_PGC_PCIE_PDNSCR_ISO. */

/*! @brief Read current value of the GPC_PGC_PCIE_PDNSCR_ISO field. */
#define BR_GPC_PGC_PCIE_PDNSCR_ISO(x) (HW_GPC_PGC_PCIE_PDNSCR(x).B.ISO)

/*! @brief Format value for bitfield GPC_PGC_PCIE_PDNSCR_ISO. */
#define BF_GPC_PGC_PCIE_PDNSCR_ISO(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_PCIE_PDNSCR_ISO) & BM_GPC_PGC_PCIE_PDNSCR_ISO)

/*! @brief Set the ISO field to a new value. */
#define BW_GPC_PGC_PCIE_PDNSCR_ISO(x, v) (HW_GPC_PGC_PCIE_PDNSCR_WR(x, (HW_GPC_PGC_PCIE_PDNSCR_RD(x) & ~BM_GPC_PGC_PCIE_PDNSCR_ISO) | BF_GPC_PGC_PCIE_PDNSCR_ISO(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_PCIE_PDNSCR, field PDN_WAIT_SCALL_OUT[7] (RW)
 *
 * If set to 1'b1, after SCALL asserting to 1'b1, wait handshake signal
 * SCALL_OUT to change to 1'b1. This register control is only for MIX Type PGC.
 */
/*@{*/
#define BP_GPC_PGC_PCIE_PDNSCR_PDN_WAIT_SCALL_OUT (7U) /*!< Bit position for GPC_PGC_PCIE_PDNSCR_PDN_WAIT_SCALL_OUT. */
#define BM_GPC_PGC_PCIE_PDNSCR_PDN_WAIT_SCALL_OUT (0x00000080U) /*!< Bit mask for GPC_PGC_PCIE_PDNSCR_PDN_WAIT_SCALL_OUT. */
#define BS_GPC_PGC_PCIE_PDNSCR_PDN_WAIT_SCALL_OUT (1U) /*!< Bit field size in bits for GPC_PGC_PCIE_PDNSCR_PDN_WAIT_SCALL_OUT. */

/*! @brief Read current value of the GPC_PGC_PCIE_PDNSCR_PDN_WAIT_SCALL_OUT field. */
#define BR_GPC_PGC_PCIE_PDNSCR_PDN_WAIT_SCALL_OUT(x) (HW_GPC_PGC_PCIE_PDNSCR(x).B.PDN_WAIT_SCALL_OUT)

/*! @brief Format value for bitfield GPC_PGC_PCIE_PDNSCR_PDN_WAIT_SCALL_OUT. */
#define BF_GPC_PGC_PCIE_PDNSCR_PDN_WAIT_SCALL_OUT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_PCIE_PDNSCR_PDN_WAIT_SCALL_OUT) & BM_GPC_PGC_PCIE_PDNSCR_PDN_WAIT_SCALL_OUT)

/*! @brief Set the PDN_WAIT_SCALL_OUT field to a new value. */
#define BW_GPC_PGC_PCIE_PDNSCR_PDN_WAIT_SCALL_OUT(x, v) (HW_GPC_PGC_PCIE_PDNSCR_WR(x, (HW_GPC_PGC_PCIE_PDNSCR_RD(x) & ~BM_GPC_PGC_PCIE_PDNSCR_PDN_WAIT_SCALL_OUT) | BF_GPC_PGC_PCIE_PDNSCR_PDN_WAIT_SCALL_OUT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_PCIE_PDNSCR, field ISO2SW[13:8] (RW)
 *
 * After asserting isolation(by pdn_req assertion), the PGC waits a number of
 * clocks equal to the value of ISO2SW before negating switch_b ISO2SW must not be
 * programmed to zero.
 */
/*@{*/
#define BP_GPC_PGC_PCIE_PDNSCR_ISO2SW (8U) /*!< Bit position for GPC_PGC_PCIE_PDNSCR_ISO2SW. */
#define BM_GPC_PGC_PCIE_PDNSCR_ISO2SW (0x00003F00U) /*!< Bit mask for GPC_PGC_PCIE_PDNSCR_ISO2SW. */
#define BS_GPC_PGC_PCIE_PDNSCR_ISO2SW (6U) /*!< Bit field size in bits for GPC_PGC_PCIE_PDNSCR_ISO2SW. */

/*! @brief Read current value of the GPC_PGC_PCIE_PDNSCR_ISO2SW field. */
#define BR_GPC_PGC_PCIE_PDNSCR_ISO2SW(x) (HW_GPC_PGC_PCIE_PDNSCR(x).B.ISO2SW)

/*! @brief Format value for bitfield GPC_PGC_PCIE_PDNSCR_ISO2SW. */
#define BF_GPC_PGC_PCIE_PDNSCR_ISO2SW(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_PCIE_PDNSCR_ISO2SW) & BM_GPC_PGC_PCIE_PDNSCR_ISO2SW)

/*! @brief Set the ISO2SW field to a new value. */
#define BW_GPC_PGC_PCIE_PDNSCR_ISO2SW(x, v) (HW_GPC_PGC_PCIE_PDNSCR_WR(x, (HW_GPC_PGC_PCIE_PDNSCR_RD(x) & ~BM_GPC_PGC_PCIE_PDNSCR_ISO2SW) | BF_GPC_PGC_PCIE_PDNSCR_ISO2SW(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_PCIE_PDNSCR, field PDN_SCALL_SCALLOUT_CNT[23:16] (RW)
 *
 * Default 8'h0. After SCALL asserting to 1'b1, count this value to complete
 * switch power down. This control is only valid when pdn_wait_scall_out is set to
 * 1'b0. It can be programmed to zero. (This register control only for MIX Type
 * PGC)
 */
/*@{*/
#define BP_GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT (16U) /*!< Bit position for GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */
#define BM_GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT (0x00FF0000U) /*!< Bit mask for GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */
#define BS_GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT (8U) /*!< Bit field size in bits for GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */

/*! @brief Read current value of the GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT field. */
#define BR_GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT(x) (HW_GPC_PGC_PCIE_PDNSCR(x).B.PDN_SCALL_SCALLOUT_CNT)

/*! @brief Format value for bitfield GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT. */
#define BF_GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT) & BM_GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT)

/*! @brief Set the PDN_SCALL_SCALLOUT_CNT field to a new value. */
#define BW_GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT(x, v) (HW_GPC_PGC_PCIE_PDNSCR_WR(x, (HW_GPC_PGC_PCIE_PDNSCR_RD(x) & ~BM_GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT) | BF_GPC_PGC_PCIE_PDNSCR_PDN_SCALL_SCALLOUT_CNT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_PCIE_PDNSCR, field PUP_SCPRE_SCALL_CNT[31:24] (RW)
 *
 * After SCPRE asserting to 1'b0, count this value to assert SCALL to 1'b0 (This
 * register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT (24U) /*!< Bit position for GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BM_GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT (0xFF000000U) /*!< Bit mask for GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BS_GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT (8U) /*!< Bit field size in bits for GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT. */

/*! @brief Read current value of the GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT field. */
#define BR_GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT(x) (HW_GPC_PGC_PCIE_PDNSCR(x).B.PUP_SCPRE_SCALL_CNT)

/*! @brief Format value for bitfield GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BF_GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT) & BM_GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT)

/*! @brief Set the PUP_SCPRE_SCALL_CNT field to a new value. */
#define BW_GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT(x, v) (HW_GPC_PGC_PCIE_PDNSCR_WR(x, (HW_GPC_PGC_PCIE_PDNSCR_RD(x) & ~BM_GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT) | BF_GPC_PGC_PCIE_PDNSCR_PUP_SCPRE_SCALL_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_PCIE_SR - GPC PGC Status Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_PCIE_SR - GPC PGC Status Register (RW)
 *
 * Reset value: 0x00001000U
 *
 * GPC PGC Status Register
 */
typedef union _hw_gpc_pgc_pcie_sr
{
    uint32_t U;
    struct _hw_gpc_pgc_pcie_sr_bitfields
    {
        uint32_t PSR : 1;              /*!< [0]  */
        uint32_t L2RETN_FLAG : 1;      /*!< [1]  */
        uint32_t ALLOFF_FLAG : 1;      /*!< [2]  */
        uint32_t PUP_CLK_DIV_SEL : 4;  /*!< [6:3]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t L2RSTDIS_DEASSERT_CNT : 10; /*!< [17:8]  */
        uint32_t RESERVED1 : 14;       /*!< [31:18]  */
    } B;
} hw_gpc_pgc_pcie_sr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_PCIE_SR register
 */
/*@{*/
#define HW_GPC_PGC_PCIE_SR_ADDR(x) ((uintptr_t)(x) + 0x14CU)

#define HW_GPC_PGC_PCIE_SR(x)    (*(__IO hw_gpc_pgc_pcie_sr_t *) HW_GPC_PGC_PCIE_SR_ADDR(x))
#define HW_GPC_PGC_PCIE_SR_RD(x) (HW_GPC_PGC_PCIE_SR(x).U)
#define HW_GPC_PGC_PCIE_SR_WR(x, v) (HW_GPC_PGC_PCIE_SR(x).U = (v))
#define HW_GPC_PGC_PCIE_SR_SET(x, v) (HW_GPC_PGC_PCIE_SR_WR(x, HW_GPC_PGC_PCIE_SR_RD(x) |  (v)))
#define HW_GPC_PGC_PCIE_SR_CLR(x, v) (HW_GPC_PGC_PCIE_SR_WR(x, HW_GPC_PGC_PCIE_SR_RD(x) & ~(v)))
#define HW_GPC_PGC_PCIE_SR_TOG(x, v) (HW_GPC_PGC_PCIE_SR_WR(x, HW_GPC_PGC_PCIE_SR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_PCIE_SR bitfields
 */

/*!
 * @name Register GPC_PGC_PCIE_SR, field PSR[0] (RO)
 *
 * Power status. When in functional (or software-controlled debug) mode, PGC
 * hardware sets PSR as soon as any of the power control output changes its state to
 * one. Write one to clear this bit. Software should clear this bit after power
 * up; otherwise, PSR continues to reflect the power status of the initial power
 * down.
 *
 * Values:
 * - 0 - The target subsystem was not powered down for the previous power-down
 *     request.
 * - 1 - The target subsystem was powered down for the previous power-down
 *     request.
 */
/*@{*/
#define BP_GPC_PGC_PCIE_SR_PSR (0U)        /*!< Bit position for GPC_PGC_PCIE_SR_PSR. */
#define BM_GPC_PGC_PCIE_SR_PSR (0x00000001U) /*!< Bit mask for GPC_PGC_PCIE_SR_PSR. */
#define BS_GPC_PGC_PCIE_SR_PSR (1U)        /*!< Bit field size in bits for GPC_PGC_PCIE_SR_PSR. */

/*! @brief Read current value of the GPC_PGC_PCIE_SR_PSR field. */
#define BR_GPC_PGC_PCIE_SR_PSR(x) (HW_GPC_PGC_PCIE_SR(x).B.PSR)
/*@}*/

/*!
 * @name Register GPC_PGC_PCIE_SR, field L2RETN_FLAG[1] (RO)
 *
 * L2 Retention Flag Software should write "1" to clear this flag after A7 is
 * wakeup from L2 retention mode, otherwise it will always keep to 1 (This register
 * control only for SCU Type PGC)
 *
 * Values:
 * - 0 - A7 is not wakeup from L2 retention mode.
 * - 1 - A7 is wakeup from L2 retention mode.
 */
/*@{*/
#define BP_GPC_PGC_PCIE_SR_L2RETN_FLAG (1U) /*!< Bit position for GPC_PGC_PCIE_SR_L2RETN_FLAG. */
#define BM_GPC_PGC_PCIE_SR_L2RETN_FLAG (0x00000002U) /*!< Bit mask for GPC_PGC_PCIE_SR_L2RETN_FLAG. */
#define BS_GPC_PGC_PCIE_SR_L2RETN_FLAG (1U) /*!< Bit field size in bits for GPC_PGC_PCIE_SR_L2RETN_FLAG. */

/*! @brief Read current value of the GPC_PGC_PCIE_SR_L2RETN_FLAG field. */
#define BR_GPC_PGC_PCIE_SR_L2RETN_FLAG(x) (HW_GPC_PGC_PCIE_SR(x).B.L2RETN_FLAG)
/*@}*/

/*!
 * @name Register GPC_PGC_PCIE_SR, field ALLOFF_FLAG[2] (RO)
 *
 * All-off flag. Software should write "1" to clear this flag after A7 is wakeup
 * from ALL_OFF mode, otherwise, it will always keep to 1 (This register control
 * only for SCU Type PGC)
 *
 * Values:
 * - 0 - A7 is not wakeup from ALL_OFF mode.
 * - 1 - A7 is wakeup from ALL_OFF mode.
 */
/*@{*/
#define BP_GPC_PGC_PCIE_SR_ALLOFF_FLAG (2U) /*!< Bit position for GPC_PGC_PCIE_SR_ALLOFF_FLAG. */
#define BM_GPC_PGC_PCIE_SR_ALLOFF_FLAG (0x00000004U) /*!< Bit mask for GPC_PGC_PCIE_SR_ALLOFF_FLAG. */
#define BS_GPC_PGC_PCIE_SR_ALLOFF_FLAG (1U) /*!< Bit field size in bits for GPC_PGC_PCIE_SR_ALLOFF_FLAG. */

/*! @brief Read current value of the GPC_PGC_PCIE_SR_ALLOFF_FLAG field. */
#define BR_GPC_PGC_PCIE_SR_ALLOFF_FLAG(x) (HW_GPC_PGC_PCIE_SR(x).B.ALLOFF_FLAG)
/*@}*/

/*!
 * @name Register GPC_PGC_PCIE_SR, field PUP_CLK_DIV_SEL[6:3] (RW)
 *
 * Clock divider select for the clock of power up counter(count_clk is 32KHz for
 * CPU/SCU type PGC, ipg_clk(66MHz) for MIX/PU Type PGC)
 *
 * Values:
 * - 0000 - 1
 * - 0001 - 1/2 count_clk
 * - 0010 - 1/4 count_clk
 * - 0011 - 1/8 count_clk
 * - 0100 - 1/16 count_clk
 * - 0101 - 1/32 count_clk
 * - 0110 - 1/64 count_clk
 * - 0111 - 1/128 count_clk
 * - 1000 - 1/256 count_clk
 * - 1001 - 1/512 count_clk
 * - 1010 - 1/1024 count_clk
 * - 1011 - 1/2056 count_clk
 * - 1100 - 1/4096 count_clk
 * - 1101 - 1/8192 count_clk
 * - 1110 - 1/16384 count_clk
 * - 1111 - 1/32768 count_clk
 */
/*@{*/
#define BP_GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL (3U) /*!< Bit position for GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL. */
#define BM_GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL (0x00000078U) /*!< Bit mask for GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL. */
#define BS_GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL (4U) /*!< Bit field size in bits for GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL. */

/*! @brief Read current value of the GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL field. */
#define BR_GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL(x) (HW_GPC_PGC_PCIE_SR(x).B.PUP_CLK_DIV_SEL)

/*! @brief Format value for bitfield GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL. */
#define BF_GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL) & BM_GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL)

/*! @brief Set the PUP_CLK_DIV_SEL field to a new value. */
#define BW_GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL(x, v) (HW_GPC_PGC_PCIE_SR_WR(x, (HW_GPC_PGC_PCIE_SR_RD(x) & ~BM_GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL) | BF_GPC_PGC_PCIE_SR_PUP_CLK_DIV_SEL(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_PCIE_SR, field L2RSTDIS_DEASSERT_CNT[17:8] (RW)
 *
 * Count this value to de-assert L2RSTDISABLE to LOW after CPU0 or CPU1 power up
 * This value can't be programmed to zero (This register control only for SCU
 * Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT (8U) /*!< Bit position for GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT. */
#define BM_GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT (0x0003FF00U) /*!< Bit mask for GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT. */
#define BS_GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT (10U) /*!< Bit field size in bits for GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT. */

/*! @brief Read current value of the GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT field. */
#define BR_GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT(x) (HW_GPC_PGC_PCIE_SR(x).B.L2RSTDIS_DEASSERT_CNT)

/*! @brief Format value for bitfield GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT. */
#define BF_GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT) & BM_GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT)

/*! @brief Set the L2RSTDIS_DEASSERT_CNT field to a new value. */
#define BW_GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT(x, v) (HW_GPC_PGC_PCIE_SR_WR(x, (HW_GPC_PGC_PCIE_SR_RD(x) & ~BM_GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT) | BF_GPC_PGC_PCIE_SR_L2RSTDIS_DEASSERT_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_MIPI_AUXSW - GPC PGC Auxiliary Power Switch Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_MIPI_AUXSW - GPC PGC Auxiliary Power Switch Control Register (RW)
 *
 * Reset value: 0x00000131U
 *
 * GPC PGC Auxiliary Power Switch Control Register. The register has different
 * field definition for PCIE/MIPI PGC and SCU Type PGC.
 */
typedef union _hw_gpc_pgc_mipi_auxsw
{
    uint32_t U;
    struct _hw_gpc_pgc_mipi_auxsw_bitfields
    {
        uint32_t SW2 : 6;              /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t ISO2SW2 : 6;          /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t PDN_CLK_DIV_SEL : 4;  /*!< [19:16]  */
        uint32_t RESERVED2 : 12;       /*!< [31:20]  */
    } B;
} hw_gpc_pgc_mipi_auxsw_t;

/*!
 * @name Constants and macros for entire GPC_PGC_MIPI_AUXSW register
 */
/*@{*/
#define HW_GPC_PGC_MIPI_AUXSW_ADDR(x) ((uintptr_t)(x) + 0x410U)

#define HW_GPC_PGC_MIPI_AUXSW(x) (*(__IO hw_gpc_pgc_mipi_auxsw_t *) HW_GPC_PGC_MIPI_AUXSW_ADDR(x))
#define HW_GPC_PGC_MIPI_AUXSW_RD(x) (HW_GPC_PGC_MIPI_AUXSW(x).U)
#define HW_GPC_PGC_MIPI_AUXSW_WR(x, v) (HW_GPC_PGC_MIPI_AUXSW(x).U = (v))
#define HW_GPC_PGC_MIPI_AUXSW_SET(x, v) (HW_GPC_PGC_MIPI_AUXSW_WR(x, HW_GPC_PGC_MIPI_AUXSW_RD(x) |  (v)))
#define HW_GPC_PGC_MIPI_AUXSW_CLR(x, v) (HW_GPC_PGC_MIPI_AUXSW_WR(x, HW_GPC_PGC_MIPI_AUXSW_RD(x) & ~(v)))
#define HW_GPC_PGC_MIPI_AUXSW_TOG(x, v) (HW_GPC_PGC_MIPI_AUXSW_WR(x, HW_GPC_PGC_MIPI_AUXSW_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_MIPI_AUXSW bitfields
 */

/*!
 * @name Register GPC_PGC_MIPI_AUXSW, field SW2[5:0] (RW)
 *
 * After a power-up request (pup_req assertion), the PGC waits a number of
 * clocks equal to the value of SW2 before asserting switch2_b(1P8 Power) SW2 must not
 * be programmed to zero.
 */
/*@{*/
#define BP_GPC_PGC_MIPI_AUXSW_SW2 (0U)     /*!< Bit position for GPC_PGC_MIPI_AUXSW_SW2. */
#define BM_GPC_PGC_MIPI_AUXSW_SW2 (0x0000003FU) /*!< Bit mask for GPC_PGC_MIPI_AUXSW_SW2. */
#define BS_GPC_PGC_MIPI_AUXSW_SW2 (6U)     /*!< Bit field size in bits for GPC_PGC_MIPI_AUXSW_SW2. */

/*! @brief Read current value of the GPC_PGC_MIPI_AUXSW_SW2 field. */
#define BR_GPC_PGC_MIPI_AUXSW_SW2(x) (HW_GPC_PGC_MIPI_AUXSW(x).B.SW2)

/*! @brief Format value for bitfield GPC_PGC_MIPI_AUXSW_SW2. */
#define BF_GPC_PGC_MIPI_AUXSW_SW2(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIPI_AUXSW_SW2) & BM_GPC_PGC_MIPI_AUXSW_SW2)

/*! @brief Set the SW2 field to a new value. */
#define BW_GPC_PGC_MIPI_AUXSW_SW2(x, v) (HW_GPC_PGC_MIPI_AUXSW_WR(x, (HW_GPC_PGC_MIPI_AUXSW_RD(x) & ~BM_GPC_PGC_MIPI_AUXSW_SW2) | BF_GPC_PGC_MIPI_AUXSW_SW2(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_MIPI_AUXSW, field ISO2SW2[13:8] (RO)
 *
 * after asserting isolation by power-down request(pdn_req assertion), the PGC
 * waits a number of clocks equal to the value of ISO2SW2 before negating
 * switch2_b(1P8 Power) ISO2SW2 must not be programmed to zero.
 *
 * Values:
 * - 0 - A7 is not wakeup from ALL_OFF mode.
 * - 1 - A7 is wakeup from ALL_OFF mode.
 */
/*@{*/
#define BP_GPC_PGC_MIPI_AUXSW_ISO2SW2 (8U) /*!< Bit position for GPC_PGC_MIPI_AUXSW_ISO2SW2. */
#define BM_GPC_PGC_MIPI_AUXSW_ISO2SW2 (0x00003F00U) /*!< Bit mask for GPC_PGC_MIPI_AUXSW_ISO2SW2. */
#define BS_GPC_PGC_MIPI_AUXSW_ISO2SW2 (6U) /*!< Bit field size in bits for GPC_PGC_MIPI_AUXSW_ISO2SW2. */

/*! @brief Read current value of the GPC_PGC_MIPI_AUXSW_ISO2SW2 field. */
#define BR_GPC_PGC_MIPI_AUXSW_ISO2SW2(x) (HW_GPC_PGC_MIPI_AUXSW(x).B.ISO2SW2)
/*@}*/

/*!
 * @name Register GPC_PGC_MIPI_AUXSW, field PDN_CLK_DIV_SEL[19:16] (RW)
 *
 * Clock divider select for the clock of power down counter
 *
 * Values:
 * - 0000 - 1
 * - 0001 - 1/2 count_clk
 * - 0010 - 1/4 count_clk
 * - 0011 - 1/8 count_clk
 * - 0100 - 1/16 count_clk
 * - 0101 - 1/32 count_clk
 * - 0110 - 1/64 count_clk
 * - 0111 - 1/128 count_clk
 * - 1000 - 1/256 count_clk
 * - 1001 - 1/512 count_clk
 * - 1010 - 1/1024 count_clk
 * - 1011 - 1/2056 count_clk
 * - 1100 - 1/4096 count_clk
 * - 1101 - 1/8192 count_clk
 * - 1110 - 1/16384 count_clk
 * - 1111 - 1/32768 count_clk
 */
/*@{*/
#define BP_GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL (16U) /*!< Bit position for GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL. */
#define BM_GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL (0x000F0000U) /*!< Bit mask for GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL. */
#define BS_GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL (4U) /*!< Bit field size in bits for GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL. */

/*! @brief Read current value of the GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL field. */
#define BR_GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL(x) (HW_GPC_PGC_MIPI_AUXSW(x).B.PDN_CLK_DIV_SEL)

/*! @brief Format value for bitfield GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL. */
#define BF_GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL) & BM_GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL)

/*! @brief Set the PDN_CLK_DIV_SEL field to a new value. */
#define BW_GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL(x, v) (HW_GPC_PGC_MIPI_AUXSW_WR(x, (HW_GPC_PGC_MIPI_AUXSW_RD(x) & ~BM_GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL) | BF_GPC_PGC_MIPI_AUXSW_PDN_CLK_DIV_SEL(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_PCIE_AUXSW - GPC PGC Auxiliary Power Switch Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_PCIE_AUXSW - GPC PGC Auxiliary Power Switch Control Register (RW)
 *
 * Reset value: 0x00000131U
 *
 * GPC PGC Auxiliary Power Switch Control Register. The register has different
 * field definition for PCIE/MIPI PGC and SCU Type PGC.
 */
typedef union _hw_gpc_pgc_pcie_auxsw
{
    uint32_t U;
    struct _hw_gpc_pgc_pcie_auxsw_bitfields
    {
        uint32_t SW2 : 6;              /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t ISO2SW2 : 6;          /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t PDN_CLK_DIV_SEL : 4;  /*!< [19:16]  */
        uint32_t RESERVED2 : 12;       /*!< [31:20]  */
    } B;
} hw_gpc_pgc_pcie_auxsw_t;

/*!
 * @name Constants and macros for entire GPC_PGC_PCIE_AUXSW register
 */
/*@{*/
#define HW_GPC_PGC_PCIE_AUXSW_ADDR(x) ((uintptr_t)(x) + 0x450U)

#define HW_GPC_PGC_PCIE_AUXSW(x) (*(__IO hw_gpc_pgc_pcie_auxsw_t *) HW_GPC_PGC_PCIE_AUXSW_ADDR(x))
#define HW_GPC_PGC_PCIE_AUXSW_RD(x) (HW_GPC_PGC_PCIE_AUXSW(x).U)
#define HW_GPC_PGC_PCIE_AUXSW_WR(x, v) (HW_GPC_PGC_PCIE_AUXSW(x).U = (v))
#define HW_GPC_PGC_PCIE_AUXSW_SET(x, v) (HW_GPC_PGC_PCIE_AUXSW_WR(x, HW_GPC_PGC_PCIE_AUXSW_RD(x) |  (v)))
#define HW_GPC_PGC_PCIE_AUXSW_CLR(x, v) (HW_GPC_PGC_PCIE_AUXSW_WR(x, HW_GPC_PGC_PCIE_AUXSW_RD(x) & ~(v)))
#define HW_GPC_PGC_PCIE_AUXSW_TOG(x, v) (HW_GPC_PGC_PCIE_AUXSW_WR(x, HW_GPC_PGC_PCIE_AUXSW_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_PCIE_AUXSW bitfields
 */

/*!
 * @name Register GPC_PGC_PCIE_AUXSW, field SW2[5:0] (RW)
 *
 * After a power-up request (pup_req assertion), the PGC waits a number of
 * clocks equal to the value of SW2 before asserting switch2_b(1P8 Power) SW2 must not
 * be programmed to zero.
 */
/*@{*/
#define BP_GPC_PGC_PCIE_AUXSW_SW2 (0U)     /*!< Bit position for GPC_PGC_PCIE_AUXSW_SW2. */
#define BM_GPC_PGC_PCIE_AUXSW_SW2 (0x0000003FU) /*!< Bit mask for GPC_PGC_PCIE_AUXSW_SW2. */
#define BS_GPC_PGC_PCIE_AUXSW_SW2 (6U)     /*!< Bit field size in bits for GPC_PGC_PCIE_AUXSW_SW2. */

/*! @brief Read current value of the GPC_PGC_PCIE_AUXSW_SW2 field. */
#define BR_GPC_PGC_PCIE_AUXSW_SW2(x) (HW_GPC_PGC_PCIE_AUXSW(x).B.SW2)

/*! @brief Format value for bitfield GPC_PGC_PCIE_AUXSW_SW2. */
#define BF_GPC_PGC_PCIE_AUXSW_SW2(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_PCIE_AUXSW_SW2) & BM_GPC_PGC_PCIE_AUXSW_SW2)

/*! @brief Set the SW2 field to a new value. */
#define BW_GPC_PGC_PCIE_AUXSW_SW2(x, v) (HW_GPC_PGC_PCIE_AUXSW_WR(x, (HW_GPC_PGC_PCIE_AUXSW_RD(x) & ~BM_GPC_PGC_PCIE_AUXSW_SW2) | BF_GPC_PGC_PCIE_AUXSW_SW2(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_PCIE_AUXSW, field ISO2SW2[13:8] (RO)
 *
 * after asserting isolation by power-down request(pdn_req assertion), the PGC
 * waits a number of clocks equal to the value of ISO2SW2 before negating
 * switch2_b(1P8 Power) ISO2SW2 must not be programmed to zero.
 *
 * Values:
 * - 0 - A7 is not wakeup from ALL_OFF mode.
 * - 1 - A7 is wakeup from ALL_OFF mode.
 */
/*@{*/
#define BP_GPC_PGC_PCIE_AUXSW_ISO2SW2 (8U) /*!< Bit position for GPC_PGC_PCIE_AUXSW_ISO2SW2. */
#define BM_GPC_PGC_PCIE_AUXSW_ISO2SW2 (0x00003F00U) /*!< Bit mask for GPC_PGC_PCIE_AUXSW_ISO2SW2. */
#define BS_GPC_PGC_PCIE_AUXSW_ISO2SW2 (6U) /*!< Bit field size in bits for GPC_PGC_PCIE_AUXSW_ISO2SW2. */

/*! @brief Read current value of the GPC_PGC_PCIE_AUXSW_ISO2SW2 field. */
#define BR_GPC_PGC_PCIE_AUXSW_ISO2SW2(x) (HW_GPC_PGC_PCIE_AUXSW(x).B.ISO2SW2)
/*@}*/

/*!
 * @name Register GPC_PGC_PCIE_AUXSW, field PDN_CLK_DIV_SEL[19:16] (RW)
 *
 * Clock divider select for the clock of power down counter
 *
 * Values:
 * - 0000 - 1
 * - 0001 - 1/2 count_clk
 * - 0010 - 1/4 count_clk
 * - 0011 - 1/8 count_clk
 * - 0100 - 1/16 count_clk
 * - 0101 - 1/32 count_clk
 * - 0110 - 1/64 count_clk
 * - 0111 - 1/128 count_clk
 * - 1000 - 1/256 count_clk
 * - 1001 - 1/512 count_clk
 * - 1010 - 1/1024 count_clk
 * - 1011 - 1/2056 count_clk
 * - 1100 - 1/4096 count_clk
 * - 1101 - 1/8192 count_clk
 * - 1110 - 1/16384 count_clk
 * - 1111 - 1/32768 count_clk
 */
/*@{*/
#define BP_GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL (16U) /*!< Bit position for GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL. */
#define BM_GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL (0x000F0000U) /*!< Bit mask for GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL. */
#define BS_GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL (4U) /*!< Bit field size in bits for GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL. */

/*! @brief Read current value of the GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL field. */
#define BR_GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL(x) (HW_GPC_PGC_PCIE_AUXSW(x).B.PDN_CLK_DIV_SEL)

/*! @brief Format value for bitfield GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL. */
#define BF_GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL) & BM_GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL)

/*! @brief Set the PDN_CLK_DIV_SEL field to a new value. */
#define BW_GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL(x, v) (HW_GPC_PGC_PCIE_AUXSW_WR(x, (HW_GPC_PGC_PCIE_AUXSW_RD(x) & ~BM_GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL) | BF_GPC_PGC_PCIE_AUXSW_PDN_CLK_DIV_SEL(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_HSIC_CTRL - GPC PGC Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_HSIC_CTRL - GPC PGC Control Register (RW)
 *
 * Reset value: 0x06040202U
 *
 * GPC PGC Control Register
 */
typedef union _hw_gpc_pgc_hsic_ctrl
{
    uint32_t U;
    struct _hw_gpc_pgc_hsic_ctrl_bitfields
    {
        uint32_t PCR : 1;              /*!< [0]  */
        uint32_t L2RSTDIS : 6;         /*!< [6:1]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t DFTRAM_TCD1 : 6;      /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t L2RETN_TCD1_TDR : 6;  /*!< [21:16]  */
        uint32_t RESERVED2 : 2;        /*!< [23:22]  */
        uint32_t MEMPWR_TCD1_TDR_TRM : 6; /*!< [29:24]  */
        uint32_t RESERVED3 : 2;        /*!< [31:30]  */
    } B;
} hw_gpc_pgc_hsic_ctrl_t;

/*!
 * @name Constants and macros for entire GPC_PGC_HSIC_CTRL register
 */
/*@{*/
#define HW_GPC_PGC_HSIC_CTRL_ADDR(x) ((uintptr_t)(x) + 0x500U)

#define HW_GPC_PGC_HSIC_CTRL(x)  (*(__IO hw_gpc_pgc_hsic_ctrl_t *) HW_GPC_PGC_HSIC_CTRL_ADDR(x))
#define HW_GPC_PGC_HSIC_CTRL_RD(x) (HW_GPC_PGC_HSIC_CTRL(x).U)
#define HW_GPC_PGC_HSIC_CTRL_WR(x, v) (HW_GPC_PGC_HSIC_CTRL(x).U = (v))
#define HW_GPC_PGC_HSIC_CTRL_SET(x, v) (HW_GPC_PGC_HSIC_CTRL_WR(x, HW_GPC_PGC_HSIC_CTRL_RD(x) |  (v)))
#define HW_GPC_PGC_HSIC_CTRL_CLR(x, v) (HW_GPC_PGC_HSIC_CTRL_WR(x, HW_GPC_PGC_HSIC_CTRL_RD(x) & ~(v)))
#define HW_GPC_PGC_HSIC_CTRL_TOG(x, v) (HW_GPC_PGC_HSIC_CTRL_WR(x, HW_GPC_PGC_HSIC_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_HSIC_CTRL bitfields
 */

/*!
 * @name Register GPC_PGC_HSIC_CTRL, field PCR[0] (RW)
 *
 * Power ControlPCR must not change from power-down request (pdn_req) assertion
 * until the target subsystem is completely powered up.
 *
 * Values:
 * - 0 - Do not switch off power even if pdn_req is asserted.
 * - 1 - Switch off power when pdn_req is asserted.
 */
/*@{*/
#define BP_GPC_PGC_HSIC_CTRL_PCR (0U)      /*!< Bit position for GPC_PGC_HSIC_CTRL_PCR. */
#define BM_GPC_PGC_HSIC_CTRL_PCR (0x00000001U) /*!< Bit mask for GPC_PGC_HSIC_CTRL_PCR. */
#define BS_GPC_PGC_HSIC_CTRL_PCR (1U)      /*!< Bit field size in bits for GPC_PGC_HSIC_CTRL_PCR. */

/*! @brief Read current value of the GPC_PGC_HSIC_CTRL_PCR field. */
#define BR_GPC_PGC_HSIC_CTRL_PCR(x) (HW_GPC_PGC_HSIC_CTRL(x).B.PCR)

/*! @brief Format value for bitfield GPC_PGC_HSIC_CTRL_PCR. */
#define BF_GPC_PGC_HSIC_CTRL_PCR(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_HSIC_CTRL_PCR) & BM_GPC_PGC_HSIC_CTRL_PCR)

/*! @brief Set the PCR field to a new value. */
#define BW_GPC_PGC_HSIC_CTRL_PCR(x, v) (HW_GPC_PGC_HSIC_CTRL_WR(x, (HW_GPC_PGC_HSIC_CTRL_RD(x) & ~BM_GPC_PGC_HSIC_CTRL_PCR) | BF_GPC_PGC_HSIC_CTRL_PCR(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_HSIC_CTRL, field L2RSTDIS[6:1] (RW)
 *
 * After scu pdn_req, count this value to assert A7 l2rstdis to 1'b1, it will be
 * clear automatically once any of A7 core0/core1 is wakeup Can't be programmed
 * to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_HSIC_CTRL_L2RSTDIS (1U) /*!< Bit position for GPC_PGC_HSIC_CTRL_L2RSTDIS. */
#define BM_GPC_PGC_HSIC_CTRL_L2RSTDIS (0x0000007EU) /*!< Bit mask for GPC_PGC_HSIC_CTRL_L2RSTDIS. */
#define BS_GPC_PGC_HSIC_CTRL_L2RSTDIS (6U) /*!< Bit field size in bits for GPC_PGC_HSIC_CTRL_L2RSTDIS. */

/*! @brief Read current value of the GPC_PGC_HSIC_CTRL_L2RSTDIS field. */
#define BR_GPC_PGC_HSIC_CTRL_L2RSTDIS(x) (HW_GPC_PGC_HSIC_CTRL(x).B.L2RSTDIS)

/*! @brief Format value for bitfield GPC_PGC_HSIC_CTRL_L2RSTDIS. */
#define BF_GPC_PGC_HSIC_CTRL_L2RSTDIS(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_HSIC_CTRL_L2RSTDIS) & BM_GPC_PGC_HSIC_CTRL_L2RSTDIS)

/*! @brief Set the L2RSTDIS field to a new value. */
#define BW_GPC_PGC_HSIC_CTRL_L2RSTDIS(x, v) (HW_GPC_PGC_HSIC_CTRL_WR(x, (HW_GPC_PGC_HSIC_CTRL_RD(x) & ~BM_GPC_PGC_HSIC_CTRL_L2RSTDIS) | BF_GPC_PGC_HSIC_CTRL_L2RSTDIS(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_HSIC_CTRL, field DFTRAM_TCD1[13:8] (RW)
 *
 * After scu pdn_req, count this value to assert A7 dftram to 1'b1 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_HSIC_CTRL_DFTRAM_TCD1 (8U) /*!< Bit position for GPC_PGC_HSIC_CTRL_DFTRAM_TCD1. */
#define BM_GPC_PGC_HSIC_CTRL_DFTRAM_TCD1 (0x00003F00U) /*!< Bit mask for GPC_PGC_HSIC_CTRL_DFTRAM_TCD1. */
#define BS_GPC_PGC_HSIC_CTRL_DFTRAM_TCD1 (6U) /*!< Bit field size in bits for GPC_PGC_HSIC_CTRL_DFTRAM_TCD1. */

/*! @brief Read current value of the GPC_PGC_HSIC_CTRL_DFTRAM_TCD1 field. */
#define BR_GPC_PGC_HSIC_CTRL_DFTRAM_TCD1(x) (HW_GPC_PGC_HSIC_CTRL(x).B.DFTRAM_TCD1)

/*! @brief Format value for bitfield GPC_PGC_HSIC_CTRL_DFTRAM_TCD1. */
#define BF_GPC_PGC_HSIC_CTRL_DFTRAM_TCD1(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_HSIC_CTRL_DFTRAM_TCD1) & BM_GPC_PGC_HSIC_CTRL_DFTRAM_TCD1)

/*! @brief Set the DFTRAM_TCD1 field to a new value. */
#define BW_GPC_PGC_HSIC_CTRL_DFTRAM_TCD1(x, v) (HW_GPC_PGC_HSIC_CTRL_WR(x, (HW_GPC_PGC_HSIC_CTRL_RD(x) & ~BM_GPC_PGC_HSIC_CTRL_DFTRAM_TCD1) | BF_GPC_PGC_HSIC_CTRL_DFTRAM_TCD1(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_HSIC_CTRL, field L2RETN_TCD1_TDR[21:16] (RW)
 *
 * After scu pdn_req, count this value to assert A7 l2retn to 1'b0 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR (16U) /*!< Bit position for GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR. */
#define BM_GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR (0x003F0000U) /*!< Bit mask for GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR. */
#define BS_GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR (6U) /*!< Bit field size in bits for GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR. */

/*! @brief Read current value of the GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR field. */
#define BR_GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR(x) (HW_GPC_PGC_HSIC_CTRL(x).B.L2RETN_TCD1_TDR)

/*! @brief Format value for bitfield GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR. */
#define BF_GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR) & BM_GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR)

/*! @brief Set the L2RETN_TCD1_TDR field to a new value. */
#define BW_GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR(x, v) (HW_GPC_PGC_HSIC_CTRL_WR(x, (HW_GPC_PGC_HSIC_CTRL_RD(x) & ~BM_GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR) | BF_GPC_PGC_HSIC_CTRL_L2RETN_TCD1_TDR(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_HSIC_CTRL, field MEMPWR_TCD1_TDR_TRM[29:24] (RW)
 *
 * After scu pdn_req, count this value to assert A7 mempwr to 1'b1 Can't be
 * programmed to zero (This register control only for SCU Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM (24U) /*!< Bit position for GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BM_GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM (0x3F000000U) /*!< Bit mask for GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BS_GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM (6U) /*!< Bit field size in bits for GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM. */

/*! @brief Read current value of the GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM field. */
#define BR_GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM(x) (HW_GPC_PGC_HSIC_CTRL(x).B.MEMPWR_TCD1_TDR_TRM)

/*! @brief Format value for bitfield GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM. */
#define BF_GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM) & BM_GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM)

/*! @brief Set the MEMPWR_TCD1_TDR_TRM field to a new value. */
#define BW_GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM(x, v) (HW_GPC_PGC_HSIC_CTRL_WR(x, (HW_GPC_PGC_HSIC_CTRL_RD(x) & ~BM_GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM) | BF_GPC_PGC_HSIC_CTRL_MEMPWR_TCD1_TDR_TRM(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_HSIC_PUPSCR - GPC PGC Up Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_HSIC_PUPSCR - GPC PGC Up Sequence Control Register (RW)
 *
 * Reset value: 0x000997C1U
 *
 * GPC PGC Up Sequence Control Register
 */
typedef union _hw_gpc_pgc_hsic_pupscr
{
    uint32_t U;
    struct _hw_gpc_pgc_hsic_pupscr_bitfields
    {
        uint32_t SW : 6;               /*!< [5:0]  */
        uint32_t PUP_WAIT_SCALL_OUT : 1; /*!< [6]  */
        uint32_t SW2ISO : 16;          /*!< [22:7]  */
        uint32_t PUP_SCALLOUT_CNT : 9; /*!< [31:23]  */
    } B;
} hw_gpc_pgc_hsic_pupscr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_HSIC_PUPSCR register
 */
/*@{*/
#define HW_GPC_PGC_HSIC_PUPSCR_ADDR(x) ((uintptr_t)(x) + 0x504U)

#define HW_GPC_PGC_HSIC_PUPSCR(x) (*(__IO hw_gpc_pgc_hsic_pupscr_t *) HW_GPC_PGC_HSIC_PUPSCR_ADDR(x))
#define HW_GPC_PGC_HSIC_PUPSCR_RD(x) (HW_GPC_PGC_HSIC_PUPSCR(x).U)
#define HW_GPC_PGC_HSIC_PUPSCR_WR(x, v) (HW_GPC_PGC_HSIC_PUPSCR(x).U = (v))
#define HW_GPC_PGC_HSIC_PUPSCR_SET(x, v) (HW_GPC_PGC_HSIC_PUPSCR_WR(x, HW_GPC_PGC_HSIC_PUPSCR_RD(x) |  (v)))
#define HW_GPC_PGC_HSIC_PUPSCR_CLR(x, v) (HW_GPC_PGC_HSIC_PUPSCR_WR(x, HW_GPC_PGC_HSIC_PUPSCR_RD(x) & ~(v)))
#define HW_GPC_PGC_HSIC_PUPSCR_TOG(x, v) (HW_GPC_PGC_HSIC_PUPSCR_WR(x, HW_GPC_PGC_HSIC_PUPSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_HSIC_PUPSCR bitfields
 */

/*!
 * @name Register GPC_PGC_HSIC_PUPSCR, field SW[5:0] (RW)
 *
 * After a power-up request (pup_req assertion), the PGC waits a number of
 * clocks equal to the value of SW before asserting switch_b SW must not be programmed
 * to zero.
 */
/*@{*/
#define BP_GPC_PGC_HSIC_PUPSCR_SW (0U)     /*!< Bit position for GPC_PGC_HSIC_PUPSCR_SW. */
#define BM_GPC_PGC_HSIC_PUPSCR_SW (0x0000003FU) /*!< Bit mask for GPC_PGC_HSIC_PUPSCR_SW. */
#define BS_GPC_PGC_HSIC_PUPSCR_SW (6U)     /*!< Bit field size in bits for GPC_PGC_HSIC_PUPSCR_SW. */

/*! @brief Read current value of the GPC_PGC_HSIC_PUPSCR_SW field. */
#define BR_GPC_PGC_HSIC_PUPSCR_SW(x) (HW_GPC_PGC_HSIC_PUPSCR(x).B.SW)

/*! @brief Format value for bitfield GPC_PGC_HSIC_PUPSCR_SW. */
#define BF_GPC_PGC_HSIC_PUPSCR_SW(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_HSIC_PUPSCR_SW) & BM_GPC_PGC_HSIC_PUPSCR_SW)

/*! @brief Set the SW field to a new value. */
#define BW_GPC_PGC_HSIC_PUPSCR_SW(x, v) (HW_GPC_PGC_HSIC_PUPSCR_WR(x, (HW_GPC_PGC_HSIC_PUPSCR_RD(x) & ~BM_GPC_PGC_HSIC_PUPSCR_SW) | BF_GPC_PGC_HSIC_PUPSCR_SW(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_HSIC_PUPSCR, field PUP_WAIT_SCALL_OUT[6] (RW)
 *
 * After SCALL asserting to 1'b0, wait handshake signal SCALL_OUT to return to
 * 1'b0 (This register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_HSIC_PUPSCR_PUP_WAIT_SCALL_OUT (6U) /*!< Bit position for GPC_PGC_HSIC_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BM_GPC_PGC_HSIC_PUPSCR_PUP_WAIT_SCALL_OUT (0x00000040U) /*!< Bit mask for GPC_PGC_HSIC_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BS_GPC_PGC_HSIC_PUPSCR_PUP_WAIT_SCALL_OUT (1U) /*!< Bit field size in bits for GPC_PGC_HSIC_PUPSCR_PUP_WAIT_SCALL_OUT. */

/*! @brief Read current value of the GPC_PGC_HSIC_PUPSCR_PUP_WAIT_SCALL_OUT field. */
#define BR_GPC_PGC_HSIC_PUPSCR_PUP_WAIT_SCALL_OUT(x) (HW_GPC_PGC_HSIC_PUPSCR(x).B.PUP_WAIT_SCALL_OUT)

/*! @brief Format value for bitfield GPC_PGC_HSIC_PUPSCR_PUP_WAIT_SCALL_OUT. */
#define BF_GPC_PGC_HSIC_PUPSCR_PUP_WAIT_SCALL_OUT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_HSIC_PUPSCR_PUP_WAIT_SCALL_OUT) & BM_GPC_PGC_HSIC_PUPSCR_PUP_WAIT_SCALL_OUT)

/*! @brief Set the PUP_WAIT_SCALL_OUT field to a new value. */
#define BW_GPC_PGC_HSIC_PUPSCR_PUP_WAIT_SCALL_OUT(x, v) (HW_GPC_PGC_HSIC_PUPSCR_WR(x, (HW_GPC_PGC_HSIC_PUPSCR_RD(x) & ~BM_GPC_PGC_HSIC_PUPSCR_PUP_WAIT_SCALL_OUT) | BF_GPC_PGC_HSIC_PUPSCR_PUP_WAIT_SCALL_OUT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_HSIC_PUPSCR, field SW2ISO[22:7] (RW)
 *
 * After asserting switch_b, the PGC waits a number of clocks equal to the value
 * of SW2ISO before negating isolation.
 */
/*@{*/
#define BP_GPC_PGC_HSIC_PUPSCR_SW2ISO (7U) /*!< Bit position for GPC_PGC_HSIC_PUPSCR_SW2ISO. */
#define BM_GPC_PGC_HSIC_PUPSCR_SW2ISO (0x007FFF80U) /*!< Bit mask for GPC_PGC_HSIC_PUPSCR_SW2ISO. */
#define BS_GPC_PGC_HSIC_PUPSCR_SW2ISO (16U) /*!< Bit field size in bits for GPC_PGC_HSIC_PUPSCR_SW2ISO. */

/*! @brief Read current value of the GPC_PGC_HSIC_PUPSCR_SW2ISO field. */
#define BR_GPC_PGC_HSIC_PUPSCR_SW2ISO(x) (HW_GPC_PGC_HSIC_PUPSCR(x).B.SW2ISO)

/*! @brief Format value for bitfield GPC_PGC_HSIC_PUPSCR_SW2ISO. */
#define BF_GPC_PGC_HSIC_PUPSCR_SW2ISO(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_HSIC_PUPSCR_SW2ISO) & BM_GPC_PGC_HSIC_PUPSCR_SW2ISO)

/*! @brief Set the SW2ISO field to a new value. */
#define BW_GPC_PGC_HSIC_PUPSCR_SW2ISO(x, v) (HW_GPC_PGC_HSIC_PUPSCR_WR(x, (HW_GPC_PGC_HSIC_PUPSCR_RD(x) & ~BM_GPC_PGC_HSIC_PUPSCR_SW2ISO) | BF_GPC_PGC_HSIC_PUPSCR_SW2ISO(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_HSIC_PUPSCR, field PUP_SCALLOUT_CNT[31:23] (RW)
 *
 * After SCALL asserting to 1'b0, count this value to complete switch power up
 * Only valid when pup_wait_scall_out is set to 1'b0. Can't be programmed to zero
 * (This register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT (23U) /*!< Bit position for GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT. */
#define BM_GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT (0xFF800000U) /*!< Bit mask for GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT. */
#define BS_GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT (9U) /*!< Bit field size in bits for GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT. */

/*! @brief Read current value of the GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT field. */
#define BR_GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT(x) (HW_GPC_PGC_HSIC_PUPSCR(x).B.PUP_SCALLOUT_CNT)

/*! @brief Format value for bitfield GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT. */
#define BF_GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT) & BM_GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT)

/*! @brief Set the PUP_SCALLOUT_CNT field to a new value. */
#define BW_GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT(x, v) (HW_GPC_PGC_HSIC_PUPSCR_WR(x, (HW_GPC_PGC_HSIC_PUPSCR_RD(x) & ~BM_GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT) | BF_GPC_PGC_HSIC_PUPSCR_PUP_SCALLOUT_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_HSIC_PDNSCR - GPC PGC Down Sequence Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_HSIC_PDNSCR - GPC PGC Down Sequence Control Register (RW)
 *
 * Reset value: 0x21000801U
 *
 * GPC PGC Down Sequence Control Register
 */
typedef union _hw_gpc_pgc_hsic_pdnscr
{
    uint32_t U;
    struct _hw_gpc_pgc_hsic_pdnscr_bitfields
    {
        uint32_t ISO : 6;              /*!< [5:0]  */
        uint32_t RESERVED0 : 1;        /*!< [6]  */
        uint32_t PUP_WAIT_SCALL_OUT : 1; /*!< [7]  */
        uint32_t ISO2SW : 6;           /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t PUP_SCALLOUT_CNT : 8; /*!< [23:16]  */
        uint32_t PUP_SCPRE_SCALL_CNT : 8; /*!< [31:24]  */
    } B;
} hw_gpc_pgc_hsic_pdnscr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_HSIC_PDNSCR register
 */
/*@{*/
#define HW_GPC_PGC_HSIC_PDNSCR_ADDR(x) ((uintptr_t)(x) + 0x508U)

#define HW_GPC_PGC_HSIC_PDNSCR(x) (*(__IO hw_gpc_pgc_hsic_pdnscr_t *) HW_GPC_PGC_HSIC_PDNSCR_ADDR(x))
#define HW_GPC_PGC_HSIC_PDNSCR_RD(x) (HW_GPC_PGC_HSIC_PDNSCR(x).U)
#define HW_GPC_PGC_HSIC_PDNSCR_WR(x, v) (HW_GPC_PGC_HSIC_PDNSCR(x).U = (v))
#define HW_GPC_PGC_HSIC_PDNSCR_SET(x, v) (HW_GPC_PGC_HSIC_PDNSCR_WR(x, HW_GPC_PGC_HSIC_PDNSCR_RD(x) |  (v)))
#define HW_GPC_PGC_HSIC_PDNSCR_CLR(x, v) (HW_GPC_PGC_HSIC_PDNSCR_WR(x, HW_GPC_PGC_HSIC_PDNSCR_RD(x) & ~(v)))
#define HW_GPC_PGC_HSIC_PDNSCR_TOG(x, v) (HW_GPC_PGC_HSIC_PDNSCR_WR(x, HW_GPC_PGC_HSIC_PDNSCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_HSIC_PDNSCR bitfields
 */

/*!
 * @name Register GPC_PGC_HSIC_PDNSCR, field ISO[5:0] (RW)
 *
 * Aafte a power-down request (pdn_req assertion), the PGC waits a number of
 * clocks equal to the value of ISO before asserting isolation ISO must not be
 * programmed to zero.
 */
/*@{*/
#define BP_GPC_PGC_HSIC_PDNSCR_ISO (0U)    /*!< Bit position for GPC_PGC_HSIC_PDNSCR_ISO. */
#define BM_GPC_PGC_HSIC_PDNSCR_ISO (0x0000003FU) /*!< Bit mask for GPC_PGC_HSIC_PDNSCR_ISO. */
#define BS_GPC_PGC_HSIC_PDNSCR_ISO (6U)    /*!< Bit field size in bits for GPC_PGC_HSIC_PDNSCR_ISO. */

/*! @brief Read current value of the GPC_PGC_HSIC_PDNSCR_ISO field. */
#define BR_GPC_PGC_HSIC_PDNSCR_ISO(x) (HW_GPC_PGC_HSIC_PDNSCR(x).B.ISO)

/*! @brief Format value for bitfield GPC_PGC_HSIC_PDNSCR_ISO. */
#define BF_GPC_PGC_HSIC_PDNSCR_ISO(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_HSIC_PDNSCR_ISO) & BM_GPC_PGC_HSIC_PDNSCR_ISO)

/*! @brief Set the ISO field to a new value. */
#define BW_GPC_PGC_HSIC_PDNSCR_ISO(x, v) (HW_GPC_PGC_HSIC_PDNSCR_WR(x, (HW_GPC_PGC_HSIC_PDNSCR_RD(x) & ~BM_GPC_PGC_HSIC_PDNSCR_ISO) | BF_GPC_PGC_HSIC_PDNSCR_ISO(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_HSIC_PDNSCR, field PUP_WAIT_SCALL_OUT[7] (RW)
 *
 * After SCALL asserting to 1'b0, wait handshake signal SCALL_OUT to return to
 * 1'b0 (This register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_HSIC_PDNSCR_PUP_WAIT_SCALL_OUT (7U) /*!< Bit position for GPC_PGC_HSIC_PDNSCR_PUP_WAIT_SCALL_OUT. */
#define BM_GPC_PGC_HSIC_PDNSCR_PUP_WAIT_SCALL_OUT (0x00000080U) /*!< Bit mask for GPC_PGC_HSIC_PDNSCR_PUP_WAIT_SCALL_OUT. */
#define BS_GPC_PGC_HSIC_PDNSCR_PUP_WAIT_SCALL_OUT (1U) /*!< Bit field size in bits for GPC_PGC_HSIC_PDNSCR_PUP_WAIT_SCALL_OUT. */

/*! @brief Read current value of the GPC_PGC_HSIC_PDNSCR_PUP_WAIT_SCALL_OUT field. */
#define BR_GPC_PGC_HSIC_PDNSCR_PUP_WAIT_SCALL_OUT(x) (HW_GPC_PGC_HSIC_PDNSCR(x).B.PUP_WAIT_SCALL_OUT)

/*! @brief Format value for bitfield GPC_PGC_HSIC_PDNSCR_PUP_WAIT_SCALL_OUT. */
#define BF_GPC_PGC_HSIC_PDNSCR_PUP_WAIT_SCALL_OUT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_HSIC_PDNSCR_PUP_WAIT_SCALL_OUT) & BM_GPC_PGC_HSIC_PDNSCR_PUP_WAIT_SCALL_OUT)

/*! @brief Set the PUP_WAIT_SCALL_OUT field to a new value. */
#define BW_GPC_PGC_HSIC_PDNSCR_PUP_WAIT_SCALL_OUT(x, v) (HW_GPC_PGC_HSIC_PDNSCR_WR(x, (HW_GPC_PGC_HSIC_PDNSCR_RD(x) & ~BM_GPC_PGC_HSIC_PDNSCR_PUP_WAIT_SCALL_OUT) | BF_GPC_PGC_HSIC_PDNSCR_PUP_WAIT_SCALL_OUT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_HSIC_PDNSCR, field ISO2SW[13:8] (RW)
 *
 * After asserting isolation(by pdn_req assertion), the PGC waits a number of
 * clocks equal to the value of ISO2SW before negating switch_b ISO2SW must not be
 * programmed to zero.
 */
/*@{*/
#define BP_GPC_PGC_HSIC_PDNSCR_ISO2SW (8U) /*!< Bit position for GPC_PGC_HSIC_PDNSCR_ISO2SW. */
#define BM_GPC_PGC_HSIC_PDNSCR_ISO2SW (0x00003F00U) /*!< Bit mask for GPC_PGC_HSIC_PDNSCR_ISO2SW. */
#define BS_GPC_PGC_HSIC_PDNSCR_ISO2SW (6U) /*!< Bit field size in bits for GPC_PGC_HSIC_PDNSCR_ISO2SW. */

/*! @brief Read current value of the GPC_PGC_HSIC_PDNSCR_ISO2SW field. */
#define BR_GPC_PGC_HSIC_PDNSCR_ISO2SW(x) (HW_GPC_PGC_HSIC_PDNSCR(x).B.ISO2SW)

/*! @brief Format value for bitfield GPC_PGC_HSIC_PDNSCR_ISO2SW. */
#define BF_GPC_PGC_HSIC_PDNSCR_ISO2SW(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_HSIC_PDNSCR_ISO2SW) & BM_GPC_PGC_HSIC_PDNSCR_ISO2SW)

/*! @brief Set the ISO2SW field to a new value. */
#define BW_GPC_PGC_HSIC_PDNSCR_ISO2SW(x, v) (HW_GPC_PGC_HSIC_PDNSCR_WR(x, (HW_GPC_PGC_HSIC_PDNSCR_RD(x) & ~BM_GPC_PGC_HSIC_PDNSCR_ISO2SW) | BF_GPC_PGC_HSIC_PDNSCR_ISO2SW(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_HSIC_PDNSCR, field PUP_SCALLOUT_CNT[23:16] (RW)
 *
 * After SCALL asserting to 1'b1, count this value to complete switch power down
 * This control is only valid when pdn_wait_scall_out is set to 1'b0. It can be
 * programmed to zero (This register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT (16U) /*!< Bit position for GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT. */
#define BM_GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT (0x00FF0000U) /*!< Bit mask for GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT. */
#define BS_GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT (8U) /*!< Bit field size in bits for GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT. */

/*! @brief Read current value of the GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT field. */
#define BR_GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT(x) (HW_GPC_PGC_HSIC_PDNSCR(x).B.PUP_SCALLOUT_CNT)

/*! @brief Format value for bitfield GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT. */
#define BF_GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT) & BM_GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT)

/*! @brief Set the PUP_SCALLOUT_CNT field to a new value. */
#define BW_GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT(x, v) (HW_GPC_PGC_HSIC_PDNSCR_WR(x, (HW_GPC_PGC_HSIC_PDNSCR_RD(x) & ~BM_GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT) | BF_GPC_PGC_HSIC_PDNSCR_PUP_SCALLOUT_CNT(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_HSIC_PDNSCR, field PUP_SCPRE_SCALL_CNT[31:24] (RW)
 *
 * After SCPRE asserting to 1'b0, count this value to assert SCALL to 1'b0 (This
 * register control only for MIX Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT (24U) /*!< Bit position for GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BM_GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT (0xFF000000U) /*!< Bit mask for GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BS_GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT (8U) /*!< Bit field size in bits for GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT. */

/*! @brief Read current value of the GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT field. */
#define BR_GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT(x) (HW_GPC_PGC_HSIC_PDNSCR(x).B.PUP_SCPRE_SCALL_CNT)

/*! @brief Format value for bitfield GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT. */
#define BF_GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT) & BM_GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT)

/*! @brief Set the PUP_SCPRE_SCALL_CNT field to a new value. */
#define BW_GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT(x, v) (HW_GPC_PGC_HSIC_PDNSCR_WR(x, (HW_GPC_PGC_HSIC_PDNSCR_RD(x) & ~BM_GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT) | BF_GPC_PGC_HSIC_PDNSCR_PUP_SCPRE_SCALL_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPC_PGC_HSIC_SR - GPC PGC Status Register
 ******************************************************************************/

/*!
 * @brief HW_GPC_PGC_HSIC_SR - GPC PGC Status Register (RW)
 *
 * Reset value: 0x00001000U
 *
 * GPC PGC Status Register
 */
typedef union _hw_gpc_pgc_hsic_sr
{
    uint32_t U;
    struct _hw_gpc_pgc_hsic_sr_bitfields
    {
        uint32_t PSR : 1;              /*!< [0]  */
        uint32_t L2RETN_FLAG : 1;      /*!< [1]  */
        uint32_t ALLOFF_FLAG : 1;      /*!< [2]  */
        uint32_t PUP_CLK_DIV_SEL : 4;  /*!< [6:3]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t L2RSTDIS_DEASSERT_CNT : 10; /*!< [17:8]  */
        uint32_t RESERVED1 : 14;       /*!< [31:18]  */
    } B;
} hw_gpc_pgc_hsic_sr_t;

/*!
 * @name Constants and macros for entire GPC_PGC_HSIC_SR register
 */
/*@{*/
#define HW_GPC_PGC_HSIC_SR_ADDR(x) ((uintptr_t)(x) + 0x50CU)

#define HW_GPC_PGC_HSIC_SR(x)    (*(__IO hw_gpc_pgc_hsic_sr_t *) HW_GPC_PGC_HSIC_SR_ADDR(x))
#define HW_GPC_PGC_HSIC_SR_RD(x) (HW_GPC_PGC_HSIC_SR(x).U)
#define HW_GPC_PGC_HSIC_SR_WR(x, v) (HW_GPC_PGC_HSIC_SR(x).U = (v))
#define HW_GPC_PGC_HSIC_SR_SET(x, v) (HW_GPC_PGC_HSIC_SR_WR(x, HW_GPC_PGC_HSIC_SR_RD(x) |  (v)))
#define HW_GPC_PGC_HSIC_SR_CLR(x, v) (HW_GPC_PGC_HSIC_SR_WR(x, HW_GPC_PGC_HSIC_SR_RD(x) & ~(v)))
#define HW_GPC_PGC_HSIC_SR_TOG(x, v) (HW_GPC_PGC_HSIC_SR_WR(x, HW_GPC_PGC_HSIC_SR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPC_PGC_HSIC_SR bitfields
 */

/*!
 * @name Register GPC_PGC_HSIC_SR, field PSR[0] (RO)
 *
 * Power status. When in functional (or software-controlled debug) mode, PGC
 * hardware sets PSR as soon as any of the power control output changes its state to
 * one. Write one to clear this bit. Software should clear this bit after power
 * up; otherwise, PSR continues to reflect the power status of the initial power
 * down.
 *
 * Values:
 * - 0 - The target subsystem was not powered down for the previous power-down
 *     request.
 * - 1 - The target subsystem was powered down for the previous power-down
 *     request.
 */
/*@{*/
#define BP_GPC_PGC_HSIC_SR_PSR (0U)        /*!< Bit position for GPC_PGC_HSIC_SR_PSR. */
#define BM_GPC_PGC_HSIC_SR_PSR (0x00000001U) /*!< Bit mask for GPC_PGC_HSIC_SR_PSR. */
#define BS_GPC_PGC_HSIC_SR_PSR (1U)        /*!< Bit field size in bits for GPC_PGC_HSIC_SR_PSR. */

/*! @brief Read current value of the GPC_PGC_HSIC_SR_PSR field. */
#define BR_GPC_PGC_HSIC_SR_PSR(x) (HW_GPC_PGC_HSIC_SR(x).B.PSR)
/*@}*/

/*!
 * @name Register GPC_PGC_HSIC_SR, field L2RETN_FLAG[1] (RO)
 *
 * L2 Retention Flag Software should write "1" to clear this flag after A7 is
 * wakeup from L2 retention mode, otherwise it will always keep to 1 (This register
 * control only for SCU Type PGC)
 *
 * Values:
 * - 0 - A7 is not wakeup from L2 retention mode.
 * - 1 - A7 is wakeup from L2 retention mode.
 */
/*@{*/
#define BP_GPC_PGC_HSIC_SR_L2RETN_FLAG (1U) /*!< Bit position for GPC_PGC_HSIC_SR_L2RETN_FLAG. */
#define BM_GPC_PGC_HSIC_SR_L2RETN_FLAG (0x00000002U) /*!< Bit mask for GPC_PGC_HSIC_SR_L2RETN_FLAG. */
#define BS_GPC_PGC_HSIC_SR_L2RETN_FLAG (1U) /*!< Bit field size in bits for GPC_PGC_HSIC_SR_L2RETN_FLAG. */

/*! @brief Read current value of the GPC_PGC_HSIC_SR_L2RETN_FLAG field. */
#define BR_GPC_PGC_HSIC_SR_L2RETN_FLAG(x) (HW_GPC_PGC_HSIC_SR(x).B.L2RETN_FLAG)
/*@}*/

/*!
 * @name Register GPC_PGC_HSIC_SR, field ALLOFF_FLAG[2] (RO)
 *
 * All-off flag. Software should write "1" to clear this flag after A7 is wakeup
 * from ALL_OFF mode, otherwise, it will always keep to 1 (This register control
 * only for SCU Type PGC)
 *
 * Values:
 * - 0 - A7 is not wakeup from ALL_OFF mode.
 * - 1 - A7 is wakeup from ALL_OFF mode.
 */
/*@{*/
#define BP_GPC_PGC_HSIC_SR_ALLOFF_FLAG (2U) /*!< Bit position for GPC_PGC_HSIC_SR_ALLOFF_FLAG. */
#define BM_GPC_PGC_HSIC_SR_ALLOFF_FLAG (0x00000004U) /*!< Bit mask for GPC_PGC_HSIC_SR_ALLOFF_FLAG. */
#define BS_GPC_PGC_HSIC_SR_ALLOFF_FLAG (1U) /*!< Bit field size in bits for GPC_PGC_HSIC_SR_ALLOFF_FLAG. */

/*! @brief Read current value of the GPC_PGC_HSIC_SR_ALLOFF_FLAG field. */
#define BR_GPC_PGC_HSIC_SR_ALLOFF_FLAG(x) (HW_GPC_PGC_HSIC_SR(x).B.ALLOFF_FLAG)
/*@}*/

/*!
 * @name Register GPC_PGC_HSIC_SR, field PUP_CLK_DIV_SEL[6:3] (RW)
 *
 * Clock divider select for the clock of power up counter(count_clk is 32KHz for
 * CPU/SCU type PGC, ipg_clk(66MHz) for MIX/PU Type PGC)
 *
 * Values:
 * - 0000 - 1
 * - 0001 - 1/2 count_clk
 * - 0010 - 1/4 count_clk
 * - 0011 - 1/8 count_clk
 * - 0100 - 1/16 count_clk
 * - 0101 - 1/32 count_clk
 * - 0110 - 1/64 count_clk
 * - 0111 - 1/128 count_clk
 * - 1000 - 1/256 count_clk
 * - 1001 - 1/512 count_clk
 * - 1010 - 1/1024 count_clk
 * - 1011 - 1/2056 count_clk
 * - 1100 - 1/4096 count_clk
 * - 1101 - 1/8192 count_clk
 * - 1110 - 1/16384 count_clk
 * - 1111 - 1/32768 count_clk
 */
/*@{*/
#define BP_GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL (3U) /*!< Bit position for GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL. */
#define BM_GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL (0x00000078U) /*!< Bit mask for GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL. */
#define BS_GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL (4U) /*!< Bit field size in bits for GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL. */

/*! @brief Read current value of the GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL field. */
#define BR_GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL(x) (HW_GPC_PGC_HSIC_SR(x).B.PUP_CLK_DIV_SEL)

/*! @brief Format value for bitfield GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL. */
#define BF_GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL) & BM_GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL)

/*! @brief Set the PUP_CLK_DIV_SEL field to a new value. */
#define BW_GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL(x, v) (HW_GPC_PGC_HSIC_SR_WR(x, (HW_GPC_PGC_HSIC_SR_RD(x) & ~BM_GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL) | BF_GPC_PGC_HSIC_SR_PUP_CLK_DIV_SEL(v)))
/*@}*/

/*!
 * @name Register GPC_PGC_HSIC_SR, field L2RSTDIS_DEASSERT_CNT[17:8] (RW)
 *
 * Count this value to de-assert L2RSTDISABLE to LOW after CPU0 or CPU1 power up
 * This value can't be programmed to zero (This register control only for SCU
 * Type PGC)
 */
/*@{*/
#define BP_GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT (8U) /*!< Bit position for GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT. */
#define BM_GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT (0x0003FF00U) /*!< Bit mask for GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT. */
#define BS_GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT (10U) /*!< Bit field size in bits for GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT. */

/*! @brief Read current value of the GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT field. */
#define BR_GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT(x) (HW_GPC_PGC_HSIC_SR(x).B.L2RSTDIS_DEASSERT_CNT)

/*! @brief Format value for bitfield GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT. */
#define BF_GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT) & BM_GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT)

/*! @brief Set the L2RSTDIS_DEASSERT_CNT field to a new value. */
#define BW_GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT(x, v) (HW_GPC_PGC_HSIC_SR_WR(x, (HW_GPC_PGC_HSIC_SR_RD(x) & ~BM_GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT) | BF_GPC_PGC_HSIC_SR_L2RSTDIS_DEASSERT_CNT(v)))
/*@}*/

/*******************************************************************************
 * hw_gpc_pgc_t - module struct
 ******************************************************************************/
/*!
 * @brief All GPC_PGC module registers.
 */
#pragma pack(1)
typedef struct _hw_gpc_pgc
{
    __IO hw_gpc_pgc_a7core0_ctrl_t A7CORE0_CTRL; /*!< [0x0] GPC PGC Control Register */
    __IO hw_gpc_pgc_a7core0_pupscr_t A7CORE0_PUPSCR; /*!< [0x4] GPC PGC Up Sequence Control Register */
    __IO hw_gpc_pgc_a7core0_pdnscr_t A7CORE0_PDNSCR; /*!< [0x8] GPC PGC Down Sequence Control Register */
    __IO hw_gpc_pgc_a7core0_sr_t A7CORE0_SR; /*!< [0xC] GPC PGC Status Register */
    uint8_t _reserved0[48];
    __IO hw_gpc_pgc_a7core1_ctrl_t A7CORE1_CTRL; /*!< [0x40] GPC PGC Control Register */
    __IO hw_gpc_pgc_a7core1_pupscr_t A7CORE1_PUPSCR; /*!< [0x44] GPC PGC Up Sequence Control Register */
    __IO hw_gpc_pgc_a7core1_pdnscr_t A7CORE1_PDNSCR; /*!< [0x48] GPC PGC Down Sequence Control Register */
    __IO hw_gpc_pgc_a7core1_sr_t A7CORE1_SR; /*!< [0x4C] GPC PGC Status Register */
    uint8_t _reserved1[48];
    __IO hw_gpc_pgc_a7scu_ctrl_t A7SCU_CTRL; /*!< [0x80] GPC PGC Control Register */
    __IO hw_gpc_pgc_a7scu_pupscr_t A7SCU_PUPSCR; /*!< [0x84] GPC PGC Up Sequence Control Register */
    __IO hw_gpc_pgc_a7scu_pdnscr_t A7SCU_PDNSCR; /*!< [0x88] GPC PGC Down Sequence Control Register */
    __IO hw_gpc_pgc_a7scu_sr_t A7SCU_SR;   /*!< [0x8C] GPC PGC Status Register */
    __I hw_gpc_pgc_scu_auxsw_t SCU_AUXSW;  /*!< [0x90] GPC PGC Auxiliary Power Switch SCU Control Register */
    uint8_t _reserved2[44];
    __IO hw_gpc_pgc_mix_ctrl_t MIX_CTRL;   /*!< [0xC0] GPC PGC Control Register */
    __IO hw_gpc_pgc_mix_pupscr_t MIX_PUPSCR; /*!< [0xC4] GPC PGC Up Sequence Control Register */
    __IO hw_gpc_pgc_mix_pdnscr_t MIX_PDNSCR; /*!< [0xC8] GPC PGC Down Sequence Control Register */
    __IO hw_gpc_pgc_mix_sr_t MIX_SR;       /*!< [0xCC] GPC PGC Status Register */
    uint8_t _reserved3[48];
    __IO hw_gpc_pgc_mipi_ctrl_t MIPI_CTRL; /*!< [0x100] GPC PGC Control Register */
    __IO hw_gpc_pgc_mipi_pupscr_t MIPI_PUPSCR; /*!< [0x104] GPC PGC Up Sequence Control Register */
    __IO hw_gpc_pgc_mipi_pdnscr_t MIPI_PDNSCR; /*!< [0x108] GPC PGC Down Sequence Control Register */
    __IO hw_gpc_pgc_mipi_sr_t MIPI_SR;     /*!< [0x10C] GPC PGC Status Register */
    uint8_t _reserved4[48];
    __IO hw_gpc_pgc_pcie_ctrl_t PCIE_CTRL; /*!< [0x140] GPC PGC Control Register */
    __IO hw_gpc_pgc_pcie_pupscr_t PCIE_PUPSCR; /*!< [0x144] GPC PGC Up Sequence Control Register */
    __IO hw_gpc_pgc_pcie_pdnscr_t PCIE_PDNSCR; /*!< [0x148] GPC PGC Down Sequence Control Register */
    __IO hw_gpc_pgc_pcie_sr_t PCIE_SR;     /*!< [0x14C] GPC PGC Status Register */
    uint8_t _reserved5[704];
    __IO hw_gpc_pgc_mipi_auxsw_t MIPI_AUXSW; /*!< [0x410] GPC PGC Auxiliary Power Switch Control Register */
    uint8_t _reserved6[60];
    __IO hw_gpc_pgc_pcie_auxsw_t PCIE_AUXSW; /*!< [0x450] GPC PGC Auxiliary Power Switch Control Register */
    uint8_t _reserved7[172];
    __IO hw_gpc_pgc_hsic_ctrl_t HSIC_CTRL; /*!< [0x500] GPC PGC Control Register */
    __IO hw_gpc_pgc_hsic_pupscr_t HSIC_PUPSCR; /*!< [0x504] GPC PGC Up Sequence Control Register */
    __IO hw_gpc_pgc_hsic_pdnscr_t HSIC_PDNSCR; /*!< [0x508] GPC PGC Down Sequence Control Register */
    __IO hw_gpc_pgc_hsic_sr_t HSIC_SR;     /*!< [0x50C] GPC PGC Status Register */
} hw_gpc_pgc_t;
#pragma pack()

/*! @brief Macro to access all GPC_PGC registers. */
/*! @param x GPC_PGC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_GPC_PGC_REGS(GPC_PGC_BASE)</code>. */
#define HW_GPC_PGC_REGS(x) (*(hw_gpc_pgc_t *)(x))

/*
 * iMX7D GPIO
 *
 * General Purpose Input/Output (GPIO)
 *
 * Registers defined in this header file:
 * - HW_GPIO_DR - GPIO data register
 * - HW_GPIO_GDIR - GPIO direction register
 * - HW_GPIO_PSR - GPIO pad status register
 * - HW_GPIO_ICR1 - GPIO interrupt configuration register1
 * - HW_GPIO_ICR2 - GPIO interrupt configuration register2
 * - HW_GPIO_IMR - GPIO interrupt mask register
 * - HW_GPIO_ISR - GPIO interrupt status register
 * - HW_GPIO_EDGE_SEL - GPIO edge select register
 *
 * - hw_gpio_t - Struct containing all module registers.
 */

#define HW_GPIO_INSTANCE_COUNT (7U) /*!< Number of instances of the GPIO module. */
#define HW_GPIO1 (0U) /*!< Instance number for GPIO1. */
#define HW_GPIO2 (1U) /*!< Instance number for GPIO2. */
#define HW_GPIO3 (2U) /*!< Instance number for GPIO3. */
#define HW_GPIO4 (3U) /*!< Instance number for GPIO4. */
#define HW_GPIO5 (4U) /*!< Instance number for GPIO5. */
#define HW_GPIO6 (5U) /*!< Instance number for GPIO6. */
#define HW_GPIO7 (6U) /*!< Instance number for GPIO7. */
#define GPIO1_BASE            (0x30200000U) /*!< Base address for GPIO1. */
#define GPIO2_BASE            (0x30210000U) /*!< Base address for GPIO2. */
#define GPIO3_BASE            (0x30220000U) /*!< Base address for GPIO3. */
#define GPIO4_BASE            (0x30230000U) /*!< Base address for GPIO4. */
#define GPIO5_BASE            (0x30240000U) /*!< Base address for GPIO5. */
#define GPIO6_BASE            (0x30250000U) /*!< Base address for GPIO6. */
#define GPIO7_BASE            (0x30260000U) /*!< Base address for GPIO7. */
/*! Array initializer of GPIO base addresses. */
#define GPIO_BASE_ADDRS       { GPIO1_BASE, GPIO2_BASE, GPIO3_BASE, GPIO4_BASE, GPIO5_BASE, GPIO6_BASE, GPIO7_BASE }

/*******************************************************************************
 * HW_GPIO_DR - GPIO data register
 ******************************************************************************/

/*!
 * @brief HW_GPIO_DR - GPIO data register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The 32-bit GPIO_DR register stores data that is ready to be driven to the
 * output lines. If the IOMUXC is in GPIO mode and a given GPIO direction bit is
 * set, then the corresponding DR bit is driven to the output. If a given GPIO
 * direction bit is cleared, then a read of GPIO_DR reflects the value of the
 * corresponding signal.Two wait states are required in read access for synchronization.
 * The results of a read of a DR bit depends on the IOMUXC input mode settings
 * and the corresponding GDIR bit as follows: If GDIR[n] is set and IOMUXC input
 * mode is GPIO, then reading DR[n] returns the contents of DR[n]. If GDIR[n] is
 * cleared and IOMUXC input mode is GPIO, then reading DR[n] returns the
 * corresponding input signal's value. If GDIR[n] is set and IOMUXC input mode is not GPIO,
 * then reading DR[n] returns the contents of DR[n]. If GDIR[n] is cleared and
 * IOMUXC input mode is not GPIO, then reading DR[n] always returns zero.
 */
typedef union _hw_gpio_dr
{
    uint32_t U;
    struct _hw_gpio_dr_bitfields
    {
        uint32_t DR : 32;              /*!< [31:0]  */
    } B;
} hw_gpio_dr_t;

/*!
 * @name Constants and macros for entire GPIO_DR register
 */
/*@{*/
#define HW_GPIO_DR_ADDR(x)       ((uintptr_t)(x) + 0x0U)

#define HW_GPIO_DR(x)            (*(__IO hw_gpio_dr_t *) HW_GPIO_DR_ADDR(x))
#define HW_GPIO_DR_RD(x)         (HW_GPIO_DR(x).U)
#define HW_GPIO_DR_WR(x, v)      (HW_GPIO_DR(x).U = (v))
#define HW_GPIO_DR_SET(x, v)     (HW_GPIO_DR_WR(x, HW_GPIO_DR_RD(x) |  (v)))
#define HW_GPIO_DR_CLR(x, v)     (HW_GPIO_DR_WR(x, HW_GPIO_DR_RD(x) & ~(v)))
#define HW_GPIO_DR_TOG(x, v)     (HW_GPIO_DR_WR(x, HW_GPIO_DR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPIO_DR bitfields
 */

/*!
 * @name Register GPIO_DR, field DR[31:0] (RW)
 *
 * Data bits. This register defines the value of the GPIO output when the signal
 * is configured as an output (GDIR[n]=1). Writes to this register are stored in
 * a register. Reading GPIO_DR returns the value stored in the register if the
 * signal is configured as an output (GDIR[n]=1), or the input signal's value if
 * configured as an input (GDIR[n]=0). The I/O multiplexer must be configured to
 * GPIO mode for the GPIO_DR value to connect with the signal. Reading the data
 * register with the input path disabled always returns a zero value.
 */
/*@{*/
#define BP_GPIO_DR_DR        (0U)          /*!< Bit position for GPIO_DR_DR. */
#define BM_GPIO_DR_DR        (0xFFFFFFFFU) /*!< Bit mask for GPIO_DR_DR. */
#define BS_GPIO_DR_DR        (32U)         /*!< Bit field size in bits for GPIO_DR_DR. */

/*! @brief Read current value of the GPIO_DR_DR field. */
#define BR_GPIO_DR_DR(x)     (HW_GPIO_DR(x).U)

/*! @brief Format value for bitfield GPIO_DR_DR. */
#define BF_GPIO_DR_DR(v)     ((uint32_t)((uint32_t)(v) << BP_GPIO_DR_DR) & BM_GPIO_DR_DR)

/*! @brief Set the DR field to a new value. */
#define BW_GPIO_DR_DR(x, v)  (HW_GPIO_DR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPIO_GDIR - GPIO direction register
 ******************************************************************************/

/*!
 * @brief HW_GPIO_GDIR - GPIO direction register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPIO_GDIR functions as direction control when the IOMUXC is in GPIO mode.
 * Each bit specifies the direction of a one-bit signal. The mapping of each DIR bit
 * to a corresponding SoC signal is determined by the SoC's pin assignment and
 * the IOMUX table. For more details consult the IOMUXC chapter.
 */
typedef union _hw_gpio_gdir
{
    uint32_t U;
    struct _hw_gpio_gdir_bitfields
    {
        uint32_t GDIR : 32;            /*!< [31:0]  */
    } B;
} hw_gpio_gdir_t;

/*!
 * @name Constants and macros for entire GPIO_GDIR register
 */
/*@{*/
#define HW_GPIO_GDIR_ADDR(x)     ((uintptr_t)(x) + 0x4U)

#define HW_GPIO_GDIR(x)          (*(__IO hw_gpio_gdir_t *) HW_GPIO_GDIR_ADDR(x))
#define HW_GPIO_GDIR_RD(x)       (HW_GPIO_GDIR(x).U)
#define HW_GPIO_GDIR_WR(x, v)    (HW_GPIO_GDIR(x).U = (v))
#define HW_GPIO_GDIR_SET(x, v)   (HW_GPIO_GDIR_WR(x, HW_GPIO_GDIR_RD(x) |  (v)))
#define HW_GPIO_GDIR_CLR(x, v)   (HW_GPIO_GDIR_WR(x, HW_GPIO_GDIR_RD(x) & ~(v)))
#define HW_GPIO_GDIR_TOG(x, v)   (HW_GPIO_GDIR_WR(x, HW_GPIO_GDIR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPIO_GDIR bitfields
 */

/*!
 * @name Register GPIO_GDIR, field GDIR[31:0] (RW)
 *
 * GPIO direction bits. Bit n of this register defines the direction of the
 * GPIO[n] signal. GPIO_GDIR affects only the direction of the I/O signal when the
 * corresponding bit in the I/O MUX is configured for GPIO.
 *
 * Values:
 * - 0 - GPIO is configured as input.
 * - 1 - GPIO is configured as output.
 */
/*@{*/
#define BP_GPIO_GDIR_GDIR    (0U)          /*!< Bit position for GPIO_GDIR_GDIR. */
#define BM_GPIO_GDIR_GDIR    (0xFFFFFFFFU) /*!< Bit mask for GPIO_GDIR_GDIR. */
#define BS_GPIO_GDIR_GDIR    (32U)         /*!< Bit field size in bits for GPIO_GDIR_GDIR. */

#define BV_GPIO_GDIR_GDIR_INPUT        (0U)          /*!< Bit field value for GPIO_GDIR_GDIR: GPIO is configured as input. */
#define BV_GPIO_GDIR_GDIR_OUTPUT       (0x1U)        /*!< Bit field value for GPIO_GDIR_GDIR: GPIO is configured as output. */

/*! @brief Read current value of the GPIO_GDIR_GDIR field. */
#define BR_GPIO_GDIR_GDIR(x) (HW_GPIO_GDIR(x).U)

/*! @brief Format value for bitfield GPIO_GDIR_GDIR. */
#define BF_GPIO_GDIR_GDIR(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_GDIR_GDIR) & BM_GPIO_GDIR_GDIR)

/*! @brief Set the GDIR field to a new value. */
#define BW_GPIO_GDIR_GDIR(x, v) (HW_GPIO_GDIR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPIO_PSR - GPIO pad status register
 ******************************************************************************/

/*!
 * @brief HW_GPIO_PSR - GPIO pad status register (RO)
 *
 * Reset value: 0x00000000U
 *
 * GPIO_PSR is a read-only register. Each bit stores the value of the
 * corresponding input signal (as configured in the IOMUX). This register is clocked with
 * the ipg_clk_s clock, meaning that the input signal is sampled only when
 * accessing this location. Two wait states are required any time this register is
 * accessed for synchronization.
 */
typedef union _hw_gpio_psr
{
    uint32_t U;
    struct _hw_gpio_psr_bitfields
    {
        uint32_t PSR : 32;             /*!< [31:0]  */
    } B;
} hw_gpio_psr_t;

/*!
 * @name Constants and macros for entire GPIO_PSR register
 */
/*@{*/
#define HW_GPIO_PSR_ADDR(x)      ((uintptr_t)(x) + 0x8U)

#define HW_GPIO_PSR(x)           (*(__I hw_gpio_psr_t *) HW_GPIO_PSR_ADDR(x))
#define HW_GPIO_PSR_RD(x)        (HW_GPIO_PSR(x).U)
/*@}*/

/*
 * Constants & macros for individual GPIO_PSR bitfields
 */

/*!
 * @name Register GPIO_PSR, field PSR[31:0] (RO)
 *
 * GPIO pad status bits (status bits). Reading GPIO_PSR returns the state of the
 * corresponding input signal. Settings: The IOMUXC must be configured to GPIO
 * mode for GPIO_PSR to reflect the state of the corresponding signal.
 */
/*@{*/
#define BP_GPIO_PSR_PSR      (0U)          /*!< Bit position for GPIO_PSR_PSR. */
#define BM_GPIO_PSR_PSR      (0xFFFFFFFFU) /*!< Bit mask for GPIO_PSR_PSR. */
#define BS_GPIO_PSR_PSR      (32U)         /*!< Bit field size in bits for GPIO_PSR_PSR. */

/*! @brief Read current value of the GPIO_PSR_PSR field. */
#define BR_GPIO_PSR_PSR(x)   (HW_GPIO_PSR(x).U)
/*@}*/

/*******************************************************************************
 * HW_GPIO_ICR1 - GPIO interrupt configuration register1
 ******************************************************************************/

/*!
 * @brief HW_GPIO_ICR1 - GPIO interrupt configuration register1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPIO_ICR1 contains 16 two-bit fields, where each field specifies the
 * interrupt configuration for a different input signal.
 */
typedef union _hw_gpio_icr1
{
    uint32_t U;
    struct _hw_gpio_icr1_bitfields
    {
        uint32_t ICR0 : 2;             /*!< [1:0]  */
        uint32_t ICR1 : 2;             /*!< [3:2]  */
        uint32_t ICR2 : 2;             /*!< [5:4]  */
        uint32_t ICR3 : 2;             /*!< [7:6]  */
        uint32_t ICR4 : 2;             /*!< [9:8]  */
        uint32_t ICR5 : 2;             /*!< [11:10]  */
        uint32_t ICR6 : 2;             /*!< [13:12]  */
        uint32_t ICR7 : 2;             /*!< [15:14]  */
        uint32_t ICR8 : 2;             /*!< [17:16]  */
        uint32_t ICR9 : 2;             /*!< [19:18]  */
        uint32_t ICR10 : 2;            /*!< [21:20]  */
        uint32_t ICR11 : 2;            /*!< [23:22]  */
        uint32_t ICR12 : 2;            /*!< [25:24]  */
        uint32_t ICR13 : 2;            /*!< [27:26]  */
        uint32_t ICR14 : 2;            /*!< [29:28]  */
        uint32_t ICR15 : 2;            /*!< [31:30]  */
    } B;
} hw_gpio_icr1_t;

/*!
 * @name Constants and macros for entire GPIO_ICR1 register
 */
/*@{*/
#define HW_GPIO_ICR1_ADDR(x)     ((uintptr_t)(x) + 0xCU)

#define HW_GPIO_ICR1(x)          (*(__IO hw_gpio_icr1_t *) HW_GPIO_ICR1_ADDR(x))
#define HW_GPIO_ICR1_RD(x)       (HW_GPIO_ICR1(x).U)
#define HW_GPIO_ICR1_WR(x, v)    (HW_GPIO_ICR1(x).U = (v))
#define HW_GPIO_ICR1_SET(x, v)   (HW_GPIO_ICR1_WR(x, HW_GPIO_ICR1_RD(x) |  (v)))
#define HW_GPIO_ICR1_CLR(x, v)   (HW_GPIO_ICR1_WR(x, HW_GPIO_ICR1_RD(x) & ~(v)))
#define HW_GPIO_ICR1_TOG(x, v)   (HW_GPIO_ICR1_WR(x, HW_GPIO_ICR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPIO_ICR1 bitfields
 */

/*!
 * @name Register GPIO_ICR1, field ICR0[1:0] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 0. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR0    (0U)          /*!< Bit position for GPIO_ICR1_ICR0. */
#define BM_GPIO_ICR1_ICR0    (0x00000003U) /*!< Bit mask for GPIO_ICR1_ICR0. */
#define BS_GPIO_ICR1_ICR0    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR0. */

#define BV_GPIO_ICR1_ICR0_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR0: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR0_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR0: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR0_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR0: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR0_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR0: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR0 field. */
#define BR_GPIO_ICR1_ICR0(x) (HW_GPIO_ICR1(x).B.ICR0)

/*! @brief Format value for bitfield GPIO_ICR1_ICR0. */
#define BF_GPIO_ICR1_ICR0(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR0) & BM_GPIO_ICR1_ICR0)

/*! @brief Set the ICR0 field to a new value. */
#define BW_GPIO_ICR1_ICR0(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR0) | BF_GPIO_ICR1_ICR0(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR1[3:2] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 1. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR1    (2U)          /*!< Bit position for GPIO_ICR1_ICR1. */
#define BM_GPIO_ICR1_ICR1    (0x0000000CU) /*!< Bit mask for GPIO_ICR1_ICR1. */
#define BS_GPIO_ICR1_ICR1    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR1. */

#define BV_GPIO_ICR1_ICR1_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR1: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR1_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR1: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR1_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR1: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR1_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR1: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR1 field. */
#define BR_GPIO_ICR1_ICR1(x) (HW_GPIO_ICR1(x).B.ICR1)

/*! @brief Format value for bitfield GPIO_ICR1_ICR1. */
#define BF_GPIO_ICR1_ICR1(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR1) & BM_GPIO_ICR1_ICR1)

/*! @brief Set the ICR1 field to a new value. */
#define BW_GPIO_ICR1_ICR1(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR1) | BF_GPIO_ICR1_ICR1(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR2[5:4] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 2. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR2    (4U)          /*!< Bit position for GPIO_ICR1_ICR2. */
#define BM_GPIO_ICR1_ICR2    (0x00000030U) /*!< Bit mask for GPIO_ICR1_ICR2. */
#define BS_GPIO_ICR1_ICR2    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR2. */

#define BV_GPIO_ICR1_ICR2_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR2: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR2_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR2: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR2_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR2: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR2_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR2: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR2 field. */
#define BR_GPIO_ICR1_ICR2(x) (HW_GPIO_ICR1(x).B.ICR2)

/*! @brief Format value for bitfield GPIO_ICR1_ICR2. */
#define BF_GPIO_ICR1_ICR2(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR2) & BM_GPIO_ICR1_ICR2)

/*! @brief Set the ICR2 field to a new value. */
#define BW_GPIO_ICR1_ICR2(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR2) | BF_GPIO_ICR1_ICR2(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR3[7:6] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 3. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR3    (6U)          /*!< Bit position for GPIO_ICR1_ICR3. */
#define BM_GPIO_ICR1_ICR3    (0x000000C0U) /*!< Bit mask for GPIO_ICR1_ICR3. */
#define BS_GPIO_ICR1_ICR3    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR3. */

#define BV_GPIO_ICR1_ICR3_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR3: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR3_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR3: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR3_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR3: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR3_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR3: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR3 field. */
#define BR_GPIO_ICR1_ICR3(x) (HW_GPIO_ICR1(x).B.ICR3)

/*! @brief Format value for bitfield GPIO_ICR1_ICR3. */
#define BF_GPIO_ICR1_ICR3(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR3) & BM_GPIO_ICR1_ICR3)

/*! @brief Set the ICR3 field to a new value. */
#define BW_GPIO_ICR1_ICR3(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR3) | BF_GPIO_ICR1_ICR3(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR4[9:8] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 4. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR4    (8U)          /*!< Bit position for GPIO_ICR1_ICR4. */
#define BM_GPIO_ICR1_ICR4    (0x00000300U) /*!< Bit mask for GPIO_ICR1_ICR4. */
#define BS_GPIO_ICR1_ICR4    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR4. */

#define BV_GPIO_ICR1_ICR4_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR4: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR4_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR4: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR4_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR4: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR4_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR4: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR4 field. */
#define BR_GPIO_ICR1_ICR4(x) (HW_GPIO_ICR1(x).B.ICR4)

/*! @brief Format value for bitfield GPIO_ICR1_ICR4. */
#define BF_GPIO_ICR1_ICR4(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR4) & BM_GPIO_ICR1_ICR4)

/*! @brief Set the ICR4 field to a new value. */
#define BW_GPIO_ICR1_ICR4(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR4) | BF_GPIO_ICR1_ICR4(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR5[11:10] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 5. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR5    (10U)         /*!< Bit position for GPIO_ICR1_ICR5. */
#define BM_GPIO_ICR1_ICR5    (0x00000C00U) /*!< Bit mask for GPIO_ICR1_ICR5. */
#define BS_GPIO_ICR1_ICR5    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR5. */

#define BV_GPIO_ICR1_ICR5_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR5: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR5_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR5: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR5_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR5: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR5_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR5: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR5 field. */
#define BR_GPIO_ICR1_ICR5(x) (HW_GPIO_ICR1(x).B.ICR5)

/*! @brief Format value for bitfield GPIO_ICR1_ICR5. */
#define BF_GPIO_ICR1_ICR5(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR5) & BM_GPIO_ICR1_ICR5)

/*! @brief Set the ICR5 field to a new value. */
#define BW_GPIO_ICR1_ICR5(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR5) | BF_GPIO_ICR1_ICR5(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR6[13:12] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 6. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR6    (12U)         /*!< Bit position for GPIO_ICR1_ICR6. */
#define BM_GPIO_ICR1_ICR6    (0x00003000U) /*!< Bit mask for GPIO_ICR1_ICR6. */
#define BS_GPIO_ICR1_ICR6    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR6. */

#define BV_GPIO_ICR1_ICR6_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR6: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR6_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR6: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR6_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR6: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR6_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR6: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR6 field. */
#define BR_GPIO_ICR1_ICR6(x) (HW_GPIO_ICR1(x).B.ICR6)

/*! @brief Format value for bitfield GPIO_ICR1_ICR6. */
#define BF_GPIO_ICR1_ICR6(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR6) & BM_GPIO_ICR1_ICR6)

/*! @brief Set the ICR6 field to a new value. */
#define BW_GPIO_ICR1_ICR6(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR6) | BF_GPIO_ICR1_ICR6(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR7[15:14] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 7. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR7    (14U)         /*!< Bit position for GPIO_ICR1_ICR7. */
#define BM_GPIO_ICR1_ICR7    (0x0000C000U) /*!< Bit mask for GPIO_ICR1_ICR7. */
#define BS_GPIO_ICR1_ICR7    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR7. */

#define BV_GPIO_ICR1_ICR7_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR7: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR7_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR7: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR7_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR7: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR7_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR7: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR7 field. */
#define BR_GPIO_ICR1_ICR7(x) (HW_GPIO_ICR1(x).B.ICR7)

/*! @brief Format value for bitfield GPIO_ICR1_ICR7. */
#define BF_GPIO_ICR1_ICR7(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR7) & BM_GPIO_ICR1_ICR7)

/*! @brief Set the ICR7 field to a new value. */
#define BW_GPIO_ICR1_ICR7(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR7) | BF_GPIO_ICR1_ICR7(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR8[17:16] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 8. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR8    (16U)         /*!< Bit position for GPIO_ICR1_ICR8. */
#define BM_GPIO_ICR1_ICR8    (0x00030000U) /*!< Bit mask for GPIO_ICR1_ICR8. */
#define BS_GPIO_ICR1_ICR8    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR8. */

#define BV_GPIO_ICR1_ICR8_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR8: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR8_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR8: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR8_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR8: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR8_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR8: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR8 field. */
#define BR_GPIO_ICR1_ICR8(x) (HW_GPIO_ICR1(x).B.ICR8)

/*! @brief Format value for bitfield GPIO_ICR1_ICR8. */
#define BF_GPIO_ICR1_ICR8(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR8) & BM_GPIO_ICR1_ICR8)

/*! @brief Set the ICR8 field to a new value. */
#define BW_GPIO_ICR1_ICR8(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR8) | BF_GPIO_ICR1_ICR8(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR9[19:18] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 9. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR9    (18U)         /*!< Bit position for GPIO_ICR1_ICR9. */
#define BM_GPIO_ICR1_ICR9    (0x000C0000U) /*!< Bit mask for GPIO_ICR1_ICR9. */
#define BS_GPIO_ICR1_ICR9    (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR9. */

#define BV_GPIO_ICR1_ICR9_LOW_LEVEL    (0U)          /*!< Bit field value for GPIO_ICR1_ICR9: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR9_HIGH_LEVEL   (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR9: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR9_RISING_EDGE  (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR9: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR9_FALLING_EDGE (0x3U)        /*!< Bit field value for GPIO_ICR1_ICR9: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR9 field. */
#define BR_GPIO_ICR1_ICR9(x) (HW_GPIO_ICR1(x).B.ICR9)

/*! @brief Format value for bitfield GPIO_ICR1_ICR9. */
#define BF_GPIO_ICR1_ICR9(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR9) & BM_GPIO_ICR1_ICR9)

/*! @brief Set the ICR9 field to a new value. */
#define BW_GPIO_ICR1_ICR9(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR9) | BF_GPIO_ICR1_ICR9(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR10[21:20] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 10. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR10   (20U)         /*!< Bit position for GPIO_ICR1_ICR10. */
#define BM_GPIO_ICR1_ICR10   (0x00300000U) /*!< Bit mask for GPIO_ICR1_ICR10. */
#define BS_GPIO_ICR1_ICR10   (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR10. */

#define BV_GPIO_ICR1_ICR10_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR1_ICR10: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR10_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR10: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR10_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR10: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR10_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR1_ICR10: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR10 field. */
#define BR_GPIO_ICR1_ICR10(x) (HW_GPIO_ICR1(x).B.ICR10)

/*! @brief Format value for bitfield GPIO_ICR1_ICR10. */
#define BF_GPIO_ICR1_ICR10(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR10) & BM_GPIO_ICR1_ICR10)

/*! @brief Set the ICR10 field to a new value. */
#define BW_GPIO_ICR1_ICR10(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR10) | BF_GPIO_ICR1_ICR10(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR11[23:22] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 11. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR11   (22U)         /*!< Bit position for GPIO_ICR1_ICR11. */
#define BM_GPIO_ICR1_ICR11   (0x00C00000U) /*!< Bit mask for GPIO_ICR1_ICR11. */
#define BS_GPIO_ICR1_ICR11   (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR11. */

#define BV_GPIO_ICR1_ICR11_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR1_ICR11: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR11_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR11: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR11_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR11: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR11_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR1_ICR11: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR11 field. */
#define BR_GPIO_ICR1_ICR11(x) (HW_GPIO_ICR1(x).B.ICR11)

/*! @brief Format value for bitfield GPIO_ICR1_ICR11. */
#define BF_GPIO_ICR1_ICR11(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR11) & BM_GPIO_ICR1_ICR11)

/*! @brief Set the ICR11 field to a new value. */
#define BW_GPIO_ICR1_ICR11(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR11) | BF_GPIO_ICR1_ICR11(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR12[25:24] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 12. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR12   (24U)         /*!< Bit position for GPIO_ICR1_ICR12. */
#define BM_GPIO_ICR1_ICR12   (0x03000000U) /*!< Bit mask for GPIO_ICR1_ICR12. */
#define BS_GPIO_ICR1_ICR12   (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR12. */

#define BV_GPIO_ICR1_ICR12_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR1_ICR12: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR12_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR12: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR12_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR12: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR12_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR1_ICR12: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR12 field. */
#define BR_GPIO_ICR1_ICR12(x) (HW_GPIO_ICR1(x).B.ICR12)

/*! @brief Format value for bitfield GPIO_ICR1_ICR12. */
#define BF_GPIO_ICR1_ICR12(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR12) & BM_GPIO_ICR1_ICR12)

/*! @brief Set the ICR12 field to a new value. */
#define BW_GPIO_ICR1_ICR12(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR12) | BF_GPIO_ICR1_ICR12(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR13[27:26] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 13. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR13   (26U)         /*!< Bit position for GPIO_ICR1_ICR13. */
#define BM_GPIO_ICR1_ICR13   (0x0C000000U) /*!< Bit mask for GPIO_ICR1_ICR13. */
#define BS_GPIO_ICR1_ICR13   (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR13. */

#define BV_GPIO_ICR1_ICR13_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR1_ICR13: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR13_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR13: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR13_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR13: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR13_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR1_ICR13: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR13 field. */
#define BR_GPIO_ICR1_ICR13(x) (HW_GPIO_ICR1(x).B.ICR13)

/*! @brief Format value for bitfield GPIO_ICR1_ICR13. */
#define BF_GPIO_ICR1_ICR13(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR13) & BM_GPIO_ICR1_ICR13)

/*! @brief Set the ICR13 field to a new value. */
#define BW_GPIO_ICR1_ICR13(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR13) | BF_GPIO_ICR1_ICR13(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR14[29:28] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 14. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR14   (28U)         /*!< Bit position for GPIO_ICR1_ICR14. */
#define BM_GPIO_ICR1_ICR14   (0x30000000U) /*!< Bit mask for GPIO_ICR1_ICR14. */
#define BS_GPIO_ICR1_ICR14   (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR14. */

#define BV_GPIO_ICR1_ICR14_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR1_ICR14: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR14_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR14: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR14_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR14: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR14_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR1_ICR14: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR14 field. */
#define BR_GPIO_ICR1_ICR14(x) (HW_GPIO_ICR1(x).B.ICR14)

/*! @brief Format value for bitfield GPIO_ICR1_ICR14. */
#define BF_GPIO_ICR1_ICR14(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR14) & BM_GPIO_ICR1_ICR14)

/*! @brief Set the ICR14 field to a new value. */
#define BW_GPIO_ICR1_ICR14(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR14) | BF_GPIO_ICR1_ICR14(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR1, field ICR15[31:30] (RW)
 *
 * Interrupt configuration 1 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 15. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR1_ICR15   (30U)         /*!< Bit position for GPIO_ICR1_ICR15. */
#define BM_GPIO_ICR1_ICR15   (0xC0000000U) /*!< Bit mask for GPIO_ICR1_ICR15. */
#define BS_GPIO_ICR1_ICR15   (2U)          /*!< Bit field size in bits for GPIO_ICR1_ICR15. */

#define BV_GPIO_ICR1_ICR15_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR1_ICR15: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR1_ICR15_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR1_ICR15: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR1_ICR15_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR1_ICR15: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR1_ICR15_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR1_ICR15: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR1_ICR15 field. */
#define BR_GPIO_ICR1_ICR15(x) (HW_GPIO_ICR1(x).B.ICR15)

/*! @brief Format value for bitfield GPIO_ICR1_ICR15. */
#define BF_GPIO_ICR1_ICR15(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR1_ICR15) & BM_GPIO_ICR1_ICR15)

/*! @brief Set the ICR15 field to a new value. */
#define BW_GPIO_ICR1_ICR15(x, v) (HW_GPIO_ICR1_WR(x, (HW_GPIO_ICR1_RD(x) & ~BM_GPIO_ICR1_ICR15) | BF_GPIO_ICR1_ICR15(v)))
/*@}*/

/*******************************************************************************
 * HW_GPIO_ICR2 - GPIO interrupt configuration register2
 ******************************************************************************/

/*!
 * @brief HW_GPIO_ICR2 - GPIO interrupt configuration register2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPIO_ICR2 contains 16 two-bit fields, where each field specifies the
 * interrupt configuration for a different input signal.
 */
typedef union _hw_gpio_icr2
{
    uint32_t U;
    struct _hw_gpio_icr2_bitfields
    {
        uint32_t ICR16 : 2;            /*!< [1:0]  */
        uint32_t ICR17 : 2;            /*!< [3:2]  */
        uint32_t ICR18 : 2;            /*!< [5:4]  */
        uint32_t ICR19 : 2;            /*!< [7:6]  */
        uint32_t ICR20 : 2;            /*!< [9:8]  */
        uint32_t ICR21 : 2;            /*!< [11:10]  */
        uint32_t ICR22 : 2;            /*!< [13:12]  */
        uint32_t ICR23 : 2;            /*!< [15:14]  */
        uint32_t ICR24 : 2;            /*!< [17:16]  */
        uint32_t ICR25 : 2;            /*!< [19:18]  */
        uint32_t ICR26 : 2;            /*!< [21:20]  */
        uint32_t ICR27 : 2;            /*!< [23:22]  */
        uint32_t ICR28 : 2;            /*!< [25:24]  */
        uint32_t ICR29 : 2;            /*!< [27:26]  */
        uint32_t ICR30 : 2;            /*!< [29:28]  */
        uint32_t ICR31 : 2;            /*!< [31:30]  */
    } B;
} hw_gpio_icr2_t;

/*!
 * @name Constants and macros for entire GPIO_ICR2 register
 */
/*@{*/
#define HW_GPIO_ICR2_ADDR(x)     ((uintptr_t)(x) + 0x10U)

#define HW_GPIO_ICR2(x)          (*(__IO hw_gpio_icr2_t *) HW_GPIO_ICR2_ADDR(x))
#define HW_GPIO_ICR2_RD(x)       (HW_GPIO_ICR2(x).U)
#define HW_GPIO_ICR2_WR(x, v)    (HW_GPIO_ICR2(x).U = (v))
#define HW_GPIO_ICR2_SET(x, v)   (HW_GPIO_ICR2_WR(x, HW_GPIO_ICR2_RD(x) |  (v)))
#define HW_GPIO_ICR2_CLR(x, v)   (HW_GPIO_ICR2_WR(x, HW_GPIO_ICR2_RD(x) & ~(v)))
#define HW_GPIO_ICR2_TOG(x, v)   (HW_GPIO_ICR2_WR(x, HW_GPIO_ICR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPIO_ICR2 bitfields
 */

/*!
 * @name Register GPIO_ICR2, field ICR16[1:0] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 16. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR16   (0U)          /*!< Bit position for GPIO_ICR2_ICR16. */
#define BM_GPIO_ICR2_ICR16   (0x00000003U) /*!< Bit mask for GPIO_ICR2_ICR16. */
#define BS_GPIO_ICR2_ICR16   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR16. */

#define BV_GPIO_ICR2_ICR16_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR16: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR16_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR16: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR16_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR16: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR16_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR16: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR16 field. */
#define BR_GPIO_ICR2_ICR16(x) (HW_GPIO_ICR2(x).B.ICR16)

/*! @brief Format value for bitfield GPIO_ICR2_ICR16. */
#define BF_GPIO_ICR2_ICR16(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR16) & BM_GPIO_ICR2_ICR16)

/*! @brief Set the ICR16 field to a new value. */
#define BW_GPIO_ICR2_ICR16(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR16) | BF_GPIO_ICR2_ICR16(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR17[3:2] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 17. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR17   (2U)          /*!< Bit position for GPIO_ICR2_ICR17. */
#define BM_GPIO_ICR2_ICR17   (0x0000000CU) /*!< Bit mask for GPIO_ICR2_ICR17. */
#define BS_GPIO_ICR2_ICR17   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR17. */

#define BV_GPIO_ICR2_ICR17_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR17: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR17_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR17: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR17_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR17: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR17_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR17: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR17 field. */
#define BR_GPIO_ICR2_ICR17(x) (HW_GPIO_ICR2(x).B.ICR17)

/*! @brief Format value for bitfield GPIO_ICR2_ICR17. */
#define BF_GPIO_ICR2_ICR17(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR17) & BM_GPIO_ICR2_ICR17)

/*! @brief Set the ICR17 field to a new value. */
#define BW_GPIO_ICR2_ICR17(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR17) | BF_GPIO_ICR2_ICR17(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR18[5:4] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 18. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR18   (4U)          /*!< Bit position for GPIO_ICR2_ICR18. */
#define BM_GPIO_ICR2_ICR18   (0x00000030U) /*!< Bit mask for GPIO_ICR2_ICR18. */
#define BS_GPIO_ICR2_ICR18   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR18. */

#define BV_GPIO_ICR2_ICR18_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR18: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR18_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR18: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR18_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR18: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR18_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR18: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR18 field. */
#define BR_GPIO_ICR2_ICR18(x) (HW_GPIO_ICR2(x).B.ICR18)

/*! @brief Format value for bitfield GPIO_ICR2_ICR18. */
#define BF_GPIO_ICR2_ICR18(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR18) & BM_GPIO_ICR2_ICR18)

/*! @brief Set the ICR18 field to a new value. */
#define BW_GPIO_ICR2_ICR18(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR18) | BF_GPIO_ICR2_ICR18(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR19[7:6] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 19. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR19   (6U)          /*!< Bit position for GPIO_ICR2_ICR19. */
#define BM_GPIO_ICR2_ICR19   (0x000000C0U) /*!< Bit mask for GPIO_ICR2_ICR19. */
#define BS_GPIO_ICR2_ICR19   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR19. */

#define BV_GPIO_ICR2_ICR19_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR19: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR19_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR19: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR19_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR19: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR19_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR19: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR19 field. */
#define BR_GPIO_ICR2_ICR19(x) (HW_GPIO_ICR2(x).B.ICR19)

/*! @brief Format value for bitfield GPIO_ICR2_ICR19. */
#define BF_GPIO_ICR2_ICR19(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR19) & BM_GPIO_ICR2_ICR19)

/*! @brief Set the ICR19 field to a new value. */
#define BW_GPIO_ICR2_ICR19(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR19) | BF_GPIO_ICR2_ICR19(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR20[9:8] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 20. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR20   (8U)          /*!< Bit position for GPIO_ICR2_ICR20. */
#define BM_GPIO_ICR2_ICR20   (0x00000300U) /*!< Bit mask for GPIO_ICR2_ICR20. */
#define BS_GPIO_ICR2_ICR20   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR20. */

#define BV_GPIO_ICR2_ICR20_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR20: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR20_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR20: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR20_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR20: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR20_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR20: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR20 field. */
#define BR_GPIO_ICR2_ICR20(x) (HW_GPIO_ICR2(x).B.ICR20)

/*! @brief Format value for bitfield GPIO_ICR2_ICR20. */
#define BF_GPIO_ICR2_ICR20(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR20) & BM_GPIO_ICR2_ICR20)

/*! @brief Set the ICR20 field to a new value. */
#define BW_GPIO_ICR2_ICR20(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR20) | BF_GPIO_ICR2_ICR20(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR21[11:10] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 21. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR21   (10U)         /*!< Bit position for GPIO_ICR2_ICR21. */
#define BM_GPIO_ICR2_ICR21   (0x00000C00U) /*!< Bit mask for GPIO_ICR2_ICR21. */
#define BS_GPIO_ICR2_ICR21   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR21. */

#define BV_GPIO_ICR2_ICR21_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR21: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR21_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR21: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR21_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR21: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR21_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR21: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR21 field. */
#define BR_GPIO_ICR2_ICR21(x) (HW_GPIO_ICR2(x).B.ICR21)

/*! @brief Format value for bitfield GPIO_ICR2_ICR21. */
#define BF_GPIO_ICR2_ICR21(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR21) & BM_GPIO_ICR2_ICR21)

/*! @brief Set the ICR21 field to a new value. */
#define BW_GPIO_ICR2_ICR21(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR21) | BF_GPIO_ICR2_ICR21(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR22[13:12] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 22. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR22   (12U)         /*!< Bit position for GPIO_ICR2_ICR22. */
#define BM_GPIO_ICR2_ICR22   (0x00003000U) /*!< Bit mask for GPIO_ICR2_ICR22. */
#define BS_GPIO_ICR2_ICR22   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR22. */

#define BV_GPIO_ICR2_ICR22_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR22: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR22_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR22: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR22_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR22: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR22_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR22: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR22 field. */
#define BR_GPIO_ICR2_ICR22(x) (HW_GPIO_ICR2(x).B.ICR22)

/*! @brief Format value for bitfield GPIO_ICR2_ICR22. */
#define BF_GPIO_ICR2_ICR22(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR22) & BM_GPIO_ICR2_ICR22)

/*! @brief Set the ICR22 field to a new value. */
#define BW_GPIO_ICR2_ICR22(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR22) | BF_GPIO_ICR2_ICR22(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR23[15:14] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 23. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR23   (14U)         /*!< Bit position for GPIO_ICR2_ICR23. */
#define BM_GPIO_ICR2_ICR23   (0x0000C000U) /*!< Bit mask for GPIO_ICR2_ICR23. */
#define BS_GPIO_ICR2_ICR23   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR23. */

#define BV_GPIO_ICR2_ICR23_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR23: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR23_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR23: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR23_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR23: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR23_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR23: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR23 field. */
#define BR_GPIO_ICR2_ICR23(x) (HW_GPIO_ICR2(x).B.ICR23)

/*! @brief Format value for bitfield GPIO_ICR2_ICR23. */
#define BF_GPIO_ICR2_ICR23(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR23) & BM_GPIO_ICR2_ICR23)

/*! @brief Set the ICR23 field to a new value. */
#define BW_GPIO_ICR2_ICR23(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR23) | BF_GPIO_ICR2_ICR23(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR24[17:16] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 24. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR24   (16U)         /*!< Bit position for GPIO_ICR2_ICR24. */
#define BM_GPIO_ICR2_ICR24   (0x00030000U) /*!< Bit mask for GPIO_ICR2_ICR24. */
#define BS_GPIO_ICR2_ICR24   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR24. */

#define BV_GPIO_ICR2_ICR24_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR24: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR24_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR24: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR24_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR24: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR24_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR24: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR24 field. */
#define BR_GPIO_ICR2_ICR24(x) (HW_GPIO_ICR2(x).B.ICR24)

/*! @brief Format value for bitfield GPIO_ICR2_ICR24. */
#define BF_GPIO_ICR2_ICR24(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR24) & BM_GPIO_ICR2_ICR24)

/*! @brief Set the ICR24 field to a new value. */
#define BW_GPIO_ICR2_ICR24(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR24) | BF_GPIO_ICR2_ICR24(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR25[19:18] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 25. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR25   (18U)         /*!< Bit position for GPIO_ICR2_ICR25. */
#define BM_GPIO_ICR2_ICR25   (0x000C0000U) /*!< Bit mask for GPIO_ICR2_ICR25. */
#define BS_GPIO_ICR2_ICR25   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR25. */

#define BV_GPIO_ICR2_ICR25_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR25: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR25_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR25: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR25_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR25: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR25_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR25: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR25 field. */
#define BR_GPIO_ICR2_ICR25(x) (HW_GPIO_ICR2(x).B.ICR25)

/*! @brief Format value for bitfield GPIO_ICR2_ICR25. */
#define BF_GPIO_ICR2_ICR25(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR25) & BM_GPIO_ICR2_ICR25)

/*! @brief Set the ICR25 field to a new value. */
#define BW_GPIO_ICR2_ICR25(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR25) | BF_GPIO_ICR2_ICR25(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR26[21:20] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 26. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR26   (20U)         /*!< Bit position for GPIO_ICR2_ICR26. */
#define BM_GPIO_ICR2_ICR26   (0x00300000U) /*!< Bit mask for GPIO_ICR2_ICR26. */
#define BS_GPIO_ICR2_ICR26   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR26. */

#define BV_GPIO_ICR2_ICR26_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR26: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR26_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR26: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR26_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR26: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR26_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR26: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR26 field. */
#define BR_GPIO_ICR2_ICR26(x) (HW_GPIO_ICR2(x).B.ICR26)

/*! @brief Format value for bitfield GPIO_ICR2_ICR26. */
#define BF_GPIO_ICR2_ICR26(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR26) & BM_GPIO_ICR2_ICR26)

/*! @brief Set the ICR26 field to a new value. */
#define BW_GPIO_ICR2_ICR26(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR26) | BF_GPIO_ICR2_ICR26(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR27[23:22] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 27. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR27   (22U)         /*!< Bit position for GPIO_ICR2_ICR27. */
#define BM_GPIO_ICR2_ICR27   (0x00C00000U) /*!< Bit mask for GPIO_ICR2_ICR27. */
#define BS_GPIO_ICR2_ICR27   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR27. */

#define BV_GPIO_ICR2_ICR27_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR27: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR27_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR27: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR27_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR27: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR27_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR27: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR27 field. */
#define BR_GPIO_ICR2_ICR27(x) (HW_GPIO_ICR2(x).B.ICR27)

/*! @brief Format value for bitfield GPIO_ICR2_ICR27. */
#define BF_GPIO_ICR2_ICR27(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR27) & BM_GPIO_ICR2_ICR27)

/*! @brief Set the ICR27 field to a new value. */
#define BW_GPIO_ICR2_ICR27(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR27) | BF_GPIO_ICR2_ICR27(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR28[25:24] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 28. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR28   (24U)         /*!< Bit position for GPIO_ICR2_ICR28. */
#define BM_GPIO_ICR2_ICR28   (0x03000000U) /*!< Bit mask for GPIO_ICR2_ICR28. */
#define BS_GPIO_ICR2_ICR28   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR28. */

#define BV_GPIO_ICR2_ICR28_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR28: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR28_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR28: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR28_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR28: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR28_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR28: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR28 field. */
#define BR_GPIO_ICR2_ICR28(x) (HW_GPIO_ICR2(x).B.ICR28)

/*! @brief Format value for bitfield GPIO_ICR2_ICR28. */
#define BF_GPIO_ICR2_ICR28(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR28) & BM_GPIO_ICR2_ICR28)

/*! @brief Set the ICR28 field to a new value. */
#define BW_GPIO_ICR2_ICR28(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR28) | BF_GPIO_ICR2_ICR28(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR29[27:26] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 29. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR29   (26U)         /*!< Bit position for GPIO_ICR2_ICR29. */
#define BM_GPIO_ICR2_ICR29   (0x0C000000U) /*!< Bit mask for GPIO_ICR2_ICR29. */
#define BS_GPIO_ICR2_ICR29   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR29. */

#define BV_GPIO_ICR2_ICR29_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR29: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR29_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR29: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR29_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR29: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR29_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR29: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR29 field. */
#define BR_GPIO_ICR2_ICR29(x) (HW_GPIO_ICR2(x).B.ICR29)

/*! @brief Format value for bitfield GPIO_ICR2_ICR29. */
#define BF_GPIO_ICR2_ICR29(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR29) & BM_GPIO_ICR2_ICR29)

/*! @brief Set the ICR29 field to a new value. */
#define BW_GPIO_ICR2_ICR29(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR29) | BF_GPIO_ICR2_ICR29(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR30[29:28] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 30. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR30   (28U)         /*!< Bit position for GPIO_ICR2_ICR30. */
#define BM_GPIO_ICR2_ICR30   (0x30000000U) /*!< Bit mask for GPIO_ICR2_ICR30. */
#define BS_GPIO_ICR2_ICR30   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR30. */

#define BV_GPIO_ICR2_ICR30_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR30: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR30_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR30: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR30_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR30: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR30_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR30: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR30 field. */
#define BR_GPIO_ICR2_ICR30(x) (HW_GPIO_ICR2(x).B.ICR30)

/*! @brief Format value for bitfield GPIO_ICR2_ICR30. */
#define BF_GPIO_ICR2_ICR30(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR30) & BM_GPIO_ICR2_ICR30)

/*! @brief Set the ICR30 field to a new value. */
#define BW_GPIO_ICR2_ICR30(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR30) | BF_GPIO_ICR2_ICR30(v)))
/*@}*/

/*!
 * @name Register GPIO_ICR2, field ICR31[31:30] (RW)
 *
 * Interrupt configuration 2 fields. This register controls the active condition
 * of the interrupt function for GPIO interrupt 31. Settings: Bits ICRn[1:0]
 * determine the interrupt condition for signal n as follows:
 *
 * Values:
 * - 00 - Interrupt n is low-level sensitive.
 * - 01 - Interrupt n is high-level sensitive.
 * - 10 - Interrupt n is rising-edge sensitive.
 * - 11 - Interrupt n is falling-edge sensitive.
 */
/*@{*/
#define BP_GPIO_ICR2_ICR31   (30U)         /*!< Bit position for GPIO_ICR2_ICR31. */
#define BM_GPIO_ICR2_ICR31   (0xC0000000U) /*!< Bit mask for GPIO_ICR2_ICR31. */
#define BS_GPIO_ICR2_ICR31   (2U)          /*!< Bit field size in bits for GPIO_ICR2_ICR31. */

#define BV_GPIO_ICR2_ICR31_LOW_LEVEL   (0U)          /*!< Bit field value for GPIO_ICR2_ICR31: Interrupt n is low-level sensitive. */
#define BV_GPIO_ICR2_ICR31_HIGH_LEVEL  (0x1U)        /*!< Bit field value for GPIO_ICR2_ICR31: Interrupt n is high-level sensitive. */
#define BV_GPIO_ICR2_ICR31_RISING_EDGE (0x2U)        /*!< Bit field value for GPIO_ICR2_ICR31: Interrupt n is rising-edge sensitive. */
#define BV_GPIO_ICR2_ICR31_FALLING_EDGE (0x3U)       /*!< Bit field value for GPIO_ICR2_ICR31: Interrupt n is falling-edge sensitive. */

/*! @brief Read current value of the GPIO_ICR2_ICR31 field. */
#define BR_GPIO_ICR2_ICR31(x) (HW_GPIO_ICR2(x).B.ICR31)

/*! @brief Format value for bitfield GPIO_ICR2_ICR31. */
#define BF_GPIO_ICR2_ICR31(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_ICR2_ICR31) & BM_GPIO_ICR2_ICR31)

/*! @brief Set the ICR31 field to a new value. */
#define BW_GPIO_ICR2_ICR31(x, v) (HW_GPIO_ICR2_WR(x, (HW_GPIO_ICR2_RD(x) & ~BM_GPIO_ICR2_ICR31) | BF_GPIO_ICR2_ICR31(v)))
/*@}*/

/*******************************************************************************
 * HW_GPIO_IMR - GPIO interrupt mask register
 ******************************************************************************/

/*!
 * @brief HW_GPIO_IMR - GPIO interrupt mask register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPIO_IMR contains masking bits for each interrupt line.
 */
typedef union _hw_gpio_imr
{
    uint32_t U;
    struct _hw_gpio_imr_bitfields
    {
        uint32_t IMR : 32;             /*!< [31:0]  */
    } B;
} hw_gpio_imr_t;

/*!
 * @name Constants and macros for entire GPIO_IMR register
 */
/*@{*/
#define HW_GPIO_IMR_ADDR(x)      ((uintptr_t)(x) + 0x14U)

#define HW_GPIO_IMR(x)           (*(__IO hw_gpio_imr_t *) HW_GPIO_IMR_ADDR(x))
#define HW_GPIO_IMR_RD(x)        (HW_GPIO_IMR(x).U)
#define HW_GPIO_IMR_WR(x, v)     (HW_GPIO_IMR(x).U = (v))
#define HW_GPIO_IMR_SET(x, v)    (HW_GPIO_IMR_WR(x, HW_GPIO_IMR_RD(x) |  (v)))
#define HW_GPIO_IMR_CLR(x, v)    (HW_GPIO_IMR_WR(x, HW_GPIO_IMR_RD(x) & ~(v)))
#define HW_GPIO_IMR_TOG(x, v)    (HW_GPIO_IMR_WR(x, HW_GPIO_IMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPIO_IMR bitfields
 */

/*!
 * @name Register GPIO_IMR, field IMR[31:0] (RW)
 *
 * Interrupt Mask bits. This register is used to enable or disable the interrupt
 * function on each of the 32 GPIO signals. Settings: Bit IMR[n] (n=0...31)
 * controls interrupt n as follows:
 *
 * Values:
 * - 0 - Interrupt n is disabled.
 * - 1 - Interrupt n is enabled.
 */
/*@{*/
#define BP_GPIO_IMR_IMR      (0U)          /*!< Bit position for GPIO_IMR_IMR. */
#define BM_GPIO_IMR_IMR      (0xFFFFFFFFU) /*!< Bit mask for GPIO_IMR_IMR. */
#define BS_GPIO_IMR_IMR      (32U)         /*!< Bit field size in bits for GPIO_IMR_IMR. */

#define BV_GPIO_IMR_IMR_UNMASKED       (0U)          /*!< Bit field value for GPIO_IMR_IMR: Interrupt n is disabled. */
#define BV_GPIO_IMR_IMR_MASKED         (0x1U)        /*!< Bit field value for GPIO_IMR_IMR: Interrupt n is enabled. */

/*! @brief Read current value of the GPIO_IMR_IMR field. */
#define BR_GPIO_IMR_IMR(x)   (HW_GPIO_IMR(x).U)

/*! @brief Format value for bitfield GPIO_IMR_IMR. */
#define BF_GPIO_IMR_IMR(v)   ((uint32_t)((uint32_t)(v) << BP_GPIO_IMR_IMR) & BM_GPIO_IMR_IMR)

/*! @brief Set the IMR field to a new value. */
#define BW_GPIO_IMR_IMR(x, v) (HW_GPIO_IMR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPIO_ISR - GPIO interrupt status register
 ******************************************************************************/

/*!
 * @brief HW_GPIO_ISR - GPIO interrupt status register (W1C)
 *
 * Reset value: 0x00000000U
 *
 * The GPIO_ISR functions as an interrupt status indicator. Each bit indicates
 * whether an interrupt condition has been met for the corresponding input signal.
 * When an interrupt condition is met (as determined by the corresponding
 * interrupt condition register field), the corresponding bit in this register is set.
 * Two wait states are required in read access for synchronization. One wait
 * state is required for reset.
 */
typedef union _hw_gpio_isr
{
    uint32_t U;
    struct _hw_gpio_isr_bitfields
    {
        uint32_t ISR : 32;             /*!< [31:0]  */
    } B;
} hw_gpio_isr_t;

/*!
 * @name Constants and macros for entire GPIO_ISR register
 */
/*@{*/
#define HW_GPIO_ISR_ADDR(x)      ((uintptr_t)(x) + 0x18U)

#define HW_GPIO_ISR(x)           (*(__IO hw_gpio_isr_t *) HW_GPIO_ISR_ADDR(x))
#define HW_GPIO_ISR_RD(x)        (HW_GPIO_ISR(x).U)
#define HW_GPIO_ISR_WR(x, v)     (HW_GPIO_ISR(x).U = (v))
#define HW_GPIO_ISR_SET(x, v)    (HW_GPIO_ISR_WR(x, HW_GPIO_ISR_RD(x) |  (v)))
#define HW_GPIO_ISR_CLR(x, v)    (HW_GPIO_ISR_WR(x, HW_GPIO_ISR_RD(x) & ~(v)))
#define HW_GPIO_ISR_TOG(x, v)    (HW_GPIO_ISR_WR(x, HW_GPIO_ISR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPIO_ISR bitfields
 */

/*!
 * @name Register GPIO_ISR, field ISR[31:0] (W1C)
 *
 * Interrupt status bits - Bit n of this register is asserted (active high) when
 * the active condition (as determined by the corresponding ICR bit) is detected
 * on the GPIO input and is waiting for service. The value of this register is
 * independent of the value in GPIO_IMR. When the active condition has been
 * detected, the corresponding bit remains set until cleared by software. Status flags
 * are cleared by writing a 1 to the corresponding bit position.
 */
/*@{*/
#define BP_GPIO_ISR_ISR      (0U)          /*!< Bit position for GPIO_ISR_ISR. */
#define BM_GPIO_ISR_ISR      (0xFFFFFFFFU) /*!< Bit mask for GPIO_ISR_ISR. */
#define BS_GPIO_ISR_ISR      (32U)         /*!< Bit field size in bits for GPIO_ISR_ISR. */

/*! @brief Read current value of the GPIO_ISR_ISR field. */
#define BR_GPIO_ISR_ISR(x)   (HW_GPIO_ISR(x).U)

/*! @brief Format value for bitfield GPIO_ISR_ISR. */
#define BF_GPIO_ISR_ISR(v)   ((uint32_t)((uint32_t)(v) << BP_GPIO_ISR_ISR) & BM_GPIO_ISR_ISR)

/*! @brief Set the ISR field to a new value. */
#define BW_GPIO_ISR_ISR(x, v) (HW_GPIO_ISR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPIO_EDGE_SEL - GPIO edge select register
 ******************************************************************************/

/*!
 * @brief HW_GPIO_EDGE_SEL - GPIO edge select register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPIO_EDGE_SEL may be used to override the ICR registers' configuration. If
 * the GPIO_EDGE_SEL bit is set, then a rising edge or falling edge in the
 * corresponding signal generates an interrupt. This register provides backward
 * compatibility. On reset all bits are cleared (ICR is not overridden).
 */
typedef union _hw_gpio_edge_sel
{
    uint32_t U;
    struct _hw_gpio_edge_sel_bitfields
    {
        uint32_t GPIO_EDGE_SEL : 32;   /*!< [31:0]  */
    } B;
} hw_gpio_edge_sel_t;

/*!
 * @name Constants and macros for entire GPIO_EDGE_SEL register
 */
/*@{*/
#define HW_GPIO_EDGE_SEL_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_GPIO_EDGE_SEL(x)      (*(__IO hw_gpio_edge_sel_t *) HW_GPIO_EDGE_SEL_ADDR(x))
#define HW_GPIO_EDGE_SEL_RD(x)   (HW_GPIO_EDGE_SEL(x).U)
#define HW_GPIO_EDGE_SEL_WR(x, v) (HW_GPIO_EDGE_SEL(x).U = (v))
#define HW_GPIO_EDGE_SEL_SET(x, v) (HW_GPIO_EDGE_SEL_WR(x, HW_GPIO_EDGE_SEL_RD(x) |  (v)))
#define HW_GPIO_EDGE_SEL_CLR(x, v) (HW_GPIO_EDGE_SEL_WR(x, HW_GPIO_EDGE_SEL_RD(x) & ~(v)))
#define HW_GPIO_EDGE_SEL_TOG(x, v) (HW_GPIO_EDGE_SEL_WR(x, HW_GPIO_EDGE_SEL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPIO_EDGE_SEL bitfields
 */

/*!
 * @name Register GPIO_EDGE_SEL, field GPIO_EDGE_SEL[31:0] (RW)
 *
 * Edge select. When GPIO_EDGE_SEL[n] is set, the GPIO disregards the ICR[n]
 * setting, and detects any edge on the corresponding input signal.
 */
/*@{*/
#define BP_GPIO_EDGE_SEL_GPIO_EDGE_SEL (0U) /*!< Bit position for GPIO_EDGE_SEL_GPIO_EDGE_SEL. */
#define BM_GPIO_EDGE_SEL_GPIO_EDGE_SEL (0xFFFFFFFFU) /*!< Bit mask for GPIO_EDGE_SEL_GPIO_EDGE_SEL. */
#define BS_GPIO_EDGE_SEL_GPIO_EDGE_SEL (32U) /*!< Bit field size in bits for GPIO_EDGE_SEL_GPIO_EDGE_SEL. */

/*! @brief Read current value of the GPIO_EDGE_SEL_GPIO_EDGE_SEL field. */
#define BR_GPIO_EDGE_SEL_GPIO_EDGE_SEL(x) (HW_GPIO_EDGE_SEL(x).U)

/*! @brief Format value for bitfield GPIO_EDGE_SEL_GPIO_EDGE_SEL. */
#define BF_GPIO_EDGE_SEL_GPIO_EDGE_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GPIO_EDGE_SEL_GPIO_EDGE_SEL) & BM_GPIO_EDGE_SEL_GPIO_EDGE_SEL)

/*! @brief Set the GPIO_EDGE_SEL field to a new value. */
#define BW_GPIO_EDGE_SEL_GPIO_EDGE_SEL(x, v) (HW_GPIO_EDGE_SEL_WR(x, v))
/*@}*/

/*******************************************************************************
 * hw_gpio_t - module struct
 ******************************************************************************/
/*!
 * @brief All GPIO module registers.
 */
#pragma pack(1)
typedef struct _hw_gpio
{
    __IO hw_gpio_dr_t DR;                  /*!< [0x0] GPIO data register */
    __IO hw_gpio_gdir_t GDIR;              /*!< [0x4] GPIO direction register */
    __I hw_gpio_psr_t PSR;                 /*!< [0x8] GPIO pad status register */
    __IO hw_gpio_icr1_t ICR1;              /*!< [0xC] GPIO interrupt configuration register1 */
    __IO hw_gpio_icr2_t ICR2;              /*!< [0x10] GPIO interrupt configuration register2 */
    __IO hw_gpio_imr_t IMR;                /*!< [0x14] GPIO interrupt mask register */
    __IO hw_gpio_isr_t ISR;                /*!< [0x18] GPIO interrupt status register */
    __IO hw_gpio_edge_sel_t EDGE_SEL;      /*!< [0x1C] GPIO edge select register */
} hw_gpio_t;
#pragma pack()

/*! @brief Macro to access all GPIO registers. */
/*! @param x GPIO module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_GPIO_REGS(GPIO1_BASE)</code>. */
#define HW_GPIO_REGS(x) (*(hw_gpio_t *)(x))

/*
 * iMX7D GPMI
 *
 * GPMI
 *
 * Registers defined in this header file:
 * - HW_GPMI_CTRL0 - GPMI Control Register 0 Description
 * - HW_GPMI_COMPARE - GPMI Compare Register Description
 * - HW_GPMI_ECCCTRL - GPMI Integrated ECC Control Register Description
 * - HW_GPMI_ECCCOUNT - GPMI Integrated ECC Transfer Count Register Description
 * - HW_GPMI_PAYLOAD - GPMI Payload Address Register Description
 * - HW_GPMI_AUXILIARY - GPMI Auxiliary Address Register Description
 * - HW_GPMI_CTRL1 - GPMI Control Register 1 Description
 * - HW_GPMI_TIMING0 - GPMI Timing Register 0 Description
 * - HW_GPMI_TIMING1 - GPMI Timing Register 1 Description
 * - HW_GPMI_TIMING2 - GPMI Timing Register 2 Description
 * - HW_GPMI_DATA - GPMI DMA Data Transfer Register Description
 * - HW_GPMI_STAT - GPMI Status Register Description
 * - HW_GPMI_DEBUG - GPMI Debug Information Register Description
 * - HW_GPMI_VERSION - GPMI Version Register Description
 * - HW_GPMI_DEBUG2 - GPMI Debug2 Information Register Description
 * - HW_GPMI_DEBUG3 - GPMI Debug3 Information Register Description
 * - HW_GPMI_READ_DDR_DLL_CTRL - GPMI Double Rate Read DLL Control Register Description
 * - HW_GPMI_WRITE_DDR_DLL_CTRL - GPMI Double Rate Write DLL Control Register Description
 * - HW_GPMI_READ_DDR_DLL_STS - GPMI Double Rate Read DLL Status Register Description
 * - HW_GPMI_WRITE_DDR_DLL_STS - GPMI Double Rate Write DLL Status Register Description
 *
 * - hw_gpmi_t - Struct containing all module registers.
 */

#define HW_GPMI_INSTANCE_COUNT (1U) /*!< Number of instances of the GPMI module. */
#define HW_GPMI (0U) /*!< Instance number for GPMI. */
#define GPMI_BASE             (0x33002000U) /*!< Base address for GPMI. */
/*! Array initializer of GPMI base addresses. */
#define GPMI_BASE_ADDRS       { GPMI_BASE }

/*******************************************************************************
 * HW_GPMI_CTRL0 - GPMI Control Register 0 Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_CTRL0 - GPMI Control Register 0 Description (RW)
 *
 * Reset value: 0xC0000000U
 *
 * The GPMI control register 0 specifies the GPMI transaction to perform for the
 * current command chain item.
 */
typedef union _hw_gpmi_ctrl0
{
    uint32_t U;
    struct _hw_gpmi_ctrl0_bitfields
    {
        uint32_t XFER_COUNT : 16;      /*!< [15:0]  */
        uint32_t ADDRESS_INCREMENT : 1; /*!< [16]  */
        uint32_t ADDRESS : 3;          /*!< [19:17]  */
        uint32_t CS : 3;               /*!< [22:20]  */
        uint32_t WORD_LENGTH : 1;      /*!< [23]  */
        uint32_t COMMAND_MODE : 2;     /*!< [25:24]  */
        uint32_t UDMA : 1;             /*!< [26]  */
        uint32_t LOCK_CS : 1;          /*!< [27]  */
        uint32_t DEV_IRQ_EN : 1;       /*!< [28]  */
        uint32_t RUN : 1;              /*!< [29]  */
        uint32_t CLKGATE : 1;          /*!< [30]  */
        uint32_t SFTRST : 1;           /*!< [31]  */
    } B;
} hw_gpmi_ctrl0_t;

/*!
 * @name Constants and macros for entire GPMI_CTRL0 register
 */
/*@{*/
#define HW_GPMI_CTRL0_ADDR(x)    ((uintptr_t)(x) + 0x0U)
#define HW_GPMI_CTRL0_SET_ADDR(x) (HW_GPMI_CTRL0_ADDR(x) + 0x4U)
#define HW_GPMI_CTRL0_CLR_ADDR(x) (HW_GPMI_CTRL0_ADDR(x) + 0x8U)
#define HW_GPMI_CTRL0_TOG_ADDR(x) (HW_GPMI_CTRL0_ADDR(x) + 0xCU)

#define HW_GPMI_CTRL0(x)         (*(__IO hw_gpmi_ctrl0_t *) HW_GPMI_CTRL0_ADDR(x))
#define HW_GPMI_CTRL0_RD(x)      (HW_GPMI_CTRL0(x).U)
#define HW_GPMI_CTRL0_WR(x, v)   (HW_GPMI_CTRL0(x).U = (v))
#define HW_GPMI_CTRL0_SET(x, v)  ((*(uint32_t *) HW_GPMI_CTRL0_SET_ADDR(x)) = (v))
#define HW_GPMI_CTRL0_CLR(x, v)  ((*(uint32_t *) HW_GPMI_CTRL0_CLR_ADDR(x)) = (v))
#define HW_GPMI_CTRL0_TOG(x, v)  ((*(uint32_t *) HW_GPMI_CTRL0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GPMI_CTRL0 bitfields
 */

/*!
 * @name Register GPMI_CTRL0, field XFER_COUNT[15:0] (RW)
 *
 * Number of bytes to transfer for this command. A value of zero will transfer
 * 64K bytes.
 */
/*@{*/
#define BP_GPMI_CTRL0_XFER_COUNT (0U)      /*!< Bit position for GPMI_CTRL0_XFER_COUNT. */
#define BM_GPMI_CTRL0_XFER_COUNT (0x0000FFFFU) /*!< Bit mask for GPMI_CTRL0_XFER_COUNT. */
#define BS_GPMI_CTRL0_XFER_COUNT (16U)     /*!< Bit field size in bits for GPMI_CTRL0_XFER_COUNT. */

/*! @brief Read current value of the GPMI_CTRL0_XFER_COUNT field. */
#define BR_GPMI_CTRL0_XFER_COUNT(x) (HW_GPMI_CTRL0(x).B.XFER_COUNT)

/*! @brief Format value for bitfield GPMI_CTRL0_XFER_COUNT. */
#define BF_GPMI_CTRL0_XFER_COUNT(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_XFER_COUNT) & BM_GPMI_CTRL0_XFER_COUNT)

/*! @brief Set the XFER_COUNT field to a new value. */
#define BW_GPMI_CTRL0_XFER_COUNT(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_XFER_COUNT) | BF_GPMI_CTRL0_XFER_COUNT(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field ADDRESS_INCREMENT[16] (RW)
 *
 * In ATA mode, the address will increment with each cycle. In NAND mode, the
 * address will increment once, after the first cycle (going from CLE to ALE).
 * DISABLED = 0x0 Address does not increment. ENABLED = 0x1 Increment address.
 *
 * Values:
 * - 0 - Address does not increment.
 * - 1 - Increment address.
 */
/*@{*/
#define BP_GPMI_CTRL0_ADDRESS_INCREMENT (16U) /*!< Bit position for GPMI_CTRL0_ADDRESS_INCREMENT. */
#define BM_GPMI_CTRL0_ADDRESS_INCREMENT (0x00010000U) /*!< Bit mask for GPMI_CTRL0_ADDRESS_INCREMENT. */
#define BS_GPMI_CTRL0_ADDRESS_INCREMENT (1U) /*!< Bit field size in bits for GPMI_CTRL0_ADDRESS_INCREMENT. */

/*! @brief Read current value of the GPMI_CTRL0_ADDRESS_INCREMENT field. */
#define BR_GPMI_CTRL0_ADDRESS_INCREMENT(x) (HW_GPMI_CTRL0(x).B.ADDRESS_INCREMENT)

/*! @brief Format value for bitfield GPMI_CTRL0_ADDRESS_INCREMENT. */
#define BF_GPMI_CTRL0_ADDRESS_INCREMENT(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_ADDRESS_INCREMENT) & BM_GPMI_CTRL0_ADDRESS_INCREMENT)

/*! @brief Set the ADDRESS_INCREMENT field to a new value. */
#define BW_GPMI_CTRL0_ADDRESS_INCREMENT(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_ADDRESS_INCREMENT) | BF_GPMI_CTRL0_ADDRESS_INCREMENT(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field ADDRESS[19:17] (RW)
 *
 * Specifies the three address lines for ATA mode. In NAND mode, use A0 for CLE
 * and A1 for ALE. NAND_DATA = 0x0 In NAND mode, this address is used to read and
 * write data bytes. NAND_CLE = 0x1 In NAND mode, this address is used to write
 * command bytes. NAND_ALE = 0x2 In NAND mode, this address is used to write
 * address bytes.
 */
/*@{*/
#define BP_GPMI_CTRL0_ADDRESS (17U)        /*!< Bit position for GPMI_CTRL0_ADDRESS. */
#define BM_GPMI_CTRL0_ADDRESS (0x000E0000U) /*!< Bit mask for GPMI_CTRL0_ADDRESS. */
#define BS_GPMI_CTRL0_ADDRESS (3U)         /*!< Bit field size in bits for GPMI_CTRL0_ADDRESS. */

/*! @brief Read current value of the GPMI_CTRL0_ADDRESS field. */
#define BR_GPMI_CTRL0_ADDRESS(x) (HW_GPMI_CTRL0(x).B.ADDRESS)

/*! @brief Format value for bitfield GPMI_CTRL0_ADDRESS. */
#define BF_GPMI_CTRL0_ADDRESS(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_ADDRESS) & BM_GPMI_CTRL0_ADDRESS)

/*! @brief Set the ADDRESS field to a new value. */
#define BW_GPMI_CTRL0_ADDRESS(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_ADDRESS) | BF_GPMI_CTRL0_ADDRESS(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field CS[22:20] (RW)
 *
 * Selects which chip select is active for this command. For ATA WAIT_FOR_READY
 * command, this must be set to b01.
 */
/*@{*/
#define BP_GPMI_CTRL0_CS     (20U)         /*!< Bit position for GPMI_CTRL0_CS. */
#define BM_GPMI_CTRL0_CS     (0x00700000U) /*!< Bit mask for GPMI_CTRL0_CS. */
#define BS_GPMI_CTRL0_CS     (3U)          /*!< Bit field size in bits for GPMI_CTRL0_CS. */

/*! @brief Read current value of the GPMI_CTRL0_CS field. */
#define BR_GPMI_CTRL0_CS(x)  (HW_GPMI_CTRL0(x).B.CS)

/*! @brief Format value for bitfield GPMI_CTRL0_CS. */
#define BF_GPMI_CTRL0_CS(v)  ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_CS) & BM_GPMI_CTRL0_CS)

/*! @brief Set the CS field to a new value. */
#define BW_GPMI_CTRL0_CS(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_CS) | BF_GPMI_CTRL0_CS(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field WORD_LENGTH[23] (RW)
 *
 * This bit should only be changed when RUN==0. Reserve = 0x0 Reserved. 8_BIT =
 * 0x1 8-bit Data Bus mode.
 *
 * Values:
 * - 0 - Reserved.
 * - 1 - 8-bit Data Bus mode.
 */
/*@{*/
#define BP_GPMI_CTRL0_WORD_LENGTH (23U)    /*!< Bit position for GPMI_CTRL0_WORD_LENGTH. */
#define BM_GPMI_CTRL0_WORD_LENGTH (0x00800000U) /*!< Bit mask for GPMI_CTRL0_WORD_LENGTH. */
#define BS_GPMI_CTRL0_WORD_LENGTH (1U)     /*!< Bit field size in bits for GPMI_CTRL0_WORD_LENGTH. */

/*! @brief Read current value of the GPMI_CTRL0_WORD_LENGTH field. */
#define BR_GPMI_CTRL0_WORD_LENGTH(x) (HW_GPMI_CTRL0(x).B.WORD_LENGTH)

/*! @brief Format value for bitfield GPMI_CTRL0_WORD_LENGTH. */
#define BF_GPMI_CTRL0_WORD_LENGTH(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_WORD_LENGTH) & BM_GPMI_CTRL0_WORD_LENGTH)

/*! @brief Set the WORD_LENGTH field to a new value. */
#define BW_GPMI_CTRL0_WORD_LENGTH(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_WORD_LENGTH) | BF_GPMI_CTRL0_WORD_LENGTH(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field COMMAND_MODE[25:24] (RW)
 *
 * WRITE = 0x0 Write mode. READ = 0x1 Read mode. READ_AND_COMPARE = 0x2 Read and
 * Compare mode (setting sense flop). WAIT_FOR_READY = 0x3 Wait for Ready mode.
 * For ATA WAIT_FOR_READY command set CS=01.
 *
 * Values:
 * - 00 - Write mode.
 * - 01 - Read Mode.
 * - 10 - Read and Compare Mode (setting sense flop).
 * - 11 - Wait for Ready.
 */
/*@{*/
#define BP_GPMI_CTRL0_COMMAND_MODE (24U)   /*!< Bit position for GPMI_CTRL0_COMMAND_MODE. */
#define BM_GPMI_CTRL0_COMMAND_MODE (0x03000000U) /*!< Bit mask for GPMI_CTRL0_COMMAND_MODE. */
#define BS_GPMI_CTRL0_COMMAND_MODE (2U)    /*!< Bit field size in bits for GPMI_CTRL0_COMMAND_MODE. */

/*! @brief Read current value of the GPMI_CTRL0_COMMAND_MODE field. */
#define BR_GPMI_CTRL0_COMMAND_MODE(x) (HW_GPMI_CTRL0(x).B.COMMAND_MODE)

/*! @brief Format value for bitfield GPMI_CTRL0_COMMAND_MODE. */
#define BF_GPMI_CTRL0_COMMAND_MODE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_COMMAND_MODE) & BM_GPMI_CTRL0_COMMAND_MODE)

/*! @brief Set the COMMAND_MODE field to a new value. */
#define BW_GPMI_CTRL0_COMMAND_MODE(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_COMMAND_MODE) | BF_GPMI_CTRL0_COMMAND_MODE(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field UDMA[26] (RW)
 *
 * DISABLED = 0x0 Use ATA-PIO mode on the external bus. ENABLED = 0x1 Use
 * ATA-Ultra DMA mode on the external bus.
 *
 * Values:
 * - 0 - Use ATA-PIO mode on the external bus.
 * - 1 - Use ATA-Ultra DMA mode on the external bus.
 */
/*@{*/
#define BP_GPMI_CTRL0_UDMA   (26U)         /*!< Bit position for GPMI_CTRL0_UDMA. */
#define BM_GPMI_CTRL0_UDMA   (0x04000000U) /*!< Bit mask for GPMI_CTRL0_UDMA. */
#define BS_GPMI_CTRL0_UDMA   (1U)          /*!< Bit field size in bits for GPMI_CTRL0_UDMA. */

/*! @brief Read current value of the GPMI_CTRL0_UDMA field. */
#define BR_GPMI_CTRL0_UDMA(x) (HW_GPMI_CTRL0(x).B.UDMA)

/*! @brief Format value for bitfield GPMI_CTRL0_UDMA. */
#define BF_GPMI_CTRL0_UDMA(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_UDMA) & BM_GPMI_CTRL0_UDMA)

/*! @brief Set the UDMA field to a new value. */
#define BW_GPMI_CTRL0_UDMA(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_UDMA) | BF_GPMI_CTRL0_UDMA(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field LOCK_CS[27] (RW)
 *
 * For ATA/NAND mode: 0= Deassert chip select (CS) after RUN is complete. 1=
 * Continue to assert chip select (CS) after RUN is complete. For Camera Mode: 0=
 * Dont wait for VSYNC rising edge before capturing data. 1= Wait for VSYNC rising
 * edge before capturing data (Camera mode only). DISABLED = 0x0 Deassert chip
 * select (CS) after RUN is complete. ENABLED = 0x1 Continue to assert chip select
 * (CS) after RUN is complete.
 */
/*@{*/
#define BP_GPMI_CTRL0_LOCK_CS (27U)        /*!< Bit position for GPMI_CTRL0_LOCK_CS. */
#define BM_GPMI_CTRL0_LOCK_CS (0x08000000U) /*!< Bit mask for GPMI_CTRL0_LOCK_CS. */
#define BS_GPMI_CTRL0_LOCK_CS (1U)         /*!< Bit field size in bits for GPMI_CTRL0_LOCK_CS. */

/*! @brief Read current value of the GPMI_CTRL0_LOCK_CS field. */
#define BR_GPMI_CTRL0_LOCK_CS(x) (HW_GPMI_CTRL0(x).B.LOCK_CS)

/*! @brief Format value for bitfield GPMI_CTRL0_LOCK_CS. */
#define BF_GPMI_CTRL0_LOCK_CS(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_LOCK_CS) & BM_GPMI_CTRL0_LOCK_CS)

/*! @brief Set the LOCK_CS field to a new value. */
#define BW_GPMI_CTRL0_LOCK_CS(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_LOCK_CS) | BF_GPMI_CTRL0_LOCK_CS(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field DEV_IRQ_EN[28] (RW)
 *
 * When set to '1' and ATA_IRQ pin is asserted, the GPMI_IRQ output will assert.
 */
/*@{*/
#define BP_GPMI_CTRL0_DEV_IRQ_EN (28U)     /*!< Bit position for GPMI_CTRL0_DEV_IRQ_EN. */
#define BM_GPMI_CTRL0_DEV_IRQ_EN (0x10000000U) /*!< Bit mask for GPMI_CTRL0_DEV_IRQ_EN. */
#define BS_GPMI_CTRL0_DEV_IRQ_EN (1U)      /*!< Bit field size in bits for GPMI_CTRL0_DEV_IRQ_EN. */

/*! @brief Read current value of the GPMI_CTRL0_DEV_IRQ_EN field. */
#define BR_GPMI_CTRL0_DEV_IRQ_EN(x) (HW_GPMI_CTRL0(x).B.DEV_IRQ_EN)

/*! @brief Format value for bitfield GPMI_CTRL0_DEV_IRQ_EN. */
#define BF_GPMI_CTRL0_DEV_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_DEV_IRQ_EN) & BM_GPMI_CTRL0_DEV_IRQ_EN)

/*! @brief Set the DEV_IRQ_EN field to a new value. */
#define BW_GPMI_CTRL0_DEV_IRQ_EN(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_DEV_IRQ_EN) | BF_GPMI_CTRL0_DEV_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field RUN[29] (RW)
 *
 * The GPMI is busy running a command whenever this bit is set to '1'. The GPMI
 * is idle whenever this bit set to zero. This can be set to one by a CPU write.
 * In addition, the DMA sets this bit each time a DMA command has finished its
 * PIO transfer phase. IDLE = 0x0 The GPMI is idle. BUSY = 0x1 The GPMI is busy
 * running a command.
 */
/*@{*/
#define BP_GPMI_CTRL0_RUN    (29U)         /*!< Bit position for GPMI_CTRL0_RUN. */
#define BM_GPMI_CTRL0_RUN    (0x20000000U) /*!< Bit mask for GPMI_CTRL0_RUN. */
#define BS_GPMI_CTRL0_RUN    (1U)          /*!< Bit field size in bits for GPMI_CTRL0_RUN. */

/*! @brief Read current value of the GPMI_CTRL0_RUN field. */
#define BR_GPMI_CTRL0_RUN(x) (HW_GPMI_CTRL0(x).B.RUN)

/*! @brief Format value for bitfield GPMI_CTRL0_RUN. */
#define BF_GPMI_CTRL0_RUN(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_RUN) & BM_GPMI_CTRL0_RUN)

/*! @brief Set the RUN field to a new value. */
#define BW_GPMI_CTRL0_RUN(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_RUN) | BF_GPMI_CTRL0_RUN(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field CLKGATE[30] (RW)
 *
 * Set this bit zero for normal operation. Setting this bit to one (default),
 * gates all of the block level clocks off for miniminizing AC energy consumption.
 * RUN = 0x0 Allow GPMI to operate normally. NO_CLKS = 0x1 Do not clock GPMI
 * gates in order to minimize power consumption.
 */
/*@{*/
#define BP_GPMI_CTRL0_CLKGATE (30U)        /*!< Bit position for GPMI_CTRL0_CLKGATE. */
#define BM_GPMI_CTRL0_CLKGATE (0x40000000U) /*!< Bit mask for GPMI_CTRL0_CLKGATE. */
#define BS_GPMI_CTRL0_CLKGATE (1U)         /*!< Bit field size in bits for GPMI_CTRL0_CLKGATE. */

/*! @brief Read current value of the GPMI_CTRL0_CLKGATE field. */
#define BR_GPMI_CTRL0_CLKGATE(x) (HW_GPMI_CTRL0(x).B.CLKGATE)

/*! @brief Format value for bitfield GPMI_CTRL0_CLKGATE. */
#define BF_GPMI_CTRL0_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_CLKGATE) & BM_GPMI_CTRL0_CLKGATE)

/*! @brief Set the CLKGATE field to a new value. */
#define BW_GPMI_CTRL0_CLKGATE(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_CLKGATE) | BF_GPMI_CTRL0_CLKGATE(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL0, field SFTRST[31] (RW)
 *
 * Set to zero for normal operation. When this bit is set to one (default), then
 * the entire block is held in its reset state. This will not work if the
 * CLKGATE bit is already set to '1'. CLKGATE must be cleared to '0' before issuing a
 * soft reset. Also the GPMICLK must be running for this to work properly. RUN =
 * 0x0 Allow GPMI to operate normally. RESET = 0x1 Hold GPMI in reset.
 */
/*@{*/
#define BP_GPMI_CTRL0_SFTRST (31U)         /*!< Bit position for GPMI_CTRL0_SFTRST. */
#define BM_GPMI_CTRL0_SFTRST (0x80000000U) /*!< Bit mask for GPMI_CTRL0_SFTRST. */
#define BS_GPMI_CTRL0_SFTRST (1U)          /*!< Bit field size in bits for GPMI_CTRL0_SFTRST. */

/*! @brief Read current value of the GPMI_CTRL0_SFTRST field. */
#define BR_GPMI_CTRL0_SFTRST(x) (HW_GPMI_CTRL0(x).B.SFTRST)

/*! @brief Format value for bitfield GPMI_CTRL0_SFTRST. */
#define BF_GPMI_CTRL0_SFTRST(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL0_SFTRST) & BM_GPMI_CTRL0_SFTRST)

/*! @brief Set the SFTRST field to a new value. */
#define BW_GPMI_CTRL0_SFTRST(x, v) (HW_GPMI_CTRL0_WR(x, (HW_GPMI_CTRL0_RD(x) & ~BM_GPMI_CTRL0_SFTRST) | BF_GPMI_CTRL0_SFTRST(v)))
/*@}*/




/*******************************************************************************
 * HW_GPMI_COMPARE - GPMI Compare Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_COMPARE - GPMI Compare Register Description (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPMI compare register specifies the expect data and the xor mask for
 * comparing to the status values read from the device. This register is used by the
 * Read and Compare command. GPMI_COMPARE 0x010
 */
typedef union _hw_gpmi_compare
{
    uint32_t U;
    struct _hw_gpmi_compare_bitfields
    {
        uint32_t REFERENCE : 16;       /*!< [15:0]  */
        uint32_t MASK : 16;            /*!< [31:16]  */
    } B;
} hw_gpmi_compare_t;

/*!
 * @name Constants and macros for entire GPMI_COMPARE register
 */
/*@{*/
#define HW_GPMI_COMPARE_ADDR(x)  ((uintptr_t)(x) + 0x10U)

#define HW_GPMI_COMPARE(x)       (*(__IO hw_gpmi_compare_t *) HW_GPMI_COMPARE_ADDR(x))
#define HW_GPMI_COMPARE_RD(x)    (HW_GPMI_COMPARE(x).U)
#define HW_GPMI_COMPARE_WR(x, v) (HW_GPMI_COMPARE(x).U = (v))
#define HW_GPMI_COMPARE_SET(x, v) (HW_GPMI_COMPARE_WR(x, HW_GPMI_COMPARE_RD(x) |  (v)))
#define HW_GPMI_COMPARE_CLR(x, v) (HW_GPMI_COMPARE_WR(x, HW_GPMI_COMPARE_RD(x) & ~(v)))
#define HW_GPMI_COMPARE_TOG(x, v) (HW_GPMI_COMPARE_WR(x, HW_GPMI_COMPARE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_COMPARE bitfields
 */

/*!
 * @name Register GPMI_COMPARE, field REFERENCE[15:0] (RW)
 *
 * 16-bit value which is XORed with data read from the NAND device.
 */
/*@{*/
#define BP_GPMI_COMPARE_REFERENCE (0U)     /*!< Bit position for GPMI_COMPARE_REFERENCE. */
#define BM_GPMI_COMPARE_REFERENCE (0x0000FFFFU) /*!< Bit mask for GPMI_COMPARE_REFERENCE. */
#define BS_GPMI_COMPARE_REFERENCE (16U)    /*!< Bit field size in bits for GPMI_COMPARE_REFERENCE. */

/*! @brief Read current value of the GPMI_COMPARE_REFERENCE field. */
#define BR_GPMI_COMPARE_REFERENCE(x) (HW_GPMI_COMPARE(x).B.REFERENCE)

/*! @brief Format value for bitfield GPMI_COMPARE_REFERENCE. */
#define BF_GPMI_COMPARE_REFERENCE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_COMPARE_REFERENCE) & BM_GPMI_COMPARE_REFERENCE)

/*! @brief Set the REFERENCE field to a new value. */
#define BW_GPMI_COMPARE_REFERENCE(x, v) (HW_GPMI_COMPARE_WR(x, (HW_GPMI_COMPARE_RD(x) & ~BM_GPMI_COMPARE_REFERENCE) | BF_GPMI_COMPARE_REFERENCE(v)))
/*@}*/

/*!
 * @name Register GPMI_COMPARE, field MASK[31:16] (RW)
 *
 * 16-bit mask which is applied after the read data is XORed with the REFERENCE
 * bit field.
 */
/*@{*/
#define BP_GPMI_COMPARE_MASK (16U)         /*!< Bit position for GPMI_COMPARE_MASK. */
#define BM_GPMI_COMPARE_MASK (0xFFFF0000U) /*!< Bit mask for GPMI_COMPARE_MASK. */
#define BS_GPMI_COMPARE_MASK (16U)         /*!< Bit field size in bits for GPMI_COMPARE_MASK. */

/*! @brief Read current value of the GPMI_COMPARE_MASK field. */
#define BR_GPMI_COMPARE_MASK(x) (HW_GPMI_COMPARE(x).B.MASK)

/*! @brief Format value for bitfield GPMI_COMPARE_MASK. */
#define BF_GPMI_COMPARE_MASK(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_COMPARE_MASK) & BM_GPMI_COMPARE_MASK)

/*! @brief Set the MASK field to a new value. */
#define BW_GPMI_COMPARE_MASK(x, v) (HW_GPMI_COMPARE_WR(x, (HW_GPMI_COMPARE_RD(x) & ~BM_GPMI_COMPARE_MASK) | BF_GPMI_COMPARE_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_GPMI_ECCCTRL - GPMI Integrated ECC Control Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_ECCCTRL - GPMI Integrated ECC Control Register Description (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPMI ECC control register handles configuration of the integrated ECC /
 * Randomizer accelerator.
 */
typedef union _hw_gpmi_eccctrl
{
    uint32_t U;
    struct _hw_gpmi_eccctrl_bitfields
    {
        uint32_t BUFFER_MASK : 9;      /*!< [8:0]  */
        uint32_t RANDOMIZER_TYPE : 2;  /*!< [10:9]  */
        uint32_t RANDOMIZER_ENABLE : 1; /*!< [11]  */
        uint32_t ENABLE_ECC : 1;       /*!< [12]  */
        uint32_t ECC_CMD : 2;          /*!< [14:13]  */
        uint32_t RSVD2 : 1;            /*!< [15]  */
        uint32_t HANDLE : 16;          /*!< [31:16]  */
    } B;
} hw_gpmi_eccctrl_t;

/*!
 * @name Constants and macros for entire GPMI_ECCCTRL register
 */
/*@{*/
#define HW_GPMI_ECCCTRL_ADDR(x)  ((uintptr_t)(x) + 0x20U)
#define HW_GPMI_ECCCTRL_SET_ADDR(x) (HW_GPMI_ECCCTRL_ADDR(x) + 0x4U)
#define HW_GPMI_ECCCTRL_CLR_ADDR(x) (HW_GPMI_ECCCTRL_ADDR(x) + 0x8U)
#define HW_GPMI_ECCCTRL_TOG_ADDR(x) (HW_GPMI_ECCCTRL_ADDR(x) + 0xCU)

#define HW_GPMI_ECCCTRL(x)       (*(__IO hw_gpmi_eccctrl_t *) HW_GPMI_ECCCTRL_ADDR(x))
#define HW_GPMI_ECCCTRL_RD(x)    (HW_GPMI_ECCCTRL(x).U)
#define HW_GPMI_ECCCTRL_WR(x, v) (HW_GPMI_ECCCTRL(x).U = (v))
#define HW_GPMI_ECCCTRL_SET(x, v) ((*(uint32_t *) HW_GPMI_ECCCTRL_SET_ADDR(x)) = (v))
#define HW_GPMI_ECCCTRL_CLR(x, v) ((*(uint32_t *) HW_GPMI_ECCCTRL_CLR_ADDR(x)) = (v))
#define HW_GPMI_ECCCTRL_TOG(x, v) ((*(uint32_t *) HW_GPMI_ECCCTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GPMI_ECCCTRL bitfields
 */

/*!
 * @name Register GPMI_ECCCTRL, field BUFFER_MASK[8:0] (RW)
 *
 * ECC buffer information. The BCH error correction only allows two
 * configurations of the buffer mask - software may either read just the first block on the
 * flash page or the entire flash page. Write operations must be for the entire
 * flash page. Invalid buffer mask values will cause the DMA descriptor command to
 * be terminated. BCH_AUXONLY = 0x100 Set to request transfer from only the
 * auxiliary buffer (block 0 on flash). BCH_PAGE = 0x1FF Set to request transfer
 * to/from the entire page.
 */
/*@{*/
#define BP_GPMI_ECCCTRL_BUFFER_MASK (0U)   /*!< Bit position for GPMI_ECCCTRL_BUFFER_MASK. */
#define BM_GPMI_ECCCTRL_BUFFER_MASK (0x000001FFU) /*!< Bit mask for GPMI_ECCCTRL_BUFFER_MASK. */
#define BS_GPMI_ECCCTRL_BUFFER_MASK (9U)   /*!< Bit field size in bits for GPMI_ECCCTRL_BUFFER_MASK. */

/*! @brief Read current value of the GPMI_ECCCTRL_BUFFER_MASK field. */
#define BR_GPMI_ECCCTRL_BUFFER_MASK(x) (HW_GPMI_ECCCTRL(x).B.BUFFER_MASK)

/*! @brief Format value for bitfield GPMI_ECCCTRL_BUFFER_MASK. */
#define BF_GPMI_ECCCTRL_BUFFER_MASK(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_ECCCTRL_BUFFER_MASK) & BM_GPMI_ECCCTRL_BUFFER_MASK)

/*! @brief Set the BUFFER_MASK field to a new value. */
#define BW_GPMI_ECCCTRL_BUFFER_MASK(x, v) (HW_GPMI_ECCCTRL_WR(x, (HW_GPMI_ECCCTRL_RD(x) & ~BM_GPMI_ECCCTRL_BUFFER_MASK) | BF_GPMI_ECCCTRL_BUFFER_MASK(v)))
/*@}*/

/*!
 * @name Register GPMI_ECCCTRL, field RANDOMIZER_TYPE[10:9] (RW)
 *
 * Set randomizer type
 *
 * Values:
 * - 0 - Type 0
 * - 1 - Type 1
 */
/*@{*/
#define BP_GPMI_ECCCTRL_RANDOMIZER_TYPE (9U) /*!< Bit position for GPMI_ECCCTRL_RANDOMIZER_TYPE. */
#define BM_GPMI_ECCCTRL_RANDOMIZER_TYPE (0x00000600U) /*!< Bit mask for GPMI_ECCCTRL_RANDOMIZER_TYPE. */
#define BS_GPMI_ECCCTRL_RANDOMIZER_TYPE (2U) /*!< Bit field size in bits for GPMI_ECCCTRL_RANDOMIZER_TYPE. */

/*! @brief Read current value of the GPMI_ECCCTRL_RANDOMIZER_TYPE field. */
#define BR_GPMI_ECCCTRL_RANDOMIZER_TYPE(x) (HW_GPMI_ECCCTRL(x).B.RANDOMIZER_TYPE)

/*! @brief Format value for bitfield GPMI_ECCCTRL_RANDOMIZER_TYPE. */
#define BF_GPMI_ECCCTRL_RANDOMIZER_TYPE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_ECCCTRL_RANDOMIZER_TYPE) & BM_GPMI_ECCCTRL_RANDOMIZER_TYPE)

/*! @brief Set the RANDOMIZER_TYPE field to a new value. */
#define BW_GPMI_ECCCTRL_RANDOMIZER_TYPE(x, v) (HW_GPMI_ECCCTRL_WR(x, (HW_GPMI_ECCCTRL_RD(x) & ~BM_GPMI_ECCCTRL_RANDOMIZER_TYPE) | BF_GPMI_ECCCTRL_RANDOMIZER_TYPE(v)))
/*@}*/

/*!
 * @name Register GPMI_ECCCTRL, field RANDOMIZER_ENABLE[11] (RW)
 *
 * Enable randomizer function. If this bit is set to enable, ENABLE_ECC should
 * be also enable.
 *
 * Values:
 * - 0 - disable
 * - 1 - enable
 */
/*@{*/
#define BP_GPMI_ECCCTRL_RANDOMIZER_ENABLE (11U) /*!< Bit position for GPMI_ECCCTRL_RANDOMIZER_ENABLE. */
#define BM_GPMI_ECCCTRL_RANDOMIZER_ENABLE (0x00000800U) /*!< Bit mask for GPMI_ECCCTRL_RANDOMIZER_ENABLE. */
#define BS_GPMI_ECCCTRL_RANDOMIZER_ENABLE (1U) /*!< Bit field size in bits for GPMI_ECCCTRL_RANDOMIZER_ENABLE. */

/*! @brief Read current value of the GPMI_ECCCTRL_RANDOMIZER_ENABLE field. */
#define BR_GPMI_ECCCTRL_RANDOMIZER_ENABLE(x) (HW_GPMI_ECCCTRL(x).B.RANDOMIZER_ENABLE)

/*! @brief Format value for bitfield GPMI_ECCCTRL_RANDOMIZER_ENABLE. */
#define BF_GPMI_ECCCTRL_RANDOMIZER_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_ECCCTRL_RANDOMIZER_ENABLE) & BM_GPMI_ECCCTRL_RANDOMIZER_ENABLE)

/*! @brief Set the RANDOMIZER_ENABLE field to a new value. */
#define BW_GPMI_ECCCTRL_RANDOMIZER_ENABLE(x, v) (HW_GPMI_ECCCTRL_WR(x, (HW_GPMI_ECCCTRL_RD(x) & ~BM_GPMI_ECCCTRL_RANDOMIZER_ENABLE) | BF_GPMI_ECCCTRL_RANDOMIZER_ENABLE(v)))
/*@}*/

/*!
 * @name Register GPMI_ECCCTRL, field ENABLE_ECC[12] (RW)
 *
 * Enable ECC processing of GPMI transfers. ENABLE = 0x1 Use integrated ECC for
 * read and write transfers. DISABLE = 0x0 Integrated ECC remains in idle.
 */
/*@{*/
#define BP_GPMI_ECCCTRL_ENABLE_ECC (12U)   /*!< Bit position for GPMI_ECCCTRL_ENABLE_ECC. */
#define BM_GPMI_ECCCTRL_ENABLE_ECC (0x00001000U) /*!< Bit mask for GPMI_ECCCTRL_ENABLE_ECC. */
#define BS_GPMI_ECCCTRL_ENABLE_ECC (1U)    /*!< Bit field size in bits for GPMI_ECCCTRL_ENABLE_ECC. */

/*! @brief Read current value of the GPMI_ECCCTRL_ENABLE_ECC field. */
#define BR_GPMI_ECCCTRL_ENABLE_ECC(x) (HW_GPMI_ECCCTRL(x).B.ENABLE_ECC)

/*! @brief Format value for bitfield GPMI_ECCCTRL_ENABLE_ECC. */
#define BF_GPMI_ECCCTRL_ENABLE_ECC(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_ECCCTRL_ENABLE_ECC) & BM_GPMI_ECCCTRL_ENABLE_ECC)

/*! @brief Set the ENABLE_ECC field to a new value. */
#define BW_GPMI_ECCCTRL_ENABLE_ECC(x, v) (HW_GPMI_ECCCTRL_WR(x, (HW_GPMI_ECCCTRL_RD(x) & ~BM_GPMI_ECCCTRL_ENABLE_ECC) | BF_GPMI_ECCCTRL_ENABLE_ECC(v)))
/*@}*/

/*!
 * @name Register GPMI_ECCCTRL, field ECC_CMD[14:13] (RW)
 *
 * ECC Command information. DECODE = 0x0 Decode. ENCODE = 0x1 Encode. RESERVE2 =
 * 0x2 Reserved. RESERVE3 = 0x3 Reserved.
 */
/*@{*/
#define BP_GPMI_ECCCTRL_ECC_CMD (13U)      /*!< Bit position for GPMI_ECCCTRL_ECC_CMD. */
#define BM_GPMI_ECCCTRL_ECC_CMD (0x00006000U) /*!< Bit mask for GPMI_ECCCTRL_ECC_CMD. */
#define BS_GPMI_ECCCTRL_ECC_CMD (2U)       /*!< Bit field size in bits for GPMI_ECCCTRL_ECC_CMD. */

/*! @brief Read current value of the GPMI_ECCCTRL_ECC_CMD field. */
#define BR_GPMI_ECCCTRL_ECC_CMD(x) (HW_GPMI_ECCCTRL(x).B.ECC_CMD)

/*! @brief Format value for bitfield GPMI_ECCCTRL_ECC_CMD. */
#define BF_GPMI_ECCCTRL_ECC_CMD(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_ECCCTRL_ECC_CMD) & BM_GPMI_ECCCTRL_ECC_CMD)

/*! @brief Set the ECC_CMD field to a new value. */
#define BW_GPMI_ECCCTRL_ECC_CMD(x, v) (HW_GPMI_ECCCTRL_WR(x, (HW_GPMI_ECCCTRL_RD(x) & ~BM_GPMI_ECCCTRL_ECC_CMD) | BF_GPMI_ECCCTRL_ECC_CMD(v)))
/*@}*/

/*!
 * @name Register GPMI_ECCCTRL, field RSVD2[15] (RW)
 *
 * Always write zeroes to this bit field.
 */
/*@{*/
#define BP_GPMI_ECCCTRL_RSVD2 (15U)        /*!< Bit position for GPMI_ECCCTRL_RSVD2. */
#define BM_GPMI_ECCCTRL_RSVD2 (0x00008000U) /*!< Bit mask for GPMI_ECCCTRL_RSVD2. */
#define BS_GPMI_ECCCTRL_RSVD2 (1U)         /*!< Bit field size in bits for GPMI_ECCCTRL_RSVD2. */

/*! @brief Read current value of the GPMI_ECCCTRL_RSVD2 field. */
#define BR_GPMI_ECCCTRL_RSVD2(x) (HW_GPMI_ECCCTRL(x).B.RSVD2)

/*! @brief Format value for bitfield GPMI_ECCCTRL_RSVD2. */
#define BF_GPMI_ECCCTRL_RSVD2(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_ECCCTRL_RSVD2) & BM_GPMI_ECCCTRL_RSVD2)

/*! @brief Set the RSVD2 field to a new value. */
#define BW_GPMI_ECCCTRL_RSVD2(x, v) (HW_GPMI_ECCCTRL_WR(x, (HW_GPMI_ECCCTRL_RD(x) & ~BM_GPMI_ECCCTRL_RSVD2) | BF_GPMI_ECCCTRL_RSVD2(v)))
/*@}*/

/*!
 * @name Register GPMI_ECCCTRL, field HANDLE[31:16] (RW)
 *
 * This is a register available to software to attach an identifier to a
 * transaction in progress. This handle will be available from the ECC register space
 * when the completion interrupt occurs.
 */
/*@{*/
#define BP_GPMI_ECCCTRL_HANDLE (16U)       /*!< Bit position for GPMI_ECCCTRL_HANDLE. */
#define BM_GPMI_ECCCTRL_HANDLE (0xFFFF0000U) /*!< Bit mask for GPMI_ECCCTRL_HANDLE. */
#define BS_GPMI_ECCCTRL_HANDLE (16U)       /*!< Bit field size in bits for GPMI_ECCCTRL_HANDLE. */

/*! @brief Read current value of the GPMI_ECCCTRL_HANDLE field. */
#define BR_GPMI_ECCCTRL_HANDLE(x) (HW_GPMI_ECCCTRL(x).B.HANDLE)

/*! @brief Format value for bitfield GPMI_ECCCTRL_HANDLE. */
#define BF_GPMI_ECCCTRL_HANDLE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_ECCCTRL_HANDLE) & BM_GPMI_ECCCTRL_HANDLE)

/*! @brief Set the HANDLE field to a new value. */
#define BW_GPMI_ECCCTRL_HANDLE(x, v) (HW_GPMI_ECCCTRL_WR(x, (HW_GPMI_ECCCTRL_RD(x) & ~BM_GPMI_ECCCTRL_HANDLE) | BF_GPMI_ECCCTRL_HANDLE(v)))
/*@}*/




/*******************************************************************************
 * HW_GPMI_ECCCOUNT - GPMI Integrated ECC Transfer Count Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_ECCCOUNT - GPMI Integrated ECC Transfer Count Register Description (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPMI ECC Transfer Count Register contains the count of bytes that flow
 * through the ECC / Randomizer sub­system. GPMI_ECCCOUNT 0x030
 */
typedef union _hw_gpmi_ecccount
{
    uint32_t U;
    struct _hw_gpmi_ecccount_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0]  */
        uint32_t RANDOMIZER_PAGE : 8;  /*!< [23:16]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_gpmi_ecccount_t;

/*!
 * @name Constants and macros for entire GPMI_ECCCOUNT register
 */
/*@{*/
#define HW_GPMI_ECCCOUNT_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_GPMI_ECCCOUNT(x)      (*(__IO hw_gpmi_ecccount_t *) HW_GPMI_ECCCOUNT_ADDR(x))
#define HW_GPMI_ECCCOUNT_RD(x)   (HW_GPMI_ECCCOUNT(x).U)
#define HW_GPMI_ECCCOUNT_WR(x, v) (HW_GPMI_ECCCOUNT(x).U = (v))
#define HW_GPMI_ECCCOUNT_SET(x, v) (HW_GPMI_ECCCOUNT_WR(x, HW_GPMI_ECCCOUNT_RD(x) |  (v)))
#define HW_GPMI_ECCCOUNT_CLR(x, v) (HW_GPMI_ECCCOUNT_WR(x, HW_GPMI_ECCCOUNT_RD(x) & ~(v)))
#define HW_GPMI_ECCCOUNT_TOG(x, v) (HW_GPMI_ECCCOUNT_WR(x, HW_GPMI_ECCCOUNT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_ECCCOUNT bitfields
 */

/*!
 * @name Register GPMI_ECCCOUNT, field COUNT[15:0] (RW)
 *
 * Number of bytes to pass through ECC. This is the GPMI transfer count plus the
 * syndrome count that will be inserted into the stream by the ECC. In
 * DMA2ECC_MODE this count must match the GPMI_CTRL0_XFER_COUNT. A value of zero will
 * transfer 64K words.
 */
/*@{*/
#define BP_GPMI_ECCCOUNT_COUNT (0U)        /*!< Bit position for GPMI_ECCCOUNT_COUNT. */
#define BM_GPMI_ECCCOUNT_COUNT (0x0000FFFFU) /*!< Bit mask for GPMI_ECCCOUNT_COUNT. */
#define BS_GPMI_ECCCOUNT_COUNT (16U)       /*!< Bit field size in bits for GPMI_ECCCOUNT_COUNT. */

/*! @brief Read current value of the GPMI_ECCCOUNT_COUNT field. */
#define BR_GPMI_ECCCOUNT_COUNT(x) (HW_GPMI_ECCCOUNT(x).B.COUNT)

/*! @brief Format value for bitfield GPMI_ECCCOUNT_COUNT. */
#define BF_GPMI_ECCCOUNT_COUNT(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_ECCCOUNT_COUNT) & BM_GPMI_ECCCOUNT_COUNT)

/*! @brief Set the COUNT field to a new value. */
#define BW_GPMI_ECCCOUNT_COUNT(x, v) (HW_GPMI_ECCCOUNT_WR(x, (HW_GPMI_ECCCOUNT_RD(x) & ~BM_GPMI_ECCCOUNT_COUNT) | BF_GPMI_ECCCOUNT_COUNT(v)))
/*@}*/

/*!
 * @name Register GPMI_ECCCOUNT, field RANDOMIZER_PAGE[23:16] (RW)
 *
 * Set NAND page number needed to be randomized. The value is between 0-255
 */
/*@{*/
#define BP_GPMI_ECCCOUNT_RANDOMIZER_PAGE (16U) /*!< Bit position for GPMI_ECCCOUNT_RANDOMIZER_PAGE. */
#define BM_GPMI_ECCCOUNT_RANDOMIZER_PAGE (0x00FF0000U) /*!< Bit mask for GPMI_ECCCOUNT_RANDOMIZER_PAGE. */
#define BS_GPMI_ECCCOUNT_RANDOMIZER_PAGE (8U) /*!< Bit field size in bits for GPMI_ECCCOUNT_RANDOMIZER_PAGE. */

/*! @brief Read current value of the GPMI_ECCCOUNT_RANDOMIZER_PAGE field. */
#define BR_GPMI_ECCCOUNT_RANDOMIZER_PAGE(x) (HW_GPMI_ECCCOUNT(x).B.RANDOMIZER_PAGE)

/*! @brief Format value for bitfield GPMI_ECCCOUNT_RANDOMIZER_PAGE. */
#define BF_GPMI_ECCCOUNT_RANDOMIZER_PAGE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_ECCCOUNT_RANDOMIZER_PAGE) & BM_GPMI_ECCCOUNT_RANDOMIZER_PAGE)

/*! @brief Set the RANDOMIZER_PAGE field to a new value. */
#define BW_GPMI_ECCCOUNT_RANDOMIZER_PAGE(x, v) (HW_GPMI_ECCCOUNT_WR(x, (HW_GPMI_ECCCOUNT_RD(x) & ~BM_GPMI_ECCCOUNT_RANDOMIZER_PAGE) | BF_GPMI_ECCCOUNT_RANDOMIZER_PAGE(v)))
/*@}*/

/*******************************************************************************
 * HW_GPMI_PAYLOAD - GPMI Payload Address Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_PAYLOAD - GPMI Payload Address Register Description (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPMI payload address register specifies the location of the data buffers
 * in system memory. This value must be word aligned. GPMI_PAYLOAD 0x040
 */
typedef union _hw_gpmi_payload
{
    uint32_t U;
    struct _hw_gpmi_payload_bitfields
    {
        uint32_t RSVD0 : 2;            /*!< [1:0]  */
        uint32_t ADDRESS : 30;         /*!< [31:2]  */
    } B;
} hw_gpmi_payload_t;

/*!
 * @name Constants and macros for entire GPMI_PAYLOAD register
 */
/*@{*/
#define HW_GPMI_PAYLOAD_ADDR(x)  ((uintptr_t)(x) + 0x40U)

#define HW_GPMI_PAYLOAD(x)       (*(__IO hw_gpmi_payload_t *) HW_GPMI_PAYLOAD_ADDR(x))
#define HW_GPMI_PAYLOAD_RD(x)    (HW_GPMI_PAYLOAD(x).U)
#define HW_GPMI_PAYLOAD_WR(x, v) (HW_GPMI_PAYLOAD(x).U = (v))
#define HW_GPMI_PAYLOAD_SET(x, v) (HW_GPMI_PAYLOAD_WR(x, HW_GPMI_PAYLOAD_RD(x) |  (v)))
#define HW_GPMI_PAYLOAD_CLR(x, v) (HW_GPMI_PAYLOAD_WR(x, HW_GPMI_PAYLOAD_RD(x) & ~(v)))
#define HW_GPMI_PAYLOAD_TOG(x, v) (HW_GPMI_PAYLOAD_WR(x, HW_GPMI_PAYLOAD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_PAYLOAD bitfields
 */

/*!
 * @name Register GPMI_PAYLOAD, field RSVD0[1:0] (RO)
 *
 * Always write zeroes to this bit field.
 */
/*@{*/
#define BP_GPMI_PAYLOAD_RSVD0 (0U)         /*!< Bit position for GPMI_PAYLOAD_RSVD0. */
#define BM_GPMI_PAYLOAD_RSVD0 (0x00000003U) /*!< Bit mask for GPMI_PAYLOAD_RSVD0. */
#define BS_GPMI_PAYLOAD_RSVD0 (2U)         /*!< Bit field size in bits for GPMI_PAYLOAD_RSVD0. */

/*! @brief Read current value of the GPMI_PAYLOAD_RSVD0 field. */
#define BR_GPMI_PAYLOAD_RSVD0(x) (HW_GPMI_PAYLOAD(x).B.RSVD0)
/*@}*/

/*!
 * @name Register GPMI_PAYLOAD, field ADDRESS[31:2] (RW)
 *
 * Pointer to an array of one or more 512 byte payload buffers.
 */
/*@{*/
#define BP_GPMI_PAYLOAD_ADDRESS (2U)       /*!< Bit position for GPMI_PAYLOAD_ADDRESS. */
#define BM_GPMI_PAYLOAD_ADDRESS (0xFFFFFFFCU) /*!< Bit mask for GPMI_PAYLOAD_ADDRESS. */
#define BS_GPMI_PAYLOAD_ADDRESS (30U)      /*!< Bit field size in bits for GPMI_PAYLOAD_ADDRESS. */

/*! @brief Read current value of the GPMI_PAYLOAD_ADDRESS field. */
#define BR_GPMI_PAYLOAD_ADDRESS(x) (HW_GPMI_PAYLOAD(x).B.ADDRESS)

/*! @brief Format value for bitfield GPMI_PAYLOAD_ADDRESS. */
#define BF_GPMI_PAYLOAD_ADDRESS(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_PAYLOAD_ADDRESS) & BM_GPMI_PAYLOAD_ADDRESS)

/*! @brief Set the ADDRESS field to a new value. */
#define BW_GPMI_PAYLOAD_ADDRESS(x, v) (HW_GPMI_PAYLOAD_WR(x, (HW_GPMI_PAYLOAD_RD(x) & ~BM_GPMI_PAYLOAD_ADDRESS) | BF_GPMI_PAYLOAD_ADDRESS(v)))
/*@}*/

/*******************************************************************************
 * HW_GPMI_AUXILIARY - GPMI Auxiliary Address Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_AUXILIARY - GPMI Auxiliary Address Register Description (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPMI auxiliary address register specifies the location of the auxiliary
 * buffers in system memory. This value must be word aligned. GPMI_AUXILIARY 0x050
 */
typedef union _hw_gpmi_auxiliary
{
    uint32_t U;
    struct _hw_gpmi_auxiliary_bitfields
    {
        uint32_t RSVD0 : 2;            /*!< [1:0]  */
        uint32_t ADDRESS : 30;         /*!< [31:2]  */
    } B;
} hw_gpmi_auxiliary_t;

/*!
 * @name Constants and macros for entire GPMI_AUXILIARY register
 */
/*@{*/
#define HW_GPMI_AUXILIARY_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_GPMI_AUXILIARY(x)     (*(__IO hw_gpmi_auxiliary_t *) HW_GPMI_AUXILIARY_ADDR(x))
#define HW_GPMI_AUXILIARY_RD(x)  (HW_GPMI_AUXILIARY(x).U)
#define HW_GPMI_AUXILIARY_WR(x, v) (HW_GPMI_AUXILIARY(x).U = (v))
#define HW_GPMI_AUXILIARY_SET(x, v) (HW_GPMI_AUXILIARY_WR(x, HW_GPMI_AUXILIARY_RD(x) |  (v)))
#define HW_GPMI_AUXILIARY_CLR(x, v) (HW_GPMI_AUXILIARY_WR(x, HW_GPMI_AUXILIARY_RD(x) & ~(v)))
#define HW_GPMI_AUXILIARY_TOG(x, v) (HW_GPMI_AUXILIARY_WR(x, HW_GPMI_AUXILIARY_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_AUXILIARY bitfields
 */

/*!
 * @name Register GPMI_AUXILIARY, field RSVD0[1:0] (RO)
 *
 * Always write zeroes to this bit field.
 */
/*@{*/
#define BP_GPMI_AUXILIARY_RSVD0 (0U)       /*!< Bit position for GPMI_AUXILIARY_RSVD0. */
#define BM_GPMI_AUXILIARY_RSVD0 (0x00000003U) /*!< Bit mask for GPMI_AUXILIARY_RSVD0. */
#define BS_GPMI_AUXILIARY_RSVD0 (2U)       /*!< Bit field size in bits for GPMI_AUXILIARY_RSVD0. */

/*! @brief Read current value of the GPMI_AUXILIARY_RSVD0 field. */
#define BR_GPMI_AUXILIARY_RSVD0(x) (HW_GPMI_AUXILIARY(x).B.RSVD0)
/*@}*/

/*!
 * @name Register GPMI_AUXILIARY, field ADDRESS[31:2] (RW)
 *
 * Pointer to ECC control structure and meta-data storage.
 */
/*@{*/
#define BP_GPMI_AUXILIARY_ADDRESS (2U)     /*!< Bit position for GPMI_AUXILIARY_ADDRESS. */
#define BM_GPMI_AUXILIARY_ADDRESS (0xFFFFFFFCU) /*!< Bit mask for GPMI_AUXILIARY_ADDRESS. */
#define BS_GPMI_AUXILIARY_ADDRESS (30U)    /*!< Bit field size in bits for GPMI_AUXILIARY_ADDRESS. */

/*! @brief Read current value of the GPMI_AUXILIARY_ADDRESS field. */
#define BR_GPMI_AUXILIARY_ADDRESS(x) (HW_GPMI_AUXILIARY(x).B.ADDRESS)

/*! @brief Format value for bitfield GPMI_AUXILIARY_ADDRESS. */
#define BF_GPMI_AUXILIARY_ADDRESS(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_AUXILIARY_ADDRESS) & BM_GPMI_AUXILIARY_ADDRESS)

/*! @brief Set the ADDRESS field to a new value. */
#define BW_GPMI_AUXILIARY_ADDRESS(x, v) (HW_GPMI_AUXILIARY_WR(x, (HW_GPMI_AUXILIARY_RD(x) & ~BM_GPMI_AUXILIARY_ADDRESS) | BF_GPMI_AUXILIARY_ADDRESS(v)))
/*@}*/

/*******************************************************************************
 * HW_GPMI_CTRL1 - GPMI Control Register 1 Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_CTRL1 - GPMI Control Register 1 Description (RW)
 *
 * Reset value: 0x00040004U
 *
 * The GPMI control register 1 specifies additional control fields that are not
 * used on a per-transaction basis.
 */
typedef union _hw_gpmi_ctrl1
{
    uint32_t U;
    struct _hw_gpmi_ctrl1_bitfields
    {
        uint32_t GPMI_MODE : 1;        /*!< [0]  */
        uint32_t CAMERA_MODE : 1;      /*!< [1]  */
        uint32_t ATA_IRQRDY_POLARITY : 1; /*!< [2]  */
        uint32_t DEV_RESET : 1;        /*!< [3]  */
        uint32_t ABORT_WAIT_FOR_READY_CHANNEL : 3; /*!< [6:4]  */
        uint32_t ABORT_WAIT_REQUEST : 1; /*!< [7]  */
        uint32_t BURST_EN : 1;         /*!< [8]  */
        uint32_t TIMEOUT_IRQ : 1;      /*!< [9]  */
        uint32_t DEV_IRQ : 1;          /*!< [10]  */
        uint32_t DMA2ECC_MODE : 1;     /*!< [11]  */
        uint32_t RDN_DELAY : 4;        /*!< [15:12]  */
        uint32_t HALF_PERIOD : 1;      /*!< [16]  */
        uint32_t DLL_ENABLE : 1;       /*!< [17]  */
        uint32_t BCH_MODEb : 1;        /*!< [18]  */
        uint32_t GANGED_RDYBUSY : 1;   /*!< [19]  */
        uint32_t TIMEOUT_IRQ_EN : 1;   /*!< [20]  */
        uint32_t TEST_TRIGGER : 1;     /*!< [21]  */
        uint32_t WRN_DLY_SEL : 2;      /*!< [23:22]  */
        uint32_t DECOUPLE_CS : 1;      /*!< [24]  */
        uint32_t SSYNCMODE : 1;        /*!< [25]  */
        uint32_t UPDATE_CS : 1;        /*!< [26]  */
        uint32_t GPMI_CLK_DIV2_EN : 1; /*!< [27]  */
        uint32_t TOGGLE_MODE : 1;      /*!< [28]  */
        uint32_t WRITE_CLK_STOP : 1;   /*!< [29]  */
        uint32_t SSYNC_CLK_STOP : 1;   /*!< [30]  */
        uint32_t DEV_CLK_STOP : 1;     /*!< [31]  */
    } B;
} hw_gpmi_ctrl1_t;

/*!
 * @name Constants and macros for entire GPMI_CTRL1 register
 */
/*@{*/
#define HW_GPMI_CTRL1_ADDR(x)    ((uintptr_t)(x) + 0x60U)
#define HW_GPMI_CTRL1_SET_ADDR(x) (HW_GPMI_CTRL1_ADDR(x) + 0x4U)
#define HW_GPMI_CTRL1_CLR_ADDR(x) (HW_GPMI_CTRL1_ADDR(x) + 0x8U)
#define HW_GPMI_CTRL1_TOG_ADDR(x) (HW_GPMI_CTRL1_ADDR(x) + 0xCU)

#define HW_GPMI_CTRL1(x)         (*(__IO hw_gpmi_ctrl1_t *) HW_GPMI_CTRL1_ADDR(x))
#define HW_GPMI_CTRL1_RD(x)      (HW_GPMI_CTRL1(x).U)
#define HW_GPMI_CTRL1_WR(x, v)   (HW_GPMI_CTRL1(x).U = (v))
#define HW_GPMI_CTRL1_SET(x, v)  ((*(uint32_t *) HW_GPMI_CTRL1_SET_ADDR(x)) = (v))
#define HW_GPMI_CTRL1_CLR(x, v)  ((*(uint32_t *) HW_GPMI_CTRL1_CLR_ADDR(x)) = (v))
#define HW_GPMI_CTRL1_TOG(x, v)  ((*(uint32_t *) HW_GPMI_CTRL1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual GPMI_CTRL1 bitfields
 */

/*!
 * @name Register GPMI_CTRL1, field GPMI_MODE[0] (RW)
 *
 * ATA mode is only supported on channel zero. If ATA mode is selected, then
 * only channel three is available for NAND use. NAND = 0x0 NAND mode. ATA = 0x1 ATA
 * mode.
 *
 * Values:
 * - 0 - NAND mode.
 * - 1 - ATA mode.
 */
/*@{*/
#define BP_GPMI_CTRL1_GPMI_MODE (0U)       /*!< Bit position for GPMI_CTRL1_GPMI_MODE. */
#define BM_GPMI_CTRL1_GPMI_MODE (0x00000001U) /*!< Bit mask for GPMI_CTRL1_GPMI_MODE. */
#define BS_GPMI_CTRL1_GPMI_MODE (1U)       /*!< Bit field size in bits for GPMI_CTRL1_GPMI_MODE. */

/*! @brief Read current value of the GPMI_CTRL1_GPMI_MODE field. */
#define BR_GPMI_CTRL1_GPMI_MODE(x) (HW_GPMI_CTRL1(x).B.GPMI_MODE)

/*! @brief Format value for bitfield GPMI_CTRL1_GPMI_MODE. */
#define BF_GPMI_CTRL1_GPMI_MODE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_GPMI_MODE) & BM_GPMI_CTRL1_GPMI_MODE)

/*! @brief Set the GPMI_MODE field to a new value. */
#define BW_GPMI_CTRL1_GPMI_MODE(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_GPMI_MODE) | BF_GPMI_CTRL1_GPMI_MODE(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field CAMERA_MODE[1] (RW)
 *
 * When set to 1 and ATA UDMA is enabled the UDMA interface becomes a camera
 * interface.
 */
/*@{*/
#define BP_GPMI_CTRL1_CAMERA_MODE (1U)     /*!< Bit position for GPMI_CTRL1_CAMERA_MODE. */
#define BM_GPMI_CTRL1_CAMERA_MODE (0x00000002U) /*!< Bit mask for GPMI_CTRL1_CAMERA_MODE. */
#define BS_GPMI_CTRL1_CAMERA_MODE (1U)     /*!< Bit field size in bits for GPMI_CTRL1_CAMERA_MODE. */

/*! @brief Read current value of the GPMI_CTRL1_CAMERA_MODE field. */
#define BR_GPMI_CTRL1_CAMERA_MODE(x) (HW_GPMI_CTRL1(x).B.CAMERA_MODE)

/*! @brief Format value for bitfield GPMI_CTRL1_CAMERA_MODE. */
#define BF_GPMI_CTRL1_CAMERA_MODE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_CAMERA_MODE) & BM_GPMI_CTRL1_CAMERA_MODE)

/*! @brief Set the CAMERA_MODE field to a new value. */
#define BW_GPMI_CTRL1_CAMERA_MODE(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_CAMERA_MODE) | BF_GPMI_CTRL1_CAMERA_MODE(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field ATA_IRQRDY_POLARITY[2] (RW)
 *
 * For ATA MODE: Note NAND_RDY_BUSY[3:2] are not affected by this bit. ACTIVELOW
 * = 0x0 ATA IORDY and IRQ are active low, or NAND_RDY_BUSY[1:0] are active low
 * ready. ACTIVEHIGH = 0x1 ATA IORDY and IRQ are active high, or
 * NAND_RDY_BUSY[1:0] are active high ready. 0 External ATA IORDY and IRQ are active low. 1
 * External ATA IORDY and IRQ are active high. For NAND MODE:
 *
 * Values:
 * - 0 - External RDY_BUSY[1] and RDY_BUSY[0] pins are ready when low and busy
 *     when high.
 * - 1 - External RDY_BUSY[1] and RDY_BUSY[0] pins are ready when high and busy
 *     when low.
 */
/*@{*/
#define BP_GPMI_CTRL1_ATA_IRQRDY_POLARITY (2U) /*!< Bit position for GPMI_CTRL1_ATA_IRQRDY_POLARITY. */
#define BM_GPMI_CTRL1_ATA_IRQRDY_POLARITY (0x00000004U) /*!< Bit mask for GPMI_CTRL1_ATA_IRQRDY_POLARITY. */
#define BS_GPMI_CTRL1_ATA_IRQRDY_POLARITY (1U) /*!< Bit field size in bits for GPMI_CTRL1_ATA_IRQRDY_POLARITY. */

/*! @brief Read current value of the GPMI_CTRL1_ATA_IRQRDY_POLARITY field. */
#define BR_GPMI_CTRL1_ATA_IRQRDY_POLARITY(x) (HW_GPMI_CTRL1(x).B.ATA_IRQRDY_POLARITY)

/*! @brief Format value for bitfield GPMI_CTRL1_ATA_IRQRDY_POLARITY. */
#define BF_GPMI_CTRL1_ATA_IRQRDY_POLARITY(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_ATA_IRQRDY_POLARITY) & BM_GPMI_CTRL1_ATA_IRQRDY_POLARITY)

/*! @brief Set the ATA_IRQRDY_POLARITY field to a new value. */
#define BW_GPMI_CTRL1_ATA_IRQRDY_POLARITY(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_ATA_IRQRDY_POLARITY) | BF_GPMI_CTRL1_ATA_IRQRDY_POLARITY(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field DEV_RESET[3] (RW)
 *
 * ENABLED = 0x0 NANDF_WP_B(WPN) pin is held low (asserted). DISABLED = 0x1
 * NANDF_WP_B(WPN) pin is held high (de-asserted).
 *
 * Values:
 * - 0 - NANDF_WP_B pin is held low (asserted).
 * - 1 - NANDF_WP_B pin is held high (de-asserted).
 */
/*@{*/
#define BP_GPMI_CTRL1_DEV_RESET (3U)       /*!< Bit position for GPMI_CTRL1_DEV_RESET. */
#define BM_GPMI_CTRL1_DEV_RESET (0x00000008U) /*!< Bit mask for GPMI_CTRL1_DEV_RESET. */
#define BS_GPMI_CTRL1_DEV_RESET (1U)       /*!< Bit field size in bits for GPMI_CTRL1_DEV_RESET. */

/*! @brief Read current value of the GPMI_CTRL1_DEV_RESET field. */
#define BR_GPMI_CTRL1_DEV_RESET(x) (HW_GPMI_CTRL1(x).B.DEV_RESET)

/*! @brief Format value for bitfield GPMI_CTRL1_DEV_RESET. */
#define BF_GPMI_CTRL1_DEV_RESET(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_DEV_RESET) & BM_GPMI_CTRL1_DEV_RESET)

/*! @brief Set the DEV_RESET field to a new value. */
#define BW_GPMI_CTRL1_DEV_RESET(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_DEV_RESET) | BF_GPMI_CTRL1_DEV_RESET(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field ABORT_WAIT_FOR_READY_CHANNEL[6:4] (RW)
 *
 * Abort a wait for ready command on selected channel. Set the
 * ABORT_WAIT_REQUEST to kick of operation.
 */
/*@{*/
#define BP_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL (4U) /*!< Bit position for GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL. */
#define BM_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL (0x00000070U) /*!< Bit mask for GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL. */
#define BS_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL (3U) /*!< Bit field size in bits for GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL. */

/*! @brief Read current value of the GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL field. */
#define BR_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL(x) (HW_GPMI_CTRL1(x).B.ABORT_WAIT_FOR_READY_CHANNEL)

/*! @brief Format value for bitfield GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL. */
#define BF_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL) & BM_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL)

/*! @brief Set the ABORT_WAIT_FOR_READY_CHANNEL field to a new value. */
#define BW_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL) | BF_GPMI_CTRL1_ABORT_WAIT_FOR_READY_CHANNEL(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field ABORT_WAIT_REQUEST[7] (RW)
 *
 * Request to abort "wait for ready" command on channel indicated by
 * ABORT_WAIT_FOR_READY_CHANNEL. Hardware will clear this bit when abort is done.
 */
/*@{*/
#define BP_GPMI_CTRL1_ABORT_WAIT_REQUEST (7U) /*!< Bit position for GPMI_CTRL1_ABORT_WAIT_REQUEST. */
#define BM_GPMI_CTRL1_ABORT_WAIT_REQUEST (0x00000080U) /*!< Bit mask for GPMI_CTRL1_ABORT_WAIT_REQUEST. */
#define BS_GPMI_CTRL1_ABORT_WAIT_REQUEST (1U) /*!< Bit field size in bits for GPMI_CTRL1_ABORT_WAIT_REQUEST. */

/*! @brief Read current value of the GPMI_CTRL1_ABORT_WAIT_REQUEST field. */
#define BR_GPMI_CTRL1_ABORT_WAIT_REQUEST(x) (HW_GPMI_CTRL1(x).B.ABORT_WAIT_REQUEST)

/*! @brief Format value for bitfield GPMI_CTRL1_ABORT_WAIT_REQUEST. */
#define BF_GPMI_CTRL1_ABORT_WAIT_REQUEST(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_ABORT_WAIT_REQUEST) & BM_GPMI_CTRL1_ABORT_WAIT_REQUEST)

/*! @brief Set the ABORT_WAIT_REQUEST field to a new value. */
#define BW_GPMI_CTRL1_ABORT_WAIT_REQUEST(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_ABORT_WAIT_REQUEST) | BF_GPMI_CTRL1_ABORT_WAIT_REQUEST(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field BURST_EN[8] (RW)
 *
 * When set to 1 each DMA request will generate a 4-transfer burst on the APB
 * bus.
 */
/*@{*/
#define BP_GPMI_CTRL1_BURST_EN (8U)        /*!< Bit position for GPMI_CTRL1_BURST_EN. */
#define BM_GPMI_CTRL1_BURST_EN (0x00000100U) /*!< Bit mask for GPMI_CTRL1_BURST_EN. */
#define BS_GPMI_CTRL1_BURST_EN (1U)        /*!< Bit field size in bits for GPMI_CTRL1_BURST_EN. */

/*! @brief Read current value of the GPMI_CTRL1_BURST_EN field. */
#define BR_GPMI_CTRL1_BURST_EN(x) (HW_GPMI_CTRL1(x).B.BURST_EN)

/*! @brief Format value for bitfield GPMI_CTRL1_BURST_EN. */
#define BF_GPMI_CTRL1_BURST_EN(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_BURST_EN) & BM_GPMI_CTRL1_BURST_EN)

/*! @brief Set the BURST_EN field to a new value. */
#define BW_GPMI_CTRL1_BURST_EN(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_BURST_EN) | BF_GPMI_CTRL1_BURST_EN(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field TIMEOUT_IRQ[9] (RW)
 *
 * This bit is set when a timeout occurs using the Device_Busy_Timeout value.
 * Write 0 to clear.
 */
/*@{*/
#define BP_GPMI_CTRL1_TIMEOUT_IRQ (9U)     /*!< Bit position for GPMI_CTRL1_TIMEOUT_IRQ. */
#define BM_GPMI_CTRL1_TIMEOUT_IRQ (0x00000200U) /*!< Bit mask for GPMI_CTRL1_TIMEOUT_IRQ. */
#define BS_GPMI_CTRL1_TIMEOUT_IRQ (1U)     /*!< Bit field size in bits for GPMI_CTRL1_TIMEOUT_IRQ. */

/*! @brief Read current value of the GPMI_CTRL1_TIMEOUT_IRQ field. */
#define BR_GPMI_CTRL1_TIMEOUT_IRQ(x) (HW_GPMI_CTRL1(x).B.TIMEOUT_IRQ)

/*! @brief Format value for bitfield GPMI_CTRL1_TIMEOUT_IRQ. */
#define BF_GPMI_CTRL1_TIMEOUT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_TIMEOUT_IRQ) & BM_GPMI_CTRL1_TIMEOUT_IRQ)

/*! @brief Set the TIMEOUT_IRQ field to a new value. */
#define BW_GPMI_CTRL1_TIMEOUT_IRQ(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_TIMEOUT_IRQ) | BF_GPMI_CTRL1_TIMEOUT_IRQ(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field DEV_IRQ[10] (RW)
 *
 * This bit is set when an Interrupt is received from the ATA device. Write 0 to
 * clear.
 */
/*@{*/
#define BP_GPMI_CTRL1_DEV_IRQ (10U)        /*!< Bit position for GPMI_CTRL1_DEV_IRQ. */
#define BM_GPMI_CTRL1_DEV_IRQ (0x00000400U) /*!< Bit mask for GPMI_CTRL1_DEV_IRQ. */
#define BS_GPMI_CTRL1_DEV_IRQ (1U)         /*!< Bit field size in bits for GPMI_CTRL1_DEV_IRQ. */

/*! @brief Read current value of the GPMI_CTRL1_DEV_IRQ field. */
#define BR_GPMI_CTRL1_DEV_IRQ(x) (HW_GPMI_CTRL1(x).B.DEV_IRQ)

/*! @brief Format value for bitfield GPMI_CTRL1_DEV_IRQ. */
#define BF_GPMI_CTRL1_DEV_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_DEV_IRQ) & BM_GPMI_CTRL1_DEV_IRQ)

/*! @brief Set the DEV_IRQ field to a new value. */
#define BW_GPMI_CTRL1_DEV_IRQ(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_DEV_IRQ) | BF_GPMI_CTRL1_DEV_IRQ(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field DMA2ECC_MODE[11] (RW)
 *
 * This is mainly for testing HWECC without involving the Nand device. Setting
 * this bit will cause DMA write data to redirected to HWECC module (instead of
 * Nand Device) for encoding or decoding.
 */
/*@{*/
#define BP_GPMI_CTRL1_DMA2ECC_MODE (11U)   /*!< Bit position for GPMI_CTRL1_DMA2ECC_MODE. */
#define BM_GPMI_CTRL1_DMA2ECC_MODE (0x00000800U) /*!< Bit mask for GPMI_CTRL1_DMA2ECC_MODE. */
#define BS_GPMI_CTRL1_DMA2ECC_MODE (1U)    /*!< Bit field size in bits for GPMI_CTRL1_DMA2ECC_MODE. */

/*! @brief Read current value of the GPMI_CTRL1_DMA2ECC_MODE field. */
#define BR_GPMI_CTRL1_DMA2ECC_MODE(x) (HW_GPMI_CTRL1(x).B.DMA2ECC_MODE)

/*! @brief Format value for bitfield GPMI_CTRL1_DMA2ECC_MODE. */
#define BF_GPMI_CTRL1_DMA2ECC_MODE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_DMA2ECC_MODE) & BM_GPMI_CTRL1_DMA2ECC_MODE)

/*! @brief Set the DMA2ECC_MODE field to a new value. */
#define BW_GPMI_CTRL1_DMA2ECC_MODE(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_DMA2ECC_MODE) | BF_GPMI_CTRL1_DMA2ECC_MODE(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field RDN_DELAY[15:12] (RW)
 *
 * This variable is a factor in the calculated delay to apply to the internal
 * read strobe for correct read data sampling. The applied delay (AD) is between 0
 * and 1.875 times the reference period (RP). RP is one half of the GPMI clock
 * period if HALF_PERIOD=1 otherwise it is the full GPMI clock period. The equation
 * is: AD = RDN_DELAY x 0.125 x RP. This value must not exceed 16ns. This
 * variable is used to achieve faster NAND access. For example if the Read Strobe is
 * asserted from time 0 to 13ns but the read access time is 20ns, then choose
 * AD=12ns will cause the data to be sampled at time 25ns (13+12) giving a 5ns data
 * setup time. If RP=13ns then RDN_DELAY = 12/(0.125 x 13ns) = 7.38 (0111b).
 * DLL_ENABLE must be zero while changing this field.
 */
/*@{*/
#define BP_GPMI_CTRL1_RDN_DELAY (12U)      /*!< Bit position for GPMI_CTRL1_RDN_DELAY. */
#define BM_GPMI_CTRL1_RDN_DELAY (0x0000F000U) /*!< Bit mask for GPMI_CTRL1_RDN_DELAY. */
#define BS_GPMI_CTRL1_RDN_DELAY (4U)       /*!< Bit field size in bits for GPMI_CTRL1_RDN_DELAY. */

/*! @brief Read current value of the GPMI_CTRL1_RDN_DELAY field. */
#define BR_GPMI_CTRL1_RDN_DELAY(x) (HW_GPMI_CTRL1(x).B.RDN_DELAY)

/*! @brief Format value for bitfield GPMI_CTRL1_RDN_DELAY. */
#define BF_GPMI_CTRL1_RDN_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_RDN_DELAY) & BM_GPMI_CTRL1_RDN_DELAY)

/*! @brief Set the RDN_DELAY field to a new value. */
#define BW_GPMI_CTRL1_RDN_DELAY(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_RDN_DELAY) | BF_GPMI_CTRL1_RDN_DELAY(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field HALF_PERIOD[16] (RW)
 *
 * Set this bit to 1 if the GPMI clock period is greater than 16ns for proper
 * DLL operation. DLL_ENABLE must be zero while changing this field.
 */
/*@{*/
#define BP_GPMI_CTRL1_HALF_PERIOD (16U)    /*!< Bit position for GPMI_CTRL1_HALF_PERIOD. */
#define BM_GPMI_CTRL1_HALF_PERIOD (0x00010000U) /*!< Bit mask for GPMI_CTRL1_HALF_PERIOD. */
#define BS_GPMI_CTRL1_HALF_PERIOD (1U)     /*!< Bit field size in bits for GPMI_CTRL1_HALF_PERIOD. */

/*! @brief Read current value of the GPMI_CTRL1_HALF_PERIOD field. */
#define BR_GPMI_CTRL1_HALF_PERIOD(x) (HW_GPMI_CTRL1(x).B.HALF_PERIOD)

/*! @brief Format value for bitfield GPMI_CTRL1_HALF_PERIOD. */
#define BF_GPMI_CTRL1_HALF_PERIOD(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_HALF_PERIOD) & BM_GPMI_CTRL1_HALF_PERIOD)

/*! @brief Set the HALF_PERIOD field to a new value. */
#define BW_GPMI_CTRL1_HALF_PERIOD(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_HALF_PERIOD) | BF_GPMI_CTRL1_HALF_PERIOD(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field DLL_ENABLE[17] (RW)
 *
 * Set this bit to 1 to enable the GPMI DLL. This is required for fast NAND
 * reads (above 30 MHz read strobe). After setting this bit, wait 64 GPMI clock
 * cycles for the DLL to lock before performing a NAND read.
 */
/*@{*/
#define BP_GPMI_CTRL1_DLL_ENABLE (17U)     /*!< Bit position for GPMI_CTRL1_DLL_ENABLE. */
#define BM_GPMI_CTRL1_DLL_ENABLE (0x00020000U) /*!< Bit mask for GPMI_CTRL1_DLL_ENABLE. */
#define BS_GPMI_CTRL1_DLL_ENABLE (1U)      /*!< Bit field size in bits for GPMI_CTRL1_DLL_ENABLE. */

/*! @brief Read current value of the GPMI_CTRL1_DLL_ENABLE field. */
#define BR_GPMI_CTRL1_DLL_ENABLE(x) (HW_GPMI_CTRL1(x).B.DLL_ENABLE)

/*! @brief Format value for bitfield GPMI_CTRL1_DLL_ENABLE. */
#define BF_GPMI_CTRL1_DLL_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_DLL_ENABLE) & BM_GPMI_CTRL1_DLL_ENABLE)

/*! @brief Set the DLL_ENABLE field to a new value. */
#define BW_GPMI_CTRL1_DLL_ENABLE(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_DLL_ENABLE) | BF_GPMI_CTRL1_DLL_ENABLE(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field BCH_MODE[18] (RW)
 *
 * This bit selects which error correction unit will access GPMI. This bit must
 * always be set to '1', since only the BCH unit is available in this design.
 */
/*@{*/
#define BP_GPMI_CTRL1_BCH_MODE (18U)       /*!< Bit position for GPMI_CTRL1_BCH_MODE. */
#define BM_GPMI_CTRL1_BCH_MODE (0x00040000U) /*!< Bit mask for GPMI_CTRL1_BCH_MODE. */
#define BS_GPMI_CTRL1_BCH_MODE (1U)        /*!< Bit field size in bits for GPMI_CTRL1_BCH_MODE. */

/*! @brief Read current value of the GPMI_CTRL1_BCH_MODE field. */
#define BR_GPMI_CTRL1_BCH_MODE(x) (HW_GPMI_CTRL1(x).B.BCH_MODE)

/*! @brief Format value for bitfield GPMI_CTRL1_BCH_MODE. */
#define BF_GPMI_CTRL1_BCH_MODE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_BCH_MODE) & BM_GPMI_CTRL1_BCH_MODE)

/*! @brief Set the BCH_MODE field to a new value. */
#define BW_GPMI_CTRL1_BCH_MODE(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_BCH_MODE) | BF_GPMI_CTRL1_BCH_MODE(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field GANGED_RDYBUSY[19] (RW)
 *
 * Set this bit to 1 will force all Nand RDY_BUSY inputs to be sourced from
 * (tied to) RDY_BUSY0. This will free up all, except one, RDY_BUSY input pins.
 */
/*@{*/
#define BP_GPMI_CTRL1_GANGED_RDYBUSY (19U) /*!< Bit position for GPMI_CTRL1_GANGED_RDYBUSY. */
#define BM_GPMI_CTRL1_GANGED_RDYBUSY (0x00080000U) /*!< Bit mask for GPMI_CTRL1_GANGED_RDYBUSY. */
#define BS_GPMI_CTRL1_GANGED_RDYBUSY (1U)  /*!< Bit field size in bits for GPMI_CTRL1_GANGED_RDYBUSY. */

/*! @brief Read current value of the GPMI_CTRL1_GANGED_RDYBUSY field. */
#define BR_GPMI_CTRL1_GANGED_RDYBUSY(x) (HW_GPMI_CTRL1(x).B.GANGED_RDYBUSY)

/*! @brief Format value for bitfield GPMI_CTRL1_GANGED_RDYBUSY. */
#define BF_GPMI_CTRL1_GANGED_RDYBUSY(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_GANGED_RDYBUSY) & BM_GPMI_CTRL1_GANGED_RDYBUSY)

/*! @brief Set the GANGED_RDYBUSY field to a new value. */
#define BW_GPMI_CTRL1_GANGED_RDYBUSY(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_GANGED_RDYBUSY) | BF_GPMI_CTRL1_GANGED_RDYBUSY(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field TIMEOUT_IRQ_EN[20] (RW)
 *
 * Setting this bit to '1' will enable timeout IRQ for transfers in ATA mode
 * only, and for WAIT_FOR_READY commands in both ATA and Nand mode. The
 * Device_Busy_Timeout value is used for this timeout.
 */
/*@{*/
#define BP_GPMI_CTRL1_TIMEOUT_IRQ_EN (20U) /*!< Bit position for GPMI_CTRL1_TIMEOUT_IRQ_EN. */
#define BM_GPMI_CTRL1_TIMEOUT_IRQ_EN (0x00100000U) /*!< Bit mask for GPMI_CTRL1_TIMEOUT_IRQ_EN. */
#define BS_GPMI_CTRL1_TIMEOUT_IRQ_EN (1U)  /*!< Bit field size in bits for GPMI_CTRL1_TIMEOUT_IRQ_EN. */

/*! @brief Read current value of the GPMI_CTRL1_TIMEOUT_IRQ_EN field. */
#define BR_GPMI_CTRL1_TIMEOUT_IRQ_EN(x) (HW_GPMI_CTRL1(x).B.TIMEOUT_IRQ_EN)

/*! @brief Format value for bitfield GPMI_CTRL1_TIMEOUT_IRQ_EN. */
#define BF_GPMI_CTRL1_TIMEOUT_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_TIMEOUT_IRQ_EN) & BM_GPMI_CTRL1_TIMEOUT_IRQ_EN)

/*! @brief Set the TIMEOUT_IRQ_EN field to a new value. */
#define BW_GPMI_CTRL1_TIMEOUT_IRQ_EN(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_TIMEOUT_IRQ_EN) | BF_GPMI_CTRL1_TIMEOUT_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field TEST_TRIGGER[21] (RW)
 *
 * Test Trigger Enable
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_GPMI_CTRL1_TEST_TRIGGER (21U)   /*!< Bit position for GPMI_CTRL1_TEST_TRIGGER. */
#define BM_GPMI_CTRL1_TEST_TRIGGER (0x00200000U) /*!< Bit mask for GPMI_CTRL1_TEST_TRIGGER. */
#define BS_GPMI_CTRL1_TEST_TRIGGER (1U)    /*!< Bit field size in bits for GPMI_CTRL1_TEST_TRIGGER. */

/*! @brief Read current value of the GPMI_CTRL1_TEST_TRIGGER field. */
#define BR_GPMI_CTRL1_TEST_TRIGGER(x) (HW_GPMI_CTRL1(x).B.TEST_TRIGGER)

/*! @brief Format value for bitfield GPMI_CTRL1_TEST_TRIGGER. */
#define BF_GPMI_CTRL1_TEST_TRIGGER(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_TEST_TRIGGER) & BM_GPMI_CTRL1_TEST_TRIGGER)

/*! @brief Set the TEST_TRIGGER field to a new value. */
#define BW_GPMI_CTRL1_TEST_TRIGGER(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_TEST_TRIGGER) | BF_GPMI_CTRL1_TEST_TRIGGER(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field WRN_DLY_SEL[23:22] (RW)
 *
 * Since the GPMI write strobe (WRN) is a fast clock pin, the delay on this
 * signal can be programmed to match the load on this pin. 0 = ~2ns; 1 = ~4ns; 2 =
 * ~6ns; 3 = no delay.
 */
/*@{*/
#define BP_GPMI_CTRL1_WRN_DLY_SEL (22U)    /*!< Bit position for GPMI_CTRL1_WRN_DLY_SEL. */
#define BM_GPMI_CTRL1_WRN_DLY_SEL (0x00C00000U) /*!< Bit mask for GPMI_CTRL1_WRN_DLY_SEL. */
#define BS_GPMI_CTRL1_WRN_DLY_SEL (2U)     /*!< Bit field size in bits for GPMI_CTRL1_WRN_DLY_SEL. */

/*! @brief Read current value of the GPMI_CTRL1_WRN_DLY_SEL field. */
#define BR_GPMI_CTRL1_WRN_DLY_SEL(x) (HW_GPMI_CTRL1(x).B.WRN_DLY_SEL)

/*! @brief Format value for bitfield GPMI_CTRL1_WRN_DLY_SEL. */
#define BF_GPMI_CTRL1_WRN_DLY_SEL(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_WRN_DLY_SEL) & BM_GPMI_CTRL1_WRN_DLY_SEL)

/*! @brief Set the WRN_DLY_SEL field to a new value. */
#define BW_GPMI_CTRL1_WRN_DLY_SEL(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_WRN_DLY_SEL) | BF_GPMI_CTRL1_WRN_DLY_SEL(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field DECOUPLE_CS[24] (RW)
 *
 * Decouple Chip Select from DMA Channel. Setting this bit to 1 will allow a DMA
 * channel to specify any value in the CTRL0_CS register field. Software can use
 * one DMA channel to access all 8 Nand devices.
 */
/*@{*/
#define BP_GPMI_CTRL1_DECOUPLE_CS (24U)    /*!< Bit position for GPMI_CTRL1_DECOUPLE_CS. */
#define BM_GPMI_CTRL1_DECOUPLE_CS (0x01000000U) /*!< Bit mask for GPMI_CTRL1_DECOUPLE_CS. */
#define BS_GPMI_CTRL1_DECOUPLE_CS (1U)     /*!< Bit field size in bits for GPMI_CTRL1_DECOUPLE_CS. */

/*! @brief Read current value of the GPMI_CTRL1_DECOUPLE_CS field. */
#define BR_GPMI_CTRL1_DECOUPLE_CS(x) (HW_GPMI_CTRL1(x).B.DECOUPLE_CS)

/*! @brief Format value for bitfield GPMI_CTRL1_DECOUPLE_CS. */
#define BF_GPMI_CTRL1_DECOUPLE_CS(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_DECOUPLE_CS) & BM_GPMI_CTRL1_DECOUPLE_CS)

/*! @brief Set the DECOUPLE_CS field to a new value. */
#define BW_GPMI_CTRL1_DECOUPLE_CS(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_DECOUPLE_CS) | BF_GPMI_CTRL1_DECOUPLE_CS(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field SSYNCMODE[25] (RW)
 *
 * source synchronouse mode 1 or asynchrous mode 0. ASYNC = 0x0 Asynchronous
 * mode. SSYNC = 0x1 Source Synchronous mode.
 */
/*@{*/
#define BP_GPMI_CTRL1_SSYNCMODE (25U)      /*!< Bit position for GPMI_CTRL1_SSYNCMODE. */
#define BM_GPMI_CTRL1_SSYNCMODE (0x02000000U) /*!< Bit mask for GPMI_CTRL1_SSYNCMODE. */
#define BS_GPMI_CTRL1_SSYNCMODE (1U)       /*!< Bit field size in bits for GPMI_CTRL1_SSYNCMODE. */

/*! @brief Read current value of the GPMI_CTRL1_SSYNCMODE field. */
#define BR_GPMI_CTRL1_SSYNCMODE(x) (HW_GPMI_CTRL1(x).B.SSYNCMODE)

/*! @brief Format value for bitfield GPMI_CTRL1_SSYNCMODE. */
#define BF_GPMI_CTRL1_SSYNCMODE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_SSYNCMODE) & BM_GPMI_CTRL1_SSYNCMODE)

/*! @brief Set the SSYNCMODE field to a new value. */
#define BW_GPMI_CTRL1_SSYNCMODE(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_SSYNCMODE) | BF_GPMI_CTRL1_SSYNCMODE(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field UPDATE_CS[26] (RW)
 *
 * force the CS value is be updated to external chip select pin, even GPMI is
 * idle.
 */
/*@{*/
#define BP_GPMI_CTRL1_UPDATE_CS (26U)      /*!< Bit position for GPMI_CTRL1_UPDATE_CS. */
#define BM_GPMI_CTRL1_UPDATE_CS (0x04000000U) /*!< Bit mask for GPMI_CTRL1_UPDATE_CS. */
#define BS_GPMI_CTRL1_UPDATE_CS (1U)       /*!< Bit field size in bits for GPMI_CTRL1_UPDATE_CS. */

/*! @brief Read current value of the GPMI_CTRL1_UPDATE_CS field. */
#define BR_GPMI_CTRL1_UPDATE_CS(x) (HW_GPMI_CTRL1(x).B.UPDATE_CS)

/*! @brief Format value for bitfield GPMI_CTRL1_UPDATE_CS. */
#define BF_GPMI_CTRL1_UPDATE_CS(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_UPDATE_CS) & BM_GPMI_CTRL1_UPDATE_CS)

/*! @brief Set the UPDATE_CS field to a new value. */
#define BW_GPMI_CTRL1_UPDATE_CS(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_UPDATE_CS) | BF_GPMI_CTRL1_UPDATE_CS(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field GPMI_CLK_DIV2_EN[27] (RW)
 *
 * This bit should be reset to 0 in asynchronous mode. The frequence ratio of
 * (device clock : ccm gpmi clock) will be (1 : 1). This bit should be set to 1, in
 * source synchronous mode or toggle mode. The frequence raito of (device clock
 * : ccm gpmi clock) will be (1 : 2). enable the gpmi clk divider.
 *
 * Values:
 * - 0 - internal factor-2 clock divider is disabled
 * - 1 - internal factor-2 clock divider is enabled.
 */
/*@{*/
#define BP_GPMI_CTRL1_GPMI_CLK_DIV2_EN (27U) /*!< Bit position for GPMI_CTRL1_GPMI_CLK_DIV2_EN. */
#define BM_GPMI_CTRL1_GPMI_CLK_DIV2_EN (0x08000000U) /*!< Bit mask for GPMI_CTRL1_GPMI_CLK_DIV2_EN. */
#define BS_GPMI_CTRL1_GPMI_CLK_DIV2_EN (1U) /*!< Bit field size in bits for GPMI_CTRL1_GPMI_CLK_DIV2_EN. */

/*! @brief Read current value of the GPMI_CTRL1_GPMI_CLK_DIV2_EN field. */
#define BR_GPMI_CTRL1_GPMI_CLK_DIV2_EN(x) (HW_GPMI_CTRL1(x).B.GPMI_CLK_DIV2_EN)

/*! @brief Format value for bitfield GPMI_CTRL1_GPMI_CLK_DIV2_EN. */
#define BF_GPMI_CTRL1_GPMI_CLK_DIV2_EN(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_GPMI_CLK_DIV2_EN) & BM_GPMI_CTRL1_GPMI_CLK_DIV2_EN)

/*! @brief Set the GPMI_CLK_DIV2_EN field to a new value. */
#define BW_GPMI_CTRL1_GPMI_CLK_DIV2_EN(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_GPMI_CLK_DIV2_EN) | BF_GPMI_CTRL1_GPMI_CLK_DIV2_EN(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field TOGGLE_MODE[28] (RW)
 *
 * enable samsung toggle mode.
 */
/*@{*/
#define BP_GPMI_CTRL1_TOGGLE_MODE (28U)    /*!< Bit position for GPMI_CTRL1_TOGGLE_MODE. */
#define BM_GPMI_CTRL1_TOGGLE_MODE (0x10000000U) /*!< Bit mask for GPMI_CTRL1_TOGGLE_MODE. */
#define BS_GPMI_CTRL1_TOGGLE_MODE (1U)     /*!< Bit field size in bits for GPMI_CTRL1_TOGGLE_MODE. */

/*! @brief Read current value of the GPMI_CTRL1_TOGGLE_MODE field. */
#define BR_GPMI_CTRL1_TOGGLE_MODE(x) (HW_GPMI_CTRL1(x).B.TOGGLE_MODE)

/*! @brief Format value for bitfield GPMI_CTRL1_TOGGLE_MODE. */
#define BF_GPMI_CTRL1_TOGGLE_MODE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_TOGGLE_MODE) & BM_GPMI_CTRL1_TOGGLE_MODE)

/*! @brief Set the TOGGLE_MODE field to a new value. */
#define BW_GPMI_CTRL1_TOGGLE_MODE(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_TOGGLE_MODE) | BF_GPMI_CTRL1_TOGGLE_MODE(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field WRITE_CLK_STOP[29] (RW)
 *
 * In onfi source synchronous mode, host may save power during the data write
 * cycles by holding the CLK signal high (i.e. stopping the CLK). The host may only
 * stop the CLK during data write, by setting this bit to 1, if the device
 * supports this feature as indicated in the parameter page.
 */
/*@{*/
#define BP_GPMI_CTRL1_WRITE_CLK_STOP (29U) /*!< Bit position for GPMI_CTRL1_WRITE_CLK_STOP. */
#define BM_GPMI_CTRL1_WRITE_CLK_STOP (0x20000000U) /*!< Bit mask for GPMI_CTRL1_WRITE_CLK_STOP. */
#define BS_GPMI_CTRL1_WRITE_CLK_STOP (1U)  /*!< Bit field size in bits for GPMI_CTRL1_WRITE_CLK_STOP. */

/*! @brief Read current value of the GPMI_CTRL1_WRITE_CLK_STOP field. */
#define BR_GPMI_CTRL1_WRITE_CLK_STOP(x) (HW_GPMI_CTRL1(x).B.WRITE_CLK_STOP)

/*! @brief Format value for bitfield GPMI_CTRL1_WRITE_CLK_STOP. */
#define BF_GPMI_CTRL1_WRITE_CLK_STOP(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_WRITE_CLK_STOP) & BM_GPMI_CTRL1_WRITE_CLK_STOP)

/*! @brief Set the WRITE_CLK_STOP field to a new value. */
#define BW_GPMI_CTRL1_WRITE_CLK_STOP(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_WRITE_CLK_STOP) | BF_GPMI_CTRL1_WRITE_CLK_STOP(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field SSYNC_CLK_STOP[30] (RW)
 *
 * set this bit to 1 will stop the source synchronous mode clk.
 */
/*@{*/
#define BP_GPMI_CTRL1_SSYNC_CLK_STOP (30U) /*!< Bit position for GPMI_CTRL1_SSYNC_CLK_STOP. */
#define BM_GPMI_CTRL1_SSYNC_CLK_STOP (0x40000000U) /*!< Bit mask for GPMI_CTRL1_SSYNC_CLK_STOP. */
#define BS_GPMI_CTRL1_SSYNC_CLK_STOP (1U)  /*!< Bit field size in bits for GPMI_CTRL1_SSYNC_CLK_STOP. */

/*! @brief Read current value of the GPMI_CTRL1_SSYNC_CLK_STOP field. */
#define BR_GPMI_CTRL1_SSYNC_CLK_STOP(x) (HW_GPMI_CTRL1(x).B.SSYNC_CLK_STOP)

/*! @brief Format value for bitfield GPMI_CTRL1_SSYNC_CLK_STOP. */
#define BF_GPMI_CTRL1_SSYNC_CLK_STOP(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_SSYNC_CLK_STOP) & BM_GPMI_CTRL1_SSYNC_CLK_STOP)

/*! @brief Set the SSYNC_CLK_STOP field to a new value. */
#define BW_GPMI_CTRL1_SSYNC_CLK_STOP(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_SSYNC_CLK_STOP) | BF_GPMI_CTRL1_SSYNC_CLK_STOP(v)))
/*@}*/

/*!
 * @name Register GPMI_CTRL1, field DEV_CLK_STOP[31] (RW)
 *
 * set this bit to 1 will stop gpmi io working clk.
 */
/*@{*/
#define BP_GPMI_CTRL1_DEV_CLK_STOP (31U)   /*!< Bit position for GPMI_CTRL1_DEV_CLK_STOP. */
#define BM_GPMI_CTRL1_DEV_CLK_STOP (0x80000000U) /*!< Bit mask for GPMI_CTRL1_DEV_CLK_STOP. */
#define BS_GPMI_CTRL1_DEV_CLK_STOP (1U)    /*!< Bit field size in bits for GPMI_CTRL1_DEV_CLK_STOP. */

/*! @brief Read current value of the GPMI_CTRL1_DEV_CLK_STOP field. */
#define BR_GPMI_CTRL1_DEV_CLK_STOP(x) (HW_GPMI_CTRL1(x).B.DEV_CLK_STOP)

/*! @brief Format value for bitfield GPMI_CTRL1_DEV_CLK_STOP. */
#define BF_GPMI_CTRL1_DEV_CLK_STOP(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_CTRL1_DEV_CLK_STOP) & BM_GPMI_CTRL1_DEV_CLK_STOP)

/*! @brief Set the DEV_CLK_STOP field to a new value. */
#define BW_GPMI_CTRL1_DEV_CLK_STOP(x, v) (HW_GPMI_CTRL1_WR(x, (HW_GPMI_CTRL1_RD(x) & ~BM_GPMI_CTRL1_DEV_CLK_STOP) | BF_GPMI_CTRL1_DEV_CLK_STOP(v)))
/*@}*/




/*******************************************************************************
 * HW_GPMI_TIMING0 - GPMI Timing Register 0 Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_TIMING0 - GPMI Timing Register 0 Description (RW)
 *
 * Reset value: 0x00010203U
 *
 * The GPMI timing register 0 specifies the timing parameters that are used by
 * the cycle state machine to guarantee the various setup, hold and cycle times
 * for the external media type. GPMI_TIMING0 0x070
 */
typedef union _hw_gpmi_timing0
{
    uint32_t U;
    struct _hw_gpmi_timing0_bitfields
    {
        uint32_t DATA_SETUP : 8;       /*!< [7:0]  */
        uint32_t DATA_HOLD : 8;        /*!< [15:8]  */
        uint32_t ADDRESS_SETUP : 8;    /*!< [23:16]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_gpmi_timing0_t;

/*!
 * @name Constants and macros for entire GPMI_TIMING0 register
 */
/*@{*/
#define HW_GPMI_TIMING0_ADDR(x)  ((uintptr_t)(x) + 0x70U)

#define HW_GPMI_TIMING0(x)       (*(__IO hw_gpmi_timing0_t *) HW_GPMI_TIMING0_ADDR(x))
#define HW_GPMI_TIMING0_RD(x)    (HW_GPMI_TIMING0(x).U)
#define HW_GPMI_TIMING0_WR(x, v) (HW_GPMI_TIMING0(x).U = (v))
#define HW_GPMI_TIMING0_SET(x, v) (HW_GPMI_TIMING0_WR(x, HW_GPMI_TIMING0_RD(x) |  (v)))
#define HW_GPMI_TIMING0_CLR(x, v) (HW_GPMI_TIMING0_WR(x, HW_GPMI_TIMING0_RD(x) & ~(v)))
#define HW_GPMI_TIMING0_TOG(x, v) (HW_GPMI_TIMING0_WR(x, HW_GPMI_TIMING0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_TIMING0 bitfields
 */

/*!
 * @name Register GPMI_TIMING0, field DATA_SETUP[7:0] (RW)
 *
 * Data bus setup time in GPMICLK cycles. Also the time that the data strobe is
 * asserted in a cycle. This value must be greater than 2 for ATA devices that
 * use IORDY to extend transfer cycles. A value of zero is interpreted as 256. For
 * ATA PIO modes this is known in the ATA7 specification as ""DIOR-/DIOW-"
 */
/*@{*/
#define BP_GPMI_TIMING0_DATA_SETUP (0U)    /*!< Bit position for GPMI_TIMING0_DATA_SETUP. */
#define BM_GPMI_TIMING0_DATA_SETUP (0x000000FFU) /*!< Bit mask for GPMI_TIMING0_DATA_SETUP. */
#define BS_GPMI_TIMING0_DATA_SETUP (8U)    /*!< Bit field size in bits for GPMI_TIMING0_DATA_SETUP. */

/*! @brief Read current value of the GPMI_TIMING0_DATA_SETUP field. */
#define BR_GPMI_TIMING0_DATA_SETUP(x) (HW_GPMI_TIMING0(x).B.DATA_SETUP)

/*! @brief Format value for bitfield GPMI_TIMING0_DATA_SETUP. */
#define BF_GPMI_TIMING0_DATA_SETUP(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING0_DATA_SETUP) & BM_GPMI_TIMING0_DATA_SETUP)

/*! @brief Set the DATA_SETUP field to a new value. */
#define BW_GPMI_TIMING0_DATA_SETUP(x, v) (HW_GPMI_TIMING0_WR(x, (HW_GPMI_TIMING0_RD(x) & ~BM_GPMI_TIMING0_DATA_SETUP) | BF_GPMI_TIMING0_DATA_SETUP(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING0, field DATA_HOLD[15:8] (RW)
 *
 * Data bus hold time in GPMICLK cycles. Also the time that the data strobe is
 * de-asserted in a cycle. A value of zero is interpreted as 256. For ATA PIO
 * modes this is known in the ATA7 specification as "DIOR-/DIOW- recovery time"
 */
/*@{*/
#define BP_GPMI_TIMING0_DATA_HOLD (8U)     /*!< Bit position for GPMI_TIMING0_DATA_HOLD. */
#define BM_GPMI_TIMING0_DATA_HOLD (0x0000FF00U) /*!< Bit mask for GPMI_TIMING0_DATA_HOLD. */
#define BS_GPMI_TIMING0_DATA_HOLD (8U)     /*!< Bit field size in bits for GPMI_TIMING0_DATA_HOLD. */

/*! @brief Read current value of the GPMI_TIMING0_DATA_HOLD field. */
#define BR_GPMI_TIMING0_DATA_HOLD(x) (HW_GPMI_TIMING0(x).B.DATA_HOLD)

/*! @brief Format value for bitfield GPMI_TIMING0_DATA_HOLD. */
#define BF_GPMI_TIMING0_DATA_HOLD(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING0_DATA_HOLD) & BM_GPMI_TIMING0_DATA_HOLD)

/*! @brief Set the DATA_HOLD field to a new value. */
#define BW_GPMI_TIMING0_DATA_HOLD(x, v) (HW_GPMI_TIMING0_WR(x, (HW_GPMI_TIMING0_RD(x) & ~BM_GPMI_TIMING0_DATA_HOLD) | BF_GPMI_TIMING0_DATA_HOLD(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING0, field ADDRESS_SETUP[23:16] (RW)
 *
 * Number of GPMICLK cycles that the CE/ADDR signals are active before a strobe
 * is asserted. A value of zero is interpreted as 0. For ATA PIO modes this is
 * known in the ATA7 specification as "Address valid to DIOR-/DIOW- setup"
 */
/*@{*/
#define BP_GPMI_TIMING0_ADDRESS_SETUP (16U) /*!< Bit position for GPMI_TIMING0_ADDRESS_SETUP. */
#define BM_GPMI_TIMING0_ADDRESS_SETUP (0x00FF0000U) /*!< Bit mask for GPMI_TIMING0_ADDRESS_SETUP. */
#define BS_GPMI_TIMING0_ADDRESS_SETUP (8U) /*!< Bit field size in bits for GPMI_TIMING0_ADDRESS_SETUP. */

/*! @brief Read current value of the GPMI_TIMING0_ADDRESS_SETUP field. */
#define BR_GPMI_TIMING0_ADDRESS_SETUP(x) (HW_GPMI_TIMING0(x).B.ADDRESS_SETUP)

/*! @brief Format value for bitfield GPMI_TIMING0_ADDRESS_SETUP. */
#define BF_GPMI_TIMING0_ADDRESS_SETUP(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING0_ADDRESS_SETUP) & BM_GPMI_TIMING0_ADDRESS_SETUP)

/*! @brief Set the ADDRESS_SETUP field to a new value. */
#define BW_GPMI_TIMING0_ADDRESS_SETUP(x, v) (HW_GPMI_TIMING0_WR(x, (HW_GPMI_TIMING0_RD(x) & ~BM_GPMI_TIMING0_ADDRESS_SETUP) | BF_GPMI_TIMING0_ADDRESS_SETUP(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING0, field RSVD1[31:24] (WOZ)
 *
 * Always write zeroes to this bit field.
 */
/*@{*/
#define BP_GPMI_TIMING0_RSVD1 (24U)        /*!< Bit position for GPMI_TIMING0_RSVD1. */
#define BM_GPMI_TIMING0_RSVD1 (0xFF000000U) /*!< Bit mask for GPMI_TIMING0_RSVD1. */
#define BS_GPMI_TIMING0_RSVD1 (8U)         /*!< Bit field size in bits for GPMI_TIMING0_RSVD1. */

/*! @brief Format value for bitfield GPMI_TIMING0_RSVD1. */
#define BF_GPMI_TIMING0_RSVD1(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING0_RSVD1) & BM_GPMI_TIMING0_RSVD1)
/*@}*/

/*******************************************************************************
 * HW_GPMI_TIMING1 - GPMI Timing Register 1 Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_TIMING1 - GPMI Timing Register 1 Description (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPMI timing register 1 specifies the timeouts used when monitoring the
 * NAND READY pin or the ATA IRQ and IOWAIT signals. GPMI_TIMING1 0x080
 */
typedef union _hw_gpmi_timing1
{
    uint32_t U;
    struct _hw_gpmi_timing1_bitfields
    {
        uint32_t RSVD1 : 16;           /*!< [15:0]  */
        uint32_t DEVICE_BUSY_TIMEOUT : 16; /*!< [31:16]  */
    } B;
} hw_gpmi_timing1_t;

/*!
 * @name Constants and macros for entire GPMI_TIMING1 register
 */
/*@{*/
#define HW_GPMI_TIMING1_ADDR(x)  ((uintptr_t)(x) + 0x80U)

#define HW_GPMI_TIMING1(x)       (*(__IO hw_gpmi_timing1_t *) HW_GPMI_TIMING1_ADDR(x))
#define HW_GPMI_TIMING1_RD(x)    (HW_GPMI_TIMING1(x).U)
#define HW_GPMI_TIMING1_WR(x, v) (HW_GPMI_TIMING1(x).U = (v))
#define HW_GPMI_TIMING1_SET(x, v) (HW_GPMI_TIMING1_WR(x, HW_GPMI_TIMING1_RD(x) |  (v)))
#define HW_GPMI_TIMING1_CLR(x, v) (HW_GPMI_TIMING1_WR(x, HW_GPMI_TIMING1_RD(x) & ~(v)))
#define HW_GPMI_TIMING1_TOG(x, v) (HW_GPMI_TIMING1_WR(x, HW_GPMI_TIMING1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_TIMING1 bitfields
 */

/*!
 * @name Register GPMI_TIMING1, field RSVD1[15:0] (RO)
 *
 * Always write zeroes to this bit field.
 */
/*@{*/
#define BP_GPMI_TIMING1_RSVD1 (0U)         /*!< Bit position for GPMI_TIMING1_RSVD1. */
#define BM_GPMI_TIMING1_RSVD1 (0x0000FFFFU) /*!< Bit mask for GPMI_TIMING1_RSVD1. */
#define BS_GPMI_TIMING1_RSVD1 (16U)        /*!< Bit field size in bits for GPMI_TIMING1_RSVD1. */

/*! @brief Read current value of the GPMI_TIMING1_RSVD1 field. */
#define BR_GPMI_TIMING1_RSVD1(x) (HW_GPMI_TIMING1(x).B.RSVD1)
/*@}*/

/*!
 * @name Register GPMI_TIMING1, field DEVICE_BUSY_TIMEOUT[31:16] (RW)
 *
 * Timeout waiting for NAND Ready/Busy or ATA IRQ. Used in WAIT_FOR_READY mode.
 * This value is the number of GPMI_CLK cycles multiplied by 4096.
 */
/*@{*/
#define BP_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT (16U) /*!< Bit position for GPMI_TIMING1_DEVICE_BUSY_TIMEOUT. */
#define BM_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT (0xFFFF0000U) /*!< Bit mask for GPMI_TIMING1_DEVICE_BUSY_TIMEOUT. */
#define BS_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT (16U) /*!< Bit field size in bits for GPMI_TIMING1_DEVICE_BUSY_TIMEOUT. */

/*! @brief Read current value of the GPMI_TIMING1_DEVICE_BUSY_TIMEOUT field. */
#define BR_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT(x) (HW_GPMI_TIMING1(x).B.DEVICE_BUSY_TIMEOUT)

/*! @brief Format value for bitfield GPMI_TIMING1_DEVICE_BUSY_TIMEOUT. */
#define BF_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT) & BM_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT)

/*! @brief Set the DEVICE_BUSY_TIMEOUT field to a new value. */
#define BW_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT(x, v) (HW_GPMI_TIMING1_WR(x, (HW_GPMI_TIMING1_RD(x) & ~BM_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT) | BF_GPMI_TIMING1_DEVICE_BUSY_TIMEOUT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPMI_TIMING2 - GPMI Timing Register 2 Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_TIMING2 - GPMI Timing Register 2 Description (RW)
 *
 * Reset value: 0x03023336U
 *
 * The GPMI timing register 2 specifies the double data rate timing parameters
 * that are used by the cycle state machine to guarantee the various cs delay,
 * pre-amble delay, post-amble delay, command/address delay, data delay, TCR,
 * TRPSTH, and read latency cycle times for the external media type. GPMI_TIMING2 0x090
 */
typedef union _hw_gpmi_timing2
{
    uint32_t U;
    struct _hw_gpmi_timing2_bitfields
    {
        uint32_t DATA_PAUSE : 4;       /*!< [3:0]  */
        uint32_t CMDADD_PAUSE : 4;     /*!< [7:4]  */
        uint32_t POSTAMBLE_DELAY : 4;  /*!< [11:8]  */
        uint32_t PREAMBLE_DELAY : 4;   /*!< [15:12]  */
        uint32_t CE_DELAY : 5;         /*!< [20:16]  */
        uint32_t RSVD0 : 3;            /*!< [23:21]  */
        uint32_t READ_LATENCY : 3;     /*!< [26:24]  */
        uint32_t TCR : 2;              /*!< [28:27]  */
        uint32_t TRPSTH : 3;           /*!< [31:29]  */
    } B;
} hw_gpmi_timing2_t;

/*!
 * @name Constants and macros for entire GPMI_TIMING2 register
 */
/*@{*/
#define HW_GPMI_TIMING2_ADDR(x)  ((uintptr_t)(x) + 0x90U)

#define HW_GPMI_TIMING2(x)       (*(__IO hw_gpmi_timing2_t *) HW_GPMI_TIMING2_ADDR(x))
#define HW_GPMI_TIMING2_RD(x)    (HW_GPMI_TIMING2(x).U)
#define HW_GPMI_TIMING2_WR(x, v) (HW_GPMI_TIMING2(x).U = (v))
#define HW_GPMI_TIMING2_SET(x, v) (HW_GPMI_TIMING2_WR(x, HW_GPMI_TIMING2_RD(x) |  (v)))
#define HW_GPMI_TIMING2_CLR(x, v) (HW_GPMI_TIMING2_WR(x, HW_GPMI_TIMING2_RD(x) & ~(v)))
#define HW_GPMI_TIMING2_TOG(x, v) (HW_GPMI_TIMING2_WR(x, HW_GPMI_TIMING2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_TIMING2 bitfields
 */

/*!
 * @name Register GPMI_TIMING2, field DATA_PAUSE[3:0] (RW)
 *
 * GPMI delay time from data pause to data resume in GPMICLK cycles. A value of
 * zero is interpreted as 16.
 */
/*@{*/
#define BP_GPMI_TIMING2_DATA_PAUSE (0U)    /*!< Bit position for GPMI_TIMING2_DATA_PAUSE. */
#define BM_GPMI_TIMING2_DATA_PAUSE (0x0000000FU) /*!< Bit mask for GPMI_TIMING2_DATA_PAUSE. */
#define BS_GPMI_TIMING2_DATA_PAUSE (4U)    /*!< Bit field size in bits for GPMI_TIMING2_DATA_PAUSE. */

/*! @brief Read current value of the GPMI_TIMING2_DATA_PAUSE field. */
#define BR_GPMI_TIMING2_DATA_PAUSE(x) (HW_GPMI_TIMING2(x).B.DATA_PAUSE)

/*! @brief Format value for bitfield GPMI_TIMING2_DATA_PAUSE. */
#define BF_GPMI_TIMING2_DATA_PAUSE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING2_DATA_PAUSE) & BM_GPMI_TIMING2_DATA_PAUSE)

/*! @brief Set the DATA_PAUSE field to a new value. */
#define BW_GPMI_TIMING2_DATA_PAUSE(x, v) (HW_GPMI_TIMING2_WR(x, (HW_GPMI_TIMING2_RD(x) & ~BM_GPMI_TIMING2_DATA_PAUSE) | BF_GPMI_TIMING2_DATA_PAUSE(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING2, field CMDADD_PAUSE[7:4] (RW)
 *
 * GPMI delay time from command or addres pause to command or address resume in
 * GPMICLK cycles. A value of zero is interpreted as 16.
 */
/*@{*/
#define BP_GPMI_TIMING2_CMDADD_PAUSE (4U)  /*!< Bit position for GPMI_TIMING2_CMDADD_PAUSE. */
#define BM_GPMI_TIMING2_CMDADD_PAUSE (0x000000F0U) /*!< Bit mask for GPMI_TIMING2_CMDADD_PAUSE. */
#define BS_GPMI_TIMING2_CMDADD_PAUSE (4U)  /*!< Bit field size in bits for GPMI_TIMING2_CMDADD_PAUSE. */

/*! @brief Read current value of the GPMI_TIMING2_CMDADD_PAUSE field. */
#define BR_GPMI_TIMING2_CMDADD_PAUSE(x) (HW_GPMI_TIMING2(x).B.CMDADD_PAUSE)

/*! @brief Format value for bitfield GPMI_TIMING2_CMDADD_PAUSE. */
#define BF_GPMI_TIMING2_CMDADD_PAUSE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING2_CMDADD_PAUSE) & BM_GPMI_TIMING2_CMDADD_PAUSE)

/*! @brief Set the CMDADD_PAUSE field to a new value. */
#define BW_GPMI_TIMING2_CMDADD_PAUSE(x, v) (HW_GPMI_TIMING2_WR(x, (HW_GPMI_TIMING2_RD(x) & ~BM_GPMI_TIMING2_CMDADD_PAUSE) | BF_GPMI_TIMING2_CMDADD_PAUSE(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING2, field POSTAMBLE_DELAY[11:8] (RW)
 *
 * GPMI post-amble delay in GPMICLK cycles. A value of zero is interpreted as 16.
 */
/*@{*/
#define BP_GPMI_TIMING2_POSTAMBLE_DELAY (8U) /*!< Bit position for GPMI_TIMING2_POSTAMBLE_DELAY. */
#define BM_GPMI_TIMING2_POSTAMBLE_DELAY (0x00000F00U) /*!< Bit mask for GPMI_TIMING2_POSTAMBLE_DELAY. */
#define BS_GPMI_TIMING2_POSTAMBLE_DELAY (4U) /*!< Bit field size in bits for GPMI_TIMING2_POSTAMBLE_DELAY. */

/*! @brief Read current value of the GPMI_TIMING2_POSTAMBLE_DELAY field. */
#define BR_GPMI_TIMING2_POSTAMBLE_DELAY(x) (HW_GPMI_TIMING2(x).B.POSTAMBLE_DELAY)

/*! @brief Format value for bitfield GPMI_TIMING2_POSTAMBLE_DELAY. */
#define BF_GPMI_TIMING2_POSTAMBLE_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING2_POSTAMBLE_DELAY) & BM_GPMI_TIMING2_POSTAMBLE_DELAY)

/*! @brief Set the POSTAMBLE_DELAY field to a new value. */
#define BW_GPMI_TIMING2_POSTAMBLE_DELAY(x, v) (HW_GPMI_TIMING2_WR(x, (HW_GPMI_TIMING2_RD(x) & ~BM_GPMI_TIMING2_POSTAMBLE_DELAY) | BF_GPMI_TIMING2_POSTAMBLE_DELAY(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING2, field PREAMBLE_DELAY[15:12] (RW)
 *
 * GPMI pre-amble delay in GPMICLK cycles. A value of zero is interpreted as 16.
 */
/*@{*/
#define BP_GPMI_TIMING2_PREAMBLE_DELAY (12U) /*!< Bit position for GPMI_TIMING2_PREAMBLE_DELAY. */
#define BM_GPMI_TIMING2_PREAMBLE_DELAY (0x0000F000U) /*!< Bit mask for GPMI_TIMING2_PREAMBLE_DELAY. */
#define BS_GPMI_TIMING2_PREAMBLE_DELAY (4U) /*!< Bit field size in bits for GPMI_TIMING2_PREAMBLE_DELAY. */

/*! @brief Read current value of the GPMI_TIMING2_PREAMBLE_DELAY field. */
#define BR_GPMI_TIMING2_PREAMBLE_DELAY(x) (HW_GPMI_TIMING2(x).B.PREAMBLE_DELAY)

/*! @brief Format value for bitfield GPMI_TIMING2_PREAMBLE_DELAY. */
#define BF_GPMI_TIMING2_PREAMBLE_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING2_PREAMBLE_DELAY) & BM_GPMI_TIMING2_PREAMBLE_DELAY)

/*! @brief Set the PREAMBLE_DELAY field to a new value. */
#define BW_GPMI_TIMING2_PREAMBLE_DELAY(x, v) (HW_GPMI_TIMING2_WR(x, (HW_GPMI_TIMING2_RD(x) & ~BM_GPMI_TIMING2_PREAMBLE_DELAY) | BF_GPMI_TIMING2_PREAMBLE_DELAY(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING2, field CE_DELAY[20:16] (RW)
 *
 * GPMI dealy from CEn assert to W/Rn changing edge. value of zero is
 * interpreted as 32.
 */
/*@{*/
#define BP_GPMI_TIMING2_CE_DELAY (16U)     /*!< Bit position for GPMI_TIMING2_CE_DELAY. */
#define BM_GPMI_TIMING2_CE_DELAY (0x001F0000U) /*!< Bit mask for GPMI_TIMING2_CE_DELAY. */
#define BS_GPMI_TIMING2_CE_DELAY (5U)      /*!< Bit field size in bits for GPMI_TIMING2_CE_DELAY. */

/*! @brief Read current value of the GPMI_TIMING2_CE_DELAY field. */
#define BR_GPMI_TIMING2_CE_DELAY(x) (HW_GPMI_TIMING2(x).B.CE_DELAY)

/*! @brief Format value for bitfield GPMI_TIMING2_CE_DELAY. */
#define BF_GPMI_TIMING2_CE_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING2_CE_DELAY) & BM_GPMI_TIMING2_CE_DELAY)

/*! @brief Set the CE_DELAY field to a new value. */
#define BW_GPMI_TIMING2_CE_DELAY(x, v) (HW_GPMI_TIMING2_WR(x, (HW_GPMI_TIMING2_RD(x) & ~BM_GPMI_TIMING2_CE_DELAY) | BF_GPMI_TIMING2_CE_DELAY(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING2, field RSVD0[23:21] (RO)
 *
 * Always write zeroes to this bit field.
 */
/*@{*/
#define BP_GPMI_TIMING2_RSVD0 (21U)        /*!< Bit position for GPMI_TIMING2_RSVD0. */
#define BM_GPMI_TIMING2_RSVD0 (0x00E00000U) /*!< Bit mask for GPMI_TIMING2_RSVD0. */
#define BS_GPMI_TIMING2_RSVD0 (3U)         /*!< Bit field size in bits for GPMI_TIMING2_RSVD0. */

/*! @brief Read current value of the GPMI_TIMING2_RSVD0 field. */
#define BR_GPMI_TIMING2_RSVD0(x) (HW_GPMI_TIMING2(x).B.RSVD0)
/*@}*/

/*!
 * @name Register GPMI_TIMING2, field READ_LATENCY[26:24] (RW)
 *
 * This field is for double data rate read latency configuration. others READ
 * LATENCY is 3
 *
 * Values:
 * - 000 - READ LATENCY is 0
 * - 001 - READ LATENCY is 1
 * - 010 - READ LATENCY is 2
 * - 011 - READ LATENCY is 3
 * - 100 - READ LATENCY is 4
 * - 101 - READ LATENCY is 5
 */
/*@{*/
#define BP_GPMI_TIMING2_READ_LATENCY (24U) /*!< Bit position for GPMI_TIMING2_READ_LATENCY. */
#define BM_GPMI_TIMING2_READ_LATENCY (0x07000000U) /*!< Bit mask for GPMI_TIMING2_READ_LATENCY. */
#define BS_GPMI_TIMING2_READ_LATENCY (3U)  /*!< Bit field size in bits for GPMI_TIMING2_READ_LATENCY. */

/*! @brief Read current value of the GPMI_TIMING2_READ_LATENCY field. */
#define BR_GPMI_TIMING2_READ_LATENCY(x) (HW_GPMI_TIMING2(x).B.READ_LATENCY)

/*! @brief Format value for bitfield GPMI_TIMING2_READ_LATENCY. */
#define BF_GPMI_TIMING2_READ_LATENCY(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING2_READ_LATENCY) & BM_GPMI_TIMING2_READ_LATENCY)

/*! @brief Set the READ_LATENCY field to a new value. */
#define BW_GPMI_TIMING2_READ_LATENCY(x, v) (HW_GPMI_TIMING2_WR(x, (HW_GPMI_TIMING2_RD(x) & ~BM_GPMI_TIMING2_READ_LATENCY) | BF_GPMI_TIMING2_READ_LATENCY(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING2, field TCR[28:27] (RW)
 *
 * Only for Toggle NAND timing control delay (TCR+1) GPMICLK cycles for CEn_B
 * low to RE_B low, 0 is less than or equal to TCR, which is less than the
 * PREAMBLE_DELAY
 */
/*@{*/
#define BP_GPMI_TIMING2_TCR  (27U)         /*!< Bit position for GPMI_TIMING2_TCR. */
#define BM_GPMI_TIMING2_TCR  (0x18000000U) /*!< Bit mask for GPMI_TIMING2_TCR. */
#define BS_GPMI_TIMING2_TCR  (2U)          /*!< Bit field size in bits for GPMI_TIMING2_TCR. */

/*! @brief Read current value of the GPMI_TIMING2_TCR field. */
#define BR_GPMI_TIMING2_TCR(x) (HW_GPMI_TIMING2(x).B.TCR)

/*! @brief Format value for bitfield GPMI_TIMING2_TCR. */
#define BF_GPMI_TIMING2_TCR(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING2_TCR) & BM_GPMI_TIMING2_TCR)

/*! @brief Set the TCR field to a new value. */
#define BW_GPMI_TIMING2_TCR(x, v) (HW_GPMI_TIMING2_WR(x, (HW_GPMI_TIMING2_RD(x) & ~BM_GPMI_TIMING2_TCR) | BF_GPMI_TIMING2_TCR(v)))
/*@}*/

/*!
 * @name Register GPMI_TIMING2, field TRPSTH[31:29] (RW)
 *
 * Only for Toggle NAND timing control delay TRPSTH GPMICLK cycles for CEn_B
 * high to RE_B high, A value of zero is interpreted as 8
 */
/*@{*/
#define BP_GPMI_TIMING2_TRPSTH (29U)       /*!< Bit position for GPMI_TIMING2_TRPSTH. */
#define BM_GPMI_TIMING2_TRPSTH (0xE0000000U) /*!< Bit mask for GPMI_TIMING2_TRPSTH. */
#define BS_GPMI_TIMING2_TRPSTH (3U)        /*!< Bit field size in bits for GPMI_TIMING2_TRPSTH. */

/*! @brief Read current value of the GPMI_TIMING2_TRPSTH field. */
#define BR_GPMI_TIMING2_TRPSTH(x) (HW_GPMI_TIMING2(x).B.TRPSTH)

/*! @brief Format value for bitfield GPMI_TIMING2_TRPSTH. */
#define BF_GPMI_TIMING2_TRPSTH(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_TIMING2_TRPSTH) & BM_GPMI_TIMING2_TRPSTH)

/*! @brief Set the TRPSTH field to a new value. */
#define BW_GPMI_TIMING2_TRPSTH(x, v) (HW_GPMI_TIMING2_WR(x, (HW_GPMI_TIMING2_RD(x) & ~BM_GPMI_TIMING2_TRPSTH) | BF_GPMI_TIMING2_TRPSTH(v)))
/*@}*/

/*******************************************************************************
 * HW_GPMI_DATA - GPMI DMA Data Transfer Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_DATA - GPMI DMA Data Transfer Register Description (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPMI DMA data transfer register is used by the DMA to read or write data
 * to or from the ATA/NAND control state machine. GPMI_DATA 0x0A0
 */
typedef union _hw_gpmi_data
{
    uint32_t U;
    struct _hw_gpmi_data_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_gpmi_data_t;

/*!
 * @name Constants and macros for entire GPMI_DATA register
 */
/*@{*/
#define HW_GPMI_DATA_ADDR(x)     ((uintptr_t)(x) + 0xA0U)

#define HW_GPMI_DATA(x)          (*(__IO hw_gpmi_data_t *) HW_GPMI_DATA_ADDR(x))
#define HW_GPMI_DATA_RD(x)       (HW_GPMI_DATA(x).U)
#define HW_GPMI_DATA_WR(x, v)    (HW_GPMI_DATA(x).U = (v))
#define HW_GPMI_DATA_SET(x, v)   (HW_GPMI_DATA_WR(x, HW_GPMI_DATA_RD(x) |  (v)))
#define HW_GPMI_DATA_CLR(x, v)   (HW_GPMI_DATA_WR(x, HW_GPMI_DATA_RD(x) & ~(v)))
#define HW_GPMI_DATA_TOG(x, v)   (HW_GPMI_DATA_WR(x, HW_GPMI_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_DATA bitfields
 */

/*!
 * @name Register GPMI_DATA, field DATA[31:0] (RW)
 *
 * In 8-bit mode, one, two, three or four bytes can can be accessed to send the
 * same number of bus cycles.
 */
/*@{*/
#define BP_GPMI_DATA_DATA    (0U)          /*!< Bit position for GPMI_DATA_DATA. */
#define BM_GPMI_DATA_DATA    (0xFFFFFFFFU) /*!< Bit mask for GPMI_DATA_DATA. */
#define BS_GPMI_DATA_DATA    (32U)         /*!< Bit field size in bits for GPMI_DATA_DATA. */

/*! @brief Read current value of the GPMI_DATA_DATA field. */
#define BR_GPMI_DATA_DATA(x) (HW_GPMI_DATA(x).U)

/*! @brief Format value for bitfield GPMI_DATA_DATA. */
#define BF_GPMI_DATA_DATA(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_DATA_DATA) & BM_GPMI_DATA_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_GPMI_DATA_DATA(x, v) (HW_GPMI_DATA_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPMI_STAT - GPMI Status Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_STAT - GPMI Status Register Description (RO)
 *
 * Reset value: 0x00000005U
 *
 * The GPMI control and status register provides a read back path for various
 * operational states of the GPMI controller. GPMI_STAT 0x0B0
 */
typedef union _hw_gpmi_stat
{
    uint32_t U;
    struct _hw_gpmi_stat_bitfields
    {
        uint32_t PRESENT : 1;          /*!< [0]  */
        uint32_t FIFO_FULL : 1;        /*!< [1]  */
        uint32_t FIFO_EMPTY : 1;       /*!< [2]  */
        uint32_t INVALID_BUFFER_MASK : 1; /*!< [3]  */
        uint32_t ATA_IRQ : 1;          /*!< [4]  */
        uint32_t RSVD1 : 3;            /*!< [7:5]  */
        uint32_t DEV0_ERROR : 1;       /*!< [8]  */
        uint32_t DEV1_ERROR : 1;       /*!< [9]  */
        uint32_t DEV2_ERROR : 1;       /*!< [10]  */
        uint32_t DEV3_ERROR : 1;       /*!< [11]  */
        uint32_t DEV4_ERROR : 1;       /*!< [12]  */
        uint32_t DEV5_ERROR : 1;       /*!< [13]  */
        uint32_t DEV6_ERROR : 1;       /*!< [14]  */
        uint32_t DEV7_ERROR : 1;       /*!< [15]  */
        uint32_t RDY_TIMEOUT : 8;      /*!< [23:16]  */
        uint32_t READY_BUSY : 8;       /*!< [31:24]  */
    } B;
} hw_gpmi_stat_t;

/*!
 * @name Constants and macros for entire GPMI_STAT register
 */
/*@{*/
#define HW_GPMI_STAT_ADDR(x)     ((uintptr_t)(x) + 0xB0U)

#define HW_GPMI_STAT(x)          (*(__I hw_gpmi_stat_t *) HW_GPMI_STAT_ADDR(x))
#define HW_GPMI_STAT_RD(x)       (HW_GPMI_STAT(x).U)
/*@}*/

/*
 * Constants & macros for individual GPMI_STAT bitfields
 */

/*!
 * @name Register GPMI_STAT, field PRESENT[0] (RO)
 *
 * UNAVAILABLE = 0x0 GPMI is not present in this product. AVAILABLE = 0x1 GPMI
 * is present in this product.
 *
 * Values:
 * - 0 - GPMI is not present in this product.
 * - 1 - GPMI is present is in this product.
 */
/*@{*/
#define BP_GPMI_STAT_PRESENT (0U)          /*!< Bit position for GPMI_STAT_PRESENT. */
#define BM_GPMI_STAT_PRESENT (0x00000001U) /*!< Bit mask for GPMI_STAT_PRESENT. */
#define BS_GPMI_STAT_PRESENT (1U)          /*!< Bit field size in bits for GPMI_STAT_PRESENT. */

/*! @brief Read current value of the GPMI_STAT_PRESENT field. */
#define BR_GPMI_STAT_PRESENT(x) (HW_GPMI_STAT(x).B.PRESENT)
/*@}*/

/*!
 * @name Register GPMI_STAT, field FIFO_FULL[1] (RO)
 *
 * NOT_FULL = 0x0 FIFO is not full. FULL = 0x1 FIFO is full.
 *
 * Values:
 * - 0 - FIFO is not full.
 * - 1 - FIFO is full.
 */
/*@{*/
#define BP_GPMI_STAT_FIFO_FULL (1U)        /*!< Bit position for GPMI_STAT_FIFO_FULL. */
#define BM_GPMI_STAT_FIFO_FULL (0x00000002U) /*!< Bit mask for GPMI_STAT_FIFO_FULL. */
#define BS_GPMI_STAT_FIFO_FULL (1U)        /*!< Bit field size in bits for GPMI_STAT_FIFO_FULL. */

/*! @brief Read current value of the GPMI_STAT_FIFO_FULL field. */
#define BR_GPMI_STAT_FIFO_FULL(x) (HW_GPMI_STAT(x).B.FIFO_FULL)
/*@}*/

/*!
 * @name Register GPMI_STAT, field FIFO_EMPTY[2] (RO)
 *
 * NOT_EMPTY = 0x0 FIFO is not empty. EMPTY = 0x1 FIFO is empty.
 *
 * Values:
 * - 0 - FIFO is not empty.
 * - 1 - FIFO is empty.
 */
/*@{*/
#define BP_GPMI_STAT_FIFO_EMPTY (2U)       /*!< Bit position for GPMI_STAT_FIFO_EMPTY. */
#define BM_GPMI_STAT_FIFO_EMPTY (0x00000004U) /*!< Bit mask for GPMI_STAT_FIFO_EMPTY. */
#define BS_GPMI_STAT_FIFO_EMPTY (1U)       /*!< Bit field size in bits for GPMI_STAT_FIFO_EMPTY. */

/*! @brief Read current value of the GPMI_STAT_FIFO_EMPTY field. */
#define BR_GPMI_STAT_FIFO_EMPTY(x) (HW_GPMI_STAT(x).B.FIFO_EMPTY)
/*@}*/

/*!
 * @name Register GPMI_STAT, field INVALID_BUFFER_MASK[3] (RO)
 *
 * Buffer Mask Validity bit.
 *
 * Values:
 * - 0 - ECC Buffer Mask is not invalid.
 * - 1 - ECC Buffer Mask is invalid.
 */
/*@{*/
#define BP_GPMI_STAT_INVALID_BUFFER_MASK (3U) /*!< Bit position for GPMI_STAT_INVALID_BUFFER_MASK. */
#define BM_GPMI_STAT_INVALID_BUFFER_MASK (0x00000008U) /*!< Bit mask for GPMI_STAT_INVALID_BUFFER_MASK. */
#define BS_GPMI_STAT_INVALID_BUFFER_MASK (1U) /*!< Bit field size in bits for GPMI_STAT_INVALID_BUFFER_MASK. */

/*! @brief Read current value of the GPMI_STAT_INVALID_BUFFER_MASK field. */
#define BR_GPMI_STAT_INVALID_BUFFER_MASK(x) (HW_GPMI_STAT(x).B.INVALID_BUFFER_MASK)
/*@}*/

/*!
 * @name Register GPMI_STAT, field ATA_IRQ[4] (RO)
 *
 * Status of the ATA_IRQ input pin.
 */
/*@{*/
#define BP_GPMI_STAT_ATA_IRQ (4U)          /*!< Bit position for GPMI_STAT_ATA_IRQ. */
#define BM_GPMI_STAT_ATA_IRQ (0x00000010U) /*!< Bit mask for GPMI_STAT_ATA_IRQ. */
#define BS_GPMI_STAT_ATA_IRQ (1U)          /*!< Bit field size in bits for GPMI_STAT_ATA_IRQ. */

/*! @brief Read current value of the GPMI_STAT_ATA_IRQ field. */
#define BR_GPMI_STAT_ATA_IRQ(x) (HW_GPMI_STAT(x).B.ATA_IRQ)
/*@}*/

/*!
 * @name Register GPMI_STAT, field RSVD1[7:5] (RO)
 *
 * Always write zeroes to this bit field.
 */
/*@{*/
#define BP_GPMI_STAT_RSVD1   (5U)          /*!< Bit position for GPMI_STAT_RSVD1. */
#define BM_GPMI_STAT_RSVD1   (0x000000E0U) /*!< Bit mask for GPMI_STAT_RSVD1. */
#define BS_GPMI_STAT_RSVD1   (3U)          /*!< Bit field size in bits for GPMI_STAT_RSVD1. */

/*! @brief Read current value of the GPMI_STAT_RSVD1 field. */
#define BR_GPMI_STAT_RSVD1(x) (HW_GPMI_STAT(x).B.RSVD1)
/*@}*/

/*!
 * @name Register GPMI_STAT, field DEV0_ERROR[8] (RO)
 *
 * DMA channel 0 (Timeout or compare failure, depending on COMMAND_MODE).
 *
 * Values:
 * - 0 - No error condition present on ATA/NAND Device accessed by DMA channel 0.
 * - 1 - An Error has occurred on ATA/NAND Device accessed by
 */
/*@{*/
#define BP_GPMI_STAT_DEV0_ERROR (8U)       /*!< Bit position for GPMI_STAT_DEV0_ERROR. */
#define BM_GPMI_STAT_DEV0_ERROR (0x00000100U) /*!< Bit mask for GPMI_STAT_DEV0_ERROR. */
#define BS_GPMI_STAT_DEV0_ERROR (1U)       /*!< Bit field size in bits for GPMI_STAT_DEV0_ERROR. */

/*! @brief Read current value of the GPMI_STAT_DEV0_ERROR field. */
#define BR_GPMI_STAT_DEV0_ERROR(x) (HW_GPMI_STAT(x).B.DEV0_ERROR)
/*@}*/

/*!
 * @name Register GPMI_STAT, field DEV1_ERROR[9] (RO)
 *
 * DMA channel 1 (Timeout or compare failure, depending on COMMAND_MODE).
 *
 * Values:
 * - 0 - No error condition present on ATA/NAND Device accessed by DMA channel 1.
 * - 1 - An Error has occurred on ATA/NAND Device accessed by
 */
/*@{*/
#define BP_GPMI_STAT_DEV1_ERROR (9U)       /*!< Bit position for GPMI_STAT_DEV1_ERROR. */
#define BM_GPMI_STAT_DEV1_ERROR (0x00000200U) /*!< Bit mask for GPMI_STAT_DEV1_ERROR. */
#define BS_GPMI_STAT_DEV1_ERROR (1U)       /*!< Bit field size in bits for GPMI_STAT_DEV1_ERROR. */

/*! @brief Read current value of the GPMI_STAT_DEV1_ERROR field. */
#define BR_GPMI_STAT_DEV1_ERROR(x) (HW_GPMI_STAT(x).B.DEV1_ERROR)
/*@}*/

/*!
 * @name Register GPMI_STAT, field DEV2_ERROR[10] (RO)
 *
 * DMA channel 2 (Timeout or compare failure, depending on COMMAND_MODE).
 *
 * Values:
 * - 0 - No error condition present on ATA/NAND Device accessed by DMA channel 2.
 * - 1 - An Error has occurred on ATA/NAND Device accessed by
 */
/*@{*/
#define BP_GPMI_STAT_DEV2_ERROR (10U)      /*!< Bit position for GPMI_STAT_DEV2_ERROR. */
#define BM_GPMI_STAT_DEV2_ERROR (0x00000400U) /*!< Bit mask for GPMI_STAT_DEV2_ERROR. */
#define BS_GPMI_STAT_DEV2_ERROR (1U)       /*!< Bit field size in bits for GPMI_STAT_DEV2_ERROR. */

/*! @brief Read current value of the GPMI_STAT_DEV2_ERROR field. */
#define BR_GPMI_STAT_DEV2_ERROR(x) (HW_GPMI_STAT(x).B.DEV2_ERROR)
/*@}*/

/*!
 * @name Register GPMI_STAT, field DEV3_ERROR[11] (RO)
 *
 * DMA channel 3 (Timeout or compare failure, depending on COMMAND_MODE).
 *
 * Values:
 * - 0 - No error condition present on ATA/NAND Device accessed by DMA channel 3.
 * - 1 - An Error has occurred on ATA/NAND Device accessed by
 */
/*@{*/
#define BP_GPMI_STAT_DEV3_ERROR (11U)      /*!< Bit position for GPMI_STAT_DEV3_ERROR. */
#define BM_GPMI_STAT_DEV3_ERROR (0x00000800U) /*!< Bit mask for GPMI_STAT_DEV3_ERROR. */
#define BS_GPMI_STAT_DEV3_ERROR (1U)       /*!< Bit field size in bits for GPMI_STAT_DEV3_ERROR. */

/*! @brief Read current value of the GPMI_STAT_DEV3_ERROR field. */
#define BR_GPMI_STAT_DEV3_ERROR(x) (HW_GPMI_STAT(x).B.DEV3_ERROR)
/*@}*/

/*!
 * @name Register GPMI_STAT, field DEV4_ERROR[12] (RO)
 *
 * DMA channel 4 (Timeout or compare failure, depending on COMMAND_MODE).
 *
 * Values:
 * - 0 - No error condition present on ATA/NAND Device accessed by DMA channel 4.
 * - 1 - An Error has occurred on ATA/NAND Device accessed by
 */
/*@{*/
#define BP_GPMI_STAT_DEV4_ERROR (12U)      /*!< Bit position for GPMI_STAT_DEV4_ERROR. */
#define BM_GPMI_STAT_DEV4_ERROR (0x00001000U) /*!< Bit mask for GPMI_STAT_DEV4_ERROR. */
#define BS_GPMI_STAT_DEV4_ERROR (1U)       /*!< Bit field size in bits for GPMI_STAT_DEV4_ERROR. */

/*! @brief Read current value of the GPMI_STAT_DEV4_ERROR field. */
#define BR_GPMI_STAT_DEV4_ERROR(x) (HW_GPMI_STAT(x).B.DEV4_ERROR)
/*@}*/

/*!
 * @name Register GPMI_STAT, field DEV5_ERROR[13] (RO)
 *
 * DMA channel 5 (Timeout or compare failure, depending on COMMAND_MODE).
 *
 * Values:
 * - 0 - No error condition present on ATA/NAND Device accessed by DMA channel 5.
 * - 1 - An Error has occurred on ATA/NAND Device accessed by
 */
/*@{*/
#define BP_GPMI_STAT_DEV5_ERROR (13U)      /*!< Bit position for GPMI_STAT_DEV5_ERROR. */
#define BM_GPMI_STAT_DEV5_ERROR (0x00002000U) /*!< Bit mask for GPMI_STAT_DEV5_ERROR. */
#define BS_GPMI_STAT_DEV5_ERROR (1U)       /*!< Bit field size in bits for GPMI_STAT_DEV5_ERROR. */

/*! @brief Read current value of the GPMI_STAT_DEV5_ERROR field. */
#define BR_GPMI_STAT_DEV5_ERROR(x) (HW_GPMI_STAT(x).B.DEV5_ERROR)
/*@}*/

/*!
 * @name Register GPMI_STAT, field DEV6_ERROR[14] (RO)
 *
 * DMA channel 6 (Timeout or compare failure, depending on COMMAND_MODE).
 *
 * Values:
 * - 0 - No error condition present on ATA/NAND Device accessed by DMA channel 6.
 * - 1 - An Error has occurred on ATA/NAND Device accessed by
 */
/*@{*/
#define BP_GPMI_STAT_DEV6_ERROR (14U)      /*!< Bit position for GPMI_STAT_DEV6_ERROR. */
#define BM_GPMI_STAT_DEV6_ERROR (0x00004000U) /*!< Bit mask for GPMI_STAT_DEV6_ERROR. */
#define BS_GPMI_STAT_DEV6_ERROR (1U)       /*!< Bit field size in bits for GPMI_STAT_DEV6_ERROR. */

/*! @brief Read current value of the GPMI_STAT_DEV6_ERROR field. */
#define BR_GPMI_STAT_DEV6_ERROR(x) (HW_GPMI_STAT(x).B.DEV6_ERROR)
/*@}*/

/*!
 * @name Register GPMI_STAT, field DEV7_ERROR[15] (RO)
 *
 * DMA channel 7 (Timeout or compare failure, depending on COMMAND_MODE).
 *
 * Values:
 * - 0 - No error condition present on ATA/NAND Device accessed by DMA channel 7.
 * - 1 - An Error has occurred on ATA/NAND Device accessed by
 */
/*@{*/
#define BP_GPMI_STAT_DEV7_ERROR (15U)      /*!< Bit position for GPMI_STAT_DEV7_ERROR. */
#define BM_GPMI_STAT_DEV7_ERROR (0x00008000U) /*!< Bit mask for GPMI_STAT_DEV7_ERROR. */
#define BS_GPMI_STAT_DEV7_ERROR (1U)       /*!< Bit field size in bits for GPMI_STAT_DEV7_ERROR. */

/*! @brief Read current value of the GPMI_STAT_DEV7_ERROR field. */
#define BR_GPMI_STAT_DEV7_ERROR(x) (HW_GPMI_STAT(x).B.DEV7_ERROR)
/*@}*/

/*!
 * @name Register GPMI_STAT, field RDY_TIMEOUT[23:16] (RO)
 *
 * State of the RDY/BUSY Timeout Flags. When any bit is set to '1' in this
 * field, it indicates that a time out has occurred while waiting for the ready state
 * of the requested NAND device. Multiple bits may be set simultaneously. When
 * GPMI_CTRL1_DECOUPLE_CS = 0, RDY_TIMEOUT[n] is associated with the NAND device on
 * chip_select[n]. When GPMI_CTRL1_DECOUPLE_CS = 1, these flags become
 * associated to a DMA channel instead of a NAND device. For example if DMA channel 6
 * sends a WAIT_FOR_READY command for NAND Device 2, and a timeout occured on
 * READY_BUSY2, then READY_TIMEOUT[6] will be set instead of READY_TIMEOUT[2].
 */
/*@{*/
#define BP_GPMI_STAT_RDY_TIMEOUT (16U)     /*!< Bit position for GPMI_STAT_RDY_TIMEOUT. */
#define BM_GPMI_STAT_RDY_TIMEOUT (0x00FF0000U) /*!< Bit mask for GPMI_STAT_RDY_TIMEOUT. */
#define BS_GPMI_STAT_RDY_TIMEOUT (8U)      /*!< Bit field size in bits for GPMI_STAT_RDY_TIMEOUT. */

/*! @brief Read current value of the GPMI_STAT_RDY_TIMEOUT field. */
#define BR_GPMI_STAT_RDY_TIMEOUT(x) (HW_GPMI_STAT(x).B.RDY_TIMEOUT)
/*@}*/

/*!
 * @name Register GPMI_STAT, field READY_BUSY[31:24] (RO)
 *
 * Read-only view of NAND Ready_Busy Input pins.
 */
/*@{*/
#define BP_GPMI_STAT_READY_BUSY (24U)      /*!< Bit position for GPMI_STAT_READY_BUSY. */
#define BM_GPMI_STAT_READY_BUSY (0xFF000000U) /*!< Bit mask for GPMI_STAT_READY_BUSY. */
#define BS_GPMI_STAT_READY_BUSY (8U)       /*!< Bit field size in bits for GPMI_STAT_READY_BUSY. */

/*! @brief Read current value of the GPMI_STAT_READY_BUSY field. */
#define BR_GPMI_STAT_READY_BUSY(x) (HW_GPMI_STAT(x).B.READY_BUSY)
/*@}*/

/*******************************************************************************
 * HW_GPMI_DEBUG - GPMI Debug Information Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_DEBUG - GPMI Debug Information Register Description (RO)
 *
 * Reset value: 0x00000000U
 *
 * The GPMI debug information register provides a read back path for diagnostics
 * to determine the current operating state of the GPMI controller. GPMI_DEBUG
 * 0x0C0
 */
typedef union _hw_gpmi_debug
{
    uint32_t U;
    struct _hw_gpmi_debug_bitfields
    {
        uint32_t CMD_END : 8;          /*!< [7:0]  */
        uint32_t DMAREQ : 8;           /*!< [15:8]  */
        uint32_t DMA_SENSE : 8;        /*!< [23:16]  */
        uint32_t WAIT_FOR_READY_END : 8; /*!< [31:24]  */
    } B;
} hw_gpmi_debug_t;

/*!
 * @name Constants and macros for entire GPMI_DEBUG register
 */
/*@{*/
#define HW_GPMI_DEBUG_ADDR(x)    ((uintptr_t)(x) + 0xC0U)

#define HW_GPMI_DEBUG(x)         (*(__I hw_gpmi_debug_t *) HW_GPMI_DEBUG_ADDR(x))
#define HW_GPMI_DEBUG_RD(x)      (HW_GPMI_DEBUG(x).U)
/*@}*/

/*
 * Constants & macros for individual GPMI_DEBUG bitfields
 */

/*!
 * @name Register GPMI_DEBUG, field CMD_END[7:0] (RO)
 *
 * Read Only view of the Command End toggle signals to DMA. One per channel
 */
/*@{*/
#define BP_GPMI_DEBUG_CMD_END (0U)         /*!< Bit position for GPMI_DEBUG_CMD_END. */
#define BM_GPMI_DEBUG_CMD_END (0x000000FFU) /*!< Bit mask for GPMI_DEBUG_CMD_END. */
#define BS_GPMI_DEBUG_CMD_END (8U)         /*!< Bit field size in bits for GPMI_DEBUG_CMD_END. */

/*! @brief Read current value of the GPMI_DEBUG_CMD_END field. */
#define BR_GPMI_DEBUG_CMD_END(x) (HW_GPMI_DEBUG(x).B.CMD_END)
/*@}*/

/*!
 * @name Register GPMI_DEBUG, field DMAREQ[15:8] (RO)
 *
 * Read-only view of DMA request line for 8 DMA channels. A toggle on any bit
 * position indicates a DMA request for the corresponding channel.
 */
/*@{*/
#define BP_GPMI_DEBUG_DMAREQ (8U)          /*!< Bit position for GPMI_DEBUG_DMAREQ. */
#define BM_GPMI_DEBUG_DMAREQ (0x0000FF00U) /*!< Bit mask for GPMI_DEBUG_DMAREQ. */
#define BS_GPMI_DEBUG_DMAREQ (8U)          /*!< Bit field size in bits for GPMI_DEBUG_DMAREQ. */

/*! @brief Read current value of the GPMI_DEBUG_DMAREQ field. */
#define BR_GPMI_DEBUG_DMAREQ(x) (HW_GPMI_DEBUG(x).B.DMAREQ)
/*@}*/

/*!
 * @name Register GPMI_DEBUG, field DMA_SENSE[23:16] (RO)
 *
 * Read-only view of sense state of the 8 DMA channels. A value of "1" in any
 * bit position indicates that a read and compare command failed or a timeout
 * occured for the corresponding channel.
 */
/*@{*/
#define BP_GPMI_DEBUG_DMA_SENSE (16U)      /*!< Bit position for GPMI_DEBUG_DMA_SENSE. */
#define BM_GPMI_DEBUG_DMA_SENSE (0x00FF0000U) /*!< Bit mask for GPMI_DEBUG_DMA_SENSE. */
#define BS_GPMI_DEBUG_DMA_SENSE (8U)       /*!< Bit field size in bits for GPMI_DEBUG_DMA_SENSE. */

/*! @brief Read current value of the GPMI_DEBUG_DMA_SENSE field. */
#define BR_GPMI_DEBUG_DMA_SENSE(x) (HW_GPMI_DEBUG(x).B.DMA_SENSE)
/*@}*/

/*!
 * @name Register GPMI_DEBUG, field WAIT_FOR_READY_END[31:24] (RO)
 *
 * Read Only view of the Wait_For_Ready End toggle signals to DMA. One per
 * channel
 */
/*@{*/
#define BP_GPMI_DEBUG_WAIT_FOR_READY_END (24U) /*!< Bit position for GPMI_DEBUG_WAIT_FOR_READY_END. */
#define BM_GPMI_DEBUG_WAIT_FOR_READY_END (0xFF000000U) /*!< Bit mask for GPMI_DEBUG_WAIT_FOR_READY_END. */
#define BS_GPMI_DEBUG_WAIT_FOR_READY_END (8U) /*!< Bit field size in bits for GPMI_DEBUG_WAIT_FOR_READY_END. */

/*! @brief Read current value of the GPMI_DEBUG_WAIT_FOR_READY_END field. */
#define BR_GPMI_DEBUG_WAIT_FOR_READY_END(x) (HW_GPMI_DEBUG(x).B.WAIT_FOR_READY_END)
/*@}*/

/*******************************************************************************
 * HW_GPMI_VERSION - GPMI Version Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_VERSION - GPMI Version Register Description (RO)
 *
 * Reset value: 0x05020000U
 *
 * This register reflects the version number for the GPMI. GPMI_VERSION 0x0D0
 */
typedef union _hw_gpmi_version
{
    uint32_t U;
    struct _hw_gpmi_version_bitfields
    {
        uint32_t STEP : 16;            /*!< [15:0]  */
        uint32_t MINOR : 8;            /*!< [23:16]  */
        uint32_t MAJOR : 8;            /*!< [31:24]  */
    } B;
} hw_gpmi_version_t;

/*!
 * @name Constants and macros for entire GPMI_VERSION register
 */
/*@{*/
#define HW_GPMI_VERSION_ADDR(x)  ((uintptr_t)(x) + 0xD0U)

#define HW_GPMI_VERSION(x)       (*(__I hw_gpmi_version_t *) HW_GPMI_VERSION_ADDR(x))
#define HW_GPMI_VERSION_RD(x)    (HW_GPMI_VERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual GPMI_VERSION bitfields
 */

/*!
 * @name Register GPMI_VERSION, field STEP[15:0] (RO)
 *
 * Fixed read-only value reflecting the stepping of the RTL version.
 */
/*@{*/
#define BP_GPMI_VERSION_STEP (0U)          /*!< Bit position for GPMI_VERSION_STEP. */
#define BM_GPMI_VERSION_STEP (0x0000FFFFU) /*!< Bit mask for GPMI_VERSION_STEP. */
#define BS_GPMI_VERSION_STEP (16U)         /*!< Bit field size in bits for GPMI_VERSION_STEP. */

/*! @brief Read current value of the GPMI_VERSION_STEP field. */
#define BR_GPMI_VERSION_STEP(x) (HW_GPMI_VERSION(x).B.STEP)
/*@}*/

/*!
 * @name Register GPMI_VERSION, field MINOR[23:16] (RO)
 *
 * Fixed read-only value reflecting the MINOR field of the RTL version.
 */
/*@{*/
#define BP_GPMI_VERSION_MINOR (16U)        /*!< Bit position for GPMI_VERSION_MINOR. */
#define BM_GPMI_VERSION_MINOR (0x00FF0000U) /*!< Bit mask for GPMI_VERSION_MINOR. */
#define BS_GPMI_VERSION_MINOR (8U)         /*!< Bit field size in bits for GPMI_VERSION_MINOR. */

/*! @brief Read current value of the GPMI_VERSION_MINOR field. */
#define BR_GPMI_VERSION_MINOR(x) (HW_GPMI_VERSION(x).B.MINOR)
/*@}*/

/*!
 * @name Register GPMI_VERSION, field MAJOR[31:24] (RO)
 *
 * Fixed read-only value reflecting the MAJOR field of the RTL version.
 */
/*@{*/
#define BP_GPMI_VERSION_MAJOR (24U)        /*!< Bit position for GPMI_VERSION_MAJOR. */
#define BM_GPMI_VERSION_MAJOR (0xFF000000U) /*!< Bit mask for GPMI_VERSION_MAJOR. */
#define BS_GPMI_VERSION_MAJOR (8U)         /*!< Bit field size in bits for GPMI_VERSION_MAJOR. */

/*! @brief Read current value of the GPMI_VERSION_MAJOR field. */
#define BR_GPMI_VERSION_MAJOR(x) (HW_GPMI_VERSION(x).B.MAJOR)
/*@}*/

/*******************************************************************************
 * HW_GPMI_DEBUG2 - GPMI Debug2 Information Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_DEBUG2 - GPMI Debug2 Information Register Description (RW)
 *
 * Reset value: 0x0000F100U
 *
 * The GPMI Debug2 information register provides a read back path for
 * diagnostics to determine the cur­rent operating state of the GPMI controller.
 * GPMI_DEBUG2 0x0E0
 */
typedef union _hw_gpmi_debug2
{
    uint32_t U;
    struct _hw_gpmi_debug2_bitfields
    {
        uint32_t RDN_TAP : 6;          /*!< [5:0]  */
        uint32_t UPDATE_WINDOW : 1;    /*!< [6]  */
        uint32_t VIEW_DELAYED_RDN : 1; /*!< [7]  */
        uint32_t SYND2GPMI_READY : 1;  /*!< [8]  */
        uint32_t SYND2GPMI_VALID : 1;  /*!< [9]  */
        uint32_t GPMI2SYND_READY : 1;  /*!< [10]  */
        uint32_t GPMI2SYND_VALID : 1;  /*!< [11]  */
        uint32_t SYND2GPMI_BE : 4;     /*!< [15:12]  */
        uint32_t MAIN_STATE : 4;       /*!< [19:16]  */
        uint32_t PIN_STATE : 3;        /*!< [22:20]  */
        uint32_t BUSY : 1;             /*!< [23]  */
        uint32_t UDMA_STATE : 4;       /*!< [27:24]  */
        uint32_t RSVD1 : 4;            /*!< [31:28]  */
    } B;
} hw_gpmi_debug2_t;

/*!
 * @name Constants and macros for entire GPMI_DEBUG2 register
 */
/*@{*/
#define HW_GPMI_DEBUG2_ADDR(x)   ((uintptr_t)(x) + 0xE0U)

#define HW_GPMI_DEBUG2(x)        (*(__IO hw_gpmi_debug2_t *) HW_GPMI_DEBUG2_ADDR(x))
#define HW_GPMI_DEBUG2_RD(x)     (HW_GPMI_DEBUG2(x).U)
#define HW_GPMI_DEBUG2_WR(x, v)  (HW_GPMI_DEBUG2(x).U = (v))
#define HW_GPMI_DEBUG2_SET(x, v) (HW_GPMI_DEBUG2_WR(x, HW_GPMI_DEBUG2_RD(x) |  (v)))
#define HW_GPMI_DEBUG2_CLR(x, v) (HW_GPMI_DEBUG2_WR(x, HW_GPMI_DEBUG2_RD(x) & ~(v)))
#define HW_GPMI_DEBUG2_TOG(x, v) (HW_GPMI_DEBUG2_WR(x, HW_GPMI_DEBUG2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_DEBUG2 bitfields
 */

/*!
 * @name Register GPMI_DEBUG2, field RDN_TAP[5:0] (RO)
 *
 * This is the DLL tap calculated by the DLL controller. The selects the amount
 * of delay form the DLL chain.
 */
/*@{*/
#define BP_GPMI_DEBUG2_RDN_TAP (0U)        /*!< Bit position for GPMI_DEBUG2_RDN_TAP. */
#define BM_GPMI_DEBUG2_RDN_TAP (0x0000003FU) /*!< Bit mask for GPMI_DEBUG2_RDN_TAP. */
#define BS_GPMI_DEBUG2_RDN_TAP (6U)        /*!< Bit field size in bits for GPMI_DEBUG2_RDN_TAP. */

/*! @brief Read current value of the GPMI_DEBUG2_RDN_TAP field. */
#define BR_GPMI_DEBUG2_RDN_TAP(x) (HW_GPMI_DEBUG2(x).B.RDN_TAP)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field UPDATE_WINDOW[6] (RO)
 *
 * A 1 indicates that the DLL is busy generating the required delay.
 */
/*@{*/
#define BP_GPMI_DEBUG2_UPDATE_WINDOW (6U)  /*!< Bit position for GPMI_DEBUG2_UPDATE_WINDOW. */
#define BM_GPMI_DEBUG2_UPDATE_WINDOW (0x00000040U) /*!< Bit mask for GPMI_DEBUG2_UPDATE_WINDOW. */
#define BS_GPMI_DEBUG2_UPDATE_WINDOW (1U)  /*!< Bit field size in bits for GPMI_DEBUG2_UPDATE_WINDOW. */

/*! @brief Read current value of the GPMI_DEBUG2_UPDATE_WINDOW field. */
#define BR_GPMI_DEBUG2_UPDATE_WINDOW(x) (HW_GPMI_DEBUG2(x).B.UPDATE_WINDOW)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field VIEW_DELAYED_RDN[7] (RW)
 *
 * Set to a 1 to select the delayed feedback RE_B to drive the GPMI_ADDR[0]
 * (Nand CLE) pin. For debug purposes, this will allow you see if DLL is functioning
 * properly.
 */
/*@{*/
#define BP_GPMI_DEBUG2_VIEW_DELAYED_RDN (7U) /*!< Bit position for GPMI_DEBUG2_VIEW_DELAYED_RDN. */
#define BM_GPMI_DEBUG2_VIEW_DELAYED_RDN (0x00000080U) /*!< Bit mask for GPMI_DEBUG2_VIEW_DELAYED_RDN. */
#define BS_GPMI_DEBUG2_VIEW_DELAYED_RDN (1U) /*!< Bit field size in bits for GPMI_DEBUG2_VIEW_DELAYED_RDN. */

/*! @brief Read current value of the GPMI_DEBUG2_VIEW_DELAYED_RDN field. */
#define BR_GPMI_DEBUG2_VIEW_DELAYED_RDN(x) (HW_GPMI_DEBUG2(x).B.VIEW_DELAYED_RDN)

/*! @brief Format value for bitfield GPMI_DEBUG2_VIEW_DELAYED_RDN. */
#define BF_GPMI_DEBUG2_VIEW_DELAYED_RDN(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_DEBUG2_VIEW_DELAYED_RDN) & BM_GPMI_DEBUG2_VIEW_DELAYED_RDN)

/*! @brief Set the VIEW_DELAYED_RDN field to a new value. */
#define BW_GPMI_DEBUG2_VIEW_DELAYED_RDN(x, v) (HW_GPMI_DEBUG2_WR(x, (HW_GPMI_DEBUG2_RD(x) & ~BM_GPMI_DEBUG2_VIEW_DELAYED_RDN) | BF_GPMI_DEBUG2_VIEW_DELAYED_RDN(v)))
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field SYND2GPMI_READY[8] (RO)
 *
 * Data handshake Input from BCH.
 */
/*@{*/
#define BP_GPMI_DEBUG2_SYND2GPMI_READY (8U) /*!< Bit position for GPMI_DEBUG2_SYND2GPMI_READY. */
#define BM_GPMI_DEBUG2_SYND2GPMI_READY (0x00000100U) /*!< Bit mask for GPMI_DEBUG2_SYND2GPMI_READY. */
#define BS_GPMI_DEBUG2_SYND2GPMI_READY (1U) /*!< Bit field size in bits for GPMI_DEBUG2_SYND2GPMI_READY. */

/*! @brief Read current value of the GPMI_DEBUG2_SYND2GPMI_READY field. */
#define BR_GPMI_DEBUG2_SYND2GPMI_READY(x) (HW_GPMI_DEBUG2(x).B.SYND2GPMI_READY)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field SYND2GPMI_VALID[9] (RO)
 *
 * Data handshake Input from BCH.
 */
/*@{*/
#define BP_GPMI_DEBUG2_SYND2GPMI_VALID (9U) /*!< Bit position for GPMI_DEBUG2_SYND2GPMI_VALID. */
#define BM_GPMI_DEBUG2_SYND2GPMI_VALID (0x00000200U) /*!< Bit mask for GPMI_DEBUG2_SYND2GPMI_VALID. */
#define BS_GPMI_DEBUG2_SYND2GPMI_VALID (1U) /*!< Bit field size in bits for GPMI_DEBUG2_SYND2GPMI_VALID. */

/*! @brief Read current value of the GPMI_DEBUG2_SYND2GPMI_VALID field. */
#define BR_GPMI_DEBUG2_SYND2GPMI_VALID(x) (HW_GPMI_DEBUG2(x).B.SYND2GPMI_VALID)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field GPMI2SYND_READY[10] (RO)
 *
 * Data handshake output to BCH.
 */
/*@{*/
#define BP_GPMI_DEBUG2_GPMI2SYND_READY (10U) /*!< Bit position for GPMI_DEBUG2_GPMI2SYND_READY. */
#define BM_GPMI_DEBUG2_GPMI2SYND_READY (0x00000400U) /*!< Bit mask for GPMI_DEBUG2_GPMI2SYND_READY. */
#define BS_GPMI_DEBUG2_GPMI2SYND_READY (1U) /*!< Bit field size in bits for GPMI_DEBUG2_GPMI2SYND_READY. */

/*! @brief Read current value of the GPMI_DEBUG2_GPMI2SYND_READY field. */
#define BR_GPMI_DEBUG2_GPMI2SYND_READY(x) (HW_GPMI_DEBUG2(x).B.GPMI2SYND_READY)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field GPMI2SYND_VALID[11] (RO)
 *
 * Data handshake output to BCH.
 */
/*@{*/
#define BP_GPMI_DEBUG2_GPMI2SYND_VALID (11U) /*!< Bit position for GPMI_DEBUG2_GPMI2SYND_VALID. */
#define BM_GPMI_DEBUG2_GPMI2SYND_VALID (0x00000800U) /*!< Bit mask for GPMI_DEBUG2_GPMI2SYND_VALID. */
#define BS_GPMI_DEBUG2_GPMI2SYND_VALID (1U) /*!< Bit field size in bits for GPMI_DEBUG2_GPMI2SYND_VALID. */

/*! @brief Read current value of the GPMI_DEBUG2_GPMI2SYND_VALID field. */
#define BR_GPMI_DEBUG2_GPMI2SYND_VALID(x) (HW_GPMI_DEBUG2(x).B.GPMI2SYND_VALID)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field SYND2GPMI_BE[15:12] (RO)
 *
 * Data byte enable Input from BCH.
 */
/*@{*/
#define BP_GPMI_DEBUG2_SYND2GPMI_BE (12U)  /*!< Bit position for GPMI_DEBUG2_SYND2GPMI_BE. */
#define BM_GPMI_DEBUG2_SYND2GPMI_BE (0x0000F000U) /*!< Bit mask for GPMI_DEBUG2_SYND2GPMI_BE. */
#define BS_GPMI_DEBUG2_SYND2GPMI_BE (4U)   /*!< Bit field size in bits for GPMI_DEBUG2_SYND2GPMI_BE. */

/*! @brief Read current value of the GPMI_DEBUG2_SYND2GPMI_BE field. */
#define BR_GPMI_DEBUG2_SYND2GPMI_BE(x) (HW_GPMI_DEBUG2(x).B.SYND2GPMI_BE)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field MAIN_STATE[19:16] (RO)
 *
 * parameter MSM_IDLE = 4'h0, MSM_BYTCNT = 4'h1, MSM_WAITFE = 4'h2, MSM_WAITFR =
 * 4'h3, MSM_DMAREQ = 4'h4, MSM_DMAACK = 4'h5, MSM_WAITFF = 4'h6, MSM_LDFIFO =
 * 4'h7, MSM_LDDMAR = 4'h8, MSM_RDCMP = 4'h9, MSM_DONE = 4'hA. MSM_IDLE = 0x0
 * MSM_BYTCNT = 0x1 MSM_WAITFE = 0x2 MSM_WAITFR = 0x3 MSM_DMAREQ = 0x4 MSM_DMAACK =
 * 0x5 MSM_WAITFF = 0x6 MSM_LDFIFO = 0x7 MSM_LDDMAR = 0x8 MSM_RDCMP = 0x9 MSM_DONE
 * = 0xA
 */
/*@{*/
#define BP_GPMI_DEBUG2_MAIN_STATE (16U)    /*!< Bit position for GPMI_DEBUG2_MAIN_STATE. */
#define BM_GPMI_DEBUG2_MAIN_STATE (0x000F0000U) /*!< Bit mask for GPMI_DEBUG2_MAIN_STATE. */
#define BS_GPMI_DEBUG2_MAIN_STATE (4U)     /*!< Bit field size in bits for GPMI_DEBUG2_MAIN_STATE. */

/*! @brief Read current value of the GPMI_DEBUG2_MAIN_STATE field. */
#define BR_GPMI_DEBUG2_MAIN_STATE(x) (HW_GPMI_DEBUG2(x).B.MAIN_STATE)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field PIN_STATE[22:20] (RO)
 *
 * parameter PSM_IDLE = 3'h0, PSM_BYTCNT = 3'h1, PSM_ADDR = 3'h2, PSM_STALL =
 * 3'h3, PSM_STROBE = 3'h4, PSM_ATARDY = 3'h5, PSM_DHOLD = 3'h6, PSM_DONE = 3'h7.
 * PSM_IDLE = 0x0 PSM_BYTCNT = 0x1 PSM_ADDR = 0x2 PSM_STALL = 0x3 PSM_STROBE = 0x4
 * PSM_ATARDY = 0x5 PSM_DHOLD = 0x6 PSM_DONE = 0x7
 */
/*@{*/
#define BP_GPMI_DEBUG2_PIN_STATE (20U)     /*!< Bit position for GPMI_DEBUG2_PIN_STATE. */
#define BM_GPMI_DEBUG2_PIN_STATE (0x00700000U) /*!< Bit mask for GPMI_DEBUG2_PIN_STATE. */
#define BS_GPMI_DEBUG2_PIN_STATE (3U)      /*!< Bit field size in bits for GPMI_DEBUG2_PIN_STATE. */

/*! @brief Read current value of the GPMI_DEBUG2_PIN_STATE field. */
#define BR_GPMI_DEBUG2_PIN_STATE(x) (HW_GPMI_DEBUG2(x).B.PIN_STATE)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field BUSY[23] (RO)
 *
 * When asserted the GPMI is busy. Undefined results may occur if any registers
 * are written when BUSY is asserted. DISABLED = 0x0 The GPMI is not busy.
 * ENABLED = 0x1 The GPMI is busy.
 */
/*@{*/
#define BP_GPMI_DEBUG2_BUSY  (23U)         /*!< Bit position for GPMI_DEBUG2_BUSY. */
#define BM_GPMI_DEBUG2_BUSY  (0x00800000U) /*!< Bit mask for GPMI_DEBUG2_BUSY. */
#define BS_GPMI_DEBUG2_BUSY  (1U)          /*!< Bit field size in bits for GPMI_DEBUG2_BUSY. */

/*! @brief Read current value of the GPMI_DEBUG2_BUSY field. */
#define BR_GPMI_DEBUG2_BUSY(x) (HW_GPMI_DEBUG2(x).B.BUSY)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field UDMA_STATE[27:24] (RO)
 *
 * USM_IDLE = 4'h0, idle USM_DMARQ = 4'h1, DMA req USM_ACK = 4'h2, DMA ACK
 * USM_FIFO_E = 4'h3, Fifo empty USM_WPAUSE = 4'h4, WR DMA Paused by device USM_TSTRB
 * = 4'h5, Toggle HSTROBE USM_CAPTUR = 4'h6, Capture Stage, (data sampled with
 * DSTROBE is valid) USM_DATOUT = 4'h7, Change Burst DATAOUT USM_CRC = 4'h8, Source
 * CRC to Device USM_WAIT_R = 4'h9, Waiting for DDMARDY- USM_END = 4'ha; Negate
 * DMAACK (end of DMA) USM_WAIT_S = 4'hb, Waiting for DSTROBE USM_RPAUSE = 4'hc,
 * Rd DMA Paused by Host USM_RSTOP = 4'hd, Rd DMA Stopped by Host USM_WTERM =
 * 4'he, Wr DMA Termination State USM_RTERM = 4'hf, Rd DMA Termination state
 */
/*@{*/
#define BP_GPMI_DEBUG2_UDMA_STATE (24U)    /*!< Bit position for GPMI_DEBUG2_UDMA_STATE. */
#define BM_GPMI_DEBUG2_UDMA_STATE (0x0F000000U) /*!< Bit mask for GPMI_DEBUG2_UDMA_STATE. */
#define BS_GPMI_DEBUG2_UDMA_STATE (4U)     /*!< Bit field size in bits for GPMI_DEBUG2_UDMA_STATE. */

/*! @brief Read current value of the GPMI_DEBUG2_UDMA_STATE field. */
#define BR_GPMI_DEBUG2_UDMA_STATE(x) (HW_GPMI_DEBUG2(x).B.UDMA_STATE)
/*@}*/

/*!
 * @name Register GPMI_DEBUG2, field RSVD1[31:28] (RW)
 *
 * Always write zeroes to this bit field.
 */
/*@{*/
#define BP_GPMI_DEBUG2_RSVD1 (28U)         /*!< Bit position for GPMI_DEBUG2_RSVD1. */
#define BM_GPMI_DEBUG2_RSVD1 (0xF0000000U) /*!< Bit mask for GPMI_DEBUG2_RSVD1. */
#define BS_GPMI_DEBUG2_RSVD1 (4U)          /*!< Bit field size in bits for GPMI_DEBUG2_RSVD1. */

/*! @brief Read current value of the GPMI_DEBUG2_RSVD1 field. */
#define BR_GPMI_DEBUG2_RSVD1(x) (HW_GPMI_DEBUG2(x).B.RSVD1)

/*! @brief Format value for bitfield GPMI_DEBUG2_RSVD1. */
#define BF_GPMI_DEBUG2_RSVD1(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_DEBUG2_RSVD1) & BM_GPMI_DEBUG2_RSVD1)

/*! @brief Set the RSVD1 field to a new value. */
#define BW_GPMI_DEBUG2_RSVD1(x, v) (HW_GPMI_DEBUG2_WR(x, (HW_GPMI_DEBUG2_RD(x) & ~BM_GPMI_DEBUG2_RSVD1) | BF_GPMI_DEBUG2_RSVD1(v)))
/*@}*/

/*******************************************************************************
 * HW_GPMI_DEBUG3 - GPMI Debug3 Information Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_DEBUG3 - GPMI Debug3 Information Register Description (RO)
 *
 * Reset value: 0x00000000U
 *
 * The GPMI Debug3 information register provides a read back path for
 * diagnostics to determine the cur­rent operating state of the GPMI controller.
 * GPMI_DEBUG3 0x0F0
 */
typedef union _hw_gpmi_debug3
{
    uint32_t U;
    struct _hw_gpmi_debug3_bitfields
    {
        uint32_t DEV_WORD_CNTR : 16;   /*!< [15:0]  */
        uint32_t APB_WORD_CNTR : 16;   /*!< [31:16]  */
    } B;
} hw_gpmi_debug3_t;

/*!
 * @name Constants and macros for entire GPMI_DEBUG3 register
 */
/*@{*/
#define HW_GPMI_DEBUG3_ADDR(x)   ((uintptr_t)(x) + 0xF0U)

#define HW_GPMI_DEBUG3(x)        (*(__I hw_gpmi_debug3_t *) HW_GPMI_DEBUG3_ADDR(x))
#define HW_GPMI_DEBUG3_RD(x)     (HW_GPMI_DEBUG3(x).U)
/*@}*/

/*
 * Constants & macros for individual GPMI_DEBUG3 bitfields
 */

/*!
 * @name Register GPMI_DEBUG3, field DEV_WORD_CNTR[15:0] (RO)
 *
 * Reflects the number of bytes remains to be transferred on the ATA/Nand bus.
 */
/*@{*/
#define BP_GPMI_DEBUG3_DEV_WORD_CNTR (0U)  /*!< Bit position for GPMI_DEBUG3_DEV_WORD_CNTR. */
#define BM_GPMI_DEBUG3_DEV_WORD_CNTR (0x0000FFFFU) /*!< Bit mask for GPMI_DEBUG3_DEV_WORD_CNTR. */
#define BS_GPMI_DEBUG3_DEV_WORD_CNTR (16U) /*!< Bit field size in bits for GPMI_DEBUG3_DEV_WORD_CNTR. */

/*! @brief Read current value of the GPMI_DEBUG3_DEV_WORD_CNTR field. */
#define BR_GPMI_DEBUG3_DEV_WORD_CNTR(x) (HW_GPMI_DEBUG3(x).B.DEV_WORD_CNTR)
/*@}*/

/*!
 * @name Register GPMI_DEBUG3, field APB_WORD_CNTR[31:16] (RO)
 *
 * Reflects the number of bytes remains to be transferred on the APB bus.
 */
/*@{*/
#define BP_GPMI_DEBUG3_APB_WORD_CNTR (16U) /*!< Bit position for GPMI_DEBUG3_APB_WORD_CNTR. */
#define BM_GPMI_DEBUG3_APB_WORD_CNTR (0xFFFF0000U) /*!< Bit mask for GPMI_DEBUG3_APB_WORD_CNTR. */
#define BS_GPMI_DEBUG3_APB_WORD_CNTR (16U) /*!< Bit field size in bits for GPMI_DEBUG3_APB_WORD_CNTR. */

/*! @brief Read current value of the GPMI_DEBUG3_APB_WORD_CNTR field. */
#define BR_GPMI_DEBUG3_APB_WORD_CNTR(x) (HW_GPMI_DEBUG3(x).B.APB_WORD_CNTR)
/*@}*/

/*******************************************************************************
 * HW_GPMI_READ_DDR_DLL_CTRL - GPMI Double Rate Read DLL Control Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_READ_DDR_DLL_CTRL - GPMI Double Rate Read DLL Control Register Description (RW)
 *
 * Reset value: 0x00000038U
 *
 * GPMI DDR Read Delay Loop Lock Control Register. This register provides
 * programmability in DDR mode for data input timing and data formats.
 * GPMI_READ_DDR_DLL_CTRL 0x100
 */
typedef union _hw_gpmi_read_ddr_dll_ctrl
{
    uint32_t U;
    struct _hw_gpmi_read_ddr_dll_ctrl_bitfields
    {
        uint32_t ENABLE : 1;           /*!< [0]  */
        uint32_t RESET : 1;            /*!< [1]  */
        uint32_t SLV_FORCE_UPD : 1;    /*!< [2]  */
        uint32_t SLV_DLY_TARGET : 4;   /*!< [6:3]  */
        uint32_t GATE_UPDATE : 1;      /*!< [7]  */
        uint32_t REFCLK_ON : 1;        /*!< [8]  */
        uint32_t SLV_OVERRIDE : 1;     /*!< [9]  */
        uint32_t SLV_OVERRIDE_VAL : 8; /*!< [17:10]  */
        uint32_t RSVD1 : 2;            /*!< [19:18]  */
        uint32_t SLV_UPDATE_INT : 8;   /*!< [27:20]  */
        uint32_t REF_UPDATE_INT : 4;   /*!< [31:28]  */
    } B;
} hw_gpmi_read_ddr_dll_ctrl_t;

/*!
 * @name Constants and macros for entire GPMI_READ_DDR_DLL_CTRL register
 */
/*@{*/
#define HW_GPMI_READ_DDR_DLL_CTRL_ADDR(x) ((uintptr_t)(x) + 0x100U)

#define HW_GPMI_READ_DDR_DLL_CTRL(x) (*(__IO hw_gpmi_read_ddr_dll_ctrl_t *) HW_GPMI_READ_DDR_DLL_CTRL_ADDR(x))
#define HW_GPMI_READ_DDR_DLL_CTRL_RD(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).U)
#define HW_GPMI_READ_DDR_DLL_CTRL_WR(x, v) (HW_GPMI_READ_DDR_DLL_CTRL(x).U = (v))
#define HW_GPMI_READ_DDR_DLL_CTRL_SET(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, HW_GPMI_READ_DDR_DLL_CTRL_RD(x) |  (v)))
#define HW_GPMI_READ_DDR_DLL_CTRL_CLR(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~(v)))
#define HW_GPMI_READ_DDR_DLL_CTRL_TOG(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, HW_GPMI_READ_DDR_DLL_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_READ_DDR_DLL_CTRL bitfields
 */

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field ENABLE[0] (RW)
 *
 * Set this bit to 1 to enable the DLL and delay chain; otherwise; set to 0 to
 * bypasses DLL. Note that using the slave delay line override feature with
 * SLV_OVERRIDE and SLV_OVERRIDE VAL, the DLL does not need to be enabled.
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_ENABLE (0U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_ENABLE. */
#define BM_GPMI_READ_DDR_DLL_CTRL_ENABLE (0x00000001U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_ENABLE. */
#define BS_GPMI_READ_DDR_DLL_CTRL_ENABLE (1U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_ENABLE. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_ENABLE field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_ENABLE(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.ENABLE)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_ENABLE. */
#define BF_GPMI_READ_DDR_DLL_CTRL_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_ENABLE) & BM_GPMI_READ_DDR_DLL_CTRL_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_ENABLE(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_ENABLE) | BF_GPMI_READ_DDR_DLL_CTRL_ENABLE(v)))
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field RESET[1] (RW)
 *
 * Setting this bit to 1 force a reset on DLL. This will cause the DLL to lose
 * lock and re-calibrate to detect an GPMICLK half period phase shift. This signal
 * is used by the DLL as edge-sensitive, so in order to create a subsequent
 * reset, RESET must be taken low and then asserted again.
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_RESET (1U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_RESET. */
#define BM_GPMI_READ_DDR_DLL_CTRL_RESET (0x00000002U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_RESET. */
#define BS_GPMI_READ_DDR_DLL_CTRL_RESET (1U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_RESET. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_RESET field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_RESET(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.RESET)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_RESET. */
#define BF_GPMI_READ_DDR_DLL_CTRL_RESET(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_RESET) & BM_GPMI_READ_DDR_DLL_CTRL_RESET)

/*! @brief Set the RESET field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_RESET(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_RESET) | BF_GPMI_READ_DDR_DLL_CTRL_RESET(v)))
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field SLV_FORCE_UPD[2] (RW)
 *
 * Setting this bit to 1, forces the slave delay line to update to the DLL
 * calibrated value immediately. The slave delay line shall update automatically based
 * on the SLV_UPDATE_INT interval or when a DLL lock condition is sensed.
 * Subsequent forcing of the slave-line update can only occur if SLV_FORCE_UP is set
 * back to 0 and then asserted again (edge triggered).
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD (2U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD. */
#define BM_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD (0x00000004U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD. */
#define BS_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD (1U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.SLV_FORCE_UPD)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD. */
#define BF_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD) & BM_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD)

/*! @brief Set the SLV_FORCE_UPD field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD) | BF_GPMI_READ_DDR_DLL_CTRL_SLV_FORCE_UPD(v)))
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field SLV_DLY_TARGET[6:3] (RW)
 *
 * The delay target for the read clock is can be programmed in 1/16th increments
 * of an GPMICLK half-period. So the input read-clock can be delayed relative
 * input data from (GPMICLK/2)/16 to GPMICLK/2.
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET (3U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET. */
#define BM_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET (0x00000078U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET. */
#define BS_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET (4U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.SLV_DLY_TARGET)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET. */
#define BF_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET) & BM_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET)

/*! @brief Set the SLV_DLY_TARGET field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET) | BF_GPMI_READ_DDR_DLL_CTRL_SLV_DLY_TARGET(v)))
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field GATE_UPDATE[7] (RW)
 *
 * Setting this bit to 1, forces the slave delay line not update
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE (7U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE. */
#define BM_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE (0x00000080U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE. */
#define BS_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE (1U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.GATE_UPDATE)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE. */
#define BF_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE) & BM_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE)

/*! @brief Set the GATE_UPDATE field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE) | BF_GPMI_READ_DDR_DLL_CTRL_GATE_UPDATE(v)))
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field REFCLK_ON[8] (RW)
 *
 * set this bit to 1 will turn on the reference clock
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON (8U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_REFCLK_ON. */
#define BM_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON (0x00000100U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_REFCLK_ON. */
#define BS_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON (1U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_REFCLK_ON. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_REFCLK_ON field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.REFCLK_ON)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_REFCLK_ON. */
#define BF_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON) & BM_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON)

/*! @brief Set the REFCLK_ON field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON) | BF_GPMI_READ_DDR_DLL_CTRL_REFCLK_ON(v)))
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field SLV_OVERRIDE[9] (RW)
 *
 * Set this bit to 1 to Enable manual override for slave delay chain using
 * SLV_OVERRIDE_VAL; to set 0 to disable manual override. This feature does not
 * require the DLL to tbe enabled using the ENABLE bit. In fact to reduce power, if
 * SLV_OVERRIDE is used, it is recommended to disable the DLL with ENABLE=0
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE (9U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE. */
#define BM_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE (0x00000200U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE. */
#define BS_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE (1U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.SLV_OVERRIDE)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE. */
#define BF_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE) & BM_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE)

/*! @brief Set the SLV_OVERRIDE field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE) | BF_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field SLV_OVERRIDE_VAL[17:10] (RW)
 *
 * When SLV_OVERRIDE=1 This field is used to select 1 of 256 physical taps
 * manually. A value of 0 selects tap 1, and a value of 0x7f selects tap 256.
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL (10U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BM_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL (0x0003FC00U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BS_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL (8U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.SLV_OVERRIDE_VAL)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BF_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL) & BM_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL)

/*! @brief Set the SLV_OVERRIDE_VAL field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL) | BF_GPMI_READ_DDR_DLL_CTRL_SLV_OVERRIDE_VAL(v)))
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field RSVD1[19:18] (RO)
 *
 * Reserved
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_RSVD1 (18U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_RSVD1. */
#define BM_GPMI_READ_DDR_DLL_CTRL_RSVD1 (0x000C0000U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_RSVD1. */
#define BS_GPMI_READ_DDR_DLL_CTRL_RSVD1 (2U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_RSVD1. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_RSVD1 field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_RSVD1(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.RSVD1)
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field SLV_UPDATE_INT[27:20] (RW)
 *
 * Setting a value greater than 0 in this field, shall over-ride the default
 * slave delay-line update interval of 256 GPMICLK cycles. A value of 0 results in
 * an update interval of 256 GPMICLK cycles (default setting). A value of 0x0f
 * results in 15 cycles and so on. Note that software can always cause an update of
 * the slave-delay line using the SLV_FORCE_UPDATE register. Note that the slave
 * delay line will also update automatically when the reference DLL transitions
 * to a locked state (from an un-locked state).
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT (20U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT. */
#define BM_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT (0x0FF00000U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT. */
#define BS_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT (8U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.SLV_UPDATE_INT)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT. */
#define BF_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT) & BM_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT)

/*! @brief Set the SLV_UPDATE_INT field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT) | BF_GPMI_READ_DDR_DLL_CTRL_SLV_UPDATE_INT(v)))
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_CTRL, field REF_UPDATE_INT[31:28] (RW)
 *
 * This field allows the user to add additional delay cycles to the DLL control
 * loop (reference delay line control). By default, the DLL control loop shall
 * update every two GPMICLK cycles. Programming this field results in a DLL control
 * loop update interval of (2 + REF_UPDATE_INT) * GPMICLK. It should be noted
 * that increasing the reference delay-line update interval reduces the ability of
 * the DLL to adjust to fast changes in conditions that may effect the delay
 * (such as voltage and temperature)
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT (28U) /*!< Bit position for GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT. */
#define BM_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT (0xF0000000U) /*!< Bit mask for GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT. */
#define BS_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT (4U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT field. */
#define BR_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT(x) (HW_GPMI_READ_DDR_DLL_CTRL(x).B.REF_UPDATE_INT)

/*! @brief Format value for bitfield GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT. */
#define BF_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT) & BM_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT)

/*! @brief Set the REF_UPDATE_INT field to a new value. */
#define BW_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT(x, v) (HW_GPMI_READ_DDR_DLL_CTRL_WR(x, (HW_GPMI_READ_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT) | BF_GPMI_READ_DDR_DLL_CTRL_REF_UPDATE_INT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPMI_WRITE_DDR_DLL_CTRL - GPMI Double Rate Write DLL Control Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_WRITE_DDR_DLL_CTRL - GPMI Double Rate Write DLL Control Register Description (RW)
 *
 * Reset value: 0x00000038U
 *
 * GPMI DDR Write Delay Loop Lock Control Register. This register provides
 * programmability in DDR mode for data output timing and data formats.
 * GPMI_WRITE_DDR_DLL_CTRL 0x110
 */
typedef union _hw_gpmi_write_ddr_dll_ctrl
{
    uint32_t U;
    struct _hw_gpmi_write_ddr_dll_ctrl_bitfields
    {
        uint32_t ENABLE : 1;           /*!< [0]  */
        uint32_t RESET : 1;            /*!< [1]  */
        uint32_t SLV_FORCE_UPD : 1;    /*!< [2]  */
        uint32_t SLV_DLY_TARGET : 4;   /*!< [6:3]  */
        uint32_t GATE_UPDATE : 1;      /*!< [7]  */
        uint32_t REFCLK_ON : 1;        /*!< [8]  */
        uint32_t SLV_OVERRIDE : 1;     /*!< [9]  */
        uint32_t SLV_OVERRIDE_VAL : 8; /*!< [17:10]  */
        uint32_t RSVD1 : 2;            /*!< [19:18]  */
        uint32_t SLV_UPDATE_INT : 8;   /*!< [27:20]  */
        uint32_t REF_UPDATE_INT : 4;   /*!< [31:28]  */
    } B;
} hw_gpmi_write_ddr_dll_ctrl_t;

/*!
 * @name Constants and macros for entire GPMI_WRITE_DDR_DLL_CTRL register
 */
/*@{*/
#define HW_GPMI_WRITE_DDR_DLL_CTRL_ADDR(x) ((uintptr_t)(x) + 0x110U)

#define HW_GPMI_WRITE_DDR_DLL_CTRL(x) (*(__IO hw_gpmi_write_ddr_dll_ctrl_t *) HW_GPMI_WRITE_DDR_DLL_CTRL_ADDR(x))
#define HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).U)
#define HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).U = (v))
#define HW_GPMI_WRITE_DDR_DLL_CTRL_SET(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) |  (v)))
#define HW_GPMI_WRITE_DDR_DLL_CTRL_CLR(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~(v)))
#define HW_GPMI_WRITE_DDR_DLL_CTRL_TOG(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPMI_WRITE_DDR_DLL_CTRL bitfields
 */

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field ENABLE[0] (RW)
 *
 * Set this bit to 1 to enable the DLL and delay chain; otherwise; set to 0 to
 * bypasses DLL. Note that using the slave delay line override feature with
 * SLV_OVERRIDE and SLV_OVERRIDE VAL, the DLL does not need to be enabled.
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_ENABLE (0U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_ENABLE. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_ENABLE (0x00000001U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_ENABLE. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_ENABLE (1U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_ENABLE. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_ENABLE field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_ENABLE(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.ENABLE)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_ENABLE. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_ENABLE) & BM_GPMI_WRITE_DDR_DLL_CTRL_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_ENABLE(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_ENABLE) | BF_GPMI_WRITE_DDR_DLL_CTRL_ENABLE(v)))
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field RESET[1] (RW)
 *
 * Setting this bit to 1 force a reset on DLL. This will cause the DLL to lose
 * lock and re-calibrate to detect an GPMICLK half period phase shift. This signal
 * is used by the DLL as edge-sensitive, so in order to create a subsequent
 * reset, RESET must be taken low and then asserted again.
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_RESET (1U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_RESET. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_RESET (0x00000002U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_RESET. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_RESET (1U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_RESET. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_RESET field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_RESET(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.RESET)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_RESET. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_RESET(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_RESET) & BM_GPMI_WRITE_DDR_DLL_CTRL_RESET)

/*! @brief Set the RESET field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_RESET(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_RESET) | BF_GPMI_WRITE_DDR_DLL_CTRL_RESET(v)))
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field SLV_FORCE_UPD[2] (RW)
 *
 * Setting this bit to 1, forces the slave delay line to update to the DLL
 * calibrated value immediately. The slave delay line shall update automatically based
 * on the SLV_UPDATE_INT interval or when a DLL lock condition is sensed.
 * Subsequent forcing of the slave-line update can only occur if SLV_FORCE_UP is set
 * back to 0 and then asserted again (edge triggered).
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD (2U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD (0x00000004U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD (1U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.SLV_FORCE_UPD)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD) & BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD)

/*! @brief Set the SLV_FORCE_UPD field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD) | BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_FORCE_UPD(v)))
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field SLV_DLY_TARGET[6:3] (RW)
 *
 * The delay target for the read clock can be programmed in 1/16th increments of
 * an GPMICLK half-period. So the input read-clock can be delayed relative input
 * data from (GPMICLK/2)/16 to GPMICLK/2.
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET (3U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET (0x00000078U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET (4U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.SLV_DLY_TARGET)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET) & BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET)

/*! @brief Set the SLV_DLY_TARGET field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET) | BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_DLY_TARGET(v)))
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field GATE_UPDATE[7] (RW)
 *
 * Setting this bit to 1, forces the slave delay line not update
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE (7U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE (0x00000080U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE (1U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.GATE_UPDATE)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE) & BM_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE)

/*! @brief Set the GATE_UPDATE field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE) | BF_GPMI_WRITE_DDR_DLL_CTRL_GATE_UPDATE(v)))
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field REFCLK_ON[8] (RW)
 *
 * set this bit to 1 will turn on the reference clock
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON (8U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON (0x00000100U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON (1U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.REFCLK_ON)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON) & BM_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON)

/*! @brief Set the REFCLK_ON field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON) | BF_GPMI_WRITE_DDR_DLL_CTRL_REFCLK_ON(v)))
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field SLV_OVERRIDE[9] (RW)
 *
 * Set this bit to 1 to Enable manual override for slave delay chain using
 * SLV_OVERRIDE_VAL; to set 0 to disable manual override. This feature does not
 * require the DLL to tbe enabled using the ENABLE bit. In fact to reduce power, if
 * SLV_OVERRIDE is used, it is recommended to disable the DLL with ENABLE=0
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE (9U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE (0x00000200U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE (1U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.SLV_OVERRIDE)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE) & BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE)

/*! @brief Set the SLV_OVERRIDE field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE) | BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field SLV_OVERRIDE_VAL[17:10] (RW)
 *
 * When SLV_OVERRIDE=1 This field is used to select 1 of 256 physical taps
 * manually. A value of 0 selects tap 1, and a value of 0x7f selects tap 256.
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL (10U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL (0x0003FC00U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL (8U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.SLV_OVERRIDE_VAL)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL) & BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL)

/*! @brief Set the SLV_OVERRIDE_VAL field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL) | BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_OVERRIDE_VAL(v)))
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field RSVD1[19:18] (RO)
 *
 * Reserved
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_RSVD1 (18U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_RSVD1. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_RSVD1 (0x000C0000U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_RSVD1. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_RSVD1 (2U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_RSVD1. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_RSVD1 field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_RSVD1(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.RSVD1)
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field SLV_UPDATE_INT[27:20] (RW)
 *
 * Setting a value greater than 0 in this field, shall over-ride the default
 * slave delay-line update interval of 256 GPMICLK cycles. A value of 0 results in
 * an update interval of 256 GPMICLK cycles (default setting). A value of 0x0f
 * results in 15 cycles and so on. Note that software can always cause an update of
 * the slave-delay line using the SLV_FORCE_UPDATE register. Note that the slave
 * delay line will also update automatically when the reference DLL transitions
 * to a locked state (from an un-locked state).
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT (20U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT (0x0FF00000U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT (8U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.SLV_UPDATE_INT)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT) & BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT)

/*! @brief Set the SLV_UPDATE_INT field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT) | BF_GPMI_WRITE_DDR_DLL_CTRL_SLV_UPDATE_INT(v)))
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_CTRL, field REF_UPDATE_INT[31:28] (RW)
 *
 * This field allows the user to add additional delay cycles to the DLL control
 * loop (reference delay line control). By default, the DLL control loop shall
 * update every two GPMICLK cycles. Programming this field results in a DLL control
 * loop update interval of (2 + REF_UPDATE_INT) * GPMICLK. It should be noted
 * that increasing the reference delay-line update interval reduces the ability of
 * the DLL to adjust to fast changes in conditions that may effect the delay
 * (such as voltage and temperature)
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT (28U) /*!< Bit position for GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT. */
#define BM_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT (0xF0000000U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT. */
#define BS_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT (4U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT field. */
#define BR_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT(x) (HW_GPMI_WRITE_DDR_DLL_CTRL(x).B.REF_UPDATE_INT)

/*! @brief Format value for bitfield GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT. */
#define BF_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT(v) ((uint32_t)((uint32_t)(v) << BP_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT) & BM_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT)

/*! @brief Set the REF_UPDATE_INT field to a new value. */
#define BW_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT(x, v) (HW_GPMI_WRITE_DDR_DLL_CTRL_WR(x, (HW_GPMI_WRITE_DDR_DLL_CTRL_RD(x) & ~BM_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT) | BF_GPMI_WRITE_DDR_DLL_CTRL_REF_UPDATE_INT(v)))
/*@}*/

/*******************************************************************************
 * HW_GPMI_READ_DDR_DLL_STS - GPMI Double Rate Read DLL Status Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_READ_DDR_DLL_STS - GPMI Double Rate Read DLL Status Register Description (RO)
 *
 * Reset value: 0x00000000U
 *
 * GPMI Double Rate Read DLL Status Register, Read Only. GPMI DLL status fields
 * are provided in this register. GPMI_READ_DDR_DLL_STS 0x120
 */
typedef union _hw_gpmi_read_ddr_dll_sts
{
    uint32_t U;
    struct _hw_gpmi_read_ddr_dll_sts_bitfields
    {
        uint32_t SLV_LOCK : 1;         /*!< [0]  */
        uint32_t SLV_SEL : 8;          /*!< [8:1]  */
        uint32_t RSVD0 : 7;            /*!< [15:9]  */
        uint32_t REF_LOCK : 1;         /*!< [16]  */
        uint32_t REF_SEL : 8;          /*!< [24:17]  */
        uint32_t RSVD1 : 7;            /*!< [31:25]  */
    } B;
} hw_gpmi_read_ddr_dll_sts_t;

/*!
 * @name Constants and macros for entire GPMI_READ_DDR_DLL_STS register
 */
/*@{*/
#define HW_GPMI_READ_DDR_DLL_STS_ADDR(x) ((uintptr_t)(x) + 0x120U)

#define HW_GPMI_READ_DDR_DLL_STS(x) (*(__I hw_gpmi_read_ddr_dll_sts_t *) HW_GPMI_READ_DDR_DLL_STS_ADDR(x))
#define HW_GPMI_READ_DDR_DLL_STS_RD(x) (HW_GPMI_READ_DDR_DLL_STS(x).U)
/*@}*/

/*
 * Constants & macros for individual GPMI_READ_DDR_DLL_STS bitfields
 */

/*!
 * @name Register GPMI_READ_DDR_DLL_STS, field SLV_LOCK[0] (RO)
 *
 * Slave delay-line lock status. This signifies that a valid calibration has
 * been set to the slave-delay line and that the slave-delay line is implementing
 * the programmed delay value.
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_STS_SLV_LOCK (0U) /*!< Bit position for GPMI_READ_DDR_DLL_STS_SLV_LOCK. */
#define BM_GPMI_READ_DDR_DLL_STS_SLV_LOCK (0x00000001U) /*!< Bit mask for GPMI_READ_DDR_DLL_STS_SLV_LOCK. */
#define BS_GPMI_READ_DDR_DLL_STS_SLV_LOCK (1U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_STS_SLV_LOCK. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_STS_SLV_LOCK field. */
#define BR_GPMI_READ_DDR_DLL_STS_SLV_LOCK(x) (HW_GPMI_READ_DDR_DLL_STS(x).B.SLV_LOCK)
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_STS, field SLV_SEL[8:1] (RO)
 *
 * Slave delay line select status
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_STS_SLV_SEL (1U) /*!< Bit position for GPMI_READ_DDR_DLL_STS_SLV_SEL. */
#define BM_GPMI_READ_DDR_DLL_STS_SLV_SEL (0x000001FEU) /*!< Bit mask for GPMI_READ_DDR_DLL_STS_SLV_SEL. */
#define BS_GPMI_READ_DDR_DLL_STS_SLV_SEL (8U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_STS_SLV_SEL. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_STS_SLV_SEL field. */
#define BR_GPMI_READ_DDR_DLL_STS_SLV_SEL(x) (HW_GPMI_READ_DDR_DLL_STS(x).B.SLV_SEL)
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_STS, field RSVD0[15:9] (RO)
 *
 * Reserved
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_STS_RSVD0 (9U) /*!< Bit position for GPMI_READ_DDR_DLL_STS_RSVD0. */
#define BM_GPMI_READ_DDR_DLL_STS_RSVD0 (0x0000FE00U) /*!< Bit mask for GPMI_READ_DDR_DLL_STS_RSVD0. */
#define BS_GPMI_READ_DDR_DLL_STS_RSVD0 (7U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_STS_RSVD0. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_STS_RSVD0 field. */
#define BR_GPMI_READ_DDR_DLL_STS_RSVD0(x) (HW_GPMI_READ_DDR_DLL_STS(x).B.RSVD0)
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_STS, field REF_LOCK[16] (RO)
 *
 * Reference DLL lock status. This signifies that the DLL has detected and
 * locked to a half-phase GPMICLK shift, allowing the slave delay-line to perform
 * programmed clock delays.
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_STS_REF_LOCK (16U) /*!< Bit position for GPMI_READ_DDR_DLL_STS_REF_LOCK. */
#define BM_GPMI_READ_DDR_DLL_STS_REF_LOCK (0x00010000U) /*!< Bit mask for GPMI_READ_DDR_DLL_STS_REF_LOCK. */
#define BS_GPMI_READ_DDR_DLL_STS_REF_LOCK (1U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_STS_REF_LOCK. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_STS_REF_LOCK field. */
#define BR_GPMI_READ_DDR_DLL_STS_REF_LOCK(x) (HW_GPMI_READ_DDR_DLL_STS(x).B.REF_LOCK)
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_STS, field REF_SEL[24:17] (RO)
 *
 * Reference delay line select status.
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_STS_REF_SEL (17U) /*!< Bit position for GPMI_READ_DDR_DLL_STS_REF_SEL. */
#define BM_GPMI_READ_DDR_DLL_STS_REF_SEL (0x01FE0000U) /*!< Bit mask for GPMI_READ_DDR_DLL_STS_REF_SEL. */
#define BS_GPMI_READ_DDR_DLL_STS_REF_SEL (8U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_STS_REF_SEL. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_STS_REF_SEL field. */
#define BR_GPMI_READ_DDR_DLL_STS_REF_SEL(x) (HW_GPMI_READ_DDR_DLL_STS(x).B.REF_SEL)
/*@}*/

/*!
 * @name Register GPMI_READ_DDR_DLL_STS, field RSVD1[31:25] (RO)
 *
 * Reserved
 */
/*@{*/
#define BP_GPMI_READ_DDR_DLL_STS_RSVD1 (25U) /*!< Bit position for GPMI_READ_DDR_DLL_STS_RSVD1. */
#define BM_GPMI_READ_DDR_DLL_STS_RSVD1 (0xFE000000U) /*!< Bit mask for GPMI_READ_DDR_DLL_STS_RSVD1. */
#define BS_GPMI_READ_DDR_DLL_STS_RSVD1 (7U) /*!< Bit field size in bits for GPMI_READ_DDR_DLL_STS_RSVD1. */

/*! @brief Read current value of the GPMI_READ_DDR_DLL_STS_RSVD1 field. */
#define BR_GPMI_READ_DDR_DLL_STS_RSVD1(x) (HW_GPMI_READ_DDR_DLL_STS(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_GPMI_WRITE_DDR_DLL_STS - GPMI Double Rate Write DLL Status Register Description
 ******************************************************************************/

/*!
 * @brief HW_GPMI_WRITE_DDR_DLL_STS - GPMI Double Rate Write DLL Status Register Description (RO)
 *
 * Reset value: 0x00000000U
 *
 * GPMI Double Rate Write DLL Status Register, Read Only. GPMI DLL status fields
 * are provided in this register. GPMI_WRITE_DDR_DLL_STS 0x130
 */
typedef union _hw_gpmi_write_ddr_dll_sts
{
    uint32_t U;
    struct _hw_gpmi_write_ddr_dll_sts_bitfields
    {
        uint32_t SLV_LOCK : 1;         /*!< [0]  */
        uint32_t SLV_SEL : 8;          /*!< [8:1]  */
        uint32_t RSVD0 : 7;            /*!< [15:9]  */
        uint32_t REF_LOCK : 1;         /*!< [16]  */
        uint32_t REF_SEL : 8;          /*!< [24:17]  */
        uint32_t RSVD1 : 7;            /*!< [31:25]  */
    } B;
} hw_gpmi_write_ddr_dll_sts_t;

/*!
 * @name Constants and macros for entire GPMI_WRITE_DDR_DLL_STS register
 */
/*@{*/
#define HW_GPMI_WRITE_DDR_DLL_STS_ADDR(x) ((uintptr_t)(x) + 0x130U)

#define HW_GPMI_WRITE_DDR_DLL_STS(x) (*(__I hw_gpmi_write_ddr_dll_sts_t *) HW_GPMI_WRITE_DDR_DLL_STS_ADDR(x))
#define HW_GPMI_WRITE_DDR_DLL_STS_RD(x) (HW_GPMI_WRITE_DDR_DLL_STS(x).U)
/*@}*/

/*
 * Constants & macros for individual GPMI_WRITE_DDR_DLL_STS bitfields
 */

/*!
 * @name Register GPMI_WRITE_DDR_DLL_STS, field SLV_LOCK[0] (RO)
 *
 * Slave delay-line lock status. This signifies that a valid calibration has
 * been set to the slave-delay line and that the slave-delay line is implementing
 * the programmed delay value.
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_STS_SLV_LOCK (0U) /*!< Bit position for GPMI_WRITE_DDR_DLL_STS_SLV_LOCK. */
#define BM_GPMI_WRITE_DDR_DLL_STS_SLV_LOCK (0x00000001U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_STS_SLV_LOCK. */
#define BS_GPMI_WRITE_DDR_DLL_STS_SLV_LOCK (1U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_STS_SLV_LOCK. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_STS_SLV_LOCK field. */
#define BR_GPMI_WRITE_DDR_DLL_STS_SLV_LOCK(x) (HW_GPMI_WRITE_DDR_DLL_STS(x).B.SLV_LOCK)
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_STS, field SLV_SEL[8:1] (RO)
 *
 * Slave delay line select status
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_STS_SLV_SEL (1U) /*!< Bit position for GPMI_WRITE_DDR_DLL_STS_SLV_SEL. */
#define BM_GPMI_WRITE_DDR_DLL_STS_SLV_SEL (0x000001FEU) /*!< Bit mask for GPMI_WRITE_DDR_DLL_STS_SLV_SEL. */
#define BS_GPMI_WRITE_DDR_DLL_STS_SLV_SEL (8U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_STS_SLV_SEL. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_STS_SLV_SEL field. */
#define BR_GPMI_WRITE_DDR_DLL_STS_SLV_SEL(x) (HW_GPMI_WRITE_DDR_DLL_STS(x).B.SLV_SEL)
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_STS, field RSVD0[15:9] (RO)
 *
 * Reserved
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_STS_RSVD0 (9U) /*!< Bit position for GPMI_WRITE_DDR_DLL_STS_RSVD0. */
#define BM_GPMI_WRITE_DDR_DLL_STS_RSVD0 (0x0000FE00U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_STS_RSVD0. */
#define BS_GPMI_WRITE_DDR_DLL_STS_RSVD0 (7U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_STS_RSVD0. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_STS_RSVD0 field. */
#define BR_GPMI_WRITE_DDR_DLL_STS_RSVD0(x) (HW_GPMI_WRITE_DDR_DLL_STS(x).B.RSVD0)
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_STS, field REF_LOCK[16] (RO)
 *
 * Reference DLL lock status. This signifies that the DLL has detected and
 * locked to a half-phase GPMICLK shift, allowing the slave delay-line to perform
 * programmed clock delays.
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_STS_REF_LOCK (16U) /*!< Bit position for GPMI_WRITE_DDR_DLL_STS_REF_LOCK. */
#define BM_GPMI_WRITE_DDR_DLL_STS_REF_LOCK (0x00010000U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_STS_REF_LOCK. */
#define BS_GPMI_WRITE_DDR_DLL_STS_REF_LOCK (1U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_STS_REF_LOCK. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_STS_REF_LOCK field. */
#define BR_GPMI_WRITE_DDR_DLL_STS_REF_LOCK(x) (HW_GPMI_WRITE_DDR_DLL_STS(x).B.REF_LOCK)
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_STS, field REF_SEL[24:17] (RO)
 *
 * Reference delay line select status.
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_STS_REF_SEL (17U) /*!< Bit position for GPMI_WRITE_DDR_DLL_STS_REF_SEL. */
#define BM_GPMI_WRITE_DDR_DLL_STS_REF_SEL (0x01FE0000U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_STS_REF_SEL. */
#define BS_GPMI_WRITE_DDR_DLL_STS_REF_SEL (8U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_STS_REF_SEL. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_STS_REF_SEL field. */
#define BR_GPMI_WRITE_DDR_DLL_STS_REF_SEL(x) (HW_GPMI_WRITE_DDR_DLL_STS(x).B.REF_SEL)
/*@}*/

/*!
 * @name Register GPMI_WRITE_DDR_DLL_STS, field RSVD1[31:25] (RO)
 *
 * Reserved
 */
/*@{*/
#define BP_GPMI_WRITE_DDR_DLL_STS_RSVD1 (25U) /*!< Bit position for GPMI_WRITE_DDR_DLL_STS_RSVD1. */
#define BM_GPMI_WRITE_DDR_DLL_STS_RSVD1 (0xFE000000U) /*!< Bit mask for GPMI_WRITE_DDR_DLL_STS_RSVD1. */
#define BS_GPMI_WRITE_DDR_DLL_STS_RSVD1 (7U) /*!< Bit field size in bits for GPMI_WRITE_DDR_DLL_STS_RSVD1. */

/*! @brief Read current value of the GPMI_WRITE_DDR_DLL_STS_RSVD1 field. */
#define BR_GPMI_WRITE_DDR_DLL_STS_RSVD1(x) (HW_GPMI_WRITE_DDR_DLL_STS(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * hw_gpmi_t - module struct
 ******************************************************************************/
/*!
 * @brief All GPMI module registers.
 */
#pragma pack(1)
typedef struct _hw_gpmi
{
    __IO hw_gpmi_ctrl0_t CTRL0;            /*!< [0x0] GPMI Control Register 0 Description */
    uint8_t _reserved0[12];
    __IO hw_gpmi_compare_t COMPARE;        /*!< [0x10] GPMI Compare Register Description */
    uint8_t _reserved1[12];
    __IO hw_gpmi_eccctrl_t ECCCTRL;        /*!< [0x20] GPMI Integrated ECC Control Register Description */
    uint8_t _reserved2[12];
    __IO hw_gpmi_ecccount_t ECCCOUNT;      /*!< [0x30] GPMI Integrated ECC Transfer Count Register Description */
    uint8_t _reserved3[12];
    __IO hw_gpmi_payload_t PAYLOAD;        /*!< [0x40] GPMI Payload Address Register Description */
    uint8_t _reserved4[12];
    __IO hw_gpmi_auxiliary_t AUXILIARY;    /*!< [0x50] GPMI Auxiliary Address Register Description */
    uint8_t _reserved5[12];
    __IO hw_gpmi_ctrl1_t CTRL1;            /*!< [0x60] GPMI Control Register 1 Description */
    uint8_t _reserved6[12];
    __IO hw_gpmi_timing0_t TIMING0;        /*!< [0x70] GPMI Timing Register 0 Description */
    uint8_t _reserved7[12];
    __IO hw_gpmi_timing1_t TIMING1;        /*!< [0x80] GPMI Timing Register 1 Description */
    uint8_t _reserved8[12];
    __IO hw_gpmi_timing2_t TIMING2;        /*!< [0x90] GPMI Timing Register 2 Description */
    uint8_t _reserved9[12];
    __IO hw_gpmi_data_t DATA;              /*!< [0xA0] GPMI DMA Data Transfer Register Description */
    uint8_t _reserved10[12];
    __I hw_gpmi_stat_t STAT;               /*!< [0xB0] GPMI Status Register Description */
    uint8_t _reserved11[12];
    __I hw_gpmi_debug_t DEBUGr;            /*!< [0xC0] GPMI Debug Information Register Description */
    uint8_t _reserved12[12];
    __I hw_gpmi_version_t VERSION;         /*!< [0xD0] GPMI Version Register Description */
    uint8_t _reserved13[12];
    __IO hw_gpmi_debug2_t DEBUG2;          /*!< [0xE0] GPMI Debug2 Information Register Description */
    uint8_t _reserved14[12];
    __I hw_gpmi_debug3_t DEBUG3;           /*!< [0xF0] GPMI Debug3 Information Register Description */
    uint8_t _reserved15[12];
    __IO hw_gpmi_read_ddr_dll_ctrl_t READ_DDR_DLL_CTRL; /*!< [0x100] GPMI Double Rate Read DLL Control Register Description */
    uint8_t _reserved16[12];
    __IO hw_gpmi_write_ddr_dll_ctrl_t WRITE_DDR_DLL_CTRL; /*!< [0x110] GPMI Double Rate Write DLL Control Register Description */
    uint8_t _reserved17[12];
    __I hw_gpmi_read_ddr_dll_sts_t READ_DDR_DLL_STS; /*!< [0x120] GPMI Double Rate Read DLL Status Register Description */
    uint8_t _reserved18[12];
    __I hw_gpmi_write_ddr_dll_sts_t WRITE_DDR_DLL_STS; /*!< [0x130] GPMI Double Rate Write DLL Status Register Description */
} hw_gpmi_t;
#pragma pack()

/*! @brief Macro to access all GPMI registers. */
/*! @param x GPMI module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_GPMI_REGS(GPMI_BASE)</code>. */
#define HW_GPMI_REGS(x) (*(hw_gpmi_t *)(x))

/*
 * iMX7D GPT
 *
 * General Purpose Timer (GPT)
 *
 * Registers defined in this header file:
 * - HW_GPT_CR - GPT Control Register
 * - HW_GPT_PR - GPT Prescaler Register
 * - HW_GPT_SR - GPT Status Register
 * - HW_GPT_IR - GPT Interrupt Register
 * - HW_GPT_OCR1 - GPT Output Compare Register 1
 * - HW_GPT_OCR2 - GPT Output Compare Register 2
 * - HW_GPT_OCR3 - GPT Output Compare Register 3
 * - HW_GPT_ICR1 - GPT Input Capture Register 1
 * - HW_GPT_ICR2 - GPT Input Capture Register 2
 * - HW_GPT_CNT - GPT Counter Register
 *
 * - hw_gpt_t - Struct containing all module registers.
 */

#define HW_GPT_INSTANCE_COUNT (4U) /*!< Number of instances of the GPT module. */
#define HW_GPT1 (0U) /*!< Instance number for GPT1. */
#define HW_GPT2 (1U) /*!< Instance number for GPT2. */
#define HW_GPT3 (2U) /*!< Instance number for GPT3. */
#define HW_GPT4 (3U) /*!< Instance number for GPT4. */
#define GPT1_BASE             (0x302D0000U) /*!< Base address for GPT1. */
#define GPT2_BASE             (0x302E0000U) /*!< Base address for GPT2. */
#define GPT3_BASE             (0x302F0000U) /*!< Base address for GPT3. */
#define GPT4_BASE             (0x30300000U) /*!< Base address for GPT4. */
/*! Array initializer of GPT base addresses. */
#define GPT_BASE_ADDRS        { GPT1_BASE, GPT2_BASE, GPT3_BASE, GPT4_BASE }

/*******************************************************************************
 * HW_GPT_CR - GPT Control Register
 ******************************************************************************/

/*!
 * @brief HW_GPT_CR - GPT Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPT Control Register (GPT_CR) is used to program and configure GPT
 * operations. An IP Bus Write to the GPT Control Register occurs after one cycle of
 * wait state, while an IP Bus Read occurs after 0 wait states.
 */
typedef union _hw_gpt_cr
{
    uint32_t U;
    struct _hw_gpt_cr_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t ENMOD : 1;            /*!< [1]  */
        uint32_t DBGEN : 1;            /*!< [2]  */
        uint32_t WAITEN : 1;           /*!< [3]  */
        uint32_t DOZEEN : 1;           /*!< [4]  */
        uint32_t STOPEN : 1;           /*!< [5]  */
        uint32_t CLKSRC : 3;           /*!< [8:6]  */
        uint32_t FRR : 1;              /*!< [9]  */
        uint32_t EN_24M : 1;           /*!< [10]  */
        uint32_t RESERVED0 : 4;        /*!< [14:11]  */
        uint32_t SWR : 1;              /*!< [15]  */
        uint32_t IM1 : 2;              /*!< [17:16]  */
        uint32_t IM2 : 2;              /*!< [19:18]  */
        uint32_t OM1 : 3;              /*!< [22:20]  */
        uint32_t OM2 : 3;              /*!< [25:23]  */
        uint32_t OM3 : 3;              /*!< [28:26]  */
        uint32_t FO1 : 1;              /*!< [29]  */
        uint32_t FO2 : 1;              /*!< [30]  */
        uint32_t FO3 : 1;              /*!< [31]  */
    } B;
} hw_gpt_cr_t;

/*!
 * @name Constants and macros for entire GPT_CR register
 */
/*@{*/
#define HW_GPT_CR_ADDR(x)        ((uintptr_t)(x) + 0x0U)

#define HW_GPT_CR(x)             (*(__IO hw_gpt_cr_t *) HW_GPT_CR_ADDR(x))
#define HW_GPT_CR_RD(x)          (HW_GPT_CR(x).U)
#define HW_GPT_CR_WR(x, v)       (HW_GPT_CR(x).U = (v))
#define HW_GPT_CR_SET(x, v)      (HW_GPT_CR_WR(x, HW_GPT_CR_RD(x) |  (v)))
#define HW_GPT_CR_CLR(x, v)      (HW_GPT_CR_WR(x, HW_GPT_CR_RD(x) & ~(v)))
#define HW_GPT_CR_TOG(x, v)      (HW_GPT_CR_WR(x, HW_GPT_CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPT_CR bitfields
 */

/*!
 * @name Register GPT_CR, field EN[0] (RW)
 *
 * GPT Enable. The EN bit is the GPT module enable bit. Before setting the EN
 * bit, we recommend that all registers be properly programmed. A hardware reset
 * resets the EN bit. A software reset does not affect the EN bit.
 *
 * Values:
 * - 0 - GPT is disabled.
 * - 1 - GPT is enabled.
 */
/*@{*/
#define BP_GPT_CR_EN         (0U)          /*!< Bit position for GPT_CR_EN. */
#define BM_GPT_CR_EN         (0x00000001U) /*!< Bit mask for GPT_CR_EN. */
#define BS_GPT_CR_EN         (1U)          /*!< Bit field size in bits for GPT_CR_EN. */

/*! @brief Read current value of the GPT_CR_EN field. */
#define BR_GPT_CR_EN(x)      (HW_GPT_CR(x).B.EN)

/*! @brief Format value for bitfield GPT_CR_EN. */
#define BF_GPT_CR_EN(v)      ((uint32_t)((uint32_t)(v) << BP_GPT_CR_EN) & BM_GPT_CR_EN)

/*! @brief Set the EN field to a new value. */
#define BW_GPT_CR_EN(x, v)   (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_EN) | BF_GPT_CR_EN(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field ENMOD[1] (RW)
 *
 * GPT Enable mode. When the GPT is disabled (EN=0), then both the Main Counter
 * and Prescaler Counter freeze their current count values. The ENMOD bit
 * determines the value of the GPT counter when Counter is enabled again (if the EN bit
 * is set). If the ENMOD bit is 1, then the Main Counter and Prescaler Counter
 * values are reset to 0 after GPT is enabled (EN=1). If the ENMOD bit is 0, then
 * the Main Counter and Prescaler Counter restart counting from their frozen
 * values after GPT is enabled (EN=1). If GPT is programmed to be disabled in a low
 * power mode (STOP/WAIT), then the Main Counter and Prescaler Counter freeze at
 * their current count values when the GPT enters low power mode. When GPT exits
 * low power mode, the Main Counter and Prescaler Counter start counting from their
 * frozen values, regardless of the ENMOD bit value. Setting the SWR bit will
 * clear the Main Counter and Prescaler Counter values, regardless of the value of
 * EN or ENMOD bits. A hardware reset resets the ENMOD bit. A software reset does
 * not affect the ENMOD bit.
 *
 * Values:
 * - 0 - GPT counter will retain its value when it is disabled.
 * - 1 - GPT counter value is reset to 0 when it is disabled.
 */
/*@{*/
#define BP_GPT_CR_ENMOD      (1U)          /*!< Bit position for GPT_CR_ENMOD. */
#define BM_GPT_CR_ENMOD      (0x00000002U) /*!< Bit mask for GPT_CR_ENMOD. */
#define BS_GPT_CR_ENMOD      (1U)          /*!< Bit field size in bits for GPT_CR_ENMOD. */

/*! @brief Read current value of the GPT_CR_ENMOD field. */
#define BR_GPT_CR_ENMOD(x)   (HW_GPT_CR(x).B.ENMOD)

/*! @brief Format value for bitfield GPT_CR_ENMOD. */
#define BF_GPT_CR_ENMOD(v)   ((uint32_t)((uint32_t)(v) << BP_GPT_CR_ENMOD) & BM_GPT_CR_ENMOD)

/*! @brief Set the ENMOD field to a new value. */
#define BW_GPT_CR_ENMOD(x, v) (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_ENMOD) | BF_GPT_CR_ENMOD(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field DBGEN[2] (RW)
 *
 * GPT debug mode enable. The DBGEN read/write control bit enables GPT operation
 * during Debug mode. A hardware reset resets the DBGEN bit. A software reset
 * does not affect the DBGEN bit.
 *
 * Values:
 * - 0 - GPT is disabled in debug mode.
 * - 1 - GPT is enabled in debug mode.
 */
/*@{*/
#define BP_GPT_CR_DBGEN      (2U)          /*!< Bit position for GPT_CR_DBGEN. */
#define BM_GPT_CR_DBGEN      (0x00000004U) /*!< Bit mask for GPT_CR_DBGEN. */
#define BS_GPT_CR_DBGEN      (1U)          /*!< Bit field size in bits for GPT_CR_DBGEN. */

/*! @brief Read current value of the GPT_CR_DBGEN field. */
#define BR_GPT_CR_DBGEN(x)   (HW_GPT_CR(x).B.DBGEN)

/*! @brief Format value for bitfield GPT_CR_DBGEN. */
#define BF_GPT_CR_DBGEN(v)   ((uint32_t)((uint32_t)(v) << BP_GPT_CR_DBGEN) & BM_GPT_CR_DBGEN)

/*! @brief Set the DBGEN field to a new value. */
#define BW_GPT_CR_DBGEN(x, v) (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_DBGEN) | BF_GPT_CR_DBGEN(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field WAITEN[3] (RW)
 *
 * GPT Wait Mode enable. The WAITEN read/write control bit enables GPT operation
 * during Wait mode. A hardware reset resets the WAITEN bit. A software reset
 * does not affect the WAITEN bit.
 *
 * Values:
 * - 0 - GPT is disabled in wait mode.
 * - 1 - GPT is enabled in wait mode.
 */
/*@{*/
#define BP_GPT_CR_WAITEN     (3U)          /*!< Bit position for GPT_CR_WAITEN. */
#define BM_GPT_CR_WAITEN     (0x00000008U) /*!< Bit mask for GPT_CR_WAITEN. */
#define BS_GPT_CR_WAITEN     (1U)          /*!< Bit field size in bits for GPT_CR_WAITEN. */

/*! @brief Read current value of the GPT_CR_WAITEN field. */
#define BR_GPT_CR_WAITEN(x)  (HW_GPT_CR(x).B.WAITEN)

/*! @brief Format value for bitfield GPT_CR_WAITEN. */
#define BF_GPT_CR_WAITEN(v)  ((uint32_t)((uint32_t)(v) << BP_GPT_CR_WAITEN) & BM_GPT_CR_WAITEN)

/*! @brief Set the WAITEN field to a new value. */
#define BW_GPT_CR_WAITEN(x, v) (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_WAITEN) | BF_GPT_CR_WAITEN(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field DOZEEN[4] (RW)
 *
 * GPT Doze Mode Enable. A hardware reset resets the DOZEEN bit. A software
 * reset does not affect the DOZEEN bit.
 *
 * Values:
 * - 0 - GPT is disabled in doze mode.
 * - 1 - GPT is enabled in doze mode.
 */
/*@{*/
#define BP_GPT_CR_DOZEEN     (4U)          /*!< Bit position for GPT_CR_DOZEEN. */
#define BM_GPT_CR_DOZEEN     (0x00000010U) /*!< Bit mask for GPT_CR_DOZEEN. */
#define BS_GPT_CR_DOZEEN     (1U)          /*!< Bit field size in bits for GPT_CR_DOZEEN. */

/*! @brief Read current value of the GPT_CR_DOZEEN field. */
#define BR_GPT_CR_DOZEEN(x)  (HW_GPT_CR(x).B.DOZEEN)

/*! @brief Format value for bitfield GPT_CR_DOZEEN. */
#define BF_GPT_CR_DOZEEN(v)  ((uint32_t)((uint32_t)(v) << BP_GPT_CR_DOZEEN) & BM_GPT_CR_DOZEEN)

/*! @brief Set the DOZEEN field to a new value. */
#define BW_GPT_CR_DOZEEN(x, v) (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_DOZEEN) | BF_GPT_CR_DOZEEN(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field STOPEN[5] (RW)
 *
 * GPT Stop Mode enable. The STOPEN read/write control bit enables GPT operation
 * during Stop mode. A hardware reset resets the STOPEN bit. A software reset
 * does not affect the STOPEN bit.
 *
 * Values:
 * - 0 - GPT is disabled in Stop mode.
 * - 1 - GPT is enabled in Stop mode.
 */
/*@{*/
#define BP_GPT_CR_STOPEN     (5U)          /*!< Bit position for GPT_CR_STOPEN. */
#define BM_GPT_CR_STOPEN     (0x00000020U) /*!< Bit mask for GPT_CR_STOPEN. */
#define BS_GPT_CR_STOPEN     (1U)          /*!< Bit field size in bits for GPT_CR_STOPEN. */

/*! @brief Read current value of the GPT_CR_STOPEN field. */
#define BR_GPT_CR_STOPEN(x)  (HW_GPT_CR(x).B.STOPEN)

/*! @brief Format value for bitfield GPT_CR_STOPEN. */
#define BF_GPT_CR_STOPEN(v)  ((uint32_t)((uint32_t)(v) << BP_GPT_CR_STOPEN) & BM_GPT_CR_STOPEN)

/*! @brief Set the STOPEN field to a new value. */
#define BW_GPT_CR_STOPEN(x, v) (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_STOPEN) | BF_GPT_CR_STOPEN(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field CLKSRC[8:6] (RW)
 *
 * Clock Source select. The CLKSRC bits select which clock will go to the
 * prescaler (and subsequently be used to run the GPT counter). The CLKSRC bit field
 * value should only be changed after disabling the GPT by clearing the EN bit in
 * this register (GPT_CR). A software reset does not affect the CLKSRC bit.
 *
 * Values:
 * - 000 - No clock
 * - 001 - Peripheral Clock
 * - 010 - High Frequency Reference Clock
 * - 011 - External Clock (CLKIN)
 * - 100 - Low Frequency Reference Clock
 * - 101 - Crystal oscillator as Reference Clock
 */
/*@{*/
#define BP_GPT_CR_CLKSRC     (6U)          /*!< Bit position for GPT_CR_CLKSRC. */
#define BM_GPT_CR_CLKSRC     (0x000001C0U) /*!< Bit mask for GPT_CR_CLKSRC. */
#define BS_GPT_CR_CLKSRC     (3U)          /*!< Bit field size in bits for GPT_CR_CLKSRC. */

/*! @brief Read current value of the GPT_CR_CLKSRC field. */
#define BR_GPT_CR_CLKSRC(x)  (HW_GPT_CR(x).B.CLKSRC)

/*! @brief Format value for bitfield GPT_CR_CLKSRC. */
#define BF_GPT_CR_CLKSRC(v)  ((uint32_t)((uint32_t)(v) << BP_GPT_CR_CLKSRC) & BM_GPT_CR_CLKSRC)

/*! @brief Set the CLKSRC field to a new value. */
#define BW_GPT_CR_CLKSRC(x, v) (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_CLKSRC) | BF_GPT_CR_CLKSRC(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field FRR[9] (RW)
 *
 * Free-Run or Restart mode. The FFR bit determines the behavior of the GPT when
 * a compare event in channel 1 occurs. In Restart mode, after a compare event,
 * the counter resets to 0x00000000 and resumes counting (after the occurrence of
 * a compare event). In Free-Run mode, after a compare event, the counter
 * continues counting until 0xFFFFFFFF and then rolls over to 0.
 *
 * Values:
 * - 0 - Restart mode
 * - 1 - Free-Run mode
 */
/*@{*/
#define BP_GPT_CR_FRR        (9U)          /*!< Bit position for GPT_CR_FRR. */
#define BM_GPT_CR_FRR        (0x00000200U) /*!< Bit mask for GPT_CR_FRR. */
#define BS_GPT_CR_FRR        (1U)          /*!< Bit field size in bits for GPT_CR_FRR. */

/*! @brief Read current value of the GPT_CR_FRR field. */
#define BR_GPT_CR_FRR(x)     (HW_GPT_CR(x).B.FRR)

/*! @brief Format value for bitfield GPT_CR_FRR. */
#define BF_GPT_CR_FRR(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_FRR) & BM_GPT_CR_FRR)

/*! @brief Set the FRR field to a new value. */
#define BW_GPT_CR_FRR(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_FRR) | BF_GPT_CR_FRR(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field EN_24M[10] (RW)
 *
 * Enable 24 MHz clock input from crystal. A hardware reset resets the EN_24M
 * bit. A software reset does not affect the EN_24M bit.
 *
 * Values:
 * - 0 - 24M clock disabled
 * - 1 - 24M clock enabled
 */
/*@{*/
#define BP_GPT_CR_EN_24M     (10U)         /*!< Bit position for GPT_CR_EN_24M. */
#define BM_GPT_CR_EN_24M     (0x00000400U) /*!< Bit mask for GPT_CR_EN_24M. */
#define BS_GPT_CR_EN_24M     (1U)          /*!< Bit field size in bits for GPT_CR_EN_24M. */

/*! @brief Read current value of the GPT_CR_EN_24M field. */
#define BR_GPT_CR_EN_24M(x)  (HW_GPT_CR(x).B.EN_24M)

/*! @brief Format value for bitfield GPT_CR_EN_24M. */
#define BF_GPT_CR_EN_24M(v)  ((uint32_t)((uint32_t)(v) << BP_GPT_CR_EN_24M) & BM_GPT_CR_EN_24M)

/*! @brief Set the EN_24M field to a new value. */
#define BW_GPT_CR_EN_24M(x, v) (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_EN_24M) | BF_GPT_CR_EN_24M(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field SWR[15] (RW)
 *
 * Software reset. This is the software reset of the GPT module. It is a
 * self-clearing bit. The SWR bit is set when the module is in reset state. The SWR bit
 * is cleared when the reset procedure finishes. Setting the SWR bit resets all
 * of the registers to their default reset values, except for the CLKSRC, EN,
 * ENMOD, STOPEN, WAITEN, and DBGEN bits in the GPT Control Register (this control
 * register).
 *
 * Values:
 * - 0 - GPT is not in reset state
 * - 1 - GPT is in reset state
 */
/*@{*/
#define BP_GPT_CR_SWR        (15U)         /*!< Bit position for GPT_CR_SWR. */
#define BM_GPT_CR_SWR        (0x00008000U) /*!< Bit mask for GPT_CR_SWR. */
#define BS_GPT_CR_SWR        (1U)          /*!< Bit field size in bits for GPT_CR_SWR. */

/*! @brief Read current value of the GPT_CR_SWR field. */
#define BR_GPT_CR_SWR(x)     (HW_GPT_CR(x).B.SWR)

/*! @brief Format value for bitfield GPT_CR_SWR. */
#define BF_GPT_CR_SWR(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_SWR) & BM_GPT_CR_SWR)

/*! @brief Set the SWR field to a new value. */
#define BW_GPT_CR_SWR(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_SWR) | BF_GPT_CR_SWR(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field IM1[17:16] (RW)
 *
 * See IM2
 */
/*@{*/
#define BP_GPT_CR_IM1        (16U)         /*!< Bit position for GPT_CR_IM1. */
#define BM_GPT_CR_IM1        (0x00030000U) /*!< Bit mask for GPT_CR_IM1. */
#define BS_GPT_CR_IM1        (2U)          /*!< Bit field size in bits for GPT_CR_IM1. */

/*! @brief Read current value of the GPT_CR_IM1 field. */
#define BR_GPT_CR_IM1(x)     (HW_GPT_CR(x).B.IM1)

/*! @brief Format value for bitfield GPT_CR_IM1. */
#define BF_GPT_CR_IM1(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_IM1) & BM_GPT_CR_IM1)

/*! @brief Set the IM1 field to a new value. */
#define BW_GPT_CR_IM1(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_IM1) | BF_GPT_CR_IM1(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field IM2[19:18] (RW)
 *
 * IM2 (bits 19-18, Input Capture Channel 2 operating mode) IM1 (bits 17-16,
 * Input Capture Channel 1 operating mode) The IMn bit field determines the
 * transition on the input pin (for Input capture channel n), which will trigger a
 * capture event.
 *
 * Values:
 * - 00 - capture disabled
 * - 01 - capture on rising edge only
 * - 10 - capture on falling edge only
 * - 11 - capture on both edges
 */
/*@{*/
#define BP_GPT_CR_IM2        (18U)         /*!< Bit position for GPT_CR_IM2. */
#define BM_GPT_CR_IM2        (0x000C0000U) /*!< Bit mask for GPT_CR_IM2. */
#define BS_GPT_CR_IM2        (2U)          /*!< Bit field size in bits for GPT_CR_IM2. */

/*! @brief Read current value of the GPT_CR_IM2 field. */
#define BR_GPT_CR_IM2(x)     (HW_GPT_CR(x).B.IM2)

/*! @brief Format value for bitfield GPT_CR_IM2. */
#define BF_GPT_CR_IM2(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_IM2) & BM_GPT_CR_IM2)

/*! @brief Set the IM2 field to a new value. */
#define BW_GPT_CR_IM2(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_IM2) | BF_GPT_CR_IM2(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field OM1[22:20] (RW)
 *
 * See OM3
 */
/*@{*/
#define BP_GPT_CR_OM1        (20U)         /*!< Bit position for GPT_CR_OM1. */
#define BM_GPT_CR_OM1        (0x00700000U) /*!< Bit mask for GPT_CR_OM1. */
#define BS_GPT_CR_OM1        (3U)          /*!< Bit field size in bits for GPT_CR_OM1. */

/*! @brief Read current value of the GPT_CR_OM1 field. */
#define BR_GPT_CR_OM1(x)     (HW_GPT_CR(x).B.OM1)

/*! @brief Format value for bitfield GPT_CR_OM1. */
#define BF_GPT_CR_OM1(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_OM1) & BM_GPT_CR_OM1)

/*! @brief Set the OM1 field to a new value. */
#define BW_GPT_CR_OM1(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_OM1) | BF_GPT_CR_OM1(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field OM2[25:23] (RW)
 *
 * See OM3
 */
/*@{*/
#define BP_GPT_CR_OM2        (23U)         /*!< Bit position for GPT_CR_OM2. */
#define BM_GPT_CR_OM2        (0x03800000U) /*!< Bit mask for GPT_CR_OM2. */
#define BS_GPT_CR_OM2        (3U)          /*!< Bit field size in bits for GPT_CR_OM2. */

/*! @brief Read current value of the GPT_CR_OM2 field. */
#define BR_GPT_CR_OM2(x)     (HW_GPT_CR(x).B.OM2)

/*! @brief Format value for bitfield GPT_CR_OM2. */
#define BF_GPT_CR_OM2(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_OM2) & BM_GPT_CR_OM2)

/*! @brief Set the OM2 field to a new value. */
#define BW_GPT_CR_OM2(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_OM2) | BF_GPT_CR_OM2(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field OM3[28:26] (RW)
 *
 * OM3 (bits 28-26) controls the Output Compare Channel 3 operating mode. OM2
 * (bits 25-23) controls the Output Compare Channel 2 operating mode. OM1 (bits
 * 22-20) controls the Output Compare Channel 1 operating mode. The OMn bits specify
 * the response that a compare event will generate on the output pin of Output
 * Compare Channel n. The toggle, clear, and set options cause a change on the
 * output pin only if a compare event occurs. When OMn is programmed as 1xx (active
 * low pulse), the output pin is set to one immediately on the next input clock;
 * a low pulse (that is an input clock in width) occurs when there is a compare
 * event. Note that here, "input clock" refers to the clock selected by the CLKSRC
 * bits of the GPT Control Register.
 *
 * Values:
 * - 000 - Output disconnected. No response on pin.
 * - 001 - Toggle output pin
 * - 010 - Clear output pin
 * - 011 - Set output pin
 * - 1xx - Generate an active low pulse (that is one input clock wide) on the
 *     output pin.
 */
/*@{*/
#define BP_GPT_CR_OM3        (26U)         /*!< Bit position for GPT_CR_OM3. */
#define BM_GPT_CR_OM3        (0x1C000000U) /*!< Bit mask for GPT_CR_OM3. */
#define BS_GPT_CR_OM3        (3U)          /*!< Bit field size in bits for GPT_CR_OM3. */

/*! @brief Read current value of the GPT_CR_OM3 field. */
#define BR_GPT_CR_OM3(x)     (HW_GPT_CR(x).B.OM3)

/*! @brief Format value for bitfield GPT_CR_OM3. */
#define BF_GPT_CR_OM3(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_OM3) & BM_GPT_CR_OM3)

/*! @brief Set the OM3 field to a new value. */
#define BW_GPT_CR_OM3(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_OM3) | BF_GPT_CR_OM3(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field FO1[29] (WORZ)
 *
 * See F03
 */
/*@{*/
#define BP_GPT_CR_FO1        (29U)         /*!< Bit position for GPT_CR_FO1. */
#define BM_GPT_CR_FO1        (0x20000000U) /*!< Bit mask for GPT_CR_FO1. */
#define BS_GPT_CR_FO1        (1U)          /*!< Bit field size in bits for GPT_CR_FO1. */

/*! @brief Format value for bitfield GPT_CR_FO1. */
#define BF_GPT_CR_FO1(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_FO1) & BM_GPT_CR_FO1)

/*! @brief Set the FO1 field to a new value. */
#define BW_GPT_CR_FO1(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_FO1) | BF_GPT_CR_FO1(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field FO2[30] (WORZ)
 *
 * See F03
 */
/*@{*/
#define BP_GPT_CR_FO2        (30U)         /*!< Bit position for GPT_CR_FO2. */
#define BM_GPT_CR_FO2        (0x40000000U) /*!< Bit mask for GPT_CR_FO2. */
#define BS_GPT_CR_FO2        (1U)          /*!< Bit field size in bits for GPT_CR_FO2. */

/*! @brief Format value for bitfield GPT_CR_FO2. */
#define BF_GPT_CR_FO2(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_FO2) & BM_GPT_CR_FO2)

/*! @brief Set the FO2 field to a new value. */
#define BW_GPT_CR_FO2(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_FO2) | BF_GPT_CR_FO2(v)))
/*@}*/

/*!
 * @name Register GPT_CR, field FO3[31] (WORZ)
 *
 * FO3 Force Output Compare Channel 3 FO2 Force Output Compare Channel 2 FO1
 * Force Output Compare Channel 1 The FOn bit causes the pin action programmed for
 * the timer Output Compare n pin (according to the OMn bits in this register).
 * The OFn flag (OF3, OF2, OF1) in the status register is not affected. This bit is
 * self-negating and always read as zero.
 *
 * Values:
 * - 0 - Writing a 0 has no effect.
 * - 1 - Causes the programmed pin action on the timer Output Compare n pin; the
 *     OFn flag is not set.
 */
/*@{*/
#define BP_GPT_CR_FO3        (31U)         /*!< Bit position for GPT_CR_FO3. */
#define BM_GPT_CR_FO3        (0x80000000U) /*!< Bit mask for GPT_CR_FO3. */
#define BS_GPT_CR_FO3        (1U)          /*!< Bit field size in bits for GPT_CR_FO3. */

/*! @brief Format value for bitfield GPT_CR_FO3. */
#define BF_GPT_CR_FO3(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_CR_FO3) & BM_GPT_CR_FO3)

/*! @brief Set the FO3 field to a new value. */
#define BW_GPT_CR_FO3(x, v)  (HW_GPT_CR_WR(x, (HW_GPT_CR_RD(x) & ~BM_GPT_CR_FO3) | BF_GPT_CR_FO3(v)))
/*@}*/

/*******************************************************************************
 * HW_GPT_PR - GPT Prescaler Register
 ******************************************************************************/

/*!
 * @brief HW_GPT_PR - GPT Prescaler Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPT Prescaler Register (GPT_PR) contains bits that determine the divide
 * value of the clock that runs the counter.
 */
typedef union _hw_gpt_pr
{
    uint32_t U;
    struct _hw_gpt_pr_bitfields
    {
        uint32_t PRESCALER : 12;       /*!< [11:0]  */
        uint32_t PRESCALER24M : 4;     /*!< [15:12]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_gpt_pr_t;

/*!
 * @name Constants and macros for entire GPT_PR register
 */
/*@{*/
#define HW_GPT_PR_ADDR(x)        ((uintptr_t)(x) + 0x4U)

#define HW_GPT_PR(x)             (*(__IO hw_gpt_pr_t *) HW_GPT_PR_ADDR(x))
#define HW_GPT_PR_RD(x)          (HW_GPT_PR(x).U)
#define HW_GPT_PR_WR(x, v)       (HW_GPT_PR(x).U = (v))
#define HW_GPT_PR_SET(x, v)      (HW_GPT_PR_WR(x, HW_GPT_PR_RD(x) |  (v)))
#define HW_GPT_PR_CLR(x, v)      (HW_GPT_PR_WR(x, HW_GPT_PR_RD(x) & ~(v)))
#define HW_GPT_PR_TOG(x, v)      (HW_GPT_PR_WR(x, HW_GPT_PR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPT_PR bitfields
 */

/*!
 * @name Register GPT_PR, field PRESCALER[11:0] (RW)
 *
 * Prescaler bits. The clock selected by the CLKSRC field is divided by
 * [PRESCALER + 1], and then used to run the counter. A change in the value of the
 * PRESCALER bits cause the Prescaler counter to reset and a new count period to start
 * immediately. See for the timing diagram.
 *
 * Values:
 * - 0 - Divide by 1
 * - 1 - Divide by 2
 * - 111111111111 - Divide by 4096
 */
/*@{*/
#define BP_GPT_PR_PRESCALER  (0U)          /*!< Bit position for GPT_PR_PRESCALER. */
#define BM_GPT_PR_PRESCALER  (0x00000FFFU) /*!< Bit mask for GPT_PR_PRESCALER. */
#define BS_GPT_PR_PRESCALER  (12U)         /*!< Bit field size in bits for GPT_PR_PRESCALER. */

/*! @brief Read current value of the GPT_PR_PRESCALER field. */
#define BR_GPT_PR_PRESCALER(x) (HW_GPT_PR(x).B.PRESCALER)

/*! @brief Format value for bitfield GPT_PR_PRESCALER. */
#define BF_GPT_PR_PRESCALER(v) ((uint32_t)((uint32_t)(v) << BP_GPT_PR_PRESCALER) & BM_GPT_PR_PRESCALER)

/*! @brief Set the PRESCALER field to a new value. */
#define BW_GPT_PR_PRESCALER(x, v) (HW_GPT_PR_WR(x, (HW_GPT_PR_RD(x) & ~BM_GPT_PR_PRESCALER) | BF_GPT_PR_PRESCALER(v)))
/*@}*/

/*!
 * @name Register GPT_PR, field PRESCALER24M[15:12] (RW)
 *
 * Prescaler bits. 24M crystal clock is divided by [PRESCALER24M + 1] before
 * selected by the CLKSRC field. If 24M crystal clock is not selected, this feild
 * takes no effect.
 *
 * Values:
 * - 0 - Divide by 1
 * - 1 - Divide by 2
 * - 1111 - Divide by 16
 */
/*@{*/
#define BP_GPT_PR_PRESCALER24M (12U)       /*!< Bit position for GPT_PR_PRESCALER24M. */
#define BM_GPT_PR_PRESCALER24M (0x0000F000U) /*!< Bit mask for GPT_PR_PRESCALER24M. */
#define BS_GPT_PR_PRESCALER24M (4U)        /*!< Bit field size in bits for GPT_PR_PRESCALER24M. */

/*! @brief Read current value of the GPT_PR_PRESCALER24M field. */
#define BR_GPT_PR_PRESCALER24M(x) (HW_GPT_PR(x).B.PRESCALER24M)

/*! @brief Format value for bitfield GPT_PR_PRESCALER24M. */
#define BF_GPT_PR_PRESCALER24M(v) ((uint32_t)((uint32_t)(v) << BP_GPT_PR_PRESCALER24M) & BM_GPT_PR_PRESCALER24M)

/*! @brief Set the PRESCALER24M field to a new value. */
#define BW_GPT_PR_PRESCALER24M(x, v) (HW_GPT_PR_WR(x, (HW_GPT_PR_RD(x) & ~BM_GPT_PR_PRESCALER24M) | BF_GPT_PR_PRESCALER24M(v)))
/*@}*/

/*******************************************************************************
 * HW_GPT_SR - GPT Status Register
 ******************************************************************************/

/*!
 * @brief HW_GPT_SR - GPT Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPT Status Register (GPT_SR) contains bits that indicate that a counter
 * has rolled over, and if any event has occurred on the Input Capture and Output
 * Compare channels. The bits are cleared by writing a 1 to them.
 */
typedef union _hw_gpt_sr
{
    uint32_t U;
    struct _hw_gpt_sr_bitfields
    {
        uint32_t OF1 : 1;              /*!< [0]  */
        uint32_t OF2 : 1;              /*!< [1]  */
        uint32_t OF3 : 1;              /*!< [2]  */
        uint32_t IF1 : 1;              /*!< [3]  */
        uint32_t IF2 : 1;              /*!< [4]  */
        uint32_t ROV : 1;              /*!< [5]  */
        uint32_t RESERVED0 : 26;       /*!< [31:6]  */
    } B;
} hw_gpt_sr_t;

/*!
 * @name Constants and macros for entire GPT_SR register
 */
/*@{*/
#define HW_GPT_SR_ADDR(x)        ((uintptr_t)(x) + 0x8U)

#define HW_GPT_SR(x)             (*(__IO hw_gpt_sr_t *) HW_GPT_SR_ADDR(x))
#define HW_GPT_SR_RD(x)          (HW_GPT_SR(x).U)
#define HW_GPT_SR_WR(x, v)       (HW_GPT_SR(x).U = (v))
#define HW_GPT_SR_SET(x, v)      (HW_GPT_SR_WR(x, HW_GPT_SR_RD(x) |  (v)))
#define HW_GPT_SR_CLR(x, v)      (HW_GPT_SR_WR(x, HW_GPT_SR_RD(x) & ~(v)))
#define HW_GPT_SR_TOG(x, v)      (HW_GPT_SR_WR(x, HW_GPT_SR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPT_SR bitfields
 */

/*!
 * @name Register GPT_SR, field OF1[0] (W1C)
 *
 * See OF3
 */
/*@{*/
#define BP_GPT_SR_OF1        (0U)          /*!< Bit position for GPT_SR_OF1. */
#define BM_GPT_SR_OF1        (0x00000001U) /*!< Bit mask for GPT_SR_OF1. */
#define BS_GPT_SR_OF1        (1U)          /*!< Bit field size in bits for GPT_SR_OF1. */

/*! @brief Read current value of the GPT_SR_OF1 field. */
#define BR_GPT_SR_OF1(x)     (HW_GPT_SR(x).B.OF1)

/*! @brief Format value for bitfield GPT_SR_OF1. */
#define BF_GPT_SR_OF1(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_SR_OF1) & BM_GPT_SR_OF1)

/*! @brief Set the OF1 field to a new value. */
#define BW_GPT_SR_OF1(x, v)  (HW_GPT_SR_WR(x, (HW_GPT_SR_RD(x) & ~(BM_GPT_SR_OF1 | BM_GPT_SR_OF2 | BM_GPT_SR_OF3 | BM_GPT_SR_IF1 | BM_GPT_SR_IF2 | BM_GPT_SR_ROV)) | BF_GPT_SR_OF1(v)))
/*@}*/

/*!
 * @name Register GPT_SR, field OF2[1] (W1C)
 *
 * See OF3
 */
/*@{*/
#define BP_GPT_SR_OF2        (1U)          /*!< Bit position for GPT_SR_OF2. */
#define BM_GPT_SR_OF2        (0x00000002U) /*!< Bit mask for GPT_SR_OF2. */
#define BS_GPT_SR_OF2        (1U)          /*!< Bit field size in bits for GPT_SR_OF2. */

/*! @brief Read current value of the GPT_SR_OF2 field. */
#define BR_GPT_SR_OF2(x)     (HW_GPT_SR(x).B.OF2)

/*! @brief Format value for bitfield GPT_SR_OF2. */
#define BF_GPT_SR_OF2(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_SR_OF2) & BM_GPT_SR_OF2)

/*! @brief Set the OF2 field to a new value. */
#define BW_GPT_SR_OF2(x, v)  (HW_GPT_SR_WR(x, (HW_GPT_SR_RD(x) & ~(BM_GPT_SR_OF2 | BM_GPT_SR_OF1 | BM_GPT_SR_OF3 | BM_GPT_SR_IF1 | BM_GPT_SR_IF2 | BM_GPT_SR_ROV)) | BF_GPT_SR_OF2(v)))
/*@}*/

/*!
 * @name Register GPT_SR, field OF3[2] (W1C)
 *
 * OF3 Output Compare 3 Flag OF2 Output Compare 2 Flag OF1 Output Compare 1 Flag
 * The OFn bit indicates that a compare event has occurred on Output Compare
 * channel n.
 *
 * Values:
 * - 0 - Compare event has not occurred.
 * - 1 - Compare event has occurred.
 */
/*@{*/
#define BP_GPT_SR_OF3        (2U)          /*!< Bit position for GPT_SR_OF3. */
#define BM_GPT_SR_OF3        (0x00000004U) /*!< Bit mask for GPT_SR_OF3. */
#define BS_GPT_SR_OF3        (1U)          /*!< Bit field size in bits for GPT_SR_OF3. */

/*! @brief Read current value of the GPT_SR_OF3 field. */
#define BR_GPT_SR_OF3(x)     (HW_GPT_SR(x).B.OF3)

/*! @brief Format value for bitfield GPT_SR_OF3. */
#define BF_GPT_SR_OF3(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_SR_OF3) & BM_GPT_SR_OF3)

/*! @brief Set the OF3 field to a new value. */
#define BW_GPT_SR_OF3(x, v)  (HW_GPT_SR_WR(x, (HW_GPT_SR_RD(x) & ~(BM_GPT_SR_OF3 | BM_GPT_SR_OF1 | BM_GPT_SR_OF2 | BM_GPT_SR_IF1 | BM_GPT_SR_IF2 | BM_GPT_SR_ROV)) | BF_GPT_SR_OF3(v)))
/*@}*/

/*!
 * @name Register GPT_SR, field IF1[3] (W1C)
 *
 * See IF2
 */
/*@{*/
#define BP_GPT_SR_IF1        (3U)          /*!< Bit position for GPT_SR_IF1. */
#define BM_GPT_SR_IF1        (0x00000008U) /*!< Bit mask for GPT_SR_IF1. */
#define BS_GPT_SR_IF1        (1U)          /*!< Bit field size in bits for GPT_SR_IF1. */

/*! @brief Read current value of the GPT_SR_IF1 field. */
#define BR_GPT_SR_IF1(x)     (HW_GPT_SR(x).B.IF1)

/*! @brief Format value for bitfield GPT_SR_IF1. */
#define BF_GPT_SR_IF1(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_SR_IF1) & BM_GPT_SR_IF1)

/*! @brief Set the IF1 field to a new value. */
#define BW_GPT_SR_IF1(x, v)  (HW_GPT_SR_WR(x, (HW_GPT_SR_RD(x) & ~(BM_GPT_SR_IF1 | BM_GPT_SR_OF1 | BM_GPT_SR_OF2 | BM_GPT_SR_OF3 | BM_GPT_SR_IF2 | BM_GPT_SR_ROV)) | BF_GPT_SR_IF1(v)))
/*@}*/

/*!
 * @name Register GPT_SR, field IF2[4] (W1C)
 *
 * IF2 Input capture 2 Flag IF1 Input capture 1 Flag The IFn bit indicates that
 * a capture event has occurred on Input Capture channel n.
 *
 * Values:
 * - 0 - Capture event has not occurred.
 * - 1 - Capture event has occurred.
 */
/*@{*/
#define BP_GPT_SR_IF2        (4U)          /*!< Bit position for GPT_SR_IF2. */
#define BM_GPT_SR_IF2        (0x00000010U) /*!< Bit mask for GPT_SR_IF2. */
#define BS_GPT_SR_IF2        (1U)          /*!< Bit field size in bits for GPT_SR_IF2. */

/*! @brief Read current value of the GPT_SR_IF2 field. */
#define BR_GPT_SR_IF2(x)     (HW_GPT_SR(x).B.IF2)

/*! @brief Format value for bitfield GPT_SR_IF2. */
#define BF_GPT_SR_IF2(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_SR_IF2) & BM_GPT_SR_IF2)

/*! @brief Set the IF2 field to a new value. */
#define BW_GPT_SR_IF2(x, v)  (HW_GPT_SR_WR(x, (HW_GPT_SR_RD(x) & ~(BM_GPT_SR_IF2 | BM_GPT_SR_OF1 | BM_GPT_SR_OF2 | BM_GPT_SR_OF3 | BM_GPT_SR_IF1 | BM_GPT_SR_ROV)) | BF_GPT_SR_IF2(v)))
/*@}*/

/*!
 * @name Register GPT_SR, field ROV[5] (W1C)
 *
 * Rollover Flag. The ROV bit indicates that the counter has reached its maximum
 * possible value and rolled over to 0 (from which the counter continues
 * counting). The ROV bit is only set if the counter has reached 0xFFFFFFFF in both
 * Restart and Free-Run modes.
 *
 * Values:
 * - 0 - Rollover has not occurred.
 * - 1 - Rollover has occurred.
 */
/*@{*/
#define BP_GPT_SR_ROV        (5U)          /*!< Bit position for GPT_SR_ROV. */
#define BM_GPT_SR_ROV        (0x00000020U) /*!< Bit mask for GPT_SR_ROV. */
#define BS_GPT_SR_ROV        (1U)          /*!< Bit field size in bits for GPT_SR_ROV. */

/*! @brief Read current value of the GPT_SR_ROV field. */
#define BR_GPT_SR_ROV(x)     (HW_GPT_SR(x).B.ROV)

/*! @brief Format value for bitfield GPT_SR_ROV. */
#define BF_GPT_SR_ROV(v)     ((uint32_t)((uint32_t)(v) << BP_GPT_SR_ROV) & BM_GPT_SR_ROV)

/*! @brief Set the ROV field to a new value. */
#define BW_GPT_SR_ROV(x, v)  (HW_GPT_SR_WR(x, (HW_GPT_SR_RD(x) & ~(BM_GPT_SR_ROV | BM_GPT_SR_OF1 | BM_GPT_SR_OF2 | BM_GPT_SR_OF3 | BM_GPT_SR_IF1 | BM_GPT_SR_IF2)) | BF_GPT_SR_ROV(v)))
/*@}*/

/*******************************************************************************
 * HW_GPT_IR - GPT Interrupt Register
 ******************************************************************************/

/*!
 * @brief HW_GPT_IR - GPT Interrupt Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The GPT Interrupt Register (GPT_IR) contains bits that control whether
 * interrupts are generated after rollover, input capture and output compare events.
 */
typedef union _hw_gpt_ir
{
    uint32_t U;
    struct _hw_gpt_ir_bitfields
    {
        uint32_t OF1IE : 1;            /*!< [0]  */
        uint32_t OF2IE : 1;            /*!< [1]  */
        uint32_t OF3IE : 1;            /*!< [2]  */
        uint32_t IF1IE : 1;            /*!< [3]  */
        uint32_t IF2IE : 1;            /*!< [4]  */
        uint32_t ROVIE : 1;            /*!< [5]  */
        uint32_t RESERVED0 : 26;       /*!< [31:6]  */
    } B;
} hw_gpt_ir_t;

/*!
 * @name Constants and macros for entire GPT_IR register
 */
/*@{*/
#define HW_GPT_IR_ADDR(x)        ((uintptr_t)(x) + 0xCU)

#define HW_GPT_IR(x)             (*(__IO hw_gpt_ir_t *) HW_GPT_IR_ADDR(x))
#define HW_GPT_IR_RD(x)          (HW_GPT_IR(x).U)
#define HW_GPT_IR_WR(x, v)       (HW_GPT_IR(x).U = (v))
#define HW_GPT_IR_SET(x, v)      (HW_GPT_IR_WR(x, HW_GPT_IR_RD(x) |  (v)))
#define HW_GPT_IR_CLR(x, v)      (HW_GPT_IR_WR(x, HW_GPT_IR_RD(x) & ~(v)))
#define HW_GPT_IR_TOG(x, v)      (HW_GPT_IR_WR(x, HW_GPT_IR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPT_IR bitfields
 */

/*!
 * @name Register GPT_IR, field OF1IE[0] (RW)
 *
 * See OF3IE
 */
/*@{*/
#define BP_GPT_IR_OF1IE      (0U)          /*!< Bit position for GPT_IR_OF1IE. */
#define BM_GPT_IR_OF1IE      (0x00000001U) /*!< Bit mask for GPT_IR_OF1IE. */
#define BS_GPT_IR_OF1IE      (1U)          /*!< Bit field size in bits for GPT_IR_OF1IE. */

/*! @brief Read current value of the GPT_IR_OF1IE field. */
#define BR_GPT_IR_OF1IE(x)   (HW_GPT_IR(x).B.OF1IE)

/*! @brief Format value for bitfield GPT_IR_OF1IE. */
#define BF_GPT_IR_OF1IE(v)   ((uint32_t)((uint32_t)(v) << BP_GPT_IR_OF1IE) & BM_GPT_IR_OF1IE)

/*! @brief Set the OF1IE field to a new value. */
#define BW_GPT_IR_OF1IE(x, v) (HW_GPT_IR_WR(x, (HW_GPT_IR_RD(x) & ~BM_GPT_IR_OF1IE) | BF_GPT_IR_OF1IE(v)))
/*@}*/

/*!
 * @name Register GPT_IR, field OF2IE[1] (RW)
 *
 * See OF3IE
 */
/*@{*/
#define BP_GPT_IR_OF2IE      (1U)          /*!< Bit position for GPT_IR_OF2IE. */
#define BM_GPT_IR_OF2IE      (0x00000002U) /*!< Bit mask for GPT_IR_OF2IE. */
#define BS_GPT_IR_OF2IE      (1U)          /*!< Bit field size in bits for GPT_IR_OF2IE. */

/*! @brief Read current value of the GPT_IR_OF2IE field. */
#define BR_GPT_IR_OF2IE(x)   (HW_GPT_IR(x).B.OF2IE)

/*! @brief Format value for bitfield GPT_IR_OF2IE. */
#define BF_GPT_IR_OF2IE(v)   ((uint32_t)((uint32_t)(v) << BP_GPT_IR_OF2IE) & BM_GPT_IR_OF2IE)

/*! @brief Set the OF2IE field to a new value. */
#define BW_GPT_IR_OF2IE(x, v) (HW_GPT_IR_WR(x, (HW_GPT_IR_RD(x) & ~BM_GPT_IR_OF2IE) | BF_GPT_IR_OF2IE(v)))
/*@}*/

/*!
 * @name Register GPT_IR, field OF3IE[2] (RW)
 *
 * OF3IE Output Compare 3 Interrupt Enable OF2IE Output Compare 2 Interrupt
 * Enable OF1IE Output Compare 1 Interrupt Enable The OFnIE bit controls the Output
 * Compare Channel n interrupt.
 *
 * Values:
 * - 0 - Output Compare Channel n interrupt is disabled.
 * - 1 - Output Compare Channel n interrupt is enabled.
 */
/*@{*/
#define BP_GPT_IR_OF3IE      (2U)          /*!< Bit position for GPT_IR_OF3IE. */
#define BM_GPT_IR_OF3IE      (0x00000004U) /*!< Bit mask for GPT_IR_OF3IE. */
#define BS_GPT_IR_OF3IE      (1U)          /*!< Bit field size in bits for GPT_IR_OF3IE. */

/*! @brief Read current value of the GPT_IR_OF3IE field. */
#define BR_GPT_IR_OF3IE(x)   (HW_GPT_IR(x).B.OF3IE)

/*! @brief Format value for bitfield GPT_IR_OF3IE. */
#define BF_GPT_IR_OF3IE(v)   ((uint32_t)((uint32_t)(v) << BP_GPT_IR_OF3IE) & BM_GPT_IR_OF3IE)

/*! @brief Set the OF3IE field to a new value. */
#define BW_GPT_IR_OF3IE(x, v) (HW_GPT_IR_WR(x, (HW_GPT_IR_RD(x) & ~BM_GPT_IR_OF3IE) | BF_GPT_IR_OF3IE(v)))
/*@}*/

/*!
 * @name Register GPT_IR, field IF1IE[3] (RW)
 *
 * See IF2IE
 */
/*@{*/
#define BP_GPT_IR_IF1IE      (3U)          /*!< Bit position for GPT_IR_IF1IE. */
#define BM_GPT_IR_IF1IE      (0x00000008U) /*!< Bit mask for GPT_IR_IF1IE. */
#define BS_GPT_IR_IF1IE      (1U)          /*!< Bit field size in bits for GPT_IR_IF1IE. */

/*! @brief Read current value of the GPT_IR_IF1IE field. */
#define BR_GPT_IR_IF1IE(x)   (HW_GPT_IR(x).B.IF1IE)

/*! @brief Format value for bitfield GPT_IR_IF1IE. */
#define BF_GPT_IR_IF1IE(v)   ((uint32_t)((uint32_t)(v) << BP_GPT_IR_IF1IE) & BM_GPT_IR_IF1IE)

/*! @brief Set the IF1IE field to a new value. */
#define BW_GPT_IR_IF1IE(x, v) (HW_GPT_IR_WR(x, (HW_GPT_IR_RD(x) & ~BM_GPT_IR_IF1IE) | BF_GPT_IR_IF1IE(v)))
/*@}*/

/*!
 * @name Register GPT_IR, field IF2IE[4] (RW)
 *
 * IF2IE Input capture 2 Interrupt Enable IF1IE Input capture 1 Interrupt Enable
 * The IFnIE bit controls the IFnIE Input Capture n Interrupt Enable.
 *
 * Values:
 * - 0 - IF2IE Input Capture n Interrupt Enable is disabled.
 * - 1 - IF2IE Input Capture n Interrupt Enable is enabled.
 */
/*@{*/
#define BP_GPT_IR_IF2IE      (4U)          /*!< Bit position for GPT_IR_IF2IE. */
#define BM_GPT_IR_IF2IE      (0x00000010U) /*!< Bit mask for GPT_IR_IF2IE. */
#define BS_GPT_IR_IF2IE      (1U)          /*!< Bit field size in bits for GPT_IR_IF2IE. */

/*! @brief Read current value of the GPT_IR_IF2IE field. */
#define BR_GPT_IR_IF2IE(x)   (HW_GPT_IR(x).B.IF2IE)

/*! @brief Format value for bitfield GPT_IR_IF2IE. */
#define BF_GPT_IR_IF2IE(v)   ((uint32_t)((uint32_t)(v) << BP_GPT_IR_IF2IE) & BM_GPT_IR_IF2IE)

/*! @brief Set the IF2IE field to a new value. */
#define BW_GPT_IR_IF2IE(x, v) (HW_GPT_IR_WR(x, (HW_GPT_IR_RD(x) & ~BM_GPT_IR_IF2IE) | BF_GPT_IR_IF2IE(v)))
/*@}*/

/*!
 * @name Register GPT_IR, field ROVIE[5] (RW)
 *
 * Rollover Interrupt Enable. The ROVIE bit controls the Rollover interrupt.
 *
 * Values:
 * - 0 - Rollover interrupt is disabled.
 * - 1 - Rollover interrupt enabled.
 */
/*@{*/
#define BP_GPT_IR_ROVIE      (5U)          /*!< Bit position for GPT_IR_ROVIE. */
#define BM_GPT_IR_ROVIE      (0x00000020U) /*!< Bit mask for GPT_IR_ROVIE. */
#define BS_GPT_IR_ROVIE      (1U)          /*!< Bit field size in bits for GPT_IR_ROVIE. */

/*! @brief Read current value of the GPT_IR_ROVIE field. */
#define BR_GPT_IR_ROVIE(x)   (HW_GPT_IR(x).B.ROVIE)

/*! @brief Format value for bitfield GPT_IR_ROVIE. */
#define BF_GPT_IR_ROVIE(v)   ((uint32_t)((uint32_t)(v) << BP_GPT_IR_ROVIE) & BM_GPT_IR_ROVIE)

/*! @brief Set the ROVIE field to a new value. */
#define BW_GPT_IR_ROVIE(x, v) (HW_GPT_IR_WR(x, (HW_GPT_IR_RD(x) & ~BM_GPT_IR_ROVIE) | BF_GPT_IR_ROVIE(v)))
/*@}*/

/*******************************************************************************
 * HW_GPT_OCR1 - GPT Output Compare Register 1
 ******************************************************************************/

/*!
 * @brief HW_GPT_OCR1 - GPT Output Compare Register 1 (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * The GPT Compare Register 1 (GPT_OCR1) holds the value that determines when a
 * compare event will be generated on Output Compare Channel 1. Any write access
 * to the Compare register of Channel 1 while in Restart mode (FRR=0) will reset
 * the GPT counter. An IP Bus Write access to the GPT Output Compare Register1
 * (GPT_OCR1) occurs after one cycle of wait state; an IP Bus Read access occurs
 * immediately (0 wait states).
 */
typedef union _hw_gpt_ocr1
{
    uint32_t U;
    struct _hw_gpt_ocr1_bitfields
    {
        uint32_t COMP : 32;            /*!< [31:0]  */
    } B;
} hw_gpt_ocr1_t;

/*!
 * @name Constants and macros for entire GPT_OCR1 register
 */
/*@{*/
#define HW_GPT_OCR1_ADDR(x)      ((uintptr_t)(x) + 0x10U)

#define HW_GPT_OCR1(x)           (*(__IO hw_gpt_ocr1_t *) HW_GPT_OCR1_ADDR(x))
#define HW_GPT_OCR1_RD(x)        (HW_GPT_OCR1(x).U)
#define HW_GPT_OCR1_WR(x, v)     (HW_GPT_OCR1(x).U = (v))
#define HW_GPT_OCR1_SET(x, v)    (HW_GPT_OCR1_WR(x, HW_GPT_OCR1_RD(x) |  (v)))
#define HW_GPT_OCR1_CLR(x, v)    (HW_GPT_OCR1_WR(x, HW_GPT_OCR1_RD(x) & ~(v)))
#define HW_GPT_OCR1_TOG(x, v)    (HW_GPT_OCR1_WR(x, HW_GPT_OCR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPT_OCR1 bitfields
 */

/*!
 * @name Register GPT_OCR1, field COMP[31:0] (RW)
 *
 * Compare Value. When the counter value equals the COMP bit field value, a
 * compare event is generated on Output Compare Channel 1.
 */
/*@{*/
#define BP_GPT_OCR1_COMP     (0U)          /*!< Bit position for GPT_OCR1_COMP. */
#define BM_GPT_OCR1_COMP     (0xFFFFFFFFU) /*!< Bit mask for GPT_OCR1_COMP. */
#define BS_GPT_OCR1_COMP     (32U)         /*!< Bit field size in bits for GPT_OCR1_COMP. */

/*! @brief Read current value of the GPT_OCR1_COMP field. */
#define BR_GPT_OCR1_COMP(x)  (HW_GPT_OCR1(x).U)

/*! @brief Format value for bitfield GPT_OCR1_COMP. */
#define BF_GPT_OCR1_COMP(v)  ((uint32_t)((uint32_t)(v) << BP_GPT_OCR1_COMP) & BM_GPT_OCR1_COMP)

/*! @brief Set the COMP field to a new value. */
#define BW_GPT_OCR1_COMP(x, v) (HW_GPT_OCR1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPT_OCR2 - GPT Output Compare Register 2
 ******************************************************************************/

/*!
 * @brief HW_GPT_OCR2 - GPT Output Compare Register 2 (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * The GPT Compare Register 2 (GPT_OCR2) holds the value that determines when a
 * compare event will be generated on Output Compare Channel 2.
 */
typedef union _hw_gpt_ocr2
{
    uint32_t U;
    struct _hw_gpt_ocr2_bitfields
    {
        uint32_t COMP : 32;            /*!< [31:0]  */
    } B;
} hw_gpt_ocr2_t;

/*!
 * @name Constants and macros for entire GPT_OCR2 register
 */
/*@{*/
#define HW_GPT_OCR2_ADDR(x)      ((uintptr_t)(x) + 0x14U)

#define HW_GPT_OCR2(x)           (*(__IO hw_gpt_ocr2_t *) HW_GPT_OCR2_ADDR(x))
#define HW_GPT_OCR2_RD(x)        (HW_GPT_OCR2(x).U)
#define HW_GPT_OCR2_WR(x, v)     (HW_GPT_OCR2(x).U = (v))
#define HW_GPT_OCR2_SET(x, v)    (HW_GPT_OCR2_WR(x, HW_GPT_OCR2_RD(x) |  (v)))
#define HW_GPT_OCR2_CLR(x, v)    (HW_GPT_OCR2_WR(x, HW_GPT_OCR2_RD(x) & ~(v)))
#define HW_GPT_OCR2_TOG(x, v)    (HW_GPT_OCR2_WR(x, HW_GPT_OCR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPT_OCR2 bitfields
 */

/*!
 * @name Register GPT_OCR2, field COMP[31:0] (RW)
 *
 * Compare Value. When the counter value equals the COMP bit field value, a
 * compare event is generated on Output Compare Channel 2.
 */
/*@{*/
#define BP_GPT_OCR2_COMP     (0U)          /*!< Bit position for GPT_OCR2_COMP. */
#define BM_GPT_OCR2_COMP     (0xFFFFFFFFU) /*!< Bit mask for GPT_OCR2_COMP. */
#define BS_GPT_OCR2_COMP     (32U)         /*!< Bit field size in bits for GPT_OCR2_COMP. */

/*! @brief Read current value of the GPT_OCR2_COMP field. */
#define BR_GPT_OCR2_COMP(x)  (HW_GPT_OCR2(x).U)

/*! @brief Format value for bitfield GPT_OCR2_COMP. */
#define BF_GPT_OCR2_COMP(v)  ((uint32_t)((uint32_t)(v) << BP_GPT_OCR2_COMP) & BM_GPT_OCR2_COMP)

/*! @brief Set the COMP field to a new value. */
#define BW_GPT_OCR2_COMP(x, v) (HW_GPT_OCR2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPT_OCR3 - GPT Output Compare Register 3
 ******************************************************************************/

/*!
 * @brief HW_GPT_OCR3 - GPT Output Compare Register 3 (RW)
 *
 * Reset value: 0xFFFFFFFFU
 *
 * The GPT Compare Register 3 (GPT_OCR3) holds the value that determines when a
 * compare event will be generated on Output Compare Channel 3.
 */
typedef union _hw_gpt_ocr3
{
    uint32_t U;
    struct _hw_gpt_ocr3_bitfields
    {
        uint32_t COMP : 32;            /*!< [31:0]  */
    } B;
} hw_gpt_ocr3_t;

/*!
 * @name Constants and macros for entire GPT_OCR3 register
 */
/*@{*/
#define HW_GPT_OCR3_ADDR(x)      ((uintptr_t)(x) + 0x18U)

#define HW_GPT_OCR3(x)           (*(__IO hw_gpt_ocr3_t *) HW_GPT_OCR3_ADDR(x))
#define HW_GPT_OCR3_RD(x)        (HW_GPT_OCR3(x).U)
#define HW_GPT_OCR3_WR(x, v)     (HW_GPT_OCR3(x).U = (v))
#define HW_GPT_OCR3_SET(x, v)    (HW_GPT_OCR3_WR(x, HW_GPT_OCR3_RD(x) |  (v)))
#define HW_GPT_OCR3_CLR(x, v)    (HW_GPT_OCR3_WR(x, HW_GPT_OCR3_RD(x) & ~(v)))
#define HW_GPT_OCR3_TOG(x, v)    (HW_GPT_OCR3_WR(x, HW_GPT_OCR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual GPT_OCR3 bitfields
 */

/*!
 * @name Register GPT_OCR3, field COMP[31:0] (RW)
 *
 * Compare Value. When the counter value equals the COMP bit field value, a
 * compare event is generated on Output Compare Channel 3.
 */
/*@{*/
#define BP_GPT_OCR3_COMP     (0U)          /*!< Bit position for GPT_OCR3_COMP. */
#define BM_GPT_OCR3_COMP     (0xFFFFFFFFU) /*!< Bit mask for GPT_OCR3_COMP. */
#define BS_GPT_OCR3_COMP     (32U)         /*!< Bit field size in bits for GPT_OCR3_COMP. */

/*! @brief Read current value of the GPT_OCR3_COMP field. */
#define BR_GPT_OCR3_COMP(x)  (HW_GPT_OCR3(x).U)

/*! @brief Format value for bitfield GPT_OCR3_COMP. */
#define BF_GPT_OCR3_COMP(v)  ((uint32_t)((uint32_t)(v) << BP_GPT_OCR3_COMP) & BM_GPT_OCR3_COMP)

/*! @brief Set the COMP field to a new value. */
#define BW_GPT_OCR3_COMP(x, v) (HW_GPT_OCR3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_GPT_ICR1 - GPT Input Capture Register 1
 ******************************************************************************/

/*!
 * @brief HW_GPT_ICR1 - GPT Input Capture Register 1 (RO)
 *
 * Reset value: 0x00000000U
 *
 * The GPT Input Capture Register 1 (GPT_ICR1) is a read-only register that
 * holds the value that was in the counter during the last capture event on Input
 * Capture Channel 1.
 */
typedef union _hw_gpt_icr1
{
    uint32_t U;
    struct _hw_gpt_icr1_bitfields
    {
        uint32_t CAPT : 32;            /*!< [31:0]  */
    } B;
} hw_gpt_icr1_t;

/*!
 * @name Constants and macros for entire GPT_ICR1 register
 */
/*@{*/
#define HW_GPT_ICR1_ADDR(x)      ((uintptr_t)(x) + 0x1CU)

#define HW_GPT_ICR1(x)           (*(__I hw_gpt_icr1_t *) HW_GPT_ICR1_ADDR(x))
#define HW_GPT_ICR1_RD(x)        (HW_GPT_ICR1(x).U)
/*@}*/

/*
 * Constants & macros for individual GPT_ICR1 bitfields
 */

/*!
 * @name Register GPT_ICR1, field CAPT[31:0] (RO)
 *
 * Capture Value. After a capture event on Input Capture Channel 1 occurs, the
 * current value of the counter is loaded into GPT Input Capture Register 1.
 */
/*@{*/
#define BP_GPT_ICR1_CAPT     (0U)          /*!< Bit position for GPT_ICR1_CAPT. */
#define BM_GPT_ICR1_CAPT     (0xFFFFFFFFU) /*!< Bit mask for GPT_ICR1_CAPT. */
#define BS_GPT_ICR1_CAPT     (32U)         /*!< Bit field size in bits for GPT_ICR1_CAPT. */

/*! @brief Read current value of the GPT_ICR1_CAPT field. */
#define BR_GPT_ICR1_CAPT(x)  (HW_GPT_ICR1(x).U)
/*@}*/

/*******************************************************************************
 * HW_GPT_ICR2 - GPT Input Capture Register 2
 ******************************************************************************/

/*!
 * @brief HW_GPT_ICR2 - GPT Input Capture Register 2 (RO)
 *
 * Reset value: 0x00000000U
 *
 * The GPT Input capture Register 2 (GPT_ICR2) is a read-only register which
 * holds the value that was in the counter during the last capture event on input
 * capture channel 2.
 */
typedef union _hw_gpt_icr2
{
    uint32_t U;
    struct _hw_gpt_icr2_bitfields
    {
        uint32_t CAPT : 32;            /*!< [31:0]  */
    } B;
} hw_gpt_icr2_t;

/*!
 * @name Constants and macros for entire GPT_ICR2 register
 */
/*@{*/
#define HW_GPT_ICR2_ADDR(x)      ((uintptr_t)(x) + 0x20U)

#define HW_GPT_ICR2(x)           (*(__I hw_gpt_icr2_t *) HW_GPT_ICR2_ADDR(x))
#define HW_GPT_ICR2_RD(x)        (HW_GPT_ICR2(x).U)
/*@}*/

/*
 * Constants & macros for individual GPT_ICR2 bitfields
 */

/*!
 * @name Register GPT_ICR2, field CAPT[31:0] (RO)
 *
 * Capture Value. After a capture event on Input Capture Channel 2 occurs, the
 * current value of the counter is loaded into GPT Input Capture Register 2.
 */
/*@{*/
#define BP_GPT_ICR2_CAPT     (0U)          /*!< Bit position for GPT_ICR2_CAPT. */
#define BM_GPT_ICR2_CAPT     (0xFFFFFFFFU) /*!< Bit mask for GPT_ICR2_CAPT. */
#define BS_GPT_ICR2_CAPT     (32U)         /*!< Bit field size in bits for GPT_ICR2_CAPT. */

/*! @brief Read current value of the GPT_ICR2_CAPT field. */
#define BR_GPT_ICR2_CAPT(x)  (HW_GPT_ICR2(x).U)
/*@}*/

/*******************************************************************************
 * HW_GPT_CNT - GPT Counter Register
 ******************************************************************************/

/*!
 * @brief HW_GPT_CNT - GPT Counter Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The GPT Counter Register (GPT_CNT) is the main counter's register. GPT_CNT is
 * a read-only register and can be read without affecting the counting process
 * of the GPT.
 */
typedef union _hw_gpt_cnt
{
    uint32_t U;
    struct _hw_gpt_cnt_bitfields
    {
        uint32_t COUNT : 32;           /*!< [31:0]  */
    } B;
} hw_gpt_cnt_t;

/*!
 * @name Constants and macros for entire GPT_CNT register
 */
/*@{*/
#define HW_GPT_CNT_ADDR(x)       ((uintptr_t)(x) + 0x24U)

#define HW_GPT_CNT(x)            (*(__I hw_gpt_cnt_t *) HW_GPT_CNT_ADDR(x))
#define HW_GPT_CNT_RD(x)         (HW_GPT_CNT(x).U)
/*@}*/

/*
 * Constants & macros for individual GPT_CNT bitfields
 */

/*!
 * @name Register GPT_CNT, field COUNT[31:0] (RO)
 *
 * Counter Value. The COUNT bits show the current count value of the GPT counter.
 */
/*@{*/
#define BP_GPT_CNT_COUNT     (0U)          /*!< Bit position for GPT_CNT_COUNT. */
#define BM_GPT_CNT_COUNT     (0xFFFFFFFFU) /*!< Bit mask for GPT_CNT_COUNT. */
#define BS_GPT_CNT_COUNT     (32U)         /*!< Bit field size in bits for GPT_CNT_COUNT. */

/*! @brief Read current value of the GPT_CNT_COUNT field. */
#define BR_GPT_CNT_COUNT(x)  (HW_GPT_CNT(x).U)
/*@}*/

/*******************************************************************************
 * hw_gpt_t - module struct
 ******************************************************************************/
/*!
 * @brief All GPT module registers.
 */
#pragma pack(1)
typedef struct _hw_gpt
{
    __IO hw_gpt_cr_t CR;                   /*!< [0x0] GPT Control Register */
    __IO hw_gpt_pr_t PR;                   /*!< [0x4] GPT Prescaler Register */
    __IO hw_gpt_sr_t SR;                   /*!< [0x8] GPT Status Register */
    __IO hw_gpt_ir_t IR;                   /*!< [0xC] GPT Interrupt Register */
    __IO hw_gpt_ocr1_t OCR1;               /*!< [0x10] GPT Output Compare Register 1 */
    __IO hw_gpt_ocr2_t OCR2;               /*!< [0x14] GPT Output Compare Register 2 */
    __IO hw_gpt_ocr3_t OCR3;               /*!< [0x18] GPT Output Compare Register 3 */
    __I hw_gpt_icr1_t ICR1;                /*!< [0x1C] GPT Input Capture Register 1 */
    __I hw_gpt_icr2_t ICR2;                /*!< [0x20] GPT Input Capture Register 2 */
    __I hw_gpt_cnt_t CNT;                  /*!< [0x24] GPT Counter Register */
} hw_gpt_t;
#pragma pack()

/*! @brief Macro to access all GPT registers. */
/*! @param x GPT module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_GPT_REGS(GPT1_BASE)</code>. */
#define HW_GPT_REGS(x) (*(hw_gpt_t *)(x))

/*
 * iMX7D I2C
 *
 * I2C Controller (I2C)
 *
 * Registers defined in this header file:
 * - HW_I2C_IADR - I2C Address Register
 * - HW_I2C_IFDR - I2C Frequency Divider Register
 * - HW_I2C_I2CR - I2C Control Register
 * - HW_I2C_I2SR - I2C Status Register
 * - HW_I2C_I2DR - I2C Data I/O Register
 *
 * - hw_i2c_t - Struct containing all module registers.
 */

#define HW_I2C_INSTANCE_COUNT (4U) /*!< Number of instances of the I2C module. */
#define HW_I2C1 (0U) /*!< Instance number for I2C1. */
#define HW_I2C2 (1U) /*!< Instance number for I2C2. */
#define HW_I2C3 (2U) /*!< Instance number for I2C3. */
#define HW_I2C4 (3U) /*!< Instance number for I2C4. */
#define I2C1_BASE             (0x30A20000U) /*!< Base address for I2C1. */
#define I2C2_BASE             (0x30A30000U) /*!< Base address for I2C2. */
#define I2C3_BASE             (0x30A40000U) /*!< Base address for I2C3. */
#define I2C4_BASE             (0x30A50000U) /*!< Base address for I2C4. */
/*! Array initializer of I2C base addresses. */
#define I2C_BASE_ADDRS        { I2C1_BASE, I2C2_BASE, I2C3_BASE, I2C4_BASE }

/*******************************************************************************
 * HW_I2C_IADR - I2C Address Register
 ******************************************************************************/

/*!
 * @brief HW_I2C_IADR - I2C Address Register (RW)
 *
 * Reset value: 0x0000U
 */
typedef union _hw_i2c_iadr
{
    uint16_t U;
    struct _hw_i2c_iadr_bitfields
    {
        uint16_t RESERVED0 : 1;        /*!< [0]  */
        uint16_t ADR : 7;              /*!< [7:1]  */
        uint16_t RESERVED1 : 8;        /*!< [15:8]  */
    } B;
} hw_i2c_iadr_t;

/*!
 * @name Constants and macros for entire I2C_IADR register
 */
/*@{*/
#define HW_I2C_IADR_ADDR(x)      ((uintptr_t)(x) + 0x0U)

#define HW_I2C_IADR(x)           (*(__IO hw_i2c_iadr_t *) HW_I2C_IADR_ADDR(x))
#define HW_I2C_IADR_RD(x)        (HW_I2C_IADR(x).U)
#define HW_I2C_IADR_WR(x, v)     (HW_I2C_IADR(x).U = (v))
#define HW_I2C_IADR_SET(x, v)    (HW_I2C_IADR_WR(x, HW_I2C_IADR_RD(x) |  (v)))
#define HW_I2C_IADR_CLR(x, v)    (HW_I2C_IADR_WR(x, HW_I2C_IADR_RD(x) & ~(v)))
#define HW_I2C_IADR_TOG(x, v)    (HW_I2C_IADR_WR(x, HW_I2C_IADR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2C_IADR bitfields
 */

/*!
 * @name Register I2C_IADR, field ADR[7:1] (RW)
 *
 * Slave address. Contains the specific slave address to be used by the I2C.
 * Slave mode is the default I2C mode for an address match on the bus. The I2C_IADR
 * holds the address to which the I2C responds when addressed as a slave. The
 * slave address is not the address sent on the bus during the address transfer. The
 * register is not reset by a software reset.
 */
/*@{*/
#define BP_I2C_IADR_ADR      (1U)          /*!< Bit position for I2C_IADR_ADR. */
#define BM_I2C_IADR_ADR      (0x00FEU)     /*!< Bit mask for I2C_IADR_ADR. */
#define BS_I2C_IADR_ADR      (7U)          /*!< Bit field size in bits for I2C_IADR_ADR. */

/*! @brief Read current value of the I2C_IADR_ADR field. */
#define BR_I2C_IADR_ADR(x)   (HW_I2C_IADR(x).B.ADR)

/*! @brief Format value for bitfield I2C_IADR_ADR. */
#define BF_I2C_IADR_ADR(v)   ((uint16_t)((uint16_t)(v) << BP_I2C_IADR_ADR) & BM_I2C_IADR_ADR)

/*! @brief Set the ADR field to a new value. */
#define BW_I2C_IADR_ADR(x, v) (HW_I2C_IADR_WR(x, (HW_I2C_IADR_RD(x) & ~BM_I2C_IADR_ADR) | BF_I2C_IADR_ADR(v)))
/*@}*/

/*******************************************************************************
 * HW_I2C_IFDR - I2C Frequency Divider Register
 ******************************************************************************/

/*!
 * @brief HW_I2C_IFDR - I2C Frequency Divider Register (RW)
 *
 * Reset value: 0x0000U
 *
 * The I2C_IFDR provides a programmable prescaler to configure the clock for
 * bit-rate selection. The register does not get reset by a software reset. The
 * following table describes the divider and register values for the register field
 * "IC." I2C_IFDR Register Field Values IC Divider IC Divider IC Divider IC
 * Divider 0x00 30 0x10 288 0x20 22 0x30 160 0x01 32 0x11 320 0x21 24 0x31 192 0x02 36
 * 0x12 384 0x22 26 0x32 224 0x03 42 0x13 480 0x23 28 0x33 256 0x04 48 0x14 576
 * 0x24 32 0x34 320 0x05 52 0x15 640 0x25 36 0x35 384 0x06 60 0x16 768 0x26 40
 * 0x36 448 0x07 72 0x17 960 0x27 44 0x37 512 0x08 80 0x18 1152 0x28 48 0x38 640
 * 0x09 88 0x19 1280 0x29 56 0x39 768 0x0A 104 0x1A 1536 0x2A 64 0x3A 896 0x0B 128
 * 0x1B 1920 0x2B 72 0x3B 1024 0x0C 144 0x1C 2304 0x2C 80 0x3C 1280 0x0D 160 0x1D
 * 2560 0x2D 96 0x3D 1536 0x0E 192 0x1E 3072 0x2E 112 0x3E 1792 0x0F 240 0x1F
 * 3840 0x2F 128 0x3F 2048
 */
typedef union _hw_i2c_ifdr
{
    uint16_t U;
    struct _hw_i2c_ifdr_bitfields
    {
        uint16_t IC : 6;               /*!< [5:0]  */
        uint16_t RESERVED0 : 10;       /*!< [15:6]  */
    } B;
} hw_i2c_ifdr_t;

/*!
 * @name Constants and macros for entire I2C_IFDR register
 */
/*@{*/
#define HW_I2C_IFDR_ADDR(x)      ((uintptr_t)(x) + 0x4U)

#define HW_I2C_IFDR(x)           (*(__IO hw_i2c_ifdr_t *) HW_I2C_IFDR_ADDR(x))
#define HW_I2C_IFDR_RD(x)        (HW_I2C_IFDR(x).U)
#define HW_I2C_IFDR_WR(x, v)     (HW_I2C_IFDR(x).U = (v))
#define HW_I2C_IFDR_SET(x, v)    (HW_I2C_IFDR_WR(x, HW_I2C_IFDR_RD(x) |  (v)))
#define HW_I2C_IFDR_CLR(x, v)    (HW_I2C_IFDR_WR(x, HW_I2C_IFDR_RD(x) & ~(v)))
#define HW_I2C_IFDR_TOG(x, v)    (HW_I2C_IFDR_WR(x, HW_I2C_IFDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2C_IFDR bitfields
 */

/*!
 * @name Register I2C_IFDR, field IC[5:0] (RW)
 *
 * I2C clock rate. Prescales the clock for bit-rate selection. Due to
 * potentially slow I2Cn_SCL and I2Cn_SDA rise and fall times, bus signals are sampled at
 * the prescaler frequency. The serial bit clock frequency may be lower than
 * IPG_CLK_ROOT divided by the divider shown in the I2C Data I/O Register. The IC
 * value should not be changed during the data transfer, however, it can be changed
 * before a Repeat Start or Start programming sequence in I2C. The I2C protocol
 * supports bit rates of up to 400 kbps. The IC bits need to be programmed in
 * accordance with this constraint.
 */
/*@{*/
#define BP_I2C_IFDR_IC       (0U)          /*!< Bit position for I2C_IFDR_IC. */
#define BM_I2C_IFDR_IC       (0x003FU)     /*!< Bit mask for I2C_IFDR_IC. */
#define BS_I2C_IFDR_IC       (6U)          /*!< Bit field size in bits for I2C_IFDR_IC. */

/*! @brief Read current value of the I2C_IFDR_IC field. */
#define BR_I2C_IFDR_IC(x)    (HW_I2C_IFDR(x).B.IC)

/*! @brief Format value for bitfield I2C_IFDR_IC. */
#define BF_I2C_IFDR_IC(v)    ((uint16_t)((uint16_t)(v) << BP_I2C_IFDR_IC) & BM_I2C_IFDR_IC)

/*! @brief Set the IC field to a new value. */
#define BW_I2C_IFDR_IC(x, v) (HW_I2C_IFDR_WR(x, (HW_I2C_IFDR_RD(x) & ~BM_I2C_IFDR_IC) | BF_I2C_IFDR_IC(v)))
/*@}*/

/*******************************************************************************
 * HW_I2C_I2CR - I2C Control Register
 ******************************************************************************/

/*!
 * @brief HW_I2C_I2CR - I2C Control Register (RW)
 *
 * Reset value: 0x0000U
 *
 * The I2C_I2CR is used to enable the I2C and the I2C interrupt. It also
 * contains bits that govern operation as a slave or a master.
 */
typedef union _hw_i2c_i2cr
{
    uint16_t U;
    struct _hw_i2c_i2cr_bitfields
    {
        uint16_t RESERVED0 : 2;        /*!< [1:0]  */
        uint16_t RSTA : 1;             /*!< [2]  */
        uint16_t TXAK : 1;             /*!< [3]  */
        uint16_t MTX : 1;              /*!< [4]  */
        uint16_t MSTA : 1;             /*!< [5]  */
        uint16_t IIEN : 1;             /*!< [6]  */
        uint16_t IEN : 1;              /*!< [7]  */
        uint16_t RESERVED1 : 8;        /*!< [15:8]  */
    } B;
} hw_i2c_i2cr_t;

/*!
 * @name Constants and macros for entire I2C_I2CR register
 */
/*@{*/
#define HW_I2C_I2CR_ADDR(x)      ((uintptr_t)(x) + 0x8U)

#define HW_I2C_I2CR(x)           (*(__IO hw_i2c_i2cr_t *) HW_I2C_I2CR_ADDR(x))
#define HW_I2C_I2CR_RD(x)        (HW_I2C_I2CR(x).U)
#define HW_I2C_I2CR_WR(x, v)     (HW_I2C_I2CR(x).U = (v))
#define HW_I2C_I2CR_SET(x, v)    (HW_I2C_I2CR_WR(x, HW_I2C_I2CR_RD(x) |  (v)))
#define HW_I2C_I2CR_CLR(x, v)    (HW_I2C_I2CR_WR(x, HW_I2C_I2CR_RD(x) & ~(v)))
#define HW_I2C_I2CR_TOG(x, v)    (HW_I2C_I2CR_WR(x, HW_I2C_I2CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2C_I2CR bitfields
 */

/*!
 * @name Register I2C_I2CR, field RSTA[2] (WORZ)
 *
 * Repeat start. Always reads as 0. Attempting a repeat start without bus
 * mastership causes loss of arbitration.
 *
 * Values:
 * - 0 - No repeat start
 * - 1 - Generates a Repeated Start condition
 */
/*@{*/
#define BP_I2C_I2CR_RSTA     (2U)          /*!< Bit position for I2C_I2CR_RSTA. */
#define BM_I2C_I2CR_RSTA     (0x0004U)     /*!< Bit mask for I2C_I2CR_RSTA. */
#define BS_I2C_I2CR_RSTA     (1U)          /*!< Bit field size in bits for I2C_I2CR_RSTA. */

/*! @brief Format value for bitfield I2C_I2CR_RSTA. */
#define BF_I2C_I2CR_RSTA(v)  ((uint16_t)((uint16_t)(v) << BP_I2C_I2CR_RSTA) & BM_I2C_I2CR_RSTA)

/*! @brief Set the RSTA field to a new value. */
#define BW_I2C_I2CR_RSTA(x, v) (HW_I2C_I2CR_WR(x, (HW_I2C_I2CR_RD(x) & ~BM_I2C_I2CR_RSTA) | BF_I2C_I2CR_RSTA(v)))
/*@}*/

/*!
 * @name Register I2C_I2CR, field TXAK[3] (RW)
 *
 * Transmit acknowledge enable. Specifies the value driven onto I2Cn_SDA during
 * acknowledge cycles for both master and slave receivers. Writing TXAK applies
 * only when the I2C bus is a receiver.
 *
 * Values:
 * - 0 - An acknowledge signal is sent to the bus at the ninth clock bit after
 *     receiving one byte of data.
 * - 1 - No acknowledge signal response is sent (that is, the acknowledge bit =
 *     1).
 */
/*@{*/
#define BP_I2C_I2CR_TXAK     (3U)          /*!< Bit position for I2C_I2CR_TXAK. */
#define BM_I2C_I2CR_TXAK     (0x0008U)     /*!< Bit mask for I2C_I2CR_TXAK. */
#define BS_I2C_I2CR_TXAK     (1U)          /*!< Bit field size in bits for I2C_I2CR_TXAK. */

/*! @brief Read current value of the I2C_I2CR_TXAK field. */
#define BR_I2C_I2CR_TXAK(x)  (HW_I2C_I2CR(x).B.TXAK)

/*! @brief Format value for bitfield I2C_I2CR_TXAK. */
#define BF_I2C_I2CR_TXAK(v)  ((uint16_t)((uint16_t)(v) << BP_I2C_I2CR_TXAK) & BM_I2C_I2CR_TXAK)

/*! @brief Set the TXAK field to a new value. */
#define BW_I2C_I2CR_TXAK(x, v) (HW_I2C_I2CR_WR(x, (HW_I2C_I2CR_RD(x) & ~BM_I2C_I2CR_TXAK) | BF_I2C_I2CR_TXAK(v)))
/*@}*/

/*!
 * @name Register I2C_I2CR, field MTX[4] (RW)
 *
 * Transmit/Receive mode select bit. Selects the direction of master and slave
 * transfers.
 *
 * Values:
 * - 0 - Receive.When a slave is addressed, the software should set MTX
 *     according to the slave read/write bit in the I2C status register (I2C_I2SR[SRW]).
 * - 1 - Transmit.In Master mode, MTX should be set according to the type of
 *     transfer required. Therefore, for address cycles, MTX is always 1.
 */
/*@{*/
#define BP_I2C_I2CR_MTX      (4U)          /*!< Bit position for I2C_I2CR_MTX. */
#define BM_I2C_I2CR_MTX      (0x0010U)     /*!< Bit mask for I2C_I2CR_MTX. */
#define BS_I2C_I2CR_MTX      (1U)          /*!< Bit field size in bits for I2C_I2CR_MTX. */

/*! @brief Read current value of the I2C_I2CR_MTX field. */
#define BR_I2C_I2CR_MTX(x)   (HW_I2C_I2CR(x).B.MTX)

/*! @brief Format value for bitfield I2C_I2CR_MTX. */
#define BF_I2C_I2CR_MTX(v)   ((uint16_t)((uint16_t)(v) << BP_I2C_I2CR_MTX) & BM_I2C_I2CR_MTX)

/*! @brief Set the MTX field to a new value. */
#define BW_I2C_I2CR_MTX(x, v) (HW_I2C_I2CR_WR(x, (HW_I2C_I2CR_RD(x) & ~BM_I2C_I2CR_MTX) | BF_I2C_I2CR_MTX(v)))
/*@}*/

/*!
 * @name Register I2C_I2CR, field MSTA[5] (RW)
 *
 * Master/Slave mode select bit. If the master loses arbitration, MSTA is
 * cleared without generating a Stop signal. The module clock should be on for writing
 * to the MSTA bit. The MSTA bit is cleared by software to generate a Stop
 * condition; it can also be cleared by hardware when the I2C loses the bus arbitration.
 *
 * Values:
 * - 0 - Slave mode. Changing MSTA from 1 to 0 generates a Stop and selects
 *     Slave mode.
 * - 1 - Master mode. Changing MSTA from 0 to 1 signals a Start on the bus and
 *     selects Master mode.
 */
/*@{*/
#define BP_I2C_I2CR_MSTA     (5U)          /*!< Bit position for I2C_I2CR_MSTA. */
#define BM_I2C_I2CR_MSTA     (0x0020U)     /*!< Bit mask for I2C_I2CR_MSTA. */
#define BS_I2C_I2CR_MSTA     (1U)          /*!< Bit field size in bits for I2C_I2CR_MSTA. */

/*! @brief Read current value of the I2C_I2CR_MSTA field. */
#define BR_I2C_I2CR_MSTA(x)  (HW_I2C_I2CR(x).B.MSTA)

/*! @brief Format value for bitfield I2C_I2CR_MSTA. */
#define BF_I2C_I2CR_MSTA(v)  ((uint16_t)((uint16_t)(v) << BP_I2C_I2CR_MSTA) & BM_I2C_I2CR_MSTA)

/*! @brief Set the MSTA field to a new value. */
#define BW_I2C_I2CR_MSTA(x, v) (HW_I2C_I2CR_WR(x, (HW_I2C_I2CR_RD(x) & ~BM_I2C_I2CR_MSTA) | BF_I2C_I2CR_MSTA(v)))
/*@}*/

/*!
 * @name Register I2C_I2CR, field IIEN[6] (RW)
 *
 * I2C interrupt enable. If data is written during the Start condition, that is,
 * just after setting the I2C_I2CR[MSTA] and I2C_I2CR[MTX] bits, then the ICF
 * bit is cleared at the falling edge of SCLK after Start. If data is written after
 * the Start condition and falling edge of SCLK, then the ICF bit is cleared as
 * soon as data is written.
 *
 * Values:
 * - 0 - I2C interrupts are disabled, but the status flag I2C_I2SR[IIF]
 *     continues to be set when an Interrupt condition occurs.
 * - 1 - I2C interrupts are enabled. An I2C interrupt occurs if I2C_I2SR[IIF] is
 *     also set.
 */
/*@{*/
#define BP_I2C_I2CR_IIEN     (6U)          /*!< Bit position for I2C_I2CR_IIEN. */
#define BM_I2C_I2CR_IIEN     (0x0040U)     /*!< Bit mask for I2C_I2CR_IIEN. */
#define BS_I2C_I2CR_IIEN     (1U)          /*!< Bit field size in bits for I2C_I2CR_IIEN. */

/*! @brief Read current value of the I2C_I2CR_IIEN field. */
#define BR_I2C_I2CR_IIEN(x)  (HW_I2C_I2CR(x).B.IIEN)

/*! @brief Format value for bitfield I2C_I2CR_IIEN. */
#define BF_I2C_I2CR_IIEN(v)  ((uint16_t)((uint16_t)(v) << BP_I2C_I2CR_IIEN) & BM_I2C_I2CR_IIEN)

/*! @brief Set the IIEN field to a new value. */
#define BW_I2C_I2CR_IIEN(x, v) (HW_I2C_I2CR_WR(x, (HW_I2C_I2CR_RD(x) & ~BM_I2C_I2CR_IIEN) | BF_I2C_I2CR_IIEN(v)))
/*@}*/

/*!
 * @name Register I2C_I2CR, field IEN[7] (RW)
 *
 * I2C enable. Also controls the software reset of the entire I2C. Resetting the
 * bit generates an internal reset to the block. If the block is enabled in the
 * middle of a byte transfer, Slave mode ignores the current bus transfer and
 * starts operating when the next Start condition is detected. Master mode is not
 * aware that the bus is busy, so initiating a start cycle may corrupt the current
 * bus cycle, ultimately causing either the current master or the I2C to lose
 * arbitration. Subsequently, bus operation returns to normal.
 *
 * Values:
 * - 0 - The block is disabled, but registers can still be accessed.
 * - 1 - The I2C is enabled. This bit must be set before any other I2C_I2CR bits
 *     have an effect.
 */
/*@{*/
#define BP_I2C_I2CR_IEN      (7U)          /*!< Bit position for I2C_I2CR_IEN. */
#define BM_I2C_I2CR_IEN      (0x0080U)     /*!< Bit mask for I2C_I2CR_IEN. */
#define BS_I2C_I2CR_IEN      (1U)          /*!< Bit field size in bits for I2C_I2CR_IEN. */

/*! @brief Read current value of the I2C_I2CR_IEN field. */
#define BR_I2C_I2CR_IEN(x)   (HW_I2C_I2CR(x).B.IEN)

/*! @brief Format value for bitfield I2C_I2CR_IEN. */
#define BF_I2C_I2CR_IEN(v)   ((uint16_t)((uint16_t)(v) << BP_I2C_I2CR_IEN) & BM_I2C_I2CR_IEN)

/*! @brief Set the IEN field to a new value. */
#define BW_I2C_I2CR_IEN(x, v) (HW_I2C_I2CR_WR(x, (HW_I2C_I2CR_RD(x) & ~BM_I2C_I2CR_IEN) | BF_I2C_I2CR_IEN(v)))
/*@}*/

/*******************************************************************************
 * HW_I2C_I2SR - I2C Status Register
 ******************************************************************************/

/*!
 * @brief HW_I2C_I2SR - I2C Status Register (RW)
 *
 * Reset value: 0x0081U
 *
 * The I2C_I2SR contains bits that indicate transaction direction and status.
 */
typedef union _hw_i2c_i2sr
{
    uint16_t U;
    struct _hw_i2c_i2sr_bitfields
    {
        uint16_t RXAK : 1;             /*!< [0]  */
        uint16_t IIF : 1;              /*!< [1]  */
        uint16_t SRW : 1;              /*!< [2]  */
        uint16_t RESERVED0 : 1;        /*!< [3]  */
        uint16_t IAL : 1;              /*!< [4]  */
        uint16_t IBB : 1;              /*!< [5]  */
        uint16_t IAAS : 1;             /*!< [6]  */
        uint16_t ICF : 1;              /*!< [7]  */
        uint16_t RESERVED1 : 8;        /*!< [15:8]  */
    } B;
} hw_i2c_i2sr_t;

/*!
 * @name Constants and macros for entire I2C_I2SR register
 */
/*@{*/
#define HW_I2C_I2SR_ADDR(x)      ((uintptr_t)(x) + 0xCU)

#define HW_I2C_I2SR(x)           (*(__IO hw_i2c_i2sr_t *) HW_I2C_I2SR_ADDR(x))
#define HW_I2C_I2SR_RD(x)        (HW_I2C_I2SR(x).U)
#define HW_I2C_I2SR_WR(x, v)     (HW_I2C_I2SR(x).U = (v))
#define HW_I2C_I2SR_SET(x, v)    (HW_I2C_I2SR_WR(x, HW_I2C_I2SR_RD(x) |  (v)))
#define HW_I2C_I2SR_CLR(x, v)    (HW_I2C_I2SR_WR(x, HW_I2C_I2SR_RD(x) & ~(v)))
#define HW_I2C_I2SR_TOG(x, v)    (HW_I2C_I2SR_WR(x, HW_I2C_I2SR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2C_I2SR bitfields
 */

/*!
 * @name Register I2C_I2SR, field RXAK[0] (RO)
 *
 * Received acknowledge. This is the value received from the I2Cn_SDA input for
 * the acknowledge bit during a bus cycle.
 *
 * Values:
 * - 0 - An "acknowledge" signal was received after the completion of an 8-bit
 *     data transmission on the bus.
 * - 1 - A "No acknowledge" signal was detected at the ninth clock.
 */
/*@{*/
#define BP_I2C_I2SR_RXAK     (0U)          /*!< Bit position for I2C_I2SR_RXAK. */
#define BM_I2C_I2SR_RXAK     (0x0001U)     /*!< Bit mask for I2C_I2SR_RXAK. */
#define BS_I2C_I2SR_RXAK     (1U)          /*!< Bit field size in bits for I2C_I2SR_RXAK. */

/*! @brief Read current value of the I2C_I2SR_RXAK field. */
#define BR_I2C_I2SR_RXAK(x)  (HW_I2C_I2SR(x).B.RXAK)
/*@}*/

/*!
 * @name Register I2C_I2SR, field IIF[1] (RW)
 *
 * I2C interrupt. Must be cleared by the software by writing a "0" to it in the
 * interrupt routine. The software cannot set the bit.
 *
 * Values:
 * - 0 - No I2C interrupt pending.
 * - 1 - An interrupt is pending.This causes a processor interrupt request (if
 *     the interrupt enable is asserted [IIEN = 1]). The interrupt is set when one
 *     of the following occurs: One byte transfer is completed (the interrupt is
 *     set at the falling edge of the ninth clock). An address is received that
 *     matches its own specific address in Slave Receive mode. Arbitration is
 *     lost.
 */
/*@{*/
#define BP_I2C_I2SR_IIF      (1U)          /*!< Bit position for I2C_I2SR_IIF. */
#define BM_I2C_I2SR_IIF      (0x0002U)     /*!< Bit mask for I2C_I2SR_IIF. */
#define BS_I2C_I2SR_IIF      (1U)          /*!< Bit field size in bits for I2C_I2SR_IIF. */

/*! @brief Read current value of the I2C_I2SR_IIF field. */
#define BR_I2C_I2SR_IIF(x)   (HW_I2C_I2SR(x).B.IIF)

/*! @brief Format value for bitfield I2C_I2SR_IIF. */
#define BF_I2C_I2SR_IIF(v)   ((uint16_t)((uint16_t)(v) << BP_I2C_I2SR_IIF) & BM_I2C_I2SR_IIF)

/*! @brief Set the IIF field to a new value. */
#define BW_I2C_I2SR_IIF(x, v) (HW_I2C_I2SR_WR(x, (HW_I2C_I2SR_RD(x) & ~BM_I2C_I2SR_IIF) | BF_I2C_I2SR_IIF(v)))
/*@}*/

/*!
 * @name Register I2C_I2SR, field SRW[2] (RO)
 *
 * Slave read/write. When the I2C is addressed as a slave, IAAS is set, and the
 * slave read/write bit (SRW) indicates the value of the R/W command bit of the
 * calling address sent from the master. SRW is valid only when a complete
 * transfer has occurred, no other transfers have been initiated, and the I2C is a slave
 * and has an address match.
 *
 * Values:
 * - 0 - Slave receive, master writing to slave
 * - 1 - Slave transmit, master reading from slave
 */
/*@{*/
#define BP_I2C_I2SR_SRW      (2U)          /*!< Bit position for I2C_I2SR_SRW. */
#define BM_I2C_I2SR_SRW      (0x0004U)     /*!< Bit mask for I2C_I2SR_SRW. */
#define BS_I2C_I2SR_SRW      (1U)          /*!< Bit field size in bits for I2C_I2SR_SRW. */

/*! @brief Read current value of the I2C_I2SR_SRW field. */
#define BR_I2C_I2SR_SRW(x)   (HW_I2C_I2SR(x).B.SRW)
/*@}*/

/*!
 * @name Register I2C_I2SR, field IAL[4] (RW)
 *
 * Arbitration lost. Set by hardware in the following circumstances (IAL must be
 * cleared by software by writing a "0" to it at the start of the interrupt
 * service routine): I2Cn_SDA input samples low when the master drives high during an
 * address or data-transmit cycle. I2Cn_SDA input samples low when the master
 * drives high during the acknowledge bit of a data-receive cycle. For the above
 * two cases, the bit is set at the falling edge of the ninth I2Cn_SCL clock during
 * the ACK cycle. A Start cycle is attempted when the bus is busy. A Repeated
 * Start cycle is requested in Slave mode. A Stop condition is detected when the
 * master did not request it. Software cannot set the bit.
 *
 * Values:
 * - 0 - No arbitration lost.
 * - 1 - Arbitration is lost.
 */
/*@{*/
#define BP_I2C_I2SR_IAL      (4U)          /*!< Bit position for I2C_I2SR_IAL. */
#define BM_I2C_I2SR_IAL      (0x0010U)     /*!< Bit mask for I2C_I2SR_IAL. */
#define BS_I2C_I2SR_IAL      (1U)          /*!< Bit field size in bits for I2C_I2SR_IAL. */

/*! @brief Read current value of the I2C_I2SR_IAL field. */
#define BR_I2C_I2SR_IAL(x)   (HW_I2C_I2SR(x).B.IAL)

/*! @brief Format value for bitfield I2C_I2SR_IAL. */
#define BF_I2C_I2SR_IAL(v)   ((uint16_t)((uint16_t)(v) << BP_I2C_I2SR_IAL) & BM_I2C_I2SR_IAL)

/*! @brief Set the IAL field to a new value. */
#define BW_I2C_I2SR_IAL(x, v) (HW_I2C_I2SR_WR(x, (HW_I2C_I2SR_RD(x) & ~BM_I2C_I2SR_IAL) | BF_I2C_I2SR_IAL(v)))
/*@}*/

/*!
 * @name Register I2C_I2SR, field IBB[5] (RO)
 *
 * I2C bus busy bit. Indicates the status of the bus. When I2C is enabled
 * (I2C_I2CR[IEN] = 1), it continuously polls the bus data (SDA) and clock (SCL)
 * signals to determine a Start or Stop condition.
 *
 * Values:
 * - 0 - Bus is idle. If a Stop signal is detected, IBB is cleared.
 * - 1 - Bus is busy. When Start is detected, IBB is set.
 */
/*@{*/
#define BP_I2C_I2SR_IBB      (5U)          /*!< Bit position for I2C_I2SR_IBB. */
#define BM_I2C_I2SR_IBB      (0x0020U)     /*!< Bit mask for I2C_I2SR_IBB. */
#define BS_I2C_I2SR_IBB      (1U)          /*!< Bit field size in bits for I2C_I2SR_IBB. */

/*! @brief Read current value of the I2C_I2SR_IBB field. */
#define BR_I2C_I2SR_IBB(x)   (HW_I2C_I2SR(x).B.IBB)
/*@}*/

/*!
 * @name Register I2C_I2SR, field IAAS[6] (RO)
 *
 * I2C addressed as a slave bit. The ARM platform is interrupted if the
 * interrupt enable (I2C_I2CR[IIEN]) is set. The ARM platform must check the slave
 * read/write bit (SRW) and set its Transfer/Receive mode accordingly. Writing to
 * I2C_I2CR clears this bit.
 *
 * Values:
 * - 0 - Not addressed
 * - 1 - Addressed as a slave. Set when its own address (I2C_IADR) matches the
 *     calling address.
 */
/*@{*/
#define BP_I2C_I2SR_IAAS     (6U)          /*!< Bit position for I2C_I2SR_IAAS. */
#define BM_I2C_I2SR_IAAS     (0x0040U)     /*!< Bit mask for I2C_I2SR_IAAS. */
#define BS_I2C_I2SR_IAAS     (1U)          /*!< Bit field size in bits for I2C_I2SR_IAAS. */

/*! @brief Read current value of the I2C_I2SR_IAAS field. */
#define BR_I2C_I2SR_IAAS(x)  (HW_I2C_I2SR(x).B.IAAS)
/*@}*/

/*!
 * @name Register I2C_I2SR, field ICF[7] (RO)
 *
 * Data transferring bit. While one byte of data is transferred, ICF is cleared.
 *
 * Values:
 * - 0 - Transfer is in progress.
 * - 1 - Transfer is complete. This bit is set by the falling edge of the ninth
 *     clock of the last byte transfer.
 */
/*@{*/
#define BP_I2C_I2SR_ICF      (7U)          /*!< Bit position for I2C_I2SR_ICF. */
#define BM_I2C_I2SR_ICF      (0x0080U)     /*!< Bit mask for I2C_I2SR_ICF. */
#define BS_I2C_I2SR_ICF      (1U)          /*!< Bit field size in bits for I2C_I2SR_ICF. */

/*! @brief Read current value of the I2C_I2SR_ICF field. */
#define BR_I2C_I2SR_ICF(x)   (HW_I2C_I2SR(x).B.ICF)
/*@}*/

/*******************************************************************************
 * HW_I2C_I2DR - I2C Data I/O Register
 ******************************************************************************/

/*!
 * @brief HW_I2C_I2DR - I2C Data I/O Register (RW)
 *
 * Reset value: 0x0000U
 *
 * In Master Receive mode, reading the data register allows a read to occur and
 * initiates the next byte to be received. In Slave mode, the same function is
 * available after it is addressed.
 */
typedef union _hw_i2c_i2dr
{
    uint16_t U;
    struct _hw_i2c_i2dr_bitfields
    {
        uint16_t DATA : 8;             /*!< [7:0]  */
        uint16_t RESERVED0 : 8;        /*!< [15:8]  */
    } B;
} hw_i2c_i2dr_t;

/*!
 * @name Constants and macros for entire I2C_I2DR register
 */
/*@{*/
#define HW_I2C_I2DR_ADDR(x)      ((uintptr_t)(x) + 0x10U)

#define HW_I2C_I2DR(x)           (*(__IO hw_i2c_i2dr_t *) HW_I2C_I2DR_ADDR(x))
#define HW_I2C_I2DR_RD(x)        (HW_I2C_I2DR(x).U)
#define HW_I2C_I2DR_WR(x, v)     (HW_I2C_I2DR(x).U = (v))
#define HW_I2C_I2DR_SET(x, v)    (HW_I2C_I2DR_WR(x, HW_I2C_I2DR_RD(x) |  (v)))
#define HW_I2C_I2DR_CLR(x, v)    (HW_I2C_I2DR_WR(x, HW_I2C_I2DR_RD(x) & ~(v)))
#define HW_I2C_I2DR_TOG(x, v)    (HW_I2C_I2DR_WR(x, HW_I2C_I2DR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2C_I2DR bitfields
 */

/*!
 * @name Register I2C_I2DR, field DATA[7:0] (RW)
 *
 * Data Byte. Holds the last data byte received or the next data byte to be
 * transferred. Software writes the next data byte to be transmitted or reads the
 * data byte received. The core-written value in I2C_I2DR cannot be read back by the
 * core. Only data written by the I2C bus side can be read.
 */
/*@{*/
#define BP_I2C_I2DR_DATA     (0U)          /*!< Bit position for I2C_I2DR_DATA. */
#define BM_I2C_I2DR_DATA     (0x00FFU)     /*!< Bit mask for I2C_I2DR_DATA. */
#define BS_I2C_I2DR_DATA     (8U)          /*!< Bit field size in bits for I2C_I2DR_DATA. */

/*! @brief Read current value of the I2C_I2DR_DATA field. */
#define BR_I2C_I2DR_DATA(x)  (HW_I2C_I2DR(x).B.DATA)

/*! @brief Format value for bitfield I2C_I2DR_DATA. */
#define BF_I2C_I2DR_DATA(v)  ((uint16_t)((uint16_t)(v) << BP_I2C_I2DR_DATA) & BM_I2C_I2DR_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_I2C_I2DR_DATA(x, v) (HW_I2C_I2DR_WR(x, (HW_I2C_I2DR_RD(x) & ~BM_I2C_I2DR_DATA) | BF_I2C_I2DR_DATA(v)))
/*@}*/

/*******************************************************************************
 * hw_i2c_t - module struct
 ******************************************************************************/
/*!
 * @brief All I2C module registers.
 */
#pragma pack(1)
typedef struct _hw_i2c
{
    __IO hw_i2c_iadr_t IADR;               /*!< [0x0] I2C Address Register */
    uint8_t _reserved0[2];
    __IO hw_i2c_ifdr_t IFDR;               /*!< [0x4] I2C Frequency Divider Register */
    uint8_t _reserved1[2];
    __IO hw_i2c_i2cr_t I2CR;               /*!< [0x8] I2C Control Register */
    uint8_t _reserved2[2];
    __IO hw_i2c_i2sr_t I2SR;               /*!< [0xC] I2C Status Register */
    uint8_t _reserved3[2];
    __IO hw_i2c_i2dr_t I2DR;               /*!< [0x10] I2C Data I/O Register */
} hw_i2c_t;
#pragma pack()

/*! @brief Macro to access all I2C registers. */
/*! @param x I2C module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_I2C_REGS(I2C1_BASE)</code>. */
#define HW_I2C_REGS(x) (*(hw_i2c_t *)(x))

/*
 * iMX7D I2S
 *
 * Inter-IC Sound / Synchronous Audio Interface
 *
 * Registers defined in this header file:
 * - HW_I2S_TCSR - SAI Transmit Control Register
 * - HW_I2S_TCR1 - SAI Transmit Configuration 1 Register
 * - HW_I2S_TCR2 - SAI Transmit Configuration 2 Register
 * - HW_I2S_TCR3 - SAI Transmit Configuration 3 Register
 * - HW_I2S_TCR4 - SAI Transmit Configuration 4 Register
 * - HW_I2S_TCR5 - SAI Transmit Configuration 5 Register
 * - HW_I2S_TDRn - SAI Transmit Data Register
 * - HW_I2S_TFRn - SAI Transmit FIFO Register
 * - HW_I2S_TMR - SAI Transmit Mask Register
 * - HW_I2S_RCSR - SAI Receive Control Register
 * - HW_I2S_RCR1 - SAI Receive Configuration 1 Register
 * - HW_I2S_RCR2 - SAI Receive Configuration 2 Register
 * - HW_I2S_RCR3 - SAI Receive Configuration 3 Register
 * - HW_I2S_RCR4 - SAI Receive Configuration 4 Register
 * - HW_I2S_RCR5 - SAI Receive Configuration 5 Register
 * - HW_I2S_RDRn - SAI Receive Data Register
 * - HW_I2S_RFRn - SAI Receive FIFO Register
 * - HW_I2S_RMR - SAI Receive Mask Register
 *
 * - hw_i2s_t - Struct containing all module registers.
 */

#define HW_I2S_INSTANCE_COUNT (3U) /*!< Number of instances of the I2S module. */
#define HW_I2S1 (0U) /*!< Instance number for I2S1. */
#define HW_I2S2 (1U) /*!< Instance number for I2S2. */
#define HW_I2S3 (2U) /*!< Instance number for I2S3. */
#define I2S1_BASE             (0x308A0000U) /*!< Base address for I2S1. */
#define I2S2_BASE             (0x308B0000U) /*!< Base address for I2S2. */
#define I2S3_BASE             (0x308C0000U) /*!< Base address for I2S3. */
/*! Array initializer of I2S base addresses. */
#define I2S_BASE_ADDRS        { I2S1_BASE, I2S2_BASE, I2S3_BASE }

/*******************************************************************************
 * HW_I2S_TCSR - SAI Transmit Control Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_TCSR - SAI Transmit Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_i2s_tcsr
{
    uint32_t U;
    struct _hw_i2s_tcsr_bitfields
    {
        uint32_t FRDE : 1;             /*!< [0] FIFO Request DMA Enable */
        uint32_t FWDE : 1;             /*!< [1] FIFO Warning DMA Enable */
        uint32_t RESERVED0 : 6;        /*!< [7:2]  */
        uint32_t FRIE : 1;             /*!< [8] FIFO Request Interrupt Enable */
        uint32_t FWIE : 1;             /*!< [9] FIFO Warning Interrupt Enable */
        uint32_t FEIE : 1;             /*!< [10] FIFO Error Interrupt Enable */
        uint32_t SEIE : 1;             /*!< [11] Sync Error Interrupt Enable */
        uint32_t WSIE : 1;             /*!< [12] Word Start Interrupt Enable */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t FRF : 1;              /*!< [16] FIFO Request Flag */
        uint32_t FWF : 1;              /*!< [17] FIFO Warning Flag */
        uint32_t FEF : 1;              /*!< [18] FIFO Error Flag */
        uint32_t SEF : 1;              /*!< [19] Sync Error Flag */
        uint32_t WSF : 1;              /*!< [20] Word Start Flag */
        uint32_t RESERVED2 : 3;        /*!< [23:21]  */
        uint32_t SR : 1;               /*!< [24] Software Reset */
        uint32_t FR : 1;               /*!< [25] FIFO Reset */
        uint32_t RESERVED3 : 2;        /*!< [27:26]  */
        uint32_t BCE : 1;              /*!< [28] Bit Clock Enable */
        uint32_t DBGE : 1;             /*!< [29] Debug Enable */
        uint32_t STOPE : 1;            /*!< [30] Stop Enable */
        uint32_t TE : 1;               /*!< [31] Transmitter Enable */
    } B;
} hw_i2s_tcsr_t;

/*!
 * @name Constants and macros for entire I2S_TCSR register
 */
/*@{*/
#define HW_I2S_TCSR_ADDR(x)      ((uintptr_t)(x) + 0x0U)

#define HW_I2S_TCSR(x)           (*(__IO hw_i2s_tcsr_t *) HW_I2S_TCSR_ADDR(x))
#define HW_I2S_TCSR_RD(x)        (HW_I2S_TCSR(x).U)
#define HW_I2S_TCSR_WR(x, v)     (HW_I2S_TCSR(x).U = (v))
#define HW_I2S_TCSR_SET(x, v)    (HW_I2S_TCSR_WR(x, HW_I2S_TCSR_RD(x) |  (v)))
#define HW_I2S_TCSR_CLR(x, v)    (HW_I2S_TCSR_WR(x, HW_I2S_TCSR_RD(x) & ~(v)))
#define HW_I2S_TCSR_TOG(x, v)    (HW_I2S_TCSR_WR(x, HW_I2S_TCSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_TCSR bitfields
 */

/*!
 * @name Register I2S_TCSR, field FRDE[0] (RW)
 *
 * Enables/disables DMA requests.
 *
 * Values:
 * - 0 - Disables the DMA request.
 * - 1 - Enables the DMA request.
 */
/*@{*/
#define BP_I2S_TCSR_FRDE     (0U)          /*!< Bit position for I2S_TCSR_FRDE. */
#define BM_I2S_TCSR_FRDE     (0x00000001U) /*!< Bit mask for I2S_TCSR_FRDE. */
#define BS_I2S_TCSR_FRDE     (1U)          /*!< Bit field size in bits for I2S_TCSR_FRDE. */

/*! @brief Read current value of the I2S_TCSR_FRDE field. */
#define BR_I2S_TCSR_FRDE(x)  (HW_I2S_TCSR(x).B.FRDE)

/*! @brief Format value for bitfield I2S_TCSR_FRDE. */
#define BF_I2S_TCSR_FRDE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_FRDE) & BM_I2S_TCSR_FRDE)

/*! @brief Set the FRDE field to a new value. */
#define BW_I2S_TCSR_FRDE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_FRDE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_FRDE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field FWDE[1] (RW)
 *
 * Enables/disables DMA requests.
 *
 * Values:
 * - 0 - Disables the DMA request.
 * - 1 - Enables the DMA request.
 */
/*@{*/
#define BP_I2S_TCSR_FWDE     (1U)          /*!< Bit position for I2S_TCSR_FWDE. */
#define BM_I2S_TCSR_FWDE     (0x00000002U) /*!< Bit mask for I2S_TCSR_FWDE. */
#define BS_I2S_TCSR_FWDE     (1U)          /*!< Bit field size in bits for I2S_TCSR_FWDE. */

/*! @brief Read current value of the I2S_TCSR_FWDE field. */
#define BR_I2S_TCSR_FWDE(x)  (HW_I2S_TCSR(x).B.FWDE)

/*! @brief Format value for bitfield I2S_TCSR_FWDE. */
#define BF_I2S_TCSR_FWDE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_FWDE) & BM_I2S_TCSR_FWDE)

/*! @brief Set the FWDE field to a new value. */
#define BW_I2S_TCSR_FWDE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_FWDE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_FWDE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field FRIE[8] (RW)
 *
 * Enables/disables FIFO request interrupts.
 *
 * Values:
 * - 0 - Disables the interrupt.
 * - 1 - Enables the interrupt.
 */
/*@{*/
#define BP_I2S_TCSR_FRIE     (8U)          /*!< Bit position for I2S_TCSR_FRIE. */
#define BM_I2S_TCSR_FRIE     (0x00000100U) /*!< Bit mask for I2S_TCSR_FRIE. */
#define BS_I2S_TCSR_FRIE     (1U)          /*!< Bit field size in bits for I2S_TCSR_FRIE. */

/*! @brief Read current value of the I2S_TCSR_FRIE field. */
#define BR_I2S_TCSR_FRIE(x)  (HW_I2S_TCSR(x).B.FRIE)

/*! @brief Format value for bitfield I2S_TCSR_FRIE. */
#define BF_I2S_TCSR_FRIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_FRIE) & BM_I2S_TCSR_FRIE)

/*! @brief Set the FRIE field to a new value. */
#define BW_I2S_TCSR_FRIE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_FRIE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_FRIE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field FWIE[9] (RW)
 *
 * Enables/disables FIFO warning interrupts.
 *
 * Values:
 * - 0 - Disables the interrupt.
 * - 1 - Enables the interrupt.
 */
/*@{*/
#define BP_I2S_TCSR_FWIE     (9U)          /*!< Bit position for I2S_TCSR_FWIE. */
#define BM_I2S_TCSR_FWIE     (0x00000200U) /*!< Bit mask for I2S_TCSR_FWIE. */
#define BS_I2S_TCSR_FWIE     (1U)          /*!< Bit field size in bits for I2S_TCSR_FWIE. */

/*! @brief Read current value of the I2S_TCSR_FWIE field. */
#define BR_I2S_TCSR_FWIE(x)  (HW_I2S_TCSR(x).B.FWIE)

/*! @brief Format value for bitfield I2S_TCSR_FWIE. */
#define BF_I2S_TCSR_FWIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_FWIE) & BM_I2S_TCSR_FWIE)

/*! @brief Set the FWIE field to a new value. */
#define BW_I2S_TCSR_FWIE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_FWIE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_FWIE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field FEIE[10] (RW)
 *
 * Enables/disables FIFO error interrupts.
 *
 * Values:
 * - 0 - Disables the interrupt.
 * - 1 - Enables the interrupt.
 */
/*@{*/
#define BP_I2S_TCSR_FEIE     (10U)         /*!< Bit position for I2S_TCSR_FEIE. */
#define BM_I2S_TCSR_FEIE     (0x00000400U) /*!< Bit mask for I2S_TCSR_FEIE. */
#define BS_I2S_TCSR_FEIE     (1U)          /*!< Bit field size in bits for I2S_TCSR_FEIE. */

/*! @brief Read current value of the I2S_TCSR_FEIE field. */
#define BR_I2S_TCSR_FEIE(x)  (HW_I2S_TCSR(x).B.FEIE)

/*! @brief Format value for bitfield I2S_TCSR_FEIE. */
#define BF_I2S_TCSR_FEIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_FEIE) & BM_I2S_TCSR_FEIE)

/*! @brief Set the FEIE field to a new value. */
#define BW_I2S_TCSR_FEIE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_FEIE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_FEIE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field SEIE[11] (RW)
 *
 * Enables/disables sync error interrupts.
 *
 * Values:
 * - 0 - Disables interrupt.
 * - 1 - Enables interrupt.
 */
/*@{*/
#define BP_I2S_TCSR_SEIE     (11U)         /*!< Bit position for I2S_TCSR_SEIE. */
#define BM_I2S_TCSR_SEIE     (0x00000800U) /*!< Bit mask for I2S_TCSR_SEIE. */
#define BS_I2S_TCSR_SEIE     (1U)          /*!< Bit field size in bits for I2S_TCSR_SEIE. */

/*! @brief Read current value of the I2S_TCSR_SEIE field. */
#define BR_I2S_TCSR_SEIE(x)  (HW_I2S_TCSR(x).B.SEIE)

/*! @brief Format value for bitfield I2S_TCSR_SEIE. */
#define BF_I2S_TCSR_SEIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_SEIE) & BM_I2S_TCSR_SEIE)

/*! @brief Set the SEIE field to a new value. */
#define BW_I2S_TCSR_SEIE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_SEIE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_SEIE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field WSIE[12] (RW)
 *
 * Enables/disables word start interrupts.
 *
 * Values:
 * - 0 - Disables interrupt.
 * - 1 - Enables interrupt.
 */
/*@{*/
#define BP_I2S_TCSR_WSIE     (12U)         /*!< Bit position for I2S_TCSR_WSIE. */
#define BM_I2S_TCSR_WSIE     (0x00001000U) /*!< Bit mask for I2S_TCSR_WSIE. */
#define BS_I2S_TCSR_WSIE     (1U)          /*!< Bit field size in bits for I2S_TCSR_WSIE. */

/*! @brief Read current value of the I2S_TCSR_WSIE field. */
#define BR_I2S_TCSR_WSIE(x)  (HW_I2S_TCSR(x).B.WSIE)

/*! @brief Format value for bitfield I2S_TCSR_WSIE. */
#define BF_I2S_TCSR_WSIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_WSIE) & BM_I2S_TCSR_WSIE)

/*! @brief Set the WSIE field to a new value. */
#define BW_I2S_TCSR_WSIE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_WSIE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_WSIE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field FRF[16] (RO)
 *
 * Indicates that the number of words in an enabled transmit channel FIFO is
 * less than or equal to the transmit FIFO watermark.
 *
 * Values:
 * - 0 - Transmit FIFO watermark has not been reached.
 * - 1 - Transmit FIFO watermark has been reached.
 */
/*@{*/
#define BP_I2S_TCSR_FRF      (16U)         /*!< Bit position for I2S_TCSR_FRF. */
#define BM_I2S_TCSR_FRF      (0x00010000U) /*!< Bit mask for I2S_TCSR_FRF. */
#define BS_I2S_TCSR_FRF      (1U)          /*!< Bit field size in bits for I2S_TCSR_FRF. */

/*! @brief Read current value of the I2S_TCSR_FRF field. */
#define BR_I2S_TCSR_FRF(x)   (HW_I2S_TCSR(x).B.FRF)
/*@}*/

/*!
 * @name Register I2S_TCSR, field FWF[17] (RO)
 *
 * Indicates that an enabled transmit FIFO is empty.
 *
 * Values:
 * - 0 - No enabled transmit FIFO is empty.
 * - 1 - Enabled transmit FIFO is empty.
 */
/*@{*/
#define BP_I2S_TCSR_FWF      (17U)         /*!< Bit position for I2S_TCSR_FWF. */
#define BM_I2S_TCSR_FWF      (0x00020000U) /*!< Bit mask for I2S_TCSR_FWF. */
#define BS_I2S_TCSR_FWF      (1U)          /*!< Bit field size in bits for I2S_TCSR_FWF. */

/*! @brief Read current value of the I2S_TCSR_FWF field. */
#define BR_I2S_TCSR_FWF(x)   (HW_I2S_TCSR(x).B.FWF)
/*@}*/

/*!
 * @name Register I2S_TCSR, field FEF[18] (W1C)
 *
 * Indicates that an enabled transmit FIFO has underrun. Write a logic 1 to this
 * field to clear this flag.
 *
 * Values:
 * - 0 - Transmit underrun not detected.
 * - 1 - Transmit underrun detected.
 */
/*@{*/
#define BP_I2S_TCSR_FEF      (18U)         /*!< Bit position for I2S_TCSR_FEF. */
#define BM_I2S_TCSR_FEF      (0x00040000U) /*!< Bit mask for I2S_TCSR_FEF. */
#define BS_I2S_TCSR_FEF      (1U)          /*!< Bit field size in bits for I2S_TCSR_FEF. */

/*! @brief Read current value of the I2S_TCSR_FEF field. */
#define BR_I2S_TCSR_FEF(x)   (HW_I2S_TCSR(x).B.FEF)

/*! @brief Format value for bitfield I2S_TCSR_FEF. */
#define BF_I2S_TCSR_FEF(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_FEF) & BM_I2S_TCSR_FEF)

/*! @brief Set the FEF field to a new value. */
#define BW_I2S_TCSR_FEF(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_FEF(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field SEF[19] (W1C)
 *
 * Indicates that an error in the externally-generated frame sync has been
 * detected. Write a logic 1 to this field to clear this flag.
 *
 * Values:
 * - 0 - Sync error not detected.
 * - 1 - Frame sync error detected.
 */
/*@{*/
#define BP_I2S_TCSR_SEF      (19U)         /*!< Bit position for I2S_TCSR_SEF. */
#define BM_I2S_TCSR_SEF      (0x00080000U) /*!< Bit mask for I2S_TCSR_SEF. */
#define BS_I2S_TCSR_SEF      (1U)          /*!< Bit field size in bits for I2S_TCSR_SEF. */

/*! @brief Read current value of the I2S_TCSR_SEF field. */
#define BR_I2S_TCSR_SEF(x)   (HW_I2S_TCSR(x).B.SEF)

/*! @brief Format value for bitfield I2S_TCSR_SEF. */
#define BF_I2S_TCSR_SEF(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_SEF) & BM_I2S_TCSR_SEF)

/*! @brief Set the SEF field to a new value. */
#define BW_I2S_TCSR_SEF(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_SEF | BM_I2S_TCSR_FEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_SEF(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field WSF[20] (W1C)
 *
 * Indicates that the start of the configured word has been detected. Write a
 * logic 1 to this field to clear this flag.
 *
 * Values:
 * - 0 - Start of word not detected.
 * - 1 - Start of word detected.
 */
/*@{*/
#define BP_I2S_TCSR_WSF      (20U)         /*!< Bit position for I2S_TCSR_WSF. */
#define BM_I2S_TCSR_WSF      (0x00100000U) /*!< Bit mask for I2S_TCSR_WSF. */
#define BS_I2S_TCSR_WSF      (1U)          /*!< Bit field size in bits for I2S_TCSR_WSF. */

/*! @brief Read current value of the I2S_TCSR_WSF field. */
#define BR_I2S_TCSR_WSF(x)   (HW_I2S_TCSR(x).B.WSF)

/*! @brief Format value for bitfield I2S_TCSR_WSF. */
#define BF_I2S_TCSR_WSF(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_WSF) & BM_I2S_TCSR_WSF)

/*! @brief Set the WSF field to a new value. */
#define BW_I2S_TCSR_WSF(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_WSF | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF)) | BF_I2S_TCSR_WSF(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field SR[24] (RW)
 *
 * When set, resets the internal transmitter logic including the FIFO pointers.
 * Software-visible registers are not affected, except for the status registers.
 *
 * Values:
 * - 0 - No effect.
 * - 1 - Software reset.
 */
/*@{*/
#define BP_I2S_TCSR_SR       (24U)         /*!< Bit position for I2S_TCSR_SR. */
#define BM_I2S_TCSR_SR       (0x01000000U) /*!< Bit mask for I2S_TCSR_SR. */
#define BS_I2S_TCSR_SR       (1U)          /*!< Bit field size in bits for I2S_TCSR_SR. */

/*! @brief Read current value of the I2S_TCSR_SR field. */
#define BR_I2S_TCSR_SR(x)    (HW_I2S_TCSR(x).B.SR)

/*! @brief Format value for bitfield I2S_TCSR_SR. */
#define BF_I2S_TCSR_SR(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_SR) & BM_I2S_TCSR_SR)

/*! @brief Set the SR field to a new value. */
#define BW_I2S_TCSR_SR(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_SR | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_SR(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field FR[25] (WORZ)
 *
 * Resets the FIFO pointers. Reading this field will always return zero. FIFO
 * pointers should only be reset when the transmitter is disabled or the FIFO error
 * flag is set.
 *
 * Values:
 * - 0 - No effect.
 * - 1 - FIFO reset.
 */
/*@{*/
#define BP_I2S_TCSR_FR       (25U)         /*!< Bit position for I2S_TCSR_FR. */
#define BM_I2S_TCSR_FR       (0x02000000U) /*!< Bit mask for I2S_TCSR_FR. */
#define BS_I2S_TCSR_FR       (1U)          /*!< Bit field size in bits for I2S_TCSR_FR. */

/*! @brief Format value for bitfield I2S_TCSR_FR. */
#define BF_I2S_TCSR_FR(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_FR) & BM_I2S_TCSR_FR)

/*! @brief Set the FR field to a new value. */
#define BW_I2S_TCSR_FR(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_FR | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_FR(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field BCE[28] (RW)
 *
 * Enables the transmit bit clock, separately from the TE. This field is
 * automatically set whenever TE is set. When software clears this field, the transmit
 * bit clock remains enabled, and this bit remains set, until the end of the
 * current frame.
 *
 * Values:
 * - 0 - Transmit bit clock is disabled.
 * - 1 - Transmit bit clock is enabled.
 */
/*@{*/
#define BP_I2S_TCSR_BCE      (28U)         /*!< Bit position for I2S_TCSR_BCE. */
#define BM_I2S_TCSR_BCE      (0x10000000U) /*!< Bit mask for I2S_TCSR_BCE. */
#define BS_I2S_TCSR_BCE      (1U)          /*!< Bit field size in bits for I2S_TCSR_BCE. */

/*! @brief Read current value of the I2S_TCSR_BCE field. */
#define BR_I2S_TCSR_BCE(x)   (HW_I2S_TCSR(x).B.BCE)

/*! @brief Format value for bitfield I2S_TCSR_BCE. */
#define BF_I2S_TCSR_BCE(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_BCE) & BM_I2S_TCSR_BCE)

/*! @brief Set the BCE field to a new value. */
#define BW_I2S_TCSR_BCE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_BCE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_BCE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field DBGE[29] (RW)
 *
 * Enables/disables transmitter operation in Debug mode. The transmit bit clock
 * is not affected by debug mode.
 *
 * Values:
 * - 0 - Transmitter is disabled in Debug mode, after completing the current
 *     frame.
 * - 1 - Transmitter is enabled in Debug mode.
 */
/*@{*/
#define BP_I2S_TCSR_DBGE     (29U)         /*!< Bit position for I2S_TCSR_DBGE. */
#define BM_I2S_TCSR_DBGE     (0x20000000U) /*!< Bit mask for I2S_TCSR_DBGE. */
#define BS_I2S_TCSR_DBGE     (1U)          /*!< Bit field size in bits for I2S_TCSR_DBGE. */

/*! @brief Read current value of the I2S_TCSR_DBGE field. */
#define BR_I2S_TCSR_DBGE(x)  (HW_I2S_TCSR(x).B.DBGE)

/*! @brief Format value for bitfield I2S_TCSR_DBGE. */
#define BF_I2S_TCSR_DBGE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_DBGE) & BM_I2S_TCSR_DBGE)

/*! @brief Set the DBGE field to a new value. */
#define BW_I2S_TCSR_DBGE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_DBGE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_DBGE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field STOPE[30] (RW)
 *
 * Configures transmitter operation in Stop mode. This field is ignored and the
 * transmitter is disabled in all stop modes.
 *
 * Values:
 * - 0 - Transmitter disabled in Stop mode.
 * - 1 - Transmitter enabled in Stop mode.
 */
/*@{*/
#define BP_I2S_TCSR_STOPE    (30U)         /*!< Bit position for I2S_TCSR_STOPE. */
#define BM_I2S_TCSR_STOPE    (0x40000000U) /*!< Bit mask for I2S_TCSR_STOPE. */
#define BS_I2S_TCSR_STOPE    (1U)          /*!< Bit field size in bits for I2S_TCSR_STOPE. */

/*! @brief Read current value of the I2S_TCSR_STOPE field. */
#define BR_I2S_TCSR_STOPE(x) (HW_I2S_TCSR(x).B.STOPE)

/*! @brief Format value for bitfield I2S_TCSR_STOPE. */
#define BF_I2S_TCSR_STOPE(v) ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_STOPE) & BM_I2S_TCSR_STOPE)

/*! @brief Set the STOPE field to a new value. */
#define BW_I2S_TCSR_STOPE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_STOPE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_STOPE(v)))
/*@}*/

/*!
 * @name Register I2S_TCSR, field TE[31] (RW)
 *
 * Enables/disables the transmitter. When software clears this field, the
 * transmitter remains enabled, and this bit remains set, until the end of the current
 * frame.
 *
 * Values:
 * - 0 - Transmitter is disabled.
 * - 1 - Transmitter is enabled, or transmitter has been disabled and has not
 *     yet reached end of frame.
 */
/*@{*/
#define BP_I2S_TCSR_TE       (31U)         /*!< Bit position for I2S_TCSR_TE. */
#define BM_I2S_TCSR_TE       (0x80000000U) /*!< Bit mask for I2S_TCSR_TE. */
#define BS_I2S_TCSR_TE       (1U)          /*!< Bit field size in bits for I2S_TCSR_TE. */

/*! @brief Read current value of the I2S_TCSR_TE field. */
#define BR_I2S_TCSR_TE(x)    (HW_I2S_TCSR(x).B.TE)

/*! @brief Format value for bitfield I2S_TCSR_TE. */
#define BF_I2S_TCSR_TE(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_TCSR_TE) & BM_I2S_TCSR_TE)

/*! @brief Set the TE field to a new value. */
#define BW_I2S_TCSR_TE(x, v) (HW_I2S_TCSR_WR(x, (HW_I2S_TCSR_RD(x) & ~(BM_I2S_TCSR_TE | BM_I2S_TCSR_FEF | BM_I2S_TCSR_SEF | BM_I2S_TCSR_WSF)) | BF_I2S_TCSR_TE(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_TCR1 - SAI Transmit Configuration 1 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_TCR1 - SAI Transmit Configuration 1 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_i2s_tcr1
{
    uint32_t U;
    struct _hw_i2s_tcr1_bitfields
    {
        uint32_t TFW : 5;              /*!< [4:0] Transmit FIFO Watermark */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_i2s_tcr1_t;

/*!
 * @name Constants and macros for entire I2S_TCR1 register
 */
/*@{*/
#define HW_I2S_TCR1_ADDR(x)      ((uintptr_t)(x) + 0x4U)

#define HW_I2S_TCR1(x)           (*(__IO hw_i2s_tcr1_t *) HW_I2S_TCR1_ADDR(x))
#define HW_I2S_TCR1_RD(x)        (HW_I2S_TCR1(x).U)
#define HW_I2S_TCR1_WR(x, v)     (HW_I2S_TCR1(x).U = (v))
#define HW_I2S_TCR1_SET(x, v)    (HW_I2S_TCR1_WR(x, HW_I2S_TCR1_RD(x) |  (v)))
#define HW_I2S_TCR1_CLR(x, v)    (HW_I2S_TCR1_WR(x, HW_I2S_TCR1_RD(x) & ~(v)))
#define HW_I2S_TCR1_TOG(x, v)    (HW_I2S_TCR1_WR(x, HW_I2S_TCR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_TCR1 bitfields
 */

/*!
 * @name Register I2S_TCR1, field TFW[4:0] (RW)
 *
 * Configures the watermark level for all enabled transmit channels.
 */
/*@{*/
#define BP_I2S_TCR1_TFW      (0U)          /*!< Bit position for I2S_TCR1_TFW. */
#define BM_I2S_TCR1_TFW      (0x0000001FU) /*!< Bit mask for I2S_TCR1_TFW. */
#define BS_I2S_TCR1_TFW      (5U)          /*!< Bit field size in bits for I2S_TCR1_TFW. */

/*! @brief Read current value of the I2S_TCR1_TFW field. */
#define BR_I2S_TCR1_TFW(x)   (HW_I2S_TCR1(x).B.TFW)

/*! @brief Format value for bitfield I2S_TCR1_TFW. */
#define BF_I2S_TCR1_TFW(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR1_TFW) & BM_I2S_TCR1_TFW)

/*! @brief Set the TFW field to a new value. */
#define BW_I2S_TCR1_TFW(x, v) (HW_I2S_TCR1_WR(x, (HW_I2S_TCR1_RD(x) & ~BM_I2S_TCR1_TFW) | BF_I2S_TCR1_TFW(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_TCR2 - SAI Transmit Configuration 2 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_TCR2 - SAI Transmit Configuration 2 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register must not be altered when TCSR[TE] is set.
 */
typedef union _hw_i2s_tcr2
{
    uint32_t U;
    struct _hw_i2s_tcr2_bitfields
    {
        uint32_t DIV : 8;              /*!< [7:0] Bit Clock Divide */
        uint32_t RESERVED0 : 16;       /*!< [23:8]  */
        uint32_t BCD : 1;              /*!< [24] Bit Clock Direction */
        uint32_t BCP : 1;              /*!< [25] Bit Clock Polarity */
        uint32_t MSEL : 2;             /*!< [27:26] MCLK Select */
        uint32_t BCI : 1;              /*!< [28] Bit Clock Input */
        uint32_t BCS : 1;              /*!< [29] Bit Clock Swap */
        uint32_t SYNC : 2;             /*!< [31:30] Synchronous Mode */
    } B;
} hw_i2s_tcr2_t;

/*!
 * @name Constants and macros for entire I2S_TCR2 register
 */
/*@{*/
#define HW_I2S_TCR2_ADDR(x)      ((uintptr_t)(x) + 0x8U)

#define HW_I2S_TCR2(x)           (*(__IO hw_i2s_tcr2_t *) HW_I2S_TCR2_ADDR(x))
#define HW_I2S_TCR2_RD(x)        (HW_I2S_TCR2(x).U)
#define HW_I2S_TCR2_WR(x, v)     (HW_I2S_TCR2(x).U = (v))
#define HW_I2S_TCR2_SET(x, v)    (HW_I2S_TCR2_WR(x, HW_I2S_TCR2_RD(x) |  (v)))
#define HW_I2S_TCR2_CLR(x, v)    (HW_I2S_TCR2_WR(x, HW_I2S_TCR2_RD(x) & ~(v)))
#define HW_I2S_TCR2_TOG(x, v)    (HW_I2S_TCR2_WR(x, HW_I2S_TCR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_TCR2 bitfields
 */

/*!
 * @name Register I2S_TCR2, field DIV[7:0] (RW)
 *
 * Divides down the audio master clock to generate the bit clock when configured
 * for an internal bit clock. The division value is (DIV + 1) * 2.
 */
/*@{*/
#define BP_I2S_TCR2_DIV      (0U)          /*!< Bit position for I2S_TCR2_DIV. */
#define BM_I2S_TCR2_DIV      (0x000000FFU) /*!< Bit mask for I2S_TCR2_DIV. */
#define BS_I2S_TCR2_DIV      (8U)          /*!< Bit field size in bits for I2S_TCR2_DIV. */

/*! @brief Read current value of the I2S_TCR2_DIV field. */
#define BR_I2S_TCR2_DIV(x)   (HW_I2S_TCR2(x).B.DIV)

/*! @brief Format value for bitfield I2S_TCR2_DIV. */
#define BF_I2S_TCR2_DIV(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR2_DIV) & BM_I2S_TCR2_DIV)

/*! @brief Set the DIV field to a new value. */
#define BW_I2S_TCR2_DIV(x, v) (HW_I2S_TCR2_WR(x, (HW_I2S_TCR2_RD(x) & ~BM_I2S_TCR2_DIV) | BF_I2S_TCR2_DIV(v)))
/*@}*/

/*!
 * @name Register I2S_TCR2, field BCD[24] (RW)
 *
 * Configures the direction of the bit clock.
 *
 * Values:
 * - 0 - Bit clock is generated externally in Slave mode.
 * - 1 - Bit clock is generated internally in Master mode.
 */
/*@{*/
#define BP_I2S_TCR2_BCD      (24U)         /*!< Bit position for I2S_TCR2_BCD. */
#define BM_I2S_TCR2_BCD      (0x01000000U) /*!< Bit mask for I2S_TCR2_BCD. */
#define BS_I2S_TCR2_BCD      (1U)          /*!< Bit field size in bits for I2S_TCR2_BCD. */

/*! @brief Read current value of the I2S_TCR2_BCD field. */
#define BR_I2S_TCR2_BCD(x)   (HW_I2S_TCR2(x).B.BCD)

/*! @brief Format value for bitfield I2S_TCR2_BCD. */
#define BF_I2S_TCR2_BCD(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR2_BCD) & BM_I2S_TCR2_BCD)

/*! @brief Set the BCD field to a new value. */
#define BW_I2S_TCR2_BCD(x, v) (HW_I2S_TCR2_WR(x, (HW_I2S_TCR2_RD(x) & ~BM_I2S_TCR2_BCD) | BF_I2S_TCR2_BCD(v)))
/*@}*/

/*!
 * @name Register I2S_TCR2, field BCP[25] (RW)
 *
 * Configures the polarity of the bit clock.
 *
 * Values:
 * - 0 - Bit clock is active high with drive outputs on rising edge and sample
 *     inputs on falling edge.
 * - 1 - Bit clock is active low with drive outputs on falling edge and sample
 *     inputs on rising edge.
 */
/*@{*/
#define BP_I2S_TCR2_BCP      (25U)         /*!< Bit position for I2S_TCR2_BCP. */
#define BM_I2S_TCR2_BCP      (0x02000000U) /*!< Bit mask for I2S_TCR2_BCP. */
#define BS_I2S_TCR2_BCP      (1U)          /*!< Bit field size in bits for I2S_TCR2_BCP. */

/*! @brief Read current value of the I2S_TCR2_BCP field. */
#define BR_I2S_TCR2_BCP(x)   (HW_I2S_TCR2(x).B.BCP)

/*! @brief Format value for bitfield I2S_TCR2_BCP. */
#define BF_I2S_TCR2_BCP(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR2_BCP) & BM_I2S_TCR2_BCP)

/*! @brief Set the BCP field to a new value. */
#define BW_I2S_TCR2_BCP(x, v) (HW_I2S_TCR2_WR(x, (HW_I2S_TCR2_RD(x) & ~BM_I2S_TCR2_BCP) | BF_I2S_TCR2_BCP(v)))
/*@}*/

/*!
 * @name Register I2S_TCR2, field MSEL[27:26] (RW)
 *
 * Selects the audio Master Clock option used to generate an internally
 * generated bit clock. This field has no effect when configured for an externally
 * generated bit clock. Depending on the device, some Master Clock options might not be
 * available. See the chip-specific information for the meaning of each option.
 *
 * Values:
 * - 00 - Master Clock (MCLK) 1 option selected.
 * - 01 - Master Clock (MCLK) 1 option selected.
 * - 10 - Master Clock (MCLK) 2 option selected.
 * - 11 - Master Clock (MCLK) 3 option selected.
 */
/*@{*/
#define BP_I2S_TCR2_MSEL     (26U)         /*!< Bit position for I2S_TCR2_MSEL. */
#define BM_I2S_TCR2_MSEL     (0x0C000000U) /*!< Bit mask for I2S_TCR2_MSEL. */
#define BS_I2S_TCR2_MSEL     (2U)          /*!< Bit field size in bits for I2S_TCR2_MSEL. */

/*! @brief Read current value of the I2S_TCR2_MSEL field. */
#define BR_I2S_TCR2_MSEL(x)  (HW_I2S_TCR2(x).B.MSEL)

/*! @brief Format value for bitfield I2S_TCR2_MSEL. */
#define BF_I2S_TCR2_MSEL(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCR2_MSEL) & BM_I2S_TCR2_MSEL)

/*! @brief Set the MSEL field to a new value. */
#define BW_I2S_TCR2_MSEL(x, v) (HW_I2S_TCR2_WR(x, (HW_I2S_TCR2_RD(x) & ~BM_I2S_TCR2_MSEL) | BF_I2S_TCR2_MSEL(v)))
/*@}*/

/*!
 * @name Register I2S_TCR2, field BCI[28] (RW)
 *
 * When this field is set and using an internally generated bit clock in either
 * synchronous or asynchronous mode, the bit clock actually used by the
 * transmitter is delayed by the pad output delay (the transmitter is clocked by the pad
 * input as if the clock was externally generated). This has the effect of
 * decreasing the data input setup time, but increasing the data output valid time. The
 * slave mode timing from the datasheet should be used for the transmitter when
 * this bit is set. In synchronous mode, this bit allows the transmitter to use
 * the slave mode timing from the datasheet, while the receiver uses the master
 * mode timing. This field has no effect when configured for an externally generated
 * bit clock .
 *
 * Values:
 * - 0 - No effect.
 * - 1 - Internal logic is clocked as if bit clock was externally generated.
 */
/*@{*/
#define BP_I2S_TCR2_BCI      (28U)         /*!< Bit position for I2S_TCR2_BCI. */
#define BM_I2S_TCR2_BCI      (0x10000000U) /*!< Bit mask for I2S_TCR2_BCI. */
#define BS_I2S_TCR2_BCI      (1U)          /*!< Bit field size in bits for I2S_TCR2_BCI. */

/*! @brief Read current value of the I2S_TCR2_BCI field. */
#define BR_I2S_TCR2_BCI(x)   (HW_I2S_TCR2(x).B.BCI)

/*! @brief Format value for bitfield I2S_TCR2_BCI. */
#define BF_I2S_TCR2_BCI(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR2_BCI) & BM_I2S_TCR2_BCI)

/*! @brief Set the BCI field to a new value. */
#define BW_I2S_TCR2_BCI(x, v) (HW_I2S_TCR2_WR(x, (HW_I2S_TCR2_RD(x) & ~BM_I2S_TCR2_BCI) | BF_I2S_TCR2_BCI(v)))
/*@}*/

/*!
 * @name Register I2S_TCR2, field BCS[29] (RW)
 *
 * This field swaps the bit clock used by the transmitter. When the transmitter
 * is configured in asynchronous mode and this bit is set, the transmitter is
 * clocked by the receiver bit clock (SAI_RX_BCLK). This allows the transmitter and
 * receiver to share the same bit clock, but the transmitter continues to use the
 * transmit frame sync (SAI_TX_SYNC). When the transmitter is configured in
 * synchronous mode, the transmitter BCS field and receiver BCS field must be set to
 * the same value. When both are set, the transmitter and receiver are both
 * clocked by the transmitter bit clock (SAI_TX_BCLK) but use the receiver frame sync
 * (SAI_RX_SYNC).
 *
 * Values:
 * - 0 - Use the normal bit clock source.
 * - 1 - Swap the bit clock source.
 */
/*@{*/
#define BP_I2S_TCR2_BCS      (29U)         /*!< Bit position for I2S_TCR2_BCS. */
#define BM_I2S_TCR2_BCS      (0x20000000U) /*!< Bit mask for I2S_TCR2_BCS. */
#define BS_I2S_TCR2_BCS      (1U)          /*!< Bit field size in bits for I2S_TCR2_BCS. */

/*! @brief Read current value of the I2S_TCR2_BCS field. */
#define BR_I2S_TCR2_BCS(x)   (HW_I2S_TCR2(x).B.BCS)

/*! @brief Format value for bitfield I2S_TCR2_BCS. */
#define BF_I2S_TCR2_BCS(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR2_BCS) & BM_I2S_TCR2_BCS)

/*! @brief Set the BCS field to a new value. */
#define BW_I2S_TCR2_BCS(x, v) (HW_I2S_TCR2_WR(x, (HW_I2S_TCR2_RD(x) & ~BM_I2S_TCR2_BCS) | BF_I2S_TCR2_BCS(v)))
/*@}*/

/*!
 * @name Register I2S_TCR2, field SYNC[31:30] (RW)
 *
 * Configures between asynchronous and synchronous modes of operation. When
 * configured for a synchronous mode of operation, the receiver must be configured
 * for asynchronous operation.
 *
 * Values:
 * - 00 - Asynchronous mode.
 * - 01 - Synchronous with receiver.
 */
/*@{*/
#define BP_I2S_TCR2_SYNC     (30U)         /*!< Bit position for I2S_TCR2_SYNC. */
#define BM_I2S_TCR2_SYNC     (0xC0000000U) /*!< Bit mask for I2S_TCR2_SYNC. */
#define BS_I2S_TCR2_SYNC     (2U)          /*!< Bit field size in bits for I2S_TCR2_SYNC. */

/*! @brief Read current value of the I2S_TCR2_SYNC field. */
#define BR_I2S_TCR2_SYNC(x)  (HW_I2S_TCR2(x).B.SYNC)

/*! @brief Format value for bitfield I2S_TCR2_SYNC. */
#define BF_I2S_TCR2_SYNC(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCR2_SYNC) & BM_I2S_TCR2_SYNC)

/*! @brief Set the SYNC field to a new value. */
#define BW_I2S_TCR2_SYNC(x, v) (HW_I2S_TCR2_WR(x, (HW_I2S_TCR2_RD(x) & ~BM_I2S_TCR2_SYNC) | BF_I2S_TCR2_SYNC(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_TCR3 - SAI Transmit Configuration 3 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_TCR3 - SAI Transmit Configuration 3 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register must not be altered when TCSR[TE] is set.
 */
typedef union _hw_i2s_tcr3
{
    uint32_t U;
    struct _hw_i2s_tcr3_bitfields
    {
        uint32_t WDFL : 5;             /*!< [4:0] Word Flag Configuration */
        uint32_t RESERVED0 : 11;       /*!< [15:5]  */
        uint32_t TCE : 1;              /*!< [16] Transmit Channel Enable */
        uint32_t RESERVED1 : 15;       /*!< [31:17]  */
    } B;
} hw_i2s_tcr3_t;

/*!
 * @name Constants and macros for entire I2S_TCR3 register
 */
/*@{*/
#define HW_I2S_TCR3_ADDR(x)      ((uintptr_t)(x) + 0xCU)

#define HW_I2S_TCR3(x)           (*(__IO hw_i2s_tcr3_t *) HW_I2S_TCR3_ADDR(x))
#define HW_I2S_TCR3_RD(x)        (HW_I2S_TCR3(x).U)
#define HW_I2S_TCR3_WR(x, v)     (HW_I2S_TCR3(x).U = (v))
#define HW_I2S_TCR3_SET(x, v)    (HW_I2S_TCR3_WR(x, HW_I2S_TCR3_RD(x) |  (v)))
#define HW_I2S_TCR3_CLR(x, v)    (HW_I2S_TCR3_WR(x, HW_I2S_TCR3_RD(x) & ~(v)))
#define HW_I2S_TCR3_TOG(x, v)    (HW_I2S_TCR3_WR(x, HW_I2S_TCR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_TCR3 bitfields
 */

/*!
 * @name Register I2S_TCR3, field WDFL[4:0] (RW)
 *
 * Configures which word sets the start of word flag. The value written must be
 * one less than the word number. For example, writing 0 configures the first
 * word in the frame. When configured to a value greater than TCR4[FRSZ], then the
 * start of word flag is never set.
 */
/*@{*/
#define BP_I2S_TCR3_WDFL     (0U)          /*!< Bit position for I2S_TCR3_WDFL. */
#define BM_I2S_TCR3_WDFL     (0x0000001FU) /*!< Bit mask for I2S_TCR3_WDFL. */
#define BS_I2S_TCR3_WDFL     (5U)          /*!< Bit field size in bits for I2S_TCR3_WDFL. */

/*! @brief Read current value of the I2S_TCR3_WDFL field. */
#define BR_I2S_TCR3_WDFL(x)  (HW_I2S_TCR3(x).B.WDFL)

/*! @brief Format value for bitfield I2S_TCR3_WDFL. */
#define BF_I2S_TCR3_WDFL(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCR3_WDFL) & BM_I2S_TCR3_WDFL)

/*! @brief Set the WDFL field to a new value. */
#define BW_I2S_TCR3_WDFL(x, v) (HW_I2S_TCR3_WR(x, (HW_I2S_TCR3_RD(x) & ~BM_I2S_TCR3_WDFL) | BF_I2S_TCR3_WDFL(v)))
/*@}*/

/*!
 * @name Register I2S_TCR3, field TCE[16] (RW)
 *
 * Enables the corresponding data channel for transmit operation. A channel must
 * be enabled before its FIFO is accessed.
 *
 * Values:
 * - 0 - Transmit data channel N is disabled.
 * - 1 - Transmit data channel N is enabled.
 */
/*@{*/
#define BP_I2S_TCR3_TCE      (16U)         /*!< Bit position for I2S_TCR3_TCE. */
#define BM_I2S_TCR3_TCE      (0x00010000U) /*!< Bit mask for I2S_TCR3_TCE. */
#define BS_I2S_TCR3_TCE      (1U)          /*!< Bit field size in bits for I2S_TCR3_TCE. */

/*! @brief Read current value of the I2S_TCR3_TCE field. */
#define BR_I2S_TCR3_TCE(x)   (HW_I2S_TCR3(x).B.TCE)

/*! @brief Format value for bitfield I2S_TCR3_TCE. */
#define BF_I2S_TCR3_TCE(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR3_TCE) & BM_I2S_TCR3_TCE)

/*! @brief Set the TCE field to a new value. */
#define BW_I2S_TCR3_TCE(x, v) (HW_I2S_TCR3_WR(x, (HW_I2S_TCR3_RD(x) & ~BM_I2S_TCR3_TCE) | BF_I2S_TCR3_TCE(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_TCR4 - SAI Transmit Configuration 4 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_TCR4 - SAI Transmit Configuration 4 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register must not be altered when TCSR[TE] is set.
 */
typedef union _hw_i2s_tcr4
{
    uint32_t U;
    struct _hw_i2s_tcr4_bitfields
    {
        uint32_t FSD : 1;              /*!< [0] Frame Sync Direction */
        uint32_t FSP : 1;              /*!< [1] Frame Sync Polarity */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t FSE : 1;              /*!< [3] Frame Sync Early */
        uint32_t MF : 1;               /*!< [4] MSB First */
        uint32_t RESERVED1 : 3;        /*!< [7:5]  */
        uint32_t SYWD : 5;             /*!< [12:8] Sync Width */
        uint32_t RESERVED2 : 3;        /*!< [15:13]  */
        uint32_t FRSZ : 5;             /*!< [20:16] Frame size */
        uint32_t RESERVED3 : 11;       /*!< [31:21]  */
    } B;
} hw_i2s_tcr4_t;

/*!
 * @name Constants and macros for entire I2S_TCR4 register
 */
/*@{*/
#define HW_I2S_TCR4_ADDR(x)      ((uintptr_t)(x) + 0x10U)

#define HW_I2S_TCR4(x)           (*(__IO hw_i2s_tcr4_t *) HW_I2S_TCR4_ADDR(x))
#define HW_I2S_TCR4_RD(x)        (HW_I2S_TCR4(x).U)
#define HW_I2S_TCR4_WR(x, v)     (HW_I2S_TCR4(x).U = (v))
#define HW_I2S_TCR4_SET(x, v)    (HW_I2S_TCR4_WR(x, HW_I2S_TCR4_RD(x) |  (v)))
#define HW_I2S_TCR4_CLR(x, v)    (HW_I2S_TCR4_WR(x, HW_I2S_TCR4_RD(x) & ~(v)))
#define HW_I2S_TCR4_TOG(x, v)    (HW_I2S_TCR4_WR(x, HW_I2S_TCR4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_TCR4 bitfields
 */

/*!
 * @name Register I2S_TCR4, field FSD[0] (RW)
 *
 * Configures the direction of the frame sync.
 *
 * Values:
 * - 0 - Frame sync is generated externally in Slave mode.
 * - 1 - Frame sync is generated internally in Master mode.
 */
/*@{*/
#define BP_I2S_TCR4_FSD      (0U)          /*!< Bit position for I2S_TCR4_FSD. */
#define BM_I2S_TCR4_FSD      (0x00000001U) /*!< Bit mask for I2S_TCR4_FSD. */
#define BS_I2S_TCR4_FSD      (1U)          /*!< Bit field size in bits for I2S_TCR4_FSD. */

/*! @brief Read current value of the I2S_TCR4_FSD field. */
#define BR_I2S_TCR4_FSD(x)   (HW_I2S_TCR4(x).B.FSD)

/*! @brief Format value for bitfield I2S_TCR4_FSD. */
#define BF_I2S_TCR4_FSD(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR4_FSD) & BM_I2S_TCR4_FSD)

/*! @brief Set the FSD field to a new value. */
#define BW_I2S_TCR4_FSD(x, v) (HW_I2S_TCR4_WR(x, (HW_I2S_TCR4_RD(x) & ~BM_I2S_TCR4_FSD) | BF_I2S_TCR4_FSD(v)))
/*@}*/

/*!
 * @name Register I2S_TCR4, field FSP[1] (RW)
 *
 * Configures the polarity of the frame sync.
 *
 * Values:
 * - 0 - Frame sync is active high.
 * - 1 - Frame sync is active low.
 */
/*@{*/
#define BP_I2S_TCR4_FSP      (1U)          /*!< Bit position for I2S_TCR4_FSP. */
#define BM_I2S_TCR4_FSP      (0x00000002U) /*!< Bit mask for I2S_TCR4_FSP. */
#define BS_I2S_TCR4_FSP      (1U)          /*!< Bit field size in bits for I2S_TCR4_FSP. */

/*! @brief Read current value of the I2S_TCR4_FSP field. */
#define BR_I2S_TCR4_FSP(x)   (HW_I2S_TCR4(x).B.FSP)

/*! @brief Format value for bitfield I2S_TCR4_FSP. */
#define BF_I2S_TCR4_FSP(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR4_FSP) & BM_I2S_TCR4_FSP)

/*! @brief Set the FSP field to a new value. */
#define BW_I2S_TCR4_FSP(x, v) (HW_I2S_TCR4_WR(x, (HW_I2S_TCR4_RD(x) & ~BM_I2S_TCR4_FSP) | BF_I2S_TCR4_FSP(v)))
/*@}*/

/*!
 * @name Register I2S_TCR4, field FSE[3] (RW)
 *
 * Values:
 * - 0 - Frame sync asserts with the first bit of the frame.
 * - 1 - Frame sync asserts one bit before the first bit of the frame.
 */
/*@{*/
#define BP_I2S_TCR4_FSE      (3U)          /*!< Bit position for I2S_TCR4_FSE. */
#define BM_I2S_TCR4_FSE      (0x00000008U) /*!< Bit mask for I2S_TCR4_FSE. */
#define BS_I2S_TCR4_FSE      (1U)          /*!< Bit field size in bits for I2S_TCR4_FSE. */

/*! @brief Read current value of the I2S_TCR4_FSE field. */
#define BR_I2S_TCR4_FSE(x)   (HW_I2S_TCR4(x).B.FSE)

/*! @brief Format value for bitfield I2S_TCR4_FSE. */
#define BF_I2S_TCR4_FSE(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR4_FSE) & BM_I2S_TCR4_FSE)

/*! @brief Set the FSE field to a new value. */
#define BW_I2S_TCR4_FSE(x, v) (HW_I2S_TCR4_WR(x, (HW_I2S_TCR4_RD(x) & ~BM_I2S_TCR4_FSE) | BF_I2S_TCR4_FSE(v)))
/*@}*/

/*!
 * @name Register I2S_TCR4, field MF[4] (RW)
 *
 * Configures whether the LSB or the MSB is transmitted first.
 *
 * Values:
 * - 0 - LSB is transmitted first.
 * - 1 - MSB is transmitted first.
 */
/*@{*/
#define BP_I2S_TCR4_MF       (4U)          /*!< Bit position for I2S_TCR4_MF. */
#define BM_I2S_TCR4_MF       (0x00000010U) /*!< Bit mask for I2S_TCR4_MF. */
#define BS_I2S_TCR4_MF       (1U)          /*!< Bit field size in bits for I2S_TCR4_MF. */

/*! @brief Read current value of the I2S_TCR4_MF field. */
#define BR_I2S_TCR4_MF(x)    (HW_I2S_TCR4(x).B.MF)

/*! @brief Format value for bitfield I2S_TCR4_MF. */
#define BF_I2S_TCR4_MF(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_TCR4_MF) & BM_I2S_TCR4_MF)

/*! @brief Set the MF field to a new value. */
#define BW_I2S_TCR4_MF(x, v) (HW_I2S_TCR4_WR(x, (HW_I2S_TCR4_RD(x) & ~BM_I2S_TCR4_MF) | BF_I2S_TCR4_MF(v)))
/*@}*/

/*!
 * @name Register I2S_TCR4, field SYWD[12:8] (RW)
 *
 * Configures the length of the frame sync in number of bit clocks. The value
 * written must be one less than the number of bit clocks. For example, write 0 for
 * the frame sync to assert for one bit clock only. The sync width cannot be
 * configured longer than the first word of the frame.
 */
/*@{*/
#define BP_I2S_TCR4_SYWD     (8U)          /*!< Bit position for I2S_TCR4_SYWD. */
#define BM_I2S_TCR4_SYWD     (0x00001F00U) /*!< Bit mask for I2S_TCR4_SYWD. */
#define BS_I2S_TCR4_SYWD     (5U)          /*!< Bit field size in bits for I2S_TCR4_SYWD. */

/*! @brief Read current value of the I2S_TCR4_SYWD field. */
#define BR_I2S_TCR4_SYWD(x)  (HW_I2S_TCR4(x).B.SYWD)

/*! @brief Format value for bitfield I2S_TCR4_SYWD. */
#define BF_I2S_TCR4_SYWD(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCR4_SYWD) & BM_I2S_TCR4_SYWD)

/*! @brief Set the SYWD field to a new value. */
#define BW_I2S_TCR4_SYWD(x, v) (HW_I2S_TCR4_WR(x, (HW_I2S_TCR4_RD(x) & ~BM_I2S_TCR4_SYWD) | BF_I2S_TCR4_SYWD(v)))
/*@}*/

/*!
 * @name Register I2S_TCR4, field FRSZ[20:16] (RW)
 *
 * Configures the number of words in each frame. The value written must be one
 * less than the number of words in the frame. For example, write 0 for one word
 * per frame. The maximum supported frame size is 32 words.
 */
/*@{*/
#define BP_I2S_TCR4_FRSZ     (16U)         /*!< Bit position for I2S_TCR4_FRSZ. */
#define BM_I2S_TCR4_FRSZ     (0x001F0000U) /*!< Bit mask for I2S_TCR4_FRSZ. */
#define BS_I2S_TCR4_FRSZ     (5U)          /*!< Bit field size in bits for I2S_TCR4_FRSZ. */

/*! @brief Read current value of the I2S_TCR4_FRSZ field. */
#define BR_I2S_TCR4_FRSZ(x)  (HW_I2S_TCR4(x).B.FRSZ)

/*! @brief Format value for bitfield I2S_TCR4_FRSZ. */
#define BF_I2S_TCR4_FRSZ(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_TCR4_FRSZ) & BM_I2S_TCR4_FRSZ)

/*! @brief Set the FRSZ field to a new value. */
#define BW_I2S_TCR4_FRSZ(x, v) (HW_I2S_TCR4_WR(x, (HW_I2S_TCR4_RD(x) & ~BM_I2S_TCR4_FRSZ) | BF_I2S_TCR4_FRSZ(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_TCR5 - SAI Transmit Configuration 5 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_TCR5 - SAI Transmit Configuration 5 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register must not be altered when TCSR[TE] is set.
 */
typedef union _hw_i2s_tcr5
{
    uint32_t U;
    struct _hw_i2s_tcr5_bitfields
    {
        uint32_t RESERVED0 : 8;        /*!< [7:0]  */
        uint32_t FBT : 5;              /*!< [12:8] First Bit Shifted */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t W0W : 5;              /*!< [20:16] Word 0 Width */
        uint32_t RESERVED2 : 3;        /*!< [23:21]  */
        uint32_t WNW : 5;              /*!< [28:24] Word N Width */
        uint32_t RESERVED3 : 3;        /*!< [31:29]  */
    } B;
} hw_i2s_tcr5_t;

/*!
 * @name Constants and macros for entire I2S_TCR5 register
 */
/*@{*/
#define HW_I2S_TCR5_ADDR(x)      ((uintptr_t)(x) + 0x14U)

#define HW_I2S_TCR5(x)           (*(__IO hw_i2s_tcr5_t *) HW_I2S_TCR5_ADDR(x))
#define HW_I2S_TCR5_RD(x)        (HW_I2S_TCR5(x).U)
#define HW_I2S_TCR5_WR(x, v)     (HW_I2S_TCR5(x).U = (v))
#define HW_I2S_TCR5_SET(x, v)    (HW_I2S_TCR5_WR(x, HW_I2S_TCR5_RD(x) |  (v)))
#define HW_I2S_TCR5_CLR(x, v)    (HW_I2S_TCR5_WR(x, HW_I2S_TCR5_RD(x) & ~(v)))
#define HW_I2S_TCR5_TOG(x, v)    (HW_I2S_TCR5_WR(x, HW_I2S_TCR5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_TCR5 bitfields
 */

/*!
 * @name Register I2S_TCR5, field FBT[12:8] (RW)
 *
 * Configures the bit index for the first bit transmitted for each word in the
 * frame. If configured for MSB First, the index of the next bit transmitted is
 * one less than the current bit transmitted. If configured for LSB First, the
 * index of the next bit transmitted is one more than the current bit transmitted.
 * The value written must be greater than or equal to the word width when
 * configured for MSB First. The value written must be less than or equal to 31-word width
 * when configured for LSB First.
 */
/*@{*/
#define BP_I2S_TCR5_FBT      (8U)          /*!< Bit position for I2S_TCR5_FBT. */
#define BM_I2S_TCR5_FBT      (0x00001F00U) /*!< Bit mask for I2S_TCR5_FBT. */
#define BS_I2S_TCR5_FBT      (5U)          /*!< Bit field size in bits for I2S_TCR5_FBT. */

/*! @brief Read current value of the I2S_TCR5_FBT field. */
#define BR_I2S_TCR5_FBT(x)   (HW_I2S_TCR5(x).B.FBT)

/*! @brief Format value for bitfield I2S_TCR5_FBT. */
#define BF_I2S_TCR5_FBT(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR5_FBT) & BM_I2S_TCR5_FBT)

/*! @brief Set the FBT field to a new value. */
#define BW_I2S_TCR5_FBT(x, v) (HW_I2S_TCR5_WR(x, (HW_I2S_TCR5_RD(x) & ~BM_I2S_TCR5_FBT) | BF_I2S_TCR5_FBT(v)))
/*@}*/

/*!
 * @name Register I2S_TCR5, field W0W[20:16] (RW)
 *
 * Configures the number of bits in the first word in each frame. The value
 * written must be one less than the number of bits in the first word. Word width of
 * less than 8 bits is not supported if there is only one word per frame.
 */
/*@{*/
#define BP_I2S_TCR5_W0W      (16U)         /*!< Bit position for I2S_TCR5_W0W. */
#define BM_I2S_TCR5_W0W      (0x001F0000U) /*!< Bit mask for I2S_TCR5_W0W. */
#define BS_I2S_TCR5_W0W      (5U)          /*!< Bit field size in bits for I2S_TCR5_W0W. */

/*! @brief Read current value of the I2S_TCR5_W0W field. */
#define BR_I2S_TCR5_W0W(x)   (HW_I2S_TCR5(x).B.W0W)

/*! @brief Format value for bitfield I2S_TCR5_W0W. */
#define BF_I2S_TCR5_W0W(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR5_W0W) & BM_I2S_TCR5_W0W)

/*! @brief Set the W0W field to a new value. */
#define BW_I2S_TCR5_W0W(x, v) (HW_I2S_TCR5_WR(x, (HW_I2S_TCR5_RD(x) & ~BM_I2S_TCR5_W0W) | BF_I2S_TCR5_W0W(v)))
/*@}*/

/*!
 * @name Register I2S_TCR5, field WNW[28:24] (RW)
 *
 * Configures the number of bits in each word, for each word except the first in
 * the frame. The value written must be one less than the number of bits per
 * word. Word width of less than 8 bits is not supported.
 */
/*@{*/
#define BP_I2S_TCR5_WNW      (24U)         /*!< Bit position for I2S_TCR5_WNW. */
#define BM_I2S_TCR5_WNW      (0x1F000000U) /*!< Bit mask for I2S_TCR5_WNW. */
#define BS_I2S_TCR5_WNW      (5U)          /*!< Bit field size in bits for I2S_TCR5_WNW. */

/*! @brief Read current value of the I2S_TCR5_WNW field. */
#define BR_I2S_TCR5_WNW(x)   (HW_I2S_TCR5(x).B.WNW)

/*! @brief Format value for bitfield I2S_TCR5_WNW. */
#define BF_I2S_TCR5_WNW(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TCR5_WNW) & BM_I2S_TCR5_WNW)

/*! @brief Set the WNW field to a new value. */
#define BW_I2S_TCR5_WNW(x, v) (HW_I2S_TCR5_WR(x, (HW_I2S_TCR5_RD(x) & ~BM_I2S_TCR5_WNW) | BF_I2S_TCR5_WNW(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_TDRn - SAI Transmit Data Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_TDRn - SAI Transmit Data Register (WORZ)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_i2s_tdrn
{
    uint32_t U;
    struct _hw_i2s_tdrn_bitfields
    {
        uint32_t TDR : 32;             /*!< [31:0] Transmit Data Register */
    } B;
} hw_i2s_tdrn_t;

/*!
 * @name Constants and macros for entire I2S_TDRn register
 */
/*@{*/
#define HW_I2S_TDRn_COUNT (1U)

#define HW_I2S_TDRn_ADDR(x, n)   ((uintptr_t)(x) + 0x20U + (0x4U * (n)))

#define HW_I2S_TDRn(x, n)        (*(__O hw_i2s_tdrn_t *) HW_I2S_TDRn_ADDR(x, n))
#define HW_I2S_TDRn_RD(x, n)     (HW_I2S_TDRn(x, n).U)
#define HW_I2S_TDRn_WR(x, n, v)  (HW_I2S_TDRn(x, n).U = (v))
/*@}*/

/*
 * Constants & macros for individual I2S_TDRn bitfields
 */

/*!
 * @name Register I2S_TDRn, field TDR[31:0] (WORZ)
 *
 * The corresponding TCR3[TCE] bit must be set before accessing the channel's
 * transmit data register. Writes to this register when the transmit FIFO is not
 * full will push the data written into the transmit data FIFO. Writes to this
 * register when the transmit FIFO is full are ignored.
 */
/*@{*/
#define BP_I2S_TDRn_TDR      (0U)          /*!< Bit position for I2S_TDRn_TDR. */
#define BM_I2S_TDRn_TDR      (0xFFFFFFFFU) /*!< Bit mask for I2S_TDRn_TDR. */
#define BS_I2S_TDRn_TDR      (32U)         /*!< Bit field size in bits for I2S_TDRn_TDR. */

/*! @brief Format value for bitfield I2S_TDRn_TDR. */
#define BF_I2S_TDRn_TDR(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_TDRn_TDR) & BM_I2S_TDRn_TDR)

/*! @brief Set the TDR field to a new value. */
#define BW_I2S_TDRn_TDR(x, n, v) (HW_I2S_TDRn_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_I2S_TFRn - SAI Transmit FIFO Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_TFRn - SAI Transmit FIFO Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The MSB of the read and write pointers is used to distinguish between FIFO
 * full and empty conditions. If the read and write pointers are identical, then
 * the FIFO is empty. If the read and write pointers are identical except for the
 * MSB, then the FIFO is full.
 */
typedef union _hw_i2s_tfrn
{
    uint32_t U;
    struct _hw_i2s_tfrn_bitfields
    {
        uint32_t RFP : 6;              /*!< [5:0] Read FIFO Pointer */
        uint32_t RESERVED0 : 10;       /*!< [15:6]  */
        uint32_t WFP : 6;              /*!< [21:16] Write FIFO Pointer */
        uint32_t RESERVED1 : 10;       /*!< [31:22]  */
    } B;
} hw_i2s_tfrn_t;

/*!
 * @name Constants and macros for entire I2S_TFRn register
 */
/*@{*/
#define HW_I2S_TFRn_COUNT (1U)

#define HW_I2S_TFRn_ADDR(x, n)   ((uintptr_t)(x) + 0x40U + (0x4U * (n)))

#define HW_I2S_TFRn(x, n)        (*(__I hw_i2s_tfrn_t *) HW_I2S_TFRn_ADDR(x, n))
#define HW_I2S_TFRn_RD(x, n)     (HW_I2S_TFRn(x, n).U)
/*@}*/

/*
 * Constants & macros for individual I2S_TFRn bitfields
 */

/*!
 * @name Register I2S_TFRn, field RFP[5:0] (RO)
 *
 * FIFO read pointer for transmit data channel.
 */
/*@{*/
#define BP_I2S_TFRn_RFP      (0U)          /*!< Bit position for I2S_TFRn_RFP. */
#define BM_I2S_TFRn_RFP      (0x0000003FU) /*!< Bit mask for I2S_TFRn_RFP. */
#define BS_I2S_TFRn_RFP      (6U)          /*!< Bit field size in bits for I2S_TFRn_RFP. */

/*! @brief Read current value of the I2S_TFRn_RFP field. */
#define BR_I2S_TFRn_RFP(x, n) (HW_I2S_TFRn(x, n).B.RFP)
/*@}*/

/*!
 * @name Register I2S_TFRn, field WFP[21:16] (RO)
 *
 * FIFO write pointer for transmit data channel.
 */
/*@{*/
#define BP_I2S_TFRn_WFP      (16U)         /*!< Bit position for I2S_TFRn_WFP. */
#define BM_I2S_TFRn_WFP      (0x003F0000U) /*!< Bit mask for I2S_TFRn_WFP. */
#define BS_I2S_TFRn_WFP      (6U)          /*!< Bit field size in bits for I2S_TFRn_WFP. */

/*! @brief Read current value of the I2S_TFRn_WFP field. */
#define BR_I2S_TFRn_WFP(x, n) (HW_I2S_TFRn(x, n).B.WFP)
/*@}*/

/*******************************************************************************
 * HW_I2S_TMR - SAI Transmit Mask Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_TMR - SAI Transmit Mask Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is double-buffered and updates: When TCSR[TE] is first set At
 * the end of each frame. This allows the masked words in each frame to change
 * from frame to frame.
 */
typedef union _hw_i2s_tmr
{
    uint32_t U;
    struct _hw_i2s_tmr_bitfields
    {
        uint32_t TWM : 32;             /*!< [31:0] Transmit Word Mask */
    } B;
} hw_i2s_tmr_t;

/*!
 * @name Constants and macros for entire I2S_TMR register
 */
/*@{*/
#define HW_I2S_TMR_ADDR(x)       ((uintptr_t)(x) + 0x60U)

#define HW_I2S_TMR(x)            (*(__IO hw_i2s_tmr_t *) HW_I2S_TMR_ADDR(x))
#define HW_I2S_TMR_RD(x)         (HW_I2S_TMR(x).U)
#define HW_I2S_TMR_WR(x, v)      (HW_I2S_TMR(x).U = (v))
#define HW_I2S_TMR_SET(x, v)     (HW_I2S_TMR_WR(x, HW_I2S_TMR_RD(x) |  (v)))
#define HW_I2S_TMR_CLR(x, v)     (HW_I2S_TMR_WR(x, HW_I2S_TMR_RD(x) & ~(v)))
#define HW_I2S_TMR_TOG(x, v)     (HW_I2S_TMR_WR(x, HW_I2S_TMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_TMR bitfields
 */

/*!
 * @name Register I2S_TMR, field TWM[31:0] (RW)
 *
 * Configures whether the transmit word is masked (transmit data pin tristated
 * and transmit data not read from FIFO) for the corresponding word in the frame.
 *
 * Values:
 * - 0 - Word N is enabled.
 * - 1 - Word N is masked. The transmit data pins are tri-stated when masked.
 */
/*@{*/
#define BP_I2S_TMR_TWM       (0U)          /*!< Bit position for I2S_TMR_TWM. */
#define BM_I2S_TMR_TWM       (0xFFFFFFFFU) /*!< Bit mask for I2S_TMR_TWM. */
#define BS_I2S_TMR_TWM       (32U)         /*!< Bit field size in bits for I2S_TMR_TWM. */

/*! @brief Read current value of the I2S_TMR_TWM field. */
#define BR_I2S_TMR_TWM(x)    (HW_I2S_TMR(x).U)

/*! @brief Format value for bitfield I2S_TMR_TWM. */
#define BF_I2S_TMR_TWM(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_TMR_TWM) & BM_I2S_TMR_TWM)

/*! @brief Set the TWM field to a new value. */
#define BW_I2S_TMR_TWM(x, v) (HW_I2S_TMR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_I2S_RCSR - SAI Receive Control Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_RCSR - SAI Receive Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_i2s_rcsr
{
    uint32_t U;
    struct _hw_i2s_rcsr_bitfields
    {
        uint32_t FRDE : 1;             /*!< [0] FIFO Request DMA Enable */
        uint32_t FWDE : 1;             /*!< [1] FIFO Warning DMA Enable */
        uint32_t RESERVED0 : 6;        /*!< [7:2]  */
        uint32_t FRIE : 1;             /*!< [8] FIFO Request Interrupt Enable */
        uint32_t FWIE : 1;             /*!< [9] FIFO Warning Interrupt Enable */
        uint32_t FEIE : 1;             /*!< [10] FIFO Error Interrupt Enable */
        uint32_t SEIE : 1;             /*!< [11] Sync Error Interrupt Enable */
        uint32_t WSIE : 1;             /*!< [12] Word Start Interrupt Enable */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t FRF : 1;              /*!< [16] FIFO Request Flag */
        uint32_t FWF : 1;              /*!< [17] FIFO Warning Flag */
        uint32_t FEF : 1;              /*!< [18] FIFO Error Flag */
        uint32_t SEF : 1;              /*!< [19] Sync Error Flag */
        uint32_t WSF : 1;              /*!< [20] Word Start Flag */
        uint32_t RESERVED2 : 3;        /*!< [23:21]  */
        uint32_t SR : 1;               /*!< [24] Software Reset */
        uint32_t FR : 1;               /*!< [25] FIFO Reset */
        uint32_t RESERVED3 : 2;        /*!< [27:26]  */
        uint32_t BCE : 1;              /*!< [28] Bit Clock Enable */
        uint32_t DBGE : 1;             /*!< [29] Debug Enable */
        uint32_t STOPE : 1;            /*!< [30] Stop Enable */
        uint32_t RE : 1;               /*!< [31] Receiver Enable */
    } B;
} hw_i2s_rcsr_t;

/*!
 * @name Constants and macros for entire I2S_RCSR register
 */
/*@{*/
#define HW_I2S_RCSR_ADDR(x)      ((uintptr_t)(x) + 0x80U)

#define HW_I2S_RCSR(x)           (*(__IO hw_i2s_rcsr_t *) HW_I2S_RCSR_ADDR(x))
#define HW_I2S_RCSR_RD(x)        (HW_I2S_RCSR(x).U)
#define HW_I2S_RCSR_WR(x, v)     (HW_I2S_RCSR(x).U = (v))
#define HW_I2S_RCSR_SET(x, v)    (HW_I2S_RCSR_WR(x, HW_I2S_RCSR_RD(x) |  (v)))
#define HW_I2S_RCSR_CLR(x, v)    (HW_I2S_RCSR_WR(x, HW_I2S_RCSR_RD(x) & ~(v)))
#define HW_I2S_RCSR_TOG(x, v)    (HW_I2S_RCSR_WR(x, HW_I2S_RCSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_RCSR bitfields
 */

/*!
 * @name Register I2S_RCSR, field FRDE[0] (RW)
 *
 * Enables/disables DMA requests.
 *
 * Values:
 * - 0 - Disables the DMA request.
 * - 1 - Enables the DMA request.
 */
/*@{*/
#define BP_I2S_RCSR_FRDE     (0U)          /*!< Bit position for I2S_RCSR_FRDE. */
#define BM_I2S_RCSR_FRDE     (0x00000001U) /*!< Bit mask for I2S_RCSR_FRDE. */
#define BS_I2S_RCSR_FRDE     (1U)          /*!< Bit field size in bits for I2S_RCSR_FRDE. */

/*! @brief Read current value of the I2S_RCSR_FRDE field. */
#define BR_I2S_RCSR_FRDE(x)  (HW_I2S_RCSR(x).B.FRDE)

/*! @brief Format value for bitfield I2S_RCSR_FRDE. */
#define BF_I2S_RCSR_FRDE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_FRDE) & BM_I2S_RCSR_FRDE)

/*! @brief Set the FRDE field to a new value. */
#define BW_I2S_RCSR_FRDE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_FRDE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_FRDE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field FWDE[1] (RW)
 *
 * Enables/disables DMA requests.
 *
 * Values:
 * - 0 - Disables the DMA request.
 * - 1 - Enables the DMA request.
 */
/*@{*/
#define BP_I2S_RCSR_FWDE     (1U)          /*!< Bit position for I2S_RCSR_FWDE. */
#define BM_I2S_RCSR_FWDE     (0x00000002U) /*!< Bit mask for I2S_RCSR_FWDE. */
#define BS_I2S_RCSR_FWDE     (1U)          /*!< Bit field size in bits for I2S_RCSR_FWDE. */

/*! @brief Read current value of the I2S_RCSR_FWDE field. */
#define BR_I2S_RCSR_FWDE(x)  (HW_I2S_RCSR(x).B.FWDE)

/*! @brief Format value for bitfield I2S_RCSR_FWDE. */
#define BF_I2S_RCSR_FWDE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_FWDE) & BM_I2S_RCSR_FWDE)

/*! @brief Set the FWDE field to a new value. */
#define BW_I2S_RCSR_FWDE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_FWDE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_FWDE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field FRIE[8] (RW)
 *
 * Enables/disables FIFO request interrupts.
 *
 * Values:
 * - 0 - Disables the interrupt.
 * - 1 - Enables the interrupt.
 */
/*@{*/
#define BP_I2S_RCSR_FRIE     (8U)          /*!< Bit position for I2S_RCSR_FRIE. */
#define BM_I2S_RCSR_FRIE     (0x00000100U) /*!< Bit mask for I2S_RCSR_FRIE. */
#define BS_I2S_RCSR_FRIE     (1U)          /*!< Bit field size in bits for I2S_RCSR_FRIE. */

/*! @brief Read current value of the I2S_RCSR_FRIE field. */
#define BR_I2S_RCSR_FRIE(x)  (HW_I2S_RCSR(x).B.FRIE)

/*! @brief Format value for bitfield I2S_RCSR_FRIE. */
#define BF_I2S_RCSR_FRIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_FRIE) & BM_I2S_RCSR_FRIE)

/*! @brief Set the FRIE field to a new value. */
#define BW_I2S_RCSR_FRIE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_FRIE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_FRIE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field FWIE[9] (RW)
 *
 * Enables/disables FIFO warning interrupts.
 *
 * Values:
 * - 0 - Disables the interrupt.
 * - 1 - Enables the interrupt.
 */
/*@{*/
#define BP_I2S_RCSR_FWIE     (9U)          /*!< Bit position for I2S_RCSR_FWIE. */
#define BM_I2S_RCSR_FWIE     (0x00000200U) /*!< Bit mask for I2S_RCSR_FWIE. */
#define BS_I2S_RCSR_FWIE     (1U)          /*!< Bit field size in bits for I2S_RCSR_FWIE. */

/*! @brief Read current value of the I2S_RCSR_FWIE field. */
#define BR_I2S_RCSR_FWIE(x)  (HW_I2S_RCSR(x).B.FWIE)

/*! @brief Format value for bitfield I2S_RCSR_FWIE. */
#define BF_I2S_RCSR_FWIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_FWIE) & BM_I2S_RCSR_FWIE)

/*! @brief Set the FWIE field to a new value. */
#define BW_I2S_RCSR_FWIE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_FWIE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_FWIE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field FEIE[10] (RW)
 *
 * Enables/disables FIFO error interrupts.
 *
 * Values:
 * - 0 - Disables the interrupt.
 * - 1 - Enables the interrupt.
 */
/*@{*/
#define BP_I2S_RCSR_FEIE     (10U)         /*!< Bit position for I2S_RCSR_FEIE. */
#define BM_I2S_RCSR_FEIE     (0x00000400U) /*!< Bit mask for I2S_RCSR_FEIE. */
#define BS_I2S_RCSR_FEIE     (1U)          /*!< Bit field size in bits for I2S_RCSR_FEIE. */

/*! @brief Read current value of the I2S_RCSR_FEIE field. */
#define BR_I2S_RCSR_FEIE(x)  (HW_I2S_RCSR(x).B.FEIE)

/*! @brief Format value for bitfield I2S_RCSR_FEIE. */
#define BF_I2S_RCSR_FEIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_FEIE) & BM_I2S_RCSR_FEIE)

/*! @brief Set the FEIE field to a new value. */
#define BW_I2S_RCSR_FEIE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_FEIE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_FEIE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field SEIE[11] (RW)
 *
 * Enables/disables sync error interrupts.
 *
 * Values:
 * - 0 - Disables interrupt.
 * - 1 - Enables interrupt.
 */
/*@{*/
#define BP_I2S_RCSR_SEIE     (11U)         /*!< Bit position for I2S_RCSR_SEIE. */
#define BM_I2S_RCSR_SEIE     (0x00000800U) /*!< Bit mask for I2S_RCSR_SEIE. */
#define BS_I2S_RCSR_SEIE     (1U)          /*!< Bit field size in bits for I2S_RCSR_SEIE. */

/*! @brief Read current value of the I2S_RCSR_SEIE field. */
#define BR_I2S_RCSR_SEIE(x)  (HW_I2S_RCSR(x).B.SEIE)

/*! @brief Format value for bitfield I2S_RCSR_SEIE. */
#define BF_I2S_RCSR_SEIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_SEIE) & BM_I2S_RCSR_SEIE)

/*! @brief Set the SEIE field to a new value. */
#define BW_I2S_RCSR_SEIE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_SEIE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_SEIE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field WSIE[12] (RW)
 *
 * Enables/disables word start interrupts.
 *
 * Values:
 * - 0 - Disables interrupt.
 * - 1 - Enables interrupt.
 */
/*@{*/
#define BP_I2S_RCSR_WSIE     (12U)         /*!< Bit position for I2S_RCSR_WSIE. */
#define BM_I2S_RCSR_WSIE     (0x00001000U) /*!< Bit mask for I2S_RCSR_WSIE. */
#define BS_I2S_RCSR_WSIE     (1U)          /*!< Bit field size in bits for I2S_RCSR_WSIE. */

/*! @brief Read current value of the I2S_RCSR_WSIE field. */
#define BR_I2S_RCSR_WSIE(x)  (HW_I2S_RCSR(x).B.WSIE)

/*! @brief Format value for bitfield I2S_RCSR_WSIE. */
#define BF_I2S_RCSR_WSIE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_WSIE) & BM_I2S_RCSR_WSIE)

/*! @brief Set the WSIE field to a new value. */
#define BW_I2S_RCSR_WSIE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_WSIE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_WSIE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field FRF[16] (RO)
 *
 * Indicates that the number of words in an enabled receive channel FIFO is
 * greater than the receive FIFO watermark.
 *
 * Values:
 * - 0 - Receive FIFO watermark not reached.
 * - 1 - Receive FIFO watermark has been reached.
 */
/*@{*/
#define BP_I2S_RCSR_FRF      (16U)         /*!< Bit position for I2S_RCSR_FRF. */
#define BM_I2S_RCSR_FRF      (0x00010000U) /*!< Bit mask for I2S_RCSR_FRF. */
#define BS_I2S_RCSR_FRF      (1U)          /*!< Bit field size in bits for I2S_RCSR_FRF. */

/*! @brief Read current value of the I2S_RCSR_FRF field. */
#define BR_I2S_RCSR_FRF(x)   (HW_I2S_RCSR(x).B.FRF)
/*@}*/

/*!
 * @name Register I2S_RCSR, field FWF[17] (RO)
 *
 * Indicates that an enabled receive FIFO is full.
 *
 * Values:
 * - 0 - No enabled receive FIFO is full.
 * - 1 - Enabled receive FIFO is full.
 */
/*@{*/
#define BP_I2S_RCSR_FWF      (17U)         /*!< Bit position for I2S_RCSR_FWF. */
#define BM_I2S_RCSR_FWF      (0x00020000U) /*!< Bit mask for I2S_RCSR_FWF. */
#define BS_I2S_RCSR_FWF      (1U)          /*!< Bit field size in bits for I2S_RCSR_FWF. */

/*! @brief Read current value of the I2S_RCSR_FWF field. */
#define BR_I2S_RCSR_FWF(x)   (HW_I2S_RCSR(x).B.FWF)
/*@}*/

/*!
 * @name Register I2S_RCSR, field FEF[18] (W1C)
 *
 * Indicates that an enabled receive FIFO has overflowed. Write a logic 1 to
 * this field to clear this flag.
 *
 * Values:
 * - 0 - Receive overflow not detected.
 * - 1 - Receive overflow detected.
 */
/*@{*/
#define BP_I2S_RCSR_FEF      (18U)         /*!< Bit position for I2S_RCSR_FEF. */
#define BM_I2S_RCSR_FEF      (0x00040000U) /*!< Bit mask for I2S_RCSR_FEF. */
#define BS_I2S_RCSR_FEF      (1U)          /*!< Bit field size in bits for I2S_RCSR_FEF. */

/*! @brief Read current value of the I2S_RCSR_FEF field. */
#define BR_I2S_RCSR_FEF(x)   (HW_I2S_RCSR(x).B.FEF)

/*! @brief Format value for bitfield I2S_RCSR_FEF. */
#define BF_I2S_RCSR_FEF(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_FEF) & BM_I2S_RCSR_FEF)

/*! @brief Set the FEF field to a new value. */
#define BW_I2S_RCSR_FEF(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_FEF(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field SEF[19] (W1C)
 *
 * Indicates that an error in the externally-generated frame sync has been
 * detected. Write a logic 1 to this field to clear this flag.
 *
 * Values:
 * - 0 - Sync error not detected.
 * - 1 - Frame sync error detected.
 */
/*@{*/
#define BP_I2S_RCSR_SEF      (19U)         /*!< Bit position for I2S_RCSR_SEF. */
#define BM_I2S_RCSR_SEF      (0x00080000U) /*!< Bit mask for I2S_RCSR_SEF. */
#define BS_I2S_RCSR_SEF      (1U)          /*!< Bit field size in bits for I2S_RCSR_SEF. */

/*! @brief Read current value of the I2S_RCSR_SEF field. */
#define BR_I2S_RCSR_SEF(x)   (HW_I2S_RCSR(x).B.SEF)

/*! @brief Format value for bitfield I2S_RCSR_SEF. */
#define BF_I2S_RCSR_SEF(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_SEF) & BM_I2S_RCSR_SEF)

/*! @brief Set the SEF field to a new value. */
#define BW_I2S_RCSR_SEF(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_SEF | BM_I2S_RCSR_FEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_SEF(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field WSF[20] (W1C)
 *
 * Indicates that the start of the configured word has been detected. Write a
 * logic 1 to this field to clear this flag.
 *
 * Values:
 * - 0 - Start of word not detected.
 * - 1 - Start of word detected.
 */
/*@{*/
#define BP_I2S_RCSR_WSF      (20U)         /*!< Bit position for I2S_RCSR_WSF. */
#define BM_I2S_RCSR_WSF      (0x00100000U) /*!< Bit mask for I2S_RCSR_WSF. */
#define BS_I2S_RCSR_WSF      (1U)          /*!< Bit field size in bits for I2S_RCSR_WSF. */

/*! @brief Read current value of the I2S_RCSR_WSF field. */
#define BR_I2S_RCSR_WSF(x)   (HW_I2S_RCSR(x).B.WSF)

/*! @brief Format value for bitfield I2S_RCSR_WSF. */
#define BF_I2S_RCSR_WSF(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_WSF) & BM_I2S_RCSR_WSF)

/*! @brief Set the WSF field to a new value. */
#define BW_I2S_RCSR_WSF(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_WSF | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF)) | BF_I2S_RCSR_WSF(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field SR[24] (RW)
 *
 * Resets the internal receiver logic including the FIFO pointers.
 * Software-visible registers are not affected, except for the status registers.
 *
 * Values:
 * - 0 - No effect.
 * - 1 - Software reset.
 */
/*@{*/
#define BP_I2S_RCSR_SR       (24U)         /*!< Bit position for I2S_RCSR_SR. */
#define BM_I2S_RCSR_SR       (0x01000000U) /*!< Bit mask for I2S_RCSR_SR. */
#define BS_I2S_RCSR_SR       (1U)          /*!< Bit field size in bits for I2S_RCSR_SR. */

/*! @brief Read current value of the I2S_RCSR_SR field. */
#define BR_I2S_RCSR_SR(x)    (HW_I2S_RCSR(x).B.SR)

/*! @brief Format value for bitfield I2S_RCSR_SR. */
#define BF_I2S_RCSR_SR(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_SR) & BM_I2S_RCSR_SR)

/*! @brief Set the SR field to a new value. */
#define BW_I2S_RCSR_SR(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_SR | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_SR(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field FR[25] (WORZ)
 *
 * Resets the FIFO pointers. Reading this field will always return zero. FIFO
 * pointers should only be reset when the receiver is disabled or the FIFO error
 * flag is set.
 *
 * Values:
 * - 0 - No effect.
 * - 1 - FIFO reset.
 */
/*@{*/
#define BP_I2S_RCSR_FR       (25U)         /*!< Bit position for I2S_RCSR_FR. */
#define BM_I2S_RCSR_FR       (0x02000000U) /*!< Bit mask for I2S_RCSR_FR. */
#define BS_I2S_RCSR_FR       (1U)          /*!< Bit field size in bits for I2S_RCSR_FR. */

/*! @brief Format value for bitfield I2S_RCSR_FR. */
#define BF_I2S_RCSR_FR(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_FR) & BM_I2S_RCSR_FR)

/*! @brief Set the FR field to a new value. */
#define BW_I2S_RCSR_FR(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_FR | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_FR(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field BCE[28] (RW)
 *
 * Enables the receive bit clock, separately from RE. This field is
 * automatically set whenever RE is set. When software clears this field, the receive bit
 * clock remains enabled, and this field remains set, until the end of the current
 * frame.
 *
 * Values:
 * - 0 - Receive bit clock is disabled.
 * - 1 - Receive bit clock is enabled.
 */
/*@{*/
#define BP_I2S_RCSR_BCE      (28U)         /*!< Bit position for I2S_RCSR_BCE. */
#define BM_I2S_RCSR_BCE      (0x10000000U) /*!< Bit mask for I2S_RCSR_BCE. */
#define BS_I2S_RCSR_BCE      (1U)          /*!< Bit field size in bits for I2S_RCSR_BCE. */

/*! @brief Read current value of the I2S_RCSR_BCE field. */
#define BR_I2S_RCSR_BCE(x)   (HW_I2S_RCSR(x).B.BCE)

/*! @brief Format value for bitfield I2S_RCSR_BCE. */
#define BF_I2S_RCSR_BCE(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_BCE) & BM_I2S_RCSR_BCE)

/*! @brief Set the BCE field to a new value. */
#define BW_I2S_RCSR_BCE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_BCE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_BCE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field DBGE[29] (RW)
 *
 * Enables/disables receiver operation in Debug mode. The receive bit clock is
 * not affected by Debug mode.
 *
 * Values:
 * - 0 - Receiver is disabled in Debug mode, after completing the current frame.
 * - 1 - Receiver is enabled in Debug mode.
 */
/*@{*/
#define BP_I2S_RCSR_DBGE     (29U)         /*!< Bit position for I2S_RCSR_DBGE. */
#define BM_I2S_RCSR_DBGE     (0x20000000U) /*!< Bit mask for I2S_RCSR_DBGE. */
#define BS_I2S_RCSR_DBGE     (1U)          /*!< Bit field size in bits for I2S_RCSR_DBGE. */

/*! @brief Read current value of the I2S_RCSR_DBGE field. */
#define BR_I2S_RCSR_DBGE(x)  (HW_I2S_RCSR(x).B.DBGE)

/*! @brief Format value for bitfield I2S_RCSR_DBGE. */
#define BF_I2S_RCSR_DBGE(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_DBGE) & BM_I2S_RCSR_DBGE)

/*! @brief Set the DBGE field to a new value. */
#define BW_I2S_RCSR_DBGE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_DBGE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_DBGE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field STOPE[30] (RW)
 *
 * Configures receiver operation in Stop mode. This bit is ignored and the
 * receiver is disabled in all stop modes.
 *
 * Values:
 * - 0 - Receiver disabled in Stop mode.
 * - 1 - Receiver enabled in Stop mode.
 */
/*@{*/
#define BP_I2S_RCSR_STOPE    (30U)         /*!< Bit position for I2S_RCSR_STOPE. */
#define BM_I2S_RCSR_STOPE    (0x40000000U) /*!< Bit mask for I2S_RCSR_STOPE. */
#define BS_I2S_RCSR_STOPE    (1U)          /*!< Bit field size in bits for I2S_RCSR_STOPE. */

/*! @brief Read current value of the I2S_RCSR_STOPE field. */
#define BR_I2S_RCSR_STOPE(x) (HW_I2S_RCSR(x).B.STOPE)

/*! @brief Format value for bitfield I2S_RCSR_STOPE. */
#define BF_I2S_RCSR_STOPE(v) ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_STOPE) & BM_I2S_RCSR_STOPE)

/*! @brief Set the STOPE field to a new value. */
#define BW_I2S_RCSR_STOPE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_STOPE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_STOPE(v)))
/*@}*/

/*!
 * @name Register I2S_RCSR, field RE[31] (RW)
 *
 * Enables/disables the receiver. When software clears this field, the receiver
 * remains enabled, and this bit remains set, until the end of the current frame.
 *
 * Values:
 * - 0 - Receiver is disabled.
 * - 1 - Receiver is enabled, or receiver has been disabled and has not yet
 *     reached end of frame.
 */
/*@{*/
#define BP_I2S_RCSR_RE       (31U)         /*!< Bit position for I2S_RCSR_RE. */
#define BM_I2S_RCSR_RE       (0x80000000U) /*!< Bit mask for I2S_RCSR_RE. */
#define BS_I2S_RCSR_RE       (1U)          /*!< Bit field size in bits for I2S_RCSR_RE. */

/*! @brief Read current value of the I2S_RCSR_RE field. */
#define BR_I2S_RCSR_RE(x)    (HW_I2S_RCSR(x).B.RE)

/*! @brief Format value for bitfield I2S_RCSR_RE. */
#define BF_I2S_RCSR_RE(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_RCSR_RE) & BM_I2S_RCSR_RE)

/*! @brief Set the RE field to a new value. */
#define BW_I2S_RCSR_RE(x, v) (HW_I2S_RCSR_WR(x, (HW_I2S_RCSR_RD(x) & ~(BM_I2S_RCSR_RE | BM_I2S_RCSR_FEF | BM_I2S_RCSR_SEF | BM_I2S_RCSR_WSF)) | BF_I2S_RCSR_RE(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_RCR1 - SAI Receive Configuration 1 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_RCR1 - SAI Receive Configuration 1 Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_i2s_rcr1
{
    uint32_t U;
    struct _hw_i2s_rcr1_bitfields
    {
        uint32_t RFW : 5;              /*!< [4:0] Receive FIFO Watermark */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_i2s_rcr1_t;

/*!
 * @name Constants and macros for entire I2S_RCR1 register
 */
/*@{*/
#define HW_I2S_RCR1_ADDR(x)      ((uintptr_t)(x) + 0x84U)

#define HW_I2S_RCR1(x)           (*(__IO hw_i2s_rcr1_t *) HW_I2S_RCR1_ADDR(x))
#define HW_I2S_RCR1_RD(x)        (HW_I2S_RCR1(x).U)
#define HW_I2S_RCR1_WR(x, v)     (HW_I2S_RCR1(x).U = (v))
#define HW_I2S_RCR1_SET(x, v)    (HW_I2S_RCR1_WR(x, HW_I2S_RCR1_RD(x) |  (v)))
#define HW_I2S_RCR1_CLR(x, v)    (HW_I2S_RCR1_WR(x, HW_I2S_RCR1_RD(x) & ~(v)))
#define HW_I2S_RCR1_TOG(x, v)    (HW_I2S_RCR1_WR(x, HW_I2S_RCR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_RCR1 bitfields
 */

/*!
 * @name Register I2S_RCR1, field RFW[4:0] (RW)
 *
 * Configures the watermark level for all enabled receiver channels.
 */
/*@{*/
#define BP_I2S_RCR1_RFW      (0U)          /*!< Bit position for I2S_RCR1_RFW. */
#define BM_I2S_RCR1_RFW      (0x0000001FU) /*!< Bit mask for I2S_RCR1_RFW. */
#define BS_I2S_RCR1_RFW      (5U)          /*!< Bit field size in bits for I2S_RCR1_RFW. */

/*! @brief Read current value of the I2S_RCR1_RFW field. */
#define BR_I2S_RCR1_RFW(x)   (HW_I2S_RCR1(x).B.RFW)

/*! @brief Format value for bitfield I2S_RCR1_RFW. */
#define BF_I2S_RCR1_RFW(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR1_RFW) & BM_I2S_RCR1_RFW)

/*! @brief Set the RFW field to a new value. */
#define BW_I2S_RCR1_RFW(x, v) (HW_I2S_RCR1_WR(x, (HW_I2S_RCR1_RD(x) & ~BM_I2S_RCR1_RFW) | BF_I2S_RCR1_RFW(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_RCR2 - SAI Receive Configuration 2 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_RCR2 - SAI Receive Configuration 2 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register must not be altered when RCSR[RE] is set.
 */
typedef union _hw_i2s_rcr2
{
    uint32_t U;
    struct _hw_i2s_rcr2_bitfields
    {
        uint32_t DIV : 8;              /*!< [7:0] Bit Clock Divide */
        uint32_t RESERVED0 : 16;       /*!< [23:8]  */
        uint32_t BCD : 1;              /*!< [24] Bit Clock Direction */
        uint32_t BCP : 1;              /*!< [25] Bit Clock Polarity */
        uint32_t MSEL : 2;             /*!< [27:26] MCLK Select */
        uint32_t BCI : 1;              /*!< [28] Bit Clock Input */
        uint32_t BCS : 1;              /*!< [29] Bit Clock Swap */
        uint32_t SYNC : 2;             /*!< [31:30] Synchronous Mode */
    } B;
} hw_i2s_rcr2_t;

/*!
 * @name Constants and macros for entire I2S_RCR2 register
 */
/*@{*/
#define HW_I2S_RCR2_ADDR(x)      ((uintptr_t)(x) + 0x88U)

#define HW_I2S_RCR2(x)           (*(__IO hw_i2s_rcr2_t *) HW_I2S_RCR2_ADDR(x))
#define HW_I2S_RCR2_RD(x)        (HW_I2S_RCR2(x).U)
#define HW_I2S_RCR2_WR(x, v)     (HW_I2S_RCR2(x).U = (v))
#define HW_I2S_RCR2_SET(x, v)    (HW_I2S_RCR2_WR(x, HW_I2S_RCR2_RD(x) |  (v)))
#define HW_I2S_RCR2_CLR(x, v)    (HW_I2S_RCR2_WR(x, HW_I2S_RCR2_RD(x) & ~(v)))
#define HW_I2S_RCR2_TOG(x, v)    (HW_I2S_RCR2_WR(x, HW_I2S_RCR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_RCR2 bitfields
 */

/*!
 * @name Register I2S_RCR2, field DIV[7:0] (RW)
 *
 * Divides down the audio master clock to generate the bit clock when configured
 * for an internal bit clock. The division value is (DIV + 1) * 2.
 */
/*@{*/
#define BP_I2S_RCR2_DIV      (0U)          /*!< Bit position for I2S_RCR2_DIV. */
#define BM_I2S_RCR2_DIV      (0x000000FFU) /*!< Bit mask for I2S_RCR2_DIV. */
#define BS_I2S_RCR2_DIV      (8U)          /*!< Bit field size in bits for I2S_RCR2_DIV. */

/*! @brief Read current value of the I2S_RCR2_DIV field. */
#define BR_I2S_RCR2_DIV(x)   (HW_I2S_RCR2(x).B.DIV)

/*! @brief Format value for bitfield I2S_RCR2_DIV. */
#define BF_I2S_RCR2_DIV(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR2_DIV) & BM_I2S_RCR2_DIV)

/*! @brief Set the DIV field to a new value. */
#define BW_I2S_RCR2_DIV(x, v) (HW_I2S_RCR2_WR(x, (HW_I2S_RCR2_RD(x) & ~BM_I2S_RCR2_DIV) | BF_I2S_RCR2_DIV(v)))
/*@}*/

/*!
 * @name Register I2S_RCR2, field BCD[24] (RW)
 *
 * Configures the direction of the bit clock.
 *
 * Values:
 * - 0 - Bit clock is generated externally in Slave mode.
 * - 1 - Bit clock is generated internally in Master mode.
 */
/*@{*/
#define BP_I2S_RCR2_BCD      (24U)         /*!< Bit position for I2S_RCR2_BCD. */
#define BM_I2S_RCR2_BCD      (0x01000000U) /*!< Bit mask for I2S_RCR2_BCD. */
#define BS_I2S_RCR2_BCD      (1U)          /*!< Bit field size in bits for I2S_RCR2_BCD. */

/*! @brief Read current value of the I2S_RCR2_BCD field. */
#define BR_I2S_RCR2_BCD(x)   (HW_I2S_RCR2(x).B.BCD)

/*! @brief Format value for bitfield I2S_RCR2_BCD. */
#define BF_I2S_RCR2_BCD(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR2_BCD) & BM_I2S_RCR2_BCD)

/*! @brief Set the BCD field to a new value. */
#define BW_I2S_RCR2_BCD(x, v) (HW_I2S_RCR2_WR(x, (HW_I2S_RCR2_RD(x) & ~BM_I2S_RCR2_BCD) | BF_I2S_RCR2_BCD(v)))
/*@}*/

/*!
 * @name Register I2S_RCR2, field BCP[25] (RW)
 *
 * Configures the polarity of the bit clock.
 *
 * Values:
 * - 0 - Bit Clock is active high with drive outputs on rising edge and sample
 *     inputs on falling edge.
 * - 1 - Bit Clock is active low with drive outputs on falling edge and sample
 *     inputs on rising edge.
 */
/*@{*/
#define BP_I2S_RCR2_BCP      (25U)         /*!< Bit position for I2S_RCR2_BCP. */
#define BM_I2S_RCR2_BCP      (0x02000000U) /*!< Bit mask for I2S_RCR2_BCP. */
#define BS_I2S_RCR2_BCP      (1U)          /*!< Bit field size in bits for I2S_RCR2_BCP. */

/*! @brief Read current value of the I2S_RCR2_BCP field. */
#define BR_I2S_RCR2_BCP(x)   (HW_I2S_RCR2(x).B.BCP)

/*! @brief Format value for bitfield I2S_RCR2_BCP. */
#define BF_I2S_RCR2_BCP(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR2_BCP) & BM_I2S_RCR2_BCP)

/*! @brief Set the BCP field to a new value. */
#define BW_I2S_RCR2_BCP(x, v) (HW_I2S_RCR2_WR(x, (HW_I2S_RCR2_RD(x) & ~BM_I2S_RCR2_BCP) | BF_I2S_RCR2_BCP(v)))
/*@}*/

/*!
 * @name Register I2S_RCR2, field MSEL[27:26] (RW)
 *
 * Selects the audio Master Clock option used to generate an internally
 * generated bit clock. This field has no effect when configured for an externally
 * generated bit clock. Depending on the device, some Master Clock options might not be
 * available. See the chip-specific information for the availability and
 * chip-specific meaning of each option.
 *
 * Values:
 * - 00 - Bus Clock selected.
 * - 01 - Master Clock (MCLK) 1 option selected.
 * - 10 - Master Clock (MCLK) 2 option selected.
 * - 11 - Master Clock (MCLK) 3 option selected.
 */
/*@{*/
#define BP_I2S_RCR2_MSEL     (26U)         /*!< Bit position for I2S_RCR2_MSEL. */
#define BM_I2S_RCR2_MSEL     (0x0C000000U) /*!< Bit mask for I2S_RCR2_MSEL. */
#define BS_I2S_RCR2_MSEL     (2U)          /*!< Bit field size in bits for I2S_RCR2_MSEL. */

/*! @brief Read current value of the I2S_RCR2_MSEL field. */
#define BR_I2S_RCR2_MSEL(x)  (HW_I2S_RCR2(x).B.MSEL)

/*! @brief Format value for bitfield I2S_RCR2_MSEL. */
#define BF_I2S_RCR2_MSEL(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCR2_MSEL) & BM_I2S_RCR2_MSEL)

/*! @brief Set the MSEL field to a new value. */
#define BW_I2S_RCR2_MSEL(x, v) (HW_I2S_RCR2_WR(x, (HW_I2S_RCR2_RD(x) & ~BM_I2S_RCR2_MSEL) | BF_I2S_RCR2_MSEL(v)))
/*@}*/

/*!
 * @name Register I2S_RCR2, field BCI[28] (RW)
 *
 * When this field is set and using an internally generated bit clock in either
 * synchronous or asynchronous mode, the bit clock actually used by the receiver
 * is delayed by the pad output delay (the receiver is clocked by the pad input
 * as if the clock was externally generated). This has the effect of decreasing
 * the data input setup time, but increasing the data output valid time. The slave
 * mode timing from the datasheet should be used for the receiver when this bit
 * is set. In synchronous mode, this bit allows the receiver to use the slave mode
 * timing from the datasheet, while the transmitter uses the master mode timing.
 * This field has no effect when configured for an externally generated bit
 * clock .
 *
 * Values:
 * - 0 - No effect.
 * - 1 - Internal logic is clocked as if bit clock was externally generated.
 */
/*@{*/
#define BP_I2S_RCR2_BCI      (28U)         /*!< Bit position for I2S_RCR2_BCI. */
#define BM_I2S_RCR2_BCI      (0x10000000U) /*!< Bit mask for I2S_RCR2_BCI. */
#define BS_I2S_RCR2_BCI      (1U)          /*!< Bit field size in bits for I2S_RCR2_BCI. */

/*! @brief Read current value of the I2S_RCR2_BCI field. */
#define BR_I2S_RCR2_BCI(x)   (HW_I2S_RCR2(x).B.BCI)

/*! @brief Format value for bitfield I2S_RCR2_BCI. */
#define BF_I2S_RCR2_BCI(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR2_BCI) & BM_I2S_RCR2_BCI)

/*! @brief Set the BCI field to a new value. */
#define BW_I2S_RCR2_BCI(x, v) (HW_I2S_RCR2_WR(x, (HW_I2S_RCR2_RD(x) & ~BM_I2S_RCR2_BCI) | BF_I2S_RCR2_BCI(v)))
/*@}*/

/*!
 * @name Register I2S_RCR2, field BCS[29] (RW)
 *
 * This field swaps the bit clock used by the receiver. When the receiver is
 * configured in asynchronous mode and this bit is set, the receiver is clocked by
 * the transmitter bit clock (SAI_TX_BCLK). This allows the transmitter and
 * receiver to share the same bit clock, but the receiver continues to use the receiver
 * frame sync (SAI_RX_SYNC). When the receiver is configured in synchronous
 * mode, the transmitter BCS field and receiver BCS field must be set to the same
 * value. When both are set, the transmitter and receiver are both clocked by the
 * receiver bit clock (SAI_RX_BCLK) but use the transmitter frame sync
 * (SAI_TX_SYNC).
 *
 * Values:
 * - 0 - Use the normal bit clock source.
 * - 1 - Swap the bit clock source.
 */
/*@{*/
#define BP_I2S_RCR2_BCS      (29U)         /*!< Bit position for I2S_RCR2_BCS. */
#define BM_I2S_RCR2_BCS      (0x20000000U) /*!< Bit mask for I2S_RCR2_BCS. */
#define BS_I2S_RCR2_BCS      (1U)          /*!< Bit field size in bits for I2S_RCR2_BCS. */

/*! @brief Read current value of the I2S_RCR2_BCS field. */
#define BR_I2S_RCR2_BCS(x)   (HW_I2S_RCR2(x).B.BCS)

/*! @brief Format value for bitfield I2S_RCR2_BCS. */
#define BF_I2S_RCR2_BCS(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR2_BCS) & BM_I2S_RCR2_BCS)

/*! @brief Set the BCS field to a new value. */
#define BW_I2S_RCR2_BCS(x, v) (HW_I2S_RCR2_WR(x, (HW_I2S_RCR2_RD(x) & ~BM_I2S_RCR2_BCS) | BF_I2S_RCR2_BCS(v)))
/*@}*/

/*!
 * @name Register I2S_RCR2, field SYNC[31:30] (RW)
 *
 * Configures between asynchronous and synchronous modes of operation. When
 * configured for a synchronous mode of operation, the transmitter must be configured
 * for asynchronous operation.
 *
 * Values:
 * - 00 - Asynchronous mode.
 * - 01 - Synchronous with transmitter.
 */
/*@{*/
#define BP_I2S_RCR2_SYNC     (30U)         /*!< Bit position for I2S_RCR2_SYNC. */
#define BM_I2S_RCR2_SYNC     (0xC0000000U) /*!< Bit mask for I2S_RCR2_SYNC. */
#define BS_I2S_RCR2_SYNC     (2U)          /*!< Bit field size in bits for I2S_RCR2_SYNC. */

/*! @brief Read current value of the I2S_RCR2_SYNC field. */
#define BR_I2S_RCR2_SYNC(x)  (HW_I2S_RCR2(x).B.SYNC)

/*! @brief Format value for bitfield I2S_RCR2_SYNC. */
#define BF_I2S_RCR2_SYNC(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCR2_SYNC) & BM_I2S_RCR2_SYNC)

/*! @brief Set the SYNC field to a new value. */
#define BW_I2S_RCR2_SYNC(x, v) (HW_I2S_RCR2_WR(x, (HW_I2S_RCR2_RD(x) & ~BM_I2S_RCR2_SYNC) | BF_I2S_RCR2_SYNC(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_RCR3 - SAI Receive Configuration 3 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_RCR3 - SAI Receive Configuration 3 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register must not be altered when RCSR[RE] is set.
 */
typedef union _hw_i2s_rcr3
{
    uint32_t U;
    struct _hw_i2s_rcr3_bitfields
    {
        uint32_t WDFL : 5;             /*!< [4:0] Word Flag Configuration */
        uint32_t RESERVED0 : 11;       /*!< [15:5]  */
        uint32_t RCE : 1;              /*!< [16] Receive Channel Enable */
        uint32_t RESERVED1 : 15;       /*!< [31:17]  */
    } B;
} hw_i2s_rcr3_t;

/*!
 * @name Constants and macros for entire I2S_RCR3 register
 */
/*@{*/
#define HW_I2S_RCR3_ADDR(x)      ((uintptr_t)(x) + 0x8CU)

#define HW_I2S_RCR3(x)           (*(__IO hw_i2s_rcr3_t *) HW_I2S_RCR3_ADDR(x))
#define HW_I2S_RCR3_RD(x)        (HW_I2S_RCR3(x).U)
#define HW_I2S_RCR3_WR(x, v)     (HW_I2S_RCR3(x).U = (v))
#define HW_I2S_RCR3_SET(x, v)    (HW_I2S_RCR3_WR(x, HW_I2S_RCR3_RD(x) |  (v)))
#define HW_I2S_RCR3_CLR(x, v)    (HW_I2S_RCR3_WR(x, HW_I2S_RCR3_RD(x) & ~(v)))
#define HW_I2S_RCR3_TOG(x, v)    (HW_I2S_RCR3_WR(x, HW_I2S_RCR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_RCR3 bitfields
 */

/*!
 * @name Register I2S_RCR3, field WDFL[4:0] (RW)
 *
 * Configures which word the start of word flag is set. The value written should
 * be one less than the word number (for example, write zero to configure for
 * the first word in the frame). When configured to a value greater than the Frame
 * Size field, then the start of word flag is never set.
 */
/*@{*/
#define BP_I2S_RCR3_WDFL     (0U)          /*!< Bit position for I2S_RCR3_WDFL. */
#define BM_I2S_RCR3_WDFL     (0x0000001FU) /*!< Bit mask for I2S_RCR3_WDFL. */
#define BS_I2S_RCR3_WDFL     (5U)          /*!< Bit field size in bits for I2S_RCR3_WDFL. */

/*! @brief Read current value of the I2S_RCR3_WDFL field. */
#define BR_I2S_RCR3_WDFL(x)  (HW_I2S_RCR3(x).B.WDFL)

/*! @brief Format value for bitfield I2S_RCR3_WDFL. */
#define BF_I2S_RCR3_WDFL(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCR3_WDFL) & BM_I2S_RCR3_WDFL)

/*! @brief Set the WDFL field to a new value. */
#define BW_I2S_RCR3_WDFL(x, v) (HW_I2S_RCR3_WR(x, (HW_I2S_RCR3_RD(x) & ~BM_I2S_RCR3_WDFL) | BF_I2S_RCR3_WDFL(v)))
/*@}*/

/*!
 * @name Register I2S_RCR3, field RCE[16] (RW)
 *
 * Enables the corresponding data channel for receive operation. A channel must
 * be enabled before its FIFO is accessed.
 *
 * Values:
 * - 0 - Receive data channel N is disabled.
 * - 1 - Receive data channel N is enabled.
 */
/*@{*/
#define BP_I2S_RCR3_RCE      (16U)         /*!< Bit position for I2S_RCR3_RCE. */
#define BM_I2S_RCR3_RCE      (0x00010000U) /*!< Bit mask for I2S_RCR3_RCE. */
#define BS_I2S_RCR3_RCE      (1U)          /*!< Bit field size in bits for I2S_RCR3_RCE. */

/*! @brief Read current value of the I2S_RCR3_RCE field. */
#define BR_I2S_RCR3_RCE(x)   (HW_I2S_RCR3(x).B.RCE)

/*! @brief Format value for bitfield I2S_RCR3_RCE. */
#define BF_I2S_RCR3_RCE(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR3_RCE) & BM_I2S_RCR3_RCE)

/*! @brief Set the RCE field to a new value. */
#define BW_I2S_RCR3_RCE(x, v) (HW_I2S_RCR3_WR(x, (HW_I2S_RCR3_RD(x) & ~BM_I2S_RCR3_RCE) | BF_I2S_RCR3_RCE(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_RCR4 - SAI Receive Configuration 4 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_RCR4 - SAI Receive Configuration 4 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register must not be altered when RCSR[RE] is set.
 */
typedef union _hw_i2s_rcr4
{
    uint32_t U;
    struct _hw_i2s_rcr4_bitfields
    {
        uint32_t FSD : 1;              /*!< [0] Frame Sync Direction */
        uint32_t FSP : 1;              /*!< [1] Frame Sync Polarity */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t FSE : 1;              /*!< [3] Frame Sync Early */
        uint32_t MF : 1;               /*!< [4] MSB First */
        uint32_t RESERVED1 : 3;        /*!< [7:5]  */
        uint32_t SYWD : 5;             /*!< [12:8] Sync Width */
        uint32_t RESERVED2 : 3;        /*!< [15:13]  */
        uint32_t FRSZ : 5;             /*!< [20:16] Frame Size */
        uint32_t RESERVED3 : 11;       /*!< [31:21]  */
    } B;
} hw_i2s_rcr4_t;

/*!
 * @name Constants and macros for entire I2S_RCR4 register
 */
/*@{*/
#define HW_I2S_RCR4_ADDR(x)      ((uintptr_t)(x) + 0x90U)

#define HW_I2S_RCR4(x)           (*(__IO hw_i2s_rcr4_t *) HW_I2S_RCR4_ADDR(x))
#define HW_I2S_RCR4_RD(x)        (HW_I2S_RCR4(x).U)
#define HW_I2S_RCR4_WR(x, v)     (HW_I2S_RCR4(x).U = (v))
#define HW_I2S_RCR4_SET(x, v)    (HW_I2S_RCR4_WR(x, HW_I2S_RCR4_RD(x) |  (v)))
#define HW_I2S_RCR4_CLR(x, v)    (HW_I2S_RCR4_WR(x, HW_I2S_RCR4_RD(x) & ~(v)))
#define HW_I2S_RCR4_TOG(x, v)    (HW_I2S_RCR4_WR(x, HW_I2S_RCR4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_RCR4 bitfields
 */

/*!
 * @name Register I2S_RCR4, field FSD[0] (RW)
 *
 * Configures the direction of the frame sync.
 *
 * Values:
 * - 0 - Frame Sync is generated externally in Slave mode.
 * - 1 - Frame Sync is generated internally in Master mode.
 */
/*@{*/
#define BP_I2S_RCR4_FSD      (0U)          /*!< Bit position for I2S_RCR4_FSD. */
#define BM_I2S_RCR4_FSD      (0x00000001U) /*!< Bit mask for I2S_RCR4_FSD. */
#define BS_I2S_RCR4_FSD      (1U)          /*!< Bit field size in bits for I2S_RCR4_FSD. */

/*! @brief Read current value of the I2S_RCR4_FSD field. */
#define BR_I2S_RCR4_FSD(x)   (HW_I2S_RCR4(x).B.FSD)

/*! @brief Format value for bitfield I2S_RCR4_FSD. */
#define BF_I2S_RCR4_FSD(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR4_FSD) & BM_I2S_RCR4_FSD)

/*! @brief Set the FSD field to a new value. */
#define BW_I2S_RCR4_FSD(x, v) (HW_I2S_RCR4_WR(x, (HW_I2S_RCR4_RD(x) & ~BM_I2S_RCR4_FSD) | BF_I2S_RCR4_FSD(v)))
/*@}*/

/*!
 * @name Register I2S_RCR4, field FSP[1] (RW)
 *
 * Configures the polarity of the frame sync.
 *
 * Values:
 * - 0 - Frame sync is active high.
 * - 1 - Frame sync is active low.
 */
/*@{*/
#define BP_I2S_RCR4_FSP      (1U)          /*!< Bit position for I2S_RCR4_FSP. */
#define BM_I2S_RCR4_FSP      (0x00000002U) /*!< Bit mask for I2S_RCR4_FSP. */
#define BS_I2S_RCR4_FSP      (1U)          /*!< Bit field size in bits for I2S_RCR4_FSP. */

/*! @brief Read current value of the I2S_RCR4_FSP field. */
#define BR_I2S_RCR4_FSP(x)   (HW_I2S_RCR4(x).B.FSP)

/*! @brief Format value for bitfield I2S_RCR4_FSP. */
#define BF_I2S_RCR4_FSP(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR4_FSP) & BM_I2S_RCR4_FSP)

/*! @brief Set the FSP field to a new value. */
#define BW_I2S_RCR4_FSP(x, v) (HW_I2S_RCR4_WR(x, (HW_I2S_RCR4_RD(x) & ~BM_I2S_RCR4_FSP) | BF_I2S_RCR4_FSP(v)))
/*@}*/

/*!
 * @name Register I2S_RCR4, field FSE[3] (RW)
 *
 * Values:
 * - 0 - Frame sync asserts with the first bit of the frame.
 * - 1 - Frame sync asserts one bit before the first bit of the frame.
 */
/*@{*/
#define BP_I2S_RCR4_FSE      (3U)          /*!< Bit position for I2S_RCR4_FSE. */
#define BM_I2S_RCR4_FSE      (0x00000008U) /*!< Bit mask for I2S_RCR4_FSE. */
#define BS_I2S_RCR4_FSE      (1U)          /*!< Bit field size in bits for I2S_RCR4_FSE. */

/*! @brief Read current value of the I2S_RCR4_FSE field. */
#define BR_I2S_RCR4_FSE(x)   (HW_I2S_RCR4(x).B.FSE)

/*! @brief Format value for bitfield I2S_RCR4_FSE. */
#define BF_I2S_RCR4_FSE(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR4_FSE) & BM_I2S_RCR4_FSE)

/*! @brief Set the FSE field to a new value. */
#define BW_I2S_RCR4_FSE(x, v) (HW_I2S_RCR4_WR(x, (HW_I2S_RCR4_RD(x) & ~BM_I2S_RCR4_FSE) | BF_I2S_RCR4_FSE(v)))
/*@}*/

/*!
 * @name Register I2S_RCR4, field MF[4] (RW)
 *
 * Configures whether the LSB or the MSB is received first.
 *
 * Values:
 * - 0 - LSB is received first.
 * - 1 - MSB is received first.
 */
/*@{*/
#define BP_I2S_RCR4_MF       (4U)          /*!< Bit position for I2S_RCR4_MF. */
#define BM_I2S_RCR4_MF       (0x00000010U) /*!< Bit mask for I2S_RCR4_MF. */
#define BS_I2S_RCR4_MF       (1U)          /*!< Bit field size in bits for I2S_RCR4_MF. */

/*! @brief Read current value of the I2S_RCR4_MF field. */
#define BR_I2S_RCR4_MF(x)    (HW_I2S_RCR4(x).B.MF)

/*! @brief Format value for bitfield I2S_RCR4_MF. */
#define BF_I2S_RCR4_MF(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_RCR4_MF) & BM_I2S_RCR4_MF)

/*! @brief Set the MF field to a new value. */
#define BW_I2S_RCR4_MF(x, v) (HW_I2S_RCR4_WR(x, (HW_I2S_RCR4_RD(x) & ~BM_I2S_RCR4_MF) | BF_I2S_RCR4_MF(v)))
/*@}*/

/*!
 * @name Register I2S_RCR4, field SYWD[12:8] (RW)
 *
 * Configures the length of the frame sync in number of bit clocks. The value
 * written must be one less than the number of bit clocks. For example, write 0 for
 * the frame sync to assert for one bit clock only. The sync width cannot be
 * configured longer than the first word of the frame.
 */
/*@{*/
#define BP_I2S_RCR4_SYWD     (8U)          /*!< Bit position for I2S_RCR4_SYWD. */
#define BM_I2S_RCR4_SYWD     (0x00001F00U) /*!< Bit mask for I2S_RCR4_SYWD. */
#define BS_I2S_RCR4_SYWD     (5U)          /*!< Bit field size in bits for I2S_RCR4_SYWD. */

/*! @brief Read current value of the I2S_RCR4_SYWD field. */
#define BR_I2S_RCR4_SYWD(x)  (HW_I2S_RCR4(x).B.SYWD)

/*! @brief Format value for bitfield I2S_RCR4_SYWD. */
#define BF_I2S_RCR4_SYWD(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCR4_SYWD) & BM_I2S_RCR4_SYWD)

/*! @brief Set the SYWD field to a new value. */
#define BW_I2S_RCR4_SYWD(x, v) (HW_I2S_RCR4_WR(x, (HW_I2S_RCR4_RD(x) & ~BM_I2S_RCR4_SYWD) | BF_I2S_RCR4_SYWD(v)))
/*@}*/

/*!
 * @name Register I2S_RCR4, field FRSZ[20:16] (RW)
 *
 * Configures the number of words in each frame. The value written must be one
 * less than the number of words in the frame. For example, write 0 for one word
 * per frame. The maximum supported frame size is 32 words.
 */
/*@{*/
#define BP_I2S_RCR4_FRSZ     (16U)         /*!< Bit position for I2S_RCR4_FRSZ. */
#define BM_I2S_RCR4_FRSZ     (0x001F0000U) /*!< Bit mask for I2S_RCR4_FRSZ. */
#define BS_I2S_RCR4_FRSZ     (5U)          /*!< Bit field size in bits for I2S_RCR4_FRSZ. */

/*! @brief Read current value of the I2S_RCR4_FRSZ field. */
#define BR_I2S_RCR4_FRSZ(x)  (HW_I2S_RCR4(x).B.FRSZ)

/*! @brief Format value for bitfield I2S_RCR4_FRSZ. */
#define BF_I2S_RCR4_FRSZ(v)  ((uint32_t)((uint32_t)(v) << BP_I2S_RCR4_FRSZ) & BM_I2S_RCR4_FRSZ)

/*! @brief Set the FRSZ field to a new value. */
#define BW_I2S_RCR4_FRSZ(x, v) (HW_I2S_RCR4_WR(x, (HW_I2S_RCR4_RD(x) & ~BM_I2S_RCR4_FRSZ) | BF_I2S_RCR4_FRSZ(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_RCR5 - SAI Receive Configuration 5 Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_RCR5 - SAI Receive Configuration 5 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register must not be altered when RCSR[RE] is set.
 */
typedef union _hw_i2s_rcr5
{
    uint32_t U;
    struct _hw_i2s_rcr5_bitfields
    {
        uint32_t RESERVED0 : 8;        /*!< [7:0]  */
        uint32_t FBT : 5;              /*!< [12:8] First Bit Shifted */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t W0W : 5;              /*!< [20:16] Word 0 Width */
        uint32_t RESERVED2 : 3;        /*!< [23:21]  */
        uint32_t WNW : 5;              /*!< [28:24] Word N Width */
        uint32_t RESERVED3 : 3;        /*!< [31:29]  */
    } B;
} hw_i2s_rcr5_t;

/*!
 * @name Constants and macros for entire I2S_RCR5 register
 */
/*@{*/
#define HW_I2S_RCR5_ADDR(x)      ((uintptr_t)(x) + 0x94U)

#define HW_I2S_RCR5(x)           (*(__IO hw_i2s_rcr5_t *) HW_I2S_RCR5_ADDR(x))
#define HW_I2S_RCR5_RD(x)        (HW_I2S_RCR5(x).U)
#define HW_I2S_RCR5_WR(x, v)     (HW_I2S_RCR5(x).U = (v))
#define HW_I2S_RCR5_SET(x, v)    (HW_I2S_RCR5_WR(x, HW_I2S_RCR5_RD(x) |  (v)))
#define HW_I2S_RCR5_CLR(x, v)    (HW_I2S_RCR5_WR(x, HW_I2S_RCR5_RD(x) & ~(v)))
#define HW_I2S_RCR5_TOG(x, v)    (HW_I2S_RCR5_WR(x, HW_I2S_RCR5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_RCR5 bitfields
 */

/*!
 * @name Register I2S_RCR5, field FBT[12:8] (RW)
 *
 * Configures the bit index for the first bit received for each word in the
 * frame. If configured for MSB First, the index of the next bit received is one less
 * than the current bit received. If configured for LSB First, the index of the
 * next bit received is one more than the current bit received. The value written
 * must be greater than or equal to the word width when configured for MSB
 * First. The value written must be less than or equal to 31-word width when
 * configured for LSB First.
 */
/*@{*/
#define BP_I2S_RCR5_FBT      (8U)          /*!< Bit position for I2S_RCR5_FBT. */
#define BM_I2S_RCR5_FBT      (0x00001F00U) /*!< Bit mask for I2S_RCR5_FBT. */
#define BS_I2S_RCR5_FBT      (5U)          /*!< Bit field size in bits for I2S_RCR5_FBT. */

/*! @brief Read current value of the I2S_RCR5_FBT field. */
#define BR_I2S_RCR5_FBT(x)   (HW_I2S_RCR5(x).B.FBT)

/*! @brief Format value for bitfield I2S_RCR5_FBT. */
#define BF_I2S_RCR5_FBT(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR5_FBT) & BM_I2S_RCR5_FBT)

/*! @brief Set the FBT field to a new value. */
#define BW_I2S_RCR5_FBT(x, v) (HW_I2S_RCR5_WR(x, (HW_I2S_RCR5_RD(x) & ~BM_I2S_RCR5_FBT) | BF_I2S_RCR5_FBT(v)))
/*@}*/

/*!
 * @name Register I2S_RCR5, field W0W[20:16] (RW)
 *
 * Configures the number of bits in the first word in each frame. The value
 * written must be one less than the number of bits in the first word. Word width of
 * less than 8 bits is not supported if there is only one word per frame.
 */
/*@{*/
#define BP_I2S_RCR5_W0W      (16U)         /*!< Bit position for I2S_RCR5_W0W. */
#define BM_I2S_RCR5_W0W      (0x001F0000U) /*!< Bit mask for I2S_RCR5_W0W. */
#define BS_I2S_RCR5_W0W      (5U)          /*!< Bit field size in bits for I2S_RCR5_W0W. */

/*! @brief Read current value of the I2S_RCR5_W0W field. */
#define BR_I2S_RCR5_W0W(x)   (HW_I2S_RCR5(x).B.W0W)

/*! @brief Format value for bitfield I2S_RCR5_W0W. */
#define BF_I2S_RCR5_W0W(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR5_W0W) & BM_I2S_RCR5_W0W)

/*! @brief Set the W0W field to a new value. */
#define BW_I2S_RCR5_W0W(x, v) (HW_I2S_RCR5_WR(x, (HW_I2S_RCR5_RD(x) & ~BM_I2S_RCR5_W0W) | BF_I2S_RCR5_W0W(v)))
/*@}*/

/*!
 * @name Register I2S_RCR5, field WNW[28:24] (RW)
 *
 * Configures the number of bits in each word, for each word except the first in
 * the frame. The value written must be one less than the number of bits per
 * word. Word width of less than 8 bits is not supported.
 */
/*@{*/
#define BP_I2S_RCR5_WNW      (24U)         /*!< Bit position for I2S_RCR5_WNW. */
#define BM_I2S_RCR5_WNW      (0x1F000000U) /*!< Bit mask for I2S_RCR5_WNW. */
#define BS_I2S_RCR5_WNW      (5U)          /*!< Bit field size in bits for I2S_RCR5_WNW. */

/*! @brief Read current value of the I2S_RCR5_WNW field. */
#define BR_I2S_RCR5_WNW(x)   (HW_I2S_RCR5(x).B.WNW)

/*! @brief Format value for bitfield I2S_RCR5_WNW. */
#define BF_I2S_RCR5_WNW(v)   ((uint32_t)((uint32_t)(v) << BP_I2S_RCR5_WNW) & BM_I2S_RCR5_WNW)

/*! @brief Set the WNW field to a new value. */
#define BW_I2S_RCR5_WNW(x, v) (HW_I2S_RCR5_WR(x, (HW_I2S_RCR5_RD(x) & ~BM_I2S_RCR5_WNW) | BF_I2S_RCR5_WNW(v)))
/*@}*/

/*******************************************************************************
 * HW_I2S_RDRn - SAI Receive Data Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_RDRn - SAI Receive Data Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * Reading this register introduces one additional peripheral clock wait state
 * on each read.
 */
typedef union _hw_i2s_rdrn
{
    uint32_t U;
    struct _hw_i2s_rdrn_bitfields
    {
        uint32_t RDR : 32;             /*!< [31:0] Receive Data Register */
    } B;
} hw_i2s_rdrn_t;

/*!
 * @name Constants and macros for entire I2S_RDRn register
 */
/*@{*/
#define HW_I2S_RDRn_COUNT (1U)

#define HW_I2S_RDRn_ADDR(x, n)   ((uintptr_t)(x) + 0xA0U + (0x4U * (n)))

#define HW_I2S_RDRn(x, n)        (*(__I hw_i2s_rdrn_t *) HW_I2S_RDRn_ADDR(x, n))
#define HW_I2S_RDRn_RD(x, n)     (HW_I2S_RDRn(x, n).U)
/*@}*/

/*
 * Constants & macros for individual I2S_RDRn bitfields
 */

/*!
 * @name Register I2S_RDRn, field RDR[31:0] (RO)
 *
 * The corresponding RCR3[RCE] bit must be set before accessing the channel's
 * receive data register. Reads from this register when the receive FIFO is not
 * empty will return the data from the top of the receive FIFO. Reads from this
 * register when the receive FIFO is empty are ignored.
 */
/*@{*/
#define BP_I2S_RDRn_RDR      (0U)          /*!< Bit position for I2S_RDRn_RDR. */
#define BM_I2S_RDRn_RDR      (0xFFFFFFFFU) /*!< Bit mask for I2S_RDRn_RDR. */
#define BS_I2S_RDRn_RDR      (32U)         /*!< Bit field size in bits for I2S_RDRn_RDR. */

/*! @brief Read current value of the I2S_RDRn_RDR field. */
#define BR_I2S_RDRn_RDR(x, n) (HW_I2S_RDRn(x, n).U)
/*@}*/

/*******************************************************************************
 * HW_I2S_RFRn - SAI Receive FIFO Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_RFRn - SAI Receive FIFO Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The MSB of the read and write pointers is used to distinguish between FIFO
 * full and empty conditions. If the read and write pointers are identical, then
 * the FIFO is empty. If the read and write pointers are identical except for the
 * MSB, then the FIFO is full.
 */
typedef union _hw_i2s_rfrn
{
    uint32_t U;
    struct _hw_i2s_rfrn_bitfields
    {
        uint32_t RFP : 6;              /*!< [5:0] Read FIFO Pointer */
        uint32_t RESERVED0 : 10;       /*!< [15:6]  */
        uint32_t WFP : 6;              /*!< [21:16] Write FIFO Pointer */
        uint32_t RESERVED1 : 10;       /*!< [31:22]  */
    } B;
} hw_i2s_rfrn_t;

/*!
 * @name Constants and macros for entire I2S_RFRn register
 */
/*@{*/
#define HW_I2S_RFRn_COUNT (1U)

#define HW_I2S_RFRn_ADDR(x, n)   ((uintptr_t)(x) + 0xC0U + (0x4U * (n)))

#define HW_I2S_RFRn(x, n)        (*(__I hw_i2s_rfrn_t *) HW_I2S_RFRn_ADDR(x, n))
#define HW_I2S_RFRn_RD(x, n)     (HW_I2S_RFRn(x, n).U)
/*@}*/

/*
 * Constants & macros for individual I2S_RFRn bitfields
 */

/*!
 * @name Register I2S_RFRn, field RFP[5:0] (RO)
 *
 * FIFO read pointer for receive data channel.
 */
/*@{*/
#define BP_I2S_RFRn_RFP      (0U)          /*!< Bit position for I2S_RFRn_RFP. */
#define BM_I2S_RFRn_RFP      (0x0000003FU) /*!< Bit mask for I2S_RFRn_RFP. */
#define BS_I2S_RFRn_RFP      (6U)          /*!< Bit field size in bits for I2S_RFRn_RFP. */

/*! @brief Read current value of the I2S_RFRn_RFP field. */
#define BR_I2S_RFRn_RFP(x, n) (HW_I2S_RFRn(x, n).B.RFP)
/*@}*/

/*!
 * @name Register I2S_RFRn, field WFP[21:16] (RO)
 *
 * FIFO write pointer for receive data channel.
 */
/*@{*/
#define BP_I2S_RFRn_WFP      (16U)         /*!< Bit position for I2S_RFRn_WFP. */
#define BM_I2S_RFRn_WFP      (0x003F0000U) /*!< Bit mask for I2S_RFRn_WFP. */
#define BS_I2S_RFRn_WFP      (6U)          /*!< Bit field size in bits for I2S_RFRn_WFP. */

/*! @brief Read current value of the I2S_RFRn_WFP field. */
#define BR_I2S_RFRn_WFP(x, n) (HW_I2S_RFRn(x, n).B.WFP)
/*@}*/

/*******************************************************************************
 * HW_I2S_RMR - SAI Receive Mask Register
 ******************************************************************************/

/*!
 * @brief HW_I2S_RMR - SAI Receive Mask Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is double-buffered and updates: When RCSR[RE] is first set At
 * the end of each frame This allows the masked words in each frame to change from
 * frame to frame.
 */
typedef union _hw_i2s_rmr
{
    uint32_t U;
    struct _hw_i2s_rmr_bitfields
    {
        uint32_t RWM : 32;             /*!< [31:0] Receive Word Mask */
    } B;
} hw_i2s_rmr_t;

/*!
 * @name Constants and macros for entire I2S_RMR register
 */
/*@{*/
#define HW_I2S_RMR_ADDR(x)       ((uintptr_t)(x) + 0xE0U)

#define HW_I2S_RMR(x)            (*(__IO hw_i2s_rmr_t *) HW_I2S_RMR_ADDR(x))
#define HW_I2S_RMR_RD(x)         (HW_I2S_RMR(x).U)
#define HW_I2S_RMR_WR(x, v)      (HW_I2S_RMR(x).U = (v))
#define HW_I2S_RMR_SET(x, v)     (HW_I2S_RMR_WR(x, HW_I2S_RMR_RD(x) |  (v)))
#define HW_I2S_RMR_CLR(x, v)     (HW_I2S_RMR_WR(x, HW_I2S_RMR_RD(x) & ~(v)))
#define HW_I2S_RMR_TOG(x, v)     (HW_I2S_RMR_WR(x, HW_I2S_RMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual I2S_RMR bitfields
 */

/*!
 * @name Register I2S_RMR, field RWM[31:0] (RW)
 *
 * Configures whether the receive word is masked (received data ignored and not
 * written to receive FIFO) for the corresponding word in the frame.
 *
 * Values:
 * - 0 - Word N is enabled.
 * - 1 - Word N is masked.
 */
/*@{*/
#define BP_I2S_RMR_RWM       (0U)          /*!< Bit position for I2S_RMR_RWM. */
#define BM_I2S_RMR_RWM       (0xFFFFFFFFU) /*!< Bit mask for I2S_RMR_RWM. */
#define BS_I2S_RMR_RWM       (32U)         /*!< Bit field size in bits for I2S_RMR_RWM. */

/*! @brief Read current value of the I2S_RMR_RWM field. */
#define BR_I2S_RMR_RWM(x)    (HW_I2S_RMR(x).U)

/*! @brief Format value for bitfield I2S_RMR_RWM. */
#define BF_I2S_RMR_RWM(v)    ((uint32_t)((uint32_t)(v) << BP_I2S_RMR_RWM) & BM_I2S_RMR_RWM)

/*! @brief Set the RWM field to a new value. */
#define BW_I2S_RMR_RWM(x, v) (HW_I2S_RMR_WR(x, v))
/*@}*/

/*******************************************************************************
 * hw_i2s_t - module struct
 ******************************************************************************/
/*!
 * @brief All I2S module registers.
 */
#pragma pack(1)
typedef struct _hw_i2s
{
    __IO hw_i2s_tcsr_t TCSR;               /*!< [0x0] SAI Transmit Control Register */
    __IO hw_i2s_tcr1_t TCR1;               /*!< [0x4] SAI Transmit Configuration 1 Register */
    __IO hw_i2s_tcr2_t TCR2;               /*!< [0x8] SAI Transmit Configuration 2 Register */
    __IO hw_i2s_tcr3_t TCR3;               /*!< [0xC] SAI Transmit Configuration 3 Register */
    __IO hw_i2s_tcr4_t TCR4;               /*!< [0x10] SAI Transmit Configuration 4 Register */
    __IO hw_i2s_tcr5_t TCR5;               /*!< [0x14] SAI Transmit Configuration 5 Register */
    uint8_t _reserved0[8];
    __O hw_i2s_tdrn_t TDRn[1];             /*!< [0x20] SAI Transmit Data Register */
    uint8_t _reserved1[28];
    __I hw_i2s_tfrn_t TFRn[1];             /*!< [0x40] SAI Transmit FIFO Register */
    uint8_t _reserved2[28];
    __IO hw_i2s_tmr_t TMR;                 /*!< [0x60] SAI Transmit Mask Register */
    uint8_t _reserved3[28];
    __IO hw_i2s_rcsr_t RCSR;               /*!< [0x80] SAI Receive Control Register */
    __IO hw_i2s_rcr1_t RCR1;               /*!< [0x84] SAI Receive Configuration 1 Register */
    __IO hw_i2s_rcr2_t RCR2;               /*!< [0x88] SAI Receive Configuration 2 Register */
    __IO hw_i2s_rcr3_t RCR3;               /*!< [0x8C] SAI Receive Configuration 3 Register */
    __IO hw_i2s_rcr4_t RCR4;               /*!< [0x90] SAI Receive Configuration 4 Register */
    __IO hw_i2s_rcr5_t RCR5;               /*!< [0x94] SAI Receive Configuration 5 Register */
    uint8_t _reserved4[8];
    __I hw_i2s_rdrn_t RDRn[1];             /*!< [0xA0] SAI Receive Data Register */
    uint8_t _reserved5[28];
    __I hw_i2s_rfrn_t RFRn[1];             /*!< [0xC0] SAI Receive FIFO Register */
    uint8_t _reserved6[28];
    __IO hw_i2s_rmr_t RMR;                 /*!< [0xE0] SAI Receive Mask Register */
} hw_i2s_t;
#pragma pack()

/*! @brief Macro to access all I2S registers. */
/*! @param x I2S module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_I2S_REGS(I2S1_BASE)</code>. */
#define HW_I2S_REGS(x) (*(hw_i2s_t *)(x))

/*
 * iMX7D IOMUXC
 *
 * IOMUXC
 *
 * Registers defined in this header file:
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08 - SW_MUX_CTL_PAD_GPIO1_IO08 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09 - SW_MUX_CTL_PAD_GPIO1_IO09 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10 - SW_MUX_CTL_PAD_GPIO1_IO10 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11 - SW_MUX_CTL_PAD_GPIO1_IO11 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12 - SW_MUX_CTL_PAD_GPIO1_IO12 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13 - SW_MUX_CTL_PAD_GPIO1_IO13 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14 - SW_MUX_CTL_PAD_GPIO1_IO14 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15 - SW_MUX_CTL_PAD_GPIO1_IO15 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00 - SW_MUX_CTL_PAD_EPDC_DATA00 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01 - SW_MUX_CTL_PAD_EPDC_DATA01 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02 - SW_MUX_CTL_PAD_EPDC_DATA02 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03 - SW_MUX_CTL_PAD_EPDC_DATA03 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04 - SW_MUX_CTL_PAD_EPDC_DATA04 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05 - SW_MUX_CTL_PAD_EPDC_DATA05 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06 - SW_MUX_CTL_PAD_EPDC_DATA06 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07 - SW_MUX_CTL_PAD_EPDC_DATA07 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08 - SW_MUX_CTL_PAD_EPDC_DATA08 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09 - SW_MUX_CTL_PAD_EPDC_DATA09 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10 - SW_MUX_CTL_PAD_EPDC_DATA10 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11 - SW_MUX_CTL_PAD_EPDC_DATA11 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12 - SW_MUX_CTL_PAD_EPDC_DATA12 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13 - SW_MUX_CTL_PAD_EPDC_DATA13 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14 - SW_MUX_CTL_PAD_EPDC_DATA14 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15 - SW_MUX_CTL_PAD_EPDC_DATA15 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK - SW_MUX_CTL_PAD_EPDC_SDCLK SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE - SW_MUX_CTL_PAD_EPDC_SDLE SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE - SW_MUX_CTL_PAD_EPDC_SDOE SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR - SW_MUX_CTL_PAD_EPDC_SDSHR SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0 - SW_MUX_CTL_PAD_EPDC_SDCE0 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1 - SW_MUX_CTL_PAD_EPDC_SDCE1 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2 - SW_MUX_CTL_PAD_EPDC_SDCE2 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3 - SW_MUX_CTL_PAD_EPDC_SDCE3 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK - SW_MUX_CTL_PAD_EPDC_GDCLK SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE - SW_MUX_CTL_PAD_EPDC_GDOE SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL - SW_MUX_CTL_PAD_EPDC_GDRL SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP - SW_MUX_CTL_PAD_EPDC_GDSP SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0 - SW_MUX_CTL_PAD_EPDC_BDR0 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1 - SW_MUX_CTL_PAD_EPDC_BDR1 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM - SW_MUX_CTL_PAD_EPDC_PWR_COM SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT - SW_MUX_CTL_PAD_EPDC_PWR_STAT SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK - SW_MUX_CTL_PAD_LCD_CLK SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE - SW_MUX_CTL_PAD_LCD_ENABLE SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC - SW_MUX_CTL_PAD_LCD_HSYNC SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC - SW_MUX_CTL_PAD_LCD_VSYNC SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET - SW_MUX_CTL_PAD_LCD_RESET SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00 - SW_MUX_CTL_PAD_LCD_DATA00 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01 - SW_MUX_CTL_PAD_LCD_DATA01 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02 - SW_MUX_CTL_PAD_LCD_DATA02 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03 - SW_MUX_CTL_PAD_LCD_DATA03 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04 - SW_MUX_CTL_PAD_LCD_DATA04 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05 - SW_MUX_CTL_PAD_LCD_DATA05 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06 - SW_MUX_CTL_PAD_LCD_DATA06 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07 - SW_MUX_CTL_PAD_LCD_DATA07 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08 - SW_MUX_CTL_PAD_LCD_DATA08 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09 - SW_MUX_CTL_PAD_LCD_DATA09 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10 - SW_MUX_CTL_PAD_LCD_DATA10 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11 - SW_MUX_CTL_PAD_LCD_DATA11 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12 - SW_MUX_CTL_PAD_LCD_DATA12 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13 - SW_MUX_CTL_PAD_LCD_DATA13 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14 - SW_MUX_CTL_PAD_LCD_DATA14 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15 - SW_MUX_CTL_PAD_LCD_DATA15 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16 - SW_MUX_CTL_PAD_LCD_DATA16 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17 - SW_MUX_CTL_PAD_LCD_DATA17 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18 - SW_MUX_CTL_PAD_LCD_DATA18 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19 - SW_MUX_CTL_PAD_LCD_DATA19 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20 - SW_MUX_CTL_PAD_LCD_DATA20 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21 - SW_MUX_CTL_PAD_LCD_DATA21 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22 - SW_MUX_CTL_PAD_LCD_DATA22 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23 - SW_MUX_CTL_PAD_LCD_DATA23 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA - SW_MUX_CTL_PAD_UART1_RX_DATA SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA - SW_MUX_CTL_PAD_UART1_TX_DATA SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA - SW_MUX_CTL_PAD_UART2_RX_DATA SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA - SW_MUX_CTL_PAD_UART2_TX_DATA SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA - SW_MUX_CTL_PAD_UART3_RX_DATA SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA - SW_MUX_CTL_PAD_UART3_TX_DATA SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B - SW_MUX_CTL_PAD_UART3_RTS_B SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B - SW_MUX_CTL_PAD_UART3_CTS_B SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL - SW_MUX_CTL_PAD_I2C1_SCL SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA - SW_MUX_CTL_PAD_I2C1_SDA SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL - SW_MUX_CTL_PAD_I2C2_SCL SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA - SW_MUX_CTL_PAD_I2C2_SDA SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL - SW_MUX_CTL_PAD_I2C3_SCL SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA - SW_MUX_CTL_PAD_I2C3_SDA SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL - SW_MUX_CTL_PAD_I2C4_SCL SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA - SW_MUX_CTL_PAD_I2C4_SDA SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK - SW_MUX_CTL_PAD_ECSPI1_SCLK SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI - SW_MUX_CTL_PAD_ECSPI1_MOSI SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO - SW_MUX_CTL_PAD_ECSPI1_MISO SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0 - SW_MUX_CTL_PAD_ECSPI1_SS0 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK - SW_MUX_CTL_PAD_ECSPI2_SCLK SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI - SW_MUX_CTL_PAD_ECSPI2_MOSI SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO - SW_MUX_CTL_PAD_ECSPI2_MISO SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0 - SW_MUX_CTL_PAD_ECSPI2_SS0 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B - SW_MUX_CTL_PAD_SD1_CD_B SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP - SW_MUX_CTL_PAD_SD1_WP SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B - SW_MUX_CTL_PAD_SD1_RESET_B SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK - SW_MUX_CTL_PAD_SD1_CLK SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD - SW_MUX_CTL_PAD_SD1_CMD SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0 - SW_MUX_CTL_PAD_SD1_DATA0 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1 - SW_MUX_CTL_PAD_SD1_DATA1 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2 - SW_MUX_CTL_PAD_SD1_DATA2 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3 - SW_MUX_CTL_PAD_SD1_DATA3 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B - SW_MUX_CTL_PAD_SD2_CD_B SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP - SW_MUX_CTL_PAD_SD2_WP SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B - SW_MUX_CTL_PAD_SD2_RESET_B SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK - SW_MUX_CTL_PAD_SD2_CLK SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD - SW_MUX_CTL_PAD_SD2_CMD SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0 - SW_MUX_CTL_PAD_SD2_DATA0 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1 - SW_MUX_CTL_PAD_SD2_DATA1 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2 - SW_MUX_CTL_PAD_SD2_DATA2 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3 - SW_MUX_CTL_PAD_SD2_DATA3 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK - SW_MUX_CTL_PAD_SD3_CLK SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD - SW_MUX_CTL_PAD_SD3_CMD SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0 - SW_MUX_CTL_PAD_SD3_DATA0 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1 - SW_MUX_CTL_PAD_SD3_DATA1 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2 - SW_MUX_CTL_PAD_SD3_DATA2 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3 - SW_MUX_CTL_PAD_SD3_DATA3 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4 - SW_MUX_CTL_PAD_SD3_DATA4 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5 - SW_MUX_CTL_PAD_SD3_DATA5 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6 - SW_MUX_CTL_PAD_SD3_DATA6 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7 - SW_MUX_CTL_PAD_SD3_DATA7 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE - SW_MUX_CTL_PAD_SD3_STROBE SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B - SW_MUX_CTL_PAD_SD3_RESET_B SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA - SW_MUX_CTL_PAD_SAI1_RX_DATA SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK - SW_MUX_CTL_PAD_SAI1_TX_BCLK SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC - SW_MUX_CTL_PAD_SAI1_TX_SYNC SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA - SW_MUX_CTL_PAD_SAI1_TX_DATA SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC - SW_MUX_CTL_PAD_SAI1_RX_SYNC SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK - SW_MUX_CTL_PAD_SAI1_RX_BCLK SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK - SW_MUX_CTL_PAD_SAI1_MCLK SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC - SW_MUX_CTL_PAD_SAI2_TX_SYNC SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK - SW_MUX_CTL_PAD_SAI2_TX_BCLK SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA - SW_MUX_CTL_PAD_SAI2_RX_DATA SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA - SW_MUX_CTL_PAD_SAI2_TX_DATA SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0 - SW_MUX_CTL_PAD_ENET1_RGMII_RD0 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1 - SW_MUX_CTL_PAD_ENET1_RGMII_RD1 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2 - SW_MUX_CTL_PAD_ENET1_RGMII_RD2 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3 - SW_MUX_CTL_PAD_ENET1_RGMII_RD3 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL - SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC - SW_MUX_CTL_PAD_ENET1_RGMII_RXC SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0 - SW_MUX_CTL_PAD_ENET1_RGMII_TD0 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1 - SW_MUX_CTL_PAD_ENET1_RGMII_TD1 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2 - SW_MUX_CTL_PAD_ENET1_RGMII_TD2 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3 - SW_MUX_CTL_PAD_ENET1_RGMII_TD3 SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL - SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC - SW_MUX_CTL_PAD_ENET1_RGMII_TXC SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK - SW_MUX_CTL_PAD_ENET1_TX_CLK SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK - SW_MUX_CTL_PAD_ENET1_RX_CLK SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS - SW_MUX_CTL_PAD_ENET1_CRS SW MUX Control Register
 * - HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL - SW_MUX_CTL_PAD_ENET1_COL SW MUX Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08 - SW_PAD_CTL_PAD_GPIO1_IO08 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09 - SW_PAD_CTL_PAD_GPIO1_IO09 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10 - SW_PAD_CTL_PAD_GPIO1_IO10 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11 - SW_PAD_CTL_PAD_GPIO1_IO11 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12 - SW_PAD_CTL_PAD_GPIO1_IO12 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13 - SW_PAD_CTL_PAD_GPIO1_IO13 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14 - SW_PAD_CTL_PAD_GPIO1_IO14 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15 - SW_PAD_CTL_PAD_GPIO1_IO15 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD - SW_PAD_CTL_PAD_JTAG_MOD SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK - SW_PAD_CTL_PAD_JTAG_TCK SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI - SW_PAD_CTL_PAD_JTAG_TDI SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO - SW_PAD_CTL_PAD_JTAG_TDO SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS - SW_PAD_CTL_PAD_JTAG_TMS SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B - SW_PAD_CTL_PAD_JTAG_TRST_B SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00 - SW_PAD_CTL_PAD_EPDC_DATA00 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01 - SW_PAD_CTL_PAD_EPDC_DATA01 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02 - SW_PAD_CTL_PAD_EPDC_DATA02 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03 - SW_PAD_CTL_PAD_EPDC_DATA03 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04 - SW_PAD_CTL_PAD_EPDC_DATA04 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05 - SW_PAD_CTL_PAD_EPDC_DATA05 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06 - SW_PAD_CTL_PAD_EPDC_DATA06 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07 - SW_PAD_CTL_PAD_EPDC_DATA07 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08 - SW_PAD_CTL_PAD_EPDC_DATA08 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09 - SW_PAD_CTL_PAD_EPDC_DATA09 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10 - SW_PAD_CTL_PAD_EPDC_DATA10 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11 - SW_PAD_CTL_PAD_EPDC_DATA11 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12 - SW_PAD_CTL_PAD_EPDC_DATA12 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13 - SW_PAD_CTL_PAD_EPDC_DATA13 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14 - SW_PAD_CTL_PAD_EPDC_DATA14 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15 - SW_PAD_CTL_PAD_EPDC_DATA15 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK - SW_PAD_CTL_PAD_EPDC_SDCLK SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE - SW_PAD_CTL_PAD_EPDC_SDLE SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE - SW_PAD_CTL_PAD_EPDC_SDOE SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR - SW_PAD_CTL_PAD_EPDC_SDSHR SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0 - SW_PAD_CTL_PAD_EPDC_SDCE0 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1 - SW_PAD_CTL_PAD_EPDC_SDCE1 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2 - SW_PAD_CTL_PAD_EPDC_SDCE2 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3 - SW_PAD_CTL_PAD_EPDC_SDCE3 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK - SW_PAD_CTL_PAD_EPDC_GDCLK SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE - SW_PAD_CTL_PAD_EPDC_GDOE SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL - SW_PAD_CTL_PAD_EPDC_GDRL SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP - SW_PAD_CTL_PAD_EPDC_GDSP SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0 - SW_PAD_CTL_PAD_EPDC_BDR0 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1 - SW_PAD_CTL_PAD_EPDC_BDR1 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM - SW_PAD_CTL_PAD_EPDC_PWR_COM SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT - SW_PAD_CTL_PAD_EPDC_PWR_STAT SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK - SW_PAD_CTL_PAD_LCD_CLK SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE - SW_PAD_CTL_PAD_LCD_ENABLE SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC - SW_PAD_CTL_PAD_LCD_HSYNC SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC - SW_PAD_CTL_PAD_LCD_VSYNC SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET - SW_PAD_CTL_PAD_LCD_RESET SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00 - SW_PAD_CTL_PAD_LCD_DATA00 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01 - SW_PAD_CTL_PAD_LCD_DATA01 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02 - SW_PAD_CTL_PAD_LCD_DATA02 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03 - SW_PAD_CTL_PAD_LCD_DATA03 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04 - SW_PAD_CTL_PAD_LCD_DATA04 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05 - SW_PAD_CTL_PAD_LCD_DATA05 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06 - SW_PAD_CTL_PAD_LCD_DATA06 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07 - SW_PAD_CTL_PAD_LCD_DATA07 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08 - SW_PAD_CTL_PAD_LCD_DATA08 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09 - SW_PAD_CTL_PAD_LCD_DATA09 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10 - SW_PAD_CTL_PAD_LCD_DATA10 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11 - SW_PAD_CTL_PAD_LCD_DATA11 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12 - SW_PAD_CTL_PAD_LCD_DATA12 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13 - SW_PAD_CTL_PAD_LCD_DATA13 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14 - SW_PAD_CTL_PAD_LCD_DATA14 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15 - SW_PAD_CTL_PAD_LCD_DATA15 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16 - SW_PAD_CTL_PAD_LCD_DATA16 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17 - SW_PAD_CTL_PAD_LCD_DATA17 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18 - SW_PAD_CTL_PAD_LCD_DATA18 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19 - SW_PAD_CTL_PAD_LCD_DATA19 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20 - SW_PAD_CTL_PAD_LCD_DATA20 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21 - SW_PAD_CTL_PAD_LCD_DATA21 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22 - SW_PAD_CTL_PAD_LCD_DATA22 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23 - SW_PAD_CTL_PAD_LCD_DATA23 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA - SW_PAD_CTL_PAD_UART1_RX_DATA SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA - SW_PAD_CTL_PAD_UART1_TX_DATA SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA - SW_PAD_CTL_PAD_UART2_RX_DATA SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA - SW_PAD_CTL_PAD_UART2_TX_DATA SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA - SW_PAD_CTL_PAD_UART3_RX_DATA SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA - SW_PAD_CTL_PAD_UART3_TX_DATA SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B - SW_PAD_CTL_PAD_UART3_RTS_B SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B - SW_PAD_CTL_PAD_UART3_CTS_B SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL - SW_PAD_CTL_PAD_I2C1_SCL SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA - SW_PAD_CTL_PAD_I2C1_SDA SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL - SW_PAD_CTL_PAD_I2C2_SCL SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA - SW_PAD_CTL_PAD_I2C2_SDA SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL - SW_PAD_CTL_PAD_I2C3_SCL SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA - SW_PAD_CTL_PAD_I2C3_SDA SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL - SW_PAD_CTL_PAD_I2C4_SCL SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA - SW_PAD_CTL_PAD_I2C4_SDA SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK - SW_PAD_CTL_PAD_ECSPI1_SCLK SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI - SW_PAD_CTL_PAD_ECSPI1_MOSI SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO - SW_PAD_CTL_PAD_ECSPI1_MISO SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0 - SW_PAD_CTL_PAD_ECSPI1_SS0 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK - SW_PAD_CTL_PAD_ECSPI2_SCLK SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI - SW_PAD_CTL_PAD_ECSPI2_MOSI SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO - SW_PAD_CTL_PAD_ECSPI2_MISO SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0 - SW_PAD_CTL_PAD_ECSPI2_SS0 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B - SW_PAD_CTL_PAD_SD1_CD_B SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP - SW_PAD_CTL_PAD_SD1_WP SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B - SW_PAD_CTL_PAD_SD1_RESET_B SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK - SW_PAD_CTL_PAD_SD1_CLK SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD - SW_PAD_CTL_PAD_SD1_CMD SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0 - SW_PAD_CTL_PAD_SD1_DATA0 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1 - SW_PAD_CTL_PAD_SD1_DATA1 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2 - SW_PAD_CTL_PAD_SD1_DATA2 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3 - SW_PAD_CTL_PAD_SD1_DATA3 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B - SW_PAD_CTL_PAD_SD2_CD_B SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP - SW_PAD_CTL_PAD_SD2_WP SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B - SW_PAD_CTL_PAD_SD2_RESET_B SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK - SW_PAD_CTL_PAD_SD2_CLK SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD - SW_PAD_CTL_PAD_SD2_CMD SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0 - SW_PAD_CTL_PAD_SD2_DATA0 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1 - SW_PAD_CTL_PAD_SD2_DATA1 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2 - SW_PAD_CTL_PAD_SD2_DATA2 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3 - SW_PAD_CTL_PAD_SD2_DATA3 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK - SW_PAD_CTL_PAD_SD3_CLK SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD - SW_PAD_CTL_PAD_SD3_CMD SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0 - SW_PAD_CTL_PAD_SD3_DATA0 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1 - SW_PAD_CTL_PAD_SD3_DATA1 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2 - SW_PAD_CTL_PAD_SD3_DATA2 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3 - SW_PAD_CTL_PAD_SD3_DATA3 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4 - SW_PAD_CTL_PAD_SD3_DATA4 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5 - SW_PAD_CTL_PAD_SD3_DATA5 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6 - SW_PAD_CTL_PAD_SD3_DATA6 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7 - SW_PAD_CTL_PAD_SD3_DATA7 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE - SW_PAD_CTL_PAD_SD3_STROBE SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B - SW_PAD_CTL_PAD_SD3_RESET_B SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA - SW_PAD_CTL_PAD_SAI1_RX_DATA SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK - SW_PAD_CTL_PAD_SAI1_TX_BCLK SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC - SW_PAD_CTL_PAD_SAI1_TX_SYNC SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA - SW_PAD_CTL_PAD_SAI1_TX_DATA SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC - SW_PAD_CTL_PAD_SAI1_RX_SYNC SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK - SW_PAD_CTL_PAD_SAI1_RX_BCLK SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK - SW_PAD_CTL_PAD_SAI1_MCLK SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC - SW_PAD_CTL_PAD_SAI2_TX_SYNC SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK - SW_PAD_CTL_PAD_SAI2_TX_BCLK SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA - SW_PAD_CTL_PAD_SAI2_RX_DATA SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA - SW_PAD_CTL_PAD_SAI2_TX_DATA SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0 - SW_PAD_CTL_PAD_ENET1_RGMII_RD0 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1 - SW_PAD_CTL_PAD_ENET1_RGMII_RD1 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2 - SW_PAD_CTL_PAD_ENET1_RGMII_RD2 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3 - SW_PAD_CTL_PAD_ENET1_RGMII_RD3 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL - SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC - SW_PAD_CTL_PAD_ENET1_RGMII_RXC SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0 - SW_PAD_CTL_PAD_ENET1_RGMII_TD0 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1 - SW_PAD_CTL_PAD_ENET1_RGMII_TD1 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2 - SW_PAD_CTL_PAD_ENET1_RGMII_TD2 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3 - SW_PAD_CTL_PAD_ENET1_RGMII_TD3 SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL - SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC - SW_PAD_CTL_PAD_ENET1_RGMII_TXC SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK - SW_PAD_CTL_PAD_ENET1_TX_CLK SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK - SW_PAD_CTL_PAD_ENET1_RX_CLK SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS - SW_PAD_CTL_PAD_ENET1_CRS SW PAD Control Register
 * - HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL - SW_PAD_CTL_PAD_ENET1_COL SW PAD Control Register
 * - HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT - FLEXCAN1_RX_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT - FLEXCAN2_RX_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT - CCM_EXT_CLK_1_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT - CCM_EXT_CLK_2_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT - CCM_EXT_CLK_3_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT - CCM_EXT_CLK_4_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT - CCM_PMIC_READY_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_CSI_DATA2_SELECT_INPUT - CSI_DATA2_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_CSI_DATA3_SELECT_INPUT - CSI_DATA3_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_CSI_DATA4_SELECT_INPUT - CSI_DATA4_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_CSI_DATA5_SELECT_INPUT - CSI_DATA5_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_CSI_DATA6_SELECT_INPUT - CSI_DATA6_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_CSI_DATA7_SELECT_INPUT - CSI_DATA7_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_CSI_DATA8_SELECT_INPUT - CSI_DATA8_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_CSI_DATA9_SELECT_INPUT - CSI_DATA9_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_CSI_HSYNC_SELECT_INPUT - CSI_HSYNC_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT - CSI_PIXCLK_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_CSI_VSYNC_SELECT_INPUT - CSI_VSYNC_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT - ECSPI1_SCLK_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT - ECSPI1_MISO_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT - ECSPI1_MOSI_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT - ECSPI1_SS0_B_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT - ECSPI2_SCLK_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT - ECSPI2_MISO_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT - ECSPI2_MOSI_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT - ECSPI2_SS0_B_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT - ECSPI3_SCLK_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT - ECSPI3_MISO_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT - ECSPI3_MOSI_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT - ECSPI3_SS0_B_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT - ECSPI4_SCLK_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT - ECSPI4_MISO_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT - ECSPI4_MOSI_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT - ECSPI4_SS0_B_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT - CCM_ENET1_REF_CLK_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ENET1_MDIO_SELECT_INPUT - ENET1_MDIO_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT - ENET1_RX_CLK_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT - CCM_ENET2_REF_CLK_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ENET2_MDIO_SELECT_INPUT - ENET2_MDIO_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT - ENET2_RX_CLK_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT - EPDC_PWR_IRQ_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT - EPDC_PWR_STAT_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT - FLEXTIMER1_CH0_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT - FLEXTIMER1_CH1_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT - FLEXTIMER1_CH2_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT - FLEXTIMER1_CH3_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT - FLEXTIMER1_CH4_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT - FLEXTIMER1_CH5_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT - FLEXTIMER1_CH6_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT - FLEXTIMER1_CH7_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT - FLEXTIMER1_PHA_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT - FLEXTIMER1_PHB_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT - FLEXTIMER2_CH0_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT - FLEXTIMER2_CH1_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT - FLEXTIMER2_CH2_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT - FLEXTIMER2_CH3_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT - FLEXTIMER2_CH4_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT - FLEXTIMER2_CH5_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT - FLEXTIMER2_CH6_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT - FLEXTIMER2_CH7_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT - FLEXTIMER2_PHA_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT - FLEXTIMER2_PHB_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_I2C1_SCL_SELECT_INPUT - I2C1_SCL_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_I2C1_SDA_SELECT_INPUT - I2C1_SDA_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_I2C2_SCL_SELECT_INPUT - I2C2_SCL_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_I2C2_SDA_SELECT_INPUT - I2C2_SDA_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_I2C3_SCL_SELECT_INPUT - I2C3_SCL_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_I2C3_SDA_SELECT_INPUT - I2C3_SDA_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_I2C4_SCL_SELECT_INPUT - I2C4_SCL_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_I2C4_SDA_SELECT_INPUT - I2C4_SDA_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_KPP_COL0_SELECT_INPUT - KPP_COL0_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_KPP_COL1_SELECT_INPUT - KPP_COL1_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_KPP_COL2_SELECT_INPUT - KPP_COL2_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_KPP_COL3_SELECT_INPUT - KPP_COL3_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_KPP_COL4_SELECT_INPUT - KPP_COL4_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_KPP_COL5_SELECT_INPUT - KPP_COL5_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_KPP_COL6_SELECT_INPUT - KPP_COL6_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_KPP_COL7_SELECT_INPUT - KPP_COL7_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_KPP_ROW0_SELECT_INPUT - KPP_ROW0_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_KPP_ROW1_SELECT_INPUT - KPP_ROW1_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_KPP_ROW2_SELECT_INPUT - KPP_ROW2_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_KPP_ROW3_SELECT_INPUT - KPP_ROW3_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_KPP_ROW4_SELECT_INPUT - KPP_ROW4_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_KPP_ROW5_SELECT_INPUT - KPP_ROW5_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_KPP_ROW6_SELECT_INPUT - KPP_ROW6_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_KPP_ROW7_SELECT_INPUT - KPP_ROW7_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_BUSY_SELECT_INPUT - LCD_BUSY_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA00_SELECT_INPUT - LCD_DATA00_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA01_SELECT_INPUT - LCD_DATA01_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA02_SELECT_INPUT - LCD_DATA02_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA03_SELECT_INPUT - LCD_DATA03_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA04_SELECT_INPUT - LCD_DATA04_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA05_SELECT_INPUT - LCD_DATA05_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA06_SELECT_INPUT - LCD_DATA06_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA07_SELECT_INPUT - LCD_DATA07_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA08_SELECT_INPUT - LCD_DATA08_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA09_SELECT_INPUT - LCD_DATA09_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA10_SELECT_INPUT - LCD_DATA10_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA11_SELECT_INPUT - LCD_DATA11_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA12_SELECT_INPUT - LCD_DATA12_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA13_SELECT_INPUT - LCD_DATA13_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA14_SELECT_INPUT - LCD_DATA14_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA15_SELECT_INPUT - LCD_DATA15_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA16_SELECT_INPUT - LCD_DATA16_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA17_SELECT_INPUT - LCD_DATA17_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA18_SELECT_INPUT - LCD_DATA18_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA19_SELECT_INPUT - LCD_DATA19_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA20_SELECT_INPUT - LCD_DATA20_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA21_SELECT_INPUT - LCD_DATA21_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA22_SELECT_INPUT - LCD_DATA22_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_DATA23_SELECT_INPUT - LCD_DATA23_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_LCD_VSYNC_SELECT_INPUT - LCD_VSYNC_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT - SAI1_RX_BCLK_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT - SAI1_RX_DATA_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT - SAI1_RX_SYNC_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT - SAI1_TX_BCLK_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT - SAI1_TX_SYNC_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT - SAI2_RX_BCLK_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT - SAI2_RX_DATA_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT - SAI2_RX_SYNC_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT - SAI2_TX_BCLK_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT - SAI2_TX_SYNC_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT - SAI3_RX_BCLK_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT - SAI3_RX_DATA_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT - SAI3_RX_SYNC_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT - SAI3_TX_BCLK_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT - SAI3_TX_SYNC_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT - SDMA_EVENTS0_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT - SDMA_EVENTS1_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT - SIM1_PORT1_PD_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT - SIM1_PORT1_TRXD_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT - SIM2_PORT1_PD_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT - SIM2_PORT1_TRXD_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_UART1_RTS_B_SELECT_INPUT - UART1_RTS_B_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT - UART1_RX_DATA_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_UART2_RTS_B_SELECT_INPUT - UART2_RTS_B_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT - UART2_RX_DATA_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_UART3_RTS_B_SELECT_INPUT - UART3_RTS_B_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT - UART3_RX_DATA_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_UART4_RTS_B_SELECT_INPUT - UART4_RTS_B_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT - UART4_RX_DATA_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_UART5_RTS_B_SELECT_INPUT - UART5_RTS_B_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT - UART5_RX_DATA_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_UART6_RTS_B_SELECT_INPUT - UART6_RTS_B_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT - UART6_RX_DATA_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_UART7_RTS_B_SELECT_INPUT - UART7_RTS_B_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT - UART7_RX_DATA_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT - USB_OTG2_OC_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT - USB_OTG1_OC_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT - USB_OTG2_ID_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT - USB_OTG1_ID_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SD3_CD_B_SELECT_INPUT - SD3_CD_B_SELECT_INPUT DAISY Register
 * - HW_IOMUXC_SD3_WP_SELECT_INPUT - SD3_WP_SELECT_INPUT DAISY Register
 *
 * - hw_iomuxc_t - Struct containing all module registers.
 */

#define HW_IOMUXC_INSTANCE_COUNT (1U) /*!< Number of instances of the IOMUXC module. */
#define HW_IOMUXC (0U) /*!< Instance number for IOMUXC. */
#define IOMUXC_BASE           (0x30330000U) /*!< Base address for IOMUXC. */
/*! Array initializer of IOMUXC base addresses. */
#define IOMUXC_BASE_ADDRS     { IOMUXC_BASE }

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08 - SW_MUX_CTL_PAD_GPIO1_IO08 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08 - SW_MUX_CTL_PAD_GPIO1_IO08 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io08
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io08_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io08_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io08_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: GPIO1_IO08.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: IO8 of instance: GPIO1
 * - 001 - Select mux mode: ALT1 mux port: VSELECT of instance: SD1
 * - 010 - Select mux mode: ALT2 mux port: WDOG_B of instance: WDOG1
 * - 011 - Select mux mode: ALT3 mux port: RX_DATA of instance: UART3
 * - 100 - Select mux mode: ALT4 mux port: SCL of instance: I2C3
 * - 110 - Select mux mode: ALT6 mux port: COL5 of instance: KPP
 * - 111 - Select mux mode: ALT7 mux port: OUT of instance: PWM1
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE_ALT0_GPIO1_IO8 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE: Select mux mode: ALT0 mux port: IO8 of instance: GPIO1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE_ALT1_SD1_VSELECT (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE: Select mux mode: ALT1 mux port: VSELECT of instance: SD1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE_ALT2_WDOG1_WDOG_B (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE: Select mux mode: ALT2 mux port: WDOG_B of instance: WDOG1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE_ALT3_UART3_RX_DATA (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE: Select mux mode: ALT3 mux port: RX_DATA of instance: UART3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE_ALT4_I2C3_SCL (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE: Select mux mode: ALT4 mux port: SCL of instance: I2C3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE_ALT6_KPP_COL5 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE: Select mux mode: ALT6 mux port: COL5 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE_ALT7_PWM1_OUT (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE: Select mux mode: ALT7 mux port: OUT of instance: PWM1 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO08
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION: Force input path of pad GPIO1_IO08 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO08_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09 - SW_MUX_CTL_PAD_GPIO1_IO09 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09 - SW_MUX_CTL_PAD_GPIO1_IO09 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io09
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io09_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io09_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_ADDR(x) ((uintptr_t)(x) + 0x18U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io09_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: GPIO1_IO09.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: IO9 of instance: GPIO1
 * - 001 - Select mux mode: ALT1 mux port: LCTL of instance: SD1
 * - 010 - Select mux mode: ALT2 mux port: ENET_PHY_REF_CLK of instance: CCM
 * - 011 - Select mux mode: ALT3 mux port: TX_DATA of instance: UART3
 * - 100 - Select mux mode: ALT4 mux port: SDA of instance: I2C3
 * - 101 - Select mux mode: ALT5 mux port: CCM_PMIC_READY of instance: CCM
 * - 110 - Select mux mode: ALT6 mux port: ROW5 of instance: KPP
 * - 111 - Select mux mode: ALT7 mux port: OUT of instance: PWM2
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE_ALT0_GPIO1_IO9 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE: Select mux mode: ALT0 mux port: IO9 of instance: GPIO1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE_ALT1_SD1_LCTL (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE: Select mux mode: ALT1 mux port: LCTL of instance: SD1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE_ALT2_CCM_ENET_PHY_REF_CLK (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE: Select mux mode: ALT2 mux port: ENET_PHY_REF_CLK of instance: CCM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE_ALT3_UART3_TX_DATA (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE: Select mux mode: ALT3 mux port: TX_DATA of instance: UART3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE_ALT4_I2C3_SDA (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE: Select mux mode: ALT4 mux port: SDA of instance: I2C3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE_ALT5_CCM_PMIC_READY (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE: Select mux mode: ALT5 mux port: CCM_PMIC_READY of instance: CCM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE_ALT6_KPP_ROW5 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE: Select mux mode: ALT6 mux port: ROW5 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE_ALT7_PWM2_OUT (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE: Select mux mode: ALT7 mux port: OUT of instance: PWM2 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO09
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION: Force input path of pad GPIO1_IO09 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO09_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10 - SW_MUX_CTL_PAD_GPIO1_IO10 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10 - SW_MUX_CTL_PAD_GPIO1_IO10 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io10
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io10_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io10_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io10_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: GPIO1_IO10.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: IO10 of instance: GPIO1
 * - 001 - Select mux mode: ALT1 mux port: LCTL of instance: SD2
 * - 010 - Select mux mode: ALT2 mux port: MDIO of instance: ENET1
 * - 011 - Select mux mode: ALT3 mux port: RTS_B of instance: UART3
 * - 100 - Select mux mode: ALT4 mux port: SCL of instance: I2C4
 * - 101 - Select mux mode: ALT5 mux port: PHA of instance: FLEXTIMER1
 * - 110 - Select mux mode: ALT6 mux port: COL6 of instance: KPP
 * - 111 - Select mux mode: ALT7 mux port: OUT of instance: PWM3
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE_ALT0_GPIO1_IO10 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE: Select mux mode: ALT0 mux port: IO10 of instance: GPIO1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE_ALT1_SD2_LCTL (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE: Select mux mode: ALT1 mux port: LCTL of instance: SD2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE_ALT2_ENET1_MDIO (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE: Select mux mode: ALT2 mux port: MDIO of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE_ALT3_UART3_RTS_B (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE: Select mux mode: ALT3 mux port: RTS_B of instance: UART3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE_ALT4_I2C4_SCL (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE: Select mux mode: ALT4 mux port: SCL of instance: I2C4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE_ALT5_FLEXTIMER1_PHA (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE: Select mux mode: ALT5 mux port: PHA of instance: FLEXTIMER1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE_ALT6_KPP_COL6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE: Select mux mode: ALT6 mux port: COL6 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE_ALT7_PWM3_OUT (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE: Select mux mode: ALT7 mux port: OUT of instance: PWM3 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO10
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION: Force input path of pad GPIO1_IO10 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO10_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11 - SW_MUX_CTL_PAD_GPIO1_IO11 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11 - SW_MUX_CTL_PAD_GPIO1_IO11 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io11
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io11_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io11_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io11_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: GPIO1_IO11.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: IO11 of instance: GPIO1
 * - 001 - Select mux mode: ALT1 mux port: LCTL of instance: SD3
 * - 010 - Select mux mode: ALT2 mux port: MDC of instance: ENET1
 * - 011 - Select mux mode: ALT3 mux port: CTS_B of instance: UART3
 * - 100 - Select mux mode: ALT4 mux port: SDA of instance: I2C4
 * - 101 - Select mux mode: ALT5 mux port: PHB of instance: FLEXTIMER1
 * - 110 - Select mux mode: ALT6 mux port: ROW6 of instance: KPP
 * - 111 - Select mux mode: ALT7 mux port: OUT of instance: PWM4
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE_ALT0_GPIO1_IO11 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE: Select mux mode: ALT0 mux port: IO11 of instance: GPIO1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE_ALT1_SD3_LCTL (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE: Select mux mode: ALT1 mux port: LCTL of instance: SD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE_ALT2_ENET1_MDC (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE: Select mux mode: ALT2 mux port: MDC of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE_ALT3_UART3_CTS_B (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE: Select mux mode: ALT3 mux port: CTS_B of instance: UART3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE_ALT4_I2C4_SDA (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE: Select mux mode: ALT4 mux port: SDA of instance: I2C4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE_ALT5_FLEXTIMER1_PHB (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE: Select mux mode: ALT5 mux port: PHB of instance: FLEXTIMER1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE_ALT6_KPP_ROW6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE: Select mux mode: ALT6 mux port: ROW6 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE_ALT7_PWM4_OUT (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE: Select mux mode: ALT7 mux port: OUT of instance: PWM4 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO11
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION: Force input path of pad GPIO1_IO11 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO11_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12 - SW_MUX_CTL_PAD_GPIO1_IO12 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12 - SW_MUX_CTL_PAD_GPIO1_IO12 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io12
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io12_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io12_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io12_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: GPIO1_IO12.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: IO12 of instance: GPIO1
 * - 001 - Select mux mode: ALT1 mux port: VSELECT of instance: SD2
 * - 010 - Select mux mode: ALT2 mux port: ENET1_REF_CLK of instance: ENET1
 * - 011 - Select mux mode: ALT3 mux port: RX of instance: FLEXCAN1
 * - 100 - Select mux mode: ALT4 mux port: NMI of instance: CM4
 * - 101 - Select mux mode: ALT5 mux port: EXT_CLK1 of instance: CCM
 * - 110 - Select mux mode: ALT6 mux port: VIO_5 of instance: SNVS
 * - 111 - Select mux mode: ALT7 mux port: OTG1_ID of instance: USB
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE_ALT0_GPIO1_IO12 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE: Select mux mode: ALT0 mux port: IO12 of instance: GPIO1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE_ALT1_SD2_VSELECT (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE: Select mux mode: ALT1 mux port: VSELECT of instance: SD2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE_ALT2_CCM_ENET1_REF_CLK (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE: Select mux mode: ALT2 mux port: ENET1_REF_CLK of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE_ALT3_FLEXCAN1_RX (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE: Select mux mode: ALT3 mux port: RX of instance: FLEXCAN1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE_ALT4_CM4_NMI (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE: Select mux mode: ALT4 mux port: NMI of instance: CM4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE_ALT5_CCM_EXT_CLK1 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE: Select mux mode: ALT5 mux port: EXT_CLK1 of instance: CCM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE_ALT6_SNVS_VIO_5 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE: Select mux mode: ALT6 mux port: VIO_5 of instance: SNVS */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE_ALT7_USB_OTG1_ID (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE: Select mux mode: ALT7 mux port: OTG1_ID of instance: USB */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO12
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION: Force input path of pad GPIO1_IO12 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO12_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13 - SW_MUX_CTL_PAD_GPIO1_IO13 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13 - SW_MUX_CTL_PAD_GPIO1_IO13 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io13
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io13_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io13_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io13_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: GPIO1_IO13.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: IO13 of instance: GPIO1
 * - 001 - Select mux mode: ALT1 mux port: VSELECT of instance: SD3
 * - 010 - Select mux mode: ALT2 mux port: ENET2_REF_CLK of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: TX of instance: FLEXCAN1
 * - 100 - Select mux mode: ALT4 mux port: CCM_PMIC_READY of instance: CCM
 * - 101 - Select mux mode: ALT5 mux port: EXT_CLK2 of instance: CCM
 * - 110 - Select mux mode: ALT6 mux port: VIO_5_CTL of instance: SNVS
 * - 111 - Select mux mode: ALT7 mux port: OTG2_ID of instance: USB
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE_ALT0_GPIO1_IO13 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE: Select mux mode: ALT0 mux port: IO13 of instance: GPIO1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE_ALT1_SD3_VSELECT (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE: Select mux mode: ALT1 mux port: VSELECT of instance: SD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE_ALT2_CCM_ENET2_REF_CLK (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE: Select mux mode: ALT2 mux port: ENET2_REF_CLK of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE_ALT3_FLEXCAN1_TX (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE: Select mux mode: ALT3 mux port: TX of instance: FLEXCAN1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE_ALT4_CCM_PMIC_READY (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE: Select mux mode: ALT4 mux port: CCM_PMIC_READY of instance: CCM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE_ALT5_CCM_EXT_CLK2 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE: Select mux mode: ALT5 mux port: EXT_CLK2 of instance: CCM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE_ALT6_SNVS_VIO_5_CTL (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE: Select mux mode: ALT6 mux port: VIO_5_CTL of instance: SNVS */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE_ALT7_USB_OTG2_ID (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE: Select mux mode: ALT7 mux port: OTG2_ID of instance: USB */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO13
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION: Force input path of pad GPIO1_IO13 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO13_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14 - SW_MUX_CTL_PAD_GPIO1_IO14 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14 - SW_MUX_CTL_PAD_GPIO1_IO14 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io14
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io14_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io14_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_ADDR(x) ((uintptr_t)(x) + 0x2CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io14_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: GPIO1_IO14.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: IO14 of instance: GPIO1
 * - 001 - Select mux mode: ALT1 mux port: CD_B of instance: SD3
 * - 010 - Select mux mode: ALT2 mux port: MDIO of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: RX of instance: FLEXCAN2
 * - 100 - Select mux mode: ALT4 mux port: WDOG_B of instance: WDOG3
 * - 101 - Select mux mode: ALT5 mux port: EXT_CLK3 of instance: CCM
 * - 110 - Select mux mode: ALT6 mux port: EXT_EVENT0 of instance: SDMA
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE_ALT0_GPIO1_IO14 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE: Select mux mode: ALT0 mux port: IO14 of instance: GPIO1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE_ALT1_SD3_CD_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE: Select mux mode: ALT1 mux port: CD_B of instance: SD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE_ALT2_ENET2_MDIO (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE: Select mux mode: ALT2 mux port: MDIO of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE_ALT3_FLEXCAN2_RX (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE: Select mux mode: ALT3 mux port: RX of instance: FLEXCAN2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE_ALT4_WDOG3_WDOG_B (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE: Select mux mode: ALT4 mux port: WDOG_B of instance: WDOG3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE_ALT5_CCM_EXT_CLK3 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE: Select mux mode: ALT5 mux port: EXT_CLK3 of instance: CCM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE_ALT6_SDMA_EXT_EVENT0 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE: Select mux mode: ALT6 mux port: EXT_EVENT0 of instance: SDMA */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO14
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SION: Force input path of pad GPIO1_IO14 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO14_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15 - SW_MUX_CTL_PAD_GPIO1_IO15 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15 - SW_MUX_CTL_PAD_GPIO1_IO15 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_gpio1_io15
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_gpio1_io15_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_gpio1_io15_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io15_t *) HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: GPIO1_IO15.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: IO15 of instance: GPIO1
 * - 001 - Select mux mode: ALT1 mux port: WP of instance: SD3
 * - 010 - Select mux mode: ALT2 mux port: MDC of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: TX of instance: FLEXCAN2
 * - 100 - Select mux mode: ALT4 mux port: WDOG_B of instance: WDOG4
 * - 101 - Select mux mode: ALT5 mux port: EXT_CLK4 of instance: CCM
 * - 110 - Select mux mode: ALT6 mux port: EXT_EVENT1 of instance: SDMA
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE_ALT0_GPIO1_IO15 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE: Select mux mode: ALT0 mux port: IO15 of instance: GPIO1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE_ALT1_SD3_WP (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE: Select mux mode: ALT1 mux port: WP of instance: SD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE_ALT2_ENET2_MDC (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE: Select mux mode: ALT2 mux port: MDC of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE_ALT3_FLEXCAN2_TX (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE: Select mux mode: ALT3 mux port: TX of instance: FLEXCAN2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE_ALT4_WDOG4_WDOG_B (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE: Select mux mode: ALT4 mux port: WDOG_B of instance: WDOG4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE_ALT5_CCM_EXT_CLK4 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE: Select mux mode: ALT5 mux port: EXT_CLK4 of instance: CCM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE_ALT6_SDMA_EXT_EVENT1 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE: Select mux mode: ALT6 mux port: EXT_EVENT1 of instance: SDMA */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO15
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SION: Force input path of pad GPIO1_IO15 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_GPIO1_IO15_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00 - SW_MUX_CTL_PAD_EPDC_DATA00 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00 - SW_MUX_CTL_PAD_EPDC_DATA00 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_data00
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_data00_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_data00_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_data00_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: EPDC_DATA00.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA0 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT2_TRXD of instance: SIM1
 * - 010 - Select mux mode: ALT2 mux port: A_DATA0 of instance: QSPI
 * - 011 - Select mux mode: ALT3 mux port: ROW3 of instance: KPP
 * - 100 - Select mux mode: ALT4 mux port: AD0 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO0 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA0 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: CLK of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE_ALT0_EPDC_DATA0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE: Select mux mode: ALT0 mux port: DATA0 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE_ALT1_SIM1_PORT2_TRXD (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE: Select mux mode: ALT1 mux port: PORT2_TRXD of instance: SIM1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE_ALT2_QSPI_A_DATA0 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE: Select mux mode: ALT2 mux port: A_DATA0 of instance: QSPI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE_ALT3_KPP_ROW3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE: Select mux mode: ALT3 mux port: ROW3 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE_ALT4_EIM_AD0 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE: Select mux mode: ALT4 mux port: AD0 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE_ALT5_GPIO2_IO0 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE: Select mux mode: ALT5 mux port: IO0 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE_ALT6_LCD_DATA0 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE: Select mux mode: ALT6 mux port: DATA0 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE_ALT7_LCD_CLK (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE: Select mux mode: ALT7 mux port: CLK of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_DATA00
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SION: Force input path of pad EPDC_DATA00 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA00_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01 - SW_MUX_CTL_PAD_EPDC_DATA01 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01 - SW_MUX_CTL_PAD_EPDC_DATA01 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_data01
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_data01_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_data01_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_ADDR(x) ((uintptr_t)(x) + 0x38U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_data01_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: EPDC_DATA01.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA1 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT2_CLK of instance: SIM1
 * - 010 - Select mux mode: ALT2 mux port: A_DATA1 of instance: QSPI
 * - 011 - Select mux mode: ALT3 mux port: COL3 of instance: KPP
 * - 100 - Select mux mode: ALT4 mux port: AD1 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO1 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA1 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: ENABLE of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE_ALT0_EPDC_DATA1 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE: Select mux mode: ALT0 mux port: DATA1 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE_ALT1_SIM1_PORT2_CLK (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE: Select mux mode: ALT1 mux port: PORT2_CLK of instance: SIM1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE_ALT2_QSPI_A_DATA1 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE: Select mux mode: ALT2 mux port: A_DATA1 of instance: QSPI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE_ALT3_KPP_COL3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE: Select mux mode: ALT3 mux port: COL3 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE_ALT4_EIM_AD1 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE: Select mux mode: ALT4 mux port: AD1 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE_ALT5_GPIO2_IO1 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE: Select mux mode: ALT5 mux port: IO1 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE_ALT6_LCD_DATA1 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE: Select mux mode: ALT6 mux port: DATA1 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE_ALT7_LCD_ENABLE (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE: Select mux mode: ALT7 mux port: ENABLE of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_DATA01
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SION: Force input path of pad EPDC_DATA01 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA01_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02 - SW_MUX_CTL_PAD_EPDC_DATA02 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02 - SW_MUX_CTL_PAD_EPDC_DATA02 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_data02
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_data02_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_data02_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_ADDR(x) ((uintptr_t)(x) + 0x3CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_data02_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: EPDC_DATA02.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA2 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT2_RST_B of instance: SIM1
 * - 010 - Select mux mode: ALT2 mux port: A_DATA2 of instance: QSPI
 * - 011 - Select mux mode: ALT3 mux port: ROW2 of instance: KPP
 * - 100 - Select mux mode: ALT4 mux port: AD2 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO2 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA2 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: VSYNC of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE_ALT0_EPDC_DATA2 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE: Select mux mode: ALT0 mux port: DATA2 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE_ALT1_SIM1_PORT2_RST_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE: Select mux mode: ALT1 mux port: PORT2_RST_B of instance: SIM1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE_ALT2_QSPI_A_DATA2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE: Select mux mode: ALT2 mux port: A_DATA2 of instance: QSPI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE_ALT3_KPP_ROW2 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE: Select mux mode: ALT3 mux port: ROW2 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE_ALT4_EIM_AD2 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE: Select mux mode: ALT4 mux port: AD2 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE_ALT5_GPIO2_IO2 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE: Select mux mode: ALT5 mux port: IO2 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE_ALT6_LCD_DATA2 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE: Select mux mode: ALT6 mux port: DATA2 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE_ALT7_LCD_VSYNC (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE: Select mux mode: ALT7 mux port: VSYNC of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_DATA02
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SION: Force input path of pad EPDC_DATA02 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA02_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03 - SW_MUX_CTL_PAD_EPDC_DATA03 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03 - SW_MUX_CTL_PAD_EPDC_DATA03 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_data03
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_data03_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_data03_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_data03_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: EPDC_DATA03.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA3 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT2_SVEN of instance: SIM1
 * - 010 - Select mux mode: ALT2 mux port: A_DATA3 of instance: QSPI
 * - 011 - Select mux mode: ALT3 mux port: COL2 of instance: KPP
 * - 100 - Select mux mode: ALT4 mux port: AD3 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO3 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA3 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: HSYNC of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE_ALT0_EPDC_DATA3 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE: Select mux mode: ALT0 mux port: DATA3 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE_ALT1_SIM1_PORT2_SVEN (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE: Select mux mode: ALT1 mux port: PORT2_SVEN of instance: SIM1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE_ALT2_QSPI_A_DATA3 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE: Select mux mode: ALT2 mux port: A_DATA3 of instance: QSPI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE_ALT3_KPP_COL2 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE: Select mux mode: ALT3 mux port: COL2 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE_ALT4_EIM_AD3 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE: Select mux mode: ALT4 mux port: AD3 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE_ALT5_GPIO2_IO3 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE: Select mux mode: ALT5 mux port: IO3 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE_ALT6_LCD_DATA3 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE: Select mux mode: ALT6 mux port: DATA3 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE_ALT7_LCD_HSYNC (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE: Select mux mode: ALT7 mux port: HSYNC of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_DATA03
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SION: Force input path of pad EPDC_DATA03 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA03_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04 - SW_MUX_CTL_PAD_EPDC_DATA04 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04 - SW_MUX_CTL_PAD_EPDC_DATA04 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_data04
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_data04_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_data04_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_ADDR(x) ((uintptr_t)(x) + 0x44U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_data04_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: EPDC_DATA04.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA4 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT2_PD of instance: SIM1
 * - 010 - Select mux mode: ALT2 mux port: A_DQS of instance: QSPI
 * - 011 - Select mux mode: ALT3 mux port: ROW1 of instance: KPP
 * - 100 - Select mux mode: ALT4 mux port: AD4 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO4 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA4 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: FAIL of instance: JTAG
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE_ALT0_EPDC_DATA4 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE: Select mux mode: ALT0 mux port: DATA4 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE_ALT1_SIM1_PORT2_PD (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE: Select mux mode: ALT1 mux port: PORT2_PD of instance: SIM1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE_ALT2_QSPI_A_DQS (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE: Select mux mode: ALT2 mux port: A_DQS of instance: QSPI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE_ALT3_KPP_ROW1 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE: Select mux mode: ALT3 mux port: ROW1 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE_ALT4_EIM_AD4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE: Select mux mode: ALT4 mux port: AD4 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE_ALT5_GPIO2_IO4 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE: Select mux mode: ALT5 mux port: IO4 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE_ALT6_LCD_DATA4 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE: Select mux mode: ALT6 mux port: DATA4 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE_ALT7_JTAG_FAIL (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE: Select mux mode: ALT7 mux port: FAIL of instance: JTAG */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_DATA04
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SION: Force input path of pad EPDC_DATA04 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA04_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05 - SW_MUX_CTL_PAD_EPDC_DATA05 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05 - SW_MUX_CTL_PAD_EPDC_DATA05 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_data05
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_data05_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_data05_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_ADDR(x) ((uintptr_t)(x) + 0x48U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_data05_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: EPDC_DATA05.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA5 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT2_TRXD of instance: SIM2
 * - 010 - Select mux mode: ALT2 mux port: A_SCLK of instance: QSPI
 * - 011 - Select mux mode: ALT3 mux port: COL1 of instance: KPP
 * - 100 - Select mux mode: ALT4 mux port: AD5 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO5 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA5 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: ACTIVE of instance: JTAG
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE_ALT0_EPDC_DATA5 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE: Select mux mode: ALT0 mux port: DATA5 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE_ALT1_SIM2_PORT2_TRXD (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE: Select mux mode: ALT1 mux port: PORT2_TRXD of instance: SIM2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE_ALT2_QSPI_A_SCLK (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE: Select mux mode: ALT2 mux port: A_SCLK of instance: QSPI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE_ALT3_KPP_COL1 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE: Select mux mode: ALT3 mux port: COL1 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE_ALT4_EIM_AD5 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE: Select mux mode: ALT4 mux port: AD5 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE_ALT5_GPIO2_IO5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE: Select mux mode: ALT5 mux port: IO5 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE_ALT6_LCD_DATA5 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE: Select mux mode: ALT6 mux port: DATA5 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE_ALT7_JTAG_ACTIVE (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE: Select mux mode: ALT7 mux port: ACTIVE of instance: JTAG */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_DATA05
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SION: Force input path of pad EPDC_DATA05 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA05_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06 - SW_MUX_CTL_PAD_EPDC_DATA06 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06 - SW_MUX_CTL_PAD_EPDC_DATA06 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_data06
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_data06_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_data06_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_ADDR(x) ((uintptr_t)(x) + 0x4CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_data06_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: EPDC_DATA06.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA6 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT2_CLK of instance: SIM2
 * - 010 - Select mux mode: ALT2 mux port: A_SS0_B of instance: QSPI
 * - 011 - Select mux mode: ALT3 mux port: ROW0 of instance: KPP
 * - 100 - Select mux mode: ALT4 mux port: AD6 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO6 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA6 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DE_B of instance: JTAG
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE_ALT0_EPDC_DATA6 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE: Select mux mode: ALT0 mux port: DATA6 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE_ALT1_SIM2_PORT2_CLK (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE: Select mux mode: ALT1 mux port: PORT2_CLK of instance: SIM2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE_ALT2_QSPI_A_SS0_B (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE: Select mux mode: ALT2 mux port: A_SS0_B of instance: QSPI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE_ALT3_KPP_ROW0 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE: Select mux mode: ALT3 mux port: ROW0 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE_ALT4_EIM_AD6 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE: Select mux mode: ALT4 mux port: AD6 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE_ALT5_GPIO2_IO6 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE: Select mux mode: ALT5 mux port: IO6 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE_ALT6_LCD_DATA6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE: Select mux mode: ALT6 mux port: DATA6 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE_ALT7_JTAG_DE_B (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE: Select mux mode: ALT7 mux port: DE_B of instance: JTAG */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_DATA06
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SION: Force input path of pad EPDC_DATA06 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA06_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07 - SW_MUX_CTL_PAD_EPDC_DATA07 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07 - SW_MUX_CTL_PAD_EPDC_DATA07 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_data07
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_data07_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_data07_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_data07_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: EPDC_DATA07.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA7 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT2_RST_B of instance: SIM2
 * - 010 - Select mux mode: ALT2 mux port: A_SS1_B of instance: QSPI
 * - 011 - Select mux mode: ALT3 mux port: COL0 of instance: KPP
 * - 100 - Select mux mode: ALT4 mux port: AD7 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO7 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA7 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DONE of instance: JTAG
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE_ALT0_EPDC_DATA7 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE: Select mux mode: ALT0 mux port: DATA7 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE_ALT1_SIM2_PORT2_RST_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE: Select mux mode: ALT1 mux port: PORT2_RST_B of instance: SIM2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE_ALT2_QSPI_A_SS1_B (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE: Select mux mode: ALT2 mux port: A_SS1_B of instance: QSPI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE_ALT3_KPP_COL0 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE: Select mux mode: ALT3 mux port: COL0 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE_ALT4_EIM_AD7 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE: Select mux mode: ALT4 mux port: AD7 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE_ALT5_GPIO2_IO7 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE: Select mux mode: ALT5 mux port: IO7 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE_ALT6_LCD_DATA7 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE: Select mux mode: ALT6 mux port: DATA7 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE_ALT7_JTAG_DONE (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE: Select mux mode: ALT7 mux port: DONE of instance: JTAG */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_DATA07
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SION: Force input path of pad EPDC_DATA07 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA07_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08 - SW_MUX_CTL_PAD_EPDC_DATA08 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08 - SW_MUX_CTL_PAD_EPDC_DATA08 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_data08
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_data08_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_data08_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_ADDR(x) ((uintptr_t)(x) + 0x54U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_data08_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: EPDC_DATA08.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA8 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT1_TRXD of instance: SIM1
 * - 010 - Select mux mode: ALT2 mux port: B_DATA0 of instance: QSPI
 * - 011 - Select mux mode: ALT3 mux port: RX_DATA of instance: UART6
 * - 100 - Select mux mode: ALT4 mux port: OE of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO8 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA8 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: BUSY of instance: LCD
 * - 1000 - Select mux mode: ALT8 mux port: SDCLK of instance: EPDC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE_ALT0_EPDC_DATA8 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE: Select mux mode: ALT0 mux port: DATA8 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE_ALT1_SIM1_PORT1_TRXD (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE: Select mux mode: ALT1 mux port: PORT1_TRXD of instance: SIM1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE_ALT2_QSPI_B_DATA0 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE: Select mux mode: ALT2 mux port: B_DATA0 of instance: QSPI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE_ALT3_UART6_RX_DATA (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE: Select mux mode: ALT3 mux port: RX_DATA of instance: UART6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE_ALT4_EIM_OE (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE: Select mux mode: ALT4 mux port: OE of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE_ALT5_GPIO2_IO8 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE: Select mux mode: ALT5 mux port: IO8 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE_ALT6_LCD_DATA8 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE: Select mux mode: ALT6 mux port: DATA8 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE_ALT7_LCD_BUSY (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE: Select mux mode: ALT7 mux port: BUSY of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE_ALT8_EPDC_SDCLK (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE: Select mux mode: ALT8 mux port: SDCLK of instance: EPDC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_DATA08
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SION: Force input path of pad EPDC_DATA08 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA08_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09 - SW_MUX_CTL_PAD_EPDC_DATA09 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09 - SW_MUX_CTL_PAD_EPDC_DATA09 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_data09
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_data09_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_data09_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_ADDR(x) ((uintptr_t)(x) + 0x58U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_data09_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: EPDC_DATA09.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA9 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT1_CLK of instance: SIM1
 * - 010 - Select mux mode: ALT2 mux port: B_DATA1 of instance: QSPI
 * - 011 - Select mux mode: ALT3 mux port: TX_DATA of instance: UART6
 * - 100 - Select mux mode: ALT4 mux port: RW of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO9 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA9 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA0 of instance: LCD
 * - 1000 - Select mux mode: ALT8 mux port: SDLE of instance: EPDC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE_ALT0_EPDC_DATA9 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE: Select mux mode: ALT0 mux port: DATA9 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE_ALT1_SIM1_PORT1_CLK (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE: Select mux mode: ALT1 mux port: PORT1_CLK of instance: SIM1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE_ALT2_QSPI_B_DATA1 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE: Select mux mode: ALT2 mux port: B_DATA1 of instance: QSPI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE_ALT3_UART6_TX_DATA (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE: Select mux mode: ALT3 mux port: TX_DATA of instance: UART6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE_ALT4_EIM_RW (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE: Select mux mode: ALT4 mux port: RW of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE_ALT5_GPIO2_IO9 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE: Select mux mode: ALT5 mux port: IO9 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE_ALT6_LCD_DATA9 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE: Select mux mode: ALT6 mux port: DATA9 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE_ALT7_LCD_DATA0 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE: Select mux mode: ALT7 mux port: DATA0 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE_ALT8_EPDC_SDLE (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE: Select mux mode: ALT8 mux port: SDLE of instance: EPDC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_DATA09
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SION: Force input path of pad EPDC_DATA09 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA09_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10 - SW_MUX_CTL_PAD_EPDC_DATA10 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10 - SW_MUX_CTL_PAD_EPDC_DATA10 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_data10
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_data10_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_data10_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_ADDR(x) ((uintptr_t)(x) + 0x5CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_data10_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: EPDC_DATA10.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA10 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT1_RST_B of instance: SIM1
 * - 010 - Select mux mode: ALT2 mux port: B_DATA2 of instance: QSPI
 * - 011 - Select mux mode: ALT3 mux port: RTS_B of instance: UART6
 * - 100 - Select mux mode: ALT4 mux port: CS0_B of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO10 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA10 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA9 of instance: LCD
 * - 1000 - Select mux mode: ALT8 mux port: SDOE of instance: EPDC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE_ALT0_EPDC_DATA10 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE: Select mux mode: ALT0 mux port: DATA10 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE_ALT1_SIM1_PORT1_RST_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE: Select mux mode: ALT1 mux port: PORT1_RST_B of instance: SIM1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE_ALT2_QSPI_B_DATA2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE: Select mux mode: ALT2 mux port: B_DATA2 of instance: QSPI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE_ALT3_UART6_RTS_B (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE: Select mux mode: ALT3 mux port: RTS_B of instance: UART6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE_ALT4_EIM_CS0_B (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE: Select mux mode: ALT4 mux port: CS0_B of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE_ALT5_GPIO2_IO10 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE: Select mux mode: ALT5 mux port: IO10 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE_ALT6_LCD_DATA10 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE: Select mux mode: ALT6 mux port: DATA10 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE_ALT7_LCD_DATA9 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE: Select mux mode: ALT7 mux port: DATA9 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE_ALT8_EPDC_SDOE (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE: Select mux mode: ALT8 mux port: SDOE of instance: EPDC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_DATA10
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SION: Force input path of pad EPDC_DATA10 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA10_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11 - SW_MUX_CTL_PAD_EPDC_DATA11 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11 - SW_MUX_CTL_PAD_EPDC_DATA11 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_data11
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_data11_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_data11_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_ADDR(x) ((uintptr_t)(x) + 0x60U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_data11_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: EPDC_DATA11.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA11 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT1_SVEN of instance: SIM1
 * - 010 - Select mux mode: ALT2 mux port: B_DATA3 of instance: QSPI
 * - 011 - Select mux mode: ALT3 mux port: CTS_B of instance: UART6
 * - 100 - Select mux mode: ALT4 mux port: BCLK of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO11 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA11 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA1 of instance: LCD
 * - 1000 - Select mux mode: ALT8 mux port: SDCE0 of instance: EPDC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE_ALT0_EPDC_DATA11 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE: Select mux mode: ALT0 mux port: DATA11 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE_ALT1_SIM1_PORT1_SVEN (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE: Select mux mode: ALT1 mux port: PORT1_SVEN of instance: SIM1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE_ALT2_QSPI_B_DATA3 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE: Select mux mode: ALT2 mux port: B_DATA3 of instance: QSPI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE_ALT3_UART6_CTS_B (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE: Select mux mode: ALT3 mux port: CTS_B of instance: UART6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE_ALT4_EIM_BCLK (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE: Select mux mode: ALT4 mux port: BCLK of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE_ALT5_GPIO2_IO11 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE: Select mux mode: ALT5 mux port: IO11 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE_ALT6_LCD_DATA11 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE: Select mux mode: ALT6 mux port: DATA11 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE_ALT7_LCD_DATA1 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE: Select mux mode: ALT7 mux port: DATA1 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE_ALT8_EPDC_SDCE0 (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE: Select mux mode: ALT8 mux port: SDCE0 of instance: EPDC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_DATA11
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SION: Force input path of pad EPDC_DATA11 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA11_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12 - SW_MUX_CTL_PAD_EPDC_DATA12 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12 - SW_MUX_CTL_PAD_EPDC_DATA12 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_data12
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_data12_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_data12_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_ADDR(x) ((uintptr_t)(x) + 0x64U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_data12_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: EPDC_DATA12.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA12 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT1_PD of instance: SIM1
 * - 010 - Select mux mode: ALT2 mux port: B_DQS of instance: QSPI
 * - 011 - Select mux mode: ALT3 mux port: RX_DATA of instance: UART7
 * - 100 - Select mux mode: ALT4 mux port: LBA_B of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO12 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA12 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA21 of instance: LCD
 * - 1000 - Select mux mode: ALT8 mux port: GDCLK of instance: EPDC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE_ALT0_EPDC_DATA12 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE: Select mux mode: ALT0 mux port: DATA12 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE_ALT1_SIM1_PORT1_PD (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE: Select mux mode: ALT1 mux port: PORT1_PD of instance: SIM1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE_ALT2_QSPI_B_DQS (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE: Select mux mode: ALT2 mux port: B_DQS of instance: QSPI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE_ALT3_UART7_RX_DATA (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE: Select mux mode: ALT3 mux port: RX_DATA of instance: UART7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE_ALT4_EIM_LBA_B (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE: Select mux mode: ALT4 mux port: LBA_B of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE_ALT5_GPIO2_IO12 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE: Select mux mode: ALT5 mux port: IO12 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE_ALT6_LCD_DATA12 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE: Select mux mode: ALT6 mux port: DATA12 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE_ALT7_LCD_DATA21 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE: Select mux mode: ALT7 mux port: DATA21 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE_ALT8_EPDC_GDCLK (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE: Select mux mode: ALT8 mux port: GDCLK of instance: EPDC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_DATA12
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SION: Force input path of pad EPDC_DATA12 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA12_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13 - SW_MUX_CTL_PAD_EPDC_DATA13 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13 - SW_MUX_CTL_PAD_EPDC_DATA13 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_data13
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_data13_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_data13_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_ADDR(x) ((uintptr_t)(x) + 0x68U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_data13_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: EPDC_DATA13.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA13 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT1_TRXD of instance: SIM2
 * - 010 - Select mux mode: ALT2 mux port: B_SCLK of instance: QSPI
 * - 011 - Select mux mode: ALT3 mux port: TX_DATA of instance: UART7
 * - 100 - Select mux mode: ALT4 mux port: WAIT of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO13 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA13 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: CS of instance: LCD
 * - 1000 - Select mux mode: ALT8 mux port: GDOE of instance: EPDC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE_ALT0_EPDC_DATA13 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE: Select mux mode: ALT0 mux port: DATA13 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE_ALT1_SIM2_PORT1_TRXD (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE: Select mux mode: ALT1 mux port: PORT1_TRXD of instance: SIM2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE_ALT2_QSPI_B_SCLK (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE: Select mux mode: ALT2 mux port: B_SCLK of instance: QSPI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE_ALT3_UART7_TX_DATA (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE: Select mux mode: ALT3 mux port: TX_DATA of instance: UART7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE_ALT4_EIM_WAIT (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE: Select mux mode: ALT4 mux port: WAIT of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE_ALT5_GPIO2_IO13 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE: Select mux mode: ALT5 mux port: IO13 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE_ALT6_LCD_DATA13 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE: Select mux mode: ALT6 mux port: DATA13 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE_ALT7_LCD_CS (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE: Select mux mode: ALT7 mux port: CS of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE_ALT8_EPDC_GDOE (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE: Select mux mode: ALT8 mux port: GDOE of instance: EPDC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_DATA13
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SION: Force input path of pad EPDC_DATA13 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA13_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14 - SW_MUX_CTL_PAD_EPDC_DATA14 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14 - SW_MUX_CTL_PAD_EPDC_DATA14 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_data14
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_data14_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_data14_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_ADDR(x) ((uintptr_t)(x) + 0x6CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_data14_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: EPDC_DATA14.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA14 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT1_CLK of instance: SIM2
 * - 010 - Select mux mode: ALT2 mux port: B_SS0_B of instance: QSPI
 * - 011 - Select mux mode: ALT3 mux port: RTS_B of instance: UART7
 * - 100 - Select mux mode: ALT4 mux port: EB_B0 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO14 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA14 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA22 of instance: LCD
 * - 1000 - Select mux mode: ALT8 mux port: GDSP of instance: EPDC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE_ALT0_EPDC_DATA14 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE: Select mux mode: ALT0 mux port: DATA14 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE_ALT1_SIM2_PORT1_CLK (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE: Select mux mode: ALT1 mux port: PORT1_CLK of instance: SIM2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE_ALT2_QSPI_B_SS0_B (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE: Select mux mode: ALT2 mux port: B_SS0_B of instance: QSPI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE_ALT3_UART7_RTS_B (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE: Select mux mode: ALT3 mux port: RTS_B of instance: UART7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE_ALT4_EIM_EB_B0 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE: Select mux mode: ALT4 mux port: EB_B0 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE_ALT5_GPIO2_IO14 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE: Select mux mode: ALT5 mux port: IO14 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE_ALT6_LCD_DATA14 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE: Select mux mode: ALT6 mux port: DATA14 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE_ALT7_LCD_DATA22 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE: Select mux mode: ALT7 mux port: DATA22 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE_ALT8_EPDC_GDSP (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE: Select mux mode: ALT8 mux port: GDSP of instance: EPDC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_DATA14
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SION: Force input path of pad EPDC_DATA14 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA14_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15 - SW_MUX_CTL_PAD_EPDC_DATA15 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15 - SW_MUX_CTL_PAD_EPDC_DATA15 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_data15
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_data15_bitfields
    {
        uint32_t MUX_MODE : 4;         /*!< [3:0] MUX Mode Select Field. */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_data15_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_ADDR(x) ((uintptr_t)(x) + 0x70U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_data15_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15, field MUX_MODE[3:0] (RW)
 *
 * Select 1 of 9 iomux modes to be used for pad: EPDC_DATA15.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA15 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT1_RST_B of instance: SIM2
 * - 010 - Select mux mode: ALT2 mux port: B_SS1_B of instance: QSPI
 * - 011 - Select mux mode: ALT3 mux port: CTS_B of instance: UART7
 * - 100 - Select mux mode: ALT4 mux port: CS1_B of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO15 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA15 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: WR_RWN of instance: LCD
 * - 1000 - Select mux mode: ALT8 mux port: PWR_COM of instance: EPDC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE (0x0000000FU) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE (4U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE_ALT0_EPDC_DATA15 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE: Select mux mode: ALT0 mux port: DATA15 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE_ALT1_SIM2_PORT1_RST_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE: Select mux mode: ALT1 mux port: PORT1_RST_B of instance: SIM2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE_ALT2_QSPI_B_SS1_B (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE: Select mux mode: ALT2 mux port: B_SS1_B of instance: QSPI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE_ALT3_UART7_CTS_B (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE: Select mux mode: ALT3 mux port: CTS_B of instance: UART7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE_ALT4_EIM_CS1_B (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE: Select mux mode: ALT4 mux port: CS1_B of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE_ALT5_GPIO2_IO15 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE: Select mux mode: ALT5 mux port: IO15 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE_ALT6_LCD_DATA15 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE: Select mux mode: ALT6 mux port: DATA15 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE_ALT7_LCD_WR_RWN (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE: Select mux mode: ALT7 mux port: WR_RWN of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE_ALT8_EPDC_PWR_COM (0x8U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE: Select mux mode: ALT8 mux port: PWR_COM of instance: EPDC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_DATA15
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SION: Force input path of pad EPDC_DATA15 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_DATA15_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK - SW_MUX_CTL_PAD_EPDC_SDCLK SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK - SW_MUX_CTL_PAD_EPDC_SDCLK SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_sdclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_sdclk_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_sdclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_ADDR(x) ((uintptr_t)(x) + 0x74U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_sdclk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: EPDC_SDCLK.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SDCLK of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT2_SVEN of instance: SIM2
 * - 010 - Select mux mode: ALT2 mux port: RGMII_RD0 of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: ROW4 of instance: KPP
 * - 100 - Select mux mode: ALT4 mux port: AD10 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO16 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: CLK of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA20 of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE_ALT0_EPDC_SDCLK (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE: Select mux mode: ALT0 mux port: SDCLK of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE_ALT1_SIM2_PORT2_SVEN (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE: Select mux mode: ALT1 mux port: PORT2_SVEN of instance: SIM2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE_ALT2_ENET2_RGMII_RD0 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE: Select mux mode: ALT2 mux port: RGMII_RD0 of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE_ALT3_KPP_ROW4 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE: Select mux mode: ALT3 mux port: ROW4 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE_ALT4_EIM_AD10 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE: Select mux mode: ALT4 mux port: AD10 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE_ALT5_GPIO2_IO16 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE: Select mux mode: ALT5 mux port: IO16 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE_ALT6_LCD_CLK (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE: Select mux mode: ALT6 mux port: CLK of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE_ALT7_LCD_DATA20 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE: Select mux mode: ALT7 mux port: DATA20 of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_SDCLK
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SION: Force input path of pad EPDC_SDCLK */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE - SW_MUX_CTL_PAD_EPDC_SDLE SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE - SW_MUX_CTL_PAD_EPDC_SDLE SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_sdle
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_sdle_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_sdle_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_ADDR(x) ((uintptr_t)(x) + 0x78U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_sdle_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: EPDC_SDLE.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SDLE of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT2_PD of instance: SIM2
 * - 010 - Select mux mode: ALT2 mux port: RGMII_RD1 of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: COL4 of instance: KPP
 * - 100 - Select mux mode: ALT4 mux port: AD11 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO17 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA16 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA8 of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE_ALT0_EPDC_SDLE (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE: Select mux mode: ALT0 mux port: SDLE of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE_ALT1_SIM2_PORT2_PD (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE: Select mux mode: ALT1 mux port: PORT2_PD of instance: SIM2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE_ALT2_ENET2_RGMII_RD1 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE: Select mux mode: ALT2 mux port: RGMII_RD1 of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE_ALT3_KPP_COL4 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE: Select mux mode: ALT3 mux port: COL4 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE_ALT4_EIM_AD11 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE: Select mux mode: ALT4 mux port: AD11 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE_ALT5_GPIO2_IO17 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE: Select mux mode: ALT5 mux port: IO17 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE_ALT6_LCD_DATA16 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE: Select mux mode: ALT6 mux port: DATA16 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE_ALT7_LCD_DATA8 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE: Select mux mode: ALT7 mux port: DATA8 of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_SDLE
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SION: Force input path of pad EPDC_SDLE */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDLE_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE - SW_MUX_CTL_PAD_EPDC_SDOE SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE - SW_MUX_CTL_PAD_EPDC_SDOE SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_sdoe
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_sdoe_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_sdoe_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_ADDR(x) ((uintptr_t)(x) + 0x7CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_sdoe_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: EPDC_SDOE.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SDOE of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: CH0 of instance: FLEXTIMER1
 * - 010 - Select mux mode: ALT2 mux port: RGMII_RD2 of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: COL5 of instance: KPP
 * - 100 - Select mux mode: ALT4 mux port: AD12 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO18 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA17 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA23 of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE_ALT0_EPDC_SDOE (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE: Select mux mode: ALT0 mux port: SDOE of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE_ALT1_FLEXTIMER1_CH0 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE: Select mux mode: ALT1 mux port: CH0 of instance: FLEXTIMER1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE_ALT2_ENET2_RGMII_RD2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE: Select mux mode: ALT2 mux port: RGMII_RD2 of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE_ALT3_KPP_COL5 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE: Select mux mode: ALT3 mux port: COL5 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE_ALT4_EIM_AD12 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE: Select mux mode: ALT4 mux port: AD12 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE_ALT5_GPIO2_IO18 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE: Select mux mode: ALT5 mux port: IO18 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE_ALT6_LCD_DATA17 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE: Select mux mode: ALT6 mux port: DATA17 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE_ALT7_LCD_DATA23 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE: Select mux mode: ALT7 mux port: DATA23 of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_SDOE
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SION: Force input path of pad EPDC_SDOE */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDOE_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR - SW_MUX_CTL_PAD_EPDC_SDSHR SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR - SW_MUX_CTL_PAD_EPDC_SDSHR SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_sdshr
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_sdshr_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_sdshr_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_ADDR(x) ((uintptr_t)(x) + 0x80U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_sdshr_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: EPDC_SDSHR.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SDSHR of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: CH1 of instance: FLEXTIMER1
 * - 010 - Select mux mode: ALT2 mux port: RGMII_RD3 of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: ROW5 of instance: KPP
 * - 100 - Select mux mode: ALT4 mux port: AD13 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO19 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA18 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA10 of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE_ALT0_EPDC_SDSHR (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE: Select mux mode: ALT0 mux port: SDSHR of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE_ALT1_FLEXTIMER1_CH1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE: Select mux mode: ALT1 mux port: CH1 of instance: FLEXTIMER1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE_ALT2_ENET2_RGMII_RD3 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE: Select mux mode: ALT2 mux port: RGMII_RD3 of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE_ALT3_KPP_ROW5 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE: Select mux mode: ALT3 mux port: ROW5 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE_ALT4_EIM_AD13 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE: Select mux mode: ALT4 mux port: AD13 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE_ALT5_GPIO2_IO19 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE: Select mux mode: ALT5 mux port: IO19 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE_ALT6_LCD_DATA18 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE: Select mux mode: ALT6 mux port: DATA18 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE_ALT7_LCD_DATA10 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE: Select mux mode: ALT7 mux port: DATA10 of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_SDSHR
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SION: Force input path of pad EPDC_SDSHR */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDSHR_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0 - SW_MUX_CTL_PAD_EPDC_SDCE0 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0 - SW_MUX_CTL_PAD_EPDC_SDCE0 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_sdce0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_sdce0_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_sdce0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_ADDR(x) ((uintptr_t)(x) + 0x84U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_sdce0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: EPDC_SDCE0.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SDCE0 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: CH2 of instance: FLEXTIMER1
 * - 010 - Select mux mode: ALT2 mux port: RGMII_RX_CTL of instance: ENET2
 * - 100 - Select mux mode: ALT4 mux port: AD14 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO20 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA19 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA5 of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE_ALT0_EPDC_SDCE0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE: Select mux mode: ALT0 mux port: SDCE0 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE_ALT1_FLEXTIMER1_CH2 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE: Select mux mode: ALT1 mux port: CH2 of instance: FLEXTIMER1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE_ALT2_ENET2_RGMII_RX_CTL (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE: Select mux mode: ALT2 mux port: RGMII_RX_CTL of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE_ALT4_EIM_AD14 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE: Select mux mode: ALT4 mux port: AD14 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE_ALT5_GPIO2_IO20 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE: Select mux mode: ALT5 mux port: IO20 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE_ALT6_LCD_DATA19 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE: Select mux mode: ALT6 mux port: DATA19 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE_ALT7_LCD_DATA5 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE: Select mux mode: ALT7 mux port: DATA5 of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_SDCE0
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SION: Force input path of pad EPDC_SDCE0 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1 - SW_MUX_CTL_PAD_EPDC_SDCE1 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1 - SW_MUX_CTL_PAD_EPDC_SDCE1 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_sdce1
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_sdce1_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_sdce1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_ADDR(x) ((uintptr_t)(x) + 0x88U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_sdce1_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: EPDC_SDCE1.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SDCE1 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: CH3 of instance: FLEXTIMER1
 * - 010 - Select mux mode: ALT2 mux port: RGMII_RXC of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: RX_ER of instance: ENET2
 * - 100 - Select mux mode: ALT4 mux port: AD15 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO21 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA20 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA4 of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE_ALT0_EPDC_SDCE1 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE: Select mux mode: ALT0 mux port: SDCE1 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE_ALT1_FLEXTIMER1_CH3 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE: Select mux mode: ALT1 mux port: CH3 of instance: FLEXTIMER1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE_ALT2_ENET2_RGMII_RXC (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE: Select mux mode: ALT2 mux port: RGMII_RXC of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE_ALT3_ENET2_RX_ER (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE: Select mux mode: ALT3 mux port: RX_ER of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE_ALT4_EIM_AD15 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE: Select mux mode: ALT4 mux port: AD15 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE_ALT5_GPIO2_IO21 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE: Select mux mode: ALT5 mux port: IO21 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE_ALT6_LCD_DATA20 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE: Select mux mode: ALT6 mux port: DATA20 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE_ALT7_LCD_DATA4 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE: Select mux mode: ALT7 mux port: DATA4 of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_SDCE1
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SION: Force input path of pad EPDC_SDCE1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE1_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2 - SW_MUX_CTL_PAD_EPDC_SDCE2 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2 - SW_MUX_CTL_PAD_EPDC_SDCE2 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_sdce2
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_sdce2_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_sdce2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_ADDR(x) ((uintptr_t)(x) + 0x8CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_sdce2_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: EPDC_SDCE2.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SDCE2 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT1_SVEN of instance: SIM2
 * - 010 - Select mux mode: ALT2 mux port: RGMII_TD0 of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: COL6 of instance: KPP
 * - 100 - Select mux mode: ALT4 mux port: ADDR16 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO22 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA21 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA3 of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE_ALT0_EPDC_SDCE2 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE: Select mux mode: ALT0 mux port: SDCE2 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE_ALT1_SIM2_PORT1_SVEN (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE: Select mux mode: ALT1 mux port: PORT1_SVEN of instance: SIM2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE_ALT2_ENET2_RGMII_TD0 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE: Select mux mode: ALT2 mux port: RGMII_TD0 of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE_ALT3_KPP_COL6 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE: Select mux mode: ALT3 mux port: COL6 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE_ALT4_EIM_ADDR16 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE: Select mux mode: ALT4 mux port: ADDR16 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE_ALT5_GPIO2_IO22 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE: Select mux mode: ALT5 mux port: IO22 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE_ALT6_LCD_DATA21 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE: Select mux mode: ALT6 mux port: DATA21 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE_ALT7_LCD_DATA3 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE: Select mux mode: ALT7 mux port: DATA3 of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_SDCE2
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SION: Force input path of pad EPDC_SDCE2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE2_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3 - SW_MUX_CTL_PAD_EPDC_SDCE3 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3 - SW_MUX_CTL_PAD_EPDC_SDCE3 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_sdce3
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_sdce3_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_sdce3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_ADDR(x) ((uintptr_t)(x) + 0x90U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_sdce3_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: EPDC_SDCE3.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SDCE3 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PORT1_PD of instance: SIM2
 * - 010 - Select mux mode: ALT2 mux port: RGMII_TD1 of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: ROW6 of instance: KPP
 * - 100 - Select mux mode: ALT4 mux port: ADDR17 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO23 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA22 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA2 of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE_ALT0_EPDC_SDCE3 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE: Select mux mode: ALT0 mux port: SDCE3 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE_ALT1_SIM2_PORT1_PD (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE: Select mux mode: ALT1 mux port: PORT1_PD of instance: SIM2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE_ALT2_ENET2_RGMII_TD1 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE: Select mux mode: ALT2 mux port: RGMII_TD1 of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE_ALT3_KPP_ROW6 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE: Select mux mode: ALT3 mux port: ROW6 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE_ALT4_EIM_ADDR17 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE: Select mux mode: ALT4 mux port: ADDR17 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE_ALT5_GPIO2_IO23 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE: Select mux mode: ALT5 mux port: IO23 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE_ALT6_LCD_DATA22 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE: Select mux mode: ALT6 mux port: DATA22 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE_ALT7_LCD_DATA2 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE: Select mux mode: ALT7 mux port: DATA2 of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_SDCE3
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SION: Force input path of pad EPDC_SDCE3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_SDCE3_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK - SW_MUX_CTL_PAD_EPDC_GDCLK SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK - SW_MUX_CTL_PAD_EPDC_GDCLK SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_gdclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_gdclk_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_gdclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_ADDR(x) ((uintptr_t)(x) + 0x94U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_gdclk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: EPDC_GDCLK.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: GDCLK of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: CH0 of instance: FLEXTIMER2
 * - 010 - Select mux mode: ALT2 mux port: RGMII_TD2 of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: COL7 of instance: KPP
 * - 100 - Select mux mode: ALT4 mux port: ADDR18 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO24 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: DATA23 of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA16 of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE_ALT0_EPDC_GDCLK (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE: Select mux mode: ALT0 mux port: GDCLK of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE_ALT1_FLEXTIMER2_CH0 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE: Select mux mode: ALT1 mux port: CH0 of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE_ALT2_ENET2_RGMII_TD2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE: Select mux mode: ALT2 mux port: RGMII_TD2 of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE_ALT3_KPP_COL7 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE: Select mux mode: ALT3 mux port: COL7 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE_ALT4_EIM_ADDR18 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE: Select mux mode: ALT4 mux port: ADDR18 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE_ALT5_GPIO2_IO24 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE: Select mux mode: ALT5 mux port: IO24 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE_ALT6_LCD_DATA23 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE: Select mux mode: ALT6 mux port: DATA23 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE_ALT7_LCD_DATA16 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE: Select mux mode: ALT7 mux port: DATA16 of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_GDCLK
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SION: Force input path of pad EPDC_GDCLK */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDCLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE - SW_MUX_CTL_PAD_EPDC_GDOE SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE - SW_MUX_CTL_PAD_EPDC_GDOE SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_gdoe
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_gdoe_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_gdoe_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_ADDR(x) ((uintptr_t)(x) + 0x98U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_gdoe_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: EPDC_GDOE.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: GDOE of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: CH1 of instance: FLEXTIMER2
 * - 010 - Select mux mode: ALT2 mux port: RGMII_TD3 of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: ROW7 of instance: KPP
 * - 100 - Select mux mode: ALT4 mux port: ADDR19 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO25 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: WR_RWN of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA18 of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE_ALT0_EPDC_GDOE (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE: Select mux mode: ALT0 mux port: GDOE of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE_ALT1_FLEXTIMER2_CH1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE: Select mux mode: ALT1 mux port: CH1 of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE_ALT2_ENET2_RGMII_TD3 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE: Select mux mode: ALT2 mux port: RGMII_TD3 of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE_ALT3_KPP_ROW7 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE: Select mux mode: ALT3 mux port: ROW7 of instance: KPP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE_ALT4_EIM_ADDR19 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE: Select mux mode: ALT4 mux port: ADDR19 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE_ALT5_GPIO2_IO25 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE: Select mux mode: ALT5 mux port: IO25 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE_ALT6_LCD_WR_RWN (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE: Select mux mode: ALT6 mux port: WR_RWN of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE_ALT7_LCD_DATA18 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE: Select mux mode: ALT7 mux port: DATA18 of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_GDOE
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SION: Force input path of pad EPDC_GDOE */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDOE_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL - SW_MUX_CTL_PAD_EPDC_GDRL SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL - SW_MUX_CTL_PAD_EPDC_GDRL SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_gdrl
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_gdrl_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_gdrl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_ADDR(x) ((uintptr_t)(x) + 0x9CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_gdrl_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: EPDC_GDRL.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: GDRL of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: CH2 of instance: FLEXTIMER2
 * - 010 - Select mux mode: ALT2 mux port: RGMII_TX_CTL of instance: ENET2
 * - 100 - Select mux mode: ALT4 mux port: ADDR20 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO26 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: RD_E of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA19 of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE_ALT0_EPDC_GDRL (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE: Select mux mode: ALT0 mux port: GDRL of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE_ALT1_FLEXTIMER2_CH2 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE: Select mux mode: ALT1 mux port: CH2 of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE_ALT2_ENET2_RGMII_TX_CTL (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE: Select mux mode: ALT2 mux port: RGMII_TX_CTL of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE_ALT4_EIM_ADDR20 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE: Select mux mode: ALT4 mux port: ADDR20 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE_ALT5_GPIO2_IO26 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE: Select mux mode: ALT5 mux port: IO26 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE_ALT6_LCD_RD_E (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE: Select mux mode: ALT6 mux port: RD_E of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE_ALT7_LCD_DATA19 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE: Select mux mode: ALT7 mux port: DATA19 of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_GDRL
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SION: Force input path of pad EPDC_GDRL */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDRL_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP - SW_MUX_CTL_PAD_EPDC_GDSP SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP - SW_MUX_CTL_PAD_EPDC_GDSP SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_gdsp
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_gdsp_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_gdsp_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_ADDR(x) ((uintptr_t)(x) + 0xA0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_gdsp_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: EPDC_GDSP.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: GDSP of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: CH3 of instance: FLEXTIMER2
 * - 010 - Select mux mode: ALT2 mux port: RGMII_TXC of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: TX_ER of instance: ENET2
 * - 100 - Select mux mode: ALT4 mux port: ADDR21 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO27 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: BUSY of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA17 of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE_ALT0_EPDC_GDSP (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE: Select mux mode: ALT0 mux port: GDSP of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE_ALT1_FLEXTIMER2_CH3 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE: Select mux mode: ALT1 mux port: CH3 of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE_ALT2_ENET2_RGMII_TXC (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE: Select mux mode: ALT2 mux port: RGMII_TXC of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE_ALT3_ENET2_TX_ER (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE: Select mux mode: ALT3 mux port: TX_ER of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE_ALT4_EIM_ADDR21 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE: Select mux mode: ALT4 mux port: ADDR21 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE_ALT5_GPIO2_IO27 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE: Select mux mode: ALT5 mux port: IO27 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE_ALT6_LCD_BUSY (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE: Select mux mode: ALT6 mux port: BUSY of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE_ALT7_LCD_DATA17 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE: Select mux mode: ALT7 mux port: DATA17 of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_GDSP
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SION: Force input path of pad EPDC_GDSP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_GDSP_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0 - SW_MUX_CTL_PAD_EPDC_BDR0 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0 - SW_MUX_CTL_PAD_EPDC_BDR0 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_bdr0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_bdr0_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_bdr0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_ADDR(x) ((uintptr_t)(x) + 0xA4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_bdr0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: EPDC_BDR0.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: BDR0 of instance: EPDC
 * - 010 - Select mux mode: ALT2 mux port: TX_CLK of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: ENET2_REF_CLK of instance: ENET2
 * - 100 - Select mux mode: ALT4 mux port: ADDR22 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO28 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: CS of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA7 of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE_ALT0_EPDC_BDR0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE: Select mux mode: ALT0 mux port: BDR0 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE_ALT2_ENET2_TX_CLK (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE: Select mux mode: ALT2 mux port: TX_CLK of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE_ALT3_CCM_ENET2_REF_CLK (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE: Select mux mode: ALT3 mux port: ENET2_REF_CLK of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE_ALT4_EIM_ADDR22 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE: Select mux mode: ALT4 mux port: ADDR22 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE_ALT5_GPIO2_IO28 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE: Select mux mode: ALT5 mux port: IO28 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE_ALT6_LCD_CS (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE: Select mux mode: ALT6 mux port: CS of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE_ALT7_LCD_DATA7 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE: Select mux mode: ALT7 mux port: DATA7 of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_BDR0
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SION: Force input path of pad EPDC_BDR0 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1 - SW_MUX_CTL_PAD_EPDC_BDR1 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1 - SW_MUX_CTL_PAD_EPDC_BDR1 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_bdr1
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_bdr1_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_bdr1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_ADDR(x) ((uintptr_t)(x) + 0xA8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_bdr1_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: EPDC_BDR1.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: BDR1 of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: SDCLKN of instance: EPDC
 * - 010 - Select mux mode: ALT2 mux port: RX_CLK of instance: ENET2
 * - 100 - Select mux mode: ALT4 mux port: AD8 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO29 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: ENABLE of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA6 of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE_ALT0_EPDC_BDR1 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE: Select mux mode: ALT0 mux port: BDR1 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE_ALT1_EPDC_SDCLKN (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE: Select mux mode: ALT1 mux port: SDCLKN of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE_ALT2_ENET2_RX_CLK (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE: Select mux mode: ALT2 mux port: RX_CLK of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE_ALT4_EIM_AD8 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE: Select mux mode: ALT4 mux port: AD8 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE_ALT5_GPIO2_IO29 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE: Select mux mode: ALT5 mux port: IO29 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE_ALT6_LCD_ENABLE (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE: Select mux mode: ALT6 mux port: ENABLE of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE_ALT7_LCD_DATA6 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE: Select mux mode: ALT7 mux port: DATA6 of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_BDR1
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SION: Force input path of pad EPDC_BDR1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_BDR1_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM - SW_MUX_CTL_PAD_EPDC_PWR_COM SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM - SW_MUX_CTL_PAD_EPDC_PWR_COM SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_pwr_com
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_pwr_com_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_pwr_com_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_ADDR(x) ((uintptr_t)(x) + 0xACU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_pwr_com_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: EPDC_PWR_COM.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: PWR_COM of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PHA of instance: FLEXTIMER2
 * - 010 - Select mux mode: ALT2 mux port: CRS of instance: ENET2
 * - 100 - Select mux mode: ALT4 mux port: AD9 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO30 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: HSYNC of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA11 of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE_ALT0_EPDC_PWR_COM (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE: Select mux mode: ALT0 mux port: PWR_COM of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE_ALT1_FLEXTIMER2_PHA (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE: Select mux mode: ALT1 mux port: PHA of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE_ALT2_ENET2_CRS (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE: Select mux mode: ALT2 mux port: CRS of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE_ALT4_EIM_AD9 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE: Select mux mode: ALT4 mux port: AD9 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE_ALT5_GPIO2_IO30 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE: Select mux mode: ALT5 mux port: IO30 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE_ALT6_LCD_HSYNC (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE: Select mux mode: ALT6 mux port: HSYNC of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE_ALT7_LCD_DATA11 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE: Select mux mode: ALT7 mux port: DATA11 of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_PWR_COM
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SION: Force input path of pad EPDC_PWR_COM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_COM_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT - SW_MUX_CTL_PAD_EPDC_PWR_STAT SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT - SW_MUX_CTL_PAD_EPDC_PWR_STAT SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_epdc_pwr_stat
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_epdc_pwr_stat_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_epdc_pwr_stat_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_ADDR(x) ((uintptr_t)(x) + 0xB0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_epdc_pwr_stat_t *) HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: EPDC_PWR_STAT.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: PWR_STAT of instance: EPDC
 * - 001 - Select mux mode: ALT1 mux port: PHB of instance: FLEXTIMER2
 * - 010 - Select mux mode: ALT2 mux port: COL of instance: ENET2
 * - 100 - Select mux mode: ALT4 mux port: EB_B1 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO31 of instance: GPIO2
 * - 110 - Select mux mode: ALT6 mux port: VSYNC of instance: LCD
 * - 111 - Select mux mode: ALT7 mux port: DATA12 of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE_ALT0_EPDC_PWR_STAT (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE: Select mux mode: ALT0 mux port: PWR_STAT of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE_ALT1_FLEXTIMER2_PHB (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE: Select mux mode: ALT1 mux port: PHB of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE_ALT2_ENET2_COL (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE: Select mux mode: ALT2 mux port: COL of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE_ALT4_EIM_EB_B1 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE: Select mux mode: ALT4 mux port: EB_B1 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE_ALT5_GPIO2_IO31 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE: Select mux mode: ALT5 mux port: IO31 of instance: GPIO2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE_ALT6_LCD_VSYNC (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE: Select mux mode: ALT6 mux port: VSYNC of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE_ALT7_LCD_DATA12 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE: Select mux mode: ALT7 mux port: DATA12 of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad EPDC_PWR_STAT
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SION: Force input path of pad EPDC_PWR_STAT */
#define BV_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_EPDC_PWR_STAT_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK - SW_MUX_CTL_PAD_LCD_CLK SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK - SW_MUX_CTL_PAD_LCD_CLK SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_clk_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_ADDR(x) ((uintptr_t)(x) + 0xB4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_clk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_CLK, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD_CLK.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: CLK of instance: LCD
 * - 001 - Select mux mode: ALT1 mux port: MISO of instance: ECSPI4
 * - 010 - Select mux mode: ALT2 mux port: 1588_EVENT2_IN of instance: ENET1
 * - 011 - Select mux mode: ALT3 mux port: DATA16 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: RX_DATA of instance: UART2
 * - 101 - Select mux mode: ALT5 mux port: IO0 of instance: GPIO3
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE_ALT0_LCD_CLK (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE: Select mux mode: ALT0 mux port: CLK of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE_ALT1_ECSPI4_MISO (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE: Select mux mode: ALT1 mux port: MISO of instance: ECSPI4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE_ALT2_ENET1_1588_EVENT2_IN (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE: Select mux mode: ALT2 mux port: 1588_EVENT2_IN of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE_ALT3_CSI_DATA16 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE: Select mux mode: ALT3 mux port: DATA16 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE_ALT4_UART2_RX_DATA (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE: Select mux mode: ALT4 mux port: RX_DATA of instance: UART2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE_ALT5_GPIO3_IO0 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE: Select mux mode: ALT5 mux port: IO0 of instance: GPIO3 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_CLK, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_CLK
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SION: Force input path of pad LCD_CLK */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_CLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE - SW_MUX_CTL_PAD_LCD_ENABLE SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE - SW_MUX_CTL_PAD_LCD_ENABLE SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_enable
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_enable_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_enable_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_ADDR(x) ((uintptr_t)(x) + 0xB8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_enable_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD_ENABLE.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: ENABLE of instance: LCD
 * - 001 - Select mux mode: ALT1 mux port: MOSI of instance: ECSPI4
 * - 010 - Select mux mode: ALT2 mux port: 1588_EVENT3_IN of instance: ENET1
 * - 011 - Select mux mode: ALT3 mux port: DATA17 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: TX_DATA of instance: UART2
 * - 101 - Select mux mode: ALT5 mux port: IO1 of instance: GPIO3
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE_ALT0_LCD_ENABLE (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE: Select mux mode: ALT0 mux port: ENABLE of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE_ALT1_ECSPI4_MOSI (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE: Select mux mode: ALT1 mux port: MOSI of instance: ECSPI4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE_ALT2_ENET1_1588_EVENT3_IN (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE: Select mux mode: ALT2 mux port: 1588_EVENT3_IN of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE_ALT3_CSI_DATA17 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE: Select mux mode: ALT3 mux port: DATA17 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE_ALT4_UART2_TX_DATA (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE: Select mux mode: ALT4 mux port: TX_DATA of instance: UART2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE_ALT5_GPIO3_IO1 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE: Select mux mode: ALT5 mux port: IO1 of instance: GPIO3 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_ENABLE
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SION: Force input path of pad LCD_ENABLE */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_ENABLE_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC - SW_MUX_CTL_PAD_LCD_HSYNC SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC - SW_MUX_CTL_PAD_LCD_HSYNC SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_hsync
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_hsync_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_hsync_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_ADDR(x) ((uintptr_t)(x) + 0xBCU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_hsync_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD_HSYNC.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: HSYNC of instance: LCD
 * - 001 - Select mux mode: ALT1 mux port: SCLK of instance: ECSPI4
 * - 010 - Select mux mode: ALT2 mux port: 1588_EVENT2_IN of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: DATA18 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: RTS_B of instance: UART2
 * - 101 - Select mux mode: ALT5 mux port: IO2 of instance: GPIO3
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE_ALT0_LCD_HSYNC (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE: Select mux mode: ALT0 mux port: HSYNC of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE_ALT1_ECSPI4_SCLK (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE: Select mux mode: ALT1 mux port: SCLK of instance: ECSPI4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE_ALT2_ENET2_1588_EVENT2_IN (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE: Select mux mode: ALT2 mux port: 1588_EVENT2_IN of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE_ALT3_CSI_DATA18 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE: Select mux mode: ALT3 mux port: DATA18 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE_ALT4_UART2_RTS_B (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE: Select mux mode: ALT4 mux port: RTS_B of instance: UART2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE_ALT5_GPIO3_IO2 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE: Select mux mode: ALT5 mux port: IO2 of instance: GPIO3 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_HSYNC
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SION: Force input path of pad LCD_HSYNC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_HSYNC_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC - SW_MUX_CTL_PAD_LCD_VSYNC SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC - SW_MUX_CTL_PAD_LCD_VSYNC SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_vsync
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_vsync_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_vsync_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_ADDR(x) ((uintptr_t)(x) + 0xC0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_vsync_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD_VSYNC.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: VSYNC of instance: LCD
 * - 001 - Select mux mode: ALT1 mux port: SS0 of instance: ECSPI4
 * - 010 - Select mux mode: ALT2 mux port: 1588_EVENT3_IN of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: DATA19 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: CTS_B of instance: UART2
 * - 101 - Select mux mode: ALT5 mux port: IO3 of instance: GPIO3
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE_ALT0_LCD_VSYNC (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE: Select mux mode: ALT0 mux port: VSYNC of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE_ALT1_ECSPI4_SS0 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE: Select mux mode: ALT1 mux port: SS0 of instance: ECSPI4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE_ALT2_ENET2_1588_EVENT3_IN (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE: Select mux mode: ALT2 mux port: 1588_EVENT3_IN of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE_ALT3_CSI_DATA19 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE: Select mux mode: ALT3 mux port: DATA19 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE_ALT4_UART2_CTS_B (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE: Select mux mode: ALT4 mux port: CTS_B of instance: UART2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE_ALT5_GPIO3_IO3 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE: Select mux mode: ALT5 mux port: IO3 of instance: GPIO3 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_VSYNC
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SION: Force input path of pad LCD_VSYNC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_VSYNC_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET - SW_MUX_CTL_PAD_LCD_RESET SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET - SW_MUX_CTL_PAD_LCD_RESET SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_reset
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_reset_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_reset_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_RESET register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_ADDR(x) ((uintptr_t)(x) + 0xC4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_reset_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_RESET bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_RESET, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD_RESET.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RESET of instance: LCD
 * - 001 - Select mux mode: ALT1 mux port: COMPARE1 of instance: GPT1
 * - 010 - Select mux mode: ALT2 mux port: EVENTI of instance: ARM_PLATFORM
 * - 011 - Select mux mode: ALT3 mux port: FIELD of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DTACK_B of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO4 of instance: GPIO3
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE_ALT0_LCD_RESET (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE: Select mux mode: ALT0 mux port: RESET of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE_ALT1_GPT1_COMPARE1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE: Select mux mode: ALT1 mux port: COMPARE1 of instance: GPT1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE_ALT2_ARM_PLATFORM_EVENTI (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE: Select mux mode: ALT2 mux port: EVENTI of instance: ARM_PLATFORM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE_ALT3_CSI_FIELD (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE: Select mux mode: ALT3 mux port: FIELD of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE_ALT4_EIM_DTACK_B (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE: Select mux mode: ALT4 mux port: DTACK_B of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE_ALT5_GPIO3_IO4 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE: Select mux mode: ALT5 mux port: IO4 of instance: GPIO3 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_RESET, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_RESET
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SION: Force input path of pad LCD_RESET */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_RESET_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00 - SW_MUX_CTL_PAD_LCD_DATA00 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00 - SW_MUX_CTL_PAD_LCD_DATA00 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data00
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data00_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data00_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_ADDR(x) ((uintptr_t)(x) + 0xC8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data00_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: LCD_DATA00.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA0 of instance: LCD
 * - 001 - Select mux mode: ALT1 mux port: COMPARE2 of instance: GPT1
 * - 011 - Select mux mode: ALT3 mux port: DATA20 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DATA0 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO5 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG0 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE_ALT0_LCD_DATA0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE: Select mux mode: ALT0 mux port: DATA0 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE_ALT1_GPT1_COMPARE2 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE: Select mux mode: ALT1 mux port: COMPARE2 of instance: GPT1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE_ALT3_CSI_DATA20 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE: Select mux mode: ALT3 mux port: DATA20 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE_ALT4_EIM_DATA0 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE: Select mux mode: ALT4 mux port: DATA0 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE_ALT5_GPIO3_IO5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE: Select mux mode: ALT5 mux port: IO5 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE_ALT6_SRC_BOOT_CFG0 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG0 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA00
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SION: Force input path of pad LCD_DATA00 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA00_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01 - SW_MUX_CTL_PAD_LCD_DATA01 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01 - SW_MUX_CTL_PAD_LCD_DATA01 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data01
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data01_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data01_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_ADDR(x) ((uintptr_t)(x) + 0xCCU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data01_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: LCD_DATA01.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA1 of instance: LCD
 * - 001 - Select mux mode: ALT1 mux port: COMPARE3 of instance: GPT1
 * - 011 - Select mux mode: ALT3 mux port: DATA21 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DATA1 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO6 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG1 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE_ALT0_LCD_DATA1 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE: Select mux mode: ALT0 mux port: DATA1 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE_ALT1_GPT1_COMPARE3 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE: Select mux mode: ALT1 mux port: COMPARE3 of instance: GPT1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE_ALT3_CSI_DATA21 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE: Select mux mode: ALT3 mux port: DATA21 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE_ALT4_EIM_DATA1 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE: Select mux mode: ALT4 mux port: DATA1 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE_ALT5_GPIO3_IO6 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE: Select mux mode: ALT5 mux port: IO6 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE_ALT6_SRC_BOOT_CFG1 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG1 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA01
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SION: Force input path of pad LCD_DATA01 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA01_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02 - SW_MUX_CTL_PAD_LCD_DATA02 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02 - SW_MUX_CTL_PAD_LCD_DATA02 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data02
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data02_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data02_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_ADDR(x) ((uintptr_t)(x) + 0xD0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data02_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: LCD_DATA02.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA2 of instance: LCD
 * - 001 - Select mux mode: ALT1 mux port: CLK of instance: GPT1
 * - 011 - Select mux mode: ALT3 mux port: DATA22 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DATA2 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO7 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG2 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE_ALT0_LCD_DATA2 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE: Select mux mode: ALT0 mux port: DATA2 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE_ALT1_GPT1_CLK (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE: Select mux mode: ALT1 mux port: CLK of instance: GPT1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE_ALT3_CSI_DATA22 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE: Select mux mode: ALT3 mux port: DATA22 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE_ALT4_EIM_DATA2 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE: Select mux mode: ALT4 mux port: DATA2 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE_ALT5_GPIO3_IO7 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE: Select mux mode: ALT5 mux port: IO7 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE_ALT6_SRC_BOOT_CFG2 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG2 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA02
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SION: Force input path of pad LCD_DATA02 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA02_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03 - SW_MUX_CTL_PAD_LCD_DATA03 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03 - SW_MUX_CTL_PAD_LCD_DATA03 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data03
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data03_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data03_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_ADDR(x) ((uintptr_t)(x) + 0xD4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data03_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: LCD_DATA03.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA3 of instance: LCD
 * - 001 - Select mux mode: ALT1 mux port: CAPTURE1 of instance: GPT1
 * - 011 - Select mux mode: ALT3 mux port: DATA23 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DATA3 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO8 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG3 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE_ALT0_LCD_DATA3 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE: Select mux mode: ALT0 mux port: DATA3 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE_ALT1_GPT1_CAPTURE1 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE: Select mux mode: ALT1 mux port: CAPTURE1 of instance: GPT1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE_ALT3_CSI_DATA23 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE: Select mux mode: ALT3 mux port: DATA23 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE_ALT4_EIM_DATA3 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE: Select mux mode: ALT4 mux port: DATA3 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE_ALT5_GPIO3_IO8 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE: Select mux mode: ALT5 mux port: IO8 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE_ALT6_SRC_BOOT_CFG3 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG3 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA03
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SION: Force input path of pad LCD_DATA03 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA03_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04 - SW_MUX_CTL_PAD_LCD_DATA04 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04 - SW_MUX_CTL_PAD_LCD_DATA04 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data04
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data04_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data04_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_ADDR(x) ((uintptr_t)(x) + 0xD8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data04_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: LCD_DATA04.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA4 of instance: LCD
 * - 001 - Select mux mode: ALT1 mux port: CAPTURE2 of instance: GPT1
 * - 011 - Select mux mode: ALT3 mux port: VSYNC of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DATA4 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO9 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG4 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE_ALT0_LCD_DATA4 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE: Select mux mode: ALT0 mux port: DATA4 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE_ALT1_GPT1_CAPTURE2 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE: Select mux mode: ALT1 mux port: CAPTURE2 of instance: GPT1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE_ALT3_CSI_VSYNC (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE: Select mux mode: ALT3 mux port: VSYNC of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE_ALT4_EIM_DATA4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE: Select mux mode: ALT4 mux port: DATA4 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE_ALT5_GPIO3_IO9 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE: Select mux mode: ALT5 mux port: IO9 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE_ALT6_SRC_BOOT_CFG4 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG4 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA04
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SION: Force input path of pad LCD_DATA04 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA04_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05 - SW_MUX_CTL_PAD_LCD_DATA05 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05 - SW_MUX_CTL_PAD_LCD_DATA05 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data05
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data05_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data05_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_ADDR(x) ((uintptr_t)(x) + 0xDCU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data05_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD_DATA05.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA5 of instance: LCD
 * - 011 - Select mux mode: ALT3 mux port: HSYNC of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DATA5 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO10 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG5 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE_ALT0_LCD_DATA5 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE: Select mux mode: ALT0 mux port: DATA5 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE_ALT3_CSI_HSYNC (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE: Select mux mode: ALT3 mux port: HSYNC of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE_ALT4_EIM_DATA5 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE: Select mux mode: ALT4 mux port: DATA5 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE_ALT5_GPIO3_IO10 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE: Select mux mode: ALT5 mux port: IO10 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE_ALT6_SRC_BOOT_CFG5 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG5 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA05
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SION: Force input path of pad LCD_DATA05 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA05_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06 - SW_MUX_CTL_PAD_LCD_DATA06 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06 - SW_MUX_CTL_PAD_LCD_DATA06 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data06
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data06_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data06_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_ADDR(x) ((uintptr_t)(x) + 0xE0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data06_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD_DATA06.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA6 of instance: LCD
 * - 011 - Select mux mode: ALT3 mux port: PIXCLK of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DATA6 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO11 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG6 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE_ALT0_LCD_DATA6 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE: Select mux mode: ALT0 mux port: DATA6 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE_ALT3_CSI_PIXCLK (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE: Select mux mode: ALT3 mux port: PIXCLK of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE_ALT4_EIM_DATA6 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE: Select mux mode: ALT4 mux port: DATA6 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE_ALT5_GPIO3_IO11 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE: Select mux mode: ALT5 mux port: IO11 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE_ALT6_SRC_BOOT_CFG6 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG6 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA06
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SION: Force input path of pad LCD_DATA06 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA06_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07 - SW_MUX_CTL_PAD_LCD_DATA07 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07 - SW_MUX_CTL_PAD_LCD_DATA07 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data07
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data07_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data07_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_ADDR(x) ((uintptr_t)(x) + 0xE4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data07_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD_DATA07.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA7 of instance: LCD
 * - 011 - Select mux mode: ALT3 mux port: MCLK of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DATA7 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO12 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG7 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE_ALT0_LCD_DATA7 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE: Select mux mode: ALT0 mux port: DATA7 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE_ALT3_CSI_MCLK (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE: Select mux mode: ALT3 mux port: MCLK of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE_ALT4_EIM_DATA7 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE: Select mux mode: ALT4 mux port: DATA7 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE_ALT5_GPIO3_IO12 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE: Select mux mode: ALT5 mux port: IO12 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE_ALT6_SRC_BOOT_CFG7 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG7 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA07
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SION: Force input path of pad LCD_DATA07 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA07_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08 - SW_MUX_CTL_PAD_LCD_DATA08 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08 - SW_MUX_CTL_PAD_LCD_DATA08 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data08
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data08_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data08_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_ADDR(x) ((uintptr_t)(x) + 0xE8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data08_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD_DATA08.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA8 of instance: LCD
 * - 011 - Select mux mode: ALT3 mux port: DATA9 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DATA8 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO13 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG8 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE_ALT0_LCD_DATA8 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE: Select mux mode: ALT0 mux port: DATA8 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE_ALT3_CSI_DATA9 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE: Select mux mode: ALT3 mux port: DATA9 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE_ALT4_EIM_DATA8 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE: Select mux mode: ALT4 mux port: DATA8 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE_ALT5_GPIO3_IO13 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE: Select mux mode: ALT5 mux port: IO13 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE_ALT6_SRC_BOOT_CFG8 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG8 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA08
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SION: Force input path of pad LCD_DATA08 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA08_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09 - SW_MUX_CTL_PAD_LCD_DATA09 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09 - SW_MUX_CTL_PAD_LCD_DATA09 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data09
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data09_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data09_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_ADDR(x) ((uintptr_t)(x) + 0xECU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data09_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD_DATA09.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA9 of instance: LCD
 * - 011 - Select mux mode: ALT3 mux port: DATA8 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DATA9 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO14 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG9 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE_ALT0_LCD_DATA9 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE: Select mux mode: ALT0 mux port: DATA9 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE_ALT3_CSI_DATA8 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE: Select mux mode: ALT3 mux port: DATA8 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE_ALT4_EIM_DATA9 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE: Select mux mode: ALT4 mux port: DATA9 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE_ALT5_GPIO3_IO14 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE: Select mux mode: ALT5 mux port: IO14 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE_ALT6_SRC_BOOT_CFG9 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG9 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA09
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SION: Force input path of pad LCD_DATA09 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA09_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10 - SW_MUX_CTL_PAD_LCD_DATA10 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10 - SW_MUX_CTL_PAD_LCD_DATA10 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data10
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data10_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data10_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_ADDR(x) ((uintptr_t)(x) + 0xF0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data10_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD_DATA10.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA10 of instance: LCD
 * - 011 - Select mux mode: ALT3 mux port: DATA7 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DATA10 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO15 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG10 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE_ALT0_LCD_DATA10 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE: Select mux mode: ALT0 mux port: DATA10 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE_ALT3_CSI_DATA7 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE: Select mux mode: ALT3 mux port: DATA7 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE_ALT4_EIM_DATA10 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE: Select mux mode: ALT4 mux port: DATA10 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE_ALT5_GPIO3_IO15 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE: Select mux mode: ALT5 mux port: IO15 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE_ALT6_SRC_BOOT_CFG10 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG10 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA10
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SION: Force input path of pad LCD_DATA10 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA10_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11 - SW_MUX_CTL_PAD_LCD_DATA11 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11 - SW_MUX_CTL_PAD_LCD_DATA11 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data11
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data11_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data11_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_ADDR(x) ((uintptr_t)(x) + 0xF4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data11_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD_DATA11.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA11 of instance: LCD
 * - 011 - Select mux mode: ALT3 mux port: DATA6 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DATA11 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO16 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG11 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE_ALT0_LCD_DATA11 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE: Select mux mode: ALT0 mux port: DATA11 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE_ALT3_CSI_DATA6 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE: Select mux mode: ALT3 mux port: DATA6 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE_ALT4_EIM_DATA11 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE: Select mux mode: ALT4 mux port: DATA11 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE_ALT5_GPIO3_IO16 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE: Select mux mode: ALT5 mux port: IO16 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE_ALT6_SRC_BOOT_CFG11 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG11 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA11
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SION: Force input path of pad LCD_DATA11 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA11_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12 - SW_MUX_CTL_PAD_LCD_DATA12 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12 - SW_MUX_CTL_PAD_LCD_DATA12 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data12
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data12_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data12_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_ADDR(x) ((uintptr_t)(x) + 0xF8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data12_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD_DATA12.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA12 of instance: LCD
 * - 011 - Select mux mode: ALT3 mux port: DATA5 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DATA12 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO17 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG12 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE_ALT0_LCD_DATA12 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE: Select mux mode: ALT0 mux port: DATA12 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE_ALT3_CSI_DATA5 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE: Select mux mode: ALT3 mux port: DATA5 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE_ALT4_EIM_DATA12 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE: Select mux mode: ALT4 mux port: DATA12 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE_ALT5_GPIO3_IO17 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE: Select mux mode: ALT5 mux port: IO17 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE_ALT6_SRC_BOOT_CFG12 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG12 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA12
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SION: Force input path of pad LCD_DATA12 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA12_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13 - SW_MUX_CTL_PAD_LCD_DATA13 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13 - SW_MUX_CTL_PAD_LCD_DATA13 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data13
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data13_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data13_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_ADDR(x) ((uintptr_t)(x) + 0xFCU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data13_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD_DATA13.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA13 of instance: LCD
 * - 011 - Select mux mode: ALT3 mux port: DATA4 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DATA13 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO18 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG13 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE_ALT0_LCD_DATA13 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE: Select mux mode: ALT0 mux port: DATA13 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE_ALT3_CSI_DATA4 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE: Select mux mode: ALT3 mux port: DATA4 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE_ALT4_EIM_DATA13 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE: Select mux mode: ALT4 mux port: DATA13 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE_ALT5_GPIO3_IO18 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE: Select mux mode: ALT5 mux port: IO18 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE_ALT6_SRC_BOOT_CFG13 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG13 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA13
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SION: Force input path of pad LCD_DATA13 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA13_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14 - SW_MUX_CTL_PAD_LCD_DATA14 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14 - SW_MUX_CTL_PAD_LCD_DATA14 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data14
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data14_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data14_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_ADDR(x) ((uintptr_t)(x) + 0x100U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data14_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD_DATA14.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA14 of instance: LCD
 * - 011 - Select mux mode: ALT3 mux port: DATA3 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DATA14 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO19 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG14 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE_ALT0_LCD_DATA14 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE: Select mux mode: ALT0 mux port: DATA14 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE_ALT3_CSI_DATA3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE: Select mux mode: ALT3 mux port: DATA3 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE_ALT4_EIM_DATA14 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE: Select mux mode: ALT4 mux port: DATA14 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE_ALT5_GPIO3_IO19 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE: Select mux mode: ALT5 mux port: IO19 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE_ALT6_SRC_BOOT_CFG14 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG14 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA14
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SION: Force input path of pad LCD_DATA14 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA14_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15 - SW_MUX_CTL_PAD_LCD_DATA15 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15 - SW_MUX_CTL_PAD_LCD_DATA15 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data15
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data15_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data15_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_ADDR(x) ((uintptr_t)(x) + 0x104U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data15_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD_DATA15.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA15 of instance: LCD
 * - 011 - Select mux mode: ALT3 mux port: DATA2 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DATA15 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO20 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG15 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE_ALT0_LCD_DATA15 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE: Select mux mode: ALT0 mux port: DATA15 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE_ALT3_CSI_DATA2 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE: Select mux mode: ALT3 mux port: DATA2 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE_ALT4_EIM_DATA15 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE: Select mux mode: ALT4 mux port: DATA15 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE_ALT5_GPIO3_IO20 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE: Select mux mode: ALT5 mux port: IO20 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE_ALT6_SRC_BOOT_CFG15 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG15 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA15
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SION: Force input path of pad LCD_DATA15 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA15_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16 - SW_MUX_CTL_PAD_LCD_DATA16 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16 - SW_MUX_CTL_PAD_LCD_DATA16 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data16
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data16_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data16_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_ADDR(x) ((uintptr_t)(x) + 0x108U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data16_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: LCD_DATA16.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA16 of instance: LCD
 * - 001 - Select mux mode: ALT1 mux port: CH4 of instance: FLEXTIMER1
 * - 011 - Select mux mode: ALT3 mux port: DATA1 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: CRE of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO21 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG16 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE_ALT0_LCD_DATA16 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE: Select mux mode: ALT0 mux port: DATA16 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE_ALT1_FLEXTIMER1_CH4 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE: Select mux mode: ALT1 mux port: CH4 of instance: FLEXTIMER1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE_ALT3_CSI_DATA1 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE: Select mux mode: ALT3 mux port: DATA1 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE_ALT4_EIM_CRE (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE: Select mux mode: ALT4 mux port: CRE of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE_ALT5_GPIO3_IO21 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE: Select mux mode: ALT5 mux port: IO21 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE_ALT6_SRC_BOOT_CFG16 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG16 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA16
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SION: Force input path of pad LCD_DATA16 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA16_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17 - SW_MUX_CTL_PAD_LCD_DATA17 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17 - SW_MUX_CTL_PAD_LCD_DATA17 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data17
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data17_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data17_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_ADDR(x) ((uintptr_t)(x) + 0x10CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data17_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: LCD_DATA17.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA17 of instance: LCD
 * - 001 - Select mux mode: ALT1 mux port: CH5 of instance: FLEXTIMER1
 * - 011 - Select mux mode: ALT3 mux port: DATA0 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: ACLK_FREERUN of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO22 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG17 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE_ALT0_LCD_DATA17 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE: Select mux mode: ALT0 mux port: DATA17 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE_ALT1_FLEXTIMER1_CH5 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE: Select mux mode: ALT1 mux port: CH5 of instance: FLEXTIMER1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE_ALT3_CSI_DATA0 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE: Select mux mode: ALT3 mux port: DATA0 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE_ALT4_EIM_ACLK_FREERUN (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE: Select mux mode: ALT4 mux port: ACLK_FREERUN of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE_ALT5_GPIO3_IO22 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE: Select mux mode: ALT5 mux port: IO22 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE_ALT6_SRC_BOOT_CFG17 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG17 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA17
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SION: Force input path of pad LCD_DATA17 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA17_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18 - SW_MUX_CTL_PAD_LCD_DATA18 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18 - SW_MUX_CTL_PAD_LCD_DATA18 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data18
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data18_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data18_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_ADDR(x) ((uintptr_t)(x) + 0x110U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data18_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: LCD_DATA18.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA18 of instance: LCD
 * - 001 - Select mux mode: ALT1 mux port: CH6 of instance: FLEXTIMER1
 * - 010 - Select mux mode: ALT2 mux port: EVENTO of instance: ARM_PLATFORM
 * - 011 - Select mux mode: ALT3 mux port: DATA15 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: CS2_B of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO23 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG18 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE_ALT0_LCD_DATA18 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE: Select mux mode: ALT0 mux port: DATA18 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE_ALT1_FLEXTIMER1_CH6 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE: Select mux mode: ALT1 mux port: CH6 of instance: FLEXTIMER1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE_ALT2_ARM_PLATFORM_EVENTO (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE: Select mux mode: ALT2 mux port: EVENTO of instance: ARM_PLATFORM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE_ALT3_CSI_DATA15 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE: Select mux mode: ALT3 mux port: DATA15 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE_ALT4_EIM_CS2_B (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE: Select mux mode: ALT4 mux port: CS2_B of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE_ALT5_GPIO3_IO23 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE: Select mux mode: ALT5 mux port: IO23 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE_ALT6_SRC_BOOT_CFG18 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG18 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA18
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SION: Force input path of pad LCD_DATA18 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA18_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19 - SW_MUX_CTL_PAD_LCD_DATA19 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19 - SW_MUX_CTL_PAD_LCD_DATA19 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data19
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data19_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data19_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_ADDR(x) ((uintptr_t)(x) + 0x114U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data19_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: LCD_DATA19.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA19 of instance: LCD
 * - 001 - Select mux mode: ALT1 mux port: CH7 of instance: FLEXTIMER1
 * - 011 - Select mux mode: ALT3 mux port: DATA14 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: CS3_B of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO24 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: BOOT_CFG19 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE_ALT0_LCD_DATA19 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE: Select mux mode: ALT0 mux port: DATA19 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE_ALT1_FLEXTIMER1_CH7 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE: Select mux mode: ALT1 mux port: CH7 of instance: FLEXTIMER1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE_ALT3_CSI_DATA14 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE: Select mux mode: ALT3 mux port: DATA14 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE_ALT4_EIM_CS3_B (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE: Select mux mode: ALT4 mux port: CS3_B of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE_ALT5_GPIO3_IO24 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE: Select mux mode: ALT5 mux port: IO24 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE_ALT6_SRC_BOOT_CFG19 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE: Select mux mode: ALT6 mux port: BOOT_CFG19 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA19
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SION: Force input path of pad LCD_DATA19 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA19_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20 - SW_MUX_CTL_PAD_LCD_DATA20 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20 - SW_MUX_CTL_PAD_LCD_DATA20 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data20
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data20_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data20_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_ADDR(x) ((uintptr_t)(x) + 0x118U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data20_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: LCD_DATA20.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA20 of instance: LCD
 * - 001 - Select mux mode: ALT1 mux port: CH4 of instance: FLEXTIMER2
 * - 010 - Select mux mode: ALT2 mux port: 1588_EVENT2_OUT of instance: ENET1
 * - 011 - Select mux mode: ALT3 mux port: DATA13 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: ADDR23 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO25 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: SCL of instance: I2C3
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE_ALT0_LCD_DATA20 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE: Select mux mode: ALT0 mux port: DATA20 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE_ALT1_FLEXTIMER2_CH4 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE: Select mux mode: ALT1 mux port: CH4 of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE_ALT2_ENET1_1588_EVENT2_OUT (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE: Select mux mode: ALT2 mux port: 1588_EVENT2_OUT of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE_ALT3_CSI_DATA13 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE: Select mux mode: ALT3 mux port: DATA13 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE_ALT4_EIM_ADDR23 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE: Select mux mode: ALT4 mux port: ADDR23 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE_ALT5_GPIO3_IO25 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE: Select mux mode: ALT5 mux port: IO25 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE_ALT6_I2C3_SCL (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE: Select mux mode: ALT6 mux port: SCL of instance: I2C3 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA20
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SION: Force input path of pad LCD_DATA20 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA20_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21 - SW_MUX_CTL_PAD_LCD_DATA21 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21 - SW_MUX_CTL_PAD_LCD_DATA21 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data21
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data21_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data21_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_ADDR(x) ((uintptr_t)(x) + 0x11CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data21_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: LCD_DATA21.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA21 of instance: LCD
 * - 001 - Select mux mode: ALT1 mux port: CH5 of instance: FLEXTIMER2
 * - 010 - Select mux mode: ALT2 mux port: 1588_EVENT3_OUT of instance: ENET1
 * - 011 - Select mux mode: ALT3 mux port: DATA12 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: ADDR24 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO26 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: SDA of instance: I2C3
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE_ALT0_LCD_DATA21 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE: Select mux mode: ALT0 mux port: DATA21 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE_ALT1_FLEXTIMER2_CH5 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE: Select mux mode: ALT1 mux port: CH5 of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE_ALT2_ENET1_1588_EVENT3_OUT (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE: Select mux mode: ALT2 mux port: 1588_EVENT3_OUT of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE_ALT3_CSI_DATA12 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE: Select mux mode: ALT3 mux port: DATA12 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE_ALT4_EIM_ADDR24 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE: Select mux mode: ALT4 mux port: ADDR24 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE_ALT5_GPIO3_IO26 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE: Select mux mode: ALT5 mux port: IO26 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE_ALT6_I2C3_SDA (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE: Select mux mode: ALT6 mux port: SDA of instance: I2C3 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA21
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SION: Force input path of pad LCD_DATA21 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA21_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22 - SW_MUX_CTL_PAD_LCD_DATA22 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22 - SW_MUX_CTL_PAD_LCD_DATA22 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data22
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data22_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data22_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_ADDR(x) ((uintptr_t)(x) + 0x120U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data22_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: LCD_DATA22.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA22 of instance: LCD
 * - 001 - Select mux mode: ALT1 mux port: CH6 of instance: FLEXTIMER2
 * - 010 - Select mux mode: ALT2 mux port: 1588_EVENT2_OUT of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: DATA11 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: ADDR25 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO27 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: SCL of instance: I2C4
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE_ALT0_LCD_DATA22 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE: Select mux mode: ALT0 mux port: DATA22 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE_ALT1_FLEXTIMER2_CH6 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE: Select mux mode: ALT1 mux port: CH6 of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE_ALT2_ENET2_1588_EVENT2_OUT (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE: Select mux mode: ALT2 mux port: 1588_EVENT2_OUT of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE_ALT3_CSI_DATA11 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE: Select mux mode: ALT3 mux port: DATA11 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE_ALT4_EIM_ADDR25 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE: Select mux mode: ALT4 mux port: ADDR25 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE_ALT5_GPIO3_IO27 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE: Select mux mode: ALT5 mux port: IO27 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE_ALT6_I2C4_SCL (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE: Select mux mode: ALT6 mux port: SCL of instance: I2C4 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA22
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SION: Force input path of pad LCD_DATA22 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA22_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23 - SW_MUX_CTL_PAD_LCD_DATA23 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23 - SW_MUX_CTL_PAD_LCD_DATA23 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_lcd_data23
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_lcd_data23_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_lcd_data23_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_ADDR(x) ((uintptr_t)(x) + 0x124U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_lcd_data23_t *) HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: LCD_DATA23.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA23 of instance: LCD
 * - 001 - Select mux mode: ALT1 mux port: CH7 of instance: FLEXTIMER2
 * - 010 - Select mux mode: ALT2 mux port: 1588_EVENT3_OUT of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: DATA10 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: ADDR26 of instance: EIM
 * - 101 - Select mux mode: ALT5 mux port: IO28 of instance: GPIO3
 * - 110 - Select mux mode: ALT6 mux port: SDA of instance: I2C4
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE_ALT0_LCD_DATA23 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE: Select mux mode: ALT0 mux port: DATA23 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE_ALT1_FLEXTIMER2_CH7 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE: Select mux mode: ALT1 mux port: CH7 of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE_ALT2_ENET2_1588_EVENT3_OUT (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE: Select mux mode: ALT2 mux port: 1588_EVENT3_OUT of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE_ALT3_CSI_DATA10 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE: Select mux mode: ALT3 mux port: DATA10 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE_ALT4_EIM_ADDR26 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE: Select mux mode: ALT4 mux port: ADDR26 of instance: EIM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE_ALT5_GPIO3_IO28 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE: Select mux mode: ALT5 mux port: IO28 of instance: GPIO3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE_ALT6_I2C4_SDA (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE: Select mux mode: ALT6 mux port: SDA of instance: I2C4 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad LCD_DATA23
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SION: Force input path of pad LCD_DATA23 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_LCD_DATA23_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA - SW_MUX_CTL_PAD_UART1_RX_DATA SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA - SW_MUX_CTL_PAD_UART1_RX_DATA SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_uart1_rx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_uart1_rx_data_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_uart1_rx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_ADDR(x) ((uintptr_t)(x) + 0x128U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_uart1_rx_data_t *) HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: UART1_RX_DATA.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RX_DATA of instance: UART1
 * - 001 - Select mux mode: ALT1 mux port: SCL of instance: I2C1
 * - 010 - Select mux mode: ALT2 mux port: CCM_PMIC_READY of instance: CCM
 * - 011 - Select mux mode: ALT3 mux port: SS1 of instance: ECSPI1
 * - 100 - Select mux mode: ALT4 mux port: 1588_EVENT0_IN of instance: ENET2
 * - 101 - Select mux mode: ALT5 mux port: IO0 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: MDIO of instance: ENET1
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE_ALT0_UART1_RX_DATA (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE: Select mux mode: ALT0 mux port: RX_DATA of instance: UART1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE_ALT1_I2C1_SCL (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE: Select mux mode: ALT1 mux port: SCL of instance: I2C1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE_ALT2_CCM_PMIC_READY (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE: Select mux mode: ALT2 mux port: CCM_PMIC_READY of instance: CCM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE_ALT3_ECSPI1_SS1 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE: Select mux mode: ALT3 mux port: SS1 of instance: ECSPI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE_ALT4_ENET2_1588_EVENT0_IN (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE: Select mux mode: ALT4 mux port: 1588_EVENT0_IN of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE_ALT5_GPIO4_IO0 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE: Select mux mode: ALT5 mux port: IO0 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE_ALT6_ENET1_MDIO (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE: Select mux mode: ALT6 mux port: MDIO of instance: ENET1 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad UART1_RX_DATA
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SION: Force input path of pad UART1_RX_DATA */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_UART1_RX_DATA_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA - SW_MUX_CTL_PAD_UART1_TX_DATA SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA - SW_MUX_CTL_PAD_UART1_TX_DATA SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_uart1_tx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_uart1_tx_data_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_uart1_tx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_ADDR(x) ((uintptr_t)(x) + 0x12CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_uart1_tx_data_t *) HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: UART1_TX_DATA.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: TX_DATA of instance: UART1
 * - 001 - Select mux mode: ALT1 mux port: SDA of instance: I2C1
 * - 010 - Select mux mode: ALT2 mux port: MCLK of instance: SAI3
 * - 011 - Select mux mode: ALT3 mux port: SS2 of instance: ECSPI1
 * - 100 - Select mux mode: ALT4 mux port: 1588_EVENT0_OUT of instance: ENET2
 * - 101 - Select mux mode: ALT5 mux port: IO1 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: MDC of instance: ENET1
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE_ALT0_UART1_TX_DATA (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE: Select mux mode: ALT0 mux port: TX_DATA of instance: UART1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE_ALT1_I2C1_SDA (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE: Select mux mode: ALT1 mux port: SDA of instance: I2C1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE_ALT2_SAI3_MCLK (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE: Select mux mode: ALT2 mux port: MCLK of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE_ALT3_ECSPI1_SS2 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE: Select mux mode: ALT3 mux port: SS2 of instance: ECSPI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE_ALT4_ENET2_1588_EVENT0_OUT (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE: Select mux mode: ALT4 mux port: 1588_EVENT0_OUT of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE_ALT5_GPIO4_IO1 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE: Select mux mode: ALT5 mux port: IO1 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE_ALT6_ENET1_MDC (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE: Select mux mode: ALT6 mux port: MDC of instance: ENET1 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad UART1_TX_DATA
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SION: Force input path of pad UART1_TX_DATA */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_UART1_TX_DATA_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA - SW_MUX_CTL_PAD_UART2_RX_DATA SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA - SW_MUX_CTL_PAD_UART2_RX_DATA SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_uart2_rx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_uart2_rx_data_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_uart2_rx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_ADDR(x) ((uintptr_t)(x) + 0x130U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_uart2_rx_data_t *) HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: UART2_RX_DATA.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RX_DATA of instance: UART2
 * - 001 - Select mux mode: ALT1 mux port: SCL of instance: I2C2
 * - 010 - Select mux mode: ALT2 mux port: RX_BCLK of instance: SAI3
 * - 011 - Select mux mode: ALT3 mux port: SS3 of instance: ECSPI1
 * - 100 - Select mux mode: ALT4 mux port: 1588_EVENT1_IN of instance: ENET2
 * - 101 - Select mux mode: ALT5 mux port: IO2 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: MDIO of instance: ENET2
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE_ALT0_UART2_RX_DATA (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE: Select mux mode: ALT0 mux port: RX_DATA of instance: UART2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE_ALT1_I2C2_SCL (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE: Select mux mode: ALT1 mux port: SCL of instance: I2C2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE_ALT2_SAI3_RX_BCLK (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE: Select mux mode: ALT2 mux port: RX_BCLK of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE_ALT3_ECSPI1_SS3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE: Select mux mode: ALT3 mux port: SS3 of instance: ECSPI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE_ALT4_ENET2_1588_EVENT1_IN (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE: Select mux mode: ALT4 mux port: 1588_EVENT1_IN of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE_ALT5_GPIO4_IO2 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE: Select mux mode: ALT5 mux port: IO2 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE_ALT6_ENET2_MDIO (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE: Select mux mode: ALT6 mux port: MDIO of instance: ENET2 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad UART2_RX_DATA
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SION: Force input path of pad UART2_RX_DATA */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_UART2_RX_DATA_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA - SW_MUX_CTL_PAD_UART2_TX_DATA SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA - SW_MUX_CTL_PAD_UART2_TX_DATA SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_uart2_tx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_uart2_tx_data_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_uart2_tx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_ADDR(x) ((uintptr_t)(x) + 0x134U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_uart2_tx_data_t *) HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: UART2_TX_DATA.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: TX_DATA of instance: UART2
 * - 001 - Select mux mode: ALT1 mux port: SDA of instance: I2C2
 * - 010 - Select mux mode: ALT2 mux port: RX_DATA0 of instance: SAI3
 * - 011 - Select mux mode: ALT3 mux port: RDY of instance: ECSPI1
 * - 100 - Select mux mode: ALT4 mux port: 1588_EVENT1_OUT of instance: ENET2
 * - 101 - Select mux mode: ALT5 mux port: IO3 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: MDC of instance: ENET2
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE_ALT0_UART2_TX_DATA (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE: Select mux mode: ALT0 mux port: TX_DATA of instance: UART2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE_ALT1_I2C2_SDA (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE: Select mux mode: ALT1 mux port: SDA of instance: I2C2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE_ALT2_SAI3_RX_DATA0 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE: Select mux mode: ALT2 mux port: RX_DATA0 of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE_ALT3_ECSPI1_RDY (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE: Select mux mode: ALT3 mux port: RDY of instance: ECSPI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE_ALT4_ENET2_1588_EVENT1_OUT (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE: Select mux mode: ALT4 mux port: 1588_EVENT1_OUT of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE_ALT5_GPIO4_IO3 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE: Select mux mode: ALT5 mux port: IO3 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE_ALT6_ENET2_MDC (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE: Select mux mode: ALT6 mux port: MDC of instance: ENET2 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad UART2_TX_DATA
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SION: Force input path of pad UART2_TX_DATA */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_UART2_TX_DATA_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA - SW_MUX_CTL_PAD_UART3_RX_DATA SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA - SW_MUX_CTL_PAD_UART3_RX_DATA SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_uart3_rx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_uart3_rx_data_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_uart3_rx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_ADDR(x) ((uintptr_t)(x) + 0x138U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_uart3_rx_data_t *) HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: UART3_RX_DATA.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RX_DATA of instance: UART3
 * - 001 - Select mux mode: ALT1 mux port: OTG1_OC of instance: USB
 * - 010 - Select mux mode: ALT2 mux port: RX_SYNC of instance: SAI3
 * - 011 - Select mux mode: ALT3 mux port: MISO of instance: ECSPI1
 * - 100 - Select mux mode: ALT4 mux port: 1588_EVENT0_IN of instance: ENET1
 * - 101 - Select mux mode: ALT5 mux port: IO4 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: LCTL of instance: SD1
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE_ALT0_UART3_RX_DATA (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE: Select mux mode: ALT0 mux port: RX_DATA of instance: UART3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE_ALT1_USB_OTG1_OC (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE: Select mux mode: ALT1 mux port: OTG1_OC of instance: USB */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE_ALT2_SAI3_RX_SYNC (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE: Select mux mode: ALT2 mux port: RX_SYNC of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE_ALT3_ECSPI1_MISO (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE: Select mux mode: ALT3 mux port: MISO of instance: ECSPI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE_ALT4_ENET1_1588_EVENT0_IN (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE: Select mux mode: ALT4 mux port: 1588_EVENT0_IN of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE_ALT5_GPIO4_IO4 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE: Select mux mode: ALT5 mux port: IO4 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE_ALT6_SD1_LCTL (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE: Select mux mode: ALT6 mux port: LCTL of instance: SD1 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad UART3_RX_DATA
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SION: Force input path of pad UART3_RX_DATA */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_UART3_RX_DATA_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA - SW_MUX_CTL_PAD_UART3_TX_DATA SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA - SW_MUX_CTL_PAD_UART3_TX_DATA SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_uart3_tx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_uart3_tx_data_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_uart3_tx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_ADDR(x) ((uintptr_t)(x) + 0x13CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_uart3_tx_data_t *) HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: UART3_TX_DATA.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: TX_DATA of instance: UART3
 * - 001 - Select mux mode: ALT1 mux port: OTG1_PWR of instance: USB
 * - 010 - Select mux mode: ALT2 mux port: TX_BCLK of instance: SAI3
 * - 011 - Select mux mode: ALT3 mux port: MOSI of instance: ECSPI1
 * - 100 - Select mux mode: ALT4 mux port: 1588_EVENT0_OUT of instance: ENET1
 * - 101 - Select mux mode: ALT5 mux port: IO5 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: LCTL of instance: SD2
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE_ALT0_UART3_TX_DATA (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE: Select mux mode: ALT0 mux port: TX_DATA of instance: UART3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE_ALT1_USB_OTG1_PWR (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE: Select mux mode: ALT1 mux port: OTG1_PWR of instance: USB */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE_ALT2_SAI3_TX_BCLK (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE: Select mux mode: ALT2 mux port: TX_BCLK of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE_ALT3_ECSPI1_MOSI (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE: Select mux mode: ALT3 mux port: MOSI of instance: ECSPI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE_ALT4_ENET1_1588_EVENT0_OUT (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE: Select mux mode: ALT4 mux port: 1588_EVENT0_OUT of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE_ALT5_GPIO4_IO5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE: Select mux mode: ALT5 mux port: IO5 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE_ALT6_SD2_LCTL (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE: Select mux mode: ALT6 mux port: LCTL of instance: SD2 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad UART3_TX_DATA
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SION: Force input path of pad UART3_TX_DATA */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_UART3_TX_DATA_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B - SW_MUX_CTL_PAD_UART3_RTS_B SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B - SW_MUX_CTL_PAD_UART3_RTS_B SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_uart3_rts_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_uart3_rts_b_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_uart3_rts_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_ADDR(x) ((uintptr_t)(x) + 0x140U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_uart3_rts_b_t *) HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: UART3_RTS_B.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RTS_B of instance: UART3
 * - 001 - Select mux mode: ALT1 mux port: OTG2_OC of instance: USB
 * - 010 - Select mux mode: ALT2 mux port: TX_DATA0 of instance: SAI3
 * - 011 - Select mux mode: ALT3 mux port: SCLK of instance: ECSPI1
 * - 100 - Select mux mode: ALT4 mux port: 1588_EVENT1_IN of instance: ENET1
 * - 101 - Select mux mode: ALT5 mux port: IO6 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: LCTL of instance: SD3
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE_ALT0_UART3_RTS_B (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE: Select mux mode: ALT0 mux port: RTS_B of instance: UART3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE_ALT1_USB_OTG2_OC (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE: Select mux mode: ALT1 mux port: OTG2_OC of instance: USB */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE_ALT2_SAI3_TX_DATA0 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE: Select mux mode: ALT2 mux port: TX_DATA0 of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE_ALT3_ECSPI1_SCLK (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE: Select mux mode: ALT3 mux port: SCLK of instance: ECSPI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE_ALT4_ENET1_1588_EVENT1_IN (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE: Select mux mode: ALT4 mux port: 1588_EVENT1_IN of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE_ALT5_GPIO4_IO6 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE: Select mux mode: ALT5 mux port: IO6 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE_ALT6_SD3_LCTL (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE: Select mux mode: ALT6 mux port: LCTL of instance: SD3 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad UART3_RTS_B
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SION: Force input path of pad UART3_RTS_B */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_UART3_RTS_B_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B - SW_MUX_CTL_PAD_UART3_CTS_B SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B - SW_MUX_CTL_PAD_UART3_CTS_B SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_uart3_cts_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_uart3_cts_b_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_uart3_cts_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_ADDR(x) ((uintptr_t)(x) + 0x144U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_uart3_cts_b_t *) HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: UART3_CTS_B.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: CTS_B of instance: UART3
 * - 001 - Select mux mode: ALT1 mux port: OTG2_PWR of instance: USB
 * - 010 - Select mux mode: ALT2 mux port: TX_SYNC of instance: SAI3
 * - 011 - Select mux mode: ALT3 mux port: SS0 of instance: ECSPI1
 * - 100 - Select mux mode: ALT4 mux port: 1588_EVENT1_OUT of instance: ENET1
 * - 101 - Select mux mode: ALT5 mux port: IO7 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: VSELECT of instance: SD1
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE_ALT0_UART3_CTS_B (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE: Select mux mode: ALT0 mux port: CTS_B of instance: UART3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE_ALT1_USB_OTG2_PWR (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE: Select mux mode: ALT1 mux port: OTG2_PWR of instance: USB */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE_ALT2_SAI3_TX_SYNC (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE: Select mux mode: ALT2 mux port: TX_SYNC of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE_ALT3_ECSPI1_SS0 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE: Select mux mode: ALT3 mux port: SS0 of instance: ECSPI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE_ALT4_ENET1_1588_EVENT1_OUT (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE: Select mux mode: ALT4 mux port: 1588_EVENT1_OUT of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE_ALT5_GPIO4_IO7 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE: Select mux mode: ALT5 mux port: IO7 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE_ALT6_SD1_VSELECT (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE: Select mux mode: ALT6 mux port: VSELECT of instance: SD1 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad UART3_CTS_B
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SION: Force input path of pad UART3_CTS_B */
#define BV_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_UART3_CTS_B_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL - SW_MUX_CTL_PAD_I2C1_SCL SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL - SW_MUX_CTL_PAD_I2C1_SCL SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_i2c1_scl
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_i2c1_scl_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_i2c1_scl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_ADDR(x) ((uintptr_t)(x) + 0x148U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_i2c1_scl_t *) HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: I2C1_SCL.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SCL of instance: I2C1
 * - 001 - Select mux mode: ALT1 mux port: CTS_B of instance: UART4
 * - 010 - Select mux mode: ALT2 mux port: RX of instance: FLEXCAN1
 * - 011 - Select mux mode: ALT3 mux port: MISO of instance: ECSPI3
 * - 101 - Select mux mode: ALT5 mux port: IO8 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: VSELECT of instance: SD2
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE_ALT0_I2C1_SCL (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE: Select mux mode: ALT0 mux port: SCL of instance: I2C1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE_ALT1_UART4_CTS_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE: Select mux mode: ALT1 mux port: CTS_B of instance: UART4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE_ALT2_FLEXCAN1_RX (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE: Select mux mode: ALT2 mux port: RX of instance: FLEXCAN1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE_ALT3_ECSPI3_MISO (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE: Select mux mode: ALT3 mux port: MISO of instance: ECSPI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE_ALT5_GPIO4_IO8 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE: Select mux mode: ALT5 mux port: IO8 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE_ALT6_SD2_VSELECT (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE: Select mux mode: ALT6 mux port: VSELECT of instance: SD2 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad I2C1_SCL
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION: Force input path of pad I2C1_SCL */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_I2C1_SCL_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA - SW_MUX_CTL_PAD_I2C1_SDA SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA - SW_MUX_CTL_PAD_I2C1_SDA SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_i2c1_sda
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_i2c1_sda_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_i2c1_sda_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_ADDR(x) ((uintptr_t)(x) + 0x14CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_i2c1_sda_t *) HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: I2C1_SDA.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SDA of instance: I2C1
 * - 001 - Select mux mode: ALT1 mux port: RTS_B of instance: UART4
 * - 010 - Select mux mode: ALT2 mux port: TX of instance: FLEXCAN1
 * - 011 - Select mux mode: ALT3 mux port: MOSI of instance: ECSPI3
 * - 100 - Select mux mode: ALT4 mux port: ENET1_REF_CLK of instance: ENET1
 * - 101 - Select mux mode: ALT5 mux port: IO9 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: VSELECT of instance: SD3
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE_ALT0_I2C1_SDA (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE: Select mux mode: ALT0 mux port: SDA of instance: I2C1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE_ALT1_UART4_RTS_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE: Select mux mode: ALT1 mux port: RTS_B of instance: UART4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE_ALT2_FLEXCAN1_TX (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE: Select mux mode: ALT2 mux port: TX of instance: FLEXCAN1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE_ALT3_ECSPI3_MOSI (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE: Select mux mode: ALT3 mux port: MOSI of instance: ECSPI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE_ALT4_CCM_ENET1_REF_CLK (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE: Select mux mode: ALT4 mux port: ENET1_REF_CLK of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE_ALT5_GPIO4_IO9 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE: Select mux mode: ALT5 mux port: IO9 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE_ALT6_SD3_VSELECT (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE: Select mux mode: ALT6 mux port: VSELECT of instance: SD3 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad I2C1_SDA
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION: Force input path of pad I2C1_SDA */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_I2C1_SDA_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL - SW_MUX_CTL_PAD_I2C2_SCL SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL - SW_MUX_CTL_PAD_I2C2_SCL SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_i2c2_scl
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_i2c2_scl_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_i2c2_scl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_ADDR(x) ((uintptr_t)(x) + 0x150U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_i2c2_scl_t *) HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: I2C2_SCL.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SCL of instance: I2C2
 * - 001 - Select mux mode: ALT1 mux port: RX_DATA of instance: UART4
 * - 010 - Select mux mode: ALT2 mux port: WDOG_B of instance: WDOG3
 * - 011 - Select mux mode: ALT3 mux port: SCLK of instance: ECSPI3
 * - 100 - Select mux mode: ALT4 mux port: ENET2_REF_CLK of instance: ENET2
 * - 101 - Select mux mode: ALT5 mux port: IO10 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: CD_B of instance: SD3
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE_ALT0_I2C2_SCL (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE: Select mux mode: ALT0 mux port: SCL of instance: I2C2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE_ALT1_UART4_RX_DATA (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE: Select mux mode: ALT1 mux port: RX_DATA of instance: UART4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE_ALT2_WDOG3_WDOG_B (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE: Select mux mode: ALT2 mux port: WDOG_B of instance: WDOG3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE_ALT3_ECSPI3_SCLK (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE: Select mux mode: ALT3 mux port: SCLK of instance: ECSPI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE_ALT4_CCM_ENET2_REF_CLK (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE: Select mux mode: ALT4 mux port: ENET2_REF_CLK of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE_ALT5_GPIO4_IO10 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE: Select mux mode: ALT5 mux port: IO10 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE_ALT6_SD3_CD_B (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE: Select mux mode: ALT6 mux port: CD_B of instance: SD3 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad I2C2_SCL
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SION: Force input path of pad I2C2_SCL */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_I2C2_SCL_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA - SW_MUX_CTL_PAD_I2C2_SDA SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA - SW_MUX_CTL_PAD_I2C2_SDA SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_i2c2_sda
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_i2c2_sda_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_i2c2_sda_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_ADDR(x) ((uintptr_t)(x) + 0x154U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_i2c2_sda_t *) HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: I2C2_SDA.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SDA of instance: I2C2
 * - 001 - Select mux mode: ALT1 mux port: TX_DATA of instance: UART4
 * - 010 - Select mux mode: ALT2 mux port: WDOG_RST_B_DEB of instance: WDOG3
 * - 011 - Select mux mode: ALT3 mux port: SS0 of instance: ECSPI3
 * - 100 - Select mux mode: ALT4 mux port: ENET_PHY_REF_CLK of instance: CCM
 * - 101 - Select mux mode: ALT5 mux port: IO11 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: WP of instance: SD3
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE_ALT0_I2C2_SDA (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE: Select mux mode: ALT0 mux port: SDA of instance: I2C2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE_ALT1_UART4_TX_DATA (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE: Select mux mode: ALT1 mux port: TX_DATA of instance: UART4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE_ALT2_WDOG3_WDOG_RST_B_DEB (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE: Select mux mode: ALT2 mux port: WDOG_RST_B_DEB of instance: WDOG3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE_ALT3_ECSPI3_SS0 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE: Select mux mode: ALT3 mux port: SS0 of instance: ECSPI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE_ALT4_CCM_ENET_PHY_REF_CLK (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE: Select mux mode: ALT4 mux port: ENET_PHY_REF_CLK of instance: CCM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE_ALT5_GPIO4_IO11 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE: Select mux mode: ALT5 mux port: IO11 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE_ALT6_SD3_WP (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE: Select mux mode: ALT6 mux port: WP of instance: SD3 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad I2C2_SDA
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SION: Force input path of pad I2C2_SDA */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_I2C2_SDA_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL - SW_MUX_CTL_PAD_I2C3_SCL SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL - SW_MUX_CTL_PAD_I2C3_SCL SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_i2c3_scl
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_i2c3_scl_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_i2c3_scl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_ADDR(x) ((uintptr_t)(x) + 0x158U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_i2c3_scl_t *) HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: I2C3_SCL.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SCL of instance: I2C3
 * - 001 - Select mux mode: ALT1 mux port: CTS_B of instance: UART5
 * - 010 - Select mux mode: ALT2 mux port: RX of instance: FLEXCAN2
 * - 011 - Select mux mode: ALT3 mux port: VSYNC of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: EXT_EVENT0 of instance: SDMA
 * - 101 - Select mux mode: ALT5 mux port: IO12 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: BDR0 of instance: EPDC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE_ALT0_I2C3_SCL (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE: Select mux mode: ALT0 mux port: SCL of instance: I2C3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE_ALT1_UART5_CTS_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE: Select mux mode: ALT1 mux port: CTS_B of instance: UART5 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE_ALT2_FLEXCAN2_RX (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE: Select mux mode: ALT2 mux port: RX of instance: FLEXCAN2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE_ALT3_CSI_VSYNC (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE: Select mux mode: ALT3 mux port: VSYNC of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE_ALT4_SDMA_EXT_EVENT0 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE: Select mux mode: ALT4 mux port: EXT_EVENT0 of instance: SDMA */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE_ALT5_GPIO4_IO12 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE: Select mux mode: ALT5 mux port: IO12 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE_ALT6_EPDC_BDR0 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE: Select mux mode: ALT6 mux port: BDR0 of instance: EPDC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad I2C3_SCL
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SION: Force input path of pad I2C3_SCL */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_I2C3_SCL_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA - SW_MUX_CTL_PAD_I2C3_SDA SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA - SW_MUX_CTL_PAD_I2C3_SDA SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_i2c3_sda
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_i2c3_sda_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_i2c3_sda_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_ADDR(x) ((uintptr_t)(x) + 0x15CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_i2c3_sda_t *) HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: I2C3_SDA.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SDA of instance: I2C3
 * - 001 - Select mux mode: ALT1 mux port: RTS_B of instance: UART5
 * - 010 - Select mux mode: ALT2 mux port: TX of instance: FLEXCAN2
 * - 011 - Select mux mode: ALT3 mux port: HSYNC of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: EXT_EVENT1 of instance: SDMA
 * - 101 - Select mux mode: ALT5 mux port: IO13 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: BDR1 of instance: EPDC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE_ALT0_I2C3_SDA (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE: Select mux mode: ALT0 mux port: SDA of instance: I2C3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE_ALT1_UART5_RTS_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE: Select mux mode: ALT1 mux port: RTS_B of instance: UART5 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE_ALT2_FLEXCAN2_TX (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE: Select mux mode: ALT2 mux port: TX of instance: FLEXCAN2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE_ALT3_CSI_HSYNC (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE: Select mux mode: ALT3 mux port: HSYNC of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE_ALT4_SDMA_EXT_EVENT1 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE: Select mux mode: ALT4 mux port: EXT_EVENT1 of instance: SDMA */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE_ALT5_GPIO4_IO13 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE: Select mux mode: ALT5 mux port: IO13 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE_ALT6_EPDC_BDR1 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE: Select mux mode: ALT6 mux port: BDR1 of instance: EPDC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad I2C3_SDA
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SION: Force input path of pad I2C3_SDA */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_I2C3_SDA_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL - SW_MUX_CTL_PAD_I2C4_SCL SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL - SW_MUX_CTL_PAD_I2C4_SCL SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_i2c4_scl
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_i2c4_scl_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_i2c4_scl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_ADDR(x) ((uintptr_t)(x) + 0x160U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_i2c4_scl_t *) HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: I2C4_SCL.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SCL of instance: I2C4
 * - 001 - Select mux mode: ALT1 mux port: RX_DATA of instance: UART5
 * - 010 - Select mux mode: ALT2 mux port: WDOG_B of instance: WDOG4
 * - 011 - Select mux mode: ALT3 mux port: PIXCLK of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: OTG1_ID of instance: USB
 * - 101 - Select mux mode: ALT5 mux port: IO14 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: VCOM0 of instance: EPDC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE_ALT0_I2C4_SCL (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE: Select mux mode: ALT0 mux port: SCL of instance: I2C4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE_ALT1_UART5_RX_DATA (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE: Select mux mode: ALT1 mux port: RX_DATA of instance: UART5 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE_ALT2_WDOG4_WDOG_B (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE: Select mux mode: ALT2 mux port: WDOG_B of instance: WDOG4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE_ALT3_CSI_PIXCLK (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE: Select mux mode: ALT3 mux port: PIXCLK of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE_ALT4_USB_OTG1_ID (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE: Select mux mode: ALT4 mux port: OTG1_ID of instance: USB */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE_ALT5_GPIO4_IO14 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE: Select mux mode: ALT5 mux port: IO14 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE_ALT6_EPDC_VCOM0 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE: Select mux mode: ALT6 mux port: VCOM0 of instance: EPDC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad I2C4_SCL
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION: Force input path of pad I2C4_SCL */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_I2C4_SCL_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA - SW_MUX_CTL_PAD_I2C4_SDA SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA - SW_MUX_CTL_PAD_I2C4_SDA SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_i2c4_sda
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_i2c4_sda_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_i2c4_sda_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_ADDR(x) ((uintptr_t)(x) + 0x164U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_i2c4_sda_t *) HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: I2C4_SDA.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SDA of instance: I2C4
 * - 001 - Select mux mode: ALT1 mux port: TX_DATA of instance: UART5
 * - 010 - Select mux mode: ALT2 mux port: WDOG_RST_B_DEB of instance: WDOG4
 * - 011 - Select mux mode: ALT3 mux port: MCLK of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: OTG2_ID of instance: USB
 * - 101 - Select mux mode: ALT5 mux port: IO15 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: VCOM1 of instance: EPDC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE_ALT0_I2C4_SDA (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE: Select mux mode: ALT0 mux port: SDA of instance: I2C4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE_ALT1_UART5_TX_DATA (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE: Select mux mode: ALT1 mux port: TX_DATA of instance: UART5 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE_ALT2_WDOG4_WDOG_RST_B_DEB (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE: Select mux mode: ALT2 mux port: WDOG_RST_B_DEB of instance: WDOG4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE_ALT3_CSI_MCLK (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE: Select mux mode: ALT3 mux port: MCLK of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE_ALT4_USB_OTG2_ID (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE: Select mux mode: ALT4 mux port: OTG2_ID of instance: USB */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE_ALT5_GPIO4_IO15 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE: Select mux mode: ALT5 mux port: IO15 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE_ALT6_EPDC_VCOM1 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE: Select mux mode: ALT6 mux port: VCOM1 of instance: EPDC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad I2C4_SDA
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION: Force input path of pad I2C4_SDA */
#define BV_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_I2C4_SDA_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK - SW_MUX_CTL_PAD_ECSPI1_SCLK SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK - SW_MUX_CTL_PAD_ECSPI1_SCLK SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_ecspi1_sclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_ecspi1_sclk_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_ecspi1_sclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_ADDR(x) ((uintptr_t)(x) + 0x168U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_ecspi1_sclk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: ECSPI1_SCLK.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SCLK of instance: ECSPI1
 * - 001 - Select mux mode: ALT1 mux port: RX_DATA of instance: UART6
 * - 010 - Select mux mode: ALT2 mux port: DATA4 of instance: SD2
 * - 011 - Select mux mode: ALT3 mux port: DATA2 of instance: CSI
 * - 101 - Select mux mode: ALT5 mux port: IO16 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: PWR_COM of instance: EPDC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE_ALT0_ECSPI1_SCLK (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE: Select mux mode: ALT0 mux port: SCLK of instance: ECSPI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE_ALT1_UART6_RX_DATA (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE: Select mux mode: ALT1 mux port: RX_DATA of instance: UART6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE_ALT2_SD2_DATA4 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE: Select mux mode: ALT2 mux port: DATA4 of instance: SD2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE_ALT3_CSI_DATA2 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE: Select mux mode: ALT3 mux port: DATA2 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE_ALT5_GPIO4_IO16 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE: Select mux mode: ALT5 mux port: IO16 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE_ALT6_EPDC_PWR_COM (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE: Select mux mode: ALT6 mux port: PWR_COM of instance: EPDC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ECSPI1_SCLK
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SION: Force input path of pad ECSPI1_SCLK */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SCLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI - SW_MUX_CTL_PAD_ECSPI1_MOSI SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI - SW_MUX_CTL_PAD_ECSPI1_MOSI SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_ecspi1_mosi
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_ecspi1_mosi_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_ecspi1_mosi_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_ADDR(x) ((uintptr_t)(x) + 0x16CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_ecspi1_mosi_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ECSPI1_MOSI.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: MOSI of instance: ECSPI1
 * - 001 - Select mux mode: ALT1 mux port: TX_DATA of instance: UART6
 * - 010 - Select mux mode: ALT2 mux port: DATA5 of instance: SD2
 * - 011 - Select mux mode: ALT3 mux port: DATA3 of instance: CSI
 * - 101 - Select mux mode: ALT5 mux port: IO17 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: PWR_STAT of instance: EPDC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE_ALT0_ECSPI1_MOSI (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE: Select mux mode: ALT0 mux port: MOSI of instance: ECSPI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE_ALT1_UART6_TX_DATA (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE: Select mux mode: ALT1 mux port: TX_DATA of instance: UART6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE_ALT2_SD2_DATA5 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE: Select mux mode: ALT2 mux port: DATA5 of instance: SD2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE_ALT3_CSI_DATA3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE: Select mux mode: ALT3 mux port: DATA3 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE_ALT5_GPIO4_IO17 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE: Select mux mode: ALT5 mux port: IO17 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE_ALT6_EPDC_PWR_STAT (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE: Select mux mode: ALT6 mux port: PWR_STAT of instance: EPDC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ECSPI1_MOSI
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SION: Force input path of pad ECSPI1_MOSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MOSI_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO - SW_MUX_CTL_PAD_ECSPI1_MISO SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO - SW_MUX_CTL_PAD_ECSPI1_MISO SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_ecspi1_miso
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_ecspi1_miso_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_ecspi1_miso_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_ADDR(x) ((uintptr_t)(x) + 0x170U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_ecspi1_miso_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ECSPI1_MISO.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: MISO of instance: ECSPI1
 * - 001 - Select mux mode: ALT1 mux port: RTS_B of instance: UART6
 * - 010 - Select mux mode: ALT2 mux port: DATA6 of instance: SD2
 * - 011 - Select mux mode: ALT3 mux port: DATA4 of instance: CSI
 * - 101 - Select mux mode: ALT5 mux port: IO18 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: PWR_IRQ of instance: EPDC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE_ALT0_ECSPI1_MISO (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE: Select mux mode: ALT0 mux port: MISO of instance: ECSPI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE_ALT1_UART6_RTS_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE: Select mux mode: ALT1 mux port: RTS_B of instance: UART6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE_ALT2_SD2_DATA6 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE: Select mux mode: ALT2 mux port: DATA6 of instance: SD2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE_ALT3_CSI_DATA4 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE: Select mux mode: ALT3 mux port: DATA4 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE_ALT5_GPIO4_IO18 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE: Select mux mode: ALT5 mux port: IO18 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE_ALT6_EPDC_PWR_IRQ (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE: Select mux mode: ALT6 mux port: PWR_IRQ of instance: EPDC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ECSPI1_MISO
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SION: Force input path of pad ECSPI1_MISO */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_MISO_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0 - SW_MUX_CTL_PAD_ECSPI1_SS0 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0 - SW_MUX_CTL_PAD_ECSPI1_SS0 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_ecspi1_ss0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_ecspi1_ss0_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_ecspi1_ss0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_ADDR(x) ((uintptr_t)(x) + 0x174U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_ecspi1_ss0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ECSPI1_SS0.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SS0 of instance: ECSPI1
 * - 001 - Select mux mode: ALT1 mux port: CTS_B of instance: UART6
 * - 010 - Select mux mode: ALT2 mux port: DATA7 of instance: SD2
 * - 011 - Select mux mode: ALT3 mux port: DATA5 of instance: CSI
 * - 101 - Select mux mode: ALT5 mux port: IO19 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: PWR_CTRL3 of instance: EPDC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE_ALT0_ECSPI1_SS0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE: Select mux mode: ALT0 mux port: SS0 of instance: ECSPI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE_ALT1_UART6_CTS_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE: Select mux mode: ALT1 mux port: CTS_B of instance: UART6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE_ALT2_SD2_DATA7 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE: Select mux mode: ALT2 mux port: DATA7 of instance: SD2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE_ALT3_CSI_DATA5 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE: Select mux mode: ALT3 mux port: DATA5 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE_ALT5_GPIO4_IO19 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE: Select mux mode: ALT5 mux port: IO19 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE_ALT6_EPDC_PWR_CTRL3 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE: Select mux mode: ALT6 mux port: PWR_CTRL3 of instance: EPDC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ECSPI1_SS0
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SION: Force input path of pad ECSPI1_SS0 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI1_SS0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK - SW_MUX_CTL_PAD_ECSPI2_SCLK SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK - SW_MUX_CTL_PAD_ECSPI2_SCLK SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_ecspi2_sclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_ecspi2_sclk_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_ecspi2_sclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_ADDR(x) ((uintptr_t)(x) + 0x178U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_ecspi2_sclk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ECSPI2_SCLK.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SCLK of instance: ECSPI2
 * - 001 - Select mux mode: ALT1 mux port: RX_DATA of instance: UART7
 * - 010 - Select mux mode: ALT2 mux port: DATA4 of instance: SD1
 * - 011 - Select mux mode: ALT3 mux port: DATA6 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DATA13 of instance: LCD
 * - 101 - Select mux mode: ALT5 mux port: IO20 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: PWR_CTRL0 of instance: EPDC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE_ALT0_ECSPI2_SCLK (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE: Select mux mode: ALT0 mux port: SCLK of instance: ECSPI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE_ALT1_UART7_RX_DATA (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE: Select mux mode: ALT1 mux port: RX_DATA of instance: UART7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE_ALT2_SD1_DATA4 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE: Select mux mode: ALT2 mux port: DATA4 of instance: SD1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE_ALT3_CSI_DATA6 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE: Select mux mode: ALT3 mux port: DATA6 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE_ALT4_LCD_DATA13 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE: Select mux mode: ALT4 mux port: DATA13 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE_ALT5_GPIO4_IO20 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE: Select mux mode: ALT5 mux port: IO20 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE_ALT6_EPDC_PWR_CTRL0 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE: Select mux mode: ALT6 mux port: PWR_CTRL0 of instance: EPDC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ECSPI2_SCLK
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SION: Force input path of pad ECSPI2_SCLK */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SCLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI - SW_MUX_CTL_PAD_ECSPI2_MOSI SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI - SW_MUX_CTL_PAD_ECSPI2_MOSI SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_ecspi2_mosi
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_ecspi2_mosi_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_ecspi2_mosi_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_ADDR(x) ((uintptr_t)(x) + 0x17CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_ecspi2_mosi_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ECSPI2_MOSI.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: MOSI of instance: ECSPI2
 * - 001 - Select mux mode: ALT1 mux port: TX_DATA of instance: UART7
 * - 010 - Select mux mode: ALT2 mux port: DATA5 of instance: SD1
 * - 011 - Select mux mode: ALT3 mux port: DATA7 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DATA14 of instance: LCD
 * - 101 - Select mux mode: ALT5 mux port: IO21 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: PWR_CTRL1 of instance: EPDC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE_ALT0_ECSPI2_MOSI (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE: Select mux mode: ALT0 mux port: MOSI of instance: ECSPI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE_ALT1_UART7_TX_DATA (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE: Select mux mode: ALT1 mux port: TX_DATA of instance: UART7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE_ALT2_SD1_DATA5 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE: Select mux mode: ALT2 mux port: DATA5 of instance: SD1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE_ALT3_CSI_DATA7 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE: Select mux mode: ALT3 mux port: DATA7 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE_ALT4_LCD_DATA14 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE: Select mux mode: ALT4 mux port: DATA14 of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE_ALT5_GPIO4_IO21 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE: Select mux mode: ALT5 mux port: IO21 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE_ALT6_EPDC_PWR_CTRL1 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE: Select mux mode: ALT6 mux port: PWR_CTRL1 of instance: EPDC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ECSPI2_MOSI
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SION: Force input path of pad ECSPI2_MOSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MOSI_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO - SW_MUX_CTL_PAD_ECSPI2_MISO SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO - SW_MUX_CTL_PAD_ECSPI2_MISO SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_ecspi2_miso
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_ecspi2_miso_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_ecspi2_miso_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_ADDR(x) ((uintptr_t)(x) + 0x180U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_ecspi2_miso_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ECSPI2_MISO.
 *
 * Values:
 * - 101 - Select mux mode: ALT5 mux port: IO22 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: PWR_CTRL2 of instance: EPDC
 * - 000 - Select mux mode: ALT0 mux port: MISO of instance: ECSPI2
 * - 001 - Select mux mode: ALT1 mux port: RTS_B of instance: UART7
 * - 010 - Select mux mode: ALT2 mux port: DATA6 of instance: SD1
 * - 011 - Select mux mode: ALT3 mux port: DATA8 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: DATA15 of instance: LCD
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE_ALT5_GPIO4_IO22 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE: Select mux mode: ALT5 mux port: IO22 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE_ALT6_EPDC_PWR_CTRL2 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE: Select mux mode: ALT6 mux port: PWR_CTRL2 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE_ALT0_ECSPI2_MISO (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE: Select mux mode: ALT0 mux port: MISO of instance: ECSPI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE_ALT1_UART7_RTS_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE: Select mux mode: ALT1 mux port: RTS_B of instance: UART7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE_ALT2_SD1_DATA6 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE: Select mux mode: ALT2 mux port: DATA6 of instance: SD1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE_ALT3_CSI_DATA8 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE: Select mux mode: ALT3 mux port: DATA8 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE_ALT4_LCD_DATA15 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE: Select mux mode: ALT4 mux port: DATA15 of instance: LCD */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ECSPI2_MISO
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SION: Force input path of pad ECSPI2_MISO */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_MISO_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0 - SW_MUX_CTL_PAD_ECSPI2_SS0 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0 - SW_MUX_CTL_PAD_ECSPI2_SS0 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_ecspi2_ss0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_ecspi2_ss0_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_ecspi2_ss0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_ADDR(x) ((uintptr_t)(x) + 0x184U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_ecspi2_ss0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ECSPI2_SS0.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: SS0 of instance: ECSPI2
 * - 001 - Select mux mode: ALT1 mux port: CTS_B of instance: UART7
 * - 010 - Select mux mode: ALT2 mux port: DATA7 of instance: SD1
 * - 011 - Select mux mode: ALT3 mux port: DATA9 of instance: CSI
 * - 100 - Select mux mode: ALT4 mux port: RESET of instance: LCD
 * - 101 - Select mux mode: ALT5 mux port: IO23 of instance: GPIO4
 * - 110 - Select mux mode: ALT6 mux port: PWR_WAKE of instance: EPDC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE_ALT0_ECSPI2_SS0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE: Select mux mode: ALT0 mux port: SS0 of instance: ECSPI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE_ALT1_UART7_CTS_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE: Select mux mode: ALT1 mux port: CTS_B of instance: UART7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE_ALT2_SD1_DATA7 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE: Select mux mode: ALT2 mux port: DATA7 of instance: SD1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE_ALT3_CSI_DATA9 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE: Select mux mode: ALT3 mux port: DATA9 of instance: CSI */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE_ALT4_LCD_RESET (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE: Select mux mode: ALT4 mux port: RESET of instance: LCD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE_ALT5_GPIO4_IO23 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE: Select mux mode: ALT5 mux port: IO23 of instance: GPIO4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE_ALT6_EPDC_PWR_WAKE (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE: Select mux mode: ALT6 mux port: PWR_WAKE of instance: EPDC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ECSPI2_SS0
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SION: Force input path of pad ECSPI2_SS0 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ECSPI2_SS0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B - SW_MUX_CTL_PAD_SD1_CD_B SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B - SW_MUX_CTL_PAD_SD1_CD_B SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd1_cd_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd1_cd_b_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd1_cd_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_ADDR(x) ((uintptr_t)(x) + 0x188U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd1_cd_b_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD1_CD_B.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: CD_B of instance: SD1
 * - 010 - Select mux mode: ALT2 mux port: RX_DATA of instance: UART6
 * - 011 - Select mux mode: ALT3 mux port: MISO of instance: ECSPI4
 * - 100 - Select mux mode: ALT4 mux port: CH0 of instance: FLEXTIMER1
 * - 101 - Select mux mode: ALT5 mux port: IO0 of instance: GPIO5
 * - 110 - Select mux mode: ALT6 mux port: CLKO1 of instance: CCM
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE_ALT0_SD1_CD_B (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE: Select mux mode: ALT0 mux port: CD_B of instance: SD1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE_ALT2_UART6_RX_DATA (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE: Select mux mode: ALT2 mux port: RX_DATA of instance: UART6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE_ALT3_ECSPI4_MISO (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE: Select mux mode: ALT3 mux port: MISO of instance: ECSPI4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE_ALT4_FLEXTIMER1_CH0 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE: Select mux mode: ALT4 mux port: CH0 of instance: FLEXTIMER1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE_ALT5_GPIO5_IO0 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE: Select mux mode: ALT5 mux port: IO0 of instance: GPIO5 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE_ALT6_CCM_CLKO1 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE: Select mux mode: ALT6 mux port: CLKO1 of instance: CCM */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD1_CD_B
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SION: Force input path of pad SD1_CD_B */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CD_B_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP - SW_MUX_CTL_PAD_SD1_WP SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP - SW_MUX_CTL_PAD_SD1_WP SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd1_wp
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd1_wp_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd1_wp_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD1_WP register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_ADDR(x) ((uintptr_t)(x) + 0x18CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd1_wp_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD1_WP bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_WP, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD1_WP.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: WP of instance: SD1
 * - 010 - Select mux mode: ALT2 mux port: TX_DATA of instance: UART6
 * - 011 - Select mux mode: ALT3 mux port: MOSI of instance: ECSPI4
 * - 100 - Select mux mode: ALT4 mux port: CH1 of instance: FLEXTIMER1
 * - 101 - Select mux mode: ALT5 mux port: IO1 of instance: GPIO5
 * - 110 - Select mux mode: ALT6 mux port: CLKO2 of instance: CCM
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE_ALT0_SD1_WP (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE: Select mux mode: ALT0 mux port: WP of instance: SD1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE_ALT2_UART6_TX_DATA (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE: Select mux mode: ALT2 mux port: TX_DATA of instance: UART6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE_ALT3_ECSPI4_MOSI (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE: Select mux mode: ALT3 mux port: MOSI of instance: ECSPI4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE_ALT4_FLEXTIMER1_CH1 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE: Select mux mode: ALT4 mux port: CH1 of instance: FLEXTIMER1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE_ALT5_GPIO5_IO1 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE: Select mux mode: ALT5 mux port: IO1 of instance: GPIO5 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE_ALT6_CCM_CLKO2 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE: Select mux mode: ALT6 mux port: CLKO2 of instance: CCM */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_WP, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD1_WP
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SION: Force input path of pad SD1_WP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_WP_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B - SW_MUX_CTL_PAD_SD1_RESET_B SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B - SW_MUX_CTL_PAD_SD1_RESET_B SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd1_reset_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd1_reset_b_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd1_reset_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_ADDR(x) ((uintptr_t)(x) + 0x190U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd1_reset_b_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: SD1_RESET_B.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RESET_B of instance: SD1
 * - 001 - Select mux mode: ALT1 mux port: MCLK of instance: SAI3
 * - 010 - Select mux mode: ALT2 mux port: RTS_B of instance: UART6
 * - 011 - Select mux mode: ALT3 mux port: SCLK of instance: ECSPI4
 * - 100 - Select mux mode: ALT4 mux port: CH2 of instance: FLEXTIMER1
 * - 101 - Select mux mode: ALT5 mux port: IO2 of instance: GPIO5
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE_ALT0_SD1_RESET_B (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE: Select mux mode: ALT0 mux port: RESET_B of instance: SD1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE_ALT1_SAI3_MCLK (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE: Select mux mode: ALT1 mux port: MCLK of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE_ALT2_UART6_RTS_B (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE: Select mux mode: ALT2 mux port: RTS_B of instance: UART6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE_ALT3_ECSPI4_SCLK (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE: Select mux mode: ALT3 mux port: SCLK of instance: ECSPI4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE_ALT4_FLEXTIMER1_CH2 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE: Select mux mode: ALT4 mux port: CH2 of instance: FLEXTIMER1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE_ALT5_GPIO5_IO2 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE: Select mux mode: ALT5 mux port: IO2 of instance: GPIO5 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD1_RESET_B
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SION: Force input path of pad SD1_RESET_B */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_RESET_B_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK - SW_MUX_CTL_PAD_SD1_CLK SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK - SW_MUX_CTL_PAD_SD1_CLK SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd1_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd1_clk_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd1_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD1_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_ADDR(x) ((uintptr_t)(x) + 0x194U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd1_clk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD1_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_CLK, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: SD1_CLK.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: CLK of instance: SD1
 * - 001 - Select mux mode: ALT1 mux port: RX_SYNC of instance: SAI3
 * - 010 - Select mux mode: ALT2 mux port: CTS_B of instance: UART6
 * - 011 - Select mux mode: ALT3 mux port: SS0 of instance: ECSPI4
 * - 100 - Select mux mode: ALT4 mux port: CH3 of instance: FLEXTIMER1
 * - 101 - Select mux mode: ALT5 mux port: IO3 of instance: GPIO5
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE_ALT0_SD1_CLK (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE: Select mux mode: ALT0 mux port: CLK of instance: SD1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE_ALT1_SAI3_RX_SYNC (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE: Select mux mode: ALT1 mux port: RX_SYNC of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE_ALT2_UART6_CTS_B (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE: Select mux mode: ALT2 mux port: CTS_B of instance: UART6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE_ALT3_ECSPI4_SS0 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE: Select mux mode: ALT3 mux port: SS0 of instance: ECSPI4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE_ALT4_FLEXTIMER1_CH3 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE: Select mux mode: ALT4 mux port: CH3 of instance: FLEXTIMER1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE_ALT5_GPIO5_IO3 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE: Select mux mode: ALT5 mux port: IO3 of instance: GPIO5 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_CLK, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD1_CLK
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION: Force input path of pad SD1_CLK */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD - SW_MUX_CTL_PAD_SD1_CMD SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD - SW_MUX_CTL_PAD_SD1_CMD SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd1_cmd
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd1_cmd_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd1_cmd_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD1_CMD register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_ADDR(x) ((uintptr_t)(x) + 0x198U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd1_cmd_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD1_CMD bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_CMD, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD1_CMD.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: CMD of instance: SD1
 * - 001 - Select mux mode: ALT1 mux port: RX_BCLK of instance: SAI3
 * - 011 - Select mux mode: ALT3 mux port: SS1 of instance: ECSPI4
 * - 100 - Select mux mode: ALT4 mux port: CH0 of instance: FLEXTIMER2
 * - 101 - Select mux mode: ALT5 mux port: IO4 of instance: GPIO5
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE_ALT0_SD1_CMD (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE: Select mux mode: ALT0 mux port: CMD of instance: SD1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE_ALT1_SAI3_RX_BCLK (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE: Select mux mode: ALT1 mux port: RX_BCLK of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE_ALT3_ECSPI4_SS1 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE: Select mux mode: ALT3 mux port: SS1 of instance: ECSPI4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE_ALT4_FLEXTIMER2_CH0 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE: Select mux mode: ALT4 mux port: CH0 of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE_ALT5_GPIO5_IO4 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE: Select mux mode: ALT5 mux port: IO4 of instance: GPIO5 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_CMD, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD1_CMD
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION: Force input path of pad SD1_CMD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_CMD_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0 - SW_MUX_CTL_PAD_SD1_DATA0 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0 - SW_MUX_CTL_PAD_SD1_DATA0 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd1_data0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd1_data0_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd1_data0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_ADDR(x) ((uintptr_t)(x) + 0x19CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd1_data0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: SD1_DATA0.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA0 of instance: SD1
 * - 001 - Select mux mode: ALT1 mux port: RX_DATA0 of instance: SAI3
 * - 010 - Select mux mode: ALT2 mux port: RX_DATA of instance: UART7
 * - 011 - Select mux mode: ALT3 mux port: SS2 of instance: ECSPI4
 * - 100 - Select mux mode: ALT4 mux port: CH1 of instance: FLEXTIMER2
 * - 101 - Select mux mode: ALT5 mux port: IO5 of instance: GPIO5
 * - 110 - Select mux mode: ALT6 mux port: EXT_CLK1 of instance: CCM
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE_ALT0_SD1_DATA0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE: Select mux mode: ALT0 mux port: DATA0 of instance: SD1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE_ALT1_SAI3_RX_DATA0 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE: Select mux mode: ALT1 mux port: RX_DATA0 of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE_ALT2_UART7_RX_DATA (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE: Select mux mode: ALT2 mux port: RX_DATA of instance: UART7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE_ALT3_ECSPI4_SS2 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE: Select mux mode: ALT3 mux port: SS2 of instance: ECSPI4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE_ALT4_FLEXTIMER2_CH1 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE: Select mux mode: ALT4 mux port: CH1 of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE_ALT5_GPIO5_IO5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE: Select mux mode: ALT5 mux port: IO5 of instance: GPIO5 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE_ALT6_CCM_EXT_CLK1 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE: Select mux mode: ALT6 mux port: EXT_CLK1 of instance: CCM */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD1_DATA0
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION: Force input path of pad SD1_DATA0 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1 - SW_MUX_CTL_PAD_SD1_DATA1 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1 - SW_MUX_CTL_PAD_SD1_DATA1 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd1_data1
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd1_data1_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd1_data1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_ADDR(x) ((uintptr_t)(x) + 0x1A0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd1_data1_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: SD1_DATA1.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA1 of instance: SD1
 * - 001 - Select mux mode: ALT1 mux port: TX_BCLK of instance: SAI3
 * - 010 - Select mux mode: ALT2 mux port: TX_DATA of instance: UART7
 * - 011 - Select mux mode: ALT3 mux port: SS3 of instance: ECSPI4
 * - 100 - Select mux mode: ALT4 mux port: CH2 of instance: FLEXTIMER2
 * - 101 - Select mux mode: ALT5 mux port: IO6 of instance: GPIO5
 * - 110 - Select mux mode: ALT6 mux port: EXT_CLK2 of instance: CCM
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE_ALT0_SD1_DATA1 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE: Select mux mode: ALT0 mux port: DATA1 of instance: SD1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE_ALT1_SAI3_TX_BCLK (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE: Select mux mode: ALT1 mux port: TX_BCLK of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE_ALT2_UART7_TX_DATA (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE: Select mux mode: ALT2 mux port: TX_DATA of instance: UART7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE_ALT3_ECSPI4_SS3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE: Select mux mode: ALT3 mux port: SS3 of instance: ECSPI4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE_ALT4_FLEXTIMER2_CH2 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE: Select mux mode: ALT4 mux port: CH2 of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE_ALT5_GPIO5_IO6 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE: Select mux mode: ALT5 mux port: IO6 of instance: GPIO5 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE_ALT6_CCM_EXT_CLK2 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE: Select mux mode: ALT6 mux port: EXT_CLK2 of instance: CCM */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD1_DATA1
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION: Force input path of pad SD1_DATA1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA1_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2 - SW_MUX_CTL_PAD_SD1_DATA2 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2 - SW_MUX_CTL_PAD_SD1_DATA2 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd1_data2
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd1_data2_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd1_data2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_ADDR(x) ((uintptr_t)(x) + 0x1A4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd1_data2_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: SD1_DATA2.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA2 of instance: SD1
 * - 001 - Select mux mode: ALT1 mux port: TX_SYNC of instance: SAI3
 * - 010 - Select mux mode: ALT2 mux port: CTS_B of instance: UART7
 * - 011 - Select mux mode: ALT3 mux port: RDY of instance: ECSPI4
 * - 100 - Select mux mode: ALT4 mux port: CH3 of instance: FLEXTIMER2
 * - 101 - Select mux mode: ALT5 mux port: IO7 of instance: GPIO5
 * - 110 - Select mux mode: ALT6 mux port: EXT_CLK3 of instance: CCM
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE_ALT0_SD1_DATA2 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE: Select mux mode: ALT0 mux port: DATA2 of instance: SD1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE_ALT1_SAI3_TX_SYNC (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE: Select mux mode: ALT1 mux port: TX_SYNC of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE_ALT2_UART7_CTS_B (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE: Select mux mode: ALT2 mux port: CTS_B of instance: UART7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE_ALT3_ECSPI4_RDY (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE: Select mux mode: ALT3 mux port: RDY of instance: ECSPI4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE_ALT4_FLEXTIMER2_CH3 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE: Select mux mode: ALT4 mux port: CH3 of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE_ALT5_GPIO5_IO7 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE: Select mux mode: ALT5 mux port: IO7 of instance: GPIO5 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE_ALT6_CCM_EXT_CLK3 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE: Select mux mode: ALT6 mux port: EXT_CLK3 of instance: CCM */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD1_DATA2
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION: Force input path of pad SD1_DATA2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA2_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3 - SW_MUX_CTL_PAD_SD1_DATA3 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3 - SW_MUX_CTL_PAD_SD1_DATA3 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd1_data3
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd1_data3_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd1_data3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_ADDR(x) ((uintptr_t)(x) + 0x1A8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd1_data3_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: SD1_DATA3.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA3 of instance: SD1
 * - 001 - Select mux mode: ALT1 mux port: TX_DATA0 of instance: SAI3
 * - 010 - Select mux mode: ALT2 mux port: RTS_B of instance: UART7
 * - 011 - Select mux mode: ALT3 mux port: SS1 of instance: ECSPI3
 * - 100 - Select mux mode: ALT4 mux port: PHA of instance: FLEXTIMER1
 * - 101 - Select mux mode: ALT5 mux port: IO8 of instance: GPIO5
 * - 110 - Select mux mode: ALT6 mux port: EXT_CLK4 of instance: CCM
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE_ALT0_SD1_DATA3 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE: Select mux mode: ALT0 mux port: DATA3 of instance: SD1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE_ALT1_SAI3_TX_DATA0 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE: Select mux mode: ALT1 mux port: TX_DATA0 of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE_ALT2_UART7_RTS_B (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE: Select mux mode: ALT2 mux port: RTS_B of instance: UART7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE_ALT3_ECSPI3_SS1 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE: Select mux mode: ALT3 mux port: SS1 of instance: ECSPI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE_ALT4_FLEXTIMER1_PHA (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE: Select mux mode: ALT4 mux port: PHA of instance: FLEXTIMER1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE_ALT5_GPIO5_IO8 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE: Select mux mode: ALT5 mux port: IO8 of instance: GPIO5 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE_ALT6_CCM_EXT_CLK4 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE: Select mux mode: ALT6 mux port: EXT_CLK4 of instance: CCM */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD1_DATA3
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION: Force input path of pad SD1_DATA3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD1_DATA3_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B - SW_MUX_CTL_PAD_SD2_CD_B SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B - SW_MUX_CTL_PAD_SD2_CD_B SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd2_cd_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd2_cd_b_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd2_cd_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_ADDR(x) ((uintptr_t)(x) + 0x1ACU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd2_cd_b_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: SD2_CD_B.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: CD_B of instance: SD2
 * - 001 - Select mux mode: ALT1 mux port: MDIO of instance: ENET1
 * - 010 - Select mux mode: ALT2 mux port: MDIO of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: SS2 of instance: ECSPI3
 * - 100 - Select mux mode: ALT4 mux port: PHB of instance: FLEXTIMER1
 * - 101 - Select mux mode: ALT5 mux port: IO9 of instance: GPIO5
 * - 110 - Select mux mode: ALT6 mux port: EXT_EVENT0 of instance: SDMA
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE_ALT0_SD2_CD_B (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE: Select mux mode: ALT0 mux port: CD_B of instance: SD2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE_ALT1_ENET1_MDIO (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE: Select mux mode: ALT1 mux port: MDIO of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE_ALT2_ENET2_MDIO (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE: Select mux mode: ALT2 mux port: MDIO of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE_ALT3_ECSPI3_SS2 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE: Select mux mode: ALT3 mux port: SS2 of instance: ECSPI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE_ALT4_FLEXTIMER1_PHB (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE: Select mux mode: ALT4 mux port: PHB of instance: FLEXTIMER1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE_ALT5_GPIO5_IO9 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE: Select mux mode: ALT5 mux port: IO9 of instance: GPIO5 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE_ALT6_SDMA_EXT_EVENT0 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE: Select mux mode: ALT6 mux port: EXT_EVENT0 of instance: SDMA */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD2_CD_B
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SION: Force input path of pad SD2_CD_B */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CD_B_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP - SW_MUX_CTL_PAD_SD2_WP SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP - SW_MUX_CTL_PAD_SD2_WP SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd2_wp
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd2_wp_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd2_wp_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD2_WP register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_ADDR(x) ((uintptr_t)(x) + 0x1B0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd2_wp_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD2_WP bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_WP, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: SD2_WP.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: WP of instance: SD2
 * - 001 - Select mux mode: ALT1 mux port: MDC of instance: ENET1
 * - 010 - Select mux mode: ALT2 mux port: MDC of instance: ENET2
 * - 011 - Select mux mode: ALT3 mux port: SS3 of instance: ECSPI3
 * - 100 - Select mux mode: ALT4 mux port: OTG1_ID of instance: USB
 * - 101 - Select mux mode: ALT5 mux port: IO10 of instance: GPIO5
 * - 110 - Select mux mode: ALT6 mux port: EXT_EVENT1 of instance: SDMA
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE_ALT0_SD2_WP (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE: Select mux mode: ALT0 mux port: WP of instance: SD2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE_ALT1_ENET1_MDC (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE: Select mux mode: ALT1 mux port: MDC of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE_ALT2_ENET2_MDC (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE: Select mux mode: ALT2 mux port: MDC of instance: ENET2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE_ALT3_ECSPI3_SS3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE: Select mux mode: ALT3 mux port: SS3 of instance: ECSPI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE_ALT4_USB_OTG1_ID (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE: Select mux mode: ALT4 mux port: OTG1_ID of instance: USB */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE_ALT5_GPIO5_IO10 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE: Select mux mode: ALT5 mux port: IO10 of instance: GPIO5 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE_ALT6_SDMA_EXT_EVENT1 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE: Select mux mode: ALT6 mux port: EXT_EVENT1 of instance: SDMA */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_WP, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD2_WP
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SION: Force input path of pad SD2_WP */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_WP_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B - SW_MUX_CTL_PAD_SD2_RESET_B SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B - SW_MUX_CTL_PAD_SD2_RESET_B SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd2_reset_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd2_reset_b_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd2_reset_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_ADDR(x) ((uintptr_t)(x) + 0x1B4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd2_reset_b_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD2_RESET_B.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RESET_B of instance: SD2
 * - 001 - Select mux mode: ALT1 mux port: MCLK of instance: SAI2
 * - 010 - Select mux mode: ALT2 mux port: RESET of instance: SD2
 * - 011 - Select mux mode: ALT3 mux port: RDY of instance: ECSPI3
 * - 100 - Select mux mode: ALT4 mux port: OTG2_ID of instance: USB
 * - 101 - Select mux mode: ALT5 mux port: IO11 of instance: GPIO5
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE_ALT0_SD2_RESET_B (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE: Select mux mode: ALT0 mux port: RESET_B of instance: SD2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE_ALT1_SAI2_MCLK (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE: Select mux mode: ALT1 mux port: MCLK of instance: SAI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE_ALT2_SD2_RESET (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE: Select mux mode: ALT2 mux port: RESET of instance: SD2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE_ALT3_ECSPI3_RDY (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE: Select mux mode: ALT3 mux port: RDY of instance: ECSPI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE_ALT4_USB_OTG2_ID (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE: Select mux mode: ALT4 mux port: OTG2_ID of instance: USB */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE_ALT5_GPIO5_IO11 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE: Select mux mode: ALT5 mux port: IO11 of instance: GPIO5 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD2_RESET_B
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SION: Force input path of pad SD2_RESET_B */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_RESET_B_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK - SW_MUX_CTL_PAD_SD2_CLK SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK - SW_MUX_CTL_PAD_SD2_CLK SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd2_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd2_clk_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd2_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD2_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_ADDR(x) ((uintptr_t)(x) + 0x1B8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd2_clk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD2_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_CLK, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: SD2_CLK.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: CLK of instance: SD2
 * - 001 - Select mux mode: ALT1 mux port: RX_SYNC of instance: SAI2
 * - 010 - Select mux mode: ALT2 mux port: RIGHT of instance: MQS
 * - 011 - Select mux mode: ALT3 mux port: CLK of instance: GPT4
 * - 101 - Select mux mode: ALT5 mux port: IO12 of instance: GPIO5
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE_ALT0_SD2_CLK (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE: Select mux mode: ALT0 mux port: CLK of instance: SD2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE_ALT1_SAI2_RX_SYNC (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE: Select mux mode: ALT1 mux port: RX_SYNC of instance: SAI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE_ALT2_MQS_RIGHT (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE: Select mux mode: ALT2 mux port: RIGHT of instance: MQS */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE_ALT3_GPT4_CLK (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE: Select mux mode: ALT3 mux port: CLK of instance: GPT4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE_ALT5_GPIO5_IO12 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE: Select mux mode: ALT5 mux port: IO12 of instance: GPIO5 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_CLK, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD2_CLK
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION: Force input path of pad SD2_CLK */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD - SW_MUX_CTL_PAD_SD2_CMD SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD - SW_MUX_CTL_PAD_SD2_CMD SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd2_cmd
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd2_cmd_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd2_cmd_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD2_CMD register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_ADDR(x) ((uintptr_t)(x) + 0x1BCU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd2_cmd_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD2_CMD bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_CMD, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD2_CMD.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: CMD of instance: SD2
 * - 001 - Select mux mode: ALT1 mux port: RX_BCLK of instance: SAI2
 * - 010 - Select mux mode: ALT2 mux port: LEFT of instance: MQS
 * - 011 - Select mux mode: ALT3 mux port: CAPTURE1 of instance: GPT4
 * - 100 - Select mux mode: ALT4 mux port: PORT1_TRXD of instance: SIM2
 * - 101 - Select mux mode: ALT5 mux port: IO13 of instance: GPIO5
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE_ALT0_SD2_CMD (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE: Select mux mode: ALT0 mux port: CMD of instance: SD2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE_ALT1_SAI2_RX_BCLK (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE: Select mux mode: ALT1 mux port: RX_BCLK of instance: SAI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE_ALT2_MQS_LEFT (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE: Select mux mode: ALT2 mux port: LEFT of instance: MQS */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE_ALT3_GPT4_CAPTURE1 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE: Select mux mode: ALT3 mux port: CAPTURE1 of instance: GPT4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE_ALT4_SIM2_PORT1_TRXD (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE: Select mux mode: ALT4 mux port: PORT1_TRXD of instance: SIM2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE_ALT5_GPIO5_IO13 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE: Select mux mode: ALT5 mux port: IO13 of instance: GPIO5 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_CMD, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD2_CMD
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION: Force input path of pad SD2_CMD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_CMD_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0 - SW_MUX_CTL_PAD_SD2_DATA0 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0 - SW_MUX_CTL_PAD_SD2_DATA0 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd2_data0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd2_data0_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd2_data0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_ADDR(x) ((uintptr_t)(x) + 0x1C0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd2_data0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD2_DATA0.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA0 of instance: SD2
 * - 001 - Select mux mode: ALT1 mux port: RX_DATA0 of instance: SAI2
 * - 010 - Select mux mode: ALT2 mux port: RX_DATA of instance: UART4
 * - 011 - Select mux mode: ALT3 mux port: CAPTURE2 of instance: GPT4
 * - 100 - Select mux mode: ALT4 mux port: PORT1_CLK of instance: SIM2
 * - 101 - Select mux mode: ALT5 mux port: IO14 of instance: GPIO5
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE_ALT0_SD2_DATA0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE: Select mux mode: ALT0 mux port: DATA0 of instance: SD2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE_ALT1_SAI2_RX_DATA0 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE: Select mux mode: ALT1 mux port: RX_DATA0 of instance: SAI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE_ALT2_UART4_RX_DATA (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE: Select mux mode: ALT2 mux port: RX_DATA of instance: UART4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE_ALT3_GPT4_CAPTURE2 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE: Select mux mode: ALT3 mux port: CAPTURE2 of instance: GPT4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE_ALT4_SIM2_PORT1_CLK (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE: Select mux mode: ALT4 mux port: PORT1_CLK of instance: SIM2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE_ALT5_GPIO5_IO14 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE: Select mux mode: ALT5 mux port: IO14 of instance: GPIO5 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD2_DATA0
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION: Force input path of pad SD2_DATA0 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1 - SW_MUX_CTL_PAD_SD2_DATA1 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1 - SW_MUX_CTL_PAD_SD2_DATA1 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd2_data1
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd2_data1_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd2_data1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_ADDR(x) ((uintptr_t)(x) + 0x1C4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd2_data1_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD2_DATA1.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA1 of instance: SD2
 * - 001 - Select mux mode: ALT1 mux port: TX_BCLK of instance: SAI2
 * - 010 - Select mux mode: ALT2 mux port: TX_DATA of instance: UART4
 * - 011 - Select mux mode: ALT3 mux port: COMPARE1 of instance: GPT4
 * - 100 - Select mux mode: ALT4 mux port: PORT1_RST_B of instance: SIM2
 * - 101 - Select mux mode: ALT5 mux port: IO15 of instance: GPIO5
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE_ALT0_SD2_DATA1 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE: Select mux mode: ALT0 mux port: DATA1 of instance: SD2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE_ALT1_SAI2_TX_BCLK (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE: Select mux mode: ALT1 mux port: TX_BCLK of instance: SAI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE_ALT2_UART4_TX_DATA (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE: Select mux mode: ALT2 mux port: TX_DATA of instance: UART4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE_ALT3_GPT4_COMPARE1 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE: Select mux mode: ALT3 mux port: COMPARE1 of instance: GPT4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE_ALT4_SIM2_PORT1_RST_B (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE: Select mux mode: ALT4 mux port: PORT1_RST_B of instance: SIM2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE_ALT5_GPIO5_IO15 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE: Select mux mode: ALT5 mux port: IO15 of instance: GPIO5 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD2_DATA1
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION: Force input path of pad SD2_DATA1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA1_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2 - SW_MUX_CTL_PAD_SD2_DATA2 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2 - SW_MUX_CTL_PAD_SD2_DATA2 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd2_data2
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd2_data2_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd2_data2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_ADDR(x) ((uintptr_t)(x) + 0x1C8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd2_data2_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD2_DATA2.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA2 of instance: SD2
 * - 001 - Select mux mode: ALT1 mux port: TX_SYNC of instance: SAI2
 * - 010 - Select mux mode: ALT2 mux port: CTS_B of instance: UART4
 * - 011 - Select mux mode: ALT3 mux port: COMPARE2 of instance: GPT4
 * - 100 - Select mux mode: ALT4 mux port: PORT1_SVEN of instance: SIM2
 * - 101 - Select mux mode: ALT5 mux port: IO16 of instance: GPIO5
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE_ALT0_SD2_DATA2 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE: Select mux mode: ALT0 mux port: DATA2 of instance: SD2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE_ALT1_SAI2_TX_SYNC (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE: Select mux mode: ALT1 mux port: TX_SYNC of instance: SAI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE_ALT2_UART4_CTS_B (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE: Select mux mode: ALT2 mux port: CTS_B of instance: UART4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE_ALT3_GPT4_COMPARE2 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE: Select mux mode: ALT3 mux port: COMPARE2 of instance: GPT4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE_ALT4_SIM2_PORT1_SVEN (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE: Select mux mode: ALT4 mux port: PORT1_SVEN of instance: SIM2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE_ALT5_GPIO5_IO16 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE: Select mux mode: ALT5 mux port: IO16 of instance: GPIO5 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD2_DATA2
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION: Force input path of pad SD2_DATA2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA2_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3 - SW_MUX_CTL_PAD_SD2_DATA3 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3 - SW_MUX_CTL_PAD_SD2_DATA3 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd2_data3
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd2_data3_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd2_data3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_ADDR(x) ((uintptr_t)(x) + 0x1CCU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd2_data3_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD2_DATA3.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA3 of instance: SD2
 * - 001 - Select mux mode: ALT1 mux port: TX_DATA0 of instance: SAI2
 * - 010 - Select mux mode: ALT2 mux port: RTS_B of instance: UART4
 * - 011 - Select mux mode: ALT3 mux port: COMPARE3 of instance: GPT4
 * - 100 - Select mux mode: ALT4 mux port: PORT1_PD of instance: SIM2
 * - 101 - Select mux mode: ALT5 mux port: IO17 of instance: GPIO5
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE_ALT0_SD2_DATA3 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE: Select mux mode: ALT0 mux port: DATA3 of instance: SD2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE_ALT1_SAI2_TX_DATA0 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE: Select mux mode: ALT1 mux port: TX_DATA0 of instance: SAI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE_ALT2_UART4_RTS_B (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE: Select mux mode: ALT2 mux port: RTS_B of instance: UART4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE_ALT3_GPT4_COMPARE3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE: Select mux mode: ALT3 mux port: COMPARE3 of instance: GPT4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE_ALT4_SIM2_PORT1_PD (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE: Select mux mode: ALT4 mux port: PORT1_PD of instance: SIM2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE_ALT5_GPIO5_IO17 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE: Select mux mode: ALT5 mux port: IO17 of instance: GPIO5 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD2_DATA3
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION: Force input path of pad SD2_DATA3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD2_DATA3_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK - SW_MUX_CTL_PAD_SD3_CLK SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK - SW_MUX_CTL_PAD_SD3_CLK SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_clk_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_ADDR(x) ((uintptr_t)(x) + 0x1D0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_clk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_CLK, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD3_CLK.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: CLK of instance: SD3
 * - 001 - Select mux mode: ALT1 mux port: CLE of instance: NAND
 * - 010 - Select mux mode: ALT2 mux port: MISO of instance: ECSPI4
 * - 011 - Select mux mode: ALT3 mux port: RX_SYNC of instance: SAI3
 * - 100 - Select mux mode: ALT4 mux port: CLK of instance: GPT3
 * - 101 - Select mux mode: ALT5 mux port: IO0 of instance: GPIO6
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE_ALT0_SD3_CLK (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE: Select mux mode: ALT0 mux port: CLK of instance: SD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE_ALT1_NAND_CLE (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE: Select mux mode: ALT1 mux port: CLE of instance: NAND */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE_ALT2_ECSPI4_MISO (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE: Select mux mode: ALT2 mux port: MISO of instance: ECSPI4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE_ALT3_SAI3_RX_SYNC (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE: Select mux mode: ALT3 mux port: RX_SYNC of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE_ALT4_GPT3_CLK (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE: Select mux mode: ALT4 mux port: CLK of instance: GPT3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE_ALT5_GPIO6_IO0 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE: Select mux mode: ALT5 mux port: IO0 of instance: GPIO6 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_CLK, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_CLK
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION: Force input path of pad SD3_CLK */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_CLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD - SW_MUX_CTL_PAD_SD3_CMD SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD - SW_MUX_CTL_PAD_SD3_CMD SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_cmd
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_cmd_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_cmd_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_CMD register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_ADDR(x) ((uintptr_t)(x) + 0x1D4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_cmd_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_CMD bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_CMD, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD3_CMD.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: CMD of instance: SD3
 * - 001 - Select mux mode: ALT1 mux port: ALE of instance: NAND
 * - 010 - Select mux mode: ALT2 mux port: MOSI of instance: ECSPI4
 * - 011 - Select mux mode: ALT3 mux port: RX_BCLK of instance: SAI3
 * - 100 - Select mux mode: ALT4 mux port: CAPTURE1 of instance: GPT3
 * - 101 - Select mux mode: ALT5 mux port: IO1 of instance: GPIO6
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE_ALT0_SD3_CMD (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE: Select mux mode: ALT0 mux port: CMD of instance: SD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE_ALT1_NAND_ALE (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE: Select mux mode: ALT1 mux port: ALE of instance: NAND */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE_ALT2_ECSPI4_MOSI (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE: Select mux mode: ALT2 mux port: MOSI of instance: ECSPI4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE_ALT3_SAI3_RX_BCLK (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE: Select mux mode: ALT3 mux port: RX_BCLK of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE_ALT4_GPT3_CAPTURE1 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE: Select mux mode: ALT4 mux port: CAPTURE1 of instance: GPT3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE_ALT5_GPIO6_IO1 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE: Select mux mode: ALT5 mux port: IO1 of instance: GPIO6 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_CMD, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_CMD
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION: Force input path of pad SD3_CMD */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_CMD_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0 - SW_MUX_CTL_PAD_SD3_DATA0 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0 - SW_MUX_CTL_PAD_SD3_DATA0 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_data0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_data0_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_data0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_ADDR(x) ((uintptr_t)(x) + 0x1D8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_data0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD3_DATA0.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA0 of instance: SD3
 * - 001 - Select mux mode: ALT1 mux port: DATA00 of instance: NAND
 * - 010 - Select mux mode: ALT2 mux port: SS0 of instance: ECSPI4
 * - 011 - Select mux mode: ALT3 mux port: RX_DATA0 of instance: SAI3
 * - 100 - Select mux mode: ALT4 mux port: CAPTURE2 of instance: GPT3
 * - 101 - Select mux mode: ALT5 mux port: IO2 of instance: GPIO6
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE_ALT0_SD3_DATA0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE: Select mux mode: ALT0 mux port: DATA0 of instance: SD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE_ALT1_NAND_DATA00 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE: Select mux mode: ALT1 mux port: DATA00 of instance: NAND */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE_ALT2_ECSPI4_SS0 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE: Select mux mode: ALT2 mux port: SS0 of instance: ECSPI4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE_ALT3_SAI3_RX_DATA0 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE: Select mux mode: ALT3 mux port: RX_DATA0 of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE_ALT4_GPT3_CAPTURE2 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE: Select mux mode: ALT4 mux port: CAPTURE2 of instance: GPT3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE_ALT5_GPIO6_IO2 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE: Select mux mode: ALT5 mux port: IO2 of instance: GPIO6 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_DATA0
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION: Force input path of pad SD3_DATA0 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1 - SW_MUX_CTL_PAD_SD3_DATA1 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1 - SW_MUX_CTL_PAD_SD3_DATA1 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_data1
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_data1_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_data1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_ADDR(x) ((uintptr_t)(x) + 0x1DCU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_data1_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD3_DATA1.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA1 of instance: SD3
 * - 001 - Select mux mode: ALT1 mux port: DATA01 of instance: NAND
 * - 010 - Select mux mode: ALT2 mux port: SCLK of instance: ECSPI4
 * - 011 - Select mux mode: ALT3 mux port: TX_BCLK of instance: SAI3
 * - 100 - Select mux mode: ALT4 mux port: COMPARE1 of instance: GPT3
 * - 101 - Select mux mode: ALT5 mux port: IO3 of instance: GPIO6
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE_ALT0_SD3_DATA1 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE: Select mux mode: ALT0 mux port: DATA1 of instance: SD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE_ALT1_NAND_DATA01 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE: Select mux mode: ALT1 mux port: DATA01 of instance: NAND */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE_ALT2_ECSPI4_SCLK (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE: Select mux mode: ALT2 mux port: SCLK of instance: ECSPI4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE_ALT3_SAI3_TX_BCLK (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE: Select mux mode: ALT3 mux port: TX_BCLK of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE_ALT4_GPT3_COMPARE1 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE: Select mux mode: ALT4 mux port: COMPARE1 of instance: GPT3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE_ALT5_GPIO6_IO3 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE: Select mux mode: ALT5 mux port: IO3 of instance: GPIO6 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_DATA1
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION: Force input path of pad SD3_DATA1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA1_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2 - SW_MUX_CTL_PAD_SD3_DATA2 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2 - SW_MUX_CTL_PAD_SD3_DATA2 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_data2
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_data2_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_data2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_ADDR(x) ((uintptr_t)(x) + 0x1E0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_data2_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD3_DATA2.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA2 of instance: SD3
 * - 001 - Select mux mode: ALT1 mux port: DATA02 of instance: NAND
 * - 010 - Select mux mode: ALT2 mux port: SDA of instance: I2C3
 * - 011 - Select mux mode: ALT3 mux port: TX_SYNC of instance: SAI3
 * - 100 - Select mux mode: ALT4 mux port: COMPARE2 of instance: GPT3
 * - 101 - Select mux mode: ALT5 mux port: IO4 of instance: GPIO6
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE_ALT0_SD3_DATA2 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE: Select mux mode: ALT0 mux port: DATA2 of instance: SD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE_ALT1_NAND_DATA02 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE: Select mux mode: ALT1 mux port: DATA02 of instance: NAND */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE_ALT2_I2C3_SDA (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE: Select mux mode: ALT2 mux port: SDA of instance: I2C3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE_ALT3_SAI3_TX_SYNC (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE: Select mux mode: ALT3 mux port: TX_SYNC of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE_ALT4_GPT3_COMPARE2 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE: Select mux mode: ALT4 mux port: COMPARE2 of instance: GPT3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE_ALT5_GPIO6_IO4 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE: Select mux mode: ALT5 mux port: IO4 of instance: GPIO6 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_DATA2
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION: Force input path of pad SD3_DATA2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA2_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3 - SW_MUX_CTL_PAD_SD3_DATA3 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3 - SW_MUX_CTL_PAD_SD3_DATA3 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_data3
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_data3_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_data3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_ADDR(x) ((uintptr_t)(x) + 0x1E4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_data3_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD3_DATA3.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA3 of instance: SD3
 * - 001 - Select mux mode: ALT1 mux port: DATA03 of instance: NAND
 * - 010 - Select mux mode: ALT2 mux port: SCL of instance: I2C3
 * - 011 - Select mux mode: ALT3 mux port: TX_DATA0 of instance: SAI3
 * - 100 - Select mux mode: ALT4 mux port: COMPARE3 of instance: GPT3
 * - 101 - Select mux mode: ALT5 mux port: IO5 of instance: GPIO6
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE_ALT0_SD3_DATA3 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE: Select mux mode: ALT0 mux port: DATA3 of instance: SD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE_ALT1_NAND_DATA03 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE: Select mux mode: ALT1 mux port: DATA03 of instance: NAND */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE_ALT2_I2C3_SCL (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE: Select mux mode: ALT2 mux port: SCL of instance: I2C3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE_ALT3_SAI3_TX_DATA0 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE: Select mux mode: ALT3 mux port: TX_DATA0 of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE_ALT4_GPT3_COMPARE3 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE: Select mux mode: ALT4 mux port: COMPARE3 of instance: GPT3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE_ALT5_GPIO6_IO5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE: Select mux mode: ALT5 mux port: IO5 of instance: GPIO6 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_DATA3
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION: Force input path of pad SD3_DATA3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA3_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4 - SW_MUX_CTL_PAD_SD3_DATA4 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4 - SW_MUX_CTL_PAD_SD3_DATA4 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_data4
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_data4_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_data4_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_ADDR(x) ((uintptr_t)(x) + 0x1E8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_data4_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: SD3_DATA4.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA4 of instance: SD3
 * - 001 - Select mux mode: ALT1 mux port: DATA04 of instance: NAND
 * - 011 - Select mux mode: ALT3 mux port: RX_DATA of instance: UART3
 * - 100 - Select mux mode: ALT4 mux port: RX of instance: FLEXCAN2
 * - 101 - Select mux mode: ALT5 mux port: IO6 of instance: GPIO6
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE_ALT0_SD3_DATA4 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE: Select mux mode: ALT0 mux port: DATA4 of instance: SD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE_ALT1_NAND_DATA04 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE: Select mux mode: ALT1 mux port: DATA04 of instance: NAND */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE_ALT3_UART3_RX_DATA (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE: Select mux mode: ALT3 mux port: RX_DATA of instance: UART3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE_ALT4_FLEXCAN2_RX (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE: Select mux mode: ALT4 mux port: RX of instance: FLEXCAN2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE_ALT5_GPIO6_IO6 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE: Select mux mode: ALT5 mux port: IO6 of instance: GPIO6 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_DATA4
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION: Force input path of pad SD3_DATA4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA4_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5 - SW_MUX_CTL_PAD_SD3_DATA5 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5 - SW_MUX_CTL_PAD_SD3_DATA5 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_data5
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_data5_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_data5_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_ADDR(x) ((uintptr_t)(x) + 0x1ECU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_data5_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: SD3_DATA5.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA5 of instance: SD3
 * - 001 - Select mux mode: ALT1 mux port: DATA05 of instance: NAND
 * - 011 - Select mux mode: ALT3 mux port: TX_DATA of instance: UART3
 * - 100 - Select mux mode: ALT4 mux port: TX of instance: FLEXCAN1
 * - 101 - Select mux mode: ALT5 mux port: IO7 of instance: GPIO6
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE_ALT0_SD3_DATA5 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE: Select mux mode: ALT0 mux port: DATA5 of instance: SD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE_ALT1_NAND_DATA05 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE: Select mux mode: ALT1 mux port: DATA05 of instance: NAND */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE_ALT3_UART3_TX_DATA (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE: Select mux mode: ALT3 mux port: TX_DATA of instance: UART3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE_ALT4_FLEXCAN1_TX (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE: Select mux mode: ALT4 mux port: TX of instance: FLEXCAN1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE_ALT5_GPIO6_IO7 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE: Select mux mode: ALT5 mux port: IO7 of instance: GPIO6 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_DATA5
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION: Force input path of pad SD3_DATA5 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA5_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6 - SW_MUX_CTL_PAD_SD3_DATA6 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6 - SW_MUX_CTL_PAD_SD3_DATA6 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_data6
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_data6_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_data6_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_ADDR(x) ((uintptr_t)(x) + 0x1F0U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_data6_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD3_DATA6.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA6 of instance: SD3
 * - 001 - Select mux mode: ALT1 mux port: DATA06 of instance: NAND
 * - 010 - Select mux mode: ALT2 mux port: WP of instance: SD3
 * - 011 - Select mux mode: ALT3 mux port: RTS_B of instance: UART3
 * - 100 - Select mux mode: ALT4 mux port: TX of instance: FLEXCAN2
 * - 101 - Select mux mode: ALT5 mux port: IO8 of instance: GPIO6
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE_ALT0_SD3_DATA6 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE: Select mux mode: ALT0 mux port: DATA6 of instance: SD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE_ALT1_NAND_DATA06 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE: Select mux mode: ALT1 mux port: DATA06 of instance: NAND */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE_ALT2_SD3_WP (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE: Select mux mode: ALT2 mux port: WP of instance: SD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE_ALT3_UART3_RTS_B (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE: Select mux mode: ALT3 mux port: RTS_B of instance: UART3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE_ALT4_FLEXCAN2_TX (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE: Select mux mode: ALT4 mux port: TX of instance: FLEXCAN2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE_ALT5_GPIO6_IO8 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE: Select mux mode: ALT5 mux port: IO8 of instance: GPIO6 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_DATA6
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION: Force input path of pad SD3_DATA6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA6_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7 - SW_MUX_CTL_PAD_SD3_DATA7 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7 - SW_MUX_CTL_PAD_SD3_DATA7 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_data7
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_data7_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_data7_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_ADDR(x) ((uintptr_t)(x) + 0x1F4U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_data7_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SD3_DATA7.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: DATA7 of instance: SD3
 * - 001 - Select mux mode: ALT1 mux port: DATA07 of instance: NAND
 * - 010 - Select mux mode: ALT2 mux port: CD_B of instance: SD3
 * - 011 - Select mux mode: ALT3 mux port: CTS_B of instance: UART3
 * - 100 - Select mux mode: ALT4 mux port: RX of instance: FLEXCAN1
 * - 101 - Select mux mode: ALT5 mux port: IO9 of instance: GPIO6
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE_ALT0_SD3_DATA7 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE: Select mux mode: ALT0 mux port: DATA7 of instance: SD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE_ALT1_NAND_DATA07 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE: Select mux mode: ALT1 mux port: DATA07 of instance: NAND */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE_ALT2_SD3_CD_B (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE: Select mux mode: ALT2 mux port: CD_B of instance: SD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE_ALT3_UART3_CTS_B (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE: Select mux mode: ALT3 mux port: CTS_B of instance: UART3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE_ALT4_FLEXCAN1_RX (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE: Select mux mode: ALT4 mux port: RX of instance: FLEXCAN1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE_ALT5_GPIO6_IO9 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE: Select mux mode: ALT5 mux port: IO9 of instance: GPIO6 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_DATA7
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION: Force input path of pad SD3_DATA7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_DATA7_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE - SW_MUX_CTL_PAD_SD3_STROBE SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE - SW_MUX_CTL_PAD_SD3_STROBE SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_strobe
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_strobe_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_strobe_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_ADDR(x) ((uintptr_t)(x) + 0x1F8U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_strobe_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 4 iomux modes to be used for pad: SD3_STROBE.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: STROBE of instance: SD3
 * - 001 - Select mux mode: ALT1 mux port: RE_B of instance: NAND
 * - 101 - Select mux mode: ALT5 mux port: IO10 of instance: GPIO6
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE_ALT0_SD3_STROBE (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE: Select mux mode: ALT0 mux port: STROBE of instance: SD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE_ALT1_NAND_RE_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE: Select mux mode: ALT1 mux port: RE_B of instance: NAND */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE_ALT5_GPIO6_IO10 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE: Select mux mode: ALT5 mux port: IO10 of instance: GPIO6 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_STROBE
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SION: Force input path of pad SD3_STROBE */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_STROBE_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B - SW_MUX_CTL_PAD_SD3_RESET_B SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B - SW_MUX_CTL_PAD_SD3_RESET_B SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sd3_reset_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sd3_reset_b_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sd3_reset_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_ADDR(x) ((uintptr_t)(x) + 0x1FCU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sd3_reset_b_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: SD3_RESET_B.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RESET_B of instance: SD3
 * - 001 - Select mux mode: ALT1 mux port: WE_B of instance: NAND
 * - 010 - Select mux mode: ALT2 mux port: RESET of instance: SD3
 * - 011 - Select mux mode: ALT3 mux port: MCLK of instance: SAI3
 * - 101 - Select mux mode: ALT5 mux port: IO11 of instance: GPIO6
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE_ALT0_SD3_RESET_B (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE: Select mux mode: ALT0 mux port: RESET_B of instance: SD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE_ALT1_NAND_WE_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE: Select mux mode: ALT1 mux port: WE_B of instance: NAND */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE_ALT2_SD3_RESET (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE: Select mux mode: ALT2 mux port: RESET of instance: SD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE_ALT3_SAI3_MCLK (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE: Select mux mode: ALT3 mux port: MCLK of instance: SAI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE_ALT5_GPIO6_IO11 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE: Select mux mode: ALT5 mux port: IO11 of instance: GPIO6 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SD3_RESET_B
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SION: Force input path of pad SD3_RESET_B */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SD3_RESET_B_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA - SW_MUX_CTL_PAD_SAI1_RX_DATA SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA - SW_MUX_CTL_PAD_SAI1_RX_DATA SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sai1_rx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sai1_rx_data_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sai1_rx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_ADDR(x) ((uintptr_t)(x) + 0x200U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sai1_rx_data_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SAI1_RX_DATA.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RX_DATA0 of instance: SAI1
 * - 001 - Select mux mode: ALT1 mux port: CE1_B of instance: NAND
 * - 010 - Select mux mode: ALT2 mux port: RX_DATA of instance: UART5
 * - 011 - Select mux mode: ALT3 mux port: RX of instance: FLEXCAN1
 * - 100 - Select mux mode: ALT4 mux port: PORT1_TRXD of instance: SIM1
 * - 101 - Select mux mode: ALT5 mux port: IO12 of instance: GPIO6
 * - 111 - Select mux mode: ALT7 mux port: ANY_PU_RESET of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE_ALT0_SAI1_RX_DATA0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE: Select mux mode: ALT0 mux port: RX_DATA0 of instance: SAI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE_ALT1_NAND_CE1_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE: Select mux mode: ALT1 mux port: CE1_B of instance: NAND */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE_ALT2_UART5_RX_DATA (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE: Select mux mode: ALT2 mux port: RX_DATA of instance: UART5 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE_ALT3_FLEXCAN1_RX (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE: Select mux mode: ALT3 mux port: RX of instance: FLEXCAN1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE_ALT4_SIM1_PORT1_TRXD (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE: Select mux mode: ALT4 mux port: PORT1_TRXD of instance: SIM1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE_ALT5_GPIO6_IO12 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE: Select mux mode: ALT5 mux port: IO12 of instance: GPIO6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE_ALT7_SRC_ANY_PU_RESET (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE: Select mux mode: ALT7 mux port: ANY_PU_RESET of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SAI1_RX_DATA
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SION: Force input path of pad SAI1_RX_DATA */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_DATA_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK - SW_MUX_CTL_PAD_SAI1_TX_BCLK SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK - SW_MUX_CTL_PAD_SAI1_TX_BCLK SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sai1_tx_bclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sai1_tx_bclk_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sai1_tx_bclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_ADDR(x) ((uintptr_t)(x) + 0x204U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sai1_tx_bclk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SAI1_TX_BCLK.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: TX_BCLK of instance: SAI1
 * - 001 - Select mux mode: ALT1 mux port: CE0_B of instance: NAND
 * - 010 - Select mux mode: ALT2 mux port: TX_DATA of instance: UART5
 * - 011 - Select mux mode: ALT3 mux port: TX of instance: FLEXCAN1
 * - 100 - Select mux mode: ALT4 mux port: PORT1_CLK of instance: SIM1
 * - 101 - Select mux mode: ALT5 mux port: IO13 of instance: GPIO6
 * - 111 - Select mux mode: ALT7 mux port: EARLY_RESET of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE_ALT0_SAI1_TX_BCLK (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE: Select mux mode: ALT0 mux port: TX_BCLK of instance: SAI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE_ALT1_NAND_CE0_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE: Select mux mode: ALT1 mux port: CE0_B of instance: NAND */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE_ALT2_UART5_TX_DATA (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE: Select mux mode: ALT2 mux port: TX_DATA of instance: UART5 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE_ALT3_FLEXCAN1_TX (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE: Select mux mode: ALT3 mux port: TX of instance: FLEXCAN1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE_ALT4_SIM1_PORT1_CLK (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE: Select mux mode: ALT4 mux port: PORT1_CLK of instance: SIM1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE_ALT5_GPIO6_IO13 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE: Select mux mode: ALT5 mux port: IO13 of instance: GPIO6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE_ALT7_SRC_EARLY_RESET (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE: Select mux mode: ALT7 mux port: EARLY_RESET of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SAI1_TX_BCLK
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SION: Force input path of pad SAI1_TX_BCLK */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_BCLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC - SW_MUX_CTL_PAD_SAI1_TX_SYNC SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC - SW_MUX_CTL_PAD_SAI1_TX_SYNC SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sai1_tx_sync
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sai1_tx_sync_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sai1_tx_sync_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_ADDR(x) ((uintptr_t)(x) + 0x208U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sai1_tx_sync_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SAI1_TX_SYNC.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: TX_SYNC of instance: SAI1
 * - 001 - Select mux mode: ALT1 mux port: DQS of instance: NAND
 * - 010 - Select mux mode: ALT2 mux port: CTS_B of instance: UART5
 * - 011 - Select mux mode: ALT3 mux port: RX of instance: FLEXCAN2
 * - 100 - Select mux mode: ALT4 mux port: PORT1_RST_B of instance: SIM1
 * - 101 - Select mux mode: ALT5 mux port: IO14 of instance: GPIO6
 * - 111 - Select mux mode: ALT7 mux port: INT_BOOT of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE_ALT0_SAI1_TX_SYNC (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE: Select mux mode: ALT0 mux port: TX_SYNC of instance: SAI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE_ALT1_NAND_DQS (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE: Select mux mode: ALT1 mux port: DQS of instance: NAND */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE_ALT2_UART5_CTS_B (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE: Select mux mode: ALT2 mux port: CTS_B of instance: UART5 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE_ALT3_FLEXCAN2_RX (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE: Select mux mode: ALT3 mux port: RX of instance: FLEXCAN2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE_ALT4_SIM1_PORT1_RST_B (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE: Select mux mode: ALT4 mux port: PORT1_RST_B of instance: SIM1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE_ALT5_GPIO6_IO14 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE: Select mux mode: ALT5 mux port: IO14 of instance: GPIO6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE_ALT7_SRC_INT_BOOT (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE: Select mux mode: ALT7 mux port: INT_BOOT of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SAI1_TX_SYNC
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SION: Force input path of pad SAI1_TX_SYNC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_SYNC_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA - SW_MUX_CTL_PAD_SAI1_TX_DATA SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA - SW_MUX_CTL_PAD_SAI1_TX_DATA SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sai1_tx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sai1_tx_data_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sai1_tx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_ADDR(x) ((uintptr_t)(x) + 0x20CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sai1_tx_data_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SAI1_TX_DATA.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: TX_DATA0 of instance: SAI1
 * - 001 - Select mux mode: ALT1 mux port: READY_B of instance: NAND
 * - 010 - Select mux mode: ALT2 mux port: RTS_B of instance: UART5
 * - 011 - Select mux mode: ALT3 mux port: TX of instance: FLEXCAN2
 * - 100 - Select mux mode: ALT4 mux port: PORT1_SVEN of instance: SIM1
 * - 101 - Select mux mode: ALT5 mux port: IO15 of instance: GPIO6
 * - 111 - Select mux mode: ALT7 mux port: SYSTEM_RESET of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE_ALT0_SAI1_TX_DATA0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE: Select mux mode: ALT0 mux port: TX_DATA0 of instance: SAI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE_ALT1_NAND_READY_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE: Select mux mode: ALT1 mux port: READY_B of instance: NAND */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE_ALT2_UART5_RTS_B (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE: Select mux mode: ALT2 mux port: RTS_B of instance: UART5 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE_ALT3_FLEXCAN2_TX (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE: Select mux mode: ALT3 mux port: TX of instance: FLEXCAN2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE_ALT4_SIM1_PORT1_SVEN (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE: Select mux mode: ALT4 mux port: PORT1_SVEN of instance: SIM1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE_ALT5_GPIO6_IO15 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE: Select mux mode: ALT5 mux port: IO15 of instance: GPIO6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE_ALT7_SRC_SYSTEM_RESET (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE: Select mux mode: ALT7 mux port: SYSTEM_RESET of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SAI1_TX_DATA
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SION: Force input path of pad SAI1_TX_DATA */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_TX_DATA_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC - SW_MUX_CTL_PAD_SAI1_RX_SYNC SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC - SW_MUX_CTL_PAD_SAI1_RX_SYNC SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sai1_rx_sync
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sai1_rx_sync_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sai1_rx_sync_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_ADDR(x) ((uintptr_t)(x) + 0x210U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sai1_rx_sync_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: SAI1_RX_SYNC.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RX_SYNC of instance: SAI1
 * - 001 - Select mux mode: ALT1 mux port: CE2_B of instance: NAND
 * - 010 - Select mux mode: ALT2 mux port: RX_SYNC of instance: SAI2
 * - 011 - Select mux mode: ALT3 mux port: SCL of instance: I2C4
 * - 100 - Select mux mode: ALT4 mux port: PORT1_PD of instance: SIM1
 * - 101 - Select mux mode: ALT5 mux port: IO16 of instance: GPIO6
 * - 110 - Select mux mode: ALT6 mux port: RIGHT of instance: MQS
 * - 111 - Select mux mode: ALT7 mux port: CA7_RESET_B0 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE_ALT0_SAI1_RX_SYNC (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE: Select mux mode: ALT0 mux port: RX_SYNC of instance: SAI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE_ALT1_NAND_CE2_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE: Select mux mode: ALT1 mux port: CE2_B of instance: NAND */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE_ALT2_SAI2_RX_SYNC (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE: Select mux mode: ALT2 mux port: RX_SYNC of instance: SAI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE_ALT3_I2C4_SCL (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE: Select mux mode: ALT3 mux port: SCL of instance: I2C4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE_ALT4_SIM1_PORT1_PD (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE: Select mux mode: ALT4 mux port: PORT1_PD of instance: SIM1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE_ALT5_GPIO6_IO16 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE: Select mux mode: ALT5 mux port: IO16 of instance: GPIO6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE_ALT6_MQS_RIGHT (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE: Select mux mode: ALT6 mux port: RIGHT of instance: MQS */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE_ALT7_SRC_CA7_RESET_B0 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE: Select mux mode: ALT7 mux port: CA7_RESET_B0 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SAI1_RX_SYNC
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SION: Force input path of pad SAI1_RX_SYNC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_SYNC_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK - SW_MUX_CTL_PAD_SAI1_RX_BCLK SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK - SW_MUX_CTL_PAD_SAI1_RX_BCLK SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sai1_rx_bclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sai1_rx_bclk_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sai1_rx_bclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_ADDR(x) ((uintptr_t)(x) + 0x214U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sai1_rx_bclk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: SAI1_RX_BCLK.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RX_BCLK of instance: SAI1
 * - 001 - Select mux mode: ALT1 mux port: CE3_B of instance: NAND
 * - 010 - Select mux mode: ALT2 mux port: RX_BCLK of instance: SAI2
 * - 011 - Select mux mode: ALT3 mux port: SDA of instance: I2C4
 * - 100 - Select mux mode: ALT4 mux port: PHA of instance: FLEXTIMER2
 * - 101 - Select mux mode: ALT5 mux port: IO17 of instance: GPIO6
 * - 110 - Select mux mode: ALT6 mux port: LEFT of instance: MQS
 * - 111 - Select mux mode: ALT7 mux port: CA7_RESET_B1 of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE_ALT0_SAI1_RX_BCLK (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE: Select mux mode: ALT0 mux port: RX_BCLK of instance: SAI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE_ALT1_NAND_CE3_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE: Select mux mode: ALT1 mux port: CE3_B of instance: NAND */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE_ALT2_SAI2_RX_BCLK (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE: Select mux mode: ALT2 mux port: RX_BCLK of instance: SAI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE_ALT3_I2C4_SDA (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE: Select mux mode: ALT3 mux port: SDA of instance: I2C4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE_ALT4_FLEXTIMER2_PHA (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE: Select mux mode: ALT4 mux port: PHA of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE_ALT5_GPIO6_IO17 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE: Select mux mode: ALT5 mux port: IO17 of instance: GPIO6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE_ALT6_MQS_LEFT (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE: Select mux mode: ALT6 mux port: LEFT of instance: MQS */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE_ALT7_SRC_CA7_RESET_B1 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE: Select mux mode: ALT7 mux port: CA7_RESET_B1 of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SAI1_RX_BCLK
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SION: Force input path of pad SAI1_RX_BCLK */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_RX_BCLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK - SW_MUX_CTL_PAD_SAI1_MCLK SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK - SW_MUX_CTL_PAD_SAI1_MCLK SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sai1_mclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sai1_mclk_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sai1_mclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_ADDR(x) ((uintptr_t)(x) + 0x218U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sai1_mclk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SAI1_MCLK.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: MCLK of instance: SAI1
 * - 001 - Select mux mode: ALT1 mux port: WP_B of instance: NAND
 * - 010 - Select mux mode: ALT2 mux port: MCLK of instance: SAI2
 * - 011 - Select mux mode: ALT3 mux port: CCM_PMIC_READY of instance: CCM
 * - 100 - Select mux mode: ALT4 mux port: PHB of instance: FLEXTIMER2
 * - 101 - Select mux mode: ALT5 mux port: IO18 of instance: GPIO6
 * - 111 - Select mux mode: ALT7 mux port: TESTER_ACK of instance: SRC
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE_ALT0_SAI1_MCLK (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE: Select mux mode: ALT0 mux port: MCLK of instance: SAI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE_ALT1_NAND_WP_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE: Select mux mode: ALT1 mux port: WP_B of instance: NAND */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE_ALT2_SAI2_MCLK (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE: Select mux mode: ALT2 mux port: MCLK of instance: SAI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE_ALT3_CCM_PMIC_READY (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE: Select mux mode: ALT3 mux port: CCM_PMIC_READY of instance: CCM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE_ALT4_FLEXTIMER2_PHB (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE: Select mux mode: ALT4 mux port: PHB of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE_ALT5_GPIO6_IO18 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE: Select mux mode: ALT5 mux port: IO18 of instance: GPIO6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE_ALT7_SRC_TESTER_ACK (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE: Select mux mode: ALT7 mux port: TESTER_ACK of instance: SRC */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SAI1_MCLK
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SION: Force input path of pad SAI1_MCLK */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI1_MCLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC - SW_MUX_CTL_PAD_SAI2_TX_SYNC SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC - SW_MUX_CTL_PAD_SAI2_TX_SYNC SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sai2_tx_sync
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sai2_tx_sync_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sai2_tx_sync_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_ADDR(x) ((uintptr_t)(x) + 0x21CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sai2_tx_sync_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SAI2_TX_SYNC.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: TX_SYNC of instance: SAI2
 * - 001 - Select mux mode: ALT1 mux port: MISO of instance: ECSPI3
 * - 010 - Select mux mode: ALT2 mux port: RX_DATA of instance: UART4
 * - 011 - Select mux mode: ALT3 mux port: CTS_B of instance: UART1
 * - 100 - Select mux mode: ALT4 mux port: CH4 of instance: FLEXTIMER2
 * - 101 - Select mux mode: ALT5 mux port: IO19 of instance: GPIO6
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE_ALT0_SAI2_TX_SYNC (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE: Select mux mode: ALT0 mux port: TX_SYNC of instance: SAI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE_ALT1_ECSPI3_MISO (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE: Select mux mode: ALT1 mux port: MISO of instance: ECSPI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE_ALT2_UART4_RX_DATA (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE: Select mux mode: ALT2 mux port: RX_DATA of instance: UART4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE_ALT3_UART1_CTS_B (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE: Select mux mode: ALT3 mux port: CTS_B of instance: UART1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE_ALT4_FLEXTIMER2_CH4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE: Select mux mode: ALT4 mux port: CH4 of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE_ALT5_GPIO6_IO19 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE: Select mux mode: ALT5 mux port: IO19 of instance: GPIO6 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SAI2_TX_SYNC
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SION: Force input path of pad SAI2_TX_SYNC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_SYNC_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK - SW_MUX_CTL_PAD_SAI2_TX_BCLK SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK - SW_MUX_CTL_PAD_SAI2_TX_BCLK SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sai2_tx_bclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sai2_tx_bclk_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sai2_tx_bclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_ADDR(x) ((uintptr_t)(x) + 0x220U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sai2_tx_bclk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: SAI2_TX_BCLK.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: TX_BCLK of instance: SAI2
 * - 001 - Select mux mode: ALT1 mux port: MOSI of instance: ECSPI3
 * - 010 - Select mux mode: ALT2 mux port: TX_DATA of instance: UART4
 * - 011 - Select mux mode: ALT3 mux port: RTS_B of instance: UART1
 * - 100 - Select mux mode: ALT4 mux port: CH5 of instance: FLEXTIMER2
 * - 101 - Select mux mode: ALT5 mux port: IO20 of instance: GPIO6
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE_ALT0_SAI2_TX_BCLK (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE: Select mux mode: ALT0 mux port: TX_BCLK of instance: SAI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE_ALT1_ECSPI3_MOSI (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE: Select mux mode: ALT1 mux port: MOSI of instance: ECSPI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE_ALT2_UART4_TX_DATA (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE: Select mux mode: ALT2 mux port: TX_DATA of instance: UART4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE_ALT3_UART1_RTS_B (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE: Select mux mode: ALT3 mux port: RTS_B of instance: UART1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE_ALT4_FLEXTIMER2_CH5 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE: Select mux mode: ALT4 mux port: CH5 of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE_ALT5_GPIO6_IO20 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE: Select mux mode: ALT5 mux port: IO20 of instance: GPIO6 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SAI2_TX_BCLK
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SION: Force input path of pad SAI2_TX_BCLK */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_BCLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA - SW_MUX_CTL_PAD_SAI2_RX_DATA SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA - SW_MUX_CTL_PAD_SAI2_RX_DATA SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sai2_rx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sai2_rx_data_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sai2_rx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_ADDR(x) ((uintptr_t)(x) + 0x224U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sai2_rx_data_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: SAI2_RX_DATA.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RX_DATA0 of instance: SAI2
 * - 001 - Select mux mode: ALT1 mux port: SCLK of instance: ECSPI3
 * - 010 - Select mux mode: ALT2 mux port: CTS_B of instance: UART4
 * - 011 - Select mux mode: ALT3 mux port: CTS_B of instance: UART2
 * - 100 - Select mux mode: ALT4 mux port: CH6 of instance: FLEXTIMER2
 * - 101 - Select mux mode: ALT5 mux port: IO21 of instance: GPIO6
 * - 110 - Select mux mode: ALT6 mux port: COL7 of instance: KPP
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE_ALT0_SAI2_RX_DATA0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE: Select mux mode: ALT0 mux port: RX_DATA0 of instance: SAI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE_ALT1_ECSPI3_SCLK (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE: Select mux mode: ALT1 mux port: SCLK of instance: ECSPI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE_ALT2_UART4_CTS_B (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE: Select mux mode: ALT2 mux port: CTS_B of instance: UART4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE_ALT3_UART2_CTS_B (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE: Select mux mode: ALT3 mux port: CTS_B of instance: UART2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE_ALT4_FLEXTIMER2_CH6 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE: Select mux mode: ALT4 mux port: CH6 of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE_ALT5_GPIO6_IO21 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE: Select mux mode: ALT5 mux port: IO21 of instance: GPIO6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE_ALT6_KPP_COL7 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE: Select mux mode: ALT6 mux port: COL7 of instance: KPP */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SAI2_RX_DATA
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SION: Force input path of pad SAI2_RX_DATA */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI2_RX_DATA_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA - SW_MUX_CTL_PAD_SAI2_TX_DATA SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA - SW_MUX_CTL_PAD_SAI2_TX_DATA SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_sai2_tx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_sai2_tx_data_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_sai2_tx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_ADDR(x) ((uintptr_t)(x) + 0x228U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_sai2_tx_data_t *) HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: SAI2_TX_DATA.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: TX_DATA0 of instance: SAI2
 * - 001 - Select mux mode: ALT1 mux port: SS0 of instance: ECSPI3
 * - 010 - Select mux mode: ALT2 mux port: RTS_B of instance: UART4
 * - 011 - Select mux mode: ALT3 mux port: RTS_B of instance: UART2
 * - 100 - Select mux mode: ALT4 mux port: CH7 of instance: FLEXTIMER2
 * - 101 - Select mux mode: ALT5 mux port: IO22 of instance: GPIO6
 * - 110 - Select mux mode: ALT6 mux port: ROW7 of instance: KPP
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE_ALT0_SAI2_TX_DATA0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE: Select mux mode: ALT0 mux port: TX_DATA0 of instance: SAI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE_ALT1_ECSPI3_SS0 (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE: Select mux mode: ALT1 mux port: SS0 of instance: ECSPI3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE_ALT2_UART4_RTS_B (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE: Select mux mode: ALT2 mux port: RTS_B of instance: UART4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE_ALT3_UART2_RTS_B (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE: Select mux mode: ALT3 mux port: RTS_B of instance: UART2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE_ALT4_FLEXTIMER2_CH7 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE: Select mux mode: ALT4 mux port: CH7 of instance: FLEXTIMER2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE_ALT5_GPIO6_IO22 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE: Select mux mode: ALT5 mux port: IO22 of instance: GPIO6 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE_ALT6_KPP_ROW7 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE: Select mux mode: ALT6 mux port: ROW7 of instance: KPP */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad SAI2_TX_DATA
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SION: Force input path of pad SAI2_TX_DATA */
#define BV_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_SAI2_TX_DATA_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0 - SW_MUX_CTL_PAD_ENET1_RGMII_RD0 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0 - SW_MUX_CTL_PAD_ENET1_RGMII_RD0 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd0_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_ADDR(x) ((uintptr_t)(x) + 0x22CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ENET1_RGMII_RD0.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RGMII_RD0 of instance: ENET1
 * - 001 - Select mux mode: ALT1 mux port: OUT of instance: PWM1
 * - 010 - Select mux mode: ALT2 mux port: SCL of instance: I2C3
 * - 011 - Select mux mode: ALT3 mux port: CTS_B of instance: UART1
 * - 100 - Select mux mode: ALT4 mux port: VCOM0 of instance: EPDC
 * - 101 - Select mux mode: ALT5 mux port: IO0 of instance: GPIO7
 * - 110 - Select mux mode: ALT6 mux port: ROW3 of instance: KPP
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE_ALT0_ENET1_RGMII_RD0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE: Select mux mode: ALT0 mux port: RGMII_RD0 of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE_ALT1_PWM1_OUT (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE: Select mux mode: ALT1 mux port: OUT of instance: PWM1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE_ALT2_I2C3_SCL (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE: Select mux mode: ALT2 mux port: SCL of instance: I2C3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE_ALT3_UART1_CTS_B (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE: Select mux mode: ALT3 mux port: CTS_B of instance: UART1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE_ALT4_EPDC_VCOM0 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE: Select mux mode: ALT4 mux port: VCOM0 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE_ALT5_GPIO7_IO0 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE: Select mux mode: ALT5 mux port: IO0 of instance: GPIO7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE_ALT6_KPP_ROW3 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE: Select mux mode: ALT6 mux port: ROW3 of instance: KPP */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_RGMII_RD0
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SION: Force input path of pad ENET1_RGMII_RD0 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1 - SW_MUX_CTL_PAD_ENET1_RGMII_RD1 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1 - SW_MUX_CTL_PAD_ENET1_RGMII_RD1 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd1
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd1_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_ADDR(x) ((uintptr_t)(x) + 0x230U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd1_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ENET1_RGMII_RD1.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RGMII_RD1 of instance: ENET1
 * - 001 - Select mux mode: ALT1 mux port: OUT of instance: PWM2
 * - 010 - Select mux mode: ALT2 mux port: SDA of instance: I2C3
 * - 011 - Select mux mode: ALT3 mux port: RTS_B of instance: UART1
 * - 100 - Select mux mode: ALT4 mux port: VCOM1 of instance: EPDC
 * - 101 - Select mux mode: ALT5 mux port: IO1 of instance: GPIO7
 * - 110 - Select mux mode: ALT6 mux port: COL3 of instance: KPP
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE_ALT0_ENET1_RGMII_RD1 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE: Select mux mode: ALT0 mux port: RGMII_RD1 of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE_ALT1_PWM2_OUT (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE: Select mux mode: ALT1 mux port: OUT of instance: PWM2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE_ALT2_I2C3_SDA (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE: Select mux mode: ALT2 mux port: SDA of instance: I2C3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE_ALT3_UART1_RTS_B (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE: Select mux mode: ALT3 mux port: RTS_B of instance: UART1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE_ALT4_EPDC_VCOM1 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE: Select mux mode: ALT4 mux port: VCOM1 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE_ALT5_GPIO7_IO1 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE: Select mux mode: ALT5 mux port: IO1 of instance: GPIO7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE_ALT6_KPP_COL3 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE: Select mux mode: ALT6 mux port: COL3 of instance: KPP */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_RGMII_RD1
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SION: Force input path of pad ENET1_RGMII_RD1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD1_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2 - SW_MUX_CTL_PAD_ENET1_RGMII_RD2 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2 - SW_MUX_CTL_PAD_ENET1_RGMII_RD2 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd2
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd2_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_ADDR(x) ((uintptr_t)(x) + 0x234U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd2_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ENET1_RGMII_RD2.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RGMII_RD2 of instance: ENET1
 * - 001 - Select mux mode: ALT1 mux port: RX of instance: FLEXCAN1
 * - 010 - Select mux mode: ALT2 mux port: SCLK of instance: ECSPI2
 * - 011 - Select mux mode: ALT3 mux port: RX_DATA of instance: UART1
 * - 100 - Select mux mode: ALT4 mux port: SDCE4 of instance: EPDC
 * - 101 - Select mux mode: ALT5 mux port: IO2 of instance: GPIO7
 * - 110 - Select mux mode: ALT6 mux port: ROW2 of instance: KPP
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE_ALT0_ENET1_RGMII_RD2 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE: Select mux mode: ALT0 mux port: RGMII_RD2 of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE_ALT1_FLEXCAN1_RX (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE: Select mux mode: ALT1 mux port: RX of instance: FLEXCAN1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE_ALT2_ECSPI2_SCLK (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE: Select mux mode: ALT2 mux port: SCLK of instance: ECSPI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE_ALT3_UART1_RX_DATA (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE: Select mux mode: ALT3 mux port: RX_DATA of instance: UART1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE_ALT4_EPDC_SDCE4 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE: Select mux mode: ALT4 mux port: SDCE4 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE_ALT5_GPIO7_IO2 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE: Select mux mode: ALT5 mux port: IO2 of instance: GPIO7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE_ALT6_KPP_ROW2 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE: Select mux mode: ALT6 mux port: ROW2 of instance: KPP */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_RGMII_RD2
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SION: Force input path of pad ENET1_RGMII_RD2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD2_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3 - SW_MUX_CTL_PAD_ENET1_RGMII_RD3 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3 - SW_MUX_CTL_PAD_ENET1_RGMII_RD3 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd3
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd3_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_ADDR(x) ((uintptr_t)(x) + 0x238U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd3_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ENET1_RGMII_RD3.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RGMII_RD3 of instance: ENET1
 * - 001 - Select mux mode: ALT1 mux port: TX of instance: FLEXCAN1
 * - 010 - Select mux mode: ALT2 mux port: MOSI of instance: ECSPI2
 * - 011 - Select mux mode: ALT3 mux port: TX_DATA of instance: UART1
 * - 100 - Select mux mode: ALT4 mux port: SDCE5 of instance: EPDC
 * - 101 - Select mux mode: ALT5 mux port: IO3 of instance: GPIO7
 * - 110 - Select mux mode: ALT6 mux port: COL2 of instance: KPP
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE_ALT0_ENET1_RGMII_RD3 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE: Select mux mode: ALT0 mux port: RGMII_RD3 of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE_ALT1_FLEXCAN1_TX (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE: Select mux mode: ALT1 mux port: TX of instance: FLEXCAN1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE_ALT2_ECSPI2_MOSI (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE: Select mux mode: ALT2 mux port: MOSI of instance: ECSPI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE_ALT3_UART1_TX_DATA (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE: Select mux mode: ALT3 mux port: TX_DATA of instance: UART1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE_ALT4_EPDC_SDCE5 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE: Select mux mode: ALT4 mux port: SDCE5 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE_ALT5_GPIO7_IO3 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE: Select mux mode: ALT5 mux port: IO3 of instance: GPIO7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE_ALT6_KPP_COL2 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE: Select mux mode: ALT6 mux port: COL2 of instance: KPP */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_RGMII_RD3
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SION: Force input path of pad ENET1_RGMII_RD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RD3_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL - SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL - SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rx_ctl
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rx_ctl_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rx_ctl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_ADDR(x) ((uintptr_t)(x) + 0x23CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rx_ctl_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: ENET1_RGMII_RX_CTL.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RGMII_RX_CTL of instance: ENET1
 * - 010 - Select mux mode: ALT2 mux port: SS1 of instance: ECSPI2
 * - 100 - Select mux mode: ALT4 mux port: SDCE6 of instance: EPDC
 * - 101 - Select mux mode: ALT5 mux port: IO4 of instance: GPIO7
 * - 110 - Select mux mode: ALT6 mux port: ROW1 of instance: KPP
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE_ALT0_ENET1_RGMII_RX_CTL (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE: Select mux mode: ALT0 mux port: RGMII_RX_CTL of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE_ALT2_ECSPI2_SS1 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE: Select mux mode: ALT2 mux port: SS1 of instance: ECSPI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE_ALT4_EPDC_SDCE6 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE: Select mux mode: ALT4 mux port: SDCE6 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE_ALT5_GPIO7_IO4 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE: Select mux mode: ALT5 mux port: IO4 of instance: GPIO7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE_ALT6_KPP_ROW1 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE: Select mux mode: ALT6 mux port: ROW1 of instance: KPP */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_RGMII_RX_CTL
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SION: Force input path of pad ENET1_RGMII_RX_CTL */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC - SW_MUX_CTL_PAD_ENET1_RGMII_RXC SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC - SW_MUX_CTL_PAD_ENET1_RGMII_RXC SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rxc
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rxc_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rxc_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_ADDR(x) ((uintptr_t)(x) + 0x240U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rxc_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: ENET1_RGMII_RXC.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RGMII_RXC of instance: ENET1
 * - 001 - Select mux mode: ALT1 mux port: RX_ER of instance: ENET1
 * - 010 - Select mux mode: ALT2 mux port: SS2 of instance: ECSPI2
 * - 100 - Select mux mode: ALT4 mux port: SDCE7 of instance: EPDC
 * - 101 - Select mux mode: ALT5 mux port: IO5 of instance: GPIO7
 * - 110 - Select mux mode: ALT6 mux port: COL1 of instance: KPP
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE_ALT0_ENET1_RGMII_RXC (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE: Select mux mode: ALT0 mux port: RGMII_RXC of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE_ALT1_ENET1_RX_ER (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE: Select mux mode: ALT1 mux port: RX_ER of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE_ALT2_ECSPI2_SS2 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE: Select mux mode: ALT2 mux port: SS2 of instance: ECSPI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE_ALT4_EPDC_SDCE7 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE: Select mux mode: ALT4 mux port: SDCE7 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE_ALT5_GPIO7_IO5 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE: Select mux mode: ALT5 mux port: IO5 of instance: GPIO7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE_ALT6_KPP_COL1 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE: Select mux mode: ALT6 mux port: COL1 of instance: KPP */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_RGMII_RXC
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SION: Force input path of pad ENET1_RGMII_RXC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_RXC_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0 - SW_MUX_CTL_PAD_ENET1_RGMII_TD0 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0 - SW_MUX_CTL_PAD_ENET1_RGMII_TD0 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td0
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td0_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_ADDR(x) ((uintptr_t)(x) + 0x244U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td0_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: ENET1_RGMII_TD0.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RGMII_TD0 of instance: ENET1
 * - 001 - Select mux mode: ALT1 mux port: OUT of instance: PWM3
 * - 010 - Select mux mode: ALT2 mux port: SS3 of instance: ECSPI2
 * - 100 - Select mux mode: ALT4 mux port: SDCE8 of instance: EPDC
 * - 101 - Select mux mode: ALT5 mux port: IO6 of instance: GPIO7
 * - 110 - Select mux mode: ALT6 mux port: ROW0 of instance: KPP
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE_ALT0_ENET1_RGMII_TD0 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE: Select mux mode: ALT0 mux port: RGMII_TD0 of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE_ALT1_PWM3_OUT (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE: Select mux mode: ALT1 mux port: OUT of instance: PWM3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE_ALT2_ECSPI2_SS3 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE: Select mux mode: ALT2 mux port: SS3 of instance: ECSPI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE_ALT4_EPDC_SDCE8 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE: Select mux mode: ALT4 mux port: SDCE8 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE_ALT5_GPIO7_IO6 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE: Select mux mode: ALT5 mux port: IO6 of instance: GPIO7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE_ALT6_KPP_ROW0 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE: Select mux mode: ALT6 mux port: ROW0 of instance: KPP */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_RGMII_TD0
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SION: Force input path of pad ENET1_RGMII_TD0 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD0_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1 - SW_MUX_CTL_PAD_ENET1_RGMII_TD1 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1 - SW_MUX_CTL_PAD_ENET1_RGMII_TD1 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td1
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td1_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_ADDR(x) ((uintptr_t)(x) + 0x248U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td1_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: ENET1_RGMII_TD1.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RGMII_TD1 of instance: ENET1
 * - 001 - Select mux mode: ALT1 mux port: OUT of instance: PWM4
 * - 010 - Select mux mode: ALT2 mux port: RDY of instance: ECSPI2
 * - 100 - Select mux mode: ALT4 mux port: SDCE9 of instance: EPDC
 * - 101 - Select mux mode: ALT5 mux port: IO7 of instance: GPIO7
 * - 110 - Select mux mode: ALT6 mux port: COL0 of instance: KPP
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE_ALT0_ENET1_RGMII_TD1 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE: Select mux mode: ALT0 mux port: RGMII_TD1 of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE_ALT1_PWM4_OUT (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE: Select mux mode: ALT1 mux port: OUT of instance: PWM4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE_ALT2_ECSPI2_RDY (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE: Select mux mode: ALT2 mux port: RDY of instance: ECSPI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE_ALT4_EPDC_SDCE9 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE: Select mux mode: ALT4 mux port: SDCE9 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE_ALT5_GPIO7_IO7 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE: Select mux mode: ALT5 mux port: IO7 of instance: GPIO7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE_ALT6_KPP_COL0 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE: Select mux mode: ALT6 mux port: COL0 of instance: KPP */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_RGMII_TD1
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SION: Force input path of pad ENET1_RGMII_TD1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD1_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2 - SW_MUX_CTL_PAD_ENET1_RGMII_TD2 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2 - SW_MUX_CTL_PAD_ENET1_RGMII_TD2 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td2
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td2_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_ADDR(x) ((uintptr_t)(x) + 0x24CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td2_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: ENET1_RGMII_TD2.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RGMII_TD2 of instance: ENET1
 * - 001 - Select mux mode: ALT1 mux port: RX of instance: FLEXCAN2
 * - 010 - Select mux mode: ALT2 mux port: MISO of instance: ECSPI2
 * - 011 - Select mux mode: ALT3 mux port: SCL of instance: I2C4
 * - 100 - Select mux mode: ALT4 mux port: SDOED of instance: EPDC
 * - 101 - Select mux mode: ALT5 mux port: IO8 of instance: GPIO7
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE_ALT0_ENET1_RGMII_TD2 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE: Select mux mode: ALT0 mux port: RGMII_TD2 of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE_ALT1_FLEXCAN2_RX (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE: Select mux mode: ALT1 mux port: RX of instance: FLEXCAN2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE_ALT2_ECSPI2_MISO (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE: Select mux mode: ALT2 mux port: MISO of instance: ECSPI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE_ALT3_I2C4_SCL (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE: Select mux mode: ALT3 mux port: SCL of instance: I2C4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE_ALT4_EPDC_SDOED (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE: Select mux mode: ALT4 mux port: SDOED of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE_ALT5_GPIO7_IO8 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE: Select mux mode: ALT5 mux port: IO8 of instance: GPIO7 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_RGMII_TD2
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SION: Force input path of pad ENET1_RGMII_TD2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD2_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3 - SW_MUX_CTL_PAD_ENET1_RGMII_TD3 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3 - SW_MUX_CTL_PAD_ENET1_RGMII_TD3 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td3
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td3_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3 register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_ADDR(x) ((uintptr_t)(x) + 0x250U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td3_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: ENET1_RGMII_TD3.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RGMII_TD3 of instance: ENET1
 * - 001 - Select mux mode: ALT1 mux port: TX of instance: FLEXCAN2
 * - 010 - Select mux mode: ALT2 mux port: SS0 of instance: ECSPI2
 * - 011 - Select mux mode: ALT3 mux port: SDA of instance: I2C4
 * - 100 - Select mux mode: ALT4 mux port: SDOEZ of instance: EPDC
 * - 101 - Select mux mode: ALT5 mux port: IO9 of instance: GPIO7
 * - 111 - Select mux mode: ALT7 mux port: RNG_OSC_OBS of instance: CAAM
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE_ALT0_ENET1_RGMII_TD3 (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE: Select mux mode: ALT0 mux port: RGMII_TD3 of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE_ALT1_FLEXCAN2_TX (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE: Select mux mode: ALT1 mux port: TX of instance: FLEXCAN2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE_ALT2_ECSPI2_SS0 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE: Select mux mode: ALT2 mux port: SS0 of instance: ECSPI2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE_ALT3_I2C4_SDA (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE: Select mux mode: ALT3 mux port: SDA of instance: I2C4 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE_ALT4_EPDC_SDOEZ (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE: Select mux mode: ALT4 mux port: SDOEZ of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE_ALT5_GPIO7_IO9 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE: Select mux mode: ALT5 mux port: IO9 of instance: GPIO7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE_ALT7_CAAM_RNG_OSC_OBS (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE: Select mux mode: ALT7 mux port: RNG_OSC_OBS of instance: CAAM */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_RGMII_TD3
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SION: Force input path of pad ENET1_RGMII_TD3 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TD3_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL - SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL - SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_tx_ctl
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_tx_ctl_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_tx_ctl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_ADDR(x) ((uintptr_t)(x) + 0x254U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_tx_ctl_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: ENET1_RGMII_TX_CTL.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RGMII_TX_CTL of instance: ENET1
 * - 010 - Select mux mode: ALT2 mux port: RX_SYNC of instance: SAI1
 * - 011 - Select mux mode: ALT3 mux port: COMPARE1 of instance: GPT2
 * - 100 - Select mux mode: ALT4 mux port: PWR_CTRL2 of instance: EPDC
 * - 101 - Select mux mode: ALT5 mux port: IO10 of instance: GPIO7
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE_ALT0_ENET1_RGMII_TX_CTL (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE: Select mux mode: ALT0 mux port: RGMII_TX_CTL of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE_ALT2_SAI1_RX_SYNC (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE: Select mux mode: ALT2 mux port: RX_SYNC of instance: SAI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE_ALT3_GPT2_COMPARE1 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE: Select mux mode: ALT3 mux port: COMPARE1 of instance: GPT2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE_ALT4_EPDC_PWR_CTRL2 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE: Select mux mode: ALT4 mux port: PWR_CTRL2 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE_ALT5_GPIO7_IO10 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE: Select mux mode: ALT5 mux port: IO10 of instance: GPIO7 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_RGMII_TX_CTL
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SION: Force input path of pad ENET1_RGMII_TX_CTL */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC - SW_MUX_CTL_PAD_ENET1_RGMII_TXC SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC - SW_MUX_CTL_PAD_ENET1_RGMII_TXC SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_txc
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_txc_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_txc_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_ADDR(x) ((uintptr_t)(x) + 0x258U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_txc_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 6 iomux modes to be used for pad: ENET1_RGMII_TXC.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RGMII_TXC of instance: ENET1
 * - 001 - Select mux mode: ALT1 mux port: TX_ER of instance: ENET1
 * - 010 - Select mux mode: ALT2 mux port: RX_BCLK of instance: SAI1
 * - 011 - Select mux mode: ALT3 mux port: COMPARE2 of instance: GPT2
 * - 100 - Select mux mode: ALT4 mux port: PWR_CTRL3 of instance: EPDC
 * - 101 - Select mux mode: ALT5 mux port: IO11 of instance: GPIO7
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE_ALT0_ENET1_RGMII_TXC (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE: Select mux mode: ALT0 mux port: RGMII_TXC of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE_ALT1_ENET1_TX_ER (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE: Select mux mode: ALT1 mux port: TX_ER of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE_ALT2_SAI1_RX_BCLK (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE: Select mux mode: ALT2 mux port: RX_BCLK of instance: SAI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE_ALT3_GPT2_COMPARE2 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE: Select mux mode: ALT3 mux port: COMPARE2 of instance: GPT2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE_ALT4_EPDC_PWR_CTRL3 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE: Select mux mode: ALT4 mux port: PWR_CTRL3 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE_ALT5_GPIO7_IO11 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE: Select mux mode: ALT5 mux port: IO11 of instance: GPIO7 */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_RGMII_TXC
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SION: Force input path of pad ENET1_RGMII_TXC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RGMII_TXC_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK - SW_MUX_CTL_PAD_ENET1_TX_CLK SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK - SW_MUX_CTL_PAD_ENET1_TX_CLK SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_tx_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_tx_clk_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_tx_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_ADDR(x) ((uintptr_t)(x) + 0x25CU)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_tx_clk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ENET1_TX_CLK.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: TX_CLK of instance: ENET1
 * - 001 - Select mux mode: ALT1 mux port: ENET1_REF_CLK of instance: ENET1
 * - 010 - Select mux mode: ALT2 mux port: RX_DATA0 of instance: SAI1
 * - 011 - Select mux mode: ALT3 mux port: COMPARE3 of instance: GPT2
 * - 100 - Select mux mode: ALT4 mux port: PWR_IRQ of instance: EPDC
 * - 101 - Select mux mode: ALT5 mux port: IO12 of instance: GPIO7
 * - 110 - Select mux mode: ALT6 mux port: EXT_CLK1 of instance: CCM
 * - 111 - Select mux mode: ALT7 mux port: CSU_ALARM_AUT0 of instance: CSU
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE_ALT0_ENET1_TX_CLK (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE: Select mux mode: ALT0 mux port: TX_CLK of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE_ALT1_CCM_ENET1_REF_CLK (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE: Select mux mode: ALT1 mux port: ENET1_REF_CLK of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE_ALT2_SAI1_RX_DATA0 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE: Select mux mode: ALT2 mux port: RX_DATA0 of instance: SAI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE_ALT3_GPT2_COMPARE3 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE: Select mux mode: ALT3 mux port: COMPARE3 of instance: GPT2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE_ALT4_EPDC_PWR_IRQ (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE: Select mux mode: ALT4 mux port: PWR_IRQ of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE_ALT5_GPIO7_IO12 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE: Select mux mode: ALT5 mux port: IO12 of instance: GPIO7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE_ALT6_CCM_EXT_CLK1 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE: Select mux mode: ALT6 mux port: EXT_CLK1 of instance: CCM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE_ALT7_CSU_ALARM_AUT0 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE: Select mux mode: ALT7 mux port: CSU_ALARM_AUT0 of instance: CSU */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_TX_CLK
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION: Force input path of pad ENET1_TX_CLK */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_TX_CLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK - SW_MUX_CTL_PAD_ENET1_RX_CLK SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK - SW_MUX_CTL_PAD_ENET1_RX_CLK SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_rx_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_rx_clk_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_rx_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_ADDR(x) ((uintptr_t)(x) + 0x260U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_rx_clk_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ENET1_RX_CLK.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: RX_CLK of instance: ENET1
 * - 001 - Select mux mode: ALT1 mux port: WDOG_B of instance: WDOG2
 * - 010 - Select mux mode: ALT2 mux port: TX_BCLK of instance: SAI1
 * - 011 - Select mux mode: ALT3 mux port: CLK of instance: GPT2
 * - 100 - Select mux mode: ALT4 mux port: PWR_WAKE of instance: EPDC
 * - 101 - Select mux mode: ALT5 mux port: IO13 of instance: GPIO7
 * - 110 - Select mux mode: ALT6 mux port: EXT_CLK2 of instance: CCM
 * - 111 - Select mux mode: ALT7 mux port: CSU_ALARM_AUT1 of instance: CSU
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE_ALT0_ENET1_RX_CLK (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE: Select mux mode: ALT0 mux port: RX_CLK of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE_ALT1_WDOG2_WDOG_B (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE: Select mux mode: ALT1 mux port: WDOG_B of instance: WDOG2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE_ALT2_SAI1_TX_BCLK (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE: Select mux mode: ALT2 mux port: TX_BCLK of instance: SAI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE_ALT3_GPT2_CLK (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE: Select mux mode: ALT3 mux port: CLK of instance: GPT2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE_ALT4_EPDC_PWR_WAKE (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE: Select mux mode: ALT4 mux port: PWR_WAKE of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE_ALT5_GPIO7_IO13 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE: Select mux mode: ALT5 mux port: IO13 of instance: GPIO7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE_ALT6_CCM_EXT_CLK2 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE: Select mux mode: ALT6 mux port: EXT_CLK2 of instance: CCM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE_ALT7_CSU_ALARM_AUT1 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE: Select mux mode: ALT7 mux port: CSU_ALARM_AUT1 of instance: CSU */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_RX_CLK
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION: Force input path of pad ENET1_RX_CLK */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_RX_CLK_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS - SW_MUX_CTL_PAD_ENET1_CRS SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS - SW_MUX_CTL_PAD_ENET1_CRS SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_crs
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_crs_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_crs_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_ADDR(x) ((uintptr_t)(x) + 0x264U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_crs_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ENET1_CRS.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: CRS of instance: ENET1
 * - 001 - Select mux mode: ALT1 mux port: WDOG_RST_B_DEB of instance: WDOG2
 * - 010 - Select mux mode: ALT2 mux port: TX_SYNC of instance: SAI1
 * - 011 - Select mux mode: ALT3 mux port: CAPTURE1 of instance: GPT2
 * - 100 - Select mux mode: ALT4 mux port: PWR_CTRL0 of instance: EPDC
 * - 101 - Select mux mode: ALT5 mux port: IO14 of instance: GPIO7
 * - 110 - Select mux mode: ALT6 mux port: EXT_CLK3 of instance: CCM
 * - 111 - Select mux mode: ALT7 mux port: CSU_ALARM_AUT2 of instance: CSU
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE_ALT0_ENET1_CRS (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE: Select mux mode: ALT0 mux port: CRS of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE_ALT1_WDOG2_WDOG_RST_B_DEB (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE: Select mux mode: ALT1 mux port: WDOG_RST_B_DEB of instance: WDOG2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE_ALT2_SAI1_TX_SYNC (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE: Select mux mode: ALT2 mux port: TX_SYNC of instance: SAI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE_ALT3_GPT2_CAPTURE1 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE: Select mux mode: ALT3 mux port: CAPTURE1 of instance: GPT2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE_ALT4_EPDC_PWR_CTRL0 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE: Select mux mode: ALT4 mux port: PWR_CTRL0 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE_ALT5_GPIO7_IO14 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE: Select mux mode: ALT5 mux port: IO14 of instance: GPIO7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE_ALT6_CCM_EXT_CLK3 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE: Select mux mode: ALT6 mux port: EXT_CLK3 of instance: CCM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE_ALT7_CSU_ALARM_AUT2 (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE: Select mux mode: ALT7 mux port: CSU_ALARM_AUT2 of instance: CSU */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_CRS
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION: Force input path of pad ENET1_CRS */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_CRS_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL - SW_MUX_CTL_PAD_ENET1_COL SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL - SW_MUX_CTL_PAD_ENET1_COL SW MUX Control Register (RW)
 *
 * Reset value: 0x00000005U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_sw_mux_ctl_pad_enet1_col
{
    uint32_t U;
    struct _hw_iomuxc_sw_mux_ctl_pad_enet1_col_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_sw_mux_ctl_pad_enet1_col_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_MUX_CTL_PAD_ENET1_COL register
 */
/*@{*/
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_ADDR(x) ((uintptr_t)(x) + 0x268U)

#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL(x) (*(__IO hw_iomuxc_sw_mux_ctl_pad_enet1_col_t *) HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_ADDR(x))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_RD(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL(x).U)
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_WR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL(x).U = (v))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SET(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_RD(x) |  (v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_CLR(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_TOG(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_WR(x, HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_MUX_CTL_PAD_ENET1_COL bitfields
 */

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_COL, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: ENET1_COL.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: COL of instance: ENET1
 * - 001 - Select mux mode: ALT1 mux port: WDOG_ANY of instance: WDOG1
 * - 010 - Select mux mode: ALT2 mux port: TX_DATA0 of instance: SAI1
 * - 011 - Select mux mode: ALT3 mux port: CAPTURE2 of instance: GPT2
 * - 100 - Select mux mode: ALT4 mux port: PWR_CTRL1 of instance: EPDC
 * - 101 - Select mux mode: ALT5 mux port: IO15 of instance: GPIO7
 * - 110 - Select mux mode: ALT6 mux port: EXT_CLK4 of instance: CCM
 * - 111 - Select mux mode: ALT7 mux port: CSU_INT_DEB of instance: CSU
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE (0U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE_ALT0_ENET1_COL (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE: Select mux mode: ALT0 mux port: COL of instance: ENET1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE_ALT1_WDOG1_WDOG_ANY (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE: Select mux mode: ALT1 mux port: WDOG_ANY of instance: WDOG1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE_ALT2_SAI1_TX_DATA0 (0x2U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE: Select mux mode: ALT2 mux port: TX_DATA0 of instance: SAI1 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE_ALT3_GPT2_CAPTURE2 (0x3U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE: Select mux mode: ALT3 mux port: CAPTURE2 of instance: GPT2 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE_ALT4_EPDC_PWR_CTRL1 (0x4U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE: Select mux mode: ALT4 mux port: PWR_CTRL1 of instance: EPDC */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE_ALT5_GPIO7_IO15 (0x5U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE: Select mux mode: ALT5 mux port: IO15 of instance: GPIO7 */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE_ALT6_CCM_EXT_CLK4 (0x6U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE: Select mux mode: ALT6 mux port: EXT_CLK4 of instance: CCM */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE_ALT7_CSU_INT_DEB (0x7U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE: Select mux mode: ALT7 mux port: CSU_INT_DEB of instance: CSU */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_MUX_CTL_PAD_ENET1_COL, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad ENET1_COL
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION (4U) /*!< Bit position for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION. */
#define BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION (0x00000010U) /*!< Bit mask for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION. */
#define BS_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION (1U) /*!< Bit field size in bits for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION. */

#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION: Force input path of pad ENET1_COL */
#define BV_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION field. */
#define BR_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION(x) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION. */
#define BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION) & BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION(x, v) (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_WR(x, (HW_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_RD(x) & ~BM_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION) | BF_IOMUXC_SW_MUX_CTL_PAD_ENET1_COL_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08 - SW_PAD_CTL_PAD_GPIO1_IO08 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08 - SW_PAD_CTL_PAD_GPIO1_IO08 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io08
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io08_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io08_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ADDR(x) ((uintptr_t)(x) + 0x26CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io08_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO08
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08, field SRE[2] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO08
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08, field HYS[3] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO08
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08, field PE[4] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO08
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO08
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO08_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09 - SW_PAD_CTL_PAD_GPIO1_IO09 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09 - SW_PAD_CTL_PAD_GPIO1_IO09 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io09
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io09_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io09_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ADDR(x) ((uintptr_t)(x) + 0x270U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io09_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO09
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09, field SRE[2] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO09
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09, field HYS[3] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO09
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09, field PE[4] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO09
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO09
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO09_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10 - SW_PAD_CTL_PAD_GPIO1_IO10 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10 - SW_PAD_CTL_PAD_GPIO1_IO10 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io10
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io10_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io10_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ADDR(x) ((uintptr_t)(x) + 0x274U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io10_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO10
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10, field SRE[2] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO10
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10, field HYS[3] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO10
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10, field PE[4] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO10
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO10
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO10_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11 - SW_PAD_CTL_PAD_GPIO1_IO11 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11 - SW_PAD_CTL_PAD_GPIO1_IO11 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io11
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io11_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io11_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ADDR(x) ((uintptr_t)(x) + 0x278U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io11_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO11
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11, field SRE[2] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO11
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11, field HYS[3] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO11
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11, field PE[4] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO11
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO11
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO11_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12 - SW_PAD_CTL_PAD_GPIO1_IO12 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12 - SW_PAD_CTL_PAD_GPIO1_IO12 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io12
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io12_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io12_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ADDR(x) ((uintptr_t)(x) + 0x27CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io12_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO12
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12, field SRE[2] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO12
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12, field HYS[3] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO12
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12, field PE[4] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO12
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO12
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO12_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13 - SW_PAD_CTL_PAD_GPIO1_IO13 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13 - SW_PAD_CTL_PAD_GPIO1_IO13 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io13
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io13_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io13_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ADDR(x) ((uintptr_t)(x) + 0x280U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io13_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO13
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13, field SRE[2] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO13
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13, field HYS[3] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO13
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13, field PE[4] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO13
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO13
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO13_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14 - SW_PAD_CTL_PAD_GPIO1_IO14 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14 - SW_PAD_CTL_PAD_GPIO1_IO14 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io14
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io14_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io14_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_ADDR(x) ((uintptr_t)(x) + 0x284U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io14_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO14
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14, field SRE[2] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO14
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14, field HYS[3] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO14
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14, field PE[4] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO14
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO14
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO14_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15 - SW_PAD_CTL_PAD_GPIO1_IO15 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15 - SW_PAD_CTL_PAD_GPIO1_IO15 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_gpio1_io15
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_gpio1_io15_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_gpio1_io15_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_ADDR(x) ((uintptr_t)(x) + 0x288U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io15_t *) HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO15
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15, field SRE[2] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO15
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15, field HYS[3] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO15
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15, field PE[4] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO15
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO15
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_GPIO1_IO15_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD - SW_PAD_CTL_PAD_JTAG_MOD SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD - SW_PAD_CTL_PAD_JTAG_MOD SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_jtag_mod
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_jtag_mod_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_jtag_mod_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_ADDR(x) ((uintptr_t)(x) + 0x28CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_jtag_mod_t *) HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD, field DSE[1:0] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 00 - X1
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_DSE_DSE (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_DSE: X1 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD, field SRE[2] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SRE_SRE (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD(x).B.SRE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD, field HYS[3] (RW)
 *
 * Select one out of next values for pad: JTAG_MOD
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD, field PE[4] (RW)
 *
 * Select one out of next values for pad: JTAG_MOD
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: JTAG_MOD
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_MOD_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK - SW_PAD_CTL_PAD_JTAG_TCK SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK - SW_PAD_CTL_PAD_JTAG_TCK SW PAD Control Register (RW)
 *
 * Reset value: 0x00000054U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_jtag_tck
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_jtag_tck_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_jtag_tck_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_ADDR(x) ((uintptr_t)(x) + 0x290U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_jtag_tck_t *) HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK, field DSE[1:0] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 00 - X1
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_DSE_DSE (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_DSE: X1 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK, field SRE[2] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SRE_SRE (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK(x).B.SRE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK, field HYS[3] (RW)
 *
 * Select one out of next values for pad: JTAG_TCK
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK, field PE[4] (RW)
 *
 * Select one out of next values for pad: JTAG_TCK
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: JTAG_TCK
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TCK_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI - SW_PAD_CTL_PAD_JTAG_TDI SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI - SW_PAD_CTL_PAD_JTAG_TDI SW PAD Control Register (RW)
 *
 * Reset value: 0x00000054U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_jtag_tdi
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_jtag_tdi_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_jtag_tdi_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_ADDR(x) ((uintptr_t)(x) + 0x294U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_jtag_tdi_t *) HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI, field DSE[1:0] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 00 - X1
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_DSE_DSE (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_DSE: X1 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI, field SRE[2] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SRE_SRE (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI(x).B.SRE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI, field HYS[3] (RW)
 *
 * Select one out of next values for pad: JTAG_TDI
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI, field PE[4] (RW)
 *
 * Select one out of next values for pad: JTAG_TDI
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: JTAG_TDI
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDI_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO - SW_PAD_CTL_PAD_JTAG_TDO SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO - SW_PAD_CTL_PAD_JTAG_TDO SW PAD Control Register (RW)
 *
 * Reset value: 0x00000070U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_jtag_tdo
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_jtag_tdo_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_jtag_tdo_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_ADDR(x) ((uintptr_t)(x) + 0x298U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_jtag_tdo_t *) HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO, field DSE[1:0] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 00 - X1
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_DSE_DSE (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_DSE: X1 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO, field SRE[2] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 0 - Fast Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SRE_SRE (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SRE: Fast Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO(x).B.SRE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO, field HYS[3] (RW)
 *
 * Select one out of next values for pad: JTAG_TDO
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO, field PE[4] (RW)
 *
 * Select one out of next values for pad: JTAG_TDO
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: JTAG_TDO
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TDO_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS - SW_PAD_CTL_PAD_JTAG_TMS SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS - SW_PAD_CTL_PAD_JTAG_TMS SW PAD Control Register (RW)
 *
 * Reset value: 0x00000054U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_jtag_tms
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_jtag_tms_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_jtag_tms_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_ADDR(x) ((uintptr_t)(x) + 0x29CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_jtag_tms_t *) HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS, field DSE[1:0] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 00 - X1
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_DSE_DSE (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_DSE: X1 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS, field SRE[2] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SRE_SRE (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS(x).B.SRE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS, field HYS[3] (RW)
 *
 * Select one out of next values for pad: JTAG_TMS
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS, field PE[4] (RW)
 *
 * Select one out of next values for pad: JTAG_TMS
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: JTAG_TMS
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TMS_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B - SW_PAD_CTL_PAD_JTAG_TRST_B SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B - SW_PAD_CTL_PAD_JTAG_TRST_B SW PAD Control Register (RW)
 *
 * Reset value: 0x00000054U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_jtag_trst_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_jtag_trst_b_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_jtag_trst_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_ADDR(x) ((uintptr_t)(x) + 0x2A0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_jtag_trst_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B, field DSE[1:0] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 00 - X1
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_DSE_DSE (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_DSE: X1 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B, field SRE[2] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SRE_SRE (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B(x).B.SRE)
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B, field HYS[3] (RW)
 *
 * Select one out of next values for pad: JTAG_TRST_B
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B, field PE[4] (RW)
 *
 * Select one out of next values for pad: JTAG_TRST_B
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: JTAG_TRST_B
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_JTAG_TRST_B_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00 - SW_PAD_CTL_PAD_EPDC_DATA00 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00 - SW_PAD_CTL_PAD_EPDC_DATA00 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_data00
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_data00_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_data00_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_ADDR(x) ((uintptr_t)(x) + 0x2A4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_data00_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA00
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA00
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA00
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA00
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA00
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA00_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01 - SW_PAD_CTL_PAD_EPDC_DATA01 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01 - SW_PAD_CTL_PAD_EPDC_DATA01 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_data01
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_data01_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_data01_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_ADDR(x) ((uintptr_t)(x) + 0x2A8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_data01_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA01
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA01
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA01
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA01
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA01
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA01_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02 - SW_PAD_CTL_PAD_EPDC_DATA02 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02 - SW_PAD_CTL_PAD_EPDC_DATA02 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_data02
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_data02_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_data02_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_ADDR(x) ((uintptr_t)(x) + 0x2ACU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_data02_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA02
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA02
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA02
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA02
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA02
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA02_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03 - SW_PAD_CTL_PAD_EPDC_DATA03 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03 - SW_PAD_CTL_PAD_EPDC_DATA03 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_data03
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_data03_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_data03_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_ADDR(x) ((uintptr_t)(x) + 0x2B0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_data03_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA03
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA03
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA03
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA03
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA03
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA03_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04 - SW_PAD_CTL_PAD_EPDC_DATA04 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04 - SW_PAD_CTL_PAD_EPDC_DATA04 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_data04
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_data04_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_data04_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_ADDR(x) ((uintptr_t)(x) + 0x2B4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_data04_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA04
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA04
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA04
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA04
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA04
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA04_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05 - SW_PAD_CTL_PAD_EPDC_DATA05 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05 - SW_PAD_CTL_PAD_EPDC_DATA05 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_data05
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_data05_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_data05_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_ADDR(x) ((uintptr_t)(x) + 0x2B8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_data05_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA05
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA05
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA05
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA05
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA05
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA05_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06 - SW_PAD_CTL_PAD_EPDC_DATA06 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06 - SW_PAD_CTL_PAD_EPDC_DATA06 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_data06
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_data06_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_data06_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_ADDR(x) ((uintptr_t)(x) + 0x2BCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_data06_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA06
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA06
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA06
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA06
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA06
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA06_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07 - SW_PAD_CTL_PAD_EPDC_DATA07 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07 - SW_PAD_CTL_PAD_EPDC_DATA07 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_data07
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_data07_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_data07_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_ADDR(x) ((uintptr_t)(x) + 0x2C0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_data07_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA07
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA07
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA07
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA07
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA07
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA07_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08 - SW_PAD_CTL_PAD_EPDC_DATA08 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08 - SW_PAD_CTL_PAD_EPDC_DATA08 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_data08
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_data08_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_data08_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_ADDR(x) ((uintptr_t)(x) + 0x2C4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_data08_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA08
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA08
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA08
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA08
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA08
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA08_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09 - SW_PAD_CTL_PAD_EPDC_DATA09 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09 - SW_PAD_CTL_PAD_EPDC_DATA09 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_data09
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_data09_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_data09_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_ADDR(x) ((uintptr_t)(x) + 0x2C8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_data09_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA09
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA09
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA09
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA09
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA09
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA09_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10 - SW_PAD_CTL_PAD_EPDC_DATA10 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10 - SW_PAD_CTL_PAD_EPDC_DATA10 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_data10
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_data10_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_data10_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_ADDR(x) ((uintptr_t)(x) + 0x2CCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_data10_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA10
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA10
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA10
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA10
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA10
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA10_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11 - SW_PAD_CTL_PAD_EPDC_DATA11 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11 - SW_PAD_CTL_PAD_EPDC_DATA11 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_data11
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_data11_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_data11_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_ADDR(x) ((uintptr_t)(x) + 0x2D0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_data11_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA11
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA11
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA11
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA11
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA11
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA11_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12 - SW_PAD_CTL_PAD_EPDC_DATA12 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12 - SW_PAD_CTL_PAD_EPDC_DATA12 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_data12
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_data12_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_data12_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_ADDR(x) ((uintptr_t)(x) + 0x2D4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_data12_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA12
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA12
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA12
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA12
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA12
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA12_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13 - SW_PAD_CTL_PAD_EPDC_DATA13 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13 - SW_PAD_CTL_PAD_EPDC_DATA13 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_data13
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_data13_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_data13_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_ADDR(x) ((uintptr_t)(x) + 0x2D8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_data13_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA13
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA13
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA13
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA13
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA13
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA13_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14 - SW_PAD_CTL_PAD_EPDC_DATA14 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14 - SW_PAD_CTL_PAD_EPDC_DATA14 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_data14
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_data14_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_data14_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_ADDR(x) ((uintptr_t)(x) + 0x2DCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_data14_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA14
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA14
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA14
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA14
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA14
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA14_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15 - SW_PAD_CTL_PAD_EPDC_DATA15 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15 - SW_PAD_CTL_PAD_EPDC_DATA15 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_data15
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_data15_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_data15_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_ADDR(x) ((uintptr_t)(x) + 0x2E0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_data15_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA15
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA15
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA15
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA15
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_DATA15
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_DATA15_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK - SW_PAD_CTL_PAD_EPDC_SDCLK SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK - SW_PAD_CTL_PAD_EPDC_SDCLK SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_sdclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_sdclk_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_sdclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_ADDR(x) ((uintptr_t)(x) + 0x2E4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_sdclk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCLK
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCLK
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCLK
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCLK
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCLK
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCLK_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE - SW_PAD_CTL_PAD_EPDC_SDLE SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE - SW_PAD_CTL_PAD_EPDC_SDLE SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_sdle
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_sdle_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_sdle_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_ADDR(x) ((uintptr_t)(x) + 0x2E8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_sdle_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_SDLE
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_SDLE
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_SDLE
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_SDLE
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_SDLE
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDLE_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE - SW_PAD_CTL_PAD_EPDC_SDOE SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE - SW_PAD_CTL_PAD_EPDC_SDOE SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_sdoe
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_sdoe_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_sdoe_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_ADDR(x) ((uintptr_t)(x) + 0x2ECU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_sdoe_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_SDOE
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_SDOE
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_SDOE
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_SDOE
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_SDOE
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDOE_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR - SW_PAD_CTL_PAD_EPDC_SDSHR SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR - SW_PAD_CTL_PAD_EPDC_SDSHR SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_sdshr
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_sdshr_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_sdshr_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_ADDR(x) ((uintptr_t)(x) + 0x2F0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_sdshr_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_SDSHR
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_SDSHR
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_SDSHR
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_SDSHR
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_SDSHR
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDSHR_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0 - SW_PAD_CTL_PAD_EPDC_SDCE0 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0 - SW_PAD_CTL_PAD_EPDC_SDCE0 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_sdce0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_sdce0_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_sdce0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_ADDR(x) ((uintptr_t)(x) + 0x2F4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_sdce0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE0
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE0
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE0
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE0
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE0
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE0_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1 - SW_PAD_CTL_PAD_EPDC_SDCE1 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1 - SW_PAD_CTL_PAD_EPDC_SDCE1 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_sdce1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_sdce1_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_sdce1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_ADDR(x) ((uintptr_t)(x) + 0x2F8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_sdce1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE1
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE1
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE1
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE1
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE1
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE1_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2 - SW_PAD_CTL_PAD_EPDC_SDCE2 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2 - SW_PAD_CTL_PAD_EPDC_SDCE2 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_sdce2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_sdce2_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_sdce2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_ADDR(x) ((uintptr_t)(x) + 0x2FCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_sdce2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE2
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE2
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE2
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE2
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE2
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE2_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3 - SW_PAD_CTL_PAD_EPDC_SDCE3 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3 - SW_PAD_CTL_PAD_EPDC_SDCE3 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_sdce3
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_sdce3_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_sdce3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_ADDR(x) ((uintptr_t)(x) + 0x300U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_sdce3_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE3
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE3
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE3
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE3
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_SDCE3
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_SDCE3_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK - SW_PAD_CTL_PAD_EPDC_GDCLK SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK - SW_PAD_CTL_PAD_EPDC_GDCLK SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_gdclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_gdclk_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_gdclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_ADDR(x) ((uintptr_t)(x) + 0x304U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_gdclk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_GDCLK
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_GDCLK
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_GDCLK
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_GDCLK
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_GDCLK
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDCLK_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE - SW_PAD_CTL_PAD_EPDC_GDOE SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE - SW_PAD_CTL_PAD_EPDC_GDOE SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_gdoe
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_gdoe_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_gdoe_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_ADDR(x) ((uintptr_t)(x) + 0x308U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_gdoe_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_GDOE
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_GDOE
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_GDOE
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_GDOE
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_GDOE
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDOE_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL - SW_PAD_CTL_PAD_EPDC_GDRL SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL - SW_PAD_CTL_PAD_EPDC_GDRL SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_gdrl
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_gdrl_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_gdrl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_ADDR(x) ((uintptr_t)(x) + 0x30CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_gdrl_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_GDRL
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_GDRL
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_GDRL
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_GDRL
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_GDRL
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDRL_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP - SW_PAD_CTL_PAD_EPDC_GDSP SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP - SW_PAD_CTL_PAD_EPDC_GDSP SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_gdsp
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_gdsp_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_gdsp_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_ADDR(x) ((uintptr_t)(x) + 0x310U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_gdsp_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_GDSP
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_GDSP
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_GDSP
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_GDSP
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_GDSP
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_GDSP_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0 - SW_PAD_CTL_PAD_EPDC_BDR0 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0 - SW_PAD_CTL_PAD_EPDC_BDR0 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_bdr0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_bdr0_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_bdr0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_ADDR(x) ((uintptr_t)(x) + 0x314U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_bdr0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_BDR0
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_BDR0
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_BDR0
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_BDR0
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_BDR0
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR0_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1 - SW_PAD_CTL_PAD_EPDC_BDR1 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1 - SW_PAD_CTL_PAD_EPDC_BDR1 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_bdr1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_bdr1_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_bdr1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_ADDR(x) ((uintptr_t)(x) + 0x318U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_bdr1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_BDR1
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_BDR1
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_BDR1
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_BDR1
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_BDR1
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_BDR1_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM - SW_PAD_CTL_PAD_EPDC_PWR_COM SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM - SW_PAD_CTL_PAD_EPDC_PWR_COM SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_pwr_com
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_pwr_com_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_pwr_com_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_ADDR(x) ((uintptr_t)(x) + 0x31CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_pwr_com_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_PWR_COM
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_PWR_COM
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_PWR_COM
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_PWR_COM
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_PWR_COM
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_COM_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT - SW_PAD_CTL_PAD_EPDC_PWR_STAT SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT - SW_PAD_CTL_PAD_EPDC_PWR_STAT SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_epdc_pwr_stat
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_epdc_pwr_stat_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_epdc_pwr_stat_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_ADDR(x) ((uintptr_t)(x) + 0x320U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_epdc_pwr_stat_t *) HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: EPDC_PWR_STAT
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT, field SRE[2] (RW)
 *
 * Select one out of next values for pad: EPDC_PWR_STAT
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT, field HYS[3] (RW)
 *
 * Select one out of next values for pad: EPDC_PWR_STAT
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT, field PE[4] (RW)
 *
 * Select one out of next values for pad: EPDC_PWR_STAT
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: EPDC_PWR_STAT
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_EPDC_PWR_STAT_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK - SW_PAD_CTL_PAD_LCD_CLK SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK - SW_PAD_CTL_PAD_LCD_CLK SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_clk_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_ADDR(x) ((uintptr_t)(x) + 0x324U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_clk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_CLK, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_CLK
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_CLK, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_CLK
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_CLK, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_CLK
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_CLK, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_CLK
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_CLK, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_CLK
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_CLK_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE - SW_PAD_CTL_PAD_LCD_ENABLE SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE - SW_PAD_CTL_PAD_LCD_ENABLE SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_enable
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_enable_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_enable_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_ADDR(x) ((uintptr_t)(x) + 0x328U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_enable_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_ENABLE
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_ENABLE
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_ENABLE
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_ENABLE
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_ENABLE
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_ENABLE_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC - SW_PAD_CTL_PAD_LCD_HSYNC SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC - SW_PAD_CTL_PAD_LCD_HSYNC SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_hsync
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_hsync_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_hsync_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_ADDR(x) ((uintptr_t)(x) + 0x32CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_hsync_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_HSYNC
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_HSYNC
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_HSYNC
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_HSYNC
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_HSYNC
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_HSYNC_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC - SW_PAD_CTL_PAD_LCD_VSYNC SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC - SW_PAD_CTL_PAD_LCD_VSYNC SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_vsync
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_vsync_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_vsync_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_ADDR(x) ((uintptr_t)(x) + 0x330U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_vsync_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_VSYNC
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_VSYNC
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_VSYNC
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_VSYNC
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_VSYNC
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_VSYNC_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET - SW_PAD_CTL_PAD_LCD_RESET SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET - SW_PAD_CTL_PAD_LCD_RESET SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_reset
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_reset_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_reset_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_RESET register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_ADDR(x) ((uintptr_t)(x) + 0x334U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_reset_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_RESET bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_RESET, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_RESET
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_RESET, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_RESET
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_RESET, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_RESET
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_RESET, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_RESET
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_RESET, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_RESET
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_RESET_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00 - SW_PAD_CTL_PAD_LCD_DATA00 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00 - SW_PAD_CTL_PAD_LCD_DATA00 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data00
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data00_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data00_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_ADDR(x) ((uintptr_t)(x) + 0x338U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data00_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA00
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA00
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA00
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA00
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA00
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA00_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01 - SW_PAD_CTL_PAD_LCD_DATA01 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01 - SW_PAD_CTL_PAD_LCD_DATA01 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data01
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data01_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data01_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_ADDR(x) ((uintptr_t)(x) + 0x33CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data01_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA01
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA01
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA01
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA01
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA01
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA01_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02 - SW_PAD_CTL_PAD_LCD_DATA02 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02 - SW_PAD_CTL_PAD_LCD_DATA02 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data02
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data02_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data02_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_ADDR(x) ((uintptr_t)(x) + 0x340U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data02_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA02
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA02
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA02
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA02
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA02
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA02_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03 - SW_PAD_CTL_PAD_LCD_DATA03 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03 - SW_PAD_CTL_PAD_LCD_DATA03 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data03
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data03_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data03_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_ADDR(x) ((uintptr_t)(x) + 0x344U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data03_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA03
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA03
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA03
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA03
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA03
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA03_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04 - SW_PAD_CTL_PAD_LCD_DATA04 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04 - SW_PAD_CTL_PAD_LCD_DATA04 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data04
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data04_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data04_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_ADDR(x) ((uintptr_t)(x) + 0x348U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data04_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA04
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA04
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA04
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA04
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA04
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA04_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05 - SW_PAD_CTL_PAD_LCD_DATA05 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05 - SW_PAD_CTL_PAD_LCD_DATA05 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data05
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data05_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data05_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_ADDR(x) ((uintptr_t)(x) + 0x34CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data05_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA05
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA05
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA05
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA05
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA05
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA05_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06 - SW_PAD_CTL_PAD_LCD_DATA06 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06 - SW_PAD_CTL_PAD_LCD_DATA06 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data06
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data06_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data06_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_ADDR(x) ((uintptr_t)(x) + 0x350U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data06_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA06
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA06
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA06
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA06
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA06
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA06_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07 - SW_PAD_CTL_PAD_LCD_DATA07 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07 - SW_PAD_CTL_PAD_LCD_DATA07 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data07
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data07_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data07_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_ADDR(x) ((uintptr_t)(x) + 0x354U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data07_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA07
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA07
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA07
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA07
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA07
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA07_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08 - SW_PAD_CTL_PAD_LCD_DATA08 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08 - SW_PAD_CTL_PAD_LCD_DATA08 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data08
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data08_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data08_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_ADDR(x) ((uintptr_t)(x) + 0x358U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data08_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA08
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA08
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA08
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA08
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA08
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA08_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09 - SW_PAD_CTL_PAD_LCD_DATA09 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09 - SW_PAD_CTL_PAD_LCD_DATA09 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data09
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data09_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data09_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_ADDR(x) ((uintptr_t)(x) + 0x35CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data09_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA09
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA09
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA09
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA09
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA09
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA09_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10 - SW_PAD_CTL_PAD_LCD_DATA10 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10 - SW_PAD_CTL_PAD_LCD_DATA10 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data10
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data10_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data10_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_ADDR(x) ((uintptr_t)(x) + 0x360U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data10_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA10
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA10
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA10
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA10
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA10
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA10_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11 - SW_PAD_CTL_PAD_LCD_DATA11 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11 - SW_PAD_CTL_PAD_LCD_DATA11 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data11
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data11_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data11_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_ADDR(x) ((uintptr_t)(x) + 0x364U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data11_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA11
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA11
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA11
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA11
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA11
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA11_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12 - SW_PAD_CTL_PAD_LCD_DATA12 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12 - SW_PAD_CTL_PAD_LCD_DATA12 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data12
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data12_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data12_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_ADDR(x) ((uintptr_t)(x) + 0x368U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data12_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA12
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA12
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA12
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA12
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA12
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA12_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13 - SW_PAD_CTL_PAD_LCD_DATA13 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13 - SW_PAD_CTL_PAD_LCD_DATA13 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data13
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data13_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data13_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_ADDR(x) ((uintptr_t)(x) + 0x36CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data13_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA13
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA13
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA13
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA13
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA13
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA13_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14 - SW_PAD_CTL_PAD_LCD_DATA14 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14 - SW_PAD_CTL_PAD_LCD_DATA14 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data14
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data14_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data14_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_ADDR(x) ((uintptr_t)(x) + 0x370U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data14_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA14
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA14
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA14
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA14
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA14
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA14_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15 - SW_PAD_CTL_PAD_LCD_DATA15 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15 - SW_PAD_CTL_PAD_LCD_DATA15 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data15
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data15_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data15_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_ADDR(x) ((uintptr_t)(x) + 0x374U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data15_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA15
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA15
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA15
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA15
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA15
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA15_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16 - SW_PAD_CTL_PAD_LCD_DATA16 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16 - SW_PAD_CTL_PAD_LCD_DATA16 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data16
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data16_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data16_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_ADDR(x) ((uintptr_t)(x) + 0x378U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data16_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA16
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA16
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA16
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA16
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA16
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA16_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17 - SW_PAD_CTL_PAD_LCD_DATA17 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17 - SW_PAD_CTL_PAD_LCD_DATA17 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data17
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data17_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data17_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_ADDR(x) ((uintptr_t)(x) + 0x37CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data17_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA17
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA17
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA17
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA17
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA17
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA17_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18 - SW_PAD_CTL_PAD_LCD_DATA18 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18 - SW_PAD_CTL_PAD_LCD_DATA18 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data18
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data18_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data18_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_ADDR(x) ((uintptr_t)(x) + 0x380U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data18_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA18
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA18
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA18
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA18
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA18
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA18_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19 - SW_PAD_CTL_PAD_LCD_DATA19 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19 - SW_PAD_CTL_PAD_LCD_DATA19 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data19
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data19_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data19_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_ADDR(x) ((uintptr_t)(x) + 0x384U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data19_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA19
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA19
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA19
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA19
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA19
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA19_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20 - SW_PAD_CTL_PAD_LCD_DATA20 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20 - SW_PAD_CTL_PAD_LCD_DATA20 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data20
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data20_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data20_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_ADDR(x) ((uintptr_t)(x) + 0x388U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data20_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA20
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA20
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA20
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA20
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA20
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA20_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21 - SW_PAD_CTL_PAD_LCD_DATA21 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21 - SW_PAD_CTL_PAD_LCD_DATA21 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data21
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data21_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data21_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_ADDR(x) ((uintptr_t)(x) + 0x38CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data21_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA21
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA21
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA21
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA21
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA21
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA21_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22 - SW_PAD_CTL_PAD_LCD_DATA22 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22 - SW_PAD_CTL_PAD_LCD_DATA22 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data22
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data22_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data22_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_ADDR(x) ((uintptr_t)(x) + 0x390U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data22_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA22
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA22
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA22
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA22
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA22
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA22_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23 - SW_PAD_CTL_PAD_LCD_DATA23 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23 - SW_PAD_CTL_PAD_LCD_DATA23 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_lcd_data23
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_lcd_data23_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_lcd_data23_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_ADDR(x) ((uintptr_t)(x) + 0x394U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_lcd_data23_t *) HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: LCD_DATA23
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23, field SRE[2] (RW)
 *
 * Select one out of next values for pad: LCD_DATA23
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23, field HYS[3] (RW)
 *
 * Select one out of next values for pad: LCD_DATA23
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23, field PE[4] (RW)
 *
 * Select one out of next values for pad: LCD_DATA23
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: LCD_DATA23
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_LCD_DATA23_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA - SW_PAD_CTL_PAD_UART1_RX_DATA SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA - SW_PAD_CTL_PAD_UART1_RX_DATA SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_uart1_rx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_uart1_rx_data_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_uart1_rx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_ADDR(x) ((uintptr_t)(x) + 0x398U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_uart1_rx_data_t *) HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: UART1_RX_DATA
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA, field SRE[2] (RW)
 *
 * Select one out of next values for pad: UART1_RX_DATA
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA, field HYS[3] (RW)
 *
 * Select one out of next values for pad: UART1_RX_DATA
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA, field PE[4] (RW)
 *
 * Select one out of next values for pad: UART1_RX_DATA
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: UART1_RX_DATA
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_UART1_RX_DATA_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA - SW_PAD_CTL_PAD_UART1_TX_DATA SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA - SW_PAD_CTL_PAD_UART1_TX_DATA SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_uart1_tx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_uart1_tx_data_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_uart1_tx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_ADDR(x) ((uintptr_t)(x) + 0x39CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_uart1_tx_data_t *) HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: UART1_TX_DATA
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA, field SRE[2] (RW)
 *
 * Select one out of next values for pad: UART1_TX_DATA
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA, field HYS[3] (RW)
 *
 * Select one out of next values for pad: UART1_TX_DATA
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA, field PE[4] (RW)
 *
 * Select one out of next values for pad: UART1_TX_DATA
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: UART1_TX_DATA
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_UART1_TX_DATA_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA - SW_PAD_CTL_PAD_UART2_RX_DATA SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA - SW_PAD_CTL_PAD_UART2_RX_DATA SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_uart2_rx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_uart2_rx_data_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_uart2_rx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_ADDR(x) ((uintptr_t)(x) + 0x3A0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_uart2_rx_data_t *) HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: UART2_RX_DATA
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA, field SRE[2] (RW)
 *
 * Select one out of next values for pad: UART2_RX_DATA
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA, field HYS[3] (RW)
 *
 * Select one out of next values for pad: UART2_RX_DATA
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA, field PE[4] (RW)
 *
 * Select one out of next values for pad: UART2_RX_DATA
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: UART2_RX_DATA
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_UART2_RX_DATA_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA - SW_PAD_CTL_PAD_UART2_TX_DATA SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA - SW_PAD_CTL_PAD_UART2_TX_DATA SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_uart2_tx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_uart2_tx_data_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_uart2_tx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_ADDR(x) ((uintptr_t)(x) + 0x3A4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_uart2_tx_data_t *) HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: UART2_TX_DATA
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA, field SRE[2] (RW)
 *
 * Select one out of next values for pad: UART2_TX_DATA
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA, field HYS[3] (RW)
 *
 * Select one out of next values for pad: UART2_TX_DATA
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA, field PE[4] (RW)
 *
 * Select one out of next values for pad: UART2_TX_DATA
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: UART2_TX_DATA
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_UART2_TX_DATA_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA - SW_PAD_CTL_PAD_UART3_RX_DATA SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA - SW_PAD_CTL_PAD_UART3_RX_DATA SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_uart3_rx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_uart3_rx_data_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_uart3_rx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_ADDR(x) ((uintptr_t)(x) + 0x3A8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_uart3_rx_data_t *) HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: UART3_RX_DATA
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA, field SRE[2] (RW)
 *
 * Select one out of next values for pad: UART3_RX_DATA
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA, field HYS[3] (RW)
 *
 * Select one out of next values for pad: UART3_RX_DATA
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA, field PE[4] (RW)
 *
 * Select one out of next values for pad: UART3_RX_DATA
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: UART3_RX_DATA
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RX_DATA_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA - SW_PAD_CTL_PAD_UART3_TX_DATA SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA - SW_PAD_CTL_PAD_UART3_TX_DATA SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_uart3_tx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_uart3_tx_data_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_uart3_tx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_ADDR(x) ((uintptr_t)(x) + 0x3ACU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_uart3_tx_data_t *) HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: UART3_TX_DATA
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA, field SRE[2] (RW)
 *
 * Select one out of next values for pad: UART3_TX_DATA
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA, field HYS[3] (RW)
 *
 * Select one out of next values for pad: UART3_TX_DATA
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA, field PE[4] (RW)
 *
 * Select one out of next values for pad: UART3_TX_DATA
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: UART3_TX_DATA
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_TX_DATA_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B - SW_PAD_CTL_PAD_UART3_RTS_B SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B - SW_PAD_CTL_PAD_UART3_RTS_B SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_uart3_rts_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_uart3_rts_b_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_uart3_rts_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_ADDR(x) ((uintptr_t)(x) + 0x3B0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_uart3_rts_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: UART3_RTS_B
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B, field SRE[2] (RW)
 *
 * Select one out of next values for pad: UART3_RTS_B
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B, field HYS[3] (RW)
 *
 * Select one out of next values for pad: UART3_RTS_B
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B, field PE[4] (RW)
 *
 * Select one out of next values for pad: UART3_RTS_B
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: UART3_RTS_B
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_RTS_B_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B - SW_PAD_CTL_PAD_UART3_CTS_B SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B - SW_PAD_CTL_PAD_UART3_CTS_B SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_uart3_cts_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_uart3_cts_b_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_uart3_cts_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_ADDR(x) ((uintptr_t)(x) + 0x3B4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_uart3_cts_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: UART3_CTS_B
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B, field SRE[2] (RW)
 *
 * Select one out of next values for pad: UART3_CTS_B
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B, field HYS[3] (RW)
 *
 * Select one out of next values for pad: UART3_CTS_B
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B, field PE[4] (RW)
 *
 * Select one out of next values for pad: UART3_CTS_B
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: UART3_CTS_B
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_UART3_CTS_B_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL - SW_PAD_CTL_PAD_I2C1_SCL SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL - SW_PAD_CTL_PAD_I2C1_SCL SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_i2c1_scl
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_i2c1_scl_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_i2c1_scl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_ADDR(x) ((uintptr_t)(x) + 0x3B8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_i2c1_scl_t *) HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: I2C1_SCL
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL, field SRE[2] (RW)
 *
 * Select one out of next values for pad: I2C1_SCL
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL, field HYS[3] (RW)
 *
 * Select one out of next values for pad: I2C1_SCL
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL, field PE[4] (RW)
 *
 * Select one out of next values for pad: I2C1_SCL
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: I2C1_SCL
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SCL_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA - SW_PAD_CTL_PAD_I2C1_SDA SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA - SW_PAD_CTL_PAD_I2C1_SDA SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_i2c1_sda
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_i2c1_sda_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_i2c1_sda_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_ADDR(x) ((uintptr_t)(x) + 0x3BCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_i2c1_sda_t *) HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: I2C1_SDA
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA, field SRE[2] (RW)
 *
 * Select one out of next values for pad: I2C1_SDA
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA, field HYS[3] (RW)
 *
 * Select one out of next values for pad: I2C1_SDA
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA, field PE[4] (RW)
 *
 * Select one out of next values for pad: I2C1_SDA
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: I2C1_SDA
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C1_SDA_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL - SW_PAD_CTL_PAD_I2C2_SCL SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL - SW_PAD_CTL_PAD_I2C2_SCL SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_i2c2_scl
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_i2c2_scl_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_i2c2_scl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_ADDR(x) ((uintptr_t)(x) + 0x3C0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_i2c2_scl_t *) HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: I2C2_SCL
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL, field SRE[2] (RW)
 *
 * Select one out of next values for pad: I2C2_SCL
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL, field HYS[3] (RW)
 *
 * Select one out of next values for pad: I2C2_SCL
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL, field PE[4] (RW)
 *
 * Select one out of next values for pad: I2C2_SCL
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: I2C2_SCL
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SCL_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA - SW_PAD_CTL_PAD_I2C2_SDA SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA - SW_PAD_CTL_PAD_I2C2_SDA SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_i2c2_sda
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_i2c2_sda_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_i2c2_sda_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_ADDR(x) ((uintptr_t)(x) + 0x3C4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_i2c2_sda_t *) HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: I2C2_SDA
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA, field SRE[2] (RW)
 *
 * Select one out of next values for pad: I2C2_SDA
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA, field HYS[3] (RW)
 *
 * Select one out of next values for pad: I2C2_SDA
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA, field PE[4] (RW)
 *
 * Select one out of next values for pad: I2C2_SDA
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: I2C2_SDA
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C2_SDA_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL - SW_PAD_CTL_PAD_I2C3_SCL SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL - SW_PAD_CTL_PAD_I2C3_SCL SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_i2c3_scl
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_i2c3_scl_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_i2c3_scl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_ADDR(x) ((uintptr_t)(x) + 0x3C8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_i2c3_scl_t *) HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: I2C3_SCL
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL, field SRE[2] (RW)
 *
 * Select one out of next values for pad: I2C3_SCL
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL, field HYS[3] (RW)
 *
 * Select one out of next values for pad: I2C3_SCL
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL, field PE[4] (RW)
 *
 * Select one out of next values for pad: I2C3_SCL
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: I2C3_SCL
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SCL_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA - SW_PAD_CTL_PAD_I2C3_SDA SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA - SW_PAD_CTL_PAD_I2C3_SDA SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_i2c3_sda
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_i2c3_sda_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_i2c3_sda_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_ADDR(x) ((uintptr_t)(x) + 0x3CCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_i2c3_sda_t *) HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: I2C3_SDA
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA, field SRE[2] (RW)
 *
 * Select one out of next values for pad: I2C3_SDA
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA, field HYS[3] (RW)
 *
 * Select one out of next values for pad: I2C3_SDA
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA, field PE[4] (RW)
 *
 * Select one out of next values for pad: I2C3_SDA
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: I2C3_SDA
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C3_SDA_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL - SW_PAD_CTL_PAD_I2C4_SCL SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL - SW_PAD_CTL_PAD_I2C4_SCL SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_i2c4_scl
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_i2c4_scl_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_i2c4_scl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_ADDR(x) ((uintptr_t)(x) + 0x3D0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_i2c4_scl_t *) HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: I2C4_SCL
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL, field SRE[2] (RW)
 *
 * Select one out of next values for pad: I2C4_SCL
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL, field HYS[3] (RW)
 *
 * Select one out of next values for pad: I2C4_SCL
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL, field PE[4] (RW)
 *
 * Select one out of next values for pad: I2C4_SCL
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: I2C4_SCL
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SCL_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA - SW_PAD_CTL_PAD_I2C4_SDA SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA - SW_PAD_CTL_PAD_I2C4_SDA SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_i2c4_sda
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_i2c4_sda_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_i2c4_sda_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_ADDR(x) ((uintptr_t)(x) + 0x3D4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_i2c4_sda_t *) HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: I2C4_SDA
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA, field SRE[2] (RW)
 *
 * Select one out of next values for pad: I2C4_SDA
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA, field HYS[3] (RW)
 *
 * Select one out of next values for pad: I2C4_SDA
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA, field PE[4] (RW)
 *
 * Select one out of next values for pad: I2C4_SDA
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: I2C4_SDA
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_I2C4_SDA_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK - SW_PAD_CTL_PAD_ECSPI1_SCLK SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK - SW_PAD_CTL_PAD_ECSPI1_SCLK SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_ecspi1_sclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_ecspi1_sclk_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_ecspi1_sclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_ADDR(x) ((uintptr_t)(x) + 0x3D8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_ecspi1_sclk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ECSPI1_SCLK
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ECSPI1_SCLK
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ECSPI1_SCLK
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK, field PE[4] (RW)
 *
 * Select one out of next values for pad: ECSPI1_SCLK
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ECSPI1_SCLK
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SCLK_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI - SW_PAD_CTL_PAD_ECSPI1_MOSI SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI - SW_PAD_CTL_PAD_ECSPI1_MOSI SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_ecspi1_mosi
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_ecspi1_mosi_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_ecspi1_mosi_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_ADDR(x) ((uintptr_t)(x) + 0x3DCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_ecspi1_mosi_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ECSPI1_MOSI
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ECSPI1_MOSI
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ECSPI1_MOSI
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI, field PE[4] (RW)
 *
 * Select one out of next values for pad: ECSPI1_MOSI
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ECSPI1_MOSI
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MOSI_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO - SW_PAD_CTL_PAD_ECSPI1_MISO SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO - SW_PAD_CTL_PAD_ECSPI1_MISO SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_ecspi1_miso
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_ecspi1_miso_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_ecspi1_miso_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_ADDR(x) ((uintptr_t)(x) + 0x3E0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_ecspi1_miso_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ECSPI1_MISO
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ECSPI1_MISO
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ECSPI1_MISO
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO, field PE[4] (RW)
 *
 * Select one out of next values for pad: ECSPI1_MISO
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ECSPI1_MISO
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_MISO_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0 - SW_PAD_CTL_PAD_ECSPI1_SS0 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0 - SW_PAD_CTL_PAD_ECSPI1_SS0 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_ecspi1_ss0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_ecspi1_ss0_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_ecspi1_ss0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_ADDR(x) ((uintptr_t)(x) + 0x3E4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_ecspi1_ss0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ECSPI1_SS0
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ECSPI1_SS0
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ECSPI1_SS0
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0, field PE[4] (RW)
 *
 * Select one out of next values for pad: ECSPI1_SS0
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ECSPI1_SS0
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI1_SS0_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK - SW_PAD_CTL_PAD_ECSPI2_SCLK SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK - SW_PAD_CTL_PAD_ECSPI2_SCLK SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_ecspi2_sclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_ecspi2_sclk_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_ecspi2_sclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_ADDR(x) ((uintptr_t)(x) + 0x3E8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_ecspi2_sclk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ECSPI2_SCLK
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ECSPI2_SCLK
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ECSPI2_SCLK
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK, field PE[4] (RW)
 *
 * Select one out of next values for pad: ECSPI2_SCLK
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ECSPI2_SCLK
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SCLK_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI - SW_PAD_CTL_PAD_ECSPI2_MOSI SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI - SW_PAD_CTL_PAD_ECSPI2_MOSI SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_ecspi2_mosi
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_ecspi2_mosi_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_ecspi2_mosi_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_ADDR(x) ((uintptr_t)(x) + 0x3ECU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_ecspi2_mosi_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ECSPI2_MOSI
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ECSPI2_MOSI
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ECSPI2_MOSI
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI, field PE[4] (RW)
 *
 * Select one out of next values for pad: ECSPI2_MOSI
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ECSPI2_MOSI
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MOSI_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO - SW_PAD_CTL_PAD_ECSPI2_MISO SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO - SW_PAD_CTL_PAD_ECSPI2_MISO SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_ecspi2_miso
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_ecspi2_miso_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_ecspi2_miso_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_ADDR(x) ((uintptr_t)(x) + 0x3F0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_ecspi2_miso_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ECSPI2_MISO
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ECSPI2_MISO
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ECSPI2_MISO
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO, field PE[4] (RW)
 *
 * Select one out of next values for pad: ECSPI2_MISO
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ECSPI2_MISO
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_MISO_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0 - SW_PAD_CTL_PAD_ECSPI2_SS0 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0 - SW_PAD_CTL_PAD_ECSPI2_SS0 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_ecspi2_ss0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_ecspi2_ss0_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_ecspi2_ss0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_ADDR(x) ((uintptr_t)(x) + 0x3F4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_ecspi2_ss0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ECSPI2_SS0
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ECSPI2_SS0
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ECSPI2_SS0
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0, field PE[4] (RW)
 *
 * Select one out of next values for pad: ECSPI2_SS0
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ECSPI2_SS0
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ECSPI2_SS0_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B - SW_PAD_CTL_PAD_SD1_CD_B SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B - SW_PAD_CTL_PAD_SD1_CD_B SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd1_cd_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd1_cd_b_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd1_cd_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_ADDR(x) ((uintptr_t)(x) + 0x3F8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd1_cd_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD1_CD_B
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD1_CD_B
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD1_CD_B
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD1_CD_B
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD1_CD_B
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CD_B_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP - SW_PAD_CTL_PAD_SD1_WP SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP - SW_PAD_CTL_PAD_SD1_WP SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd1_wp
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd1_wp_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd1_wp_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD1_WP register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_ADDR(x) ((uintptr_t)(x) + 0x3FCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd1_wp_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD1_WP bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_WP, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD1_WP
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_WP, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD1_WP
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_WP, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD1_WP
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_WP_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_WP_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_WP, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD1_WP
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_WP, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD1_WP
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_WP_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B - SW_PAD_CTL_PAD_SD1_RESET_B SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B - SW_PAD_CTL_PAD_SD1_RESET_B SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd1_reset_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd1_reset_b_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd1_reset_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_ADDR(x) ((uintptr_t)(x) + 0x400U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd1_reset_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD1_RESET_B
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD1_RESET_B
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD1_RESET_B
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD1_RESET_B
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD1_RESET_B
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_RESET_B_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK - SW_PAD_CTL_PAD_SD1_CLK SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK - SW_PAD_CTL_PAD_SD1_CLK SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd1_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd1_clk_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd1_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD1_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ADDR(x) ((uintptr_t)(x) + 0x404U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd1_clk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD1_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CLK, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD1_CLK
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CLK, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD1_CLK
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CLK, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD1_CLK
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CLK, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD1_CLK
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CLK, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD1_CLK
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CLK_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD - SW_PAD_CTL_PAD_SD1_CMD SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD - SW_PAD_CTL_PAD_SD1_CMD SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd1_cmd
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd1_cmd_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd1_cmd_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD1_CMD register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ADDR(x) ((uintptr_t)(x) + 0x408U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd1_cmd_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD1_CMD bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CMD, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD1_CMD
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CMD, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD1_CMD
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CMD, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD1_CMD
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CMD, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD1_CMD
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_CMD, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD1_CMD
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_CMD_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0 - SW_PAD_CTL_PAD_SD1_DATA0 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0 - SW_PAD_CTL_PAD_SD1_DATA0 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd1_data0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd1_data0_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd1_data0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ADDR(x) ((uintptr_t)(x) + 0x40CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd1_data0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD1_DATA0
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD1_DATA0
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD1_DATA0
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD1_DATA0
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD1_DATA0
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA0_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1 - SW_PAD_CTL_PAD_SD1_DATA1 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1 - SW_PAD_CTL_PAD_SD1_DATA1 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd1_data1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd1_data1_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd1_data1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ADDR(x) ((uintptr_t)(x) + 0x410U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd1_data1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD1_DATA1
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD1_DATA1
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD1_DATA1
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD1_DATA1
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD1_DATA1
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA1_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2 - SW_PAD_CTL_PAD_SD1_DATA2 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2 - SW_PAD_CTL_PAD_SD1_DATA2 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd1_data2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd1_data2_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd1_data2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ADDR(x) ((uintptr_t)(x) + 0x414U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd1_data2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD1_DATA2
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD1_DATA2
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD1_DATA2
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD1_DATA2
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD1_DATA2
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA2_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3 - SW_PAD_CTL_PAD_SD1_DATA3 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3 - SW_PAD_CTL_PAD_SD1_DATA3 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd1_data3
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd1_data3_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd1_data3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ADDR(x) ((uintptr_t)(x) + 0x418U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd1_data3_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD1_DATA3
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD1_DATA3
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD1_DATA3
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD1_DATA3
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD1_DATA3
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD1_DATA3_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B - SW_PAD_CTL_PAD_SD2_CD_B SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B - SW_PAD_CTL_PAD_SD2_CD_B SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd2_cd_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd2_cd_b_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd2_cd_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_ADDR(x) ((uintptr_t)(x) + 0x41CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd2_cd_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD2_CD_B
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD2_CD_B
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD2_CD_B
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD2_CD_B
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD2_CD_B
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CD_B_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP - SW_PAD_CTL_PAD_SD2_WP SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP - SW_PAD_CTL_PAD_SD2_WP SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd2_wp
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd2_wp_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd2_wp_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD2_WP register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_ADDR(x) ((uintptr_t)(x) + 0x420U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd2_wp_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD2_WP bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_WP, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD2_WP
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_WP, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD2_WP
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_WP, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD2_WP
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_WP_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_WP_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_WP, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD2_WP
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_WP, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD2_WP
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_WP_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B - SW_PAD_CTL_PAD_SD2_RESET_B SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B - SW_PAD_CTL_PAD_SD2_RESET_B SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd2_reset_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd2_reset_b_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd2_reset_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_ADDR(x) ((uintptr_t)(x) + 0x424U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd2_reset_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD2_RESET_B
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD2_RESET_B
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD2_RESET_B
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD2_RESET_B
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD2_RESET_B
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_RESET_B_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK - SW_PAD_CTL_PAD_SD2_CLK SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK - SW_PAD_CTL_PAD_SD2_CLK SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd2_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd2_clk_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd2_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD2_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ADDR(x) ((uintptr_t)(x) + 0x428U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd2_clk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD2_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CLK, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD2_CLK
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CLK, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD2_CLK
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CLK, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD2_CLK
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CLK, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD2_CLK
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CLK, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD2_CLK
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CLK_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD - SW_PAD_CTL_PAD_SD2_CMD SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD - SW_PAD_CTL_PAD_SD2_CMD SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd2_cmd
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd2_cmd_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd2_cmd_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD2_CMD register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ADDR(x) ((uintptr_t)(x) + 0x42CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd2_cmd_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD2_CMD bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CMD, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD2_CMD
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CMD, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD2_CMD
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CMD, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD2_CMD
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CMD, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD2_CMD
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_CMD, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD2_CMD
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_CMD_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0 - SW_PAD_CTL_PAD_SD2_DATA0 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0 - SW_PAD_CTL_PAD_SD2_DATA0 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd2_data0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd2_data0_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd2_data0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ADDR(x) ((uintptr_t)(x) + 0x430U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd2_data0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD2_DATA0
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD2_DATA0
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD2_DATA0
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD2_DATA0
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD2_DATA0
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA0_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1 - SW_PAD_CTL_PAD_SD2_DATA1 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1 - SW_PAD_CTL_PAD_SD2_DATA1 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd2_data1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd2_data1_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd2_data1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ADDR(x) ((uintptr_t)(x) + 0x434U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd2_data1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD2_DATA1
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD2_DATA1
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD2_DATA1
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD2_DATA1
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD2_DATA1
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA1_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2 - SW_PAD_CTL_PAD_SD2_DATA2 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2 - SW_PAD_CTL_PAD_SD2_DATA2 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd2_data2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd2_data2_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd2_data2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ADDR(x) ((uintptr_t)(x) + 0x438U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd2_data2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD2_DATA2
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD2_DATA2
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD2_DATA2
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD2_DATA2
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD2_DATA2
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA2_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3 - SW_PAD_CTL_PAD_SD2_DATA3 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3 - SW_PAD_CTL_PAD_SD2_DATA3 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd2_data3
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd2_data3_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd2_data3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ADDR(x) ((uintptr_t)(x) + 0x43CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd2_data3_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD2_DATA3
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD2_DATA3
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD2_DATA3
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD2_DATA3
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD2_DATA3
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD2_DATA3_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK - SW_PAD_CTL_PAD_SD3_CLK SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK - SW_PAD_CTL_PAD_SD3_CLK SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_clk_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ADDR(x) ((uintptr_t)(x) + 0x440U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_clk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CLK, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD3_CLK
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CLK, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD3_CLK
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CLK, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD3_CLK
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CLK, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD3_CLK
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CLK, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD3_CLK
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CLK_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD - SW_PAD_CTL_PAD_SD3_CMD SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD - SW_PAD_CTL_PAD_SD3_CMD SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_cmd
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_cmd_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_cmd_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_CMD register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ADDR(x) ((uintptr_t)(x) + 0x444U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_cmd_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_CMD bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CMD, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD3_CMD
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CMD, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD3_CMD
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CMD, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD3_CMD
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CMD, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD3_CMD
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_CMD, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD3_CMD
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_CMD_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0 - SW_PAD_CTL_PAD_SD3_DATA0 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0 - SW_PAD_CTL_PAD_SD3_DATA0 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_data0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_data0_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_data0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ADDR(x) ((uintptr_t)(x) + 0x448U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_data0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD3_DATA0
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD3_DATA0
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD3_DATA0
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD3_DATA0
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD3_DATA0
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA0_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1 - SW_PAD_CTL_PAD_SD3_DATA1 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1 - SW_PAD_CTL_PAD_SD3_DATA1 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_data1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_data1_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_data1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ADDR(x) ((uintptr_t)(x) + 0x44CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_data1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD3_DATA1
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD3_DATA1
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD3_DATA1
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD3_DATA1
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD3_DATA1
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA1_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2 - SW_PAD_CTL_PAD_SD3_DATA2 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2 - SW_PAD_CTL_PAD_SD3_DATA2 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_data2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_data2_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_data2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ADDR(x) ((uintptr_t)(x) + 0x450U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_data2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD3_DATA2
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD3_DATA2
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD3_DATA2
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD3_DATA2
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD3_DATA2
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA2_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3 - SW_PAD_CTL_PAD_SD3_DATA3 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3 - SW_PAD_CTL_PAD_SD3_DATA3 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_data3
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_data3_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_data3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ADDR(x) ((uintptr_t)(x) + 0x454U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_data3_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD3_DATA3
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD3_DATA3
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD3_DATA3
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD3_DATA3
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD3_DATA3
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA3_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4 - SW_PAD_CTL_PAD_SD3_DATA4 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4 - SW_PAD_CTL_PAD_SD3_DATA4 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_data4
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_data4_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_data4_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ADDR(x) ((uintptr_t)(x) + 0x458U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_data4_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD3_DATA4
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD3_DATA4
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD3_DATA4
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD3_DATA4
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD3_DATA4
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA4_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5 - SW_PAD_CTL_PAD_SD3_DATA5 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5 - SW_PAD_CTL_PAD_SD3_DATA5 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_data5
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_data5_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_data5_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ADDR(x) ((uintptr_t)(x) + 0x45CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_data5_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD3_DATA5
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD3_DATA5
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD3_DATA5
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD3_DATA5
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD3_DATA5
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA5_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6 - SW_PAD_CTL_PAD_SD3_DATA6 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6 - SW_PAD_CTL_PAD_SD3_DATA6 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_data6
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_data6_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_data6_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ADDR(x) ((uintptr_t)(x) + 0x460U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_data6_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD3_DATA6
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD3_DATA6
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD3_DATA6
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD3_DATA6
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD3_DATA6
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA6_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7 - SW_PAD_CTL_PAD_SD3_DATA7 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7 - SW_PAD_CTL_PAD_SD3_DATA7 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_data7
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_data7_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_data7_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ADDR(x) ((uintptr_t)(x) + 0x464U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_data7_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD3_DATA7
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD3_DATA7
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD3_DATA7
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD3_DATA7
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD3_DATA7
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_DATA7_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE - SW_PAD_CTL_PAD_SD3_STROBE SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE - SW_PAD_CTL_PAD_SD3_STROBE SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_strobe
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_strobe_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_strobe_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_ADDR(x) ((uintptr_t)(x) + 0x468U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_strobe_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD3_STROBE
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD3_STROBE
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD3_STROBE
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD3_STROBE
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD3_STROBE
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_STROBE_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B - SW_PAD_CTL_PAD_SD3_RESET_B SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B - SW_PAD_CTL_PAD_SD3_RESET_B SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sd3_reset_b
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sd3_reset_b_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sd3_reset_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_ADDR(x) ((uintptr_t)(x) + 0x46CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sd3_reset_b_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SD3_RESET_B
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SD3_RESET_B
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SD3_RESET_B
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B, field PE[4] (RW)
 *
 * Select one out of next values for pad: SD3_RESET_B
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SD3_RESET_B
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SD3_RESET_B_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA - SW_PAD_CTL_PAD_SAI1_RX_DATA SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA - SW_PAD_CTL_PAD_SAI1_RX_DATA SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sai1_rx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sai1_rx_data_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sai1_rx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_ADDR(x) ((uintptr_t)(x) + 0x470U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sai1_rx_data_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SAI1_RX_DATA
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SAI1_RX_DATA
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SAI1_RX_DATA
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA, field PE[4] (RW)
 *
 * Select one out of next values for pad: SAI1_RX_DATA
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SAI1_RX_DATA
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_DATA_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK - SW_PAD_CTL_PAD_SAI1_TX_BCLK SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK - SW_PAD_CTL_PAD_SAI1_TX_BCLK SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sai1_tx_bclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sai1_tx_bclk_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sai1_tx_bclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_ADDR(x) ((uintptr_t)(x) + 0x474U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sai1_tx_bclk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SAI1_TX_BCLK
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SAI1_TX_BCLK
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SAI1_TX_BCLK
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK, field PE[4] (RW)
 *
 * Select one out of next values for pad: SAI1_TX_BCLK
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SAI1_TX_BCLK
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_BCLK_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC - SW_PAD_CTL_PAD_SAI1_TX_SYNC SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC - SW_PAD_CTL_PAD_SAI1_TX_SYNC SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sai1_tx_sync
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sai1_tx_sync_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sai1_tx_sync_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_ADDR(x) ((uintptr_t)(x) + 0x478U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sai1_tx_sync_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SAI1_TX_SYNC
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SAI1_TX_SYNC
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SAI1_TX_SYNC
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC, field PE[4] (RW)
 *
 * Select one out of next values for pad: SAI1_TX_SYNC
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SAI1_TX_SYNC
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_SYNC_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA - SW_PAD_CTL_PAD_SAI1_TX_DATA SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA - SW_PAD_CTL_PAD_SAI1_TX_DATA SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sai1_tx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sai1_tx_data_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sai1_tx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_ADDR(x) ((uintptr_t)(x) + 0x47CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sai1_tx_data_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SAI1_TX_DATA
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SAI1_TX_DATA
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SAI1_TX_DATA
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA, field PE[4] (RW)
 *
 * Select one out of next values for pad: SAI1_TX_DATA
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SAI1_TX_DATA
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_TX_DATA_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC - SW_PAD_CTL_PAD_SAI1_RX_SYNC SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC - SW_PAD_CTL_PAD_SAI1_RX_SYNC SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sai1_rx_sync
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sai1_rx_sync_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sai1_rx_sync_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_ADDR(x) ((uintptr_t)(x) + 0x480U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sai1_rx_sync_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SAI1_RX_SYNC
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SAI1_RX_SYNC
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SAI1_RX_SYNC
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC, field PE[4] (RW)
 *
 * Select one out of next values for pad: SAI1_RX_SYNC
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SAI1_RX_SYNC
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_SYNC_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK - SW_PAD_CTL_PAD_SAI1_RX_BCLK SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK - SW_PAD_CTL_PAD_SAI1_RX_BCLK SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sai1_rx_bclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sai1_rx_bclk_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sai1_rx_bclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_ADDR(x) ((uintptr_t)(x) + 0x484U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sai1_rx_bclk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SAI1_RX_BCLK
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SAI1_RX_BCLK
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SAI1_RX_BCLK
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK, field PE[4] (RW)
 *
 * Select one out of next values for pad: SAI1_RX_BCLK
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SAI1_RX_BCLK
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_RX_BCLK_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK - SW_PAD_CTL_PAD_SAI1_MCLK SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK - SW_PAD_CTL_PAD_SAI1_MCLK SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sai1_mclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sai1_mclk_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sai1_mclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_ADDR(x) ((uintptr_t)(x) + 0x488U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sai1_mclk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SAI1_MCLK
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SAI1_MCLK
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SAI1_MCLK
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK, field PE[4] (RW)
 *
 * Select one out of next values for pad: SAI1_MCLK
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SAI1_MCLK
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI1_MCLK_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC - SW_PAD_CTL_PAD_SAI2_TX_SYNC SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC - SW_PAD_CTL_PAD_SAI2_TX_SYNC SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sai2_tx_sync
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sai2_tx_sync_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sai2_tx_sync_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_ADDR(x) ((uintptr_t)(x) + 0x48CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sai2_tx_sync_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SAI2_TX_SYNC
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SAI2_TX_SYNC
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SAI2_TX_SYNC
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC, field PE[4] (RW)
 *
 * Select one out of next values for pad: SAI2_TX_SYNC
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SAI2_TX_SYNC
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_SYNC_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK - SW_PAD_CTL_PAD_SAI2_TX_BCLK SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK - SW_PAD_CTL_PAD_SAI2_TX_BCLK SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sai2_tx_bclk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sai2_tx_bclk_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sai2_tx_bclk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_ADDR(x) ((uintptr_t)(x) + 0x490U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sai2_tx_bclk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SAI2_TX_BCLK
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SAI2_TX_BCLK
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SAI2_TX_BCLK
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK, field PE[4] (RW)
 *
 * Select one out of next values for pad: SAI2_TX_BCLK
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SAI2_TX_BCLK
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_BCLK_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA - SW_PAD_CTL_PAD_SAI2_RX_DATA SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA - SW_PAD_CTL_PAD_SAI2_RX_DATA SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sai2_rx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sai2_rx_data_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sai2_rx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_ADDR(x) ((uintptr_t)(x) + 0x494U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sai2_rx_data_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SAI2_RX_DATA
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SAI2_RX_DATA
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SAI2_RX_DATA
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA, field PE[4] (RW)
 *
 * Select one out of next values for pad: SAI2_RX_DATA
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SAI2_RX_DATA
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_RX_DATA_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA - SW_PAD_CTL_PAD_SAI2_TX_DATA SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA - SW_PAD_CTL_PAD_SAI2_TX_DATA SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_sai2_tx_data
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_sai2_tx_data_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_sai2_tx_data_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_ADDR(x) ((uintptr_t)(x) + 0x498U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_sai2_tx_data_t *) HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: SAI2_TX_DATA
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA, field SRE[2] (RW)
 *
 * Select one out of next values for pad: SAI2_TX_DATA
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA, field HYS[3] (RW)
 *
 * Select one out of next values for pad: SAI2_TX_DATA
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA, field PE[4] (RW)
 *
 * Select one out of next values for pad: SAI2_TX_DATA
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SAI2_TX_DATA
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_SAI2_TX_DATA_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0 - SW_PAD_CTL_PAD_ENET1_RGMII_RD0 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0 - SW_PAD_CTL_PAD_ENET1_RGMII_RD0 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd0_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_ADDR(x) ((uintptr_t)(x) + 0x49CU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD0
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD0
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD0
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0, field PE[4] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD0
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD0
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD0_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1 - SW_PAD_CTL_PAD_ENET1_RGMII_RD1 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1 - SW_PAD_CTL_PAD_ENET1_RGMII_RD1 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd1_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_ADDR(x) ((uintptr_t)(x) + 0x4A0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD1
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD1
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD1
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1, field PE[4] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD1
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD1
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD1_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2 - SW_PAD_CTL_PAD_ENET1_RGMII_RD2 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2 - SW_PAD_CTL_PAD_ENET1_RGMII_RD2 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd2_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_ADDR(x) ((uintptr_t)(x) + 0x4A4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD2
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD2
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD2
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2, field PE[4] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD2
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD2
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD2_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3 - SW_PAD_CTL_PAD_ENET1_RGMII_RD3 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3 - SW_PAD_CTL_PAD_ENET1_RGMII_RD3 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd3
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd3_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_ADDR(x) ((uintptr_t)(x) + 0x4A8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd3_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD3
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD3
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD3
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3, field PE[4] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD3
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RD3
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RD3_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL - SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL - SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rx_ctl
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rx_ctl_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rx_ctl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_ADDR(x) ((uintptr_t)(x) + 0x4ACU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rx_ctl_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RX_CTL
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RX_CTL
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RX_CTL
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL, field PE[4] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RX_CTL
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RX_CTL
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC - SW_PAD_CTL_PAD_ENET1_RGMII_RXC SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC - SW_PAD_CTL_PAD_ENET1_RGMII_RXC SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rxc
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rxc_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rxc_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_ADDR(x) ((uintptr_t)(x) + 0x4B0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rxc_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RXC
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RXC
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RXC
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC, field PE[4] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RXC
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_RXC
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_RXC_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0 - SW_PAD_CTL_PAD_ENET1_RGMII_TD0 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0 - SW_PAD_CTL_PAD_ENET1_RGMII_TD0 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td0
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td0_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td0_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_ADDR(x) ((uintptr_t)(x) + 0x4B4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td0_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD0
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD0
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD0
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0, field PE[4] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD0
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD0
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD0_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1 - SW_PAD_CTL_PAD_ENET1_RGMII_TD1 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1 - SW_PAD_CTL_PAD_ENET1_RGMII_TD1 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td1
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td1_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td1_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_ADDR(x) ((uintptr_t)(x) + 0x4B8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td1_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD1
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD1
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD1
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1, field PE[4] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD1
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD1
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD1_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2 - SW_PAD_CTL_PAD_ENET1_RGMII_TD2 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2 - SW_PAD_CTL_PAD_ENET1_RGMII_TD2 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td2
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td2_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td2_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_ADDR(x) ((uintptr_t)(x) + 0x4BCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td2_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD2
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD2
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD2
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2, field PE[4] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD2
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD2
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD2_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3 - SW_PAD_CTL_PAD_ENET1_RGMII_TD3 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3 - SW_PAD_CTL_PAD_ENET1_RGMII_TD3 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td3
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td3_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td3_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3 register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_ADDR(x) ((uintptr_t)(x) + 0x4C0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td3_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3 bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD3
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD3
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD3
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3, field PE[4] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD3
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TD3
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TD3_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL - SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL - SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_tx_ctl
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_tx_ctl_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_tx_ctl_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_ADDR(x) ((uintptr_t)(x) + 0x4C4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_tx_ctl_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TX_CTL
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TX_CTL
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TX_CTL
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL, field PE[4] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TX_CTL
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TX_CTL
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC - SW_PAD_CTL_PAD_ENET1_RGMII_TXC SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC - SW_PAD_CTL_PAD_ENET1_RGMII_TXC SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_txc
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_txc_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_txc_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_ADDR(x) ((uintptr_t)(x) + 0x4C8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_txc_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TXC
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TXC
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TXC
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC, field PE[4] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TXC
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ENET1_RGMII_TXC
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RGMII_TXC_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK - SW_PAD_CTL_PAD_ENET1_TX_CLK SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK - SW_PAD_CTL_PAD_ENET1_TX_CLK SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_tx_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_tx_clk_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_tx_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ADDR(x) ((uintptr_t)(x) + 0x4CCU)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_tx_clk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ENET1_TX_CLK
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ENET1_TX_CLK
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ENET1_TX_CLK
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK, field PE[4] (RW)
 *
 * Select one out of next values for pad: ENET1_TX_CLK
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ENET1_TX_CLK
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_TX_CLK_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK - SW_PAD_CTL_PAD_ENET1_RX_CLK SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK - SW_PAD_CTL_PAD_ENET1_RX_CLK SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_rx_clk
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_rx_clk_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_rx_clk_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ADDR(x) ((uintptr_t)(x) + 0x4D0U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_rx_clk_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ENET1_RX_CLK
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ENET1_RX_CLK
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ENET1_RX_CLK
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK, field PE[4] (RW)
 *
 * Select one out of next values for pad: ENET1_RX_CLK
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ENET1_RX_CLK
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_RX_CLK_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS - SW_PAD_CTL_PAD_ENET1_CRS SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS - SW_PAD_CTL_PAD_ENET1_CRS SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_crs
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_crs_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_crs_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ADDR(x) ((uintptr_t)(x) + 0x4D4U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_crs_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ENET1_CRS
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ENET1_CRS
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ENET1_CRS
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS, field PE[4] (RW)
 *
 * Select one out of next values for pad: ENET1_CRS
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ENET1_CRS
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_CRS_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL - SW_PAD_CTL_PAD_ENET1_COL SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL - SW_PAD_CTL_PAD_ENET1_COL SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_sw_pad_ctl_pad_enet1_col
{
    uint32_t U;
    struct _hw_iomuxc_sw_pad_ctl_pad_enet1_col_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_sw_pad_ctl_pad_enet1_col_t;

/*!
 * @name Constants and macros for entire IOMUXC_SW_PAD_CTL_PAD_ENET1_COL register
 */
/*@{*/
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ADDR(x) ((uintptr_t)(x) + 0x4D8U)

#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL(x) (*(__IO hw_iomuxc_sw_pad_ctl_pad_enet1_col_t *) HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_ADDR(x))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL(x).U)
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL(x).U = (v))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SET(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) |  (v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_CLR(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) & ~(v)))
#define HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_TOG(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SW_PAD_CTL_PAD_ENET1_COL bitfields
 */

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_COL, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: ENET1_COL
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE (0U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE (0x00000003U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE: X1 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE: X4 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE: X2 */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE: X6 */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_COL, field SRE[2] (RW)
 *
 * Select one out of next values for pad: ENET1_COL
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE (2U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE (0x00000004U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE: Fast Slew Rate */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_COL, field HYS[3] (RW)
 *
 * Select one out of next values for pad: ENET1_COL
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS (3U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS (0x00000008U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS: Hysteresis Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_COL, field PE[4] (RW)
 *
 * Select one out of next values for pad: ENET1_COL
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PE (4U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PE. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PE (0x00000010U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PE. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PE (1U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PE. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PE: Pull Disabled */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PE field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PE(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PE. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PE) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PE(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PE) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_SW_PAD_CTL_PAD_ENET1_COL, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: ENET1_COL
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS (5U) /*!< Bit position for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS. */
#define BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS (0x00000060U) /*!< Bit mask for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS. */
#define BS_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS (2U) /*!< Bit field size in bits for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS. */

#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS: 100K PD */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS: 5K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS: 47K PU */
#define BV_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS field. */
#define BR_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS(x) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS. */
#define BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS) & BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS(x, v) (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_WR(x, (HW_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_RD(x) & ~BM_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS) | BF_IOMUXC_SW_PAD_CTL_PAD_ENET1_COL_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT - FLEXCAN1_RX_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT - FLEXCAN1_RX_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flexcan1_rx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flexcan1_rx_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_flexcan1_rx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXCAN1_RX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x4DCU)

#define HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT(x) (*(__IO hw_iomuxc_flexcan1_rx_select_input_t *) HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXCAN1_RX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXCAN1_RX_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting Pad: GPIO1_IO12 Mode: ALT3 for FLEXCAN1_RX
 * - 001 - Selecting Pad: I2C1_SCL Mode: ALT2 for FLEXCAN1_RX
 * - 010 - Selecting Pad: SD3_DATA7 Mode: ALT4 for FLEXCAN1_RX
 * - 011 - Selecting Pad: SAI1_RX_DATA Mode: ALT3 for FLEXCAN1_RX
 * - 100 - Selecting Pad: ENET1_RGMII_RD2 Mode: ALT1 for FLEXCAN1_RX
 */
/*@{*/
#define BP_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY_GPIO1_IO12_ALT3 (0U) /*!< Bit field value for IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO12 Mode: ALT3 for FLEXCAN1_RX */
#define BV_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY_I2C1_SCL_ALT2 (0x1U) /*!< Bit field value for IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY: Selecting Pad: I2C1_SCL Mode: ALT2 for FLEXCAN1_RX */
#define BV_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY_SD3_DATA7_ALT4 (0x2U) /*!< Bit field value for IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY: Selecting Pad: SD3_DATA7 Mode: ALT4 for FLEXCAN1_RX */
#define BV_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY_SAI1_RX_DATA_ALT3 (0x3U) /*!< Bit field value for IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY: Selecting Pad: SAI1_RX_DATA Mode: ALT3 for FLEXCAN1_RX */
#define BV_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY_ENET1_RGMII_RD2_ALT1 (0x4U) /*!< Bit field value for IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_RD2 Mode: ALT1 for FLEXCAN1_RX */

/*! @brief Read current value of the IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXCAN1_RX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT - FLEXCAN2_RX_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT - FLEXCAN2_RX_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flexcan2_rx_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flexcan2_rx_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_flexcan2_rx_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXCAN2_RX_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x4E0U)

#define HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT(x) (*(__IO hw_iomuxc_flexcan2_rx_select_input_t *) HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXCAN2_RX_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXCAN2_RX_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting Pad: GPIO1_IO14 Mode: ALT3 for FLEXCAN2_RX
 * - 001 - Selecting Pad: I2C3_SCL Mode: ALT2 for FLEXCAN2_RX
 * - 010 - Selecting Pad: SD3_DATA4 Mode: ALT4 for FLEXCAN2_RX
 * - 011 - Selecting Pad: SAI1_TX_SYNC Mode: ALT3 for FLEXCAN2_RX
 * - 100 - Selecting Pad: ENET1_RGMII_TD2 Mode: ALT1 for FLEXCAN2_RX
 */
/*@{*/
#define BP_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY_GPIO1_IO14_ALT3 (0U) /*!< Bit field value for IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO14 Mode: ALT3 for FLEXCAN2_RX */
#define BV_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY_I2C3_SCL_ALT2 (0x1U) /*!< Bit field value for IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY: Selecting Pad: I2C3_SCL Mode: ALT2 for FLEXCAN2_RX */
#define BV_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY_SD3_DATA4_ALT4 (0x2U) /*!< Bit field value for IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY: Selecting Pad: SD3_DATA4 Mode: ALT4 for FLEXCAN2_RX */
#define BV_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY_SAI1_TX_SYNC_ALT3 (0x3U) /*!< Bit field value for IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY: Selecting Pad: SAI1_TX_SYNC Mode: ALT3 for FLEXCAN2_RX */
#define BV_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY_ENET1_RGMII_TD2_ALT1 (0x4U) /*!< Bit field value for IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_TD2 Mode: ALT1 for FLEXCAN2_RX */

/*! @brief Read current value of the IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXCAN2_RX_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT - CCM_EXT_CLK_1_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT - CCM_EXT_CLK_1_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ccm_ext_clk_1_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ccm_ext_clk_1_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_ccm_ext_clk_1_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x4E4U)

#define HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT(x) (*(__IO hw_iomuxc_ccm_ext_clk_1_select_input_t *) HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_RD(x) (HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT(x).U)
#define HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: GPIO1_IO12 Mode: ALT5 for CCM_EXT_CLK_1
 * - 01 - Selecting Pad: SD1_DATA0 Mode: ALT6 for CCM_EXT_CLK_1
 * - 10 - Selecting Pad: ENET1_TX_CLK Mode: ALT6 for CCM_EXT_CLK_1
 */
/*@{*/
#define BP_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY_GPIO1_IO12_ALT5 (0U) /*!< Bit field value for IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO12 Mode: ALT5 for CCM_EXT_CLK_1 */
#define BV_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY_SD1_DATA0_ALT6 (0x1U) /*!< Bit field value for IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY: Selecting Pad: SD1_DATA0 Mode: ALT6 for CCM_EXT_CLK_1 */
#define BV_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY_ENET1_TX_CLK_ALT6 (0x2U) /*!< Bit field value for IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY: Selecting Pad: ENET1_TX_CLK Mode: ALT6 for CCM_EXT_CLK_1 */

/*! @brief Read current value of the IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY) & BM_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_WR(x, (HW_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY) | BF_IOMUXC_CCM_EXT_CLK_1_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT - CCM_EXT_CLK_2_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT - CCM_EXT_CLK_2_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ccm_ext_clk_2_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ccm_ext_clk_2_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_ccm_ext_clk_2_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x4E8U)

#define HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT(x) (*(__IO hw_iomuxc_ccm_ext_clk_2_select_input_t *) HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_RD(x) (HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT(x).U)
#define HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: GPIO1_IO13 Mode: ALT5 for CCM_EXT_CLK_2
 * - 01 - Selecting Pad: SD1_DATA1 Mode: ALT6 for CCM_EXT_CLK_2
 * - 10 - Selecting Pad: ENET1_RX_CLK Mode: ALT6 for CCM_EXT_CLK_2
 */
/*@{*/
#define BP_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY_GPIO1_IO13_ALT5 (0U) /*!< Bit field value for IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO13 Mode: ALT5 for CCM_EXT_CLK_2 */
#define BV_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY_SD1_DATA1_ALT6 (0x1U) /*!< Bit field value for IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY: Selecting Pad: SD1_DATA1 Mode: ALT6 for CCM_EXT_CLK_2 */
#define BV_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY_ENET1_RX_CLK_ALT6 (0x2U) /*!< Bit field value for IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RX_CLK Mode: ALT6 for CCM_EXT_CLK_2 */

/*! @brief Read current value of the IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY) & BM_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_WR(x, (HW_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY) | BF_IOMUXC_CCM_EXT_CLK_2_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT - CCM_EXT_CLK_3_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT - CCM_EXT_CLK_3_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ccm_ext_clk_3_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ccm_ext_clk_3_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_ccm_ext_clk_3_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x4ECU)

#define HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT(x) (*(__IO hw_iomuxc_ccm_ext_clk_3_select_input_t *) HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_RD(x) (HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT(x).U)
#define HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: GPIO1_IO14 Mode: ALT5 for CCM_EXT_CLK_3
 * - 01 - Selecting Pad: SD1_DATA2 Mode: ALT6 for CCM_EXT_CLK_3
 * - 10 - Selecting Pad: ENET1_CRS Mode: ALT6 for CCM_EXT_CLK_3
 */
/*@{*/
#define BP_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY_GPIO1_IO14_ALT5 (0U) /*!< Bit field value for IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO14 Mode: ALT5 for CCM_EXT_CLK_3 */
#define BV_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY_SD1_DATA2_ALT6 (0x1U) /*!< Bit field value for IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY: Selecting Pad: SD1_DATA2 Mode: ALT6 for CCM_EXT_CLK_3 */
#define BV_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY_ENET1_CRS_ALT6 (0x2U) /*!< Bit field value for IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY: Selecting Pad: ENET1_CRS Mode: ALT6 for CCM_EXT_CLK_3 */

/*! @brief Read current value of the IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY) & BM_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_WR(x, (HW_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY) | BF_IOMUXC_CCM_EXT_CLK_3_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT - CCM_EXT_CLK_4_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT - CCM_EXT_CLK_4_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ccm_ext_clk_4_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ccm_ext_clk_4_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_ccm_ext_clk_4_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x4F0U)

#define HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT(x) (*(__IO hw_iomuxc_ccm_ext_clk_4_select_input_t *) HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_RD(x) (HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT(x).U)
#define HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: GPIO1_IO15 Mode: ALT5 for CCM_EXT_CLK_4
 * - 01 - Selecting Pad: SD1_DATA3 Mode: ALT6 for CCM_EXT_CLK_4
 * - 10 - Selecting Pad: ENET1_COL Mode: ALT6 for CCM_EXT_CLK_4
 */
/*@{*/
#define BP_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY_GPIO1_IO15_ALT5 (0U) /*!< Bit field value for IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO15 Mode: ALT5 for CCM_EXT_CLK_4 */
#define BV_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY_SD1_DATA3_ALT6 (0x1U) /*!< Bit field value for IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY: Selecting Pad: SD1_DATA3 Mode: ALT6 for CCM_EXT_CLK_4 */
#define BV_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY_ENET1_COL_ALT6 (0x2U) /*!< Bit field value for IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY: Selecting Pad: ENET1_COL Mode: ALT6 for CCM_EXT_CLK_4 */

/*! @brief Read current value of the IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY) & BM_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_WR(x, (HW_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY) | BF_IOMUXC_CCM_EXT_CLK_4_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT - CCM_PMIC_READY_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT - CCM_PMIC_READY_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ccm_pmic_ready_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ccm_pmic_ready_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_ccm_pmic_ready_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CCM_PMIC_READY_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x4F4U)

#define HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT(x) (*(__IO hw_iomuxc_ccm_pmic_ready_select_input_t *) HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_RD(x) (HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT(x).U)
#define HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CCM_PMIC_READY_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CCM_PMIC_READY_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: GPIO1_IO09 Mode: ALT5 for CCM_PMIC_READY
 * - 01 - Selecting Pad: GPIO1_IO13 Mode: ALT4 for CCM_PMIC_READY
 * - 10 - Selecting Pad: UART1_RX_DATA Mode: ALT2 for CCM_PMIC_READY
 * - 11 - Selecting Pad: SAI1_MCLK Mode: ALT3 for CCM_PMIC_READY
 */
/*@{*/
#define BP_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY_GPIO1_IO09_ALT5 (0U) /*!< Bit field value for IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO09 Mode: ALT5 for CCM_PMIC_READY */
#define BV_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY_GPIO1_IO13_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO13 Mode: ALT4 for CCM_PMIC_READY */
#define BV_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY_UART1_RX_DATA_ALT2 (0x2U) /*!< Bit field value for IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY: Selecting Pad: UART1_RX_DATA Mode: ALT2 for CCM_PMIC_READY */
#define BV_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY_SAI1_MCLK_ALT3 (0x3U) /*!< Bit field value for IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY: Selecting Pad: SAI1_MCLK Mode: ALT3 for CCM_PMIC_READY */

/*! @brief Read current value of the IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY) & BM_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_WR(x, (HW_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY) | BF_IOMUXC_CCM_PMIC_READY_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI_DATA2_SELECT_INPUT - CSI_DATA2_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI_DATA2_SELECT_INPUT - CSI_DATA2_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_csi_data2_select_input
{
    uint32_t U;
    struct _hw_iomuxc_csi_data2_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi_data2_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI_DATA2_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CSI_DATA2_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x4F8U)

#define HW_IOMUXC_CSI_DATA2_SELECT_INPUT(x) (*(__IO hw_iomuxc_csi_data2_select_input_t *) HW_IOMUXC_CSI_DATA2_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CSI_DATA2_SELECT_INPUT_RD(x) (HW_IOMUXC_CSI_DATA2_SELECT_INPUT(x).U)
#define HW_IOMUXC_CSI_DATA2_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CSI_DATA2_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CSI_DATA2_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CSI_DATA2_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA2_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CSI_DATA2_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CSI_DATA2_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA2_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CSI_DATA2_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CSI_DATA2_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA2_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI_DATA2_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CSI_DATA2_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: LCD_DATA15 Mode: ALT3 for CSI_DATA2
 * - 1 - Selecting Pad: ECSPI1_SCLK Mode: ALT3 for CSI_DATA2
 */
/*@{*/
#define BP_IOMUXC_CSI_DATA2_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CSI_DATA2_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CSI_DATA2_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI_DATA2_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CSI_DATA2_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI_DATA2_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CSI_DATA2_SELECT_INPUT_DAISY_LCD_DATA15_ALT3 (0U) /*!< Bit field value for IOMUXC_CSI_DATA2_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA15 Mode: ALT3 for CSI_DATA2 */
#define BV_IOMUXC_CSI_DATA2_SELECT_INPUT_DAISY_ECSPI1_SCLK_ALT3 (0x1U) /*!< Bit field value for IOMUXC_CSI_DATA2_SELECT_INPUT_DAISY: Selecting Pad: ECSPI1_SCLK Mode: ALT3 for CSI_DATA2 */

/*! @brief Read current value of the IOMUXC_CSI_DATA2_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CSI_DATA2_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CSI_DATA2_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI_DATA2_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CSI_DATA2_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI_DATA2_SELECT_INPUT_DAISY) & BM_IOMUXC_CSI_DATA2_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI_DATA2_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CSI_DATA2_SELECT_INPUT_WR(x, (HW_IOMUXC_CSI_DATA2_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CSI_DATA2_SELECT_INPUT_DAISY) | BF_IOMUXC_CSI_DATA2_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI_DATA3_SELECT_INPUT - CSI_DATA3_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI_DATA3_SELECT_INPUT - CSI_DATA3_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_csi_data3_select_input
{
    uint32_t U;
    struct _hw_iomuxc_csi_data3_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi_data3_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI_DATA3_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CSI_DATA3_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x4FCU)

#define HW_IOMUXC_CSI_DATA3_SELECT_INPUT(x) (*(__IO hw_iomuxc_csi_data3_select_input_t *) HW_IOMUXC_CSI_DATA3_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CSI_DATA3_SELECT_INPUT_RD(x) (HW_IOMUXC_CSI_DATA3_SELECT_INPUT(x).U)
#define HW_IOMUXC_CSI_DATA3_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CSI_DATA3_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CSI_DATA3_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CSI_DATA3_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA3_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CSI_DATA3_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CSI_DATA3_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA3_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CSI_DATA3_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CSI_DATA3_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA3_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI_DATA3_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CSI_DATA3_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: LCD_DATA14 Mode: ALT3 for CSI_DATA3
 * - 1 - Selecting Pad: ECSPI1_MOSI Mode: ALT3 for CSI_DATA3
 */
/*@{*/
#define BP_IOMUXC_CSI_DATA3_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CSI_DATA3_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CSI_DATA3_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI_DATA3_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CSI_DATA3_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI_DATA3_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CSI_DATA3_SELECT_INPUT_DAISY_LCD_DATA14_ALT3 (0U) /*!< Bit field value for IOMUXC_CSI_DATA3_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA14 Mode: ALT3 for CSI_DATA3 */
#define BV_IOMUXC_CSI_DATA3_SELECT_INPUT_DAISY_ECSPI1_MOSI_ALT3 (0x1U) /*!< Bit field value for IOMUXC_CSI_DATA3_SELECT_INPUT_DAISY: Selecting Pad: ECSPI1_MOSI Mode: ALT3 for CSI_DATA3 */

/*! @brief Read current value of the IOMUXC_CSI_DATA3_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CSI_DATA3_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CSI_DATA3_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI_DATA3_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CSI_DATA3_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI_DATA3_SELECT_INPUT_DAISY) & BM_IOMUXC_CSI_DATA3_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI_DATA3_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CSI_DATA3_SELECT_INPUT_WR(x, (HW_IOMUXC_CSI_DATA3_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CSI_DATA3_SELECT_INPUT_DAISY) | BF_IOMUXC_CSI_DATA3_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI_DATA4_SELECT_INPUT - CSI_DATA4_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI_DATA4_SELECT_INPUT - CSI_DATA4_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_csi_data4_select_input
{
    uint32_t U;
    struct _hw_iomuxc_csi_data4_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi_data4_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI_DATA4_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CSI_DATA4_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x500U)

#define HW_IOMUXC_CSI_DATA4_SELECT_INPUT(x) (*(__IO hw_iomuxc_csi_data4_select_input_t *) HW_IOMUXC_CSI_DATA4_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CSI_DATA4_SELECT_INPUT_RD(x) (HW_IOMUXC_CSI_DATA4_SELECT_INPUT(x).U)
#define HW_IOMUXC_CSI_DATA4_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CSI_DATA4_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CSI_DATA4_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CSI_DATA4_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA4_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CSI_DATA4_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CSI_DATA4_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA4_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CSI_DATA4_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CSI_DATA4_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA4_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI_DATA4_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CSI_DATA4_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: LCD_DATA13 Mode: ALT3 for CSI_DATA4
 * - 1 - Selecting Pad: ECSPI1_MISO Mode: ALT3 for CSI_DATA4
 */
/*@{*/
#define BP_IOMUXC_CSI_DATA4_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CSI_DATA4_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CSI_DATA4_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI_DATA4_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CSI_DATA4_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI_DATA4_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CSI_DATA4_SELECT_INPUT_DAISY_LCD_DATA13_ALT3 (0U) /*!< Bit field value for IOMUXC_CSI_DATA4_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA13 Mode: ALT3 for CSI_DATA4 */
#define BV_IOMUXC_CSI_DATA4_SELECT_INPUT_DAISY_ECSPI1_MISO_ALT3 (0x1U) /*!< Bit field value for IOMUXC_CSI_DATA4_SELECT_INPUT_DAISY: Selecting Pad: ECSPI1_MISO Mode: ALT3 for CSI_DATA4 */

/*! @brief Read current value of the IOMUXC_CSI_DATA4_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CSI_DATA4_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CSI_DATA4_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI_DATA4_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CSI_DATA4_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI_DATA4_SELECT_INPUT_DAISY) & BM_IOMUXC_CSI_DATA4_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI_DATA4_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CSI_DATA4_SELECT_INPUT_WR(x, (HW_IOMUXC_CSI_DATA4_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CSI_DATA4_SELECT_INPUT_DAISY) | BF_IOMUXC_CSI_DATA4_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI_DATA5_SELECT_INPUT - CSI_DATA5_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI_DATA5_SELECT_INPUT - CSI_DATA5_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_csi_data5_select_input
{
    uint32_t U;
    struct _hw_iomuxc_csi_data5_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi_data5_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI_DATA5_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CSI_DATA5_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x504U)

#define HW_IOMUXC_CSI_DATA5_SELECT_INPUT(x) (*(__IO hw_iomuxc_csi_data5_select_input_t *) HW_IOMUXC_CSI_DATA5_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CSI_DATA5_SELECT_INPUT_RD(x) (HW_IOMUXC_CSI_DATA5_SELECT_INPUT(x).U)
#define HW_IOMUXC_CSI_DATA5_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CSI_DATA5_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CSI_DATA5_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CSI_DATA5_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA5_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CSI_DATA5_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CSI_DATA5_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA5_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CSI_DATA5_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CSI_DATA5_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA5_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI_DATA5_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CSI_DATA5_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: LCD_DATA12 Mode: ALT3 for CSI_DATA5
 * - 1 - Selecting Pad: ECSPI1_SS0 Mode: ALT3 for CSI_DATA5
 */
/*@{*/
#define BP_IOMUXC_CSI_DATA5_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CSI_DATA5_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CSI_DATA5_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI_DATA5_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CSI_DATA5_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI_DATA5_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CSI_DATA5_SELECT_INPUT_DAISY_LCD_DATA12_ALT3 (0U) /*!< Bit field value for IOMUXC_CSI_DATA5_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA12 Mode: ALT3 for CSI_DATA5 */
#define BV_IOMUXC_CSI_DATA5_SELECT_INPUT_DAISY_ECSPI1_SS0_ALT3 (0x1U) /*!< Bit field value for IOMUXC_CSI_DATA5_SELECT_INPUT_DAISY: Selecting Pad: ECSPI1_SS0 Mode: ALT3 for CSI_DATA5 */

/*! @brief Read current value of the IOMUXC_CSI_DATA5_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CSI_DATA5_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CSI_DATA5_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI_DATA5_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CSI_DATA5_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI_DATA5_SELECT_INPUT_DAISY) & BM_IOMUXC_CSI_DATA5_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI_DATA5_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CSI_DATA5_SELECT_INPUT_WR(x, (HW_IOMUXC_CSI_DATA5_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CSI_DATA5_SELECT_INPUT_DAISY) | BF_IOMUXC_CSI_DATA5_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI_DATA6_SELECT_INPUT - CSI_DATA6_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI_DATA6_SELECT_INPUT - CSI_DATA6_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_csi_data6_select_input
{
    uint32_t U;
    struct _hw_iomuxc_csi_data6_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi_data6_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI_DATA6_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CSI_DATA6_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x508U)

#define HW_IOMUXC_CSI_DATA6_SELECT_INPUT(x) (*(__IO hw_iomuxc_csi_data6_select_input_t *) HW_IOMUXC_CSI_DATA6_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CSI_DATA6_SELECT_INPUT_RD(x) (HW_IOMUXC_CSI_DATA6_SELECT_INPUT(x).U)
#define HW_IOMUXC_CSI_DATA6_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CSI_DATA6_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CSI_DATA6_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CSI_DATA6_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA6_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CSI_DATA6_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CSI_DATA6_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA6_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CSI_DATA6_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CSI_DATA6_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA6_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI_DATA6_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CSI_DATA6_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: LCD_DATA11 Mode: ALT3 for CSI_DATA6
 * - 1 - Selecting Pad: ECSPI2_SCLK Mode: ALT3 for CSI_DATA6
 */
/*@{*/
#define BP_IOMUXC_CSI_DATA6_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CSI_DATA6_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CSI_DATA6_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI_DATA6_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CSI_DATA6_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI_DATA6_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CSI_DATA6_SELECT_INPUT_DAISY_LCD_DATA11_ALT3 (0U) /*!< Bit field value for IOMUXC_CSI_DATA6_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA11 Mode: ALT3 for CSI_DATA6 */
#define BV_IOMUXC_CSI_DATA6_SELECT_INPUT_DAISY_ECSPI2_SCLK_ALT3 (0x1U) /*!< Bit field value for IOMUXC_CSI_DATA6_SELECT_INPUT_DAISY: Selecting Pad: ECSPI2_SCLK Mode: ALT3 for CSI_DATA6 */

/*! @brief Read current value of the IOMUXC_CSI_DATA6_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CSI_DATA6_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CSI_DATA6_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI_DATA6_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CSI_DATA6_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI_DATA6_SELECT_INPUT_DAISY) & BM_IOMUXC_CSI_DATA6_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI_DATA6_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CSI_DATA6_SELECT_INPUT_WR(x, (HW_IOMUXC_CSI_DATA6_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CSI_DATA6_SELECT_INPUT_DAISY) | BF_IOMUXC_CSI_DATA6_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI_DATA7_SELECT_INPUT - CSI_DATA7_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI_DATA7_SELECT_INPUT - CSI_DATA7_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_csi_data7_select_input
{
    uint32_t U;
    struct _hw_iomuxc_csi_data7_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi_data7_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI_DATA7_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CSI_DATA7_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x50CU)

#define HW_IOMUXC_CSI_DATA7_SELECT_INPUT(x) (*(__IO hw_iomuxc_csi_data7_select_input_t *) HW_IOMUXC_CSI_DATA7_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CSI_DATA7_SELECT_INPUT_RD(x) (HW_IOMUXC_CSI_DATA7_SELECT_INPUT(x).U)
#define HW_IOMUXC_CSI_DATA7_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CSI_DATA7_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CSI_DATA7_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CSI_DATA7_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA7_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CSI_DATA7_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CSI_DATA7_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA7_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CSI_DATA7_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CSI_DATA7_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA7_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI_DATA7_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CSI_DATA7_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: LCD_DATA10 Mode: ALT3 for CSI_DATA7
 * - 1 - Selecting Pad: ECSPI2_MOSI Mode: ALT3 for CSI_DATA7
 */
/*@{*/
#define BP_IOMUXC_CSI_DATA7_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CSI_DATA7_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CSI_DATA7_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI_DATA7_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CSI_DATA7_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI_DATA7_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CSI_DATA7_SELECT_INPUT_DAISY_LCD_DATA10_ALT3 (0U) /*!< Bit field value for IOMUXC_CSI_DATA7_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA10 Mode: ALT3 for CSI_DATA7 */
#define BV_IOMUXC_CSI_DATA7_SELECT_INPUT_DAISY_ECSPI2_MOSI_ALT3 (0x1U) /*!< Bit field value for IOMUXC_CSI_DATA7_SELECT_INPUT_DAISY: Selecting Pad: ECSPI2_MOSI Mode: ALT3 for CSI_DATA7 */

/*! @brief Read current value of the IOMUXC_CSI_DATA7_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CSI_DATA7_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CSI_DATA7_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI_DATA7_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CSI_DATA7_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI_DATA7_SELECT_INPUT_DAISY) & BM_IOMUXC_CSI_DATA7_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI_DATA7_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CSI_DATA7_SELECT_INPUT_WR(x, (HW_IOMUXC_CSI_DATA7_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CSI_DATA7_SELECT_INPUT_DAISY) | BF_IOMUXC_CSI_DATA7_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI_DATA8_SELECT_INPUT - CSI_DATA8_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI_DATA8_SELECT_INPUT - CSI_DATA8_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_csi_data8_select_input
{
    uint32_t U;
    struct _hw_iomuxc_csi_data8_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi_data8_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI_DATA8_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CSI_DATA8_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x510U)

#define HW_IOMUXC_CSI_DATA8_SELECT_INPUT(x) (*(__IO hw_iomuxc_csi_data8_select_input_t *) HW_IOMUXC_CSI_DATA8_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CSI_DATA8_SELECT_INPUT_RD(x) (HW_IOMUXC_CSI_DATA8_SELECT_INPUT(x).U)
#define HW_IOMUXC_CSI_DATA8_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CSI_DATA8_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CSI_DATA8_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CSI_DATA8_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA8_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CSI_DATA8_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CSI_DATA8_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA8_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CSI_DATA8_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CSI_DATA8_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA8_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI_DATA8_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CSI_DATA8_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: LCD_DATA09 Mode: ALT3 for CSI_DATA8
 * - 1 - Selecting Pad: ECSPI2_MISO Mode: ALT3 for CSI_DATA8
 */
/*@{*/
#define BP_IOMUXC_CSI_DATA8_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CSI_DATA8_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CSI_DATA8_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI_DATA8_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CSI_DATA8_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI_DATA8_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CSI_DATA8_SELECT_INPUT_DAISY_LCD_DATA09_ALT3 (0U) /*!< Bit field value for IOMUXC_CSI_DATA8_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA09 Mode: ALT3 for CSI_DATA8 */
#define BV_IOMUXC_CSI_DATA8_SELECT_INPUT_DAISY_ECSPI2_MISO_ALT3 (0x1U) /*!< Bit field value for IOMUXC_CSI_DATA8_SELECT_INPUT_DAISY: Selecting Pad: ECSPI2_MISO Mode: ALT3 for CSI_DATA8 */

/*! @brief Read current value of the IOMUXC_CSI_DATA8_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CSI_DATA8_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CSI_DATA8_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI_DATA8_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CSI_DATA8_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI_DATA8_SELECT_INPUT_DAISY) & BM_IOMUXC_CSI_DATA8_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI_DATA8_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CSI_DATA8_SELECT_INPUT_WR(x, (HW_IOMUXC_CSI_DATA8_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CSI_DATA8_SELECT_INPUT_DAISY) | BF_IOMUXC_CSI_DATA8_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI_DATA9_SELECT_INPUT - CSI_DATA9_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI_DATA9_SELECT_INPUT - CSI_DATA9_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_csi_data9_select_input
{
    uint32_t U;
    struct _hw_iomuxc_csi_data9_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi_data9_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI_DATA9_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CSI_DATA9_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x514U)

#define HW_IOMUXC_CSI_DATA9_SELECT_INPUT(x) (*(__IO hw_iomuxc_csi_data9_select_input_t *) HW_IOMUXC_CSI_DATA9_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CSI_DATA9_SELECT_INPUT_RD(x) (HW_IOMUXC_CSI_DATA9_SELECT_INPUT(x).U)
#define HW_IOMUXC_CSI_DATA9_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CSI_DATA9_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CSI_DATA9_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CSI_DATA9_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA9_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CSI_DATA9_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CSI_DATA9_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA9_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CSI_DATA9_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CSI_DATA9_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_DATA9_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI_DATA9_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CSI_DATA9_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: LCD_DATA08 Mode: ALT3 for CSI_DATA9
 * - 1 - Selecting Pad: ECSPI2_SS0 Mode: ALT3 for CSI_DATA9
 */
/*@{*/
#define BP_IOMUXC_CSI_DATA9_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CSI_DATA9_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CSI_DATA9_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI_DATA9_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CSI_DATA9_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI_DATA9_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CSI_DATA9_SELECT_INPUT_DAISY_LCD_DATA08_ALT3 (0U) /*!< Bit field value for IOMUXC_CSI_DATA9_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA08 Mode: ALT3 for CSI_DATA9 */
#define BV_IOMUXC_CSI_DATA9_SELECT_INPUT_DAISY_ECSPI2_SS0_ALT3 (0x1U) /*!< Bit field value for IOMUXC_CSI_DATA9_SELECT_INPUT_DAISY: Selecting Pad: ECSPI2_SS0 Mode: ALT3 for CSI_DATA9 */

/*! @brief Read current value of the IOMUXC_CSI_DATA9_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CSI_DATA9_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CSI_DATA9_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI_DATA9_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CSI_DATA9_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI_DATA9_SELECT_INPUT_DAISY) & BM_IOMUXC_CSI_DATA9_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI_DATA9_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CSI_DATA9_SELECT_INPUT_WR(x, (HW_IOMUXC_CSI_DATA9_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CSI_DATA9_SELECT_INPUT_DAISY) | BF_IOMUXC_CSI_DATA9_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI_HSYNC_SELECT_INPUT - CSI_HSYNC_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI_HSYNC_SELECT_INPUT - CSI_HSYNC_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_csi_hsync_select_input
{
    uint32_t U;
    struct _hw_iomuxc_csi_hsync_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi_hsync_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI_HSYNC_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CSI_HSYNC_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x518U)

#define HW_IOMUXC_CSI_HSYNC_SELECT_INPUT(x) (*(__IO hw_iomuxc_csi_hsync_select_input_t *) HW_IOMUXC_CSI_HSYNC_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CSI_HSYNC_SELECT_INPUT_RD(x) (HW_IOMUXC_CSI_HSYNC_SELECT_INPUT(x).U)
#define HW_IOMUXC_CSI_HSYNC_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CSI_HSYNC_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CSI_HSYNC_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CSI_HSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_HSYNC_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CSI_HSYNC_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CSI_HSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_HSYNC_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CSI_HSYNC_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CSI_HSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_HSYNC_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI_HSYNC_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CSI_HSYNC_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: LCD_DATA05 Mode: ALT3 for CSI_HSYNC
 * - 1 - Selecting Pad: I2C3_SDA Mode: ALT3 for CSI_HSYNC
 */
/*@{*/
#define BP_IOMUXC_CSI_HSYNC_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CSI_HSYNC_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CSI_HSYNC_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI_HSYNC_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CSI_HSYNC_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI_HSYNC_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CSI_HSYNC_SELECT_INPUT_DAISY_LCD_DATA05_ALT3 (0U) /*!< Bit field value for IOMUXC_CSI_HSYNC_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA05 Mode: ALT3 for CSI_HSYNC */
#define BV_IOMUXC_CSI_HSYNC_SELECT_INPUT_DAISY_I2C3_SDA_ALT3 (0x1U) /*!< Bit field value for IOMUXC_CSI_HSYNC_SELECT_INPUT_DAISY: Selecting Pad: I2C3_SDA Mode: ALT3 for CSI_HSYNC */

/*! @brief Read current value of the IOMUXC_CSI_HSYNC_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CSI_HSYNC_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CSI_HSYNC_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI_HSYNC_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CSI_HSYNC_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI_HSYNC_SELECT_INPUT_DAISY) & BM_IOMUXC_CSI_HSYNC_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI_HSYNC_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CSI_HSYNC_SELECT_INPUT_WR(x, (HW_IOMUXC_CSI_HSYNC_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CSI_HSYNC_SELECT_INPUT_DAISY) | BF_IOMUXC_CSI_HSYNC_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT - CSI_PIXCLK_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT - CSI_PIXCLK_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_csi_pixclk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_csi_pixclk_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi_pixclk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI_PIXCLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x51CU)

#define HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_csi_pixclk_select_input_t *) HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT_RD(x) (HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI_PIXCLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CSI_PIXCLK_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: LCD_DATA06 Mode: ALT3 for CSI_PIXCLK
 * - 1 - Selecting Pad: I2C4_SCL Mode: ALT3 for CSI_PIXCLK
 */
/*@{*/
#define BP_IOMUXC_CSI_PIXCLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CSI_PIXCLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CSI_PIXCLK_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI_PIXCLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CSI_PIXCLK_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI_PIXCLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CSI_PIXCLK_SELECT_INPUT_DAISY_LCD_DATA06_ALT3 (0U) /*!< Bit field value for IOMUXC_CSI_PIXCLK_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA06 Mode: ALT3 for CSI_PIXCLK */
#define BV_IOMUXC_CSI_PIXCLK_SELECT_INPUT_DAISY_I2C4_SCL_ALT3 (0x1U) /*!< Bit field value for IOMUXC_CSI_PIXCLK_SELECT_INPUT_DAISY: Selecting Pad: I2C4_SCL Mode: ALT3 for CSI_PIXCLK */

/*! @brief Read current value of the IOMUXC_CSI_PIXCLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CSI_PIXCLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI_PIXCLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CSI_PIXCLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI_PIXCLK_SELECT_INPUT_DAISY) & BM_IOMUXC_CSI_PIXCLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI_PIXCLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT_WR(x, (HW_IOMUXC_CSI_PIXCLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CSI_PIXCLK_SELECT_INPUT_DAISY) | BF_IOMUXC_CSI_PIXCLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CSI_VSYNC_SELECT_INPUT - CSI_VSYNC_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CSI_VSYNC_SELECT_INPUT - CSI_VSYNC_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_csi_vsync_select_input
{
    uint32_t U;
    struct _hw_iomuxc_csi_vsync_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_csi_vsync_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CSI_VSYNC_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CSI_VSYNC_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x520U)

#define HW_IOMUXC_CSI_VSYNC_SELECT_INPUT(x) (*(__IO hw_iomuxc_csi_vsync_select_input_t *) HW_IOMUXC_CSI_VSYNC_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CSI_VSYNC_SELECT_INPUT_RD(x) (HW_IOMUXC_CSI_VSYNC_SELECT_INPUT(x).U)
#define HW_IOMUXC_CSI_VSYNC_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CSI_VSYNC_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CSI_VSYNC_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CSI_VSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_VSYNC_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CSI_VSYNC_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CSI_VSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_VSYNC_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CSI_VSYNC_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CSI_VSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_CSI_VSYNC_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CSI_VSYNC_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CSI_VSYNC_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: LCD_DATA04 Mode: ALT3 for CSI_VSYNC
 * - 1 - Selecting Pad: I2C3_SCL Mode: ALT3 for CSI_VSYNC
 */
/*@{*/
#define BP_IOMUXC_CSI_VSYNC_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CSI_VSYNC_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CSI_VSYNC_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_CSI_VSYNC_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CSI_VSYNC_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_CSI_VSYNC_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CSI_VSYNC_SELECT_INPUT_DAISY_LCD_DATA04_ALT3 (0U) /*!< Bit field value for IOMUXC_CSI_VSYNC_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA04 Mode: ALT3 for CSI_VSYNC */
#define BV_IOMUXC_CSI_VSYNC_SELECT_INPUT_DAISY_I2C3_SCL_ALT3 (0x1U) /*!< Bit field value for IOMUXC_CSI_VSYNC_SELECT_INPUT_DAISY: Selecting Pad: I2C3_SCL Mode: ALT3 for CSI_VSYNC */

/*! @brief Read current value of the IOMUXC_CSI_VSYNC_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CSI_VSYNC_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CSI_VSYNC_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CSI_VSYNC_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CSI_VSYNC_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CSI_VSYNC_SELECT_INPUT_DAISY) & BM_IOMUXC_CSI_VSYNC_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CSI_VSYNC_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CSI_VSYNC_SELECT_INPUT_WR(x, (HW_IOMUXC_CSI_VSYNC_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CSI_VSYNC_SELECT_INPUT_DAISY) | BF_IOMUXC_CSI_VSYNC_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT - ECSPI1_SCLK_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT - ECSPI1_SCLK_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ecspi1_sclk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi1_sclk_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi1_sclk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI1_SCLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x524U)

#define HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi1_sclk_select_input_t *) HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI1_SCLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI1_SCLK_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: UART3_RTS_B Mode: ALT3 for ECSPI1_SCLK
 * - 1 - Selecting Pad: ECSPI1_SCLK Mode: ALT0 for ECSPI1_SCLK
 */
/*@{*/
#define BP_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI1_SCLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI1_SCLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI1_SCLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_DAISY_UART3_RTS_B_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI1_SCLK_SELECT_INPUT_DAISY: Selecting Pad: UART3_RTS_B Mode: ALT3 for ECSPI1_SCLK */
#define BV_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_DAISY_ECSPI1_SCLK_ALT0 (0x1U) /*!< Bit field value for IOMUXC_ECSPI1_SCLK_SELECT_INPUT_DAISY: Selecting Pad: ECSPI1_SCLK Mode: ALT0 for ECSPI1_SCLK */

/*! @brief Read current value of the IOMUXC_ECSPI1_SCLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI1_SCLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI1_SCLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT - ECSPI1_MISO_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT - ECSPI1_MISO_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ecspi1_miso_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi1_miso_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi1_miso_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI1_MISO_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x528U)

#define HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi1_miso_select_input_t *) HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI1_MISO_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI1_MISO_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: UART3_RX_DATA Mode: ALT3 for ECSPI1_MISO
 * - 1 - Selecting Pad: ECSPI1_MISO Mode: ALT0 for ECSPI1_MISO
 */
/*@{*/
#define BP_IOMUXC_ECSPI1_MISO_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI1_MISO_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI1_MISO_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI1_MISO_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI1_MISO_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI1_MISO_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI1_MISO_SELECT_INPUT_DAISY_UART3_RX_DATA_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI1_MISO_SELECT_INPUT_DAISY: Selecting Pad: UART3_RX_DATA Mode: ALT3 for ECSPI1_MISO */
#define BV_IOMUXC_ECSPI1_MISO_SELECT_INPUT_DAISY_ECSPI1_MISO_ALT0 (0x1U) /*!< Bit field value for IOMUXC_ECSPI1_MISO_SELECT_INPUT_DAISY: Selecting Pad: ECSPI1_MISO Mode: ALT0 for ECSPI1_MISO */

/*! @brief Read current value of the IOMUXC_ECSPI1_MISO_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI1_MISO_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI1_MISO_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI1_MISO_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI1_MISO_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI1_MISO_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI1_MISO_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI1_MISO_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI1_MISO_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI1_MISO_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT - ECSPI1_MOSI_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT - ECSPI1_MOSI_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ecspi1_mosi_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi1_mosi_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi1_mosi_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI1_MOSI_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x52CU)

#define HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi1_mosi_select_input_t *) HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI1_MOSI_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI1_MOSI_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: UART3_TX_DATA Mode: ALT3 for ECSPI1_MOSI
 * - 1 - Selecting Pad: ECSPI1_MOSI Mode: ALT0 for ECSPI1_MOSI
 */
/*@{*/
#define BP_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI1_MOSI_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI1_MOSI_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI1_MOSI_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_DAISY_UART3_TX_DATA_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI1_MOSI_SELECT_INPUT_DAISY: Selecting Pad: UART3_TX_DATA Mode: ALT3 for ECSPI1_MOSI */
#define BV_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_DAISY_ECSPI1_MOSI_ALT0 (0x1U) /*!< Bit field value for IOMUXC_ECSPI1_MOSI_SELECT_INPUT_DAISY: Selecting Pad: ECSPI1_MOSI Mode: ALT0 for ECSPI1_MOSI */

/*! @brief Read current value of the IOMUXC_ECSPI1_MOSI_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI1_MOSI_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI1_MOSI_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT - ECSPI1_SS0_B_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT - ECSPI1_SS0_B_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ecspi1_ss0_b_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi1_ss0_b_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi1_ss0_b_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI1_SS0_B_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x530U)

#define HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi1_ss0_b_select_input_t *) HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI1_SS0_B_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI1_SS0_B_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: UART3_CTS_B Mode: ALT3 for ECSPI1_SS0_B
 * - 1 - Selecting Pad: ECSPI1_SS0 Mode: ALT0 for ECSPI1_SS0_B
 */
/*@{*/
#define BP_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_DAISY_UART3_CTS_B_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_DAISY: Selecting Pad: UART3_CTS_B Mode: ALT3 for ECSPI1_SS0_B */
#define BV_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_DAISY_ECSPI1_SS0_ALT0 (0x1U) /*!< Bit field value for IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_DAISY: Selecting Pad: ECSPI1_SS0 Mode: ALT0 for ECSPI1_SS0_B */

/*! @brief Read current value of the IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI1_SS0_B_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT - ECSPI2_SCLK_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT - ECSPI2_SCLK_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ecspi2_sclk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi2_sclk_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi2_sclk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI2_SCLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x534U)

#define HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi2_sclk_select_input_t *) HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI2_SCLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI2_SCLK_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: ECSPI2_SCLK Mode: ALT0 for ECSPI2_SCLK
 * - 1 - Selecting Pad: ENET1_RGMII_RD2 Mode: ALT2 for ECSPI2_SCLK
 */
/*@{*/
#define BP_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI2_SCLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI2_SCLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI2_SCLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_DAISY_ECSPI2_SCLK_ALT0 (0U) /*!< Bit field value for IOMUXC_ECSPI2_SCLK_SELECT_INPUT_DAISY: Selecting Pad: ECSPI2_SCLK Mode: ALT0 for ECSPI2_SCLK */
#define BV_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_DAISY_ENET1_RGMII_RD2_ALT2 (0x1U) /*!< Bit field value for IOMUXC_ECSPI2_SCLK_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_RD2 Mode: ALT2 for ECSPI2_SCLK */

/*! @brief Read current value of the IOMUXC_ECSPI2_SCLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI2_SCLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI2_SCLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT - ECSPI2_MISO_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT - ECSPI2_MISO_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ecspi2_miso_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi2_miso_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi2_miso_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI2_MISO_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x538U)

#define HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi2_miso_select_input_t *) HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI2_MISO_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI2_MISO_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: ECSPI2_MISO Mode: ALT0 for ECSPI2_MISO
 * - 1 - Selecting Pad: ENET1_RGMII_TD2 Mode: ALT2 for ECSPI2_MISO
 */
/*@{*/
#define BP_IOMUXC_ECSPI2_MISO_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI2_MISO_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI2_MISO_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI2_MISO_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI2_MISO_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI2_MISO_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI2_MISO_SELECT_INPUT_DAISY_ECSPI2_MISO_ALT0 (0U) /*!< Bit field value for IOMUXC_ECSPI2_MISO_SELECT_INPUT_DAISY: Selecting Pad: ECSPI2_MISO Mode: ALT0 for ECSPI2_MISO */
#define BV_IOMUXC_ECSPI2_MISO_SELECT_INPUT_DAISY_ENET1_RGMII_TD2_ALT2 (0x1U) /*!< Bit field value for IOMUXC_ECSPI2_MISO_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_TD2 Mode: ALT2 for ECSPI2_MISO */

/*! @brief Read current value of the IOMUXC_ECSPI2_MISO_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI2_MISO_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI2_MISO_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI2_MISO_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI2_MISO_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI2_MISO_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI2_MISO_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI2_MISO_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI2_MISO_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI2_MISO_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT - ECSPI2_MOSI_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT - ECSPI2_MOSI_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ecspi2_mosi_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi2_mosi_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi2_mosi_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI2_MOSI_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x53CU)

#define HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi2_mosi_select_input_t *) HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI2_MOSI_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI2_MOSI_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: ECSPI2_MOSI Mode: ALT0 for ECSPI2_MOSI
 * - 1 - Selecting Pad: ENET1_RGMII_RD3 Mode: ALT2 for ECSPI2_MOSI
 */
/*@{*/
#define BP_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI2_MOSI_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI2_MOSI_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI2_MOSI_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_DAISY_ECSPI2_MOSI_ALT0 (0U) /*!< Bit field value for IOMUXC_ECSPI2_MOSI_SELECT_INPUT_DAISY: Selecting Pad: ECSPI2_MOSI Mode: ALT0 for ECSPI2_MOSI */
#define BV_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_DAISY_ENET1_RGMII_RD3_ALT2 (0x1U) /*!< Bit field value for IOMUXC_ECSPI2_MOSI_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_RD3 Mode: ALT2 for ECSPI2_MOSI */

/*! @brief Read current value of the IOMUXC_ECSPI2_MOSI_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI2_MOSI_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI2_MOSI_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT - ECSPI2_SS0_B_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT - ECSPI2_SS0_B_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ecspi2_ss0_b_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi2_ss0_b_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi2_ss0_b_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI2_SS0_B_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x540U)

#define HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi2_ss0_b_select_input_t *) HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI2_SS0_B_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI2_SS0_B_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: ECSPI2_SS0 Mode: ALT0 for ECSPI2_SS0_B
 * - 1 - Selecting Pad: ENET1_RGMII_TD3 Mode: ALT2 for ECSPI2_SS0_B
 */
/*@{*/
#define BP_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_DAISY_ECSPI2_SS0_ALT0 (0U) /*!< Bit field value for IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_DAISY: Selecting Pad: ECSPI2_SS0 Mode: ALT0 for ECSPI2_SS0_B */
#define BV_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_DAISY_ENET1_RGMII_TD3_ALT2 (0x1U) /*!< Bit field value for IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_TD3 Mode: ALT2 for ECSPI2_SS0_B */

/*! @brief Read current value of the IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI2_SS0_B_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT - ECSPI3_SCLK_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT - ECSPI3_SCLK_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ecspi3_sclk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi3_sclk_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi3_sclk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI3_SCLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x544U)

#define HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi3_sclk_select_input_t *) HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI3_SCLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI3_SCLK_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: I2C2_SCL Mode: ALT3 for ECSPI3_SCLK
 * - 1 - Selecting Pad: SAI2_RX_DATA Mode: ALT1 for ECSPI3_SCLK
 */
/*@{*/
#define BP_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI3_SCLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI3_SCLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI3_SCLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_DAISY_I2C2_SCL_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI3_SCLK_SELECT_INPUT_DAISY: Selecting Pad: I2C2_SCL Mode: ALT3 for ECSPI3_SCLK */
#define BV_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_DAISY_SAI2_RX_DATA_ALT1 (0x1U) /*!< Bit field value for IOMUXC_ECSPI3_SCLK_SELECT_INPUT_DAISY: Selecting Pad: SAI2_RX_DATA Mode: ALT1 for ECSPI3_SCLK */

/*! @brief Read current value of the IOMUXC_ECSPI3_SCLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI3_SCLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI3_SCLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT - ECSPI3_MISO_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT - ECSPI3_MISO_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ecspi3_miso_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi3_miso_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi3_miso_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI3_MISO_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x548U)

#define HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi3_miso_select_input_t *) HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI3_MISO_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI3_MISO_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: I2C1_SCL Mode: ALT3 for ECSPI3_MIS
 * - 1 - Selecting Pad: SAI2_TX_SYNC Mode: ALT1 for ECSPI3_MIS
 */
/*@{*/
#define BP_IOMUXC_ECSPI3_MISO_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI3_MISO_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI3_MISO_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI3_MISO_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI3_MISO_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI3_MISO_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI3_MISO_SELECT_INPUT_DAISY_I2C1_SCL_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI3_MISO_SELECT_INPUT_DAISY: Selecting Pad: I2C1_SCL Mode: ALT3 for ECSPI3_MIS */
#define BV_IOMUXC_ECSPI3_MISO_SELECT_INPUT_DAISY_SAI2_TX_SYNC_ALT1 (0x1U) /*!< Bit field value for IOMUXC_ECSPI3_MISO_SELECT_INPUT_DAISY: Selecting Pad: SAI2_TX_SYNC Mode: ALT1 for ECSPI3_MIS */

/*! @brief Read current value of the IOMUXC_ECSPI3_MISO_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI3_MISO_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI3_MISO_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI3_MISO_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI3_MISO_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI3_MISO_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI3_MISO_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI3_MISO_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI3_MISO_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI3_MISO_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT - ECSPI3_MOSI_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT - ECSPI3_MOSI_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ecspi3_mosi_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi3_mosi_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi3_mosi_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI3_MOSI_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x54CU)

#define HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi3_mosi_select_input_t *) HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI3_MOSI_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI3_MOSI_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: I2C1_SDA Mode: ALT3 for ECSPI3_MOSI
 * - 1 - Selecting Pad: SAI2_TX_BCLK Mode: ALT1 for ECSPI3_MOSI
 */
/*@{*/
#define BP_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI3_MOSI_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI3_MOSI_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI3_MOSI_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_DAISY_I2C1_SDA_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI3_MOSI_SELECT_INPUT_DAISY: Selecting Pad: I2C1_SDA Mode: ALT3 for ECSPI3_MOSI */
#define BV_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_DAISY_SAI2_TX_BCLK_ALT1 (0x1U) /*!< Bit field value for IOMUXC_ECSPI3_MOSI_SELECT_INPUT_DAISY: Selecting Pad: SAI2_TX_BCLK Mode: ALT1 for ECSPI3_MOSI */

/*! @brief Read current value of the IOMUXC_ECSPI3_MOSI_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI3_MOSI_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI3_MOSI_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT - ECSPI3_SS0_B_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT - ECSPI3_SS0_B_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ecspi3_ss0_b_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi3_ss0_b_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_ecspi3_ss0_b_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI3_SS0_B_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x550U)

#define HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi3_ss0_b_select_input_t *) HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI3_SS0_B_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI3_SS0_B_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: I2C2_SDA Mode: ALT3 for ECSPI3_SS0_B
 * - 1 - Selecting Pad: SAI2_TX_DATA Mode: ALT1 for ECSPI3_SS0_B
 */
/*@{*/
#define BP_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_DAISY_I2C2_SDA_ALT3 (0U) /*!< Bit field value for IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_DAISY: Selecting Pad: I2C2_SDA Mode: ALT3 for ECSPI3_SS0_B */
#define BV_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_DAISY_SAI2_TX_DATA_ALT1 (0x1U) /*!< Bit field value for IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_DAISY: Selecting Pad: SAI2_TX_DATA Mode: ALT1 for ECSPI3_SS0_B */

/*! @brief Read current value of the IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI3_SS0_B_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT - ECSPI4_SCLK_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT - ECSPI4_SCLK_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ecspi4_sclk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi4_sclk_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_ecspi4_sclk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI4_SCLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x554U)

#define HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi4_sclk_select_input_t *) HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI4_SCLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI4_SCLK_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: LCD_HSYNC Mode: ALT1 for ECSPI4_SCLK
 * - 01 - Selecting Pad: SD1_RESET_B Mode: ALT3 for ECSPI4_SCLK
 * - 10 - Selecting Pad: SD3_DATA1 Mode: ALT2 for
 */
/*@{*/
#define BP_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY_LCD_HSYNC_ALT1 (0U) /*!< Bit field value for IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY: Selecting Pad: LCD_HSYNC Mode: ALT1 for ECSPI4_SCLK */
#define BV_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY_SD1_RESET_B_ALT3 (0x1U) /*!< Bit field value for IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY: Selecting Pad: SD1_RESET_B Mode: ALT3 for ECSPI4_SCLK */
#define BV_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY_SD3_DATA1_ALT2 (0x2U) /*!< Bit field value for IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY: Selecting Pad: SD3_DATA1 Mode: ALT2 for */

/*! @brief Read current value of the IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI4_SCLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT - ECSPI4_MISO_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT - ECSPI4_MISO_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ecspi4_miso_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi4_miso_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_ecspi4_miso_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI4_MISO_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x558U)

#define HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi4_miso_select_input_t *) HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI4_MISO_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI4_MISO_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: LCD_CLK Mode: ALT1 for ECSPI4_MISO
 * - 01 - Selecting Pad: SD1_CD_B Mode: ALT3 for ECSPI4_MISO
 * - 10 - Selecting Pad: SD3_CLK Mode: ALT2 for ECSPI4_MISO
 */
/*@{*/
#define BP_IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY_LCD_CLK_ALT1 (0U) /*!< Bit field value for IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY: Selecting Pad: LCD_CLK Mode: ALT1 for ECSPI4_MISO */
#define BV_IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY_SD1_CD_B_ALT3 (0x1U) /*!< Bit field value for IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY: Selecting Pad: SD1_CD_B Mode: ALT3 for ECSPI4_MISO */
#define BV_IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY_SD3_CLK_ALT2 (0x2U) /*!< Bit field value for IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY: Selecting Pad: SD3_CLK Mode: ALT2 for ECSPI4_MISO */

/*! @brief Read current value of the IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI4_MISO_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI4_MISO_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT - ECSPI4_MOSI_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT - ECSPI4_MOSI_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ecspi4_mosi_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi4_mosi_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_ecspi4_mosi_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI4_MOSI_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x55CU)

#define HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi4_mosi_select_input_t *) HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI4_MOSI_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI4_MOSI_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: LCD_ENABLE Mode: ALT1 for ECSPI4_MOSI
 * - 01 - Selecting Pad: SD1_WP Mode: ALT3 for ECSPI4_MOSI
 * - 10 - Selecting Pad: SD3_CMD Mode: ALT2 for ECSPI4_MOSI
 */
/*@{*/
#define BP_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY_LCD_ENABLE_ALT1 (0U) /*!< Bit field value for IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY: Selecting Pad: LCD_ENABLE Mode: ALT1 for ECSPI4_MOSI */
#define BV_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY_SD1_WP_ALT3 (0x1U) /*!< Bit field value for IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY: Selecting Pad: SD1_WP Mode: ALT3 for ECSPI4_MOSI */
#define BV_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY_SD3_CMD_ALT2 (0x2U) /*!< Bit field value for IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY: Selecting Pad: SD3_CMD Mode: ALT2 for ECSPI4_MOSI */

/*! @brief Read current value of the IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI4_MOSI_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT - ECSPI4_SS0_B_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT - ECSPI4_SS0_B_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ecspi4_ss0_b_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ecspi4_ss0_b_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_ecspi4_ss0_b_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ECSPI4_SS0_B_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x560U)

#define HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT(x) (*(__IO hw_iomuxc_ecspi4_ss0_b_select_input_t *) HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_RD(x) (HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT(x).U)
#define HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_WR(x, HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ECSPI4_SS0_B_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ECSPI4_SS0_B_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: LCD_VSYNC Mode: ALT1 for ECSPI4_SS0_B
 * - 01 - Selecting Pad: SD1_CLK Mode: ALT3 for ECSPI4_SS0_B
 * - 10 - Selecting Pad: SD3_DATA0 Mode: ALT2 for ECSPI4_SS0_B
 */
/*@{*/
#define BP_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY_LCD_VSYNC_ALT1 (0U) /*!< Bit field value for IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY: Selecting Pad: LCD_VSYNC Mode: ALT1 for ECSPI4_SS0_B */
#define BV_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY_SD1_CLK_ALT3 (0x1U) /*!< Bit field value for IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY: Selecting Pad: SD1_CLK Mode: ALT3 for ECSPI4_SS0_B */
#define BV_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY_SD3_DATA0_ALT2 (0x2U) /*!< Bit field value for IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY: Selecting Pad: SD3_DATA0 Mode: ALT2 for ECSPI4_SS0_B */

/*! @brief Read current value of the IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY) & BM_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_WR(x, (HW_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY) | BF_IOMUXC_ECSPI4_SS0_B_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT - CCM_ENET1_REF_CLK_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT - CCM_ENET1_REF_CLK_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ccm_enet1_ref_clk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ccm_enet1_ref_clk_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_ccm_enet1_ref_clk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x564U)

#define HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_ccm_enet1_ref_clk_select_input_t *) HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_RD(x) (HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: GPIO1_IO12 Mode: ALT2 for CCM_ENET1_REF_CLK
 * - 01 - Selecting Pad: I2C1_SDA Mode: ALT4 for CCM_ENET1_REF_CLK
 * - 10 - Selecting Pad: ENET1_TX_CLK Mode: ALT1 for CCM_ENET1_REF_CLK
 * - 11 - Selecting Pad: GPIO1_IO02 Mode: ALT2 for CCM_ENET1_REF_CLK
 */
/*@{*/
#define BP_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY_GPIO1_IO12_ALT2 (0U) /*!< Bit field value for IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO12 Mode: ALT2 for CCM_ENET1_REF_CLK */
#define BV_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY_I2C1_SDA_ALT4 (0x1U) /*!< Bit field value for IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY: Selecting Pad: I2C1_SDA Mode: ALT4 for CCM_ENET1_REF_CLK */
#define BV_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY_ENET1_TX_CLK_ALT1 (0x2U) /*!< Bit field value for IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY: Selecting Pad: ENET1_TX_CLK Mode: ALT1 for CCM_ENET1_REF_CLK */
#define BV_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY_GPIO1_IO02_ALT2 (0x3U) /*!< Bit field value for IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO02 Mode: ALT2 for CCM_ENET1_REF_CLK */

/*! @brief Read current value of the IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY) & BM_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_WR(x, (HW_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY) | BF_IOMUXC_CCM_ENET1_REF_CLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ENET1_MDIO_SELECT_INPUT - ENET1_MDIO_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ENET1_MDIO_SELECT_INPUT - ENET1_MDIO_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_enet1_mdio_select_input
{
    uint32_t U;
    struct _hw_iomuxc_enet1_mdio_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_enet1_mdio_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ENET1_MDIO_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ENET1_MDIO_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x568U)

#define HW_IOMUXC_ENET1_MDIO_SELECT_INPUT(x) (*(__IO hw_iomuxc_enet1_mdio_select_input_t *) HW_IOMUXC_ENET1_MDIO_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ENET1_MDIO_SELECT_INPUT_RD(x) (HW_IOMUXC_ENET1_MDIO_SELECT_INPUT(x).U)
#define HW_IOMUXC_ENET1_MDIO_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ENET1_MDIO_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ENET1_MDIO_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ENET1_MDIO_SELECT_INPUT_WR(x, HW_IOMUXC_ENET1_MDIO_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ENET1_MDIO_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ENET1_MDIO_SELECT_INPUT_WR(x, HW_IOMUXC_ENET1_MDIO_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ENET1_MDIO_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ENET1_MDIO_SELECT_INPUT_WR(x, HW_IOMUXC_ENET1_MDIO_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ENET1_MDIO_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ENET1_MDIO_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: GPIO1_IO10 Mode: ALT2 for ENET1_MDIO
 * - 01 - Selecting Pad: UART1_RX_DATA Mode: ALT6 for ENET1_MDIO
 * - 10 - Selecting Pad: SD2_CD_B Mode: ALT1 for ENET1_MDIO
 */
/*@{*/
#define BP_IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY_GPIO1_IO10_ALT2 (0U) /*!< Bit field value for IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO10 Mode: ALT2 for ENET1_MDIO */
#define BV_IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY_UART1_RX_DATA_ALT6 (0x1U) /*!< Bit field value for IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY: Selecting Pad: UART1_RX_DATA Mode: ALT6 for ENET1_MDIO */
#define BV_IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY_SD2_CD_B_ALT1 (0x2U) /*!< Bit field value for IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY: Selecting Pad: SD2_CD_B Mode: ALT1 for ENET1_MDIO */

/*! @brief Read current value of the IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ENET1_MDIO_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY) & BM_IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ENET1_MDIO_SELECT_INPUT_WR(x, (HW_IOMUXC_ENET1_MDIO_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY) | BF_IOMUXC_ENET1_MDIO_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT - ENET1_RX_CLK_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT - ENET1_RX_CLK_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_enet1_rx_clk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_enet1_rx_clk_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_enet1_rx_clk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ENET1_RX_CLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x56CU)

#define HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_enet1_rx_clk_select_input_t *) HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_RD(x) (HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_WR(x, HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_WR(x, HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_WR(x, HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ENET1_RX_CLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ENET1_RX_CLK_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: ENET1_RGMII_RXC Mode: ALT0 for ENET1_RGMII_RXC
 * - 1 - Selecting Pad: ENET1_RX_CLK Mode: ALT0 for ENET1_RX_CLK
 */
/*@{*/
#define BP_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ENET1_RX_CLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ENET1_RX_CLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ENET1_RX_CLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_DAISY_ENET1_RGMII_RXC_ALT0 (0U) /*!< Bit field value for IOMUXC_ENET1_RX_CLK_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_RXC Mode: ALT0 for ENET1_RGMII_RXC */
#define BV_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_DAISY_ENET1_RX_CLK_ALT0 (0x1U) /*!< Bit field value for IOMUXC_ENET1_RX_CLK_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RX_CLK Mode: ALT0 for ENET1_RX_CLK */

/*! @brief Read current value of the IOMUXC_ENET1_RX_CLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ENET1_RX_CLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_DAISY) & BM_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_WR(x, (HW_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_DAISY) | BF_IOMUXC_ENET1_RX_CLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT - CCM_ENET2_REF_CLK_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT - CCM_ENET2_REF_CLK_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_ccm_enet2_ref_clk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_ccm_enet2_ref_clk_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_ccm_enet2_ref_clk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x570U)

#define HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_ccm_enet2_ref_clk_select_input_t *) HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_RD(x) (HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_WR(x, HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: GPIO1_IO13 Mode: ALT2 for CCM_ENET2_REF_CLK
 * - 01 - Selecting Pad: EPDC_BDR0 Mode: ALT3 for CCM_ENET2_REF_CLK
 * - 10 - Selecting Pad: I2C2_SCL Mode: ALT4 for CCM_ENET2_REF_CLK
 * - 11 - Selecting Pad: GPIO1_IO03 Mode: ALT2 for CCM_ENET2_REF_CLK
 */
/*@{*/
#define BP_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY_GPIO1_IO13_ALT2 (0U) /*!< Bit field value for IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO13 Mode: ALT2 for CCM_ENET2_REF_CLK */
#define BV_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY_EPDC_BDR0_ALT3 (0x1U) /*!< Bit field value for IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY: Selecting Pad: EPDC_BDR0 Mode: ALT3 for CCM_ENET2_REF_CLK */
#define BV_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY_I2C2_SCL_ALT4 (0x2U) /*!< Bit field value for IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY: Selecting Pad: I2C2_SCL Mode: ALT4 for CCM_ENET2_REF_CLK */
#define BV_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY_GPIO1_IO03_ALT2 (0x3U) /*!< Bit field value for IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO03 Mode: ALT2 for CCM_ENET2_REF_CLK */

/*! @brief Read current value of the IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY) & BM_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_WR(x, (HW_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY) | BF_IOMUXC_CCM_ENET2_REF_CLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ENET2_MDIO_SELECT_INPUT - ENET2_MDIO_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ENET2_MDIO_SELECT_INPUT - ENET2_MDIO_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_enet2_mdio_select_input
{
    uint32_t U;
    struct _hw_iomuxc_enet2_mdio_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_enet2_mdio_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ENET2_MDIO_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ENET2_MDIO_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x574U)

#define HW_IOMUXC_ENET2_MDIO_SELECT_INPUT(x) (*(__IO hw_iomuxc_enet2_mdio_select_input_t *) HW_IOMUXC_ENET2_MDIO_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ENET2_MDIO_SELECT_INPUT_RD(x) (HW_IOMUXC_ENET2_MDIO_SELECT_INPUT(x).U)
#define HW_IOMUXC_ENET2_MDIO_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ENET2_MDIO_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ENET2_MDIO_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ENET2_MDIO_SELECT_INPUT_WR(x, HW_IOMUXC_ENET2_MDIO_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ENET2_MDIO_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ENET2_MDIO_SELECT_INPUT_WR(x, HW_IOMUXC_ENET2_MDIO_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ENET2_MDIO_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ENET2_MDIO_SELECT_INPUT_WR(x, HW_IOMUXC_ENET2_MDIO_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ENET2_MDIO_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ENET2_MDIO_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: GPIO1_IO14 Mode: ALT2 for ENET2_MDIO
 * - 01 - Selecting Pad: UART2_RX_DATA Mode: ALT6 for ENET2_MDIO
 * - 10 - Selecting Pad: SD2_CD_B Mode: ALT2 for ENET2_MDIO
 */
/*@{*/
#define BP_IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY_GPIO1_IO14_ALT2 (0U) /*!< Bit field value for IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO14 Mode: ALT2 for ENET2_MDIO */
#define BV_IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY_UART2_RX_DATA_ALT6 (0x1U) /*!< Bit field value for IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY: Selecting Pad: UART2_RX_DATA Mode: ALT6 for ENET2_MDIO */
#define BV_IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY_SD2_CD_B_ALT2 (0x2U) /*!< Bit field value for IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY: Selecting Pad: SD2_CD_B Mode: ALT2 for ENET2_MDIO */

/*! @brief Read current value of the IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ENET2_MDIO_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY) & BM_IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ENET2_MDIO_SELECT_INPUT_WR(x, (HW_IOMUXC_ENET2_MDIO_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY) | BF_IOMUXC_ENET2_MDIO_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT - ENET2_RX_CLK_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT - ENET2_RX_CLK_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_enet2_rx_clk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_enet2_rx_clk_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_enet2_rx_clk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_ENET2_RX_CLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x578U)

#define HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_enet2_rx_clk_select_input_t *) HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_RD(x) (HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_WR(x, HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_WR(x, HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_WR(x, HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_ENET2_RX_CLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_ENET2_RX_CLK_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_SDCE1 Mode: ALT2 for ENET2_RX_CLK
 * - 1 - Selecting Pad: EPDC_BDR1 Mode: ALT2 for ENET2_RX_CLK
 */
/*@{*/
#define BP_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_ENET2_RX_CLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_ENET2_RX_CLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_ENET2_RX_CLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_DAISY_EPDC_SDCE1_ALT2 (0U) /*!< Bit field value for IOMUXC_ENET2_RX_CLK_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDCE1 Mode: ALT2 for ENET2_RX_CLK */
#define BV_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_DAISY_EPDC_BDR1_ALT2 (0x1U) /*!< Bit field value for IOMUXC_ENET2_RX_CLK_SELECT_INPUT_DAISY: Selecting Pad: EPDC_BDR1 Mode: ALT2 for ENET2_RX_CLK */

/*! @brief Read current value of the IOMUXC_ENET2_RX_CLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_ENET2_RX_CLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_DAISY) & BM_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_WR(x, (HW_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_DAISY) | BF_IOMUXC_ENET2_RX_CLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT - EPDC_PWR_IRQ_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT - EPDC_PWR_IRQ_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_epdc_pwr_irq_select_input
{
    uint32_t U;
    struct _hw_iomuxc_epdc_pwr_irq_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_epdc_pwr_irq_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x57CU)

#define HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT(x) (*(__IO hw_iomuxc_epdc_pwr_irq_select_input_t *) HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_RD(x) (HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT(x).U)
#define HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_WR(x, v) (HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_SET(x, v) (HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_WR(x, HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_WR(x, HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_WR(x, HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: ECSPI1_MISO Mode: ALT6 for EPDC_PWR_IRQ
 * - 1 - Selecting Pad: ENET1_TX_CLK Mode: ALT4 for EPDC_PWR_IRQ
 */
/*@{*/
#define BP_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_DAISY_ECSPI1_MISO_ALT6 (0U) /*!< Bit field value for IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_DAISY: Selecting Pad: ECSPI1_MISO Mode: ALT6 for EPDC_PWR_IRQ */
#define BV_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_DAISY_ENET1_TX_CLK_ALT4 (0x1U) /*!< Bit field value for IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_DAISY: Selecting Pad: ENET1_TX_CLK Mode: ALT4 for EPDC_PWR_IRQ */

/*! @brief Read current value of the IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_DAISY(x) (HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_DAISY) & BM_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_WR(x, (HW_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_RD(x) & ~BM_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_DAISY) | BF_IOMUXC_EPDC_PWR_IRQ_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT - EPDC_PWR_STAT_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT - EPDC_PWR_STAT_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_epdc_pwr_stat_select_input
{
    uint32_t U;
    struct _hw_iomuxc_epdc_pwr_stat_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_epdc_pwr_stat_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_EPDC_PWR_STAT_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x580U)

#define HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT(x) (*(__IO hw_iomuxc_epdc_pwr_stat_select_input_t *) HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_RD(x) (HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT(x).U)
#define HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_WR(x, v) (HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_SET(x, v) (HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_WR(x, HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_WR(x, HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_WR(x, HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_EPDC_PWR_STAT_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_EPDC_PWR_STAT_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_PWR_STAT Mode: ALT0 for EPDC_PWR_STAT
 * - 1 - Selecting Pad: ECSPI1_MOSI Mode: ALT6 for EPDC_PWR_STAT
 */
/*@{*/
#define BP_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_DAISY_EPDC_PWR_STAT_ALT0 (0U) /*!< Bit field value for IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_DAISY: Selecting Pad: EPDC_PWR_STAT Mode: ALT0 for EPDC_PWR_STAT */
#define BV_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_DAISY_ECSPI1_MOSI_ALT6 (0x1U) /*!< Bit field value for IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_DAISY: Selecting Pad: ECSPI1_MOSI Mode: ALT6 for EPDC_PWR_STAT */

/*! @brief Read current value of the IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_DAISY(x) (HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_DAISY) & BM_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_WR(x, (HW_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_RD(x) & ~BM_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_DAISY) | BF_IOMUXC_EPDC_PWR_STAT_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT - FLEXTIMER1_CH0_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT - FLEXTIMER1_CH0_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer1_ch0_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer1_ch0_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer1_ch0_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x584U)

#define HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer1_ch0_select_input_t *) HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_SDOE Mode: ALT1 for FLEXTIMER1_CH0
 * - 1 - Selecting Pad: SD1_CD_B Mode: ALT4 for FLEXTIMER1_CH0
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_DAISY_EPDC_SDOE_ALT1 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDOE Mode: ALT1 for FLEXTIMER1_CH0 */
#define BV_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_DAISY_SD1_CD_B_ALT4 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_DAISY: Selecting Pad: SD1_CD_B Mode: ALT4 for FLEXTIMER1_CH0 */

/*! @brief Read current value of the IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER1_CH0_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT - FLEXTIMER1_CH1_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT - FLEXTIMER1_CH1_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer1_ch1_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer1_ch1_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer1_ch1_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x588U)

#define HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer1_ch1_select_input_t *) HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_SDSHR Mode: ALT1 for FLEXTIMER1_CH1
 * - 1 - Selecting Pad: SD1_WP Mode: ALT4 for FLEXTIMER1_CH1
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_DAISY_EPDC_SDSHR_ALT1 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDSHR Mode: ALT1 for FLEXTIMER1_CH1 */
#define BV_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_DAISY_SD1_WP_ALT4 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_DAISY: Selecting Pad: SD1_WP Mode: ALT4 for FLEXTIMER1_CH1 */

/*! @brief Read current value of the IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER1_CH1_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT - FLEXTIMER1_CH2_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT - FLEXTIMER1_CH2_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer1_ch2_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer1_ch2_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer1_ch2_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x58CU)

#define HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer1_ch2_select_input_t *) HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_SDCE0 Mode: ALT1 for FLEXTIMER1_CH2
 * - 1 - Selecting Pad: SD1_RESET_B Mode: ALT4 for FLEXTIMER1_CH2
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_DAISY_EPDC_SDCE0_ALT1 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDCE0 Mode: ALT1 for FLEXTIMER1_CH2 */
#define BV_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_DAISY_SD1_RESET_B_ALT4 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_DAISY: Selecting Pad: SD1_RESET_B Mode: ALT4 for FLEXTIMER1_CH2 */

/*! @brief Read current value of the IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER1_CH2_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT - FLEXTIMER1_CH3_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT - FLEXTIMER1_CH3_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer1_ch3_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer1_ch3_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer1_ch3_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x590U)

#define HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer1_ch3_select_input_t *) HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_SDCE1 Mode: ALT1 for FLEXTIMER1_CH3
 * - 1 - Selecting Pad: SD1_CLK Mode: ALT4 for FLEXTIMER1_CH3
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_DAISY_EPDC_SDCE1_ALT1 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDCE1 Mode: ALT1 for FLEXTIMER1_CH3 */
#define BV_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_DAISY_SD1_CLK_ALT4 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_DAISY: Selecting Pad: SD1_CLK Mode: ALT4 for FLEXTIMER1_CH3 */

/*! @brief Read current value of the IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER1_CH3_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT - FLEXTIMER1_CH4_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT - FLEXTIMER1_CH4_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer1_ch4_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer1_ch4_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer1_ch4_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x594U)

#define HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer1_ch4_select_input_t *) HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: LCD_DATA16 Mode: ALT1 for FLEXTIMER1_CH4
 * - 1 - Selecting Pad: GPIO1_IO04 Mode: ALT2 for FLEXTIMER1_CH4
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_DAISY_LCD_DATA16_ALT1 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA16 Mode: ALT1 for FLEXTIMER1_CH4 */
#define BV_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_DAISY_GPIO1_IO04_ALT2 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO04 Mode: ALT2 for FLEXTIMER1_CH4 */

/*! @brief Read current value of the IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER1_CH4_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT - FLEXTIMER1_CH5_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT - FLEXTIMER1_CH5_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer1_ch5_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer1_ch5_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer1_ch5_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x598U)

#define HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer1_ch5_select_input_t *) HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: LCD_DATA17 Mode: ALT1 for FLEXTIMER1_CH5
 * - 1 - Selecting Pad: GPIO1_IO05 Mode: ALT2 for FLEXTIMER1_CH5
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_DAISY_LCD_DATA17_ALT1 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA17 Mode: ALT1 for FLEXTIMER1_CH5 */
#define BV_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_DAISY_GPIO1_IO05_ALT2 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO05 Mode: ALT2 for FLEXTIMER1_CH5 */

/*! @brief Read current value of the IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER1_CH5_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT - FLEXTIMER1_CH6_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT - FLEXTIMER1_CH6_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer1_ch6_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer1_ch6_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer1_ch6_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x59CU)

#define HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer1_ch6_select_input_t *) HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: LCD_DATA18 Mode: ALT1 for FLEXTIMER1_CH6
 * - 1 - Selecting Pad: GPIO1_IO06 Mode: ALT2 for FLEXTIMER1_CH6
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_DAISY_LCD_DATA18_ALT1 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA18 Mode: ALT1 for FLEXTIMER1_CH6 */
#define BV_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_DAISY_GPIO1_IO06_ALT2 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO06 Mode: ALT2 for FLEXTIMER1_CH6 */

/*! @brief Read current value of the IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER1_CH6_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT - FLEXTIMER1_CH7_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT - FLEXTIMER1_CH7_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer1_ch7_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer1_ch7_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer1_ch7_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5A0U)

#define HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer1_ch7_select_input_t *) HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: LCD_DATA19 Mode: ALT1 for FLEXTIMER1_CH7
 * - 1 - Selecting Pad: GPIO1_IO07 Mode: ALT2 for FLEXTIMER1_CH7
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_DAISY_LCD_DATA19_ALT1 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA19 Mode: ALT1 for FLEXTIMER1_CH7 */
#define BV_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_DAISY_GPIO1_IO07_ALT2 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO07 Mode: ALT2 for FLEXTIMER1_CH7 */

/*! @brief Read current value of the IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER1_CH7_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT - FLEXTIMER1_PHA_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT - FLEXTIMER1_PHA_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer1_pha_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer1_pha_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer1_pha_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5A4U)

#define HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer1_pha_select_input_t *) HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: GPIO1_IO10 Mode: ALT5 for FLEXTIMER1_PHA
 * - 1 - Selecting Pad: SD1_DATA3 Mode: ALT4 for FLEXTIMER1_PHA
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_DAISY_GPIO1_IO10_ALT5 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO10 Mode: ALT5 for FLEXTIMER1_PHA */
#define BV_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_DAISY_SD1_DATA3_ALT4 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_DAISY: Selecting Pad: SD1_DATA3 Mode: ALT4 for FLEXTIMER1_PHA */

/*! @brief Read current value of the IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER1_PHA_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT - FLEXTIMER1_PHB_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT - FLEXTIMER1_PHB_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer1_phb_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer1_phb_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer1_phb_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5A8U)

#define HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer1_phb_select_input_t *) HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: GPIO1_IO11 Mode: ALT5 for FLEXTIMER1_PHB
 * - 1 - Selecting Pad: SD2_CD_B Mode: ALT4 for FLEXTIMER1_PHB
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_DAISY_GPIO1_IO11_ALT5 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO11 Mode: ALT5 for FLEXTIMER1_PHB */
#define BV_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_DAISY_SD2_CD_B_ALT4 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_DAISY: Selecting Pad: SD2_CD_B Mode: ALT4 for FLEXTIMER1_PHB */

/*! @brief Read current value of the IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER1_PHB_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT - FLEXTIMER2_CH0_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT - FLEXTIMER2_CH0_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer2_ch0_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer2_ch0_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer2_ch0_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5ACU)

#define HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer2_ch0_select_input_t *) HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_GDCLK Mode: ALT1 for FLEXTIMER2_CH0
 * - 1 - Selecting Pad: SD1_CMD Mode: ALT4 for FLEXTIMER2_CH0
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_DAISY_EPDC_GDCLK_ALT1 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_DAISY: Selecting Pad: EPDC_GDCLK Mode: ALT1 for FLEXTIMER2_CH0 */
#define BV_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_DAISY_SD1_CMD_ALT4 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_DAISY: Selecting Pad: SD1_CMD Mode: ALT4 for FLEXTIMER2_CH0 */

/*! @brief Read current value of the IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER2_CH0_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT - FLEXTIMER2_CH1_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT - FLEXTIMER2_CH1_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer2_ch1_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer2_ch1_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer2_ch1_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5B0U)

#define HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer2_ch1_select_input_t *) HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_GDOE Mode: ALT1 for FLEXTIMER2_CH1
 * - 1 - Selecting Pad: SD1_DATA0 Mode: ALT4 for FLEXTIMER2_CH1
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_DAISY_EPDC_GDOE_ALT1 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_DAISY: Selecting Pad: EPDC_GDOE Mode: ALT1 for FLEXTIMER2_CH1 */
#define BV_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_DAISY_SD1_DATA0_ALT4 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_DAISY: Selecting Pad: SD1_DATA0 Mode: ALT4 for FLEXTIMER2_CH1 */

/*! @brief Read current value of the IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER2_CH1_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT - FLEXTIMER2_CH2_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT - FLEXTIMER2_CH2_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer2_ch2_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer2_ch2_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer2_ch2_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5B4U)

#define HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer2_ch2_select_input_t *) HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_GDRL Mode: ALT1 for FLEXTIMER2_CH2
 * - 1 - Selecting Pad: SD1_DATA1 Mode: ALT4 for FLEXTIMER2_CH2
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_DAISY_EPDC_GDRL_ALT1 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_DAISY: Selecting Pad: EPDC_GDRL Mode: ALT1 for FLEXTIMER2_CH2 */
#define BV_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_DAISY_SD1_DATA1_ALT4 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_DAISY: Selecting Pad: SD1_DATA1 Mode: ALT4 for FLEXTIMER2_CH2 */

/*! @brief Read current value of the IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER2_CH2_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT - FLEXTIMER2_CH3_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT - FLEXTIMER2_CH3_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer2_ch3_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer2_ch3_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer2_ch3_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5B8U)

#define HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer2_ch3_select_input_t *) HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_GDSP Mode: ALT1 for FLEXTIMER2_CH3
 * - 1 - Selecting Pad: SD1_DATA2 Mode: ALT4 for FLEXTIMER2_CH3
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_DAISY_EPDC_GDSP_ALT1 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_DAISY: Selecting Pad: EPDC_GDSP Mode: ALT1 for FLEXTIMER2_CH3 */
#define BV_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_DAISY_SD1_DATA2_ALT4 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_DAISY: Selecting Pad: SD1_DATA2 Mode: ALT4 for FLEXTIMER2_CH3 */

/*! @brief Read current value of the IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER2_CH3_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT - FLEXTIMER2_CH4_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT - FLEXTIMER2_CH4_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer2_ch4_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer2_ch4_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer2_ch4_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5BCU)

#define HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer2_ch4_select_input_t *) HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: LCD_DATA20 Mode: ALT1 for FLEXTIMER2_CH4
 * - 1 - Selecting Pad: SAI2_TX_SYNC Mode: ALT4 for FLEXTIMER2_CH4
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_DAISY_LCD_DATA20_ALT1 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA20 Mode: ALT1 for FLEXTIMER2_CH4 */
#define BV_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_DAISY_SAI2_TX_SYNC_ALT4 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_DAISY: Selecting Pad: SAI2_TX_SYNC Mode: ALT4 for FLEXTIMER2_CH4 */

/*! @brief Read current value of the IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER2_CH4_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT - FLEXTIMER2_CH5_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT - FLEXTIMER2_CH5_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer2_ch5_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer2_ch5_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer2_ch5_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5C0U)

#define HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer2_ch5_select_input_t *) HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: LCD_DATA21 Mode: ALT1 for FLEXTIMER2_CH5
 * - 1 - Selecting Pad: SAI2_TX_BCLK Mode: ALT4 for FLEXTIMER2_CH5
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_DAISY_LCD_DATA21_ALT1 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA21 Mode: ALT1 for FLEXTIMER2_CH5 */
#define BV_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_DAISY_SAI2_TX_BCLK_ALT4 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_DAISY: Selecting Pad: SAI2_TX_BCLK Mode: ALT4 for FLEXTIMER2_CH5 */

/*! @brief Read current value of the IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER2_CH5_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT - FLEXTIMER2_CH6_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT - FLEXTIMER2_CH6_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer2_ch6_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer2_ch6_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer2_ch6_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5C4U)

#define HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer2_ch6_select_input_t *) HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: LCD_DATA22 Mode: ALT1 for FLEXTIMER2_CH6
 * - 1 - Selecting Pad: SAI2_RX_DATA Mode: ALT4 for FLEXTIMER2_CH6
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_DAISY_LCD_DATA22_ALT1 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA22 Mode: ALT1 for FLEXTIMER2_CH6 */
#define BV_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_DAISY_SAI2_RX_DATA_ALT4 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_DAISY: Selecting Pad: SAI2_RX_DATA Mode: ALT4 for FLEXTIMER2_CH6 */

/*! @brief Read current value of the IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER2_CH6_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT - FLEXTIMER2_CH7_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT - FLEXTIMER2_CH7_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer2_ch7_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer2_ch7_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer2_ch7_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5C8U)

#define HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer2_ch7_select_input_t *) HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: LCD_DATA23 Mode: ALT1 for FLEXTIMER2_CH7
 * - 1 - Selecting Pad: SAI2_TX_DATA Mode: ALT4 for FLEXTIMER2_CH7
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_DAISY_LCD_DATA23_ALT1 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA23 Mode: ALT1 for FLEXTIMER2_CH7 */
#define BV_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_DAISY_SAI2_TX_DATA_ALT4 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_DAISY: Selecting Pad: SAI2_TX_DATA Mode: ALT4 for FLEXTIMER2_CH7 */

/*! @brief Read current value of the IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER2_CH7_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT - FLEXTIMER2_PHA_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT - FLEXTIMER2_PHA_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer2_pha_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer2_pha_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer2_pha_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5CCU)

#define HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer2_pha_select_input_t *) HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_PWR_COM Mode: ALT1 for FLEXTIMER2_PHA
 * - 1 - Selecting Pad: SAI1_RX_BCLK Mode: ALT4 for FLEXTIMER2_PHA
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_DAISY_EPDC_PWR_COM_ALT1 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_DAISY: Selecting Pad: EPDC_PWR_COM Mode: ALT1 for FLEXTIMER2_PHA */
#define BV_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_DAISY_SAI1_RX_BCLK_ALT4 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_DAISY: Selecting Pad: SAI1_RX_BCLK Mode: ALT4 for FLEXTIMER2_PHA */

/*! @brief Read current value of the IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER2_PHA_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT - FLEXTIMER2_PHB_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT - FLEXTIMER2_PHB_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_flextimer2_phb_select_input
{
    uint32_t U;
    struct _hw_iomuxc_flextimer2_phb_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_flextimer2_phb_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5D0U)

#define HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT(x) (*(__IO hw_iomuxc_flextimer2_phb_select_input_t *) HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_RD(x) (HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT(x).U)
#define HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_WR(x, v) (HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_SET(x, v) (HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_WR(x, HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_PWR_STAT Mode: ALT1 for FLEXTIMER2_PHB
 * - 1 - Selecting Pad: SAI1_MCLK Mode: ALT4 for FLEXTIMER2_PHB
 */
/*@{*/
#define BP_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_DAISY_EPDC_PWR_STAT_ALT1 (0U) /*!< Bit field value for IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_DAISY: Selecting Pad: EPDC_PWR_STAT Mode: ALT1 for FLEXTIMER2_PHB */
#define BV_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_DAISY_SAI1_MCLK_ALT4 (0x1U) /*!< Bit field value for IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_DAISY: Selecting Pad: SAI1_MCLK Mode: ALT4 for FLEXTIMER2_PHB */

/*! @brief Read current value of the IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_DAISY(x) (HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_DAISY) & BM_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_WR(x, (HW_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_RD(x) & ~BM_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_DAISY) | BF_IOMUXC_FLEXTIMER2_PHB_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_I2C1_SCL_SELECT_INPUT - I2C1_SCL_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_I2C1_SCL_SELECT_INPUT - I2C1_SCL_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_i2c1_scl_select_input
{
    uint32_t U;
    struct _hw_iomuxc_i2c1_scl_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_i2c1_scl_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_I2C1_SCL_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_I2C1_SCL_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5D4U)

#define HW_IOMUXC_I2C1_SCL_SELECT_INPUT(x) (*(__IO hw_iomuxc_i2c1_scl_select_input_t *) HW_IOMUXC_I2C1_SCL_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_I2C1_SCL_SELECT_INPUT_RD(x) (HW_IOMUXC_I2C1_SCL_SELECT_INPUT(x).U)
#define HW_IOMUXC_I2C1_SCL_SELECT_INPUT_WR(x, v) (HW_IOMUXC_I2C1_SCL_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_I2C1_SCL_SELECT_INPUT_SET(x, v) (HW_IOMUXC_I2C1_SCL_SELECT_INPUT_WR(x, HW_IOMUXC_I2C1_SCL_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_I2C1_SCL_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_I2C1_SCL_SELECT_INPUT_WR(x, HW_IOMUXC_I2C1_SCL_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_I2C1_SCL_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_I2C1_SCL_SELECT_INPUT_WR(x, HW_IOMUXC_I2C1_SCL_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_I2C1_SCL_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_I2C1_SCL_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: UART1_RX_DATA Mode: ALT1 for I2C1_SCL
 * - 01 - Selecting Pad: I2C1_SCL Mode: ALT0 for I2C1_SCL
 * - 10 - Selecting Pad: GPIO1_IO04 Mode: ALT4 for I2C1_SCL
 */
/*@{*/
#define BP_IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY_UART1_RX_DATA_ALT1 (0U) /*!< Bit field value for IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY: Selecting Pad: UART1_RX_DATA Mode: ALT1 for I2C1_SCL */
#define BV_IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY_I2C1_SCL_ALT0 (0x1U) /*!< Bit field value for IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY: Selecting Pad: I2C1_SCL Mode: ALT0 for I2C1_SCL */
#define BV_IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY_GPIO1_IO04_ALT4 (0x2U) /*!< Bit field value for IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO04 Mode: ALT4 for I2C1_SCL */

/*! @brief Read current value of the IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY(x) (HW_IOMUXC_I2C1_SCL_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY) & BM_IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_I2C1_SCL_SELECT_INPUT_WR(x, (HW_IOMUXC_I2C1_SCL_SELECT_INPUT_RD(x) & ~BM_IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY) | BF_IOMUXC_I2C1_SCL_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_I2C1_SDA_SELECT_INPUT - I2C1_SDA_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_I2C1_SDA_SELECT_INPUT - I2C1_SDA_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_i2c1_sda_select_input
{
    uint32_t U;
    struct _hw_iomuxc_i2c1_sda_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_i2c1_sda_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_I2C1_SDA_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_I2C1_SDA_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5D8U)

#define HW_IOMUXC_I2C1_SDA_SELECT_INPUT(x) (*(__IO hw_iomuxc_i2c1_sda_select_input_t *) HW_IOMUXC_I2C1_SDA_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_I2C1_SDA_SELECT_INPUT_RD(x) (HW_IOMUXC_I2C1_SDA_SELECT_INPUT(x).U)
#define HW_IOMUXC_I2C1_SDA_SELECT_INPUT_WR(x, v) (HW_IOMUXC_I2C1_SDA_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_I2C1_SDA_SELECT_INPUT_SET(x, v) (HW_IOMUXC_I2C1_SDA_SELECT_INPUT_WR(x, HW_IOMUXC_I2C1_SDA_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_I2C1_SDA_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_I2C1_SDA_SELECT_INPUT_WR(x, HW_IOMUXC_I2C1_SDA_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_I2C1_SDA_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_I2C1_SDA_SELECT_INPUT_WR(x, HW_IOMUXC_I2C1_SDA_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_I2C1_SDA_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_I2C1_SDA_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: UART1_TX_DATA Mode: ALT1 for I2C1_SDA
 * - 01 - Selecting Pad: I2C1_SDA Mode: ALT0 for I2C1_SDA
 * - 10 - Selecting Pad: GPIO1_IO05 Mode: ALT4 for I2C1_SDA
 */
/*@{*/
#define BP_IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY_UART1_TX_DATA_ALT1 (0U) /*!< Bit field value for IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY: Selecting Pad: UART1_TX_DATA Mode: ALT1 for I2C1_SDA */
#define BV_IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY_I2C1_SDA_ALT0 (0x1U) /*!< Bit field value for IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY: Selecting Pad: I2C1_SDA Mode: ALT0 for I2C1_SDA */
#define BV_IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY_GPIO1_IO05_ALT4 (0x2U) /*!< Bit field value for IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO05 Mode: ALT4 for I2C1_SDA */

/*! @brief Read current value of the IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY(x) (HW_IOMUXC_I2C1_SDA_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY) & BM_IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_I2C1_SDA_SELECT_INPUT_WR(x, (HW_IOMUXC_I2C1_SDA_SELECT_INPUT_RD(x) & ~BM_IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY) | BF_IOMUXC_I2C1_SDA_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_I2C2_SCL_SELECT_INPUT - I2C2_SCL_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_I2C2_SCL_SELECT_INPUT - I2C2_SCL_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_i2c2_scl_select_input
{
    uint32_t U;
    struct _hw_iomuxc_i2c2_scl_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_i2c2_scl_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_I2C2_SCL_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_I2C2_SCL_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5DCU)

#define HW_IOMUXC_I2C2_SCL_SELECT_INPUT(x) (*(__IO hw_iomuxc_i2c2_scl_select_input_t *) HW_IOMUXC_I2C2_SCL_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_I2C2_SCL_SELECT_INPUT_RD(x) (HW_IOMUXC_I2C2_SCL_SELECT_INPUT(x).U)
#define HW_IOMUXC_I2C2_SCL_SELECT_INPUT_WR(x, v) (HW_IOMUXC_I2C2_SCL_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_I2C2_SCL_SELECT_INPUT_SET(x, v) (HW_IOMUXC_I2C2_SCL_SELECT_INPUT_WR(x, HW_IOMUXC_I2C2_SCL_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_I2C2_SCL_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_I2C2_SCL_SELECT_INPUT_WR(x, HW_IOMUXC_I2C2_SCL_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_I2C2_SCL_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_I2C2_SCL_SELECT_INPUT_WR(x, HW_IOMUXC_I2C2_SCL_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_I2C2_SCL_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_I2C2_SCL_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: UART2_RX_DATA Mode: ALT1 for I2C2_SCL
 * - 01 - Selecting Pad: I2C2_SCL Mode: ALT0 for I2C2_SCL
 * - 10 - Selecting Pad: GPIO1_IO06 Mode: ALT4 for I2C2_SCL
 */
/*@{*/
#define BP_IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY_UART2_RX_DATA_ALT1 (0U) /*!< Bit field value for IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY: Selecting Pad: UART2_RX_DATA Mode: ALT1 for I2C2_SCL */
#define BV_IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY_I2C2_SCL_ALT0 (0x1U) /*!< Bit field value for IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY: Selecting Pad: I2C2_SCL Mode: ALT0 for I2C2_SCL */
#define BV_IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY_GPIO1_IO06_ALT4 (0x2U) /*!< Bit field value for IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO06 Mode: ALT4 for I2C2_SCL */

/*! @brief Read current value of the IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY(x) (HW_IOMUXC_I2C2_SCL_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY) & BM_IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_I2C2_SCL_SELECT_INPUT_WR(x, (HW_IOMUXC_I2C2_SCL_SELECT_INPUT_RD(x) & ~BM_IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY) | BF_IOMUXC_I2C2_SCL_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_I2C2_SDA_SELECT_INPUT - I2C2_SDA_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_I2C2_SDA_SELECT_INPUT - I2C2_SDA_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_i2c2_sda_select_input
{
    uint32_t U;
    struct _hw_iomuxc_i2c2_sda_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_i2c2_sda_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_I2C2_SDA_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_I2C2_SDA_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5E0U)

#define HW_IOMUXC_I2C2_SDA_SELECT_INPUT(x) (*(__IO hw_iomuxc_i2c2_sda_select_input_t *) HW_IOMUXC_I2C2_SDA_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_I2C2_SDA_SELECT_INPUT_RD(x) (HW_IOMUXC_I2C2_SDA_SELECT_INPUT(x).U)
#define HW_IOMUXC_I2C2_SDA_SELECT_INPUT_WR(x, v) (HW_IOMUXC_I2C2_SDA_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_I2C2_SDA_SELECT_INPUT_SET(x, v) (HW_IOMUXC_I2C2_SDA_SELECT_INPUT_WR(x, HW_IOMUXC_I2C2_SDA_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_I2C2_SDA_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_I2C2_SDA_SELECT_INPUT_WR(x, HW_IOMUXC_I2C2_SDA_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_I2C2_SDA_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_I2C2_SDA_SELECT_INPUT_WR(x, HW_IOMUXC_I2C2_SDA_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_I2C2_SDA_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_I2C2_SDA_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: UART2_TX_DATA Mode: ALT1 for I2C2_SDA
 * - 01 - Selecting Pad: I2C2_SDA Mode: ALT0 for I2C2_SDA
 * - 10 - Selecting Pad: GPIO1_IO07 Mode: ALT4 for I2C2_SDA
 */
/*@{*/
#define BP_IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY_UART2_TX_DATA_ALT1 (0U) /*!< Bit field value for IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY: Selecting Pad: UART2_TX_DATA Mode: ALT1 for I2C2_SDA */
#define BV_IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY_I2C2_SDA_ALT0 (0x1U) /*!< Bit field value for IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY: Selecting Pad: I2C2_SDA Mode: ALT0 for I2C2_SDA */
#define BV_IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY_GPIO1_IO07_ALT4 (0x2U) /*!< Bit field value for IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO07 Mode: ALT4 for I2C2_SDA */

/*! @brief Read current value of the IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY(x) (HW_IOMUXC_I2C2_SDA_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY) & BM_IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_I2C2_SDA_SELECT_INPUT_WR(x, (HW_IOMUXC_I2C2_SDA_SELECT_INPUT_RD(x) & ~BM_IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY) | BF_IOMUXC_I2C2_SDA_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_I2C3_SCL_SELECT_INPUT - I2C3_SCL_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_I2C3_SCL_SELECT_INPUT - I2C3_SCL_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_i2c3_scl_select_input
{
    uint32_t U;
    struct _hw_iomuxc_i2c3_scl_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_i2c3_scl_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_I2C3_SCL_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_I2C3_SCL_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5E4U)

#define HW_IOMUXC_I2C3_SCL_SELECT_INPUT(x) (*(__IO hw_iomuxc_i2c3_scl_select_input_t *) HW_IOMUXC_I2C3_SCL_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_I2C3_SCL_SELECT_INPUT_RD(x) (HW_IOMUXC_I2C3_SCL_SELECT_INPUT(x).U)
#define HW_IOMUXC_I2C3_SCL_SELECT_INPUT_WR(x, v) (HW_IOMUXC_I2C3_SCL_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_I2C3_SCL_SELECT_INPUT_SET(x, v) (HW_IOMUXC_I2C3_SCL_SELECT_INPUT_WR(x, HW_IOMUXC_I2C3_SCL_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_I2C3_SCL_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_I2C3_SCL_SELECT_INPUT_WR(x, HW_IOMUXC_I2C3_SCL_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_I2C3_SCL_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_I2C3_SCL_SELECT_INPUT_WR(x, HW_IOMUXC_I2C3_SCL_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_I2C3_SCL_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_I2C3_SCL_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting Pad: GPIO1_IO08 Mode: ALT4 for I2C3_SCL
 * - 001 - Selecting Pad: LCD_DATA20 Mode: ALT6 for I2C3_SCL
 * - 010 - Selecting Pad: I2C3_SCL Mode: ALT0 for I2C3_SCL
 * - 011 - Selecting Pad: SD3_DATA3 Mode: ALT2 for I2C3_SCL
 * - 100 - Selecting Pad: ENET1_RGMII_RD0 Mode: ALT2 for I2C3_SCL
 */
/*@{*/
#define BP_IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY_GPIO1_IO08_ALT4 (0U) /*!< Bit field value for IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO08 Mode: ALT4 for I2C3_SCL */
#define BV_IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY_LCD_DATA20_ALT6 (0x1U) /*!< Bit field value for IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA20 Mode: ALT6 for I2C3_SCL */
#define BV_IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY_I2C3_SCL_ALT0 (0x2U) /*!< Bit field value for IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY: Selecting Pad: I2C3_SCL Mode: ALT0 for I2C3_SCL */
#define BV_IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY_SD3_DATA3_ALT2 (0x3U) /*!< Bit field value for IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY: Selecting Pad: SD3_DATA3 Mode: ALT2 for I2C3_SCL */
#define BV_IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY_ENET1_RGMII_RD0_ALT2 (0x4U) /*!< Bit field value for IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_RD0 Mode: ALT2 for I2C3_SCL */

/*! @brief Read current value of the IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY(x) (HW_IOMUXC_I2C3_SCL_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY) & BM_IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_I2C3_SCL_SELECT_INPUT_WR(x, (HW_IOMUXC_I2C3_SCL_SELECT_INPUT_RD(x) & ~BM_IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY) | BF_IOMUXC_I2C3_SCL_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_I2C3_SDA_SELECT_INPUT - I2C3_SDA_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_I2C3_SDA_SELECT_INPUT - I2C3_SDA_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_i2c3_sda_select_input
{
    uint32_t U;
    struct _hw_iomuxc_i2c3_sda_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_i2c3_sda_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_I2C3_SDA_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_I2C3_SDA_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5E8U)

#define HW_IOMUXC_I2C3_SDA_SELECT_INPUT(x) (*(__IO hw_iomuxc_i2c3_sda_select_input_t *) HW_IOMUXC_I2C3_SDA_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_I2C3_SDA_SELECT_INPUT_RD(x) (HW_IOMUXC_I2C3_SDA_SELECT_INPUT(x).U)
#define HW_IOMUXC_I2C3_SDA_SELECT_INPUT_WR(x, v) (HW_IOMUXC_I2C3_SDA_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_I2C3_SDA_SELECT_INPUT_SET(x, v) (HW_IOMUXC_I2C3_SDA_SELECT_INPUT_WR(x, HW_IOMUXC_I2C3_SDA_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_I2C3_SDA_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_I2C3_SDA_SELECT_INPUT_WR(x, HW_IOMUXC_I2C3_SDA_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_I2C3_SDA_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_I2C3_SDA_SELECT_INPUT_WR(x, HW_IOMUXC_I2C3_SDA_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_I2C3_SDA_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_I2C3_SDA_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting Pad: GPIO1_IO09 Mode: ALT4 for I2C3_SDA
 * - 001 - Selecting Pad: LCD_DATA21 Mode: ALT6 for I2C3_SDA
 * - 010 - Selecting Pad: I2C3_SDA Mode: ALT0 for I2C3_SDA
 * - 011 - Selecting Pad: SD3_DATA2 Mode: ALT2 for I2C3_SDA
 * - 100 - Selecting Pad: ENET1_RGMII_RD1 Mode: ALT2 for I2C3_SDA
 */
/*@{*/
#define BP_IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY_GPIO1_IO09_ALT4 (0U) /*!< Bit field value for IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO09 Mode: ALT4 for I2C3_SDA */
#define BV_IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY_LCD_DATA21_ALT6 (0x1U) /*!< Bit field value for IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA21 Mode: ALT6 for I2C3_SDA */
#define BV_IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY_I2C3_SDA_ALT0 (0x2U) /*!< Bit field value for IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY: Selecting Pad: I2C3_SDA Mode: ALT0 for I2C3_SDA */
#define BV_IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY_SD3_DATA2_ALT2 (0x3U) /*!< Bit field value for IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY: Selecting Pad: SD3_DATA2 Mode: ALT2 for I2C3_SDA */
#define BV_IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY_ENET1_RGMII_RD1_ALT2 (0x4U) /*!< Bit field value for IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_RD1 Mode: ALT2 for I2C3_SDA */

/*! @brief Read current value of the IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY(x) (HW_IOMUXC_I2C3_SDA_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY) & BM_IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_I2C3_SDA_SELECT_INPUT_WR(x, (HW_IOMUXC_I2C3_SDA_SELECT_INPUT_RD(x) & ~BM_IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY) | BF_IOMUXC_I2C3_SDA_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_I2C4_SCL_SELECT_INPUT - I2C4_SCL_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_I2C4_SCL_SELECT_INPUT - I2C4_SCL_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_i2c4_scl_select_input
{
    uint32_t U;
    struct _hw_iomuxc_i2c4_scl_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_i2c4_scl_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_I2C4_SCL_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_I2C4_SCL_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5ECU)

#define HW_IOMUXC_I2C4_SCL_SELECT_INPUT(x) (*(__IO hw_iomuxc_i2c4_scl_select_input_t *) HW_IOMUXC_I2C4_SCL_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_I2C4_SCL_SELECT_INPUT_RD(x) (HW_IOMUXC_I2C4_SCL_SELECT_INPUT(x).U)
#define HW_IOMUXC_I2C4_SCL_SELECT_INPUT_WR(x, v) (HW_IOMUXC_I2C4_SCL_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_I2C4_SCL_SELECT_INPUT_SET(x, v) (HW_IOMUXC_I2C4_SCL_SELECT_INPUT_WR(x, HW_IOMUXC_I2C4_SCL_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_I2C4_SCL_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_I2C4_SCL_SELECT_INPUT_WR(x, HW_IOMUXC_I2C4_SCL_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_I2C4_SCL_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_I2C4_SCL_SELECT_INPUT_WR(x, HW_IOMUXC_I2C4_SCL_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_I2C4_SCL_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_I2C4_SCL_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting Pad: GPIO1_IO10 Mode: ALT4 for I2C4_SCL
 * - 001 - Selecting Pad: LCD_DATA22 Mode: ALT6 for I2C4_SCL
 * - 010 - Selecting Pad: I2C4_SCL Mode: ALT0 for I2C4_SCL
 * - 011 - Selecting Pad: SAI1_RX_SYNC Mode: ALT3 for I2C4_SCL
 * - 100 - Selecting Pad: ENET1_RGMII_TD2 Mode: ALT3 for I2C4_SCL
 */
/*@{*/
#define BP_IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY_GPIO1_IO10_ALT4 (0U) /*!< Bit field value for IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO10 Mode: ALT4 for I2C4_SCL */
#define BV_IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY_LCD_DATA22_ALT6 (0x1U) /*!< Bit field value for IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA22 Mode: ALT6 for I2C4_SCL */
#define BV_IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY_I2C4_SCL_ALT0 (0x2U) /*!< Bit field value for IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY: Selecting Pad: I2C4_SCL Mode: ALT0 for I2C4_SCL */
#define BV_IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY_SAI1_RX_SYNC_ALT3 (0x3U) /*!< Bit field value for IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY: Selecting Pad: SAI1_RX_SYNC Mode: ALT3 for I2C4_SCL */
#define BV_IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY_ENET1_RGMII_TD2_ALT3 (0x4U) /*!< Bit field value for IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_TD2 Mode: ALT3 for I2C4_SCL */

/*! @brief Read current value of the IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY(x) (HW_IOMUXC_I2C4_SCL_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY) & BM_IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_I2C4_SCL_SELECT_INPUT_WR(x, (HW_IOMUXC_I2C4_SCL_SELECT_INPUT_RD(x) & ~BM_IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY) | BF_IOMUXC_I2C4_SCL_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_I2C4_SDA_SELECT_INPUT - I2C4_SDA_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_I2C4_SDA_SELECT_INPUT - I2C4_SDA_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_i2c4_sda_select_input
{
    uint32_t U;
    struct _hw_iomuxc_i2c4_sda_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_i2c4_sda_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_I2C4_SDA_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_I2C4_SDA_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5F0U)

#define HW_IOMUXC_I2C4_SDA_SELECT_INPUT(x) (*(__IO hw_iomuxc_i2c4_sda_select_input_t *) HW_IOMUXC_I2C4_SDA_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_I2C4_SDA_SELECT_INPUT_RD(x) (HW_IOMUXC_I2C4_SDA_SELECT_INPUT(x).U)
#define HW_IOMUXC_I2C4_SDA_SELECT_INPUT_WR(x, v) (HW_IOMUXC_I2C4_SDA_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_I2C4_SDA_SELECT_INPUT_SET(x, v) (HW_IOMUXC_I2C4_SDA_SELECT_INPUT_WR(x, HW_IOMUXC_I2C4_SDA_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_I2C4_SDA_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_I2C4_SDA_SELECT_INPUT_WR(x, HW_IOMUXC_I2C4_SDA_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_I2C4_SDA_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_I2C4_SDA_SELECT_INPUT_WR(x, HW_IOMUXC_I2C4_SDA_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_I2C4_SDA_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_I2C4_SDA_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting Pad: GPIO1_IO11 Mode: ALT4 for I2C4_SDA
 * - 001 - Selecting Pad: LCD_DATA23 Mode: ALT6 for I2C4_SDA
 * - 010 - Selecting Pad: I2C4_SDA Mode: ALT0 for I2C4_SDA
 * - 011 - Selecting Pad: SAI1_RX_BCLK Mode: ALT3 for I2C4_SDA
 * - 100 - Selecting Pad: ENET1_RGMII_TD3 Mode: ALT3 for I2C4_SDA
 */
/*@{*/
#define BP_IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY_GPIO1_IO11_ALT4 (0U) /*!< Bit field value for IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO11 Mode: ALT4 for I2C4_SDA */
#define BV_IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY_LCD_DATA23_ALT6 (0x1U) /*!< Bit field value for IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA23 Mode: ALT6 for I2C4_SDA */
#define BV_IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY_I2C4_SDA_ALT0 (0x2U) /*!< Bit field value for IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY: Selecting Pad: I2C4_SDA Mode: ALT0 for I2C4_SDA */
#define BV_IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY_SAI1_RX_BCLK_ALT3 (0x3U) /*!< Bit field value for IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY: Selecting Pad: SAI1_RX_BCLK Mode: ALT3 for I2C4_SDA */
#define BV_IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY_ENET1_RGMII_TD3_ALT3 (0x4U) /*!< Bit field value for IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_TD3 Mode: ALT3 for I2C4_SDA */

/*! @brief Read current value of the IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY(x) (HW_IOMUXC_I2C4_SDA_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY) & BM_IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_I2C4_SDA_SELECT_INPUT_WR(x, (HW_IOMUXC_I2C4_SDA_SELECT_INPUT_RD(x) & ~BM_IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY) | BF_IOMUXC_I2C4_SDA_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_COL0_SELECT_INPUT - KPP_COL0_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_COL0_SELECT_INPUT - KPP_COL0_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_kpp_col0_select_input
{
    uint32_t U;
    struct _hw_iomuxc_kpp_col0_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_col0_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_COL0_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_KPP_COL0_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5F4U)

#define HW_IOMUXC_KPP_COL0_SELECT_INPUT(x) (*(__IO hw_iomuxc_kpp_col0_select_input_t *) HW_IOMUXC_KPP_COL0_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_KPP_COL0_SELECT_INPUT_RD(x) (HW_IOMUXC_KPP_COL0_SELECT_INPUT(x).U)
#define HW_IOMUXC_KPP_COL0_SELECT_INPUT_WR(x, v) (HW_IOMUXC_KPP_COL0_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_KPP_COL0_SELECT_INPUT_SET(x, v) (HW_IOMUXC_KPP_COL0_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL0_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_KPP_COL0_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_KPP_COL0_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL0_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_COL0_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_KPP_COL0_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL0_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_COL0_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_KPP_COL0_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_DATA07 Mode: ALT3 for KPP_COL0
 * - 1 - Selecting Pad: ENET1_RGMII_TD1 Mode: ALT6 for KPP_COL0
 */
/*@{*/
#define BP_IOMUXC_KPP_COL0_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_KPP_COL0_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_KPP_COL0_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_COL0_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_KPP_COL0_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_COL0_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_KPP_COL0_SELECT_INPUT_DAISY_EPDC_DATA07_ALT3 (0U) /*!< Bit field value for IOMUXC_KPP_COL0_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA07 Mode: ALT3 for KPP_COL0 */
#define BV_IOMUXC_KPP_COL0_SELECT_INPUT_DAISY_ENET1_RGMII_TD1_ALT6 (0x1U) /*!< Bit field value for IOMUXC_KPP_COL0_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_TD1 Mode: ALT6 for KPP_COL0 */

/*! @brief Read current value of the IOMUXC_KPP_COL0_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_KPP_COL0_SELECT_INPUT_DAISY(x) (HW_IOMUXC_KPP_COL0_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_COL0_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_KPP_COL0_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_COL0_SELECT_INPUT_DAISY) & BM_IOMUXC_KPP_COL0_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_COL0_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_KPP_COL0_SELECT_INPUT_WR(x, (HW_IOMUXC_KPP_COL0_SELECT_INPUT_RD(x) & ~BM_IOMUXC_KPP_COL0_SELECT_INPUT_DAISY) | BF_IOMUXC_KPP_COL0_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_COL1_SELECT_INPUT - KPP_COL1_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_COL1_SELECT_INPUT - KPP_COL1_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_kpp_col1_select_input
{
    uint32_t U;
    struct _hw_iomuxc_kpp_col1_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_col1_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_COL1_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_KPP_COL1_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5F8U)

#define HW_IOMUXC_KPP_COL1_SELECT_INPUT(x) (*(__IO hw_iomuxc_kpp_col1_select_input_t *) HW_IOMUXC_KPP_COL1_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_KPP_COL1_SELECT_INPUT_RD(x) (HW_IOMUXC_KPP_COL1_SELECT_INPUT(x).U)
#define HW_IOMUXC_KPP_COL1_SELECT_INPUT_WR(x, v) (HW_IOMUXC_KPP_COL1_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_KPP_COL1_SELECT_INPUT_SET(x, v) (HW_IOMUXC_KPP_COL1_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL1_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_KPP_COL1_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_KPP_COL1_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL1_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_COL1_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_KPP_COL1_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL1_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_COL1_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_KPP_COL1_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_DATA05 Mode: ALT3 for KPP_COL1
 * - 1 - Selecting Pad: ENET1_RGMII_RXC Mode: ALT6 for KPP_COL1
 */
/*@{*/
#define BP_IOMUXC_KPP_COL1_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_KPP_COL1_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_KPP_COL1_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_COL1_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_KPP_COL1_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_COL1_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_KPP_COL1_SELECT_INPUT_DAISY_EPDC_DATA05_ALT3 (0U) /*!< Bit field value for IOMUXC_KPP_COL1_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA05 Mode: ALT3 for KPP_COL1 */
#define BV_IOMUXC_KPP_COL1_SELECT_INPUT_DAISY_ENET1_RGMII_RXC_ALT6 (0x1U) /*!< Bit field value for IOMUXC_KPP_COL1_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_RXC Mode: ALT6 for KPP_COL1 */

/*! @brief Read current value of the IOMUXC_KPP_COL1_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_KPP_COL1_SELECT_INPUT_DAISY(x) (HW_IOMUXC_KPP_COL1_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_COL1_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_KPP_COL1_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_COL1_SELECT_INPUT_DAISY) & BM_IOMUXC_KPP_COL1_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_COL1_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_KPP_COL1_SELECT_INPUT_WR(x, (HW_IOMUXC_KPP_COL1_SELECT_INPUT_RD(x) & ~BM_IOMUXC_KPP_COL1_SELECT_INPUT_DAISY) | BF_IOMUXC_KPP_COL1_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_COL2_SELECT_INPUT - KPP_COL2_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_COL2_SELECT_INPUT - KPP_COL2_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_kpp_col2_select_input
{
    uint32_t U;
    struct _hw_iomuxc_kpp_col2_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_col2_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_COL2_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_KPP_COL2_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x5FCU)

#define HW_IOMUXC_KPP_COL2_SELECT_INPUT(x) (*(__IO hw_iomuxc_kpp_col2_select_input_t *) HW_IOMUXC_KPP_COL2_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_KPP_COL2_SELECT_INPUT_RD(x) (HW_IOMUXC_KPP_COL2_SELECT_INPUT(x).U)
#define HW_IOMUXC_KPP_COL2_SELECT_INPUT_WR(x, v) (HW_IOMUXC_KPP_COL2_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_KPP_COL2_SELECT_INPUT_SET(x, v) (HW_IOMUXC_KPP_COL2_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL2_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_KPP_COL2_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_KPP_COL2_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL2_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_COL2_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_KPP_COL2_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL2_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_COL2_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_KPP_COL2_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_DATA03 Mode: ALT3 for KPP_COL2
 * - 1 - Selecting Pad: ENET1_RGMII_RD3 Mode: ALT6 for KPP_COL2
 */
/*@{*/
#define BP_IOMUXC_KPP_COL2_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_KPP_COL2_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_KPP_COL2_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_COL2_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_KPP_COL2_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_COL2_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_KPP_COL2_SELECT_INPUT_DAISY_EPDC_DATA03_ALT3 (0U) /*!< Bit field value for IOMUXC_KPP_COL2_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA03 Mode: ALT3 for KPP_COL2 */
#define BV_IOMUXC_KPP_COL2_SELECT_INPUT_DAISY_ENET1_RGMII_RD3_ALT6 (0x1U) /*!< Bit field value for IOMUXC_KPP_COL2_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_RD3 Mode: ALT6 for KPP_COL2 */

/*! @brief Read current value of the IOMUXC_KPP_COL2_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_KPP_COL2_SELECT_INPUT_DAISY(x) (HW_IOMUXC_KPP_COL2_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_COL2_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_KPP_COL2_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_COL2_SELECT_INPUT_DAISY) & BM_IOMUXC_KPP_COL2_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_COL2_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_KPP_COL2_SELECT_INPUT_WR(x, (HW_IOMUXC_KPP_COL2_SELECT_INPUT_RD(x) & ~BM_IOMUXC_KPP_COL2_SELECT_INPUT_DAISY) | BF_IOMUXC_KPP_COL2_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_COL3_SELECT_INPUT - KPP_COL3_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_COL3_SELECT_INPUT - KPP_COL3_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_kpp_col3_select_input
{
    uint32_t U;
    struct _hw_iomuxc_kpp_col3_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_col3_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_COL3_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_KPP_COL3_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x600U)

#define HW_IOMUXC_KPP_COL3_SELECT_INPUT(x) (*(__IO hw_iomuxc_kpp_col3_select_input_t *) HW_IOMUXC_KPP_COL3_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_KPP_COL3_SELECT_INPUT_RD(x) (HW_IOMUXC_KPP_COL3_SELECT_INPUT(x).U)
#define HW_IOMUXC_KPP_COL3_SELECT_INPUT_WR(x, v) (HW_IOMUXC_KPP_COL3_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_KPP_COL3_SELECT_INPUT_SET(x, v) (HW_IOMUXC_KPP_COL3_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL3_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_KPP_COL3_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_KPP_COL3_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL3_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_COL3_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_KPP_COL3_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL3_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_COL3_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_KPP_COL3_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_DATA01 Mode: ALT3 for KPP_COL3
 * - 1 - Selecting Pad: ENET1_RGMII_RD1 Mode: ALT6 for KPP_COL3
 */
/*@{*/
#define BP_IOMUXC_KPP_COL3_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_KPP_COL3_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_KPP_COL3_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_COL3_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_KPP_COL3_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_COL3_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_KPP_COL3_SELECT_INPUT_DAISY_EPDC_DATA01_ALT3 (0U) /*!< Bit field value for IOMUXC_KPP_COL3_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA01 Mode: ALT3 for KPP_COL3 */
#define BV_IOMUXC_KPP_COL3_SELECT_INPUT_DAISY_ENET1_RGMII_RD1_ALT6 (0x1U) /*!< Bit field value for IOMUXC_KPP_COL3_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_RD1 Mode: ALT6 for KPP_COL3 */

/*! @brief Read current value of the IOMUXC_KPP_COL3_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_KPP_COL3_SELECT_INPUT_DAISY(x) (HW_IOMUXC_KPP_COL3_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_COL3_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_KPP_COL3_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_COL3_SELECT_INPUT_DAISY) & BM_IOMUXC_KPP_COL3_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_COL3_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_KPP_COL3_SELECT_INPUT_WR(x, (HW_IOMUXC_KPP_COL3_SELECT_INPUT_RD(x) & ~BM_IOMUXC_KPP_COL3_SELECT_INPUT_DAISY) | BF_IOMUXC_KPP_COL3_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_COL4_SELECT_INPUT - KPP_COL4_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_COL4_SELECT_INPUT - KPP_COL4_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_kpp_col4_select_input
{
    uint32_t U;
    struct _hw_iomuxc_kpp_col4_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_col4_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_COL4_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_KPP_COL4_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x604U)

#define HW_IOMUXC_KPP_COL4_SELECT_INPUT(x) (*(__IO hw_iomuxc_kpp_col4_select_input_t *) HW_IOMUXC_KPP_COL4_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_KPP_COL4_SELECT_INPUT_RD(x) (HW_IOMUXC_KPP_COL4_SELECT_INPUT(x).U)
#define HW_IOMUXC_KPP_COL4_SELECT_INPUT_WR(x, v) (HW_IOMUXC_KPP_COL4_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_KPP_COL4_SELECT_INPUT_SET(x, v) (HW_IOMUXC_KPP_COL4_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL4_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_KPP_COL4_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_KPP_COL4_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL4_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_COL4_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_KPP_COL4_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL4_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_COL4_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_KPP_COL4_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_SDLE Mode: ALT3 for KPP_COL4
 * - 1 - Selecting Pad: GPIO1_IO07 Mode: ALT6 for KPP_COL4
 */
/*@{*/
#define BP_IOMUXC_KPP_COL4_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_KPP_COL4_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_KPP_COL4_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_COL4_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_KPP_COL4_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_COL4_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_KPP_COL4_SELECT_INPUT_DAISY_EPDC_SDLE_ALT3 (0U) /*!< Bit field value for IOMUXC_KPP_COL4_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDLE Mode: ALT3 for KPP_COL4 */
#define BV_IOMUXC_KPP_COL4_SELECT_INPUT_DAISY_GPIO1_IO07_ALT6 (0x1U) /*!< Bit field value for IOMUXC_KPP_COL4_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO07 Mode: ALT6 for KPP_COL4 */

/*! @brief Read current value of the IOMUXC_KPP_COL4_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_KPP_COL4_SELECT_INPUT_DAISY(x) (HW_IOMUXC_KPP_COL4_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_COL4_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_KPP_COL4_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_COL4_SELECT_INPUT_DAISY) & BM_IOMUXC_KPP_COL4_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_COL4_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_KPP_COL4_SELECT_INPUT_WR(x, (HW_IOMUXC_KPP_COL4_SELECT_INPUT_RD(x) & ~BM_IOMUXC_KPP_COL4_SELECT_INPUT_DAISY) | BF_IOMUXC_KPP_COL4_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_COL5_SELECT_INPUT - KPP_COL5_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_COL5_SELECT_INPUT - KPP_COL5_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_kpp_col5_select_input
{
    uint32_t U;
    struct _hw_iomuxc_kpp_col5_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_col5_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_COL5_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_KPP_COL5_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x608U)

#define HW_IOMUXC_KPP_COL5_SELECT_INPUT(x) (*(__IO hw_iomuxc_kpp_col5_select_input_t *) HW_IOMUXC_KPP_COL5_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_KPP_COL5_SELECT_INPUT_RD(x) (HW_IOMUXC_KPP_COL5_SELECT_INPUT(x).U)
#define HW_IOMUXC_KPP_COL5_SELECT_INPUT_WR(x, v) (HW_IOMUXC_KPP_COL5_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_KPP_COL5_SELECT_INPUT_SET(x, v) (HW_IOMUXC_KPP_COL5_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL5_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_KPP_COL5_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_KPP_COL5_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL5_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_COL5_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_KPP_COL5_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL5_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_COL5_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_KPP_COL5_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: GPIO1_IO08 Mode: ALT6 for KPP_COL5
 * - 1 - Selecting Pad: EPDC_SDOE Mode: ALT3 for KPP_COL5
 */
/*@{*/
#define BP_IOMUXC_KPP_COL5_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_KPP_COL5_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_KPP_COL5_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_COL5_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_KPP_COL5_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_COL5_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_KPP_COL5_SELECT_INPUT_DAISY_GPIO1_IO08_ALT6 (0U) /*!< Bit field value for IOMUXC_KPP_COL5_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO08 Mode: ALT6 for KPP_COL5 */
#define BV_IOMUXC_KPP_COL5_SELECT_INPUT_DAISY_EPDC_SDOE_ALT3 (0x1U) /*!< Bit field value for IOMUXC_KPP_COL5_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDOE Mode: ALT3 for KPP_COL5 */

/*! @brief Read current value of the IOMUXC_KPP_COL5_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_KPP_COL5_SELECT_INPUT_DAISY(x) (HW_IOMUXC_KPP_COL5_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_COL5_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_KPP_COL5_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_COL5_SELECT_INPUT_DAISY) & BM_IOMUXC_KPP_COL5_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_COL5_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_KPP_COL5_SELECT_INPUT_WR(x, (HW_IOMUXC_KPP_COL5_SELECT_INPUT_RD(x) & ~BM_IOMUXC_KPP_COL5_SELECT_INPUT_DAISY) | BF_IOMUXC_KPP_COL5_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_COL6_SELECT_INPUT - KPP_COL6_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_COL6_SELECT_INPUT - KPP_COL6_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_kpp_col6_select_input
{
    uint32_t U;
    struct _hw_iomuxc_kpp_col6_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_col6_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_COL6_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_KPP_COL6_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x60CU)

#define HW_IOMUXC_KPP_COL6_SELECT_INPUT(x) (*(__IO hw_iomuxc_kpp_col6_select_input_t *) HW_IOMUXC_KPP_COL6_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_KPP_COL6_SELECT_INPUT_RD(x) (HW_IOMUXC_KPP_COL6_SELECT_INPUT(x).U)
#define HW_IOMUXC_KPP_COL6_SELECT_INPUT_WR(x, v) (HW_IOMUXC_KPP_COL6_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_KPP_COL6_SELECT_INPUT_SET(x, v) (HW_IOMUXC_KPP_COL6_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL6_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_KPP_COL6_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_KPP_COL6_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL6_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_COL6_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_KPP_COL6_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL6_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_COL6_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_KPP_COL6_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: GPIO1_IO10 Mode: ALT6 for KPP_COL6
 * - 1 - Selecting Pad: EPDC_SDCE2 Mode: ALT3 for KPP_COL6
 */
/*@{*/
#define BP_IOMUXC_KPP_COL6_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_KPP_COL6_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_KPP_COL6_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_COL6_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_KPP_COL6_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_COL6_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_KPP_COL6_SELECT_INPUT_DAISY_GPIO1_IO10_ALT6 (0U) /*!< Bit field value for IOMUXC_KPP_COL6_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO10 Mode: ALT6 for KPP_COL6 */
#define BV_IOMUXC_KPP_COL6_SELECT_INPUT_DAISY_EPDC_SDCE2_ALT3 (0x1U) /*!< Bit field value for IOMUXC_KPP_COL6_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDCE2 Mode: ALT3 for KPP_COL6 */

/*! @brief Read current value of the IOMUXC_KPP_COL6_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_KPP_COL6_SELECT_INPUT_DAISY(x) (HW_IOMUXC_KPP_COL6_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_COL6_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_KPP_COL6_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_COL6_SELECT_INPUT_DAISY) & BM_IOMUXC_KPP_COL6_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_COL6_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_KPP_COL6_SELECT_INPUT_WR(x, (HW_IOMUXC_KPP_COL6_SELECT_INPUT_RD(x) & ~BM_IOMUXC_KPP_COL6_SELECT_INPUT_DAISY) | BF_IOMUXC_KPP_COL6_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_COL7_SELECT_INPUT - KPP_COL7_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_COL7_SELECT_INPUT - KPP_COL7_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_kpp_col7_select_input
{
    uint32_t U;
    struct _hw_iomuxc_kpp_col7_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_col7_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_COL7_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_KPP_COL7_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x610U)

#define HW_IOMUXC_KPP_COL7_SELECT_INPUT(x) (*(__IO hw_iomuxc_kpp_col7_select_input_t *) HW_IOMUXC_KPP_COL7_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_KPP_COL7_SELECT_INPUT_RD(x) (HW_IOMUXC_KPP_COL7_SELECT_INPUT(x).U)
#define HW_IOMUXC_KPP_COL7_SELECT_INPUT_WR(x, v) (HW_IOMUXC_KPP_COL7_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_KPP_COL7_SELECT_INPUT_SET(x, v) (HW_IOMUXC_KPP_COL7_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL7_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_KPP_COL7_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_KPP_COL7_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL7_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_COL7_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_KPP_COL7_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_COL7_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_COL7_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_KPP_COL7_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_GDCLK Mode: ALT3 for KPP_COL7
 * - 1 - Selecting Pad: SAI2_RX_DATA Mode: ALT6 for KPP_COL7
 */
/*@{*/
#define BP_IOMUXC_KPP_COL7_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_KPP_COL7_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_KPP_COL7_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_COL7_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_KPP_COL7_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_COL7_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_KPP_COL7_SELECT_INPUT_DAISY_EPDC_GDCLK_ALT3 (0U) /*!< Bit field value for IOMUXC_KPP_COL7_SELECT_INPUT_DAISY: Selecting Pad: EPDC_GDCLK Mode: ALT3 for KPP_COL7 */
#define BV_IOMUXC_KPP_COL7_SELECT_INPUT_DAISY_SAI2_RX_DATA_ALT6 (0x1U) /*!< Bit field value for IOMUXC_KPP_COL7_SELECT_INPUT_DAISY: Selecting Pad: SAI2_RX_DATA Mode: ALT6 for KPP_COL7 */

/*! @brief Read current value of the IOMUXC_KPP_COL7_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_KPP_COL7_SELECT_INPUT_DAISY(x) (HW_IOMUXC_KPP_COL7_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_COL7_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_KPP_COL7_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_COL7_SELECT_INPUT_DAISY) & BM_IOMUXC_KPP_COL7_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_COL7_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_KPP_COL7_SELECT_INPUT_WR(x, (HW_IOMUXC_KPP_COL7_SELECT_INPUT_RD(x) & ~BM_IOMUXC_KPP_COL7_SELECT_INPUT_DAISY) | BF_IOMUXC_KPP_COL7_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_ROW0_SELECT_INPUT - KPP_ROW0_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_ROW0_SELECT_INPUT - KPP_ROW0_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_kpp_row0_select_input
{
    uint32_t U;
    struct _hw_iomuxc_kpp_row0_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_row0_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_ROW0_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_KPP_ROW0_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x614U)

#define HW_IOMUXC_KPP_ROW0_SELECT_INPUT(x) (*(__IO hw_iomuxc_kpp_row0_select_input_t *) HW_IOMUXC_KPP_ROW0_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_KPP_ROW0_SELECT_INPUT_RD(x) (HW_IOMUXC_KPP_ROW0_SELECT_INPUT(x).U)
#define HW_IOMUXC_KPP_ROW0_SELECT_INPUT_WR(x, v) (HW_IOMUXC_KPP_ROW0_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_KPP_ROW0_SELECT_INPUT_SET(x, v) (HW_IOMUXC_KPP_ROW0_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW0_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_KPP_ROW0_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_KPP_ROW0_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW0_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_ROW0_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_KPP_ROW0_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW0_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_ROW0_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_KPP_ROW0_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_DATA06 Mode: ALT3 for KPP_ROW0
 * - 1 - Selecting Pad: ENET1_RGMII_TD0 Mode: ALT6 for KPP_ROW0
 */
/*@{*/
#define BP_IOMUXC_KPP_ROW0_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_KPP_ROW0_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_KPP_ROW0_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_ROW0_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_KPP_ROW0_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_ROW0_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_KPP_ROW0_SELECT_INPUT_DAISY_EPDC_DATA06_ALT3 (0U) /*!< Bit field value for IOMUXC_KPP_ROW0_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA06 Mode: ALT3 for KPP_ROW0 */
#define BV_IOMUXC_KPP_ROW0_SELECT_INPUT_DAISY_ENET1_RGMII_TD0_ALT6 (0x1U) /*!< Bit field value for IOMUXC_KPP_ROW0_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_TD0 Mode: ALT6 for KPP_ROW0 */

/*! @brief Read current value of the IOMUXC_KPP_ROW0_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_KPP_ROW0_SELECT_INPUT_DAISY(x) (HW_IOMUXC_KPP_ROW0_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_ROW0_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_KPP_ROW0_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_ROW0_SELECT_INPUT_DAISY) & BM_IOMUXC_KPP_ROW0_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_ROW0_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_KPP_ROW0_SELECT_INPUT_WR(x, (HW_IOMUXC_KPP_ROW0_SELECT_INPUT_RD(x) & ~BM_IOMUXC_KPP_ROW0_SELECT_INPUT_DAISY) | BF_IOMUXC_KPP_ROW0_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_ROW1_SELECT_INPUT - KPP_ROW1_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_ROW1_SELECT_INPUT - KPP_ROW1_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_kpp_row1_select_input
{
    uint32_t U;
    struct _hw_iomuxc_kpp_row1_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_row1_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_ROW1_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_KPP_ROW1_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x618U)

#define HW_IOMUXC_KPP_ROW1_SELECT_INPUT(x) (*(__IO hw_iomuxc_kpp_row1_select_input_t *) HW_IOMUXC_KPP_ROW1_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_KPP_ROW1_SELECT_INPUT_RD(x) (HW_IOMUXC_KPP_ROW1_SELECT_INPUT(x).U)
#define HW_IOMUXC_KPP_ROW1_SELECT_INPUT_WR(x, v) (HW_IOMUXC_KPP_ROW1_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_KPP_ROW1_SELECT_INPUT_SET(x, v) (HW_IOMUXC_KPP_ROW1_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW1_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_KPP_ROW1_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_KPP_ROW1_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW1_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_ROW1_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_KPP_ROW1_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW1_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_ROW1_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_KPP_ROW1_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_DATA04 Mode: ALT3 for KPP_ROW1
 * - 1 - Selecting Pad: ENET1_RGMII_RX_CTL Mode: ALT6 for KPP_ROW1
 */
/*@{*/
#define BP_IOMUXC_KPP_ROW1_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_KPP_ROW1_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_KPP_ROW1_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_ROW1_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_KPP_ROW1_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_ROW1_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_KPP_ROW1_SELECT_INPUT_DAISY_EPDC_DATA04_ALT3 (0U) /*!< Bit field value for IOMUXC_KPP_ROW1_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA04 Mode: ALT3 for KPP_ROW1 */
#define BV_IOMUXC_KPP_ROW1_SELECT_INPUT_DAISY_ENET1_RGMII_RX_CTL_ALT6 (0x1U) /*!< Bit field value for IOMUXC_KPP_ROW1_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_RX_CTL Mode: ALT6 for KPP_ROW1 */

/*! @brief Read current value of the IOMUXC_KPP_ROW1_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_KPP_ROW1_SELECT_INPUT_DAISY(x) (HW_IOMUXC_KPP_ROW1_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_ROW1_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_KPP_ROW1_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_ROW1_SELECT_INPUT_DAISY) & BM_IOMUXC_KPP_ROW1_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_ROW1_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_KPP_ROW1_SELECT_INPUT_WR(x, (HW_IOMUXC_KPP_ROW1_SELECT_INPUT_RD(x) & ~BM_IOMUXC_KPP_ROW1_SELECT_INPUT_DAISY) | BF_IOMUXC_KPP_ROW1_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_ROW2_SELECT_INPUT - KPP_ROW2_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_ROW2_SELECT_INPUT - KPP_ROW2_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_kpp_row2_select_input
{
    uint32_t U;
    struct _hw_iomuxc_kpp_row2_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_row2_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_ROW2_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_KPP_ROW2_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x61CU)

#define HW_IOMUXC_KPP_ROW2_SELECT_INPUT(x) (*(__IO hw_iomuxc_kpp_row2_select_input_t *) HW_IOMUXC_KPP_ROW2_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_KPP_ROW2_SELECT_INPUT_RD(x) (HW_IOMUXC_KPP_ROW2_SELECT_INPUT(x).U)
#define HW_IOMUXC_KPP_ROW2_SELECT_INPUT_WR(x, v) (HW_IOMUXC_KPP_ROW2_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_KPP_ROW2_SELECT_INPUT_SET(x, v) (HW_IOMUXC_KPP_ROW2_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW2_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_KPP_ROW2_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_KPP_ROW2_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW2_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_ROW2_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_KPP_ROW2_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW2_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_ROW2_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_KPP_ROW2_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_DATA02 Mode: ALT3 for KPP_ROW2
 * - 1 - Selecting Pad: ENET1_RGMII_RD2 Mode: ALT6 for KPP_ROW2
 */
/*@{*/
#define BP_IOMUXC_KPP_ROW2_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_KPP_ROW2_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_KPP_ROW2_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_ROW2_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_KPP_ROW2_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_ROW2_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_KPP_ROW2_SELECT_INPUT_DAISY_EPDC_DATA02_ALT3 (0U) /*!< Bit field value for IOMUXC_KPP_ROW2_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA02 Mode: ALT3 for KPP_ROW2 */
#define BV_IOMUXC_KPP_ROW2_SELECT_INPUT_DAISY_ENET1_RGMII_RD2_ALT6 (0x1U) /*!< Bit field value for IOMUXC_KPP_ROW2_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_RD2 Mode: ALT6 for KPP_ROW2 */

/*! @brief Read current value of the IOMUXC_KPP_ROW2_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_KPP_ROW2_SELECT_INPUT_DAISY(x) (HW_IOMUXC_KPP_ROW2_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_ROW2_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_KPP_ROW2_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_ROW2_SELECT_INPUT_DAISY) & BM_IOMUXC_KPP_ROW2_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_ROW2_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_KPP_ROW2_SELECT_INPUT_WR(x, (HW_IOMUXC_KPP_ROW2_SELECT_INPUT_RD(x) & ~BM_IOMUXC_KPP_ROW2_SELECT_INPUT_DAISY) | BF_IOMUXC_KPP_ROW2_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_ROW3_SELECT_INPUT - KPP_ROW3_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_ROW3_SELECT_INPUT - KPP_ROW3_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_kpp_row3_select_input
{
    uint32_t U;
    struct _hw_iomuxc_kpp_row3_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_row3_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_ROW3_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_KPP_ROW3_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x620U)

#define HW_IOMUXC_KPP_ROW3_SELECT_INPUT(x) (*(__IO hw_iomuxc_kpp_row3_select_input_t *) HW_IOMUXC_KPP_ROW3_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_KPP_ROW3_SELECT_INPUT_RD(x) (HW_IOMUXC_KPP_ROW3_SELECT_INPUT(x).U)
#define HW_IOMUXC_KPP_ROW3_SELECT_INPUT_WR(x, v) (HW_IOMUXC_KPP_ROW3_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_KPP_ROW3_SELECT_INPUT_SET(x, v) (HW_IOMUXC_KPP_ROW3_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW3_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_KPP_ROW3_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_KPP_ROW3_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW3_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_ROW3_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_KPP_ROW3_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW3_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_ROW3_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_KPP_ROW3_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_DATA00 Mode: ALT3 for KPP_ROW3
 * - 1 - Selecting Pad: ENET1_RGMII_RD0 Mode: ALT6 for KPP_ROW3
 */
/*@{*/
#define BP_IOMUXC_KPP_ROW3_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_KPP_ROW3_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_KPP_ROW3_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_ROW3_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_KPP_ROW3_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_ROW3_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_KPP_ROW3_SELECT_INPUT_DAISY_EPDC_DATA00_ALT3 (0U) /*!< Bit field value for IOMUXC_KPP_ROW3_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA00 Mode: ALT3 for KPP_ROW3 */
#define BV_IOMUXC_KPP_ROW3_SELECT_INPUT_DAISY_ENET1_RGMII_RD0_ALT6 (0x1U) /*!< Bit field value for IOMUXC_KPP_ROW3_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_RD0 Mode: ALT6 for KPP_ROW3 */

/*! @brief Read current value of the IOMUXC_KPP_ROW3_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_KPP_ROW3_SELECT_INPUT_DAISY(x) (HW_IOMUXC_KPP_ROW3_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_ROW3_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_KPP_ROW3_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_ROW3_SELECT_INPUT_DAISY) & BM_IOMUXC_KPP_ROW3_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_ROW3_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_KPP_ROW3_SELECT_INPUT_WR(x, (HW_IOMUXC_KPP_ROW3_SELECT_INPUT_RD(x) & ~BM_IOMUXC_KPP_ROW3_SELECT_INPUT_DAISY) | BF_IOMUXC_KPP_ROW3_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_ROW4_SELECT_INPUT - KPP_ROW4_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_ROW4_SELECT_INPUT - KPP_ROW4_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_kpp_row4_select_input
{
    uint32_t U;
    struct _hw_iomuxc_kpp_row4_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_row4_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_ROW4_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_KPP_ROW4_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x624U)

#define HW_IOMUXC_KPP_ROW4_SELECT_INPUT(x) (*(__IO hw_iomuxc_kpp_row4_select_input_t *) HW_IOMUXC_KPP_ROW4_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_KPP_ROW4_SELECT_INPUT_RD(x) (HW_IOMUXC_KPP_ROW4_SELECT_INPUT(x).U)
#define HW_IOMUXC_KPP_ROW4_SELECT_INPUT_WR(x, v) (HW_IOMUXC_KPP_ROW4_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_KPP_ROW4_SELECT_INPUT_SET(x, v) (HW_IOMUXC_KPP_ROW4_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW4_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_KPP_ROW4_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_KPP_ROW4_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW4_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_ROW4_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_KPP_ROW4_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW4_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_ROW4_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_KPP_ROW4_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_SDCLK Mode: ALT3 for KPP_ROW4
 * - 1 - Selecting Pad: GPIO1_IO06 Mode: ALT6 for KPP_ROW4
 */
/*@{*/
#define BP_IOMUXC_KPP_ROW4_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_KPP_ROW4_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_KPP_ROW4_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_ROW4_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_KPP_ROW4_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_ROW4_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_KPP_ROW4_SELECT_INPUT_DAISY_EPDC_SDCLK_ALT3 (0U) /*!< Bit field value for IOMUXC_KPP_ROW4_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDCLK Mode: ALT3 for KPP_ROW4 */
#define BV_IOMUXC_KPP_ROW4_SELECT_INPUT_DAISY_GPIO1_IO06_ALT6 (0x1U) /*!< Bit field value for IOMUXC_KPP_ROW4_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO06 Mode: ALT6 for KPP_ROW4 */

/*! @brief Read current value of the IOMUXC_KPP_ROW4_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_KPP_ROW4_SELECT_INPUT_DAISY(x) (HW_IOMUXC_KPP_ROW4_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_ROW4_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_KPP_ROW4_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_ROW4_SELECT_INPUT_DAISY) & BM_IOMUXC_KPP_ROW4_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_ROW4_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_KPP_ROW4_SELECT_INPUT_WR(x, (HW_IOMUXC_KPP_ROW4_SELECT_INPUT_RD(x) & ~BM_IOMUXC_KPP_ROW4_SELECT_INPUT_DAISY) | BF_IOMUXC_KPP_ROW4_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_ROW5_SELECT_INPUT - KPP_ROW5_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_ROW5_SELECT_INPUT - KPP_ROW5_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_kpp_row5_select_input
{
    uint32_t U;
    struct _hw_iomuxc_kpp_row5_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_row5_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_ROW5_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_KPP_ROW5_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x628U)

#define HW_IOMUXC_KPP_ROW5_SELECT_INPUT(x) (*(__IO hw_iomuxc_kpp_row5_select_input_t *) HW_IOMUXC_KPP_ROW5_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_KPP_ROW5_SELECT_INPUT_RD(x) (HW_IOMUXC_KPP_ROW5_SELECT_INPUT(x).U)
#define HW_IOMUXC_KPP_ROW5_SELECT_INPUT_WR(x, v) (HW_IOMUXC_KPP_ROW5_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_KPP_ROW5_SELECT_INPUT_SET(x, v) (HW_IOMUXC_KPP_ROW5_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW5_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_KPP_ROW5_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_KPP_ROW5_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW5_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_ROW5_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_KPP_ROW5_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW5_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_ROW5_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_KPP_ROW5_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: GPIO1_IO09 Mode: ALT6 for KPP_ROW5
 * - 1 - Selecting Pad: EPDC_SDSHR Mode: ALT3 for KPP_ROW5
 */
/*@{*/
#define BP_IOMUXC_KPP_ROW5_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_KPP_ROW5_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_KPP_ROW5_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_ROW5_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_KPP_ROW5_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_ROW5_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_KPP_ROW5_SELECT_INPUT_DAISY_GPIO1_IO09_ALT6 (0U) /*!< Bit field value for IOMUXC_KPP_ROW5_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO09 Mode: ALT6 for KPP_ROW5 */
#define BV_IOMUXC_KPP_ROW5_SELECT_INPUT_DAISY_EPDC_SDSHR_ALT3 (0x1U) /*!< Bit field value for IOMUXC_KPP_ROW5_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDSHR Mode: ALT3 for KPP_ROW5 */

/*! @brief Read current value of the IOMUXC_KPP_ROW5_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_KPP_ROW5_SELECT_INPUT_DAISY(x) (HW_IOMUXC_KPP_ROW5_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_ROW5_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_KPP_ROW5_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_ROW5_SELECT_INPUT_DAISY) & BM_IOMUXC_KPP_ROW5_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_ROW5_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_KPP_ROW5_SELECT_INPUT_WR(x, (HW_IOMUXC_KPP_ROW5_SELECT_INPUT_RD(x) & ~BM_IOMUXC_KPP_ROW5_SELECT_INPUT_DAISY) | BF_IOMUXC_KPP_ROW5_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_ROW6_SELECT_INPUT - KPP_ROW6_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_ROW6_SELECT_INPUT - KPP_ROW6_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_kpp_row6_select_input
{
    uint32_t U;
    struct _hw_iomuxc_kpp_row6_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_row6_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_ROW6_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_KPP_ROW6_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x62CU)

#define HW_IOMUXC_KPP_ROW6_SELECT_INPUT(x) (*(__IO hw_iomuxc_kpp_row6_select_input_t *) HW_IOMUXC_KPP_ROW6_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_KPP_ROW6_SELECT_INPUT_RD(x) (HW_IOMUXC_KPP_ROW6_SELECT_INPUT(x).U)
#define HW_IOMUXC_KPP_ROW6_SELECT_INPUT_WR(x, v) (HW_IOMUXC_KPP_ROW6_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_KPP_ROW6_SELECT_INPUT_SET(x, v) (HW_IOMUXC_KPP_ROW6_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW6_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_KPP_ROW6_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_KPP_ROW6_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW6_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_ROW6_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_KPP_ROW6_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW6_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_ROW6_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_KPP_ROW6_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: GPIO1_IO11 Mode: ALT6 for KPP_ROW6
 * - 1 - Selecting Pad: EPDC_SDCE3 Mode: ALT3 for KPP_ROW6
 */
/*@{*/
#define BP_IOMUXC_KPP_ROW6_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_KPP_ROW6_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_KPP_ROW6_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_ROW6_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_KPP_ROW6_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_ROW6_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_KPP_ROW6_SELECT_INPUT_DAISY_GPIO1_IO11_ALT6 (0U) /*!< Bit field value for IOMUXC_KPP_ROW6_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO11 Mode: ALT6 for KPP_ROW6 */
#define BV_IOMUXC_KPP_ROW6_SELECT_INPUT_DAISY_EPDC_SDCE3_ALT3 (0x1U) /*!< Bit field value for IOMUXC_KPP_ROW6_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDCE3 Mode: ALT3 for KPP_ROW6 */

/*! @brief Read current value of the IOMUXC_KPP_ROW6_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_KPP_ROW6_SELECT_INPUT_DAISY(x) (HW_IOMUXC_KPP_ROW6_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_ROW6_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_KPP_ROW6_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_ROW6_SELECT_INPUT_DAISY) & BM_IOMUXC_KPP_ROW6_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_ROW6_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_KPP_ROW6_SELECT_INPUT_WR(x, (HW_IOMUXC_KPP_ROW6_SELECT_INPUT_RD(x) & ~BM_IOMUXC_KPP_ROW6_SELECT_INPUT_DAISY) | BF_IOMUXC_KPP_ROW6_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_KPP_ROW7_SELECT_INPUT - KPP_ROW7_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_KPP_ROW7_SELECT_INPUT - KPP_ROW7_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_kpp_row7_select_input
{
    uint32_t U;
    struct _hw_iomuxc_kpp_row7_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_kpp_row7_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_KPP_ROW7_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_KPP_ROW7_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x630U)

#define HW_IOMUXC_KPP_ROW7_SELECT_INPUT(x) (*(__IO hw_iomuxc_kpp_row7_select_input_t *) HW_IOMUXC_KPP_ROW7_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_KPP_ROW7_SELECT_INPUT_RD(x) (HW_IOMUXC_KPP_ROW7_SELECT_INPUT(x).U)
#define HW_IOMUXC_KPP_ROW7_SELECT_INPUT_WR(x, v) (HW_IOMUXC_KPP_ROW7_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_KPP_ROW7_SELECT_INPUT_SET(x, v) (HW_IOMUXC_KPP_ROW7_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW7_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_KPP_ROW7_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_KPP_ROW7_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW7_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_KPP_ROW7_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_KPP_ROW7_SELECT_INPUT_WR(x, HW_IOMUXC_KPP_ROW7_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_KPP_ROW7_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_KPP_ROW7_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_GDOE Mode: ALT3 for KPP_ROW7
 * - 1 - Selecting Pad: SAI2_TX_DATA Mode: ALT6 for KPP_ROW7
 */
/*@{*/
#define BP_IOMUXC_KPP_ROW7_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_KPP_ROW7_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_KPP_ROW7_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_KPP_ROW7_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_KPP_ROW7_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_KPP_ROW7_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_KPP_ROW7_SELECT_INPUT_DAISY_EPDC_GDOE_ALT3 (0U) /*!< Bit field value for IOMUXC_KPP_ROW7_SELECT_INPUT_DAISY: Selecting Pad: EPDC_GDOE Mode: ALT3 for KPP_ROW7 */
#define BV_IOMUXC_KPP_ROW7_SELECT_INPUT_DAISY_SAI2_TX_DATA_ALT6 (0x1U) /*!< Bit field value for IOMUXC_KPP_ROW7_SELECT_INPUT_DAISY: Selecting Pad: SAI2_TX_DATA Mode: ALT6 for KPP_ROW7 */

/*! @brief Read current value of the IOMUXC_KPP_ROW7_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_KPP_ROW7_SELECT_INPUT_DAISY(x) (HW_IOMUXC_KPP_ROW7_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_KPP_ROW7_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_KPP_ROW7_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_KPP_ROW7_SELECT_INPUT_DAISY) & BM_IOMUXC_KPP_ROW7_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_KPP_ROW7_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_KPP_ROW7_SELECT_INPUT_WR(x, (HW_IOMUXC_KPP_ROW7_SELECT_INPUT_RD(x) & ~BM_IOMUXC_KPP_ROW7_SELECT_INPUT_DAISY) | BF_IOMUXC_KPP_ROW7_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_BUSY_SELECT_INPUT - LCD_BUSY_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_BUSY_SELECT_INPUT - LCD_BUSY_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_busy_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_busy_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_lcd_busy_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_BUSY_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_BUSY_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x634U)

#define HW_IOMUXC_LCD_BUSY_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_busy_select_input_t *) HW_IOMUXC_LCD_BUSY_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_BUSY_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_BUSY_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_BUSY_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_BUSY_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_BUSY_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_BUSY_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_BUSY_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_BUSY_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_BUSY_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_BUSY_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_BUSY_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_BUSY_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_BUSY_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_BUSY_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_BUSY_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_DATA08 Mode: ALT7 for LCD_BUSY
 * - 1 - Selecting Pad: EPDC_GDSP Mode: ALT6 for LCD_BUSY
 */
/*@{*/
#define BP_IOMUXC_LCD_BUSY_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_BUSY_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_BUSY_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_LCD_BUSY_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_BUSY_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_LCD_BUSY_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_BUSY_SELECT_INPUT_DAISY_EPDC_DATA08_ALT7 (0U) /*!< Bit field value for IOMUXC_LCD_BUSY_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA08 Mode: ALT7 for LCD_BUSY */
#define BV_IOMUXC_LCD_BUSY_SELECT_INPUT_DAISY_EPDC_GDSP_ALT6 (0x1U) /*!< Bit field value for IOMUXC_LCD_BUSY_SELECT_INPUT_DAISY: Selecting Pad: EPDC_GDSP Mode: ALT6 for LCD_BUSY */

/*! @brief Read current value of the IOMUXC_LCD_BUSY_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_BUSY_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_BUSY_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_BUSY_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_BUSY_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_BUSY_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_BUSY_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_BUSY_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_BUSY_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_BUSY_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_BUSY_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_BUSY_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA00_SELECT_INPUT - LCD_DATA00_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA00_SELECT_INPUT - LCD_DATA00_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data00_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data00_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data00_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA00_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA00_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x638U)

#define HW_IOMUXC_LCD_DATA00_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data00_select_input_t *) HW_IOMUXC_LCD_DATA00_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA00_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA00_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA00_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA00_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA00_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA00_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA00_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA00_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA00_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA00_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA00_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA00_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA00_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA00_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA00_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_DATA00 Mode: ALT6 for LCD_DATA00
 * - 01 - Selecting Pad: EPDC_DATA09 Mode: ALT7 for LCD_DATA
 * - 10 - Selecting Pad: LCD_DATA00 Mode: ALT0 for LCD_DATA00
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY_EPDC_DATA00_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA00 Mode: ALT6 for LCD_DATA00 */
#define BV_IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY_EPDC_DATA09_ALT7 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA09 Mode: ALT7 for LCD_DATA */
#define BV_IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY_LCD_DATA00_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA00 Mode: ALT0 for LCD_DATA00 */

/*! @brief Read current value of the IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA00_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA00_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA00_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA00_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA01_SELECT_INPUT - LCD_DATA01_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA01_SELECT_INPUT - LCD_DATA01_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data01_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data01_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data01_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA01_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA01_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x63CU)

#define HW_IOMUXC_LCD_DATA01_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data01_select_input_t *) HW_IOMUXC_LCD_DATA01_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA01_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA01_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA01_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA01_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA01_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA01_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA01_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA01_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA01_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA01_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA01_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA01_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA01_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA01_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA01_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_DATA01 Mode: ALT6 for LCD_DATA01
 * - 01 - Selecting Pad: EPDC_DATA11 Mode: ALT7 for LCD_DATA01
 * - 10 - Selecting Pad: LCD_DATA01 Mode: ALT0 for LCD_DATA01
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY_EPDC_DATA01_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA01 Mode: ALT6 for LCD_DATA01 */
#define BV_IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY_EPDC_DATA11_ALT7 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA11 Mode: ALT7 for LCD_DATA01 */
#define BV_IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY_LCD_DATA01_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA01 Mode: ALT0 for LCD_DATA01 */

/*! @brief Read current value of the IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA01_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA01_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA01_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA01_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA02_SELECT_INPUT - LCD_DATA02_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA02_SELECT_INPUT - LCD_DATA02_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data02_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data02_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data02_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA02_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA02_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x640U)

#define HW_IOMUXC_LCD_DATA02_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data02_select_input_t *) HW_IOMUXC_LCD_DATA02_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA02_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA02_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA02_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA02_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA02_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA02_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA02_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA02_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA02_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA02_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA02_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA02_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA02_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA02_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA02_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_DATA02 Mode: ALT6 for LCD_DATA02
 * - 01 - Selecting Pad: EPDC_SDCE3 Mode: ALT7 for LCD_DATA02
 * - 10 - Selecting Pad: LCD_DATA02 Mode: ALT0 for LCD_DATA02
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY_EPDC_DATA02_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA02 Mode: ALT6 for LCD_DATA02 */
#define BV_IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY_EPDC_SDCE3_ALT7 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDCE3 Mode: ALT7 for LCD_DATA02 */
#define BV_IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY_LCD_DATA02_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA02 Mode: ALT0 for LCD_DATA02 */

/*! @brief Read current value of the IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA02_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA02_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA02_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA02_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA03_SELECT_INPUT - LCD_DATA03_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA03_SELECT_INPUT - LCD_DATA03_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data03_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data03_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data03_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA03_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA03_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x644U)

#define HW_IOMUXC_LCD_DATA03_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data03_select_input_t *) HW_IOMUXC_LCD_DATA03_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA03_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA03_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA03_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA03_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA03_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA03_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA03_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA03_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA03_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA03_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA03_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA03_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA03_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA03_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA03_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_DATA03 Mode: ALT6 for LCD_DATA03
 * - 01 - Selecting Pad: EPDC_SDCE2 Mode: ALT7 for LCD_DATA03
 * - 10 - Selecting Pad: LCD_DATA03 Mode: ALT0 for LCD_DATA03
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY_EPDC_DATA03_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA03 Mode: ALT6 for LCD_DATA03 */
#define BV_IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY_EPDC_SDCE2_ALT7 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDCE2 Mode: ALT7 for LCD_DATA03 */
#define BV_IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY_LCD_DATA03_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA03 Mode: ALT0 for LCD_DATA03 */

/*! @brief Read current value of the IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA03_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA03_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA03_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA03_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA04_SELECT_INPUT - LCD_DATA04_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA04_SELECT_INPUT - LCD_DATA04_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data04_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data04_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data04_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA04_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA04_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x648U)

#define HW_IOMUXC_LCD_DATA04_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data04_select_input_t *) HW_IOMUXC_LCD_DATA04_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA04_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA04_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA04_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA04_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA04_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA04_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA04_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA04_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA04_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA04_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA04_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA04_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA04_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA04_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA04_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_DATA04 Mode: ALT6 for LCD_DATA04
 * - 01 - Selecting Pad: EPDC_SDCE1 Mode: ALT7 for LCD_DATA04
 * - 10 - Selecting Pad: LCD_DATA04 Mode: ALT0 for LCD_DATA04
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY_EPDC_DATA04_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA04 Mode: ALT6 for LCD_DATA04 */
#define BV_IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY_EPDC_SDCE1_ALT7 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDCE1 Mode: ALT7 for LCD_DATA04 */
#define BV_IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY_LCD_DATA04_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA04 Mode: ALT0 for LCD_DATA04 */

/*! @brief Read current value of the IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA04_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA04_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA04_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA04_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA05_SELECT_INPUT - LCD_DATA05_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA05_SELECT_INPUT - LCD_DATA05_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data05_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data05_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data05_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA05_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA05_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x64CU)

#define HW_IOMUXC_LCD_DATA05_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data05_select_input_t *) HW_IOMUXC_LCD_DATA05_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA05_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA05_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA05_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA05_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA05_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA05_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA05_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA05_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA05_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA05_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA05_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA05_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA05_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA05_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA05_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_DATA05 Mode: ALT6 for LCD_DATA05
 * - 01 - Selecting Pad: EPDC_SDCE0 Mode: ALT7 for LCD_DATA05
 * - 10 - Selecting Pad: LCD_DATA05 Mode: ALT0 for LCD_DATA05
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY_EPDC_DATA05_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA05 Mode: ALT6 for LCD_DATA05 */
#define BV_IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY_EPDC_SDCE0_ALT7 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDCE0 Mode: ALT7 for LCD_DATA05 */
#define BV_IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY_LCD_DATA05_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA05 Mode: ALT0 for LCD_DATA05 */

/*! @brief Read current value of the IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA05_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA05_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA05_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA05_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA06_SELECT_INPUT - LCD_DATA06_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA06_SELECT_INPUT - LCD_DATA06_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data06_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data06_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data06_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA06_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA06_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x650U)

#define HW_IOMUXC_LCD_DATA06_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data06_select_input_t *) HW_IOMUXC_LCD_DATA06_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA06_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA06_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA06_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA06_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA06_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA06_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA06_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA06_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA06_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA06_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA06_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA06_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA06_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA06_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA06_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_DATA06 Mode: ALT6 for LCD_DATA06
 * - 01 - Selecting Pad: EPDC_BDR1 Mode: ALT7 for LCD_DATA06
 * - 10 - Selecting Pad: LCD_DATA06 Mode: ALT0 for LCD_DATA06
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY_EPDC_DATA06_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA06 Mode: ALT6 for LCD_DATA06 */
#define BV_IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY_EPDC_BDR1_ALT7 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY: Selecting Pad: EPDC_BDR1 Mode: ALT7 for LCD_DATA06 */
#define BV_IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY_LCD_DATA06_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA06 Mode: ALT0 for LCD_DATA06 */

/*! @brief Read current value of the IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA06_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA06_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA06_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA06_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA07_SELECT_INPUT - LCD_DATA07_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA07_SELECT_INPUT - LCD_DATA07_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data07_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data07_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data07_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA07_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA07_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x654U)

#define HW_IOMUXC_LCD_DATA07_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data07_select_input_t *) HW_IOMUXC_LCD_DATA07_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA07_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA07_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA07_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA07_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA07_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA07_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA07_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA07_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA07_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA07_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA07_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA07_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA07_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA07_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA07_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_DATA07 Mode: ALT6 for LCD_DATA07
 * - 01 - Selecting Pad: EPDC_BDR0 Mode: ALT7 for LCD_DATA07
 * - 10 - Selecting Pad: LCD_DATA07 Mode: ALT0 for LCD_DATA07
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY_EPDC_DATA07_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA07 Mode: ALT6 for LCD_DATA07 */
#define BV_IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY_EPDC_BDR0_ALT7 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY: Selecting Pad: EPDC_BDR0 Mode: ALT7 for LCD_DATA07 */
#define BV_IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY_LCD_DATA07_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA07 Mode: ALT0 for LCD_DATA07 */

/*! @brief Read current value of the IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA07_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA07_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA07_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA07_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA08_SELECT_INPUT - LCD_DATA08_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA08_SELECT_INPUT - LCD_DATA08_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data08_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data08_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data08_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA08_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA08_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x658U)

#define HW_IOMUXC_LCD_DATA08_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data08_select_input_t *) HW_IOMUXC_LCD_DATA08_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA08_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA08_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA08_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA08_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA08_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA08_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA08_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA08_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA08_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA08_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA08_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA08_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA08_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA08_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA08_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_DATA08 Mode: ALT6 for LCD_DATA08
 * - 01 - Selecting Pad: EPDC_SDLE Mode: ALT7 for LCD_DATA08
 * - 10 - Selecting Pad: LCD_DATA08 Mode: ALT0 for LCD_DATA08
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY_EPDC_DATA08_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA08 Mode: ALT6 for LCD_DATA08 */
#define BV_IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY_EPDC_SDLE_ALT7 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDLE Mode: ALT7 for LCD_DATA08 */
#define BV_IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY_LCD_DATA08_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA08 Mode: ALT0 for LCD_DATA08 */

/*! @brief Read current value of the IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA08_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA08_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA08_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA08_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA09_SELECT_INPUT - LCD_DATA09_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA09_SELECT_INPUT - LCD_DATA09_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data09_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data09_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data09_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA09_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA09_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x65CU)

#define HW_IOMUXC_LCD_DATA09_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data09_select_input_t *) HW_IOMUXC_LCD_DATA09_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA09_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA09_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA09_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA09_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA09_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA09_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA09_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA09_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA09_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA09_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA09_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA09_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA09_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA09_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA09_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_DATA09 Mode: ALT6 for LCD_DATA09
 * - 01 - Selecting Pad: EPDC_DATA10 Mode: ALT7 for LCD_DATA09
 * - 10 - Selecting Pad: LCD_DATA09 Mode: ALT0 for LCD_DATA09
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY_EPDC_DATA09_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA09 Mode: ALT6 for LCD_DATA09 */
#define BV_IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY_EPDC_DATA10_ALT7 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA10 Mode: ALT7 for LCD_DATA09 */
#define BV_IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY_LCD_DATA09_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA09 Mode: ALT0 for LCD_DATA09 */

/*! @brief Read current value of the IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA09_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA09_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA09_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA09_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA10_SELECT_INPUT - LCD_DATA10_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA10_SELECT_INPUT - LCD_DATA10_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data10_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data10_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data10_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA10_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA10_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x660U)

#define HW_IOMUXC_LCD_DATA10_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data10_select_input_t *) HW_IOMUXC_LCD_DATA10_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA10_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA10_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA10_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA10_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA10_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA10_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA10_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA10_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA10_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA10_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA10_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA10_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA10_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA10_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA10_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_DATA10 Mode: ALT6 for LCD_DATA10
 * - 01 - Selecting Pad: EPDC_SDSHR Mode: ALT7 for LCD_DATA10
 * - 10 - Selecting Pad: LCD_DATA10 Mode: ALT0 for LCD_DATA10
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY_EPDC_DATA10_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA10 Mode: ALT6 for LCD_DATA10 */
#define BV_IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY_EPDC_SDSHR_ALT7 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDSHR Mode: ALT7 for LCD_DATA10 */
#define BV_IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY_LCD_DATA10_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA10 Mode: ALT0 for LCD_DATA10 */

/*! @brief Read current value of the IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA10_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA10_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA10_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA10_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA11_SELECT_INPUT - LCD_DATA11_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA11_SELECT_INPUT - LCD_DATA11_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data11_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data11_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data11_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA11_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA11_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x664U)

#define HW_IOMUXC_LCD_DATA11_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data11_select_input_t *) HW_IOMUXC_LCD_DATA11_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA11_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA11_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA11_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA11_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA11_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA11_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA11_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA11_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA11_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA11_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA11_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA11_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA11_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA11_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA11_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_DATA11 Mode: ALT6 for LCD_DATA11
 * - 01 - Selecting Pad: EPDC_PWR_COM Mode: ALT7 for LCD_DATA11
 * - 10 - Selecting Pad: LCD_DATA11 Mode: ALT0 for LCD_DATA11
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY_EPDC_DATA11_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA11 Mode: ALT6 for LCD_DATA11 */
#define BV_IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY_EPDC_PWR_COM_ALT7 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY: Selecting Pad: EPDC_PWR_COM Mode: ALT7 for LCD_DATA11 */
#define BV_IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY_LCD_DATA11_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA11 Mode: ALT0 for LCD_DATA11 */

/*! @brief Read current value of the IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA11_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA11_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA11_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA11_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA12_SELECT_INPUT - LCD_DATA12_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA12_SELECT_INPUT - LCD_DATA12_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data12_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data12_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data12_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA12_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA12_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x668U)

#define HW_IOMUXC_LCD_DATA12_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data12_select_input_t *) HW_IOMUXC_LCD_DATA12_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA12_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA12_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA12_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA12_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA12_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA12_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA12_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA12_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA12_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA12_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA12_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA12_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA12_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA12_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA12_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_DATA12 Mode: ALT6 for LCD_DATA12
 * - 01 - Selecting Pad: EPDC_PWR_STAT Mode: ALT7 for LCD_DATA12
 * - 10 - Selecting Pad: LCD_DATA12 Mode: ALT0 for LCD_DATA12
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY_EPDC_DATA12_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA12 Mode: ALT6 for LCD_DATA12 */
#define BV_IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY_EPDC_PWR_STAT_ALT7 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY: Selecting Pad: EPDC_PWR_STAT Mode: ALT7 for LCD_DATA12 */
#define BV_IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY_LCD_DATA12_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA12 Mode: ALT0 for LCD_DATA12 */

/*! @brief Read current value of the IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA12_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA12_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA12_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA12_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA13_SELECT_INPUT - LCD_DATA13_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA13_SELECT_INPUT - LCD_DATA13_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data13_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data13_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data13_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA13_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA13_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x66CU)

#define HW_IOMUXC_LCD_DATA13_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data13_select_input_t *) HW_IOMUXC_LCD_DATA13_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA13_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA13_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA13_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA13_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA13_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA13_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA13_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA13_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA13_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA13_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA13_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA13_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA13_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA13_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA13_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_DATA13 Mode: ALT6 for LCD_DATA13
 * - 01 - Selecting Pad: LCD_DATA13 Mode: ALT0 for LCD_DATA13
 * - 10 - Selecting Pad: ECSPI2_SCLK Mode: ALT4 for LCD_DATA13
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY_EPDC_DATA13_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA13 Mode: ALT6 for LCD_DATA13 */
#define BV_IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY_LCD_DATA13_ALT0 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA13 Mode: ALT0 for LCD_DATA13 */
#define BV_IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY_ECSPI2_SCLK_ALT4 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY: Selecting Pad: ECSPI2_SCLK Mode: ALT4 for LCD_DATA13 */

/*! @brief Read current value of the IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA13_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA13_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA13_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA13_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA14_SELECT_INPUT - LCD_DATA14_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA14_SELECT_INPUT - LCD_DATA14_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data14_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data14_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data14_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA14_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA14_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x670U)

#define HW_IOMUXC_LCD_DATA14_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data14_select_input_t *) HW_IOMUXC_LCD_DATA14_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA14_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA14_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA14_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA14_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA14_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA14_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA14_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA14_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA14_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA14_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA14_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA14_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA14_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA14_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA14_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_DATA14 Mode: ALT6 for LCD_DATA14
 * - 01 - Selecting Pad: LCD_DATA14 Mode: ALT0 for LCD_DATA14
 * - 10 - Selecting Pad: ECSPI2_MOSI Mode: ALT4 for LCD_DATA14
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY_EPDC_DATA14_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA14 Mode: ALT6 for LCD_DATA14 */
#define BV_IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY_LCD_DATA14_ALT0 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA14 Mode: ALT0 for LCD_DATA14 */
#define BV_IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY_ECSPI2_MOSI_ALT4 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY: Selecting Pad: ECSPI2_MOSI Mode: ALT4 for LCD_DATA14 */

/*! @brief Read current value of the IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA14_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA14_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA14_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA14_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA15_SELECT_INPUT - LCD_DATA15_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA15_SELECT_INPUT - LCD_DATA15_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data15_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data15_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data15_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA15_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA15_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x674U)

#define HW_IOMUXC_LCD_DATA15_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data15_select_input_t *) HW_IOMUXC_LCD_DATA15_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA15_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA15_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA15_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA15_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA15_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA15_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA15_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA15_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA15_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA15_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA15_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA15_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA15_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA15_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA15_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_DATA15 Mode: ALT6 for LCD_DATA15
 * - 01 - Selecting Pad: LCD_DATA15 Mode: ALT0 for LCD_DATA15
 * - 10 - Selecting Pad: ECSPI2_MISO Mode: ALT4 for LCD_DATA15
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY_EPDC_DATA15_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA15 Mode: ALT6 for LCD_DATA15 */
#define BV_IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY_LCD_DATA15_ALT0 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA15 Mode: ALT0 for LCD_DATA15 */
#define BV_IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY_ECSPI2_MISO_ALT4 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY: Selecting Pad: ECSPI2_MISO Mode: ALT4 for LCD_DATA15 */

/*! @brief Read current value of the IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA15_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA15_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA15_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA15_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA16_SELECT_INPUT - LCD_DATA16_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA16_SELECT_INPUT - LCD_DATA16_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data16_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data16_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data16_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA16_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA16_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x678U)

#define HW_IOMUXC_LCD_DATA16_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data16_select_input_t *) HW_IOMUXC_LCD_DATA16_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA16_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA16_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA16_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA16_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA16_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA16_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA16_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA16_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA16_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA16_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA16_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA16_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA16_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA16_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA16_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_SDLE Mode: ALT6 for LCD_DATA16
 * - 01 - Selecting Pad: EPDC_GDCLK Mode: ALT7 for LCD_DATA16
 * - 10 - Selecting Pad: LCD_DATA16 Mode: ALT0 for LCD_DATA16
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY_EPDC_SDLE_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDLE Mode: ALT6 for LCD_DATA16 */
#define BV_IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY_EPDC_GDCLK_ALT7 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY: Selecting Pad: EPDC_GDCLK Mode: ALT7 for LCD_DATA16 */
#define BV_IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY_LCD_DATA16_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA16 Mode: ALT0 for LCD_DATA16 */

/*! @brief Read current value of the IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA16_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA16_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA16_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA16_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA17_SELECT_INPUT - LCD_DATA17_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA17_SELECT_INPUT - LCD_DATA17_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data17_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data17_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data17_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA17_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA17_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x67CU)

#define HW_IOMUXC_LCD_DATA17_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data17_select_input_t *) HW_IOMUXC_LCD_DATA17_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA17_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA17_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA17_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA17_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA17_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA17_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA17_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA17_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA17_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA17_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA17_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA17_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA17_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA17_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA17_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_SDOE Mode: ALT6 for LCD_DATA17
 * - 01 - Selecting Pad: EPDC_GDSP Mode: ALT7 for LCD_DATA17
 * - 10 - Selecting Pad: LCD_DATA17 Mode: ALT0 for LCD_DATA17
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY_EPDC_SDOE_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDOE Mode: ALT6 for LCD_DATA17 */
#define BV_IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY_EPDC_GDSP_ALT7 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY: Selecting Pad: EPDC_GDSP Mode: ALT7 for LCD_DATA17 */
#define BV_IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY_LCD_DATA17_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA17 Mode: ALT0 for LCD_DATA17 */

/*! @brief Read current value of the IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA17_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA17_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA17_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA17_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA18_SELECT_INPUT - LCD_DATA18_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA18_SELECT_INPUT - LCD_DATA18_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data18_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data18_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data18_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA18_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA18_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x680U)

#define HW_IOMUXC_LCD_DATA18_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data18_select_input_t *) HW_IOMUXC_LCD_DATA18_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA18_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA18_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA18_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA18_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA18_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA18_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA18_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA18_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA18_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA18_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA18_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA18_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA18_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA18_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA18_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_SDSHR Mode: ALT6 for LCD_DATA18
 * - 01 - Selecting Pad: EPDC_GDOE Mode: ALT7 for LCD_DATA18
 * - 10 - Selecting Pad: LCD_DATA18 Mode: ALT0 for LCD_DATA18
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY_EPDC_SDSHR_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDSHR Mode: ALT6 for LCD_DATA18 */
#define BV_IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY_EPDC_GDOE_ALT7 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY: Selecting Pad: EPDC_GDOE Mode: ALT7 for LCD_DATA18 */
#define BV_IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY_LCD_DATA18_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA18 Mode: ALT0 for LCD_DATA18 */

/*! @brief Read current value of the IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA18_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA18_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA18_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA18_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA19_SELECT_INPUT - LCD_DATA19_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA19_SELECT_INPUT - LCD_DATA19_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data19_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data19_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data19_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA19_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA19_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x684U)

#define HW_IOMUXC_LCD_DATA19_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data19_select_input_t *) HW_IOMUXC_LCD_DATA19_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA19_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA19_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA19_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA19_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA19_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA19_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA19_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA19_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA19_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA19_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA19_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA19_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA19_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA19_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA19_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_SDCE0 Mode: ALT6 for LCD_DATA19
 * - 01 - Selecting Pad: EPDC_GDRL Mode: ALT7 for LCD_DATA19
 * - 10 - Selecting Pad: LCD_DATA19 Mode: ALT0 for LCD_DATA19
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY_EPDC_SDCE0_ALT6 (0U) /*!< Bit field value for IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDCE0 Mode: ALT6 for LCD_DATA19 */
#define BV_IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY_EPDC_GDRL_ALT7 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY: Selecting Pad: EPDC_GDRL Mode: ALT7 for LCD_DATA19 */
#define BV_IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY_LCD_DATA19_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA19 Mode: ALT0 for LCD_DATA19 */

/*! @brief Read current value of the IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA19_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA19_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA19_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA19_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA20_SELECT_INPUT - LCD_DATA20_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA20_SELECT_INPUT - LCD_DATA20_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data20_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data20_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data20_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA20_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA20_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x688U)

#define HW_IOMUXC_LCD_DATA20_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data20_select_input_t *) HW_IOMUXC_LCD_DATA20_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA20_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA20_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA20_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA20_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA20_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA20_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA20_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA20_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA20_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA20_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA20_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA20_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA20_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA20_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA20_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_SDCLK Mode: ALT7 for LCD_DATA20
 * - 01 - Selecting Pad: EPDC_SDCE1 Mode: ALT6 for LCD_DATA20
 * - 10 - Selecting Pad: LCD_DATA20 Mode: ALT0 for LCD_DATA20
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY_EPDC_SDCLK_ALT7 (0U) /*!< Bit field value for IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDCLK Mode: ALT7 for LCD_DATA20 */
#define BV_IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY_EPDC_SDCE1_ALT6 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDCE1 Mode: ALT6 for LCD_DATA20 */
#define BV_IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY_LCD_DATA20_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA20 Mode: ALT0 for LCD_DATA20 */

/*! @brief Read current value of the IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA20_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA20_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA20_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA20_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA21_SELECT_INPUT - LCD_DATA21_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA21_SELECT_INPUT - LCD_DATA21_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data21_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data21_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data21_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA21_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA21_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x68CU)

#define HW_IOMUXC_LCD_DATA21_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data21_select_input_t *) HW_IOMUXC_LCD_DATA21_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA21_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA21_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA21_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA21_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA21_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA21_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA21_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA21_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA21_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA21_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA21_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA21_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA21_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA21_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA21_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_DATA12 Mode: ALT7 for LCD_DATA21
 * - 01 - Selecting Pad: EPDC_SDCE2 Mode: ALT6 for LCD_DATA21
 * - 10 - Selecting Pad: LCD_DATA21 Mode: ALT0 for LCD_DATA21
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY_EPDC_DATA12_ALT7 (0U) /*!< Bit field value for IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA12 Mode: ALT7 for LCD_DATA21 */
#define BV_IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY_EPDC_SDCE2_ALT6 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDCE2 Mode: ALT6 for LCD_DATA21 */
#define BV_IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY_LCD_DATA21_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA21 Mode: ALT0 for LCD_DATA21 */

/*! @brief Read current value of the IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA21_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA21_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA21_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA21_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA22_SELECT_INPUT - LCD_DATA22_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA22_SELECT_INPUT - LCD_DATA22_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data22_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data22_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data22_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA22_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA22_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x690U)

#define HW_IOMUXC_LCD_DATA22_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data22_select_input_t *) HW_IOMUXC_LCD_DATA22_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA22_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA22_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA22_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA22_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA22_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA22_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA22_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA22_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA22_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA22_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA22_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA22_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA22_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA22_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA22_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_DATA14 Mode: ALT7 for LCD_DATA22
 * - 01 - Selecting Pad: EPDC_SDCE3 Mode: ALT6 for LCD_DATA22
 * - 10 - Selecting Pad: LCD_DATA22 Mode: ALT0 for LCD_DATA22
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY_EPDC_DATA14_ALT7 (0U) /*!< Bit field value for IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA14 Mode: ALT7 for LCD_DATA22 */
#define BV_IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY_EPDC_SDCE3_ALT6 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDCE3 Mode: ALT6 for LCD_DATA22 */
#define BV_IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY_LCD_DATA22_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA22 Mode: ALT0 for LCD_DATA22 */

/*! @brief Read current value of the IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA22_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA22_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA22_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA22_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_DATA23_SELECT_INPUT - LCD_DATA23_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_DATA23_SELECT_INPUT - LCD_DATA23_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_data23_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_data23_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_data23_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_DATA23_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_DATA23_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x694U)

#define HW_IOMUXC_LCD_DATA23_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_data23_select_input_t *) HW_IOMUXC_LCD_DATA23_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_DATA23_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_DATA23_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_DATA23_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_DATA23_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_DATA23_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_DATA23_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA23_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_DATA23_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_DATA23_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA23_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_DATA23_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_DATA23_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_DATA23_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_DATA23_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_DATA23_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_SDOE Mode: ALT7 for LCD_DATA23
 * - 01 - Selecting Pad: EPDC_GDCLK Mode: ALT6 for LCD_DATA23
 * - 10 - Selecting Pad: LCD_DATA23 Mode: ALT0 for LCD_DATA23
 */
/*@{*/
#define BP_IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY_EPDC_SDOE_ALT7 (0U) /*!< Bit field value for IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDOE Mode: ALT7 for LCD_DATA23 */
#define BV_IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY_EPDC_GDCLK_ALT6 (0x1U) /*!< Bit field value for IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY: Selecting Pad: EPDC_GDCLK Mode: ALT6 for LCD_DATA23 */
#define BV_IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY_LCD_DATA23_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY: Selecting Pad: LCD_DATA23 Mode: ALT0 for LCD_DATA23 */

/*! @brief Read current value of the IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_DATA23_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_DATA23_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_DATA23_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_DATA23_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LCD_VSYNC_SELECT_INPUT - LCD_VSYNC_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LCD_VSYNC_SELECT_INPUT - LCD_VSYNC_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_lcd_vsync_select_input
{
    uint32_t U;
    struct _hw_iomuxc_lcd_vsync_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_lcd_vsync_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_LCD_VSYNC_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_LCD_VSYNC_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x698U)

#define HW_IOMUXC_LCD_VSYNC_SELECT_INPUT(x) (*(__IO hw_iomuxc_lcd_vsync_select_input_t *) HW_IOMUXC_LCD_VSYNC_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_LCD_VSYNC_SELECT_INPUT_RD(x) (HW_IOMUXC_LCD_VSYNC_SELECT_INPUT(x).U)
#define HW_IOMUXC_LCD_VSYNC_SELECT_INPUT_WR(x, v) (HW_IOMUXC_LCD_VSYNC_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_LCD_VSYNC_SELECT_INPUT_SET(x, v) (HW_IOMUXC_LCD_VSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_VSYNC_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_LCD_VSYNC_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_LCD_VSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_VSYNC_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_LCD_VSYNC_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_LCD_VSYNC_SELECT_INPUT_WR(x, HW_IOMUXC_LCD_VSYNC_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LCD_VSYNC_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_LCD_VSYNC_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: EPDC_DATA02 Mode: ALT7 for LCD_VSYNC
 * - 01 - Selecting Pad: EPDC_PWR_STAT Mode: ALT6 for LCD_VSYNC
 * - 10 - Selecting Pad: LCD_VSYNC Mode: ALT0 for LCD_VSYNC
 */
/*@{*/
#define BP_IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY_EPDC_DATA02_ALT7 (0U) /*!< Bit field value for IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA02 Mode: ALT7 for LCD_VSYNC */
#define BV_IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY_EPDC_PWR_STAT_ALT6 (0x1U) /*!< Bit field value for IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY: Selecting Pad: EPDC_PWR_STAT Mode: ALT6 for LCD_VSYNC */
#define BV_IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY_LCD_VSYNC_ALT0 (0x2U) /*!< Bit field value for IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY: Selecting Pad: LCD_VSYNC Mode: ALT0 for LCD_VSYNC */

/*! @brief Read current value of the IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY(x) (HW_IOMUXC_LCD_VSYNC_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY) & BM_IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_LCD_VSYNC_SELECT_INPUT_WR(x, (HW_IOMUXC_LCD_VSYNC_SELECT_INPUT_RD(x) & ~BM_IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY) | BF_IOMUXC_LCD_VSYNC_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT - SAI1_RX_BCLK_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT - SAI1_RX_BCLK_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sai1_rx_bclk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai1_rx_bclk_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai1_rx_bclk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI1_RX_BCLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x69CU)

#define HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai1_rx_bclk_select_input_t *) HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI1_RX_BCLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI1_RX_BCLK_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: SAI1_RX_BCLK Mode: ALT0 for SAI1_RX_BCLK
 * - 1 - Selecting Pad: ENET1_TXC Mode: ALT2 for SAI1_RX_BCLK
 */
/*@{*/
#define BP_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_DAISY_SAI1_RX_BCLK_ALT0 (0U) /*!< Bit field value for IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_DAISY: Selecting Pad: SAI1_RX_BCLK Mode: ALT0 for SAI1_RX_BCLK */
#define BV_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_DAISY_ENET1_TXC_ALT2 (0x1U) /*!< Bit field value for IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_DAISY: Selecting Pad: ENET1_TXC Mode: ALT2 for SAI1_RX_BCLK */

/*! @brief Read current value of the IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI1_RX_BCLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT - SAI1_RX_DATA_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT - SAI1_RX_DATA_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sai1_rx_data_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai1_rx_data_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai1_rx_data_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI1_RX_DATA_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6A0U)

#define HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai1_rx_data_select_input_t *) HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI1_RX_DATA_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI1_RX_DATA_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: SAI1_RX_DATA Mode: ALT0 for SAI1_RX_DATA
 * - 1 - Selecting Pad: ENET1_TX_CLK Mode: ALT2 for SAI1_RX_DATA
 */
/*@{*/
#define BP_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI1_RX_DATA_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI1_RX_DATA_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI1_RX_DATA_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_DAISY_SAI1_RX_DATA_ALT0 (0U) /*!< Bit field value for IOMUXC_SAI1_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: SAI1_RX_DATA Mode: ALT0 for SAI1_RX_DATA */
#define BV_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_DAISY_ENET1_TX_CLK_ALT2 (0x1U) /*!< Bit field value for IOMUXC_SAI1_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: ENET1_TX_CLK Mode: ALT2 for SAI1_RX_DATA */

/*! @brief Read current value of the IOMUXC_SAI1_RX_DATA_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI1_RX_DATA_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI1_RX_DATA_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT - SAI1_RX_SYNC_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT - SAI1_RX_SYNC_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sai1_rx_sync_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai1_rx_sync_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai1_rx_sync_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI1_RX_SYNC_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6A4U)

#define HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai1_rx_sync_select_input_t *) HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI1_RX_SYNC_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI1_RX_SYNC_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: SAI1_RX_SYNC Mode: ALT0 for SAI1_RX_SYNC
 * - 1 - Selecting Pad: ENET1_TX_CTL Mode: ALT2 for SAI1_RX_SYNC
 */
/*@{*/
#define BP_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_DAISY_SAI1_RX_SYNC_ALT0 (0U) /*!< Bit field value for IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_DAISY: Selecting Pad: SAI1_RX_SYNC Mode: ALT0 for SAI1_RX_SYNC */
#define BV_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_DAISY_ENET1_TX_CTL_ALT2 (0x1U) /*!< Bit field value for IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_DAISY: Selecting Pad: ENET1_TX_CTL Mode: ALT2 for SAI1_RX_SYNC */

/*! @brief Read current value of the IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI1_RX_SYNC_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT - SAI1_TX_BCLK_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT - SAI1_TX_BCLK_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sai1_tx_bclk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai1_tx_bclk_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai1_tx_bclk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI1_TX_BCLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6A8U)

#define HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai1_tx_bclk_select_input_t *) HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI1_TX_BCLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI1_TX_BCLK_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: SAI1_TX_BCLK Mode: ALT0 for SAI1_TX_BCLK
 * - 1 - Selecting Pad: ENET1_RX_CLK Mode: ALT2 for SAI1_TX_BCLK
 */
/*@{*/
#define BP_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_DAISY_SAI1_TX_BCLK_ALT0 (0U) /*!< Bit field value for IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_DAISY: Selecting Pad: SAI1_TX_BCLK Mode: ALT0 for SAI1_TX_BCLK */
#define BV_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_DAISY_ENET1_RX_CLK_ALT2 (0x1U) /*!< Bit field value for IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RX_CLK Mode: ALT2 for SAI1_TX_BCLK */

/*! @brief Read current value of the IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI1_TX_BCLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT - SAI1_TX_SYNC_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT - SAI1_TX_SYNC_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sai1_tx_sync_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai1_tx_sync_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai1_tx_sync_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI1_TX_SYNC_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6ACU)

#define HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai1_tx_sync_select_input_t *) HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI1_TX_SYNC_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI1_TX_SYNC_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: SAI1_TX_SYNC Mode: ALT0 for SAI1_TX_SYNC
 * - 1 - Selecting Pad: ENET1_CRS Mode: ALT2 for SAI1_TX_SYNC
 */
/*@{*/
#define BP_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_DAISY_SAI1_TX_SYNC_ALT0 (0U) /*!< Bit field value for IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_DAISY: Selecting Pad: SAI1_TX_SYNC Mode: ALT0 for SAI1_TX_SYNC */
#define BV_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_DAISY_ENET1_CRS_ALT2 (0x1U) /*!< Bit field value for IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_DAISY: Selecting Pad: ENET1_CRS Mode: ALT2 for SAI1_TX_SYNC */

/*! @brief Read current value of the IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI1_TX_SYNC_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT - SAI2_RX_BCLK_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT - SAI2_RX_BCLK_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sai2_rx_bclk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai2_rx_bclk_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai2_rx_bclk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI2_RX_BCLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6B0U)

#define HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai2_rx_bclk_select_input_t *) HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI2_RX_BCLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI2_RX_BCLK_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: SD2_CMD Mode: ALT1 for SAI2_RX_BCLK
 * - 1 - Selecting Pad: SAI1_RX_BCLK Mode: ALT2 for SAI2_RX_BCLK
 */
/*@{*/
#define BP_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_DAISY_SD2_CMD_ALT1 (0U) /*!< Bit field value for IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_DAISY: Selecting Pad: SD2_CMD Mode: ALT1 for SAI2_RX_BCLK */
#define BV_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_DAISY_SAI1_RX_BCLK_ALT2 (0x1U) /*!< Bit field value for IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_DAISY: Selecting Pad: SAI1_RX_BCLK Mode: ALT2 for SAI2_RX_BCLK */

/*! @brief Read current value of the IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI2_RX_BCLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT - SAI2_RX_DATA_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT - SAI2_RX_DATA_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sai2_rx_data_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai2_rx_data_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai2_rx_data_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI2_RX_DATA_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6B4U)

#define HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai2_rx_data_select_input_t *) HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI2_RX_DATA_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI2_RX_DATA_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: SD2_DATA0 Mode: ALT1 for SAI2_RX_DATA
 * - 1 - Selecting Pad: SAI2_RX_DATA Mode: ALT0 for SAI2_RX_DATA
 */
/*@{*/
#define BP_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI2_RX_DATA_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI2_RX_DATA_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI2_RX_DATA_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_DAISY_SD2_DATA0_ALT1 (0U) /*!< Bit field value for IOMUXC_SAI2_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: SD2_DATA0 Mode: ALT1 for SAI2_RX_DATA */
#define BV_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_DAISY_SAI2_RX_DATA_ALT0 (0x1U) /*!< Bit field value for IOMUXC_SAI2_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: SAI2_RX_DATA Mode: ALT0 for SAI2_RX_DATA */

/*! @brief Read current value of the IOMUXC_SAI2_RX_DATA_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI2_RX_DATA_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI2_RX_DATA_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT - SAI2_RX_SYNC_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT - SAI2_RX_SYNC_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sai2_rx_sync_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai2_rx_sync_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai2_rx_sync_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI2_RX_SYNC_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6B8U)

#define HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai2_rx_sync_select_input_t *) HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI2_RX_SYNC_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI2_RX_SYNC_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: SD2_CLK Mode: ALT1 for SAI2_RX_SYNC
 * - 1 - Selecting Pad: SAI1_RX_SYNC Mode: ALT2 for SAI2_RX_SYNC
 */
/*@{*/
#define BP_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_DAISY_SD2_CLK_ALT1 (0U) /*!< Bit field value for IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_DAISY: Selecting Pad: SD2_CLK Mode: ALT1 for SAI2_RX_SYNC */
#define BV_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_DAISY_SAI1_RX_SYNC_ALT2 (0x1U) /*!< Bit field value for IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_DAISY: Selecting Pad: SAI1_RX_SYNC Mode: ALT2 for SAI2_RX_SYNC */

/*! @brief Read current value of the IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI2_RX_SYNC_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT - SAI2_TX_BCLK_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT - SAI2_TX_BCLK_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sai2_tx_bclk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai2_tx_bclk_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai2_tx_bclk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI2_TX_BCLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6BCU)

#define HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai2_tx_bclk_select_input_t *) HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI2_TX_BCLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI2_TX_BCLK_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: SD2_DATA1 Mode: ALT1 for SAI2_TX_BCLK
 * - 1 - Selecting Pad: SAI2_TX_BCLK Mode: ALT0 for SAI2_TX_BCLK
 */
/*@{*/
#define BP_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_DAISY_SD2_DATA1_ALT1 (0U) /*!< Bit field value for IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_DAISY: Selecting Pad: SD2_DATA1 Mode: ALT1 for SAI2_TX_BCLK */
#define BV_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_DAISY_SAI2_TX_BCLK_ALT0 (0x1U) /*!< Bit field value for IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_DAISY: Selecting Pad: SAI2_TX_BCLK Mode: ALT0 for SAI2_TX_BCLK */

/*! @brief Read current value of the IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI2_TX_BCLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT - SAI2_TX_SYNC_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT - SAI2_TX_SYNC_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sai2_tx_sync_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai2_tx_sync_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sai2_tx_sync_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI2_TX_SYNC_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6C0U)

#define HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai2_tx_sync_select_input_t *) HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI2_TX_SYNC_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI2_TX_SYNC_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: SD2_DATA2 Mode: ALT1 for SAI2_TX_SYNC
 * - 1 - Selecting Pad: SAI2_TX_SYNC Mode: ALT0 for SAI2_TX_SYNC
 */
/*@{*/
#define BP_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_DAISY_SD2_DATA2_ALT1 (0U) /*!< Bit field value for IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_DAISY: Selecting Pad: SD2_DATA2 Mode: ALT1 for SAI2_TX_SYNC */
#define BV_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_DAISY_SAI2_TX_SYNC_ALT0 (0x1U) /*!< Bit field value for IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_DAISY: Selecting Pad: SAI2_TX_SYNC Mode: ALT0 for SAI2_TX_SYNC */

/*! @brief Read current value of the IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI2_TX_SYNC_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT - SAI3_RX_BCLK_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT - SAI3_RX_BCLK_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sai3_rx_bclk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai3_rx_bclk_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_sai3_rx_bclk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI3_RX_BCLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6C4U)

#define HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai3_rx_bclk_select_input_t *) HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI3_RX_BCLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI3_RX_BCLK_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: UART2_RX_DATA Mode: ALT2 for SAI3_RX_BCLK
 * - 01 - Selecting Pad: SD1_CMD Mode: ALT1 for SAI3_RX_BCLK
 * - 10 - Selecting Pad: SD3_CMD Mode: ALT3 for SAI3_RX_BCLK
 */
/*@{*/
#define BP_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY_UART2_RX_DATA_ALT2 (0U) /*!< Bit field value for IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY: Selecting Pad: UART2_RX_DATA Mode: ALT2 for SAI3_RX_BCLK */
#define BV_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY_SD1_CMD_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY: Selecting Pad: SD1_CMD Mode: ALT1 for SAI3_RX_BCLK */
#define BV_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY_SD3_CMD_ALT3 (0x2U) /*!< Bit field value for IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY: Selecting Pad: SD3_CMD Mode: ALT3 for SAI3_RX_BCLK */

/*! @brief Read current value of the IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI3_RX_BCLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT - SAI3_RX_DATA_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT - SAI3_RX_DATA_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sai3_rx_data_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai3_rx_data_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_sai3_rx_data_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI3_RX_DATA_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6C8U)

#define HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai3_rx_data_select_input_t *) HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI3_RX_DATA_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI3_RX_DATA_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: UART2_TX_DATA Mode: ALT2 for SAI3_RX_DATA
 * - 01 - Selecting Pad: SD1_DATA0 Mode: ALT1 for SAI3_RX_DATA
 * - 10 - Selecting Pad: SD3_DATA0 Mode: ALT3 for
 */
/*@{*/
#define BP_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY_UART2_TX_DATA_ALT2 (0U) /*!< Bit field value for IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: UART2_TX_DATA Mode: ALT2 for SAI3_RX_DATA */
#define BV_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY_SD1_DATA0_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: SD1_DATA0 Mode: ALT1 for SAI3_RX_DATA */
#define BV_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY_SD3_DATA0_ALT3 (0x2U) /*!< Bit field value for IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: SD3_DATA0 Mode: ALT3 for */

/*! @brief Read current value of the IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI3_RX_DATA_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT - SAI3_RX_SYNC_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT - SAI3_RX_SYNC_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sai3_rx_sync_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai3_rx_sync_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_sai3_rx_sync_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI3_RX_SYNC_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6CCU)

#define HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai3_rx_sync_select_input_t *) HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI3_RX_SYNC_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI3_RX_SYNC_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: UART3_RX_DATA Mode: ALT2 for SAI3_RX_SYNC
 * - 01 - Selecting Pad: SD1_CLK Mode: ALT1 for SAI3_RX_SYNC
 * - 10 - Selecting Pad: SD3_CLK Mode: ALT3 for SAI3_RX_SYNC
 */
/*@{*/
#define BP_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY_UART3_RX_DATA_ALT2 (0U) /*!< Bit field value for IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY: Selecting Pad: UART3_RX_DATA Mode: ALT2 for SAI3_RX_SYNC */
#define BV_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY_SD1_CLK_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY: Selecting Pad: SD1_CLK Mode: ALT1 for SAI3_RX_SYNC */
#define BV_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY_SD3_CLK_ALT3 (0x2U) /*!< Bit field value for IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY: Selecting Pad: SD3_CLK Mode: ALT3 for SAI3_RX_SYNC */

/*! @brief Read current value of the IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI3_RX_SYNC_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT - SAI3_TX_BCLK_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT - SAI3_TX_BCLK_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sai3_tx_bclk_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai3_tx_bclk_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_sai3_tx_bclk_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI3_TX_BCLK_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6D0U)

#define HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai3_tx_bclk_select_input_t *) HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_WR(x, HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI3_TX_BCLK_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI3_TX_BCLK_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: UART3_TX_DATA Mode: ALT2 for SAI3_TX_BCLK
 * - 01 - Selecting Pad: SD1_DATA1 Mode: ALT1 for SAI3_TX_BCLK
 * - 10 - Selecting Pad: SD3_DATA1 Mode: ALT3 for SAI3_TX_BCLK
 */
/*@{*/
#define BP_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY_UART3_TX_DATA_ALT2 (0U) /*!< Bit field value for IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY: Selecting Pad: UART3_TX_DATA Mode: ALT2 for SAI3_TX_BCLK */
#define BV_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY_SD1_DATA1_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY: Selecting Pad: SD1_DATA1 Mode: ALT1 for SAI3_TX_BCLK */
#define BV_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY_SD3_DATA1_ALT3 (0x2U) /*!< Bit field value for IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY: Selecting Pad: SD3_DATA1 Mode: ALT3 for SAI3_TX_BCLK */

/*! @brief Read current value of the IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI3_TX_BCLK_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT - SAI3_TX_SYNC_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT - SAI3_TX_SYNC_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sai3_tx_sync_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sai3_tx_sync_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_sai3_tx_sync_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SAI3_TX_SYNC_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6D4U)

#define HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT(x) (*(__IO hw_iomuxc_sai3_tx_sync_select_input_t *) HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_RD(x) (HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT(x).U)
#define HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_WR(x, HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SAI3_TX_SYNC_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SAI3_TX_SYNC_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: UART3_CTS_B Mode: ALT2 for SAI3_TX_SYNC
 * - 01 - Selecting Pad: SD1_DATA2 Mode: ALT1 for SAI3_TX_SYNC
 * - 10 - Selecting Pad: SD3_DATA2 Mode: ALT3 for SAI3_TX_SYNC
 */
/*@{*/
#define BP_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY_UART3_CTS_B_ALT2 (0U) /*!< Bit field value for IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY: Selecting Pad: UART3_CTS_B Mode: ALT2 for SAI3_TX_SYNC */
#define BV_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY_SD1_DATA2_ALT1 (0x1U) /*!< Bit field value for IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY: Selecting Pad: SD1_DATA2 Mode: ALT1 for SAI3_TX_SYNC */
#define BV_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY_SD3_DATA2_ALT3 (0x2U) /*!< Bit field value for IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY: Selecting Pad: SD3_DATA2 Mode: ALT3 for SAI3_TX_SYNC */

/*! @brief Read current value of the IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY) & BM_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_WR(x, (HW_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY) | BF_IOMUXC_SAI3_TX_SYNC_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT - SDMA_EVENTS0_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT - SDMA_EVENTS0_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sdma_events0_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sdma_events0_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_sdma_events0_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SDMA_EVENTS0_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6D8U)

#define HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT(x) (*(__IO hw_iomuxc_sdma_events0_select_input_t *) HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_RD(x) (HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT(x).U)
#define HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_WR(x, HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_WR(x, HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_WR(x, HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SDMA_EVENTS0_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SDMA_EVENTS0_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: GPIO1_IO14 Mode: ALT6 for SDMA_EVENTS0
 * - 01 - Selecting Pad: I2C3_SCL Mode: ALT4 for SDMA_EVENTS0
 * - 10 - Selecting Pad: SD2_CD_B Mode: ALT6 for SDMA_EVENTS0
 */
/*@{*/
#define BP_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY_GPIO1_IO14_ALT6 (0U) /*!< Bit field value for IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO14 Mode: ALT6 for SDMA_EVENTS0 */
#define BV_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY_I2C3_SCL_ALT4 (0x1U) /*!< Bit field value for IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY: Selecting Pad: I2C3_SCL Mode: ALT4 for SDMA_EVENTS0 */
#define BV_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY_SD2_CD_B_ALT6 (0x2U) /*!< Bit field value for IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY: Selecting Pad: SD2_CD_B Mode: ALT6 for SDMA_EVENTS0 */

/*! @brief Read current value of the IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY) & BM_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_WR(x, (HW_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY) | BF_IOMUXC_SDMA_EVENTS0_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT - SDMA_EVENTS1_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT - SDMA_EVENTS1_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sdma_events1_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sdma_events1_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_sdma_events1_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SDMA_EVENTS1_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6DCU)

#define HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT(x) (*(__IO hw_iomuxc_sdma_events1_select_input_t *) HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_RD(x) (HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT(x).U)
#define HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_WR(x, HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_WR(x, HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_WR(x, HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SDMA_EVENTS1_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SDMA_EVENTS1_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: GPIO1_IO15 Mode: ALT6 for SDMA_EVENTS1
 * - 01 - Selecting Pad: I2C3_SDA Mode: ALT4 for SDMA_EVENTS1
 * - 10 - Selecting Pad: SD2_WP Mode: ALT6 for SDMA_EVENTS1
 */
/*@{*/
#define BP_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY_GPIO1_IO15_ALT6 (0U) /*!< Bit field value for IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO15 Mode: ALT6 for SDMA_EVENTS1 */
#define BV_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY_I2C3_SDA_ALT4 (0x1U) /*!< Bit field value for IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY: Selecting Pad: I2C3_SDA Mode: ALT4 for SDMA_EVENTS1 */
#define BV_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY_SD2_WP_ALT6 (0x2U) /*!< Bit field value for IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY: Selecting Pad: SD2_WP Mode: ALT6 for SDMA_EVENTS1 */

/*! @brief Read current value of the IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY) & BM_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_WR(x, (HW_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY) | BF_IOMUXC_SDMA_EVENTS1_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT - SIM1_PORT1_PD_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT - SIM1_PORT1_PD_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sim1_port1_pd_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sim1_port1_pd_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sim1_port1_pd_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SIM1_PORT1_PD_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6E0U)

#define HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT(x) (*(__IO hw_iomuxc_sim1_port1_pd_select_input_t *) HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_RD(x) (HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT(x).U)
#define HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_WR(x, HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_WR(x, HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_WR(x, HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SIM1_PORT1_PD_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SIM1_PORT1_PD_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_DATA12 Mode: ALT1 for SIM1_PORT1_PD
 * - 1 - Selecting Pad: SAI1_RX_SYNC Mode: ALT4 for SIM1_PORT1_PD
 */
/*@{*/
#define BP_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_DAISY_EPDC_DATA12_ALT1 (0U) /*!< Bit field value for IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA12 Mode: ALT1 for SIM1_PORT1_PD */
#define BV_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_DAISY_SAI1_RX_SYNC_ALT4 (0x1U) /*!< Bit field value for IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_DAISY: Selecting Pad: SAI1_RX_SYNC Mode: ALT4 for SIM1_PORT1_PD */

/*! @brief Read current value of the IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_DAISY) & BM_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_WR(x, (HW_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_DAISY) | BF_IOMUXC_SIM1_PORT1_PD_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT - SIM1_PORT1_TRXD_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT - SIM1_PORT1_TRXD_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sim1_port1_trxd_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sim1_port1_trxd_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sim1_port1_trxd_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6E4U)

#define HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT(x) (*(__IO hw_iomuxc_sim1_port1_trxd_select_input_t *) HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_RD(x) (HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT(x).U)
#define HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_WR(x, HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_WR(x, HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_WR(x, HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_DATA08 Mode: ALT1 for SIM1_PORT1_TRXD
 * - 1 - Selecting Pad: SAI1_RX_DATA Mode: ALT4 for SIM1_PORT1_TRXD
 */
/*@{*/
#define BP_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_DAISY_EPDC_DATA08_ALT1 (0U) /*!< Bit field value for IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA08 Mode: ALT1 for SIM1_PORT1_TRXD */
#define BV_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_DAISY_SAI1_RX_DATA_ALT4 (0x1U) /*!< Bit field value for IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_DAISY: Selecting Pad: SAI1_RX_DATA Mode: ALT4 for SIM1_PORT1_TRXD */

/*! @brief Read current value of the IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_DAISY) & BM_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_WR(x, (HW_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_DAISY) | BF_IOMUXC_SIM1_PORT1_TRXD_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT - SIM2_PORT1_PD_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT - SIM2_PORT1_PD_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sim2_port1_pd_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sim2_port1_pd_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sim2_port1_pd_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SIM2_PORT1_PD_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6E8U)

#define HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT(x) (*(__IO hw_iomuxc_sim2_port1_pd_select_input_t *) HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_RD(x) (HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT(x).U)
#define HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_WR(x, HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_WR(x, HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_WR(x, HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SIM2_PORT1_PD_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SIM2_PORT1_PD_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_SDCE3 Mode: ALT1 for SIM2_PORT1_PD
 * - 1 - Selecting Pad: SD2_DATA3 Mode: ALT4 for SIM2_PORT1_PD
 */
/*@{*/
#define BP_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_DAISY_EPDC_SDCE3_ALT1 (0U) /*!< Bit field value for IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_DAISY: Selecting Pad: EPDC_SDCE3 Mode: ALT1 for SIM2_PORT1_PD */
#define BV_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_DAISY_SD2_DATA3_ALT4 (0x1U) /*!< Bit field value for IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_DAISY: Selecting Pad: SD2_DATA3 Mode: ALT4 for SIM2_PORT1_PD */

/*! @brief Read current value of the IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_DAISY) & BM_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_WR(x, (HW_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_DAISY) | BF_IOMUXC_SIM2_PORT1_PD_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT - SIM2_PORT1_TRXD_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT - SIM2_PORT1_TRXD_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sim2_port1_trxd_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sim2_port1_trxd_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_sim2_port1_trxd_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6ECU)

#define HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT(x) (*(__IO hw_iomuxc_sim2_port1_trxd_select_input_t *) HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_RD(x) (HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT(x).U)
#define HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_WR(x, HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_WR(x, HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_WR(x, HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: EPDC_DATA13 Mode: ALT1 for SIM2_PORT1_TRXD
 * - 1 - Selecting Pad: SD2_CMD Mode: ALT4 for SIM2_PORT1_TRXD
 */
/*@{*/
#define BP_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_DAISY_EPDC_DATA13_ALT1 (0U) /*!< Bit field value for IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA13 Mode: ALT1 for SIM2_PORT1_TRXD */
#define BV_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_DAISY_SD2_CMD_ALT4 (0x1U) /*!< Bit field value for IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_DAISY: Selecting Pad: SD2_CMD Mode: ALT4 for SIM2_PORT1_TRXD */

/*! @brief Read current value of the IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_DAISY) & BM_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_WR(x, (HW_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_DAISY) | BF_IOMUXC_SIM2_PORT1_TRXD_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART1_RTS_B_SELECT_INPUT - UART1_RTS_B_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART1_RTS_B_SELECT_INPUT - UART1_RTS_B_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_uart1_rts_b_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart1_rts_b_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_uart1_rts_b_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART1_RTS_B_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART1_RTS_B_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6F0U)

#define HW_IOMUXC_UART1_RTS_B_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart1_rts_b_select_input_t *) HW_IOMUXC_UART1_RTS_B_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART1_RTS_B_SELECT_INPUT_RD(x) (HW_IOMUXC_UART1_RTS_B_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART1_RTS_B_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART1_RTS_B_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART1_RTS_B_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART1_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART1_RTS_B_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART1_RTS_B_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART1_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART1_RTS_B_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART1_RTS_B_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART1_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART1_RTS_B_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART1_RTS_B_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART1_RTS_B_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: SAI2_TX_SYNC Mode: ALT3 for UART1_RTS_B
 * - 01 - Selecting Pad: SAI2_TX_BCLK Mode: ALT3 for UART1_RTS_B
 * - 10 - Selecting Pad: ENET1_RGMII_RD0 Mode: ALT3 for UART1_RTS_B
 * - 11 - Selecting Pad: ENET1_RGMII_RD1 Mode: ALT3 for UART1_RTS_B
 */
/*@{*/
#define BP_IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY_SAI2_TX_SYNC_ALT3 (0U) /*!< Bit field value for IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: SAI2_TX_SYNC Mode: ALT3 for UART1_RTS_B */
#define BV_IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY_SAI2_TX_BCLK_ALT3 (0x1U) /*!< Bit field value for IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: SAI2_TX_BCLK Mode: ALT3 for UART1_RTS_B */
#define BV_IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY_ENET1_RGMII_RD0_ALT3 (0x2U) /*!< Bit field value for IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_RD0 Mode: ALT3 for UART1_RTS_B */
#define BV_IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY_ENET1_RGMII_RD1_ALT3 (0x3U) /*!< Bit field value for IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_RD1 Mode: ALT3 for UART1_RTS_B */

/*! @brief Read current value of the IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART1_RTS_B_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY) & BM_IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART1_RTS_B_SELECT_INPUT_WR(x, (HW_IOMUXC_UART1_RTS_B_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY) | BF_IOMUXC_UART1_RTS_B_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT - UART1_RX_DATA_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT - UART1_RX_DATA_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_uart1_rx_data_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart1_rx_data_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_uart1_rx_data_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART1_RX_DATA_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6F4U)

#define HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart1_rx_data_select_input_t *) HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT_RD(x) (HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART1_RX_DATA_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART1_RX_DATA_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: UART1_RX_DATA Mode: ALT0 for UART1_RX_DATA
 * - 01 - Selecting Pad: UART1_TX_DATA Mode: ALT0 for UART1_RX_DATA
 * - 10 - Selecting Pad: ENET1_RGMII_RD2 Mode: ALT3 for UART1_RX_DATA
 * - 11 - Selecting Pad: ENET1_RGMII_RD3 Mode: ALT3 for UART1_RX_DATA
 */
/*@{*/
#define BP_IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY_UART1_RX_DATA_ALT0 (0U) /*!< Bit field value for IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: UART1_RX_DATA Mode: ALT0 for UART1_RX_DATA */
#define BV_IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY_UART1_TX_DATA_ALT0 (0x1U) /*!< Bit field value for IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: UART1_TX_DATA Mode: ALT0 for UART1_RX_DATA */
#define BV_IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY_ENET1_RGMII_RD2_ALT3 (0x2U) /*!< Bit field value for IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_RD2 Mode: ALT3 for UART1_RX_DATA */
#define BV_IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY_ENET1_RGMII_RD3_ALT3 (0x3U) /*!< Bit field value for IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: ENET1_RGMII_RD3 Mode: ALT3 for UART1_RX_DATA */

/*! @brief Read current value of the IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY) & BM_IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT_WR(x, (HW_IOMUXC_UART1_RX_DATA_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY) | BF_IOMUXC_UART1_RX_DATA_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART2_RTS_B_SELECT_INPUT - UART2_RTS_B_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART2_RTS_B_SELECT_INPUT - UART2_RTS_B_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_uart2_rts_b_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart2_rts_b_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_uart2_rts_b_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART2_RTS_B_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART2_RTS_B_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6F8U)

#define HW_IOMUXC_UART2_RTS_B_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart2_rts_b_select_input_t *) HW_IOMUXC_UART2_RTS_B_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART2_RTS_B_SELECT_INPUT_RD(x) (HW_IOMUXC_UART2_RTS_B_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART2_RTS_B_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART2_RTS_B_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART2_RTS_B_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART2_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART2_RTS_B_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART2_RTS_B_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART2_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART2_RTS_B_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART2_RTS_B_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART2_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART2_RTS_B_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART2_RTS_B_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART2_RTS_B_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: LCD_HSYNC Mode: ALT4 for UART2_RTS_B
 * - 01 - Selecting Pad: LCD_VSYNC Mode: ALT4 for UART2_RTS_B
 * - 10 - Selecting Pad: SAI2_RX_DATA Mode: ALT3 for UART2_RTS_B
 * - 11 - Selecting Pad: SAI2_TX_DATA Mode: ALT3 for UART2_RTS_B
 */
/*@{*/
#define BP_IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY_LCD_HSYNC_ALT4 (0U) /*!< Bit field value for IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: LCD_HSYNC Mode: ALT4 for UART2_RTS_B */
#define BV_IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY_LCD_VSYNC_ALT4 (0x1U) /*!< Bit field value for IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: LCD_VSYNC Mode: ALT4 for UART2_RTS_B */
#define BV_IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY_SAI2_RX_DATA_ALT3 (0x2U) /*!< Bit field value for IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: SAI2_RX_DATA Mode: ALT3 for UART2_RTS_B */
#define BV_IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY_SAI2_TX_DATA_ALT3 (0x3U) /*!< Bit field value for IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: SAI2_TX_DATA Mode: ALT3 for UART2_RTS_B */

/*! @brief Read current value of the IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART2_RTS_B_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY) & BM_IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART2_RTS_B_SELECT_INPUT_WR(x, (HW_IOMUXC_UART2_RTS_B_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY) | BF_IOMUXC_UART2_RTS_B_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT - UART2_RX_DATA_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT - UART2_RX_DATA_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_uart2_rx_data_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart2_rx_data_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_uart2_rx_data_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART2_RX_DATA_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x6FCU)

#define HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart2_rx_data_select_input_t *) HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT_RD(x) (HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART2_RX_DATA_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART2_RX_DATA_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: LCD_CLK Mode: ALT4 for UART2_RX_DATA
 * - 01 - Selecting Pad: LCD_ENABLE Mode: ALT4 for UART2_RX_DATA
 * - 10 - Selecting Pad: UART2_RX_DATA Mode: ALT0 for UART2_RX_DATA
 * - 11 - Selecting Pad: UART2_TX_DATA Mode: ALT0 for UART2_RX_DATA
 */
/*@{*/
#define BP_IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY_LCD_CLK_ALT4 (0U) /*!< Bit field value for IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: LCD_CLK Mode: ALT4 for UART2_RX_DATA */
#define BV_IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY_LCD_ENABLE_ALT4 (0x1U) /*!< Bit field value for IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: LCD_ENABLE Mode: ALT4 for UART2_RX_DATA */
#define BV_IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY_UART2_RX_DATA_ALT0 (0x2U) /*!< Bit field value for IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: UART2_RX_DATA Mode: ALT0 for UART2_RX_DATA */
#define BV_IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY_UART2_TX_DATA_ALT0 (0x3U) /*!< Bit field value for IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: UART2_TX_DATA Mode: ALT0 for UART2_RX_DATA */

/*! @brief Read current value of the IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY) & BM_IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT_WR(x, (HW_IOMUXC_UART2_RX_DATA_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY) | BF_IOMUXC_UART2_RX_DATA_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART3_RTS_B_SELECT_INPUT - UART3_RTS_B_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART3_RTS_B_SELECT_INPUT - UART3_RTS_B_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_uart3_rts_b_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart3_rts_b_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_uart3_rts_b_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART3_RTS_B_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART3_RTS_B_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x700U)

#define HW_IOMUXC_UART3_RTS_B_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart3_rts_b_select_input_t *) HW_IOMUXC_UART3_RTS_B_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART3_RTS_B_SELECT_INPUT_RD(x) (HW_IOMUXC_UART3_RTS_B_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART3_RTS_B_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART3_RTS_B_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART3_RTS_B_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART3_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART3_RTS_B_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART3_RTS_B_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART3_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART3_RTS_B_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART3_RTS_B_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART3_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART3_RTS_B_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART3_RTS_B_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART3_RTS_B_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting Pad: GPIO1_IO10 Mode: ALT3 for UART3_RTS_B
 * - 001 - Selecting Pad: GPIO1_IO11 Mode: ALT3 for UART3_RTS_B
 * - 010 - Selecting Pad: UART3_RTS_B Mode: ALT0 for UART3_RTS_B
 * - 011 - Selecting Pad: UART3_CTS_B Mode: ALT0 for UART3_RTS_B
 * - 100 - Selecting Pad: SD3_DATA6 Mode: ALT3 for UART3_RTS_B
 * - 101 - Selecting Pad: SD3_DATA7 Mode: ALT3 for UART3_RTS_B
 */
/*@{*/
#define BP_IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY_GPIO1_IO10_ALT3 (0U) /*!< Bit field value for IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO10 Mode: ALT3 for UART3_RTS_B */
#define BV_IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY_GPIO1_IO11_ALT3 (0x1U) /*!< Bit field value for IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO11 Mode: ALT3 for UART3_RTS_B */
#define BV_IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY_UART3_RTS_B_ALT0 (0x2U) /*!< Bit field value for IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: UART3_RTS_B Mode: ALT0 for UART3_RTS_B */
#define BV_IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY_UART3_CTS_B_ALT0 (0x3U) /*!< Bit field value for IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: UART3_CTS_B Mode: ALT0 for UART3_RTS_B */
#define BV_IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY_SD3_DATA6_ALT3 (0x4U) /*!< Bit field value for IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: SD3_DATA6 Mode: ALT3 for UART3_RTS_B */
#define BV_IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY_SD3_DATA7_ALT3 (0x5U) /*!< Bit field value for IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: SD3_DATA7 Mode: ALT3 for UART3_RTS_B */

/*! @brief Read current value of the IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART3_RTS_B_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY) & BM_IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART3_RTS_B_SELECT_INPUT_WR(x, (HW_IOMUXC_UART3_RTS_B_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY) | BF_IOMUXC_UART3_RTS_B_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT - UART3_RX_DATA_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT - UART3_RX_DATA_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_uart3_rx_data_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart3_rx_data_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_uart3_rx_data_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART3_RX_DATA_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x704U)

#define HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart3_rx_data_select_input_t *) HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT_RD(x) (HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART3_RX_DATA_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART3_RX_DATA_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting Pad: GPIO1_IO08 Mode: ALT3 for UART3_RX_DATA
 * - 001 - Selecting Pad: GPIO1_IO09 Mode: ALT3 for UART3_RX_DATA
 * - 010 - Selecting Pad: UART3_RX_DATA Mode: ALT0 for UART3_RX_DATA
 * - 011 - Selecting Pad: UART3_TX_DATA Mode: ALT0 for UART3_RX_DATA
 * - 100 - Selecting Pad: SD3_DATA4 Mode: ALT3 for UART3_RX_DATA
 * - 101 - Selecting Pad: SD3_DATA5 Mode: ALT3 for UART3_RX_DATA
 */
/*@{*/
#define BP_IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY_GPIO1_IO08_ALT3 (0U) /*!< Bit field value for IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO08 Mode: ALT3 for UART3_RX_DATA */
#define BV_IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY_GPIO1_IO09_ALT3 (0x1U) /*!< Bit field value for IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO09 Mode: ALT3 for UART3_RX_DATA */
#define BV_IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY_UART3_RX_DATA_ALT0 (0x2U) /*!< Bit field value for IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: UART3_RX_DATA Mode: ALT0 for UART3_RX_DATA */
#define BV_IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY_UART3_TX_DATA_ALT0 (0x3U) /*!< Bit field value for IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: UART3_TX_DATA Mode: ALT0 for UART3_RX_DATA */
#define BV_IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY_SD3_DATA4_ALT3 (0x4U) /*!< Bit field value for IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: SD3_DATA4 Mode: ALT3 for UART3_RX_DATA */
#define BV_IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY_SD3_DATA5_ALT3 (0x5U) /*!< Bit field value for IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: SD3_DATA5 Mode: ALT3 for UART3_RX_DATA */

/*! @brief Read current value of the IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY) & BM_IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT_WR(x, (HW_IOMUXC_UART3_RX_DATA_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY) | BF_IOMUXC_UART3_RX_DATA_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART4_RTS_B_SELECT_INPUT - UART4_RTS_B_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART4_RTS_B_SELECT_INPUT - UART4_RTS_B_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_uart4_rts_b_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart4_rts_b_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_uart4_rts_b_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART4_RTS_B_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART4_RTS_B_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x708U)

#define HW_IOMUXC_UART4_RTS_B_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart4_rts_b_select_input_t *) HW_IOMUXC_UART4_RTS_B_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART4_RTS_B_SELECT_INPUT_RD(x) (HW_IOMUXC_UART4_RTS_B_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART4_RTS_B_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART4_RTS_B_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART4_RTS_B_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART4_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART4_RTS_B_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART4_RTS_B_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART4_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART4_RTS_B_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART4_RTS_B_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART4_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART4_RTS_B_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART4_RTS_B_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART4_RTS_B_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting Pad: I2C1_SCL Mode: ALT1 for UART4_RTS_B
 * - 001 - Selecting Pad: I2C1_SDA Mode: ALT1 for UART4_RTS_B
 * - 010 - Selecting Pad: SD2_DATA2 Mode: ALT2 for UART4_RTS_B
 * - 011 - Selecting Pad: SD2_DATA3 Mode: ALT2 for UART4_RTS_B
 * - 100 - Selecting Pad: SAI2_RX_DATA Mode: ALT2 for UART4_RTS_B
 * - 101 - Selecting Pad: SAI2_TX_DATA Mode: ALT2 for UART4_RTS_B
 */
/*@{*/
#define BP_IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY_I2C1_SCL_ALT1 (0U) /*!< Bit field value for IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: I2C1_SCL Mode: ALT1 for UART4_RTS_B */
#define BV_IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY_I2C1_SDA_ALT1 (0x1U) /*!< Bit field value for IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: I2C1_SDA Mode: ALT1 for UART4_RTS_B */
#define BV_IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY_SD2_DATA2_ALT2 (0x2U) /*!< Bit field value for IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: SD2_DATA2 Mode: ALT2 for UART4_RTS_B */
#define BV_IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY_SD2_DATA3_ALT2 (0x3U) /*!< Bit field value for IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: SD2_DATA3 Mode: ALT2 for UART4_RTS_B */
#define BV_IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY_SAI2_RX_DATA_ALT2 (0x4U) /*!< Bit field value for IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: SAI2_RX_DATA Mode: ALT2 for UART4_RTS_B */
#define BV_IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY_SAI2_TX_DATA_ALT2 (0x5U) /*!< Bit field value for IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: SAI2_TX_DATA Mode: ALT2 for UART4_RTS_B */

/*! @brief Read current value of the IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART4_RTS_B_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY) & BM_IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART4_RTS_B_SELECT_INPUT_WR(x, (HW_IOMUXC_UART4_RTS_B_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY) | BF_IOMUXC_UART4_RTS_B_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT - UART4_RX_DATA_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT - UART4_RX_DATA_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_uart4_rx_data_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart4_rx_data_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_uart4_rx_data_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART4_RX_DATA_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x70CU)

#define HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart4_rx_data_select_input_t *) HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT_RD(x) (HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART4_RX_DATA_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART4_RX_DATA_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting Pad: I2C2_SCL Mode: ALT1 for UART4_RX_DATA
 * - 001 - Selecting Pad: I2C2_SDA Mode: ALT1 for UART4_RX_DATA
 * - 010 - Selecting Pad: SD2_DATA0 Mode: ALT2 for UART4_RX_DATA
 * - 011 - Selecting Pad: SD2_DATA1 Mode: ALT2 for UART4_RX_DATA
 * - 100 - Selecting Pad: SAI2_TX_SYNC Mode: ALT2 for UART4_RX_DATA
 * - 101 - Selecting Pad: SAI2_TX_BCLK Mode: ALT2 for UART4_RX_DATA
 */
/*@{*/
#define BP_IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY_I2C2_SCL_ALT1 (0U) /*!< Bit field value for IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: I2C2_SCL Mode: ALT1 for UART4_RX_DATA */
#define BV_IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY_I2C2_SDA_ALT1 (0x1U) /*!< Bit field value for IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: I2C2_SDA Mode: ALT1 for UART4_RX_DATA */
#define BV_IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY_SD2_DATA0_ALT2 (0x2U) /*!< Bit field value for IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: SD2_DATA0 Mode: ALT2 for UART4_RX_DATA */
#define BV_IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY_SD2_DATA1_ALT2 (0x3U) /*!< Bit field value for IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: SD2_DATA1 Mode: ALT2 for UART4_RX_DATA */
#define BV_IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY_SAI2_TX_SYNC_ALT2 (0x4U) /*!< Bit field value for IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: SAI2_TX_SYNC Mode: ALT2 for UART4_RX_DATA */
#define BV_IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY_SAI2_TX_BCLK_ALT2 (0x5U) /*!< Bit field value for IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: SAI2_TX_BCLK Mode: ALT2 for UART4_RX_DATA */

/*! @brief Read current value of the IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY) & BM_IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT_WR(x, (HW_IOMUXC_UART4_RX_DATA_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY) | BF_IOMUXC_UART4_RX_DATA_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART5_RTS_B_SELECT_INPUT - UART5_RTS_B_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART5_RTS_B_SELECT_INPUT - UART5_RTS_B_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_uart5_rts_b_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart5_rts_b_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_uart5_rts_b_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART5_RTS_B_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART5_RTS_B_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x710U)

#define HW_IOMUXC_UART5_RTS_B_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart5_rts_b_select_input_t *) HW_IOMUXC_UART5_RTS_B_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART5_RTS_B_SELECT_INPUT_RD(x) (HW_IOMUXC_UART5_RTS_B_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART5_RTS_B_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART5_RTS_B_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART5_RTS_B_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART5_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART5_RTS_B_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART5_RTS_B_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART5_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART5_RTS_B_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART5_RTS_B_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART5_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART5_RTS_B_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART5_RTS_B_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART5_RTS_B_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting Pad: I2C3_SCL Mode: ALT1 for UART5_RTS_B
 * - 001 - Selecting Pad: I2C3_SDA Mode: ALT1 for UART5_RTS_B
 * - 010 - Selecting Pad: SAI1_TX_SYNC Mode: ALT2 for UART5_RTS_B
 * - 011 - Selecting Pad: SAI1_TX_DATA Mode: ALT2 for UART5_RTS_B
 * - 100 - Selecting Pad: GPIO1_IO04 Mode: ALT3 for UART5_RTS_B
 * - 101 - Selecting Pad: GPIO1_IO05 Mode: ALT3 for UART5_RTS_B
 */
/*@{*/
#define BP_IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY_I2C3_SCL_ALT1 (0U) /*!< Bit field value for IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: I2C3_SCL Mode: ALT1 for UART5_RTS_B */
#define BV_IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY_I2C3_SDA_ALT1 (0x1U) /*!< Bit field value for IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: I2C3_SDA Mode: ALT1 for UART5_RTS_B */
#define BV_IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY_SAI1_TX_SYNC_ALT2 (0x2U) /*!< Bit field value for IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: SAI1_TX_SYNC Mode: ALT2 for UART5_RTS_B */
#define BV_IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY_SAI1_TX_DATA_ALT2 (0x3U) /*!< Bit field value for IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: SAI1_TX_DATA Mode: ALT2 for UART5_RTS_B */
#define BV_IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY_GPIO1_IO04_ALT3 (0x4U) /*!< Bit field value for IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO04 Mode: ALT3 for UART5_RTS_B */
#define BV_IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY_GPIO1_IO05_ALT3 (0x5U) /*!< Bit field value for IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO05 Mode: ALT3 for UART5_RTS_B */

/*! @brief Read current value of the IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART5_RTS_B_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY) & BM_IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART5_RTS_B_SELECT_INPUT_WR(x, (HW_IOMUXC_UART5_RTS_B_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY) | BF_IOMUXC_UART5_RTS_B_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT - UART5_RX_DATA_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT - UART5_RX_DATA_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_uart5_rx_data_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart5_rx_data_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_uart5_rx_data_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART5_RX_DATA_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x714U)

#define HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart5_rx_data_select_input_t *) HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT_RD(x) (HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART5_RX_DATA_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART5_RX_DATA_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting Pad: I2C4_SCL Mode: ALT1 for UART5_RX_DATA
 * - 001 - Selecting Pad: I2C4_SDA Mode: ALT1 for UART5_RX_DATA
 * - 010 - Selecting Pad: SAI1_RX_DATA Mode: ALT2 for UART5_RX_DATA
 * - 011 - Selecting Pad: SAI1_TX_BCLK Mode: ALT2 for UART5_RX_DATA
 * - 100 - Selecting Pad: GPIO1_IO06 Mode: ALT3 for UART5_RX_DATA
 * - 101 - Selecting Pad: GPIO1_IO07 Mode: ALT3 for UART5_RX_DATA
 */
/*@{*/
#define BP_IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY_I2C4_SCL_ALT1 (0U) /*!< Bit field value for IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: I2C4_SCL Mode: ALT1 for UART5_RX_DATA */
#define BV_IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY_I2C4_SDA_ALT1 (0x1U) /*!< Bit field value for IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: I2C4_SDA Mode: ALT1 for UART5_RX_DATA */
#define BV_IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY_SAI1_RX_DATA_ALT2 (0x2U) /*!< Bit field value for IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: SAI1_RX_DATA Mode: ALT2 for UART5_RX_DATA */
#define BV_IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY_SAI1_TX_BCLK_ALT2 (0x3U) /*!< Bit field value for IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: SAI1_TX_BCLK Mode: ALT2 for UART5_RX_DATA */
#define BV_IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY_GPIO1_IO06_ALT3 (0x4U) /*!< Bit field value for IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO06 Mode: ALT3 for UART5_RX_DATA */
#define BV_IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY_GPIO1_IO07_ALT3 (0x5U) /*!< Bit field value for IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO07 Mode: ALT3 for UART5_RX_DATA */

/*! @brief Read current value of the IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY) & BM_IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT_WR(x, (HW_IOMUXC_UART5_RX_DATA_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY) | BF_IOMUXC_UART5_RX_DATA_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART6_RTS_B_SELECT_INPUT - UART6_RTS_B_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART6_RTS_B_SELECT_INPUT - UART6_RTS_B_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_uart6_rts_b_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart6_rts_b_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_uart6_rts_b_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART6_RTS_B_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART6_RTS_B_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x718U)

#define HW_IOMUXC_UART6_RTS_B_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart6_rts_b_select_input_t *) HW_IOMUXC_UART6_RTS_B_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART6_RTS_B_SELECT_INPUT_RD(x) (HW_IOMUXC_UART6_RTS_B_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART6_RTS_B_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART6_RTS_B_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART6_RTS_B_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART6_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART6_RTS_B_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART6_RTS_B_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART6_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART6_RTS_B_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART6_RTS_B_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART6_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART6_RTS_B_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART6_RTS_B_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART6_RTS_B_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting Pad: EPDC_DATA10 Mode: ALT3 for UART6_RTS_B
 * - 001 - Selecting Pad: EPDC_DATA11 Mode: ALT3 for UART6_RTS_B
 * - 010 - Selecting Pad: ECSPI1_MISO Mode: ALT1 for UART6_RTS_B
 * - 011 - Selecting Pad: ECSPI1_SS0 Mode: ALT1 for UART6_RTS_B
 * - 100 - Selecting Pad: SD1_RESET_B Mode: ALT2 for UART6_RTS_B
 * - 101 - Selecting Pad: SD1_CLK Mode: ALT2 for UART6_RTS_B
 */
/*@{*/
#define BP_IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY_EPDC_DATA10_ALT3 (0U) /*!< Bit field value for IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA10 Mode: ALT3 for UART6_RTS_B */
#define BV_IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY_EPDC_DATA11_ALT3 (0x1U) /*!< Bit field value for IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA11 Mode: ALT3 for UART6_RTS_B */
#define BV_IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY_ECSPI1_MISO_ALT1 (0x2U) /*!< Bit field value for IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: ECSPI1_MISO Mode: ALT1 for UART6_RTS_B */
#define BV_IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY_ECSPI1_SS0_ALT1 (0x3U) /*!< Bit field value for IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: ECSPI1_SS0 Mode: ALT1 for UART6_RTS_B */
#define BV_IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY_SD1_RESET_B_ALT2 (0x4U) /*!< Bit field value for IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: SD1_RESET_B Mode: ALT2 for UART6_RTS_B */
#define BV_IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY_SD1_CLK_ALT2 (0x5U) /*!< Bit field value for IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: SD1_CLK Mode: ALT2 for UART6_RTS_B */

/*! @brief Read current value of the IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART6_RTS_B_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY) & BM_IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART6_RTS_B_SELECT_INPUT_WR(x, (HW_IOMUXC_UART6_RTS_B_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY) | BF_IOMUXC_UART6_RTS_B_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT - UART6_RX_DATA_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT - UART6_RX_DATA_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_uart6_rx_data_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart6_rx_data_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_uart6_rx_data_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART6_RX_DATA_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x71CU)

#define HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart6_rx_data_select_input_t *) HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT_RD(x) (HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART6_RX_DATA_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART6_RX_DATA_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting Pad: EPDC_DATA08 Mode: ALT3 for UART6_RX_DATA
 * - 001 - Selecting Pad: EPDC_DATA09 Mode: ALT3 for UART6_RX_DATA
 * - 010 - Selecting Pad: ECSPI1_SCLK Mode: ALT1 for UART6_RX_DATA
 * - 011 - Selecting Pad: ECSPI1_MOSI Mode: ALT1 for UART6_RX_DATA
 * - 100 - Selecting Pad: SD1_CD_B Mode: ALT2 for UART6_RX_DATA
 * - 101 - Selecting Pad: SD1_WP Mode: ALT2 for UART6_RX_DATA
 */
/*@{*/
#define BP_IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY_EPDC_DATA08_ALT3 (0U) /*!< Bit field value for IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA08 Mode: ALT3 for UART6_RX_DATA */
#define BV_IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY_EPDC_DATA09_ALT3 (0x1U) /*!< Bit field value for IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA09 Mode: ALT3 for UART6_RX_DATA */
#define BV_IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY_ECSPI1_SCLK_ALT1 (0x2U) /*!< Bit field value for IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: ECSPI1_SCLK Mode: ALT1 for UART6_RX_DATA */
#define BV_IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY_ECSPI1_MOSI_ALT1 (0x3U) /*!< Bit field value for IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: ECSPI1_MOSI Mode: ALT1 for UART6_RX_DATA */
#define BV_IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY_SD1_CD_B_ALT2 (0x4U) /*!< Bit field value for IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: SD1_CD_B Mode: ALT2 for UART6_RX_DATA */
#define BV_IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY_SD1_WP_ALT2 (0x5U) /*!< Bit field value for IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: SD1_WP Mode: ALT2 for UART6_RX_DATA */

/*! @brief Read current value of the IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY) & BM_IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT_WR(x, (HW_IOMUXC_UART6_RX_DATA_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY) | BF_IOMUXC_UART6_RX_DATA_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART7_RTS_B_SELECT_INPUT - UART7_RTS_B_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART7_RTS_B_SELECT_INPUT - UART7_RTS_B_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_uart7_rts_b_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart7_rts_b_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_uart7_rts_b_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART7_RTS_B_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART7_RTS_B_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x720U)

#define HW_IOMUXC_UART7_RTS_B_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart7_rts_b_select_input_t *) HW_IOMUXC_UART7_RTS_B_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART7_RTS_B_SELECT_INPUT_RD(x) (HW_IOMUXC_UART7_RTS_B_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART7_RTS_B_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART7_RTS_B_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART7_RTS_B_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART7_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART7_RTS_B_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART7_RTS_B_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART7_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART7_RTS_B_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART7_RTS_B_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART7_RTS_B_SELECT_INPUT_WR(x, HW_IOMUXC_UART7_RTS_B_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART7_RTS_B_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART7_RTS_B_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting Pad: EPDC_DATA14 Mode: ALT3 for UART7_RTS_B
 * - 001 - Selecting Pad: EPDC_DATA15 Mode: ALT3 for UART7_RTS_B
 * - 010 - Selecting Pad: ECSPI2_MISO Mode: ALT1 for UART7_RTS_B
 * - 011 - Selecting Pad: ECSPI2_SS0 Mode: ALT1 for UART7_RTS_B
 * - 100 - Selecting Pad: SD1_DATA2 Mode: ALT2 for UART7_RTS_B
 * - 101 - Selecting Pad: SD1_DATA3 Mode: ALT2 for UART7_RTS_B
 */
/*@{*/
#define BP_IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY_EPDC_DATA14_ALT3 (0U) /*!< Bit field value for IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA14 Mode: ALT3 for UART7_RTS_B */
#define BV_IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY_EPDC_DATA15_ALT3 (0x1U) /*!< Bit field value for IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA15 Mode: ALT3 for UART7_RTS_B */
#define BV_IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY_ECSPI2_MISO_ALT1 (0x2U) /*!< Bit field value for IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: ECSPI2_MISO Mode: ALT1 for UART7_RTS_B */
#define BV_IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY_ECSPI2_SS0_ALT1 (0x3U) /*!< Bit field value for IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: ECSPI2_SS0 Mode: ALT1 for UART7_RTS_B */
#define BV_IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY_SD1_DATA2_ALT2 (0x4U) /*!< Bit field value for IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: SD1_DATA2 Mode: ALT2 for UART7_RTS_B */
#define BV_IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY_SD1_DATA3_ALT2 (0x5U) /*!< Bit field value for IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY: Selecting Pad: SD1_DATA3 Mode: ALT2 for UART7_RTS_B */

/*! @brief Read current value of the IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART7_RTS_B_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY) & BM_IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART7_RTS_B_SELECT_INPUT_WR(x, (HW_IOMUXC_UART7_RTS_B_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY) | BF_IOMUXC_UART7_RTS_B_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT - UART7_RX_DATA_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT - UART7_RX_DATA_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_uart7_rx_data_select_input
{
    uint32_t U;
    struct _hw_iomuxc_uart7_rx_data_select_input_bitfields
    {
        uint32_t DAISY : 3;            /*!< [2:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_iomuxc_uart7_rx_data_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_UART7_RX_DATA_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x724U)

#define HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT(x) (*(__IO hw_iomuxc_uart7_rx_data_select_input_t *) HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT_RD(x) (HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT(x).U)
#define HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT_WR(x, v) (HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT_SET(x, v) (HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT_WR(x, HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_UART7_RX_DATA_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_UART7_RX_DATA_SELECT_INPUT, field DAISY[2:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 000 - Selecting Pad: EPDC_DATA12 Mode: ALT3 for UART7_RX_DATA
 * - 001 - Selecting Pad: EPDC_DATA13 Mode: ALT3 for UART7_RX_DATA
 * - 010 - Selecting Pad: ECSPI2_SCLK Mode: ALT1 for UART7_RX_DATA
 * - 011 - Selecting Pad: ECSPI2_MOSI Mode: ALT1 for UART7_RX_DATA
 * - 100 - Selecting Pad: SD1_DATA0 Mode: ALT2 for UART7_RX_DATA
 * - 101 - Selecting Pad: SD1_DATA1 Mode: ALT2 for UART7_RX_DATA
 */
/*@{*/
#define BP_IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY (0x00000007U) /*!< Bit mask for IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY (3U) /*!< Bit field size in bits for IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY_EPDC_DATA12_ALT3 (0U) /*!< Bit field value for IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA12 Mode: ALT3 for UART7_RX_DATA */
#define BV_IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY_EPDC_DATA13_ALT3 (0x1U) /*!< Bit field value for IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: EPDC_DATA13 Mode: ALT3 for UART7_RX_DATA */
#define BV_IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY_ECSPI2_SCLK_ALT1 (0x2U) /*!< Bit field value for IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: ECSPI2_SCLK Mode: ALT1 for UART7_RX_DATA */
#define BV_IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY_ECSPI2_MOSI_ALT1 (0x3U) /*!< Bit field value for IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: ECSPI2_MOSI Mode: ALT1 for UART7_RX_DATA */
#define BV_IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY_SD1_DATA0_ALT2 (0x4U) /*!< Bit field value for IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: SD1_DATA0 Mode: ALT2 for UART7_RX_DATA */
#define BV_IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY_SD1_DATA1_ALT2 (0x5U) /*!< Bit field value for IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY: Selecting Pad: SD1_DATA1 Mode: ALT2 for UART7_RX_DATA */

/*! @brief Read current value of the IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY(x) (HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY) & BM_IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT_WR(x, (HW_IOMUXC_UART7_RX_DATA_SELECT_INPUT_RD(x) & ~BM_IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY) | BF_IOMUXC_UART7_RX_DATA_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT - USB_OTG2_OC_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT - USB_OTG2_OC_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_usb_otg2_oc_select_input
{
    uint32_t U;
    struct _hw_iomuxc_usb_otg2_oc_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_usb_otg2_oc_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_USB_OTG2_OC_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x728U)

#define HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT(x) (*(__IO hw_iomuxc_usb_otg2_oc_select_input_t *) HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT_RD(x) (HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT(x).U)
#define HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT_WR(x, v) (HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT_SET(x, v) (HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT_WR(x, HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT_WR(x, HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT_WR(x, HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_USB_OTG2_OC_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_USB_OTG2_OC_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: UART3_RTS_B Mode: ALT1 for USB_OTG2_OC
 * - 1 - Selecting Pad: GPIO1_IO06 Mode: ALT1 for USB_OTG2_OC
 */
/*@{*/
#define BP_IOMUXC_USB_OTG2_OC_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_USB_OTG2_OC_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_USB_OTG2_OC_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_USB_OTG2_OC_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_USB_OTG2_OC_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_USB_OTG2_OC_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_USB_OTG2_OC_SELECT_INPUT_DAISY_UART3_RTS_B_ALT1 (0U) /*!< Bit field value for IOMUXC_USB_OTG2_OC_SELECT_INPUT_DAISY: Selecting Pad: UART3_RTS_B Mode: ALT1 for USB_OTG2_OC */
#define BV_IOMUXC_USB_OTG2_OC_SELECT_INPUT_DAISY_GPIO1_IO06_ALT1 (0x1U) /*!< Bit field value for IOMUXC_USB_OTG2_OC_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO06 Mode: ALT1 for USB_OTG2_OC */

/*! @brief Read current value of the IOMUXC_USB_OTG2_OC_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_USB_OTG2_OC_SELECT_INPUT_DAISY(x) (HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_USB_OTG2_OC_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_USB_OTG2_OC_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_USB_OTG2_OC_SELECT_INPUT_DAISY) & BM_IOMUXC_USB_OTG2_OC_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_USB_OTG2_OC_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT_WR(x, (HW_IOMUXC_USB_OTG2_OC_SELECT_INPUT_RD(x) & ~BM_IOMUXC_USB_OTG2_OC_SELECT_INPUT_DAISY) | BF_IOMUXC_USB_OTG2_OC_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT - USB_OTG1_OC_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT - USB_OTG1_OC_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_usb_otg1_oc_select_input
{
    uint32_t U;
    struct _hw_iomuxc_usb_otg1_oc_select_input_bitfields
    {
        uint32_t DAISY : 1;            /*!< [0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_iomuxc_usb_otg1_oc_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_USB_OTG1_OC_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x72CU)

#define HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT(x) (*(__IO hw_iomuxc_usb_otg1_oc_select_input_t *) HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT_RD(x) (HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT(x).U)
#define HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT_WR(x, v) (HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT_SET(x, v) (HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT_WR(x, HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT_WR(x, HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT_WR(x, HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_USB_OTG1_OC_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_USB_OTG1_OC_SELECT_INPUT, field DAISY[0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 0 - Selecting Pad: UART3_RX_DATA Mode: ALT1 for USB_OTG1_OC
 * - 1 - Selecting Pad: GPIO1_IO04 Mode: ALT1 for USB_OTG1_OC
 */
/*@{*/
#define BP_IOMUXC_USB_OTG1_OC_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_USB_OTG1_OC_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_USB_OTG1_OC_SELECT_INPUT_DAISY (0x00000001U) /*!< Bit mask for IOMUXC_USB_OTG1_OC_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_USB_OTG1_OC_SELECT_INPUT_DAISY (1U) /*!< Bit field size in bits for IOMUXC_USB_OTG1_OC_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_USB_OTG1_OC_SELECT_INPUT_DAISY_UART3_RX_DATA_ALT1 (0U) /*!< Bit field value for IOMUXC_USB_OTG1_OC_SELECT_INPUT_DAISY: Selecting Pad: UART3_RX_DATA Mode: ALT1 for USB_OTG1_OC */
#define BV_IOMUXC_USB_OTG1_OC_SELECT_INPUT_DAISY_GPIO1_IO04_ALT1 (0x1U) /*!< Bit field value for IOMUXC_USB_OTG1_OC_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO04 Mode: ALT1 for USB_OTG1_OC */

/*! @brief Read current value of the IOMUXC_USB_OTG1_OC_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_USB_OTG1_OC_SELECT_INPUT_DAISY(x) (HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_USB_OTG1_OC_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_USB_OTG1_OC_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_USB_OTG1_OC_SELECT_INPUT_DAISY) & BM_IOMUXC_USB_OTG1_OC_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_USB_OTG1_OC_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT_WR(x, (HW_IOMUXC_USB_OTG1_OC_SELECT_INPUT_RD(x) & ~BM_IOMUXC_USB_OTG1_OC_SELECT_INPUT_DAISY) | BF_IOMUXC_USB_OTG1_OC_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT - USB_OTG2_ID_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT - USB_OTG2_ID_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_usb_otg2_id_select_input
{
    uint32_t U;
    struct _hw_iomuxc_usb_otg2_id_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_usb_otg2_id_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_USB_OTG2_ID_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x730U)

#define HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT(x) (*(__IO hw_iomuxc_usb_otg2_id_select_input_t *) HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT_RD(x) (HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT(x).U)
#define HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT_WR(x, v) (HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT_SET(x, v) (HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT_WR(x, HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT_WR(x, HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT_WR(x, HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_USB_OTG2_ID_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_USB_OTG2_ID_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: GPIO1_IO13 Mode: ALT7 for USB_OTG2_ID
 * - 01 - Selecting Pad: I2C4_SDA Mode: ALT4 for USB_OTG2_ID
 * - 10 - Selecting Pad: SD2_RESET_B Mode: ALT4 for USB_OTG2_ID
 * - 11 - Selecting Pad: GPIO1_IO03 Mode: ALT7 for USB_OTG2_ID
 */
/*@{*/
#define BP_IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY_GPIO1_IO13_ALT7 (0U) /*!< Bit field value for IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO13 Mode: ALT7 for USB_OTG2_ID */
#define BV_IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY_I2C4_SDA_ALT4 (0x1U) /*!< Bit field value for IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY: Selecting Pad: I2C4_SDA Mode: ALT4 for USB_OTG2_ID */
#define BV_IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY_SD2_RESET_B_ALT4 (0x2U) /*!< Bit field value for IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY: Selecting Pad: SD2_RESET_B Mode: ALT4 for USB_OTG2_ID */
#define BV_IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY_GPIO1_IO03_ALT7 (0x3U) /*!< Bit field value for IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO03 Mode: ALT7 for USB_OTG2_ID */

/*! @brief Read current value of the IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY(x) (HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY) & BM_IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT_WR(x, (HW_IOMUXC_USB_OTG2_ID_SELECT_INPUT_RD(x) & ~BM_IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY) | BF_IOMUXC_USB_OTG2_ID_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT - USB_OTG1_ID_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT - USB_OTG1_ID_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_usb_otg1_id_select_input
{
    uint32_t U;
    struct _hw_iomuxc_usb_otg1_id_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_usb_otg1_id_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_USB_OTG1_ID_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x734U)

#define HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT(x) (*(__IO hw_iomuxc_usb_otg1_id_select_input_t *) HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT_RD(x) (HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT(x).U)
#define HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT_WR(x, v) (HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT_SET(x, v) (HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT_WR(x, HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT_WR(x, HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT_WR(x, HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_USB_OTG1_ID_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_USB_OTG1_ID_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: GPIO1_IO12 Mode: ALT7 for USB_OTG1_ID
 * - 01 - Selecting Pad: I2C4_SCL Mode: ALT4 for USB_OTG1_ID
 * - 10 - Selecting Pad: SD2_WP Mode: ALT4 for USB_OTG1_ID
 * - 11 - Selecting Pad: GPIO1_IO02 Mode: ALT7 for USB_OTG1_ID
 */
/*@{*/
#define BP_IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY_GPIO1_IO12_ALT7 (0U) /*!< Bit field value for IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO12 Mode: ALT7 for USB_OTG1_ID */
#define BV_IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY_I2C4_SCL_ALT4 (0x1U) /*!< Bit field value for IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY: Selecting Pad: I2C4_SCL Mode: ALT4 for USB_OTG1_ID */
#define BV_IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY_SD2_WP_ALT4 (0x2U) /*!< Bit field value for IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY: Selecting Pad: SD2_WP Mode: ALT4 for USB_OTG1_ID */
#define BV_IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY_GPIO1_IO02_ALT7 (0x3U) /*!< Bit field value for IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO02 Mode: ALT7 for USB_OTG1_ID */

/*! @brief Read current value of the IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY(x) (HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY) & BM_IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT_WR(x, (HW_IOMUXC_USB_OTG1_ID_SELECT_INPUT_RD(x) & ~BM_IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY) | BF_IOMUXC_USB_OTG1_ID_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SD3_CD_B_SELECT_INPUT - SD3_CD_B_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SD3_CD_B_SELECT_INPUT - SD3_CD_B_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sd3_cd_b_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sd3_cd_b_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_sd3_cd_b_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SD3_CD_B_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SD3_CD_B_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x738U)

#define HW_IOMUXC_SD3_CD_B_SELECT_INPUT(x) (*(__IO hw_iomuxc_sd3_cd_b_select_input_t *) HW_IOMUXC_SD3_CD_B_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SD3_CD_B_SELECT_INPUT_RD(x) (HW_IOMUXC_SD3_CD_B_SELECT_INPUT(x).U)
#define HW_IOMUXC_SD3_CD_B_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SD3_CD_B_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SD3_CD_B_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SD3_CD_B_SELECT_INPUT_WR(x, HW_IOMUXC_SD3_CD_B_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SD3_CD_B_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SD3_CD_B_SELECT_INPUT_WR(x, HW_IOMUXC_SD3_CD_B_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SD3_CD_B_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SD3_CD_B_SELECT_INPUT_WR(x, HW_IOMUXC_SD3_CD_B_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SD3_CD_B_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SD3_CD_B_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: GPIO1_IO14 Mode: ALT1 for SD3_CD_B
 * - 01 - Selecting Pad: I2C2_SCL Mode: ALT6 for SD3_CD_B
 * - 10 - Selecting Pad: SD3_DATA7 Mode: ALT2 for SD3_CD_B
 */
/*@{*/
#define BP_IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY_GPIO1_IO14_ALT1 (0U) /*!< Bit field value for IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO14 Mode: ALT1 for SD3_CD_B */
#define BV_IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY_I2C2_SCL_ALT6 (0x1U) /*!< Bit field value for IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY: Selecting Pad: I2C2_SCL Mode: ALT6 for SD3_CD_B */
#define BV_IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY_SD3_DATA7_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY: Selecting Pad: SD3_DATA7 Mode: ALT2 for SD3_CD_B */

/*! @brief Read current value of the IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SD3_CD_B_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY) & BM_IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SD3_CD_B_SELECT_INPUT_WR(x, (HW_IOMUXC_SD3_CD_B_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY) | BF_IOMUXC_SD3_CD_B_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_SD3_WP_SELECT_INPUT - SD3_WP_SELECT_INPUT DAISY Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_SD3_WP_SELECT_INPUT - SD3_WP_SELECT_INPUT DAISY Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * DAISY Register
 */
typedef union _hw_iomuxc_sd3_wp_select_input
{
    uint32_t U;
    struct _hw_iomuxc_sd3_wp_select_input_bitfields
    {
        uint32_t DAISY : 2;            /*!< [1:0] Input Select (DAISY) Field */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_sd3_wp_select_input_t;

/*!
 * @name Constants and macros for entire IOMUXC_SD3_WP_SELECT_INPUT register
 */
/*@{*/
#define HW_IOMUXC_SD3_WP_SELECT_INPUT_ADDR(x) ((uintptr_t)(x) + 0x73CU)

#define HW_IOMUXC_SD3_WP_SELECT_INPUT(x) (*(__IO hw_iomuxc_sd3_wp_select_input_t *) HW_IOMUXC_SD3_WP_SELECT_INPUT_ADDR(x))
#define HW_IOMUXC_SD3_WP_SELECT_INPUT_RD(x) (HW_IOMUXC_SD3_WP_SELECT_INPUT(x).U)
#define HW_IOMUXC_SD3_WP_SELECT_INPUT_WR(x, v) (HW_IOMUXC_SD3_WP_SELECT_INPUT(x).U = (v))
#define HW_IOMUXC_SD3_WP_SELECT_INPUT_SET(x, v) (HW_IOMUXC_SD3_WP_SELECT_INPUT_WR(x, HW_IOMUXC_SD3_WP_SELECT_INPUT_RD(x) |  (v)))
#define HW_IOMUXC_SD3_WP_SELECT_INPUT_CLR(x, v) (HW_IOMUXC_SD3_WP_SELECT_INPUT_WR(x, HW_IOMUXC_SD3_WP_SELECT_INPUT_RD(x) & ~(v)))
#define HW_IOMUXC_SD3_WP_SELECT_INPUT_TOG(x, v) (HW_IOMUXC_SD3_WP_SELECT_INPUT_WR(x, HW_IOMUXC_SD3_WP_SELECT_INPUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_SD3_WP_SELECT_INPUT bitfields
 */

/*!
 * @name Register IOMUXC_SD3_WP_SELECT_INPUT, field DAISY[1:0] (RW)
 *
 * Selecting Pads Involved in Daisy Chain.
 *
 * Values:
 * - 00 - Selecting Pad: GPIO1_IO15 Mode: ALT1 for SD3_WP
 * - 01 - Selecting Pad: I2C2_SDA Mode: ALT6 for SD3_WP
 * - 10 - Selecting Pad: SD3_DATA6 Mode: ALT2 for SD3_WP
 */
/*@{*/
#define BP_IOMUXC_SD3_WP_SELECT_INPUT_DAISY (0U) /*!< Bit position for IOMUXC_SD3_WP_SELECT_INPUT_DAISY. */
#define BM_IOMUXC_SD3_WP_SELECT_INPUT_DAISY (0x00000003U) /*!< Bit mask for IOMUXC_SD3_WP_SELECT_INPUT_DAISY. */
#define BS_IOMUXC_SD3_WP_SELECT_INPUT_DAISY (2U) /*!< Bit field size in bits for IOMUXC_SD3_WP_SELECT_INPUT_DAISY. */

#define BV_IOMUXC_SD3_WP_SELECT_INPUT_DAISY_GPIO1_IO15_ALT1 (0U) /*!< Bit field value for IOMUXC_SD3_WP_SELECT_INPUT_DAISY: Selecting Pad: GPIO1_IO15 Mode: ALT1 for SD3_WP */
#define BV_IOMUXC_SD3_WP_SELECT_INPUT_DAISY_I2C2_SDA_ALT6 (0x1U) /*!< Bit field value for IOMUXC_SD3_WP_SELECT_INPUT_DAISY: Selecting Pad: I2C2_SDA Mode: ALT6 for SD3_WP */
#define BV_IOMUXC_SD3_WP_SELECT_INPUT_DAISY_SD3_DATA6_ALT2 (0x2U) /*!< Bit field value for IOMUXC_SD3_WP_SELECT_INPUT_DAISY: Selecting Pad: SD3_DATA6 Mode: ALT2 for SD3_WP */

/*! @brief Read current value of the IOMUXC_SD3_WP_SELECT_INPUT_DAISY field. */
#define BR_IOMUXC_SD3_WP_SELECT_INPUT_DAISY(x) (HW_IOMUXC_SD3_WP_SELECT_INPUT(x).B.DAISY)

/*! @brief Format value for bitfield IOMUXC_SD3_WP_SELECT_INPUT_DAISY. */
#define BF_IOMUXC_SD3_WP_SELECT_INPUT_DAISY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_SD3_WP_SELECT_INPUT_DAISY) & BM_IOMUXC_SD3_WP_SELECT_INPUT_DAISY)

/*! @brief Set the DAISY field to a new value. */
#define BW_IOMUXC_SD3_WP_SELECT_INPUT_DAISY(x, v) (HW_IOMUXC_SD3_WP_SELECT_INPUT_WR(x, (HW_IOMUXC_SD3_WP_SELECT_INPUT_RD(x) & ~BM_IOMUXC_SD3_WP_SELECT_INPUT_DAISY) | BF_IOMUXC_SD3_WP_SELECT_INPUT_DAISY(v)))
/*@}*/

/*******************************************************************************
 * hw_iomuxc_t - module struct
 ******************************************************************************/
/*!
 * @brief All IOMUXC module registers.
 */
#pragma pack(1)
typedef struct _hw_iomuxc
{
    uint8_t _reserved0[20];
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io08_t SW_MUX_CTL_PAD_GPIO1_IO08; /*!< [0x14] SW_MUX_CTL_PAD_GPIO1_IO08 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io09_t SW_MUX_CTL_PAD_GPIO1_IO09; /*!< [0x18] SW_MUX_CTL_PAD_GPIO1_IO09 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io10_t SW_MUX_CTL_PAD_GPIO1_IO10; /*!< [0x1C] SW_MUX_CTL_PAD_GPIO1_IO10 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io11_t SW_MUX_CTL_PAD_GPIO1_IO11; /*!< [0x20] SW_MUX_CTL_PAD_GPIO1_IO11 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io12_t SW_MUX_CTL_PAD_GPIO1_IO12; /*!< [0x24] SW_MUX_CTL_PAD_GPIO1_IO12 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io13_t SW_MUX_CTL_PAD_GPIO1_IO13; /*!< [0x28] SW_MUX_CTL_PAD_GPIO1_IO13 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io14_t SW_MUX_CTL_PAD_GPIO1_IO14; /*!< [0x2C] SW_MUX_CTL_PAD_GPIO1_IO14 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_gpio1_io15_t SW_MUX_CTL_PAD_GPIO1_IO15; /*!< [0x30] SW_MUX_CTL_PAD_GPIO1_IO15 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_data00_t SW_MUX_CTL_PAD_EPDC_DATA00; /*!< [0x34] SW_MUX_CTL_PAD_EPDC_DATA00 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_data01_t SW_MUX_CTL_PAD_EPDC_DATA01; /*!< [0x38] SW_MUX_CTL_PAD_EPDC_DATA01 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_data02_t SW_MUX_CTL_PAD_EPDC_DATA02; /*!< [0x3C] SW_MUX_CTL_PAD_EPDC_DATA02 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_data03_t SW_MUX_CTL_PAD_EPDC_DATA03; /*!< [0x40] SW_MUX_CTL_PAD_EPDC_DATA03 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_data04_t SW_MUX_CTL_PAD_EPDC_DATA04; /*!< [0x44] SW_MUX_CTL_PAD_EPDC_DATA04 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_data05_t SW_MUX_CTL_PAD_EPDC_DATA05; /*!< [0x48] SW_MUX_CTL_PAD_EPDC_DATA05 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_data06_t SW_MUX_CTL_PAD_EPDC_DATA06; /*!< [0x4C] SW_MUX_CTL_PAD_EPDC_DATA06 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_data07_t SW_MUX_CTL_PAD_EPDC_DATA07; /*!< [0x50] SW_MUX_CTL_PAD_EPDC_DATA07 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_data08_t SW_MUX_CTL_PAD_EPDC_DATA08; /*!< [0x54] SW_MUX_CTL_PAD_EPDC_DATA08 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_data09_t SW_MUX_CTL_PAD_EPDC_DATA09; /*!< [0x58] SW_MUX_CTL_PAD_EPDC_DATA09 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_data10_t SW_MUX_CTL_PAD_EPDC_DATA10; /*!< [0x5C] SW_MUX_CTL_PAD_EPDC_DATA10 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_data11_t SW_MUX_CTL_PAD_EPDC_DATA11; /*!< [0x60] SW_MUX_CTL_PAD_EPDC_DATA11 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_data12_t SW_MUX_CTL_PAD_EPDC_DATA12; /*!< [0x64] SW_MUX_CTL_PAD_EPDC_DATA12 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_data13_t SW_MUX_CTL_PAD_EPDC_DATA13; /*!< [0x68] SW_MUX_CTL_PAD_EPDC_DATA13 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_data14_t SW_MUX_CTL_PAD_EPDC_DATA14; /*!< [0x6C] SW_MUX_CTL_PAD_EPDC_DATA14 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_data15_t SW_MUX_CTL_PAD_EPDC_DATA15; /*!< [0x70] SW_MUX_CTL_PAD_EPDC_DATA15 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_sdclk_t SW_MUX_CTL_PAD_EPDC_SDCLK; /*!< [0x74] SW_MUX_CTL_PAD_EPDC_SDCLK SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_sdle_t SW_MUX_CTL_PAD_EPDC_SDLE; /*!< [0x78] SW_MUX_CTL_PAD_EPDC_SDLE SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_sdoe_t SW_MUX_CTL_PAD_EPDC_SDOE; /*!< [0x7C] SW_MUX_CTL_PAD_EPDC_SDOE SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_sdshr_t SW_MUX_CTL_PAD_EPDC_SDSHR; /*!< [0x80] SW_MUX_CTL_PAD_EPDC_SDSHR SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_sdce0_t SW_MUX_CTL_PAD_EPDC_SDCE0; /*!< [0x84] SW_MUX_CTL_PAD_EPDC_SDCE0 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_sdce1_t SW_MUX_CTL_PAD_EPDC_SDCE1; /*!< [0x88] SW_MUX_CTL_PAD_EPDC_SDCE1 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_sdce2_t SW_MUX_CTL_PAD_EPDC_SDCE2; /*!< [0x8C] SW_MUX_CTL_PAD_EPDC_SDCE2 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_sdce3_t SW_MUX_CTL_PAD_EPDC_SDCE3; /*!< [0x90] SW_MUX_CTL_PAD_EPDC_SDCE3 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_gdclk_t SW_MUX_CTL_PAD_EPDC_GDCLK; /*!< [0x94] SW_MUX_CTL_PAD_EPDC_GDCLK SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_gdoe_t SW_MUX_CTL_PAD_EPDC_GDOE; /*!< [0x98] SW_MUX_CTL_PAD_EPDC_GDOE SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_gdrl_t SW_MUX_CTL_PAD_EPDC_GDRL; /*!< [0x9C] SW_MUX_CTL_PAD_EPDC_GDRL SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_gdsp_t SW_MUX_CTL_PAD_EPDC_GDSP; /*!< [0xA0] SW_MUX_CTL_PAD_EPDC_GDSP SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_bdr0_t SW_MUX_CTL_PAD_EPDC_BDR0; /*!< [0xA4] SW_MUX_CTL_PAD_EPDC_BDR0 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_bdr1_t SW_MUX_CTL_PAD_EPDC_BDR1; /*!< [0xA8] SW_MUX_CTL_PAD_EPDC_BDR1 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_pwr_com_t SW_MUX_CTL_PAD_EPDC_PWR_COM; /*!< [0xAC] SW_MUX_CTL_PAD_EPDC_PWR_COM SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_epdc_pwr_stat_t SW_MUX_CTL_PAD_EPDC_PWR_STAT; /*!< [0xB0] SW_MUX_CTL_PAD_EPDC_PWR_STAT SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_clk_t SW_MUX_CTL_PAD_LCD_CLK; /*!< [0xB4] SW_MUX_CTL_PAD_LCD_CLK SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_enable_t SW_MUX_CTL_PAD_LCD_ENABLE; /*!< [0xB8] SW_MUX_CTL_PAD_LCD_ENABLE SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_hsync_t SW_MUX_CTL_PAD_LCD_HSYNC; /*!< [0xBC] SW_MUX_CTL_PAD_LCD_HSYNC SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_vsync_t SW_MUX_CTL_PAD_LCD_VSYNC; /*!< [0xC0] SW_MUX_CTL_PAD_LCD_VSYNC SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_reset_t SW_MUX_CTL_PAD_LCD_RESET; /*!< [0xC4] SW_MUX_CTL_PAD_LCD_RESET SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data00_t SW_MUX_CTL_PAD_LCD_DATA00; /*!< [0xC8] SW_MUX_CTL_PAD_LCD_DATA00 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data01_t SW_MUX_CTL_PAD_LCD_DATA01; /*!< [0xCC] SW_MUX_CTL_PAD_LCD_DATA01 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data02_t SW_MUX_CTL_PAD_LCD_DATA02; /*!< [0xD0] SW_MUX_CTL_PAD_LCD_DATA02 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data03_t SW_MUX_CTL_PAD_LCD_DATA03; /*!< [0xD4] SW_MUX_CTL_PAD_LCD_DATA03 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data04_t SW_MUX_CTL_PAD_LCD_DATA04; /*!< [0xD8] SW_MUX_CTL_PAD_LCD_DATA04 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data05_t SW_MUX_CTL_PAD_LCD_DATA05; /*!< [0xDC] SW_MUX_CTL_PAD_LCD_DATA05 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data06_t SW_MUX_CTL_PAD_LCD_DATA06; /*!< [0xE0] SW_MUX_CTL_PAD_LCD_DATA06 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data07_t SW_MUX_CTL_PAD_LCD_DATA07; /*!< [0xE4] SW_MUX_CTL_PAD_LCD_DATA07 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data08_t SW_MUX_CTL_PAD_LCD_DATA08; /*!< [0xE8] SW_MUX_CTL_PAD_LCD_DATA08 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data09_t SW_MUX_CTL_PAD_LCD_DATA09; /*!< [0xEC] SW_MUX_CTL_PAD_LCD_DATA09 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data10_t SW_MUX_CTL_PAD_LCD_DATA10; /*!< [0xF0] SW_MUX_CTL_PAD_LCD_DATA10 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data11_t SW_MUX_CTL_PAD_LCD_DATA11; /*!< [0xF4] SW_MUX_CTL_PAD_LCD_DATA11 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data12_t SW_MUX_CTL_PAD_LCD_DATA12; /*!< [0xF8] SW_MUX_CTL_PAD_LCD_DATA12 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data13_t SW_MUX_CTL_PAD_LCD_DATA13; /*!< [0xFC] SW_MUX_CTL_PAD_LCD_DATA13 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data14_t SW_MUX_CTL_PAD_LCD_DATA14; /*!< [0x100] SW_MUX_CTL_PAD_LCD_DATA14 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data15_t SW_MUX_CTL_PAD_LCD_DATA15; /*!< [0x104] SW_MUX_CTL_PAD_LCD_DATA15 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data16_t SW_MUX_CTL_PAD_LCD_DATA16; /*!< [0x108] SW_MUX_CTL_PAD_LCD_DATA16 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data17_t SW_MUX_CTL_PAD_LCD_DATA17; /*!< [0x10C] SW_MUX_CTL_PAD_LCD_DATA17 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data18_t SW_MUX_CTL_PAD_LCD_DATA18; /*!< [0x110] SW_MUX_CTL_PAD_LCD_DATA18 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data19_t SW_MUX_CTL_PAD_LCD_DATA19; /*!< [0x114] SW_MUX_CTL_PAD_LCD_DATA19 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data20_t SW_MUX_CTL_PAD_LCD_DATA20; /*!< [0x118] SW_MUX_CTL_PAD_LCD_DATA20 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data21_t SW_MUX_CTL_PAD_LCD_DATA21; /*!< [0x11C] SW_MUX_CTL_PAD_LCD_DATA21 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data22_t SW_MUX_CTL_PAD_LCD_DATA22; /*!< [0x120] SW_MUX_CTL_PAD_LCD_DATA22 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_lcd_data23_t SW_MUX_CTL_PAD_LCD_DATA23; /*!< [0x124] SW_MUX_CTL_PAD_LCD_DATA23 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_uart1_rx_data_t SW_MUX_CTL_PAD_UART1_RX_DATA; /*!< [0x128] SW_MUX_CTL_PAD_UART1_RX_DATA SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_uart1_tx_data_t SW_MUX_CTL_PAD_UART1_TX_DATA; /*!< [0x12C] SW_MUX_CTL_PAD_UART1_TX_DATA SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_uart2_rx_data_t SW_MUX_CTL_PAD_UART2_RX_DATA; /*!< [0x130] SW_MUX_CTL_PAD_UART2_RX_DATA SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_uart2_tx_data_t SW_MUX_CTL_PAD_UART2_TX_DATA; /*!< [0x134] SW_MUX_CTL_PAD_UART2_TX_DATA SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_uart3_rx_data_t SW_MUX_CTL_PAD_UART3_RX_DATA; /*!< [0x138] SW_MUX_CTL_PAD_UART3_RX_DATA SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_uart3_tx_data_t SW_MUX_CTL_PAD_UART3_TX_DATA; /*!< [0x13C] SW_MUX_CTL_PAD_UART3_TX_DATA SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_uart3_rts_b_t SW_MUX_CTL_PAD_UART3_RTS_B; /*!< [0x140] SW_MUX_CTL_PAD_UART3_RTS_B SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_uart3_cts_b_t SW_MUX_CTL_PAD_UART3_CTS_B; /*!< [0x144] SW_MUX_CTL_PAD_UART3_CTS_B SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_i2c1_scl_t SW_MUX_CTL_PAD_I2C1_SCL; /*!< [0x148] SW_MUX_CTL_PAD_I2C1_SCL SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_i2c1_sda_t SW_MUX_CTL_PAD_I2C1_SDA; /*!< [0x14C] SW_MUX_CTL_PAD_I2C1_SDA SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_i2c2_scl_t SW_MUX_CTL_PAD_I2C2_SCL; /*!< [0x150] SW_MUX_CTL_PAD_I2C2_SCL SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_i2c2_sda_t SW_MUX_CTL_PAD_I2C2_SDA; /*!< [0x154] SW_MUX_CTL_PAD_I2C2_SDA SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_i2c3_scl_t SW_MUX_CTL_PAD_I2C3_SCL; /*!< [0x158] SW_MUX_CTL_PAD_I2C3_SCL SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_i2c3_sda_t SW_MUX_CTL_PAD_I2C3_SDA; /*!< [0x15C] SW_MUX_CTL_PAD_I2C3_SDA SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_i2c4_scl_t SW_MUX_CTL_PAD_I2C4_SCL; /*!< [0x160] SW_MUX_CTL_PAD_I2C4_SCL SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_i2c4_sda_t SW_MUX_CTL_PAD_I2C4_SDA; /*!< [0x164] SW_MUX_CTL_PAD_I2C4_SDA SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_ecspi1_sclk_t SW_MUX_CTL_PAD_ECSPI1_SCLK; /*!< [0x168] SW_MUX_CTL_PAD_ECSPI1_SCLK SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_ecspi1_mosi_t SW_MUX_CTL_PAD_ECSPI1_MOSI; /*!< [0x16C] SW_MUX_CTL_PAD_ECSPI1_MOSI SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_ecspi1_miso_t SW_MUX_CTL_PAD_ECSPI1_MISO; /*!< [0x170] SW_MUX_CTL_PAD_ECSPI1_MISO SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_ecspi1_ss0_t SW_MUX_CTL_PAD_ECSPI1_SS0; /*!< [0x174] SW_MUX_CTL_PAD_ECSPI1_SS0 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_ecspi2_sclk_t SW_MUX_CTL_PAD_ECSPI2_SCLK; /*!< [0x178] SW_MUX_CTL_PAD_ECSPI2_SCLK SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_ecspi2_mosi_t SW_MUX_CTL_PAD_ECSPI2_MOSI; /*!< [0x17C] SW_MUX_CTL_PAD_ECSPI2_MOSI SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_ecspi2_miso_t SW_MUX_CTL_PAD_ECSPI2_MISO; /*!< [0x180] SW_MUX_CTL_PAD_ECSPI2_MISO SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_ecspi2_ss0_t SW_MUX_CTL_PAD_ECSPI2_SS0; /*!< [0x184] SW_MUX_CTL_PAD_ECSPI2_SS0 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd1_cd_b_t SW_MUX_CTL_PAD_SD1_CD_B; /*!< [0x188] SW_MUX_CTL_PAD_SD1_CD_B SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd1_wp_t SW_MUX_CTL_PAD_SD1_WP; /*!< [0x18C] SW_MUX_CTL_PAD_SD1_WP SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd1_reset_b_t SW_MUX_CTL_PAD_SD1_RESET_B; /*!< [0x190] SW_MUX_CTL_PAD_SD1_RESET_B SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd1_clk_t SW_MUX_CTL_PAD_SD1_CLK; /*!< [0x194] SW_MUX_CTL_PAD_SD1_CLK SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd1_cmd_t SW_MUX_CTL_PAD_SD1_CMD; /*!< [0x198] SW_MUX_CTL_PAD_SD1_CMD SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd1_data0_t SW_MUX_CTL_PAD_SD1_DATA0; /*!< [0x19C] SW_MUX_CTL_PAD_SD1_DATA0 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd1_data1_t SW_MUX_CTL_PAD_SD1_DATA1; /*!< [0x1A0] SW_MUX_CTL_PAD_SD1_DATA1 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd1_data2_t SW_MUX_CTL_PAD_SD1_DATA2; /*!< [0x1A4] SW_MUX_CTL_PAD_SD1_DATA2 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd1_data3_t SW_MUX_CTL_PAD_SD1_DATA3; /*!< [0x1A8] SW_MUX_CTL_PAD_SD1_DATA3 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd2_cd_b_t SW_MUX_CTL_PAD_SD2_CD_B; /*!< [0x1AC] SW_MUX_CTL_PAD_SD2_CD_B SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd2_wp_t SW_MUX_CTL_PAD_SD2_WP; /*!< [0x1B0] SW_MUX_CTL_PAD_SD2_WP SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd2_reset_b_t SW_MUX_CTL_PAD_SD2_RESET_B; /*!< [0x1B4] SW_MUX_CTL_PAD_SD2_RESET_B SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd2_clk_t SW_MUX_CTL_PAD_SD2_CLK; /*!< [0x1B8] SW_MUX_CTL_PAD_SD2_CLK SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd2_cmd_t SW_MUX_CTL_PAD_SD2_CMD; /*!< [0x1BC] SW_MUX_CTL_PAD_SD2_CMD SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd2_data0_t SW_MUX_CTL_PAD_SD2_DATA0; /*!< [0x1C0] SW_MUX_CTL_PAD_SD2_DATA0 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd2_data1_t SW_MUX_CTL_PAD_SD2_DATA1; /*!< [0x1C4] SW_MUX_CTL_PAD_SD2_DATA1 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd2_data2_t SW_MUX_CTL_PAD_SD2_DATA2; /*!< [0x1C8] SW_MUX_CTL_PAD_SD2_DATA2 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd2_data3_t SW_MUX_CTL_PAD_SD2_DATA3; /*!< [0x1CC] SW_MUX_CTL_PAD_SD2_DATA3 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_clk_t SW_MUX_CTL_PAD_SD3_CLK; /*!< [0x1D0] SW_MUX_CTL_PAD_SD3_CLK SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_cmd_t SW_MUX_CTL_PAD_SD3_CMD; /*!< [0x1D4] SW_MUX_CTL_PAD_SD3_CMD SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_data0_t SW_MUX_CTL_PAD_SD3_DATA0; /*!< [0x1D8] SW_MUX_CTL_PAD_SD3_DATA0 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_data1_t SW_MUX_CTL_PAD_SD3_DATA1; /*!< [0x1DC] SW_MUX_CTL_PAD_SD3_DATA1 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_data2_t SW_MUX_CTL_PAD_SD3_DATA2; /*!< [0x1E0] SW_MUX_CTL_PAD_SD3_DATA2 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_data3_t SW_MUX_CTL_PAD_SD3_DATA3; /*!< [0x1E4] SW_MUX_CTL_PAD_SD3_DATA3 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_data4_t SW_MUX_CTL_PAD_SD3_DATA4; /*!< [0x1E8] SW_MUX_CTL_PAD_SD3_DATA4 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_data5_t SW_MUX_CTL_PAD_SD3_DATA5; /*!< [0x1EC] SW_MUX_CTL_PAD_SD3_DATA5 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_data6_t SW_MUX_CTL_PAD_SD3_DATA6; /*!< [0x1F0] SW_MUX_CTL_PAD_SD3_DATA6 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_data7_t SW_MUX_CTL_PAD_SD3_DATA7; /*!< [0x1F4] SW_MUX_CTL_PAD_SD3_DATA7 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_strobe_t SW_MUX_CTL_PAD_SD3_STROBE; /*!< [0x1F8] SW_MUX_CTL_PAD_SD3_STROBE SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sd3_reset_b_t SW_MUX_CTL_PAD_SD3_RESET_B; /*!< [0x1FC] SW_MUX_CTL_PAD_SD3_RESET_B SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sai1_rx_data_t SW_MUX_CTL_PAD_SAI1_RX_DATA; /*!< [0x200] SW_MUX_CTL_PAD_SAI1_RX_DATA SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sai1_tx_bclk_t SW_MUX_CTL_PAD_SAI1_TX_BCLK; /*!< [0x204] SW_MUX_CTL_PAD_SAI1_TX_BCLK SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sai1_tx_sync_t SW_MUX_CTL_PAD_SAI1_TX_SYNC; /*!< [0x208] SW_MUX_CTL_PAD_SAI1_TX_SYNC SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sai1_tx_data_t SW_MUX_CTL_PAD_SAI1_TX_DATA; /*!< [0x20C] SW_MUX_CTL_PAD_SAI1_TX_DATA SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sai1_rx_sync_t SW_MUX_CTL_PAD_SAI1_RX_SYNC; /*!< [0x210] SW_MUX_CTL_PAD_SAI1_RX_SYNC SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sai1_rx_bclk_t SW_MUX_CTL_PAD_SAI1_RX_BCLK; /*!< [0x214] SW_MUX_CTL_PAD_SAI1_RX_BCLK SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sai1_mclk_t SW_MUX_CTL_PAD_SAI1_MCLK; /*!< [0x218] SW_MUX_CTL_PAD_SAI1_MCLK SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sai2_tx_sync_t SW_MUX_CTL_PAD_SAI2_TX_SYNC; /*!< [0x21C] SW_MUX_CTL_PAD_SAI2_TX_SYNC SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sai2_tx_bclk_t SW_MUX_CTL_PAD_SAI2_TX_BCLK; /*!< [0x220] SW_MUX_CTL_PAD_SAI2_TX_BCLK SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sai2_rx_data_t SW_MUX_CTL_PAD_SAI2_RX_DATA; /*!< [0x224] SW_MUX_CTL_PAD_SAI2_RX_DATA SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_sai2_tx_data_t SW_MUX_CTL_PAD_SAI2_TX_DATA; /*!< [0x228] SW_MUX_CTL_PAD_SAI2_TX_DATA SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd0_t SW_MUX_CTL_PAD_ENET1_RGMII_RD0; /*!< [0x22C] SW_MUX_CTL_PAD_ENET1_RGMII_RD0 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd1_t SW_MUX_CTL_PAD_ENET1_RGMII_RD1; /*!< [0x230] SW_MUX_CTL_PAD_ENET1_RGMII_RD1 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd2_t SW_MUX_CTL_PAD_ENET1_RGMII_RD2; /*!< [0x234] SW_MUX_CTL_PAD_ENET1_RGMII_RD2 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rd3_t SW_MUX_CTL_PAD_ENET1_RGMII_RD3; /*!< [0x238] SW_MUX_CTL_PAD_ENET1_RGMII_RD3 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rx_ctl_t SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL; /*!< [0x23C] SW_MUX_CTL_PAD_ENET1_RGMII_RX_CTL SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_rxc_t SW_MUX_CTL_PAD_ENET1_RGMII_RXC; /*!< [0x240] SW_MUX_CTL_PAD_ENET1_RGMII_RXC SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td0_t SW_MUX_CTL_PAD_ENET1_RGMII_TD0; /*!< [0x244] SW_MUX_CTL_PAD_ENET1_RGMII_TD0 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td1_t SW_MUX_CTL_PAD_ENET1_RGMII_TD1; /*!< [0x248] SW_MUX_CTL_PAD_ENET1_RGMII_TD1 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td2_t SW_MUX_CTL_PAD_ENET1_RGMII_TD2; /*!< [0x24C] SW_MUX_CTL_PAD_ENET1_RGMII_TD2 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_td3_t SW_MUX_CTL_PAD_ENET1_RGMII_TD3; /*!< [0x250] SW_MUX_CTL_PAD_ENET1_RGMII_TD3 SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_tx_ctl_t SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL; /*!< [0x254] SW_MUX_CTL_PAD_ENET1_RGMII_TX_CTL SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_rgmii_txc_t SW_MUX_CTL_PAD_ENET1_RGMII_TXC; /*!< [0x258] SW_MUX_CTL_PAD_ENET1_RGMII_TXC SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_tx_clk_t SW_MUX_CTL_PAD_ENET1_TX_CLK; /*!< [0x25C] SW_MUX_CTL_PAD_ENET1_TX_CLK SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_rx_clk_t SW_MUX_CTL_PAD_ENET1_RX_CLK; /*!< [0x260] SW_MUX_CTL_PAD_ENET1_RX_CLK SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_crs_t SW_MUX_CTL_PAD_ENET1_CRS; /*!< [0x264] SW_MUX_CTL_PAD_ENET1_CRS SW MUX Control Register */
    __IO hw_iomuxc_sw_mux_ctl_pad_enet1_col_t SW_MUX_CTL_PAD_ENET1_COL; /*!< [0x268] SW_MUX_CTL_PAD_ENET1_COL SW MUX Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io08_t SW_PAD_CTL_PAD_GPIO1_IO08; /*!< [0x26C] SW_PAD_CTL_PAD_GPIO1_IO08 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io09_t SW_PAD_CTL_PAD_GPIO1_IO09; /*!< [0x270] SW_PAD_CTL_PAD_GPIO1_IO09 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io10_t SW_PAD_CTL_PAD_GPIO1_IO10; /*!< [0x274] SW_PAD_CTL_PAD_GPIO1_IO10 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io11_t SW_PAD_CTL_PAD_GPIO1_IO11; /*!< [0x278] SW_PAD_CTL_PAD_GPIO1_IO11 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io12_t SW_PAD_CTL_PAD_GPIO1_IO12; /*!< [0x27C] SW_PAD_CTL_PAD_GPIO1_IO12 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io13_t SW_PAD_CTL_PAD_GPIO1_IO13; /*!< [0x280] SW_PAD_CTL_PAD_GPIO1_IO13 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io14_t SW_PAD_CTL_PAD_GPIO1_IO14; /*!< [0x284] SW_PAD_CTL_PAD_GPIO1_IO14 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_gpio1_io15_t SW_PAD_CTL_PAD_GPIO1_IO15; /*!< [0x288] SW_PAD_CTL_PAD_GPIO1_IO15 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_jtag_mod_t SW_PAD_CTL_PAD_JTAG_MOD; /*!< [0x28C] SW_PAD_CTL_PAD_JTAG_MOD SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_jtag_tck_t SW_PAD_CTL_PAD_JTAG_TCK; /*!< [0x290] SW_PAD_CTL_PAD_JTAG_TCK SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_jtag_tdi_t SW_PAD_CTL_PAD_JTAG_TDI; /*!< [0x294] SW_PAD_CTL_PAD_JTAG_TDI SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_jtag_tdo_t SW_PAD_CTL_PAD_JTAG_TDO; /*!< [0x298] SW_PAD_CTL_PAD_JTAG_TDO SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_jtag_tms_t SW_PAD_CTL_PAD_JTAG_TMS; /*!< [0x29C] SW_PAD_CTL_PAD_JTAG_TMS SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_jtag_trst_b_t SW_PAD_CTL_PAD_JTAG_TRST_B; /*!< [0x2A0] SW_PAD_CTL_PAD_JTAG_TRST_B SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_data00_t SW_PAD_CTL_PAD_EPDC_DATA00; /*!< [0x2A4] SW_PAD_CTL_PAD_EPDC_DATA00 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_data01_t SW_PAD_CTL_PAD_EPDC_DATA01; /*!< [0x2A8] SW_PAD_CTL_PAD_EPDC_DATA01 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_data02_t SW_PAD_CTL_PAD_EPDC_DATA02; /*!< [0x2AC] SW_PAD_CTL_PAD_EPDC_DATA02 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_data03_t SW_PAD_CTL_PAD_EPDC_DATA03; /*!< [0x2B0] SW_PAD_CTL_PAD_EPDC_DATA03 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_data04_t SW_PAD_CTL_PAD_EPDC_DATA04; /*!< [0x2B4] SW_PAD_CTL_PAD_EPDC_DATA04 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_data05_t SW_PAD_CTL_PAD_EPDC_DATA05; /*!< [0x2B8] SW_PAD_CTL_PAD_EPDC_DATA05 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_data06_t SW_PAD_CTL_PAD_EPDC_DATA06; /*!< [0x2BC] SW_PAD_CTL_PAD_EPDC_DATA06 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_data07_t SW_PAD_CTL_PAD_EPDC_DATA07; /*!< [0x2C0] SW_PAD_CTL_PAD_EPDC_DATA07 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_data08_t SW_PAD_CTL_PAD_EPDC_DATA08; /*!< [0x2C4] SW_PAD_CTL_PAD_EPDC_DATA08 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_data09_t SW_PAD_CTL_PAD_EPDC_DATA09; /*!< [0x2C8] SW_PAD_CTL_PAD_EPDC_DATA09 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_data10_t SW_PAD_CTL_PAD_EPDC_DATA10; /*!< [0x2CC] SW_PAD_CTL_PAD_EPDC_DATA10 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_data11_t SW_PAD_CTL_PAD_EPDC_DATA11; /*!< [0x2D0] SW_PAD_CTL_PAD_EPDC_DATA11 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_data12_t SW_PAD_CTL_PAD_EPDC_DATA12; /*!< [0x2D4] SW_PAD_CTL_PAD_EPDC_DATA12 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_data13_t SW_PAD_CTL_PAD_EPDC_DATA13; /*!< [0x2D8] SW_PAD_CTL_PAD_EPDC_DATA13 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_data14_t SW_PAD_CTL_PAD_EPDC_DATA14; /*!< [0x2DC] SW_PAD_CTL_PAD_EPDC_DATA14 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_data15_t SW_PAD_CTL_PAD_EPDC_DATA15; /*!< [0x2E0] SW_PAD_CTL_PAD_EPDC_DATA15 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_sdclk_t SW_PAD_CTL_PAD_EPDC_SDCLK; /*!< [0x2E4] SW_PAD_CTL_PAD_EPDC_SDCLK SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_sdle_t SW_PAD_CTL_PAD_EPDC_SDLE; /*!< [0x2E8] SW_PAD_CTL_PAD_EPDC_SDLE SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_sdoe_t SW_PAD_CTL_PAD_EPDC_SDOE; /*!< [0x2EC] SW_PAD_CTL_PAD_EPDC_SDOE SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_sdshr_t SW_PAD_CTL_PAD_EPDC_SDSHR; /*!< [0x2F0] SW_PAD_CTL_PAD_EPDC_SDSHR SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_sdce0_t SW_PAD_CTL_PAD_EPDC_SDCE0; /*!< [0x2F4] SW_PAD_CTL_PAD_EPDC_SDCE0 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_sdce1_t SW_PAD_CTL_PAD_EPDC_SDCE1; /*!< [0x2F8] SW_PAD_CTL_PAD_EPDC_SDCE1 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_sdce2_t SW_PAD_CTL_PAD_EPDC_SDCE2; /*!< [0x2FC] SW_PAD_CTL_PAD_EPDC_SDCE2 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_sdce3_t SW_PAD_CTL_PAD_EPDC_SDCE3; /*!< [0x300] SW_PAD_CTL_PAD_EPDC_SDCE3 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_gdclk_t SW_PAD_CTL_PAD_EPDC_GDCLK; /*!< [0x304] SW_PAD_CTL_PAD_EPDC_GDCLK SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_gdoe_t SW_PAD_CTL_PAD_EPDC_GDOE; /*!< [0x308] SW_PAD_CTL_PAD_EPDC_GDOE SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_gdrl_t SW_PAD_CTL_PAD_EPDC_GDRL; /*!< [0x30C] SW_PAD_CTL_PAD_EPDC_GDRL SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_gdsp_t SW_PAD_CTL_PAD_EPDC_GDSP; /*!< [0x310] SW_PAD_CTL_PAD_EPDC_GDSP SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_bdr0_t SW_PAD_CTL_PAD_EPDC_BDR0; /*!< [0x314] SW_PAD_CTL_PAD_EPDC_BDR0 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_bdr1_t SW_PAD_CTL_PAD_EPDC_BDR1; /*!< [0x318] SW_PAD_CTL_PAD_EPDC_BDR1 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_pwr_com_t SW_PAD_CTL_PAD_EPDC_PWR_COM; /*!< [0x31C] SW_PAD_CTL_PAD_EPDC_PWR_COM SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_epdc_pwr_stat_t SW_PAD_CTL_PAD_EPDC_PWR_STAT; /*!< [0x320] SW_PAD_CTL_PAD_EPDC_PWR_STAT SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_clk_t SW_PAD_CTL_PAD_LCD_CLK; /*!< [0x324] SW_PAD_CTL_PAD_LCD_CLK SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_enable_t SW_PAD_CTL_PAD_LCD_ENABLE; /*!< [0x328] SW_PAD_CTL_PAD_LCD_ENABLE SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_hsync_t SW_PAD_CTL_PAD_LCD_HSYNC; /*!< [0x32C] SW_PAD_CTL_PAD_LCD_HSYNC SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_vsync_t SW_PAD_CTL_PAD_LCD_VSYNC; /*!< [0x330] SW_PAD_CTL_PAD_LCD_VSYNC SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_reset_t SW_PAD_CTL_PAD_LCD_RESET; /*!< [0x334] SW_PAD_CTL_PAD_LCD_RESET SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data00_t SW_PAD_CTL_PAD_LCD_DATA00; /*!< [0x338] SW_PAD_CTL_PAD_LCD_DATA00 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data01_t SW_PAD_CTL_PAD_LCD_DATA01; /*!< [0x33C] SW_PAD_CTL_PAD_LCD_DATA01 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data02_t SW_PAD_CTL_PAD_LCD_DATA02; /*!< [0x340] SW_PAD_CTL_PAD_LCD_DATA02 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data03_t SW_PAD_CTL_PAD_LCD_DATA03; /*!< [0x344] SW_PAD_CTL_PAD_LCD_DATA03 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data04_t SW_PAD_CTL_PAD_LCD_DATA04; /*!< [0x348] SW_PAD_CTL_PAD_LCD_DATA04 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data05_t SW_PAD_CTL_PAD_LCD_DATA05; /*!< [0x34C] SW_PAD_CTL_PAD_LCD_DATA05 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data06_t SW_PAD_CTL_PAD_LCD_DATA06; /*!< [0x350] SW_PAD_CTL_PAD_LCD_DATA06 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data07_t SW_PAD_CTL_PAD_LCD_DATA07; /*!< [0x354] SW_PAD_CTL_PAD_LCD_DATA07 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data08_t SW_PAD_CTL_PAD_LCD_DATA08; /*!< [0x358] SW_PAD_CTL_PAD_LCD_DATA08 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data09_t SW_PAD_CTL_PAD_LCD_DATA09; /*!< [0x35C] SW_PAD_CTL_PAD_LCD_DATA09 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data10_t SW_PAD_CTL_PAD_LCD_DATA10; /*!< [0x360] SW_PAD_CTL_PAD_LCD_DATA10 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data11_t SW_PAD_CTL_PAD_LCD_DATA11; /*!< [0x364] SW_PAD_CTL_PAD_LCD_DATA11 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data12_t SW_PAD_CTL_PAD_LCD_DATA12; /*!< [0x368] SW_PAD_CTL_PAD_LCD_DATA12 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data13_t SW_PAD_CTL_PAD_LCD_DATA13; /*!< [0x36C] SW_PAD_CTL_PAD_LCD_DATA13 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data14_t SW_PAD_CTL_PAD_LCD_DATA14; /*!< [0x370] SW_PAD_CTL_PAD_LCD_DATA14 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data15_t SW_PAD_CTL_PAD_LCD_DATA15; /*!< [0x374] SW_PAD_CTL_PAD_LCD_DATA15 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data16_t SW_PAD_CTL_PAD_LCD_DATA16; /*!< [0x378] SW_PAD_CTL_PAD_LCD_DATA16 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data17_t SW_PAD_CTL_PAD_LCD_DATA17; /*!< [0x37C] SW_PAD_CTL_PAD_LCD_DATA17 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data18_t SW_PAD_CTL_PAD_LCD_DATA18; /*!< [0x380] SW_PAD_CTL_PAD_LCD_DATA18 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data19_t SW_PAD_CTL_PAD_LCD_DATA19; /*!< [0x384] SW_PAD_CTL_PAD_LCD_DATA19 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data20_t SW_PAD_CTL_PAD_LCD_DATA20; /*!< [0x388] SW_PAD_CTL_PAD_LCD_DATA20 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data21_t SW_PAD_CTL_PAD_LCD_DATA21; /*!< [0x38C] SW_PAD_CTL_PAD_LCD_DATA21 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data22_t SW_PAD_CTL_PAD_LCD_DATA22; /*!< [0x390] SW_PAD_CTL_PAD_LCD_DATA22 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_lcd_data23_t SW_PAD_CTL_PAD_LCD_DATA23; /*!< [0x394] SW_PAD_CTL_PAD_LCD_DATA23 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_uart1_rx_data_t SW_PAD_CTL_PAD_UART1_RX_DATA; /*!< [0x398] SW_PAD_CTL_PAD_UART1_RX_DATA SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_uart1_tx_data_t SW_PAD_CTL_PAD_UART1_TX_DATA; /*!< [0x39C] SW_PAD_CTL_PAD_UART1_TX_DATA SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_uart2_rx_data_t SW_PAD_CTL_PAD_UART2_RX_DATA; /*!< [0x3A0] SW_PAD_CTL_PAD_UART2_RX_DATA SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_uart2_tx_data_t SW_PAD_CTL_PAD_UART2_TX_DATA; /*!< [0x3A4] SW_PAD_CTL_PAD_UART2_TX_DATA SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_uart3_rx_data_t SW_PAD_CTL_PAD_UART3_RX_DATA; /*!< [0x3A8] SW_PAD_CTL_PAD_UART3_RX_DATA SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_uart3_tx_data_t SW_PAD_CTL_PAD_UART3_TX_DATA; /*!< [0x3AC] SW_PAD_CTL_PAD_UART3_TX_DATA SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_uart3_rts_b_t SW_PAD_CTL_PAD_UART3_RTS_B; /*!< [0x3B0] SW_PAD_CTL_PAD_UART3_RTS_B SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_uart3_cts_b_t SW_PAD_CTL_PAD_UART3_CTS_B; /*!< [0x3B4] SW_PAD_CTL_PAD_UART3_CTS_B SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_i2c1_scl_t SW_PAD_CTL_PAD_I2C1_SCL; /*!< [0x3B8] SW_PAD_CTL_PAD_I2C1_SCL SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_i2c1_sda_t SW_PAD_CTL_PAD_I2C1_SDA; /*!< [0x3BC] SW_PAD_CTL_PAD_I2C1_SDA SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_i2c2_scl_t SW_PAD_CTL_PAD_I2C2_SCL; /*!< [0x3C0] SW_PAD_CTL_PAD_I2C2_SCL SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_i2c2_sda_t SW_PAD_CTL_PAD_I2C2_SDA; /*!< [0x3C4] SW_PAD_CTL_PAD_I2C2_SDA SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_i2c3_scl_t SW_PAD_CTL_PAD_I2C3_SCL; /*!< [0x3C8] SW_PAD_CTL_PAD_I2C3_SCL SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_i2c3_sda_t SW_PAD_CTL_PAD_I2C3_SDA; /*!< [0x3CC] SW_PAD_CTL_PAD_I2C3_SDA SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_i2c4_scl_t SW_PAD_CTL_PAD_I2C4_SCL; /*!< [0x3D0] SW_PAD_CTL_PAD_I2C4_SCL SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_i2c4_sda_t SW_PAD_CTL_PAD_I2C4_SDA; /*!< [0x3D4] SW_PAD_CTL_PAD_I2C4_SDA SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_ecspi1_sclk_t SW_PAD_CTL_PAD_ECSPI1_SCLK; /*!< [0x3D8] SW_PAD_CTL_PAD_ECSPI1_SCLK SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_ecspi1_mosi_t SW_PAD_CTL_PAD_ECSPI1_MOSI; /*!< [0x3DC] SW_PAD_CTL_PAD_ECSPI1_MOSI SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_ecspi1_miso_t SW_PAD_CTL_PAD_ECSPI1_MISO; /*!< [0x3E0] SW_PAD_CTL_PAD_ECSPI1_MISO SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_ecspi1_ss0_t SW_PAD_CTL_PAD_ECSPI1_SS0; /*!< [0x3E4] SW_PAD_CTL_PAD_ECSPI1_SS0 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_ecspi2_sclk_t SW_PAD_CTL_PAD_ECSPI2_SCLK; /*!< [0x3E8] SW_PAD_CTL_PAD_ECSPI2_SCLK SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_ecspi2_mosi_t SW_PAD_CTL_PAD_ECSPI2_MOSI; /*!< [0x3EC] SW_PAD_CTL_PAD_ECSPI2_MOSI SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_ecspi2_miso_t SW_PAD_CTL_PAD_ECSPI2_MISO; /*!< [0x3F0] SW_PAD_CTL_PAD_ECSPI2_MISO SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_ecspi2_ss0_t SW_PAD_CTL_PAD_ECSPI2_SS0; /*!< [0x3F4] SW_PAD_CTL_PAD_ECSPI2_SS0 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd1_cd_b_t SW_PAD_CTL_PAD_SD1_CD_B; /*!< [0x3F8] SW_PAD_CTL_PAD_SD1_CD_B SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd1_wp_t SW_PAD_CTL_PAD_SD1_WP; /*!< [0x3FC] SW_PAD_CTL_PAD_SD1_WP SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd1_reset_b_t SW_PAD_CTL_PAD_SD1_RESET_B; /*!< [0x400] SW_PAD_CTL_PAD_SD1_RESET_B SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd1_clk_t SW_PAD_CTL_PAD_SD1_CLK; /*!< [0x404] SW_PAD_CTL_PAD_SD1_CLK SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd1_cmd_t SW_PAD_CTL_PAD_SD1_CMD; /*!< [0x408] SW_PAD_CTL_PAD_SD1_CMD SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd1_data0_t SW_PAD_CTL_PAD_SD1_DATA0; /*!< [0x40C] SW_PAD_CTL_PAD_SD1_DATA0 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd1_data1_t SW_PAD_CTL_PAD_SD1_DATA1; /*!< [0x410] SW_PAD_CTL_PAD_SD1_DATA1 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd1_data2_t SW_PAD_CTL_PAD_SD1_DATA2; /*!< [0x414] SW_PAD_CTL_PAD_SD1_DATA2 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd1_data3_t SW_PAD_CTL_PAD_SD1_DATA3; /*!< [0x418] SW_PAD_CTL_PAD_SD1_DATA3 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd2_cd_b_t SW_PAD_CTL_PAD_SD2_CD_B; /*!< [0x41C] SW_PAD_CTL_PAD_SD2_CD_B SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd2_wp_t SW_PAD_CTL_PAD_SD2_WP; /*!< [0x420] SW_PAD_CTL_PAD_SD2_WP SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd2_reset_b_t SW_PAD_CTL_PAD_SD2_RESET_B; /*!< [0x424] SW_PAD_CTL_PAD_SD2_RESET_B SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd2_clk_t SW_PAD_CTL_PAD_SD2_CLK; /*!< [0x428] SW_PAD_CTL_PAD_SD2_CLK SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd2_cmd_t SW_PAD_CTL_PAD_SD2_CMD; /*!< [0x42C] SW_PAD_CTL_PAD_SD2_CMD SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd2_data0_t SW_PAD_CTL_PAD_SD2_DATA0; /*!< [0x430] SW_PAD_CTL_PAD_SD2_DATA0 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd2_data1_t SW_PAD_CTL_PAD_SD2_DATA1; /*!< [0x434] SW_PAD_CTL_PAD_SD2_DATA1 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd2_data2_t SW_PAD_CTL_PAD_SD2_DATA2; /*!< [0x438] SW_PAD_CTL_PAD_SD2_DATA2 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd2_data3_t SW_PAD_CTL_PAD_SD2_DATA3; /*!< [0x43C] SW_PAD_CTL_PAD_SD2_DATA3 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_clk_t SW_PAD_CTL_PAD_SD3_CLK; /*!< [0x440] SW_PAD_CTL_PAD_SD3_CLK SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_cmd_t SW_PAD_CTL_PAD_SD3_CMD; /*!< [0x444] SW_PAD_CTL_PAD_SD3_CMD SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_data0_t SW_PAD_CTL_PAD_SD3_DATA0; /*!< [0x448] SW_PAD_CTL_PAD_SD3_DATA0 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_data1_t SW_PAD_CTL_PAD_SD3_DATA1; /*!< [0x44C] SW_PAD_CTL_PAD_SD3_DATA1 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_data2_t SW_PAD_CTL_PAD_SD3_DATA2; /*!< [0x450] SW_PAD_CTL_PAD_SD3_DATA2 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_data3_t SW_PAD_CTL_PAD_SD3_DATA3; /*!< [0x454] SW_PAD_CTL_PAD_SD3_DATA3 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_data4_t SW_PAD_CTL_PAD_SD3_DATA4; /*!< [0x458] SW_PAD_CTL_PAD_SD3_DATA4 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_data5_t SW_PAD_CTL_PAD_SD3_DATA5; /*!< [0x45C] SW_PAD_CTL_PAD_SD3_DATA5 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_data6_t SW_PAD_CTL_PAD_SD3_DATA6; /*!< [0x460] SW_PAD_CTL_PAD_SD3_DATA6 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_data7_t SW_PAD_CTL_PAD_SD3_DATA7; /*!< [0x464] SW_PAD_CTL_PAD_SD3_DATA7 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_strobe_t SW_PAD_CTL_PAD_SD3_STROBE; /*!< [0x468] SW_PAD_CTL_PAD_SD3_STROBE SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sd3_reset_b_t SW_PAD_CTL_PAD_SD3_RESET_B; /*!< [0x46C] SW_PAD_CTL_PAD_SD3_RESET_B SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sai1_rx_data_t SW_PAD_CTL_PAD_SAI1_RX_DATA; /*!< [0x470] SW_PAD_CTL_PAD_SAI1_RX_DATA SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sai1_tx_bclk_t SW_PAD_CTL_PAD_SAI1_TX_BCLK; /*!< [0x474] SW_PAD_CTL_PAD_SAI1_TX_BCLK SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sai1_tx_sync_t SW_PAD_CTL_PAD_SAI1_TX_SYNC; /*!< [0x478] SW_PAD_CTL_PAD_SAI1_TX_SYNC SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sai1_tx_data_t SW_PAD_CTL_PAD_SAI1_TX_DATA; /*!< [0x47C] SW_PAD_CTL_PAD_SAI1_TX_DATA SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sai1_rx_sync_t SW_PAD_CTL_PAD_SAI1_RX_SYNC; /*!< [0x480] SW_PAD_CTL_PAD_SAI1_RX_SYNC SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sai1_rx_bclk_t SW_PAD_CTL_PAD_SAI1_RX_BCLK; /*!< [0x484] SW_PAD_CTL_PAD_SAI1_RX_BCLK SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sai1_mclk_t SW_PAD_CTL_PAD_SAI1_MCLK; /*!< [0x488] SW_PAD_CTL_PAD_SAI1_MCLK SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sai2_tx_sync_t SW_PAD_CTL_PAD_SAI2_TX_SYNC; /*!< [0x48C] SW_PAD_CTL_PAD_SAI2_TX_SYNC SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sai2_tx_bclk_t SW_PAD_CTL_PAD_SAI2_TX_BCLK; /*!< [0x490] SW_PAD_CTL_PAD_SAI2_TX_BCLK SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sai2_rx_data_t SW_PAD_CTL_PAD_SAI2_RX_DATA; /*!< [0x494] SW_PAD_CTL_PAD_SAI2_RX_DATA SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_sai2_tx_data_t SW_PAD_CTL_PAD_SAI2_TX_DATA; /*!< [0x498] SW_PAD_CTL_PAD_SAI2_TX_DATA SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd0_t SW_PAD_CTL_PAD_ENET1_RGMII_RD0; /*!< [0x49C] SW_PAD_CTL_PAD_ENET1_RGMII_RD0 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd1_t SW_PAD_CTL_PAD_ENET1_RGMII_RD1; /*!< [0x4A0] SW_PAD_CTL_PAD_ENET1_RGMII_RD1 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd2_t SW_PAD_CTL_PAD_ENET1_RGMII_RD2; /*!< [0x4A4] SW_PAD_CTL_PAD_ENET1_RGMII_RD2 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rd3_t SW_PAD_CTL_PAD_ENET1_RGMII_RD3; /*!< [0x4A8] SW_PAD_CTL_PAD_ENET1_RGMII_RD3 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rx_ctl_t SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL; /*!< [0x4AC] SW_PAD_CTL_PAD_ENET1_RGMII_RX_CTL SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_rxc_t SW_PAD_CTL_PAD_ENET1_RGMII_RXC; /*!< [0x4B0] SW_PAD_CTL_PAD_ENET1_RGMII_RXC SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td0_t SW_PAD_CTL_PAD_ENET1_RGMII_TD0; /*!< [0x4B4] SW_PAD_CTL_PAD_ENET1_RGMII_TD0 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td1_t SW_PAD_CTL_PAD_ENET1_RGMII_TD1; /*!< [0x4B8] SW_PAD_CTL_PAD_ENET1_RGMII_TD1 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td2_t SW_PAD_CTL_PAD_ENET1_RGMII_TD2; /*!< [0x4BC] SW_PAD_CTL_PAD_ENET1_RGMII_TD2 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_td3_t SW_PAD_CTL_PAD_ENET1_RGMII_TD3; /*!< [0x4C0] SW_PAD_CTL_PAD_ENET1_RGMII_TD3 SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_tx_ctl_t SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL; /*!< [0x4C4] SW_PAD_CTL_PAD_ENET1_RGMII_TX_CTL SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_rgmii_txc_t SW_PAD_CTL_PAD_ENET1_RGMII_TXC; /*!< [0x4C8] SW_PAD_CTL_PAD_ENET1_RGMII_TXC SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_tx_clk_t SW_PAD_CTL_PAD_ENET1_TX_CLK; /*!< [0x4CC] SW_PAD_CTL_PAD_ENET1_TX_CLK SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_rx_clk_t SW_PAD_CTL_PAD_ENET1_RX_CLK; /*!< [0x4D0] SW_PAD_CTL_PAD_ENET1_RX_CLK SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_crs_t SW_PAD_CTL_PAD_ENET1_CRS; /*!< [0x4D4] SW_PAD_CTL_PAD_ENET1_CRS SW PAD Control Register */
    __IO hw_iomuxc_sw_pad_ctl_pad_enet1_col_t SW_PAD_CTL_PAD_ENET1_COL; /*!< [0x4D8] SW_PAD_CTL_PAD_ENET1_COL SW PAD Control Register */
    __IO hw_iomuxc_flexcan1_rx_select_input_t FLEXCAN1_RX_SELECT_INPUT; /*!< [0x4DC] FLEXCAN1_RX_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flexcan2_rx_select_input_t FLEXCAN2_RX_SELECT_INPUT; /*!< [0x4E0] FLEXCAN2_RX_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ccm_ext_clk_1_select_input_t CCM_EXT_CLK_1_SELECT_INPUT; /*!< [0x4E4] CCM_EXT_CLK_1_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ccm_ext_clk_2_select_input_t CCM_EXT_CLK_2_SELECT_INPUT; /*!< [0x4E8] CCM_EXT_CLK_2_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ccm_ext_clk_3_select_input_t CCM_EXT_CLK_3_SELECT_INPUT; /*!< [0x4EC] CCM_EXT_CLK_3_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ccm_ext_clk_4_select_input_t CCM_EXT_CLK_4_SELECT_INPUT; /*!< [0x4F0] CCM_EXT_CLK_4_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ccm_pmic_ready_select_input_t CCM_PMIC_READY_SELECT_INPUT; /*!< [0x4F4] CCM_PMIC_READY_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_csi_data2_select_input_t CSI_DATA2_SELECT_INPUT; /*!< [0x4F8] CSI_DATA2_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_csi_data3_select_input_t CSI_DATA3_SELECT_INPUT; /*!< [0x4FC] CSI_DATA3_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_csi_data4_select_input_t CSI_DATA4_SELECT_INPUT; /*!< [0x500] CSI_DATA4_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_csi_data5_select_input_t CSI_DATA5_SELECT_INPUT; /*!< [0x504] CSI_DATA5_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_csi_data6_select_input_t CSI_DATA6_SELECT_INPUT; /*!< [0x508] CSI_DATA6_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_csi_data7_select_input_t CSI_DATA7_SELECT_INPUT; /*!< [0x50C] CSI_DATA7_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_csi_data8_select_input_t CSI_DATA8_SELECT_INPUT; /*!< [0x510] CSI_DATA8_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_csi_data9_select_input_t CSI_DATA9_SELECT_INPUT; /*!< [0x514] CSI_DATA9_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_csi_hsync_select_input_t CSI_HSYNC_SELECT_INPUT; /*!< [0x518] CSI_HSYNC_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_csi_pixclk_select_input_t CSI_PIXCLK_SELECT_INPUT; /*!< [0x51C] CSI_PIXCLK_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_csi_vsync_select_input_t CSI_VSYNC_SELECT_INPUT; /*!< [0x520] CSI_VSYNC_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ecspi1_sclk_select_input_t ECSPI1_SCLK_SELECT_INPUT; /*!< [0x524] ECSPI1_SCLK_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ecspi1_miso_select_input_t ECSPI1_MISO_SELECT_INPUT; /*!< [0x528] ECSPI1_MISO_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ecspi1_mosi_select_input_t ECSPI1_MOSI_SELECT_INPUT; /*!< [0x52C] ECSPI1_MOSI_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ecspi1_ss0_b_select_input_t ECSPI1_SS0_B_SELECT_INPUT; /*!< [0x530] ECSPI1_SS0_B_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ecspi2_sclk_select_input_t ECSPI2_SCLK_SELECT_INPUT; /*!< [0x534] ECSPI2_SCLK_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ecspi2_miso_select_input_t ECSPI2_MISO_SELECT_INPUT; /*!< [0x538] ECSPI2_MISO_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ecspi2_mosi_select_input_t ECSPI2_MOSI_SELECT_INPUT; /*!< [0x53C] ECSPI2_MOSI_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ecspi2_ss0_b_select_input_t ECSPI2_SS0_B_SELECT_INPUT; /*!< [0x540] ECSPI2_SS0_B_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ecspi3_sclk_select_input_t ECSPI3_SCLK_SELECT_INPUT; /*!< [0x544] ECSPI3_SCLK_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ecspi3_miso_select_input_t ECSPI3_MISO_SELECT_INPUT; /*!< [0x548] ECSPI3_MISO_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ecspi3_mosi_select_input_t ECSPI3_MOSI_SELECT_INPUT; /*!< [0x54C] ECSPI3_MOSI_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ecspi3_ss0_b_select_input_t ECSPI3_SS0_B_SELECT_INPUT; /*!< [0x550] ECSPI3_SS0_B_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ecspi4_sclk_select_input_t ECSPI4_SCLK_SELECT_INPUT; /*!< [0x554] ECSPI4_SCLK_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ecspi4_miso_select_input_t ECSPI4_MISO_SELECT_INPUT; /*!< [0x558] ECSPI4_MISO_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ecspi4_mosi_select_input_t ECSPI4_MOSI_SELECT_INPUT; /*!< [0x55C] ECSPI4_MOSI_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ecspi4_ss0_b_select_input_t ECSPI4_SS0_B_SELECT_INPUT; /*!< [0x560] ECSPI4_SS0_B_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ccm_enet1_ref_clk_select_input_t CCM_ENET1_REF_CLK_SELECT_INPUT; /*!< [0x564] CCM_ENET1_REF_CLK_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_enet1_mdio_select_input_t ENET1_MDIO_SELECT_INPUT; /*!< [0x568] ENET1_MDIO_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_enet1_rx_clk_select_input_t ENET1_RX_CLK_SELECT_INPUT; /*!< [0x56C] ENET1_RX_CLK_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_ccm_enet2_ref_clk_select_input_t CCM_ENET2_REF_CLK_SELECT_INPUT; /*!< [0x570] CCM_ENET2_REF_CLK_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_enet2_mdio_select_input_t ENET2_MDIO_SELECT_INPUT; /*!< [0x574] ENET2_MDIO_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_enet2_rx_clk_select_input_t ENET2_RX_CLK_SELECT_INPUT; /*!< [0x578] ENET2_RX_CLK_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_epdc_pwr_irq_select_input_t EPDC_PWR_IRQ_SELECT_INPUT; /*!< [0x57C] EPDC_PWR_IRQ_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_epdc_pwr_stat_select_input_t EPDC_PWR_STAT_SELECT_INPUT; /*!< [0x580] EPDC_PWR_STAT_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer1_ch0_select_input_t FLEXTIMER1_CH0_SELECT_INPUT; /*!< [0x584] FLEXTIMER1_CH0_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer1_ch1_select_input_t FLEXTIMER1_CH1_SELECT_INPUT; /*!< [0x588] FLEXTIMER1_CH1_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer1_ch2_select_input_t FLEXTIMER1_CH2_SELECT_INPUT; /*!< [0x58C] FLEXTIMER1_CH2_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer1_ch3_select_input_t FLEXTIMER1_CH3_SELECT_INPUT; /*!< [0x590] FLEXTIMER1_CH3_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer1_ch4_select_input_t FLEXTIMER1_CH4_SELECT_INPUT; /*!< [0x594] FLEXTIMER1_CH4_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer1_ch5_select_input_t FLEXTIMER1_CH5_SELECT_INPUT; /*!< [0x598] FLEXTIMER1_CH5_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer1_ch6_select_input_t FLEXTIMER1_CH6_SELECT_INPUT; /*!< [0x59C] FLEXTIMER1_CH6_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer1_ch7_select_input_t FLEXTIMER1_CH7_SELECT_INPUT; /*!< [0x5A0] FLEXTIMER1_CH7_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer1_pha_select_input_t FLEXTIMER1_PHA_SELECT_INPUT; /*!< [0x5A4] FLEXTIMER1_PHA_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer1_phb_select_input_t FLEXTIMER1_PHB_SELECT_INPUT; /*!< [0x5A8] FLEXTIMER1_PHB_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer2_ch0_select_input_t FLEXTIMER2_CH0_SELECT_INPUT; /*!< [0x5AC] FLEXTIMER2_CH0_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer2_ch1_select_input_t FLEXTIMER2_CH1_SELECT_INPUT; /*!< [0x5B0] FLEXTIMER2_CH1_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer2_ch2_select_input_t FLEXTIMER2_CH2_SELECT_INPUT; /*!< [0x5B4] FLEXTIMER2_CH2_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer2_ch3_select_input_t FLEXTIMER2_CH3_SELECT_INPUT; /*!< [0x5B8] FLEXTIMER2_CH3_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer2_ch4_select_input_t FLEXTIMER2_CH4_SELECT_INPUT; /*!< [0x5BC] FLEXTIMER2_CH4_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer2_ch5_select_input_t FLEXTIMER2_CH5_SELECT_INPUT; /*!< [0x5C0] FLEXTIMER2_CH5_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer2_ch6_select_input_t FLEXTIMER2_CH6_SELECT_INPUT; /*!< [0x5C4] FLEXTIMER2_CH6_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer2_ch7_select_input_t FLEXTIMER2_CH7_SELECT_INPUT; /*!< [0x5C8] FLEXTIMER2_CH7_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer2_pha_select_input_t FLEXTIMER2_PHA_SELECT_INPUT; /*!< [0x5CC] FLEXTIMER2_PHA_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_flextimer2_phb_select_input_t FLEXTIMER2_PHB_SELECT_INPUT; /*!< [0x5D0] FLEXTIMER2_PHB_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_i2c1_scl_select_input_t I2C1_SCL_SELECT_INPUT; /*!< [0x5D4] I2C1_SCL_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_i2c1_sda_select_input_t I2C1_SDA_SELECT_INPUT; /*!< [0x5D8] I2C1_SDA_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_i2c2_scl_select_input_t I2C2_SCL_SELECT_INPUT; /*!< [0x5DC] I2C2_SCL_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_i2c2_sda_select_input_t I2C2_SDA_SELECT_INPUT; /*!< [0x5E0] I2C2_SDA_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_i2c3_scl_select_input_t I2C3_SCL_SELECT_INPUT; /*!< [0x5E4] I2C3_SCL_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_i2c3_sda_select_input_t I2C3_SDA_SELECT_INPUT; /*!< [0x5E8] I2C3_SDA_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_i2c4_scl_select_input_t I2C4_SCL_SELECT_INPUT; /*!< [0x5EC] I2C4_SCL_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_i2c4_sda_select_input_t I2C4_SDA_SELECT_INPUT; /*!< [0x5F0] I2C4_SDA_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_kpp_col0_select_input_t KPP_COL0_SELECT_INPUT; /*!< [0x5F4] KPP_COL0_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_kpp_col1_select_input_t KPP_COL1_SELECT_INPUT; /*!< [0x5F8] KPP_COL1_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_kpp_col2_select_input_t KPP_COL2_SELECT_INPUT; /*!< [0x5FC] KPP_COL2_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_kpp_col3_select_input_t KPP_COL3_SELECT_INPUT; /*!< [0x600] KPP_COL3_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_kpp_col4_select_input_t KPP_COL4_SELECT_INPUT; /*!< [0x604] KPP_COL4_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_kpp_col5_select_input_t KPP_COL5_SELECT_INPUT; /*!< [0x608] KPP_COL5_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_kpp_col6_select_input_t KPP_COL6_SELECT_INPUT; /*!< [0x60C] KPP_COL6_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_kpp_col7_select_input_t KPP_COL7_SELECT_INPUT; /*!< [0x610] KPP_COL7_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_kpp_row0_select_input_t KPP_ROW0_SELECT_INPUT; /*!< [0x614] KPP_ROW0_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_kpp_row1_select_input_t KPP_ROW1_SELECT_INPUT; /*!< [0x618] KPP_ROW1_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_kpp_row2_select_input_t KPP_ROW2_SELECT_INPUT; /*!< [0x61C] KPP_ROW2_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_kpp_row3_select_input_t KPP_ROW3_SELECT_INPUT; /*!< [0x620] KPP_ROW3_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_kpp_row4_select_input_t KPP_ROW4_SELECT_INPUT; /*!< [0x624] KPP_ROW4_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_kpp_row5_select_input_t KPP_ROW5_SELECT_INPUT; /*!< [0x628] KPP_ROW5_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_kpp_row6_select_input_t KPP_ROW6_SELECT_INPUT; /*!< [0x62C] KPP_ROW6_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_kpp_row7_select_input_t KPP_ROW7_SELECT_INPUT; /*!< [0x630] KPP_ROW7_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_busy_select_input_t LCD_BUSY_SELECT_INPUT; /*!< [0x634] LCD_BUSY_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data00_select_input_t LCD_DATA00_SELECT_INPUT; /*!< [0x638] LCD_DATA00_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data01_select_input_t LCD_DATA01_SELECT_INPUT; /*!< [0x63C] LCD_DATA01_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data02_select_input_t LCD_DATA02_SELECT_INPUT; /*!< [0x640] LCD_DATA02_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data03_select_input_t LCD_DATA03_SELECT_INPUT; /*!< [0x644] LCD_DATA03_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data04_select_input_t LCD_DATA04_SELECT_INPUT; /*!< [0x648] LCD_DATA04_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data05_select_input_t LCD_DATA05_SELECT_INPUT; /*!< [0x64C] LCD_DATA05_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data06_select_input_t LCD_DATA06_SELECT_INPUT; /*!< [0x650] LCD_DATA06_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data07_select_input_t LCD_DATA07_SELECT_INPUT; /*!< [0x654] LCD_DATA07_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data08_select_input_t LCD_DATA08_SELECT_INPUT; /*!< [0x658] LCD_DATA08_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data09_select_input_t LCD_DATA09_SELECT_INPUT; /*!< [0x65C] LCD_DATA09_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data10_select_input_t LCD_DATA10_SELECT_INPUT; /*!< [0x660] LCD_DATA10_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data11_select_input_t LCD_DATA11_SELECT_INPUT; /*!< [0x664] LCD_DATA11_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data12_select_input_t LCD_DATA12_SELECT_INPUT; /*!< [0x668] LCD_DATA12_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data13_select_input_t LCD_DATA13_SELECT_INPUT; /*!< [0x66C] LCD_DATA13_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data14_select_input_t LCD_DATA14_SELECT_INPUT; /*!< [0x670] LCD_DATA14_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data15_select_input_t LCD_DATA15_SELECT_INPUT; /*!< [0x674] LCD_DATA15_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data16_select_input_t LCD_DATA16_SELECT_INPUT; /*!< [0x678] LCD_DATA16_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data17_select_input_t LCD_DATA17_SELECT_INPUT; /*!< [0x67C] LCD_DATA17_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data18_select_input_t LCD_DATA18_SELECT_INPUT; /*!< [0x680] LCD_DATA18_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data19_select_input_t LCD_DATA19_SELECT_INPUT; /*!< [0x684] LCD_DATA19_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data20_select_input_t LCD_DATA20_SELECT_INPUT; /*!< [0x688] LCD_DATA20_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data21_select_input_t LCD_DATA21_SELECT_INPUT; /*!< [0x68C] LCD_DATA21_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data22_select_input_t LCD_DATA22_SELECT_INPUT; /*!< [0x690] LCD_DATA22_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_data23_select_input_t LCD_DATA23_SELECT_INPUT; /*!< [0x694] LCD_DATA23_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_lcd_vsync_select_input_t LCD_VSYNC_SELECT_INPUT; /*!< [0x698] LCD_VSYNC_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sai1_rx_bclk_select_input_t SAI1_RX_BCLK_SELECT_INPUT; /*!< [0x69C] SAI1_RX_BCLK_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sai1_rx_data_select_input_t SAI1_RX_DATA_SELECT_INPUT; /*!< [0x6A0] SAI1_RX_DATA_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sai1_rx_sync_select_input_t SAI1_RX_SYNC_SELECT_INPUT; /*!< [0x6A4] SAI1_RX_SYNC_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sai1_tx_bclk_select_input_t SAI1_TX_BCLK_SELECT_INPUT; /*!< [0x6A8] SAI1_TX_BCLK_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sai1_tx_sync_select_input_t SAI1_TX_SYNC_SELECT_INPUT; /*!< [0x6AC] SAI1_TX_SYNC_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sai2_rx_bclk_select_input_t SAI2_RX_BCLK_SELECT_INPUT; /*!< [0x6B0] SAI2_RX_BCLK_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sai2_rx_data_select_input_t SAI2_RX_DATA_SELECT_INPUT; /*!< [0x6B4] SAI2_RX_DATA_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sai2_rx_sync_select_input_t SAI2_RX_SYNC_SELECT_INPUT; /*!< [0x6B8] SAI2_RX_SYNC_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sai2_tx_bclk_select_input_t SAI2_TX_BCLK_SELECT_INPUT; /*!< [0x6BC] SAI2_TX_BCLK_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sai2_tx_sync_select_input_t SAI2_TX_SYNC_SELECT_INPUT; /*!< [0x6C0] SAI2_TX_SYNC_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sai3_rx_bclk_select_input_t SAI3_RX_BCLK_SELECT_INPUT; /*!< [0x6C4] SAI3_RX_BCLK_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sai3_rx_data_select_input_t SAI3_RX_DATA_SELECT_INPUT; /*!< [0x6C8] SAI3_RX_DATA_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sai3_rx_sync_select_input_t SAI3_RX_SYNC_SELECT_INPUT; /*!< [0x6CC] SAI3_RX_SYNC_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sai3_tx_bclk_select_input_t SAI3_TX_BCLK_SELECT_INPUT; /*!< [0x6D0] SAI3_TX_BCLK_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sai3_tx_sync_select_input_t SAI3_TX_SYNC_SELECT_INPUT; /*!< [0x6D4] SAI3_TX_SYNC_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sdma_events0_select_input_t SDMA_EVENTS0_SELECT_INPUT; /*!< [0x6D8] SDMA_EVENTS0_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sdma_events1_select_input_t SDMA_EVENTS1_SELECT_INPUT; /*!< [0x6DC] SDMA_EVENTS1_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sim1_port1_pd_select_input_t SIM1_PORT1_PD_SELECT_INPUT; /*!< [0x6E0] SIM1_PORT1_PD_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sim1_port1_trxd_select_input_t SIM1_PORT1_TRXD_SELECT_INPUT; /*!< [0x6E4] SIM1_PORT1_TRXD_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sim2_port1_pd_select_input_t SIM2_PORT1_PD_SELECT_INPUT; /*!< [0x6E8] SIM2_PORT1_PD_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sim2_port1_trxd_select_input_t SIM2_PORT1_TRXD_SELECT_INPUT; /*!< [0x6EC] SIM2_PORT1_TRXD_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_uart1_rts_b_select_input_t UART1_RTS_B_SELECT_INPUT; /*!< [0x6F0] UART1_RTS_B_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_uart1_rx_data_select_input_t UART1_RX_DATA_SELECT_INPUT; /*!< [0x6F4] UART1_RX_DATA_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_uart2_rts_b_select_input_t UART2_RTS_B_SELECT_INPUT; /*!< [0x6F8] UART2_RTS_B_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_uart2_rx_data_select_input_t UART2_RX_DATA_SELECT_INPUT; /*!< [0x6FC] UART2_RX_DATA_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_uart3_rts_b_select_input_t UART3_RTS_B_SELECT_INPUT; /*!< [0x700] UART3_RTS_B_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_uart3_rx_data_select_input_t UART3_RX_DATA_SELECT_INPUT; /*!< [0x704] UART3_RX_DATA_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_uart4_rts_b_select_input_t UART4_RTS_B_SELECT_INPUT; /*!< [0x708] UART4_RTS_B_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_uart4_rx_data_select_input_t UART4_RX_DATA_SELECT_INPUT; /*!< [0x70C] UART4_RX_DATA_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_uart5_rts_b_select_input_t UART5_RTS_B_SELECT_INPUT; /*!< [0x710] UART5_RTS_B_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_uart5_rx_data_select_input_t UART5_RX_DATA_SELECT_INPUT; /*!< [0x714] UART5_RX_DATA_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_uart6_rts_b_select_input_t UART6_RTS_B_SELECT_INPUT; /*!< [0x718] UART6_RTS_B_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_uart6_rx_data_select_input_t UART6_RX_DATA_SELECT_INPUT; /*!< [0x71C] UART6_RX_DATA_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_uart7_rts_b_select_input_t UART7_RTS_B_SELECT_INPUT; /*!< [0x720] UART7_RTS_B_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_uart7_rx_data_select_input_t UART7_RX_DATA_SELECT_INPUT; /*!< [0x724] UART7_RX_DATA_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_usb_otg2_oc_select_input_t USB_OTG2_OC_SELECT_INPUT; /*!< [0x728] USB_OTG2_OC_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_usb_otg1_oc_select_input_t USB_OTG1_OC_SELECT_INPUT; /*!< [0x72C] USB_OTG1_OC_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_usb_otg2_id_select_input_t USB_OTG2_ID_SELECT_INPUT; /*!< [0x730] USB_OTG2_ID_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_usb_otg1_id_select_input_t USB_OTG1_ID_SELECT_INPUT; /*!< [0x734] USB_OTG1_ID_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sd3_cd_b_select_input_t SD3_CD_B_SELECT_INPUT; /*!< [0x738] SD3_CD_B_SELECT_INPUT DAISY Register */
    __IO hw_iomuxc_sd3_wp_select_input_t SD3_WP_SELECT_INPUT; /*!< [0x73C] SD3_WP_SELECT_INPUT DAISY Register */
} hw_iomuxc_t;
#pragma pack()

/*! @brief Macro to access all IOMUXC registers. */
/*! @param x IOMUXC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_IOMUXC_REGS(IOMUXC_BASE)</code>. */
#define HW_IOMUXC_REGS(x) (*(hw_iomuxc_t *)(x))

/*
 * iMX7D IOMUXC_GPR
 *
 * IOMUXC_GPR
 *
 * Registers defined in this header file:
 * - HW_IOMUXC_GPR_GPR0 - GPR0 General Purpose Register
 * - HW_IOMUXC_GPR_GPR1 - GPR1 General Purpose Register
 * - HW_IOMUXC_GPR_GPR2 - GPR2 General Purpose Register
 * - HW_IOMUXC_GPR_GPR3 - GPR3 General Purpose Register
 * - HW_IOMUXC_GPR_GPR4 - GPR4 General Purpose Register
 * - HW_IOMUXC_GPR_GPR5 - GPR5 General Purpose Register
 * - HW_IOMUXC_GPR_GPR6 - GPR6 General Purpose Register
 * - HW_IOMUXC_GPR_GPR7 - GPR7 General Purpose Register
 * - HW_IOMUXC_GPR_GPR8 - GPR8 General Purpose Register
 * - HW_IOMUXC_GPR_GPR9 - GPR9 General Purpose Register
 * - HW_IOMUXC_GPR_GPR10 - GPR10 General Purpose Register
 * - HW_IOMUXC_GPR_GPR11 - GPR11 General Purpose Register
 * - HW_IOMUXC_GPR_GPR12 - GPR12 General Purpose Register
 * - HW_IOMUXC_GPR_GPR13 - GPR13 General Purpose Register
 * - HW_IOMUXC_GPR_GPR14 - GPR14 General Purpose Register
 * - HW_IOMUXC_GPR_GPR15 - GPR15 General Purpose Register
 * - HW_IOMUXC_GPR_GPR16 - GPR16 General Purpose Register
 * - HW_IOMUXC_GPR_GPR17 - GPR17 General Purpose Register
 * - HW_IOMUXC_GPR_GPR18 - GPR18 General Purpose Register
 * - HW_IOMUXC_GPR_GPR19 - GPR19 General Purpose Register
 * - HW_IOMUXC_GPR_GPR20 - GPR20 General Purpose Register
 * - HW_IOMUXC_GPR_GPR21 - GPR21 General Purpose Register
 * - HW_IOMUXC_GPR_GPR22 - GPR22 General Purpose Register
 *
 * - hw_iomuxc_gpr_t - Struct containing all module registers.
 */

#define HW_IOMUXC_GPR_INSTANCE_COUNT (1U) /*!< Number of instances of the IOMUXC_GPR module. */
#define HW_IOMUXC_GPR (0U) /*!< Instance number for IOMUXC_GPR. */
#define IOMUXC_GPR_BASE       (0x30340000U) /*!< Base address for IOMUXC_GPR. */
/*! Array initializer of IOMUXC_GPR base addresses. */
#define IOMUXC_GPR_BASE_ADDRS { IOMUXC_GPR_BASE }

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR0 - GPR0 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR0 - GPR0 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr0
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr0_bitfields
    {
        uint32_t DMAREQ_MUX_SEL0 : 1;  /*!< [0]  */
        uint32_t DMAREQ_MUX_SEL1 : 1;  /*!< [1]  */
        uint32_t DMAREQ_MUX_SEL2 : 1;  /*!< [2]  */
        uint32_t DMAREQ_MUX_SEL3 : 1;  /*!< [3]  */
        uint32_t DMAREQ_MUX_SEL4 : 1;  /*!< [4]  */
        uint32_t DMAREQ_MUX_SEL5 : 1;  /*!< [5]  */
        uint32_t DMAREQ_MUX_SEL6 : 1;  /*!< [6]  */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_gpr_gpr0_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR0 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR0_ADDR(x) ((uintptr_t)(x) + 0x0U)

#define HW_IOMUXC_GPR_GPR0(x)    (*(__IO hw_iomuxc_gpr_gpr0_t *) HW_IOMUXC_GPR_GPR0_ADDR(x))
#define HW_IOMUXC_GPR_GPR0_RD(x) (HW_IOMUXC_GPR_GPR0(x).U)
#define HW_IOMUXC_GPR_GPR0_WR(x, v) (HW_IOMUXC_GPR_GPR0(x).U = (v))
#define HW_IOMUXC_GPR_GPR0_SET(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, HW_IOMUXC_GPR_GPR0_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR0_CLR(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, HW_IOMUXC_GPR_GPR0_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR0_TOG(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, HW_IOMUXC_GPR_GPR0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR0 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL0[0] (RW)
 *
 * Selects between two possible sources for SDMA_EVENT18
 *
 * Values:
 * - 0 - I2C1 DMA event
 * - 1 - SIM1 receive DMA request
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0 (0U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0 (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL0)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0)

/*! @brief Set the DMAREQ_MUX_SEL0 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL0(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL1[1] (RW)
 *
 * Selects between two possible sources for SDMA_EVENT19
 *
 * Values:
 * - 0 - I2C2 DMA event
 * - 1 - SIM1 transmit DMA request
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1 (1U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1 (0x00000002U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL1)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1)

/*! @brief Set the DMAREQ_MUX_SEL1 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL1(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL2[2] (RW)
 *
 * Selects between two possible sources for SDMA_EVENT20
 *
 * Values:
 * - 0 - I2C3 DMA event
 * - 1 - SIM1 receive DMA request
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2 (2U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2 (0x00000004U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL2)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2)

/*! @brief Set the DMAREQ_MUX_SEL2 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL2(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL3[3] (RW)
 *
 * Selects between two possible sources for SDMA_EVENT21
 *
 * Values:
 * - 0 - I2C4 DMA event
 * - 1 - SIM2 transmit DMA request
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3 (3U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3 (0x00000008U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL3)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3)

/*! @brief Set the DMAREQ_MUX_SEL3 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL3(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL4[4] (RW)
 *
 * Selects between two possible sources for SDMA_EVENT47
 *
 * Values:
 * - 0 - ENET1 1588 Event1 out
 * - 1 - ENET2 1588 Event1 out
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4 (4U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4 (0x00000010U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL4)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4)

/*! @brief Set the DMAREQ_MUX_SEL4 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL4(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL5[5] (RW)
 *
 * Selects between two possible sources for SDMA_EVENT40
 *
 * Values:
 * - 0 - GPT3 counter event
 * - 1 - FTM1 7 channel DMA request
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5 (5U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5 (0x00000020U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL5)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5)

/*! @brief Set the DMAREQ_MUX_SEL5 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL5(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR0, field DMAREQ_MUX_SEL6[6] (RW)
 *
 * Selects between two possible sources for SDMA_EVENT41
 *
 * Values:
 * - 0 - GPT4 counter event
 * - 1 - FTM2 8 channel DMA request
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6 (6U) /*!< Bit position for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6. */
#define BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6 (0x00000040U) /*!< Bit mask for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6. */
#define BS_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6. */

/*! @brief Read current value of the IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6 field. */
#define BR_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6(x) (HW_IOMUXC_GPR_GPR0(x).B.DMAREQ_MUX_SEL6)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6. */
#define BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6) & BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6)

/*! @brief Set the DMAREQ_MUX_SEL6 field to a new value. */
#define BW_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6(x, v) (HW_IOMUXC_GPR_GPR0_WR(x, (HW_IOMUXC_GPR_GPR0_RD(x) & ~BM_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6) | BF_IOMUXC_GPR_GPR0_DMAREQ_MUX_SEL6(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR1 - GPR1 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR1 - GPR1 General Purpose Register (RW)
 *
 * Reset value: 0x0F400005U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr1
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr1_bitfields
    {
        uint32_t WEIM_ACT_CS0 : 1;     /*!< [0]  */
        uint32_t WEIM_ADDRS0 : 2;      /*!< [2:1]  */
        uint32_t WEIM_ACT_CS1 : 1;     /*!< [3]  */
        uint32_t WEIM_ADDRS1 : 2;      /*!< [5:4]  */
        uint32_t WEIM_ACT_CS2 : 1;     /*!< [6]  */
        uint32_t WEIM_ADDRS2 : 2;      /*!< [8:7]  */
        uint32_t WEIM_ACT_CS3 : 1;     /*!< [9]  */
        uint32_t WEIM_ADDRS3 : 2;      /*!< [11:10]  */
        uint32_t IRQ : 1;              /*!< [12]  */
        uint32_t ENET1_TX_CLK_SEL : 1; /*!< [13]  */
        uint32_t ENET2_TX_CLK_SEL : 1; /*!< [14]  */
        uint32_t RESERVED0 : 1;        /*!< [15]  */
        uint32_t PAD_ADD_DS : 1;       /*!< [16]  */
        uint32_t ENET1_CLK_DIR : 1;    /*!< [17]  */
        uint32_t ENET2_CLK_DIR : 1;    /*!< [18]  */
        uint32_t RESERVED1 : 3;        /*!< [21:19]  */
        uint32_t EXC_ERR_RESP_EN : 1;  /*!< [22]  */
        uint32_t TZASC1_SECURE_BOOT_LOCK : 1; /*!< [23]  */
        uint32_t RESERVED2 : 4;        /*!< [27:24]  */
        uint32_t DBG_ACK : 2;          /*!< [29:28]  */
        uint32_t ENABLE_OCRAM_EPDC : 1; /*!< [30]  */
        uint32_t RESERVED3 : 1;        /*!< [31]  */
    } B;
} hw_iomuxc_gpr_gpr1_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR1 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR1_ADDR(x) ((uintptr_t)(x) + 0x4U)

#define HW_IOMUXC_GPR_GPR1(x)    (*(__IO hw_iomuxc_gpr_gpr1_t *) HW_IOMUXC_GPR_GPR1_ADDR(x))
#define HW_IOMUXC_GPR_GPR1_RD(x) (HW_IOMUXC_GPR_GPR1(x).U)
#define HW_IOMUXC_GPR_GPR1_WR(x, v) (HW_IOMUXC_GPR_GPR1(x).U = (v))
#define HW_IOMUXC_GPR_GPR1_SET(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, HW_IOMUXC_GPR_GPR1_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR1_CLR(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, HW_IOMUXC_GPR_GPR1_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR1_TOG(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, HW_IOMUXC_GPR_GPR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR1 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR1, field WEIM_ACT_CS0[0] (RW)
 *
 * WEIM Active Chip Select 0 See description for WEIM_ADDRS3
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_WEIM_ACT_CS0 (0U) /*!< Bit position for IOMUXC_GPR_GPR1_WEIM_ACT_CS0. */
#define BM_IOMUXC_GPR_GPR1_WEIM_ACT_CS0 (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR1_WEIM_ACT_CS0. */
#define BS_IOMUXC_GPR_GPR1_WEIM_ACT_CS0 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_WEIM_ACT_CS0. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_WEIM_ACT_CS0 field. */
#define BR_IOMUXC_GPR_GPR1_WEIM_ACT_CS0(x) (HW_IOMUXC_GPR_GPR1(x).B.WEIM_ACT_CS0)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_WEIM_ACT_CS0. */
#define BF_IOMUXC_GPR_GPR1_WEIM_ACT_CS0(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_WEIM_ACT_CS0) & BM_IOMUXC_GPR_GPR1_WEIM_ACT_CS0)

/*! @brief Set the WEIM_ACT_CS0 field to a new value. */
#define BW_IOMUXC_GPR_GPR1_WEIM_ACT_CS0(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_WEIM_ACT_CS0) | BF_IOMUXC_GPR_GPR1_WEIM_ACT_CS0(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field WEIM_ADDRS0[2:1] (RW)
 *
 * WEIM Address Space 0 See description for WEIM_ADDRS3
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_WEIM_ADDRS0 (1U) /*!< Bit position for IOMUXC_GPR_GPR1_WEIM_ADDRS0. */
#define BM_IOMUXC_GPR_GPR1_WEIM_ADDRS0 (0x00000006U) /*!< Bit mask for IOMUXC_GPR_GPR1_WEIM_ADDRS0. */
#define BS_IOMUXC_GPR_GPR1_WEIM_ADDRS0 (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_WEIM_ADDRS0. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_WEIM_ADDRS0 field. */
#define BR_IOMUXC_GPR_GPR1_WEIM_ADDRS0(x) (HW_IOMUXC_GPR_GPR1(x).B.WEIM_ADDRS0)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_WEIM_ADDRS0. */
#define BF_IOMUXC_GPR_GPR1_WEIM_ADDRS0(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_WEIM_ADDRS0) & BM_IOMUXC_GPR_GPR1_WEIM_ADDRS0)

/*! @brief Set the WEIM_ADDRS0 field to a new value. */
#define BW_IOMUXC_GPR_GPR1_WEIM_ADDRS0(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_WEIM_ADDRS0) | BF_IOMUXC_GPR_GPR1_WEIM_ADDRS0(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field WEIM_ACT_CS1[3] (RW)
 *
 * WEIM Active Chip Select 1 See description for WEIM_ADDRS3
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_WEIM_ACT_CS1 (3U) /*!< Bit position for IOMUXC_GPR_GPR1_WEIM_ACT_CS1. */
#define BM_IOMUXC_GPR_GPR1_WEIM_ACT_CS1 (0x00000008U) /*!< Bit mask for IOMUXC_GPR_GPR1_WEIM_ACT_CS1. */
#define BS_IOMUXC_GPR_GPR1_WEIM_ACT_CS1 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_WEIM_ACT_CS1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_WEIM_ACT_CS1 field. */
#define BR_IOMUXC_GPR_GPR1_WEIM_ACT_CS1(x) (HW_IOMUXC_GPR_GPR1(x).B.WEIM_ACT_CS1)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_WEIM_ACT_CS1. */
#define BF_IOMUXC_GPR_GPR1_WEIM_ACT_CS1(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_WEIM_ACT_CS1) & BM_IOMUXC_GPR_GPR1_WEIM_ACT_CS1)

/*! @brief Set the WEIM_ACT_CS1 field to a new value. */
#define BW_IOMUXC_GPR_GPR1_WEIM_ACT_CS1(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_WEIM_ACT_CS1) | BF_IOMUXC_GPR_GPR1_WEIM_ACT_CS1(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field WEIM_ADDRS1[5:4] (RW)
 *
 * WEIM Address Space 1 See description for WEIM_ADDRS3
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_WEIM_ADDRS1 (4U) /*!< Bit position for IOMUXC_GPR_GPR1_WEIM_ADDRS1. */
#define BM_IOMUXC_GPR_GPR1_WEIM_ADDRS1 (0x00000030U) /*!< Bit mask for IOMUXC_GPR_GPR1_WEIM_ADDRS1. */
#define BS_IOMUXC_GPR_GPR1_WEIM_ADDRS1 (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_WEIM_ADDRS1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_WEIM_ADDRS1 field. */
#define BR_IOMUXC_GPR_GPR1_WEIM_ADDRS1(x) (HW_IOMUXC_GPR_GPR1(x).B.WEIM_ADDRS1)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_WEIM_ADDRS1. */
#define BF_IOMUXC_GPR_GPR1_WEIM_ADDRS1(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_WEIM_ADDRS1) & BM_IOMUXC_GPR_GPR1_WEIM_ADDRS1)

/*! @brief Set the WEIM_ADDRS1 field to a new value. */
#define BW_IOMUXC_GPR_GPR1_WEIM_ADDRS1(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_WEIM_ADDRS1) | BF_IOMUXC_GPR_GPR1_WEIM_ADDRS1(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field WEIM_ACT_CS2[6] (RW)
 *
 * WEIM Active Chip Select 2 See description for WEIM_ADDRS3
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_WEIM_ACT_CS2 (6U) /*!< Bit position for IOMUXC_GPR_GPR1_WEIM_ACT_CS2. */
#define BM_IOMUXC_GPR_GPR1_WEIM_ACT_CS2 (0x00000040U) /*!< Bit mask for IOMUXC_GPR_GPR1_WEIM_ACT_CS2. */
#define BS_IOMUXC_GPR_GPR1_WEIM_ACT_CS2 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_WEIM_ACT_CS2. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_WEIM_ACT_CS2 field. */
#define BR_IOMUXC_GPR_GPR1_WEIM_ACT_CS2(x) (HW_IOMUXC_GPR_GPR1(x).B.WEIM_ACT_CS2)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_WEIM_ACT_CS2. */
#define BF_IOMUXC_GPR_GPR1_WEIM_ACT_CS2(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_WEIM_ACT_CS2) & BM_IOMUXC_GPR_GPR1_WEIM_ACT_CS2)

/*! @brief Set the WEIM_ACT_CS2 field to a new value. */
#define BW_IOMUXC_GPR_GPR1_WEIM_ACT_CS2(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_WEIM_ACT_CS2) | BF_IOMUXC_GPR_GPR1_WEIM_ACT_CS2(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field WEIM_ADDRS2[8:7] (RW)
 *
 * WEIM Address Space 2 See description for WEIM_ADDRS3
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_WEIM_ADDRS2 (7U) /*!< Bit position for IOMUXC_GPR_GPR1_WEIM_ADDRS2. */
#define BM_IOMUXC_GPR_GPR1_WEIM_ADDRS2 (0x00000180U) /*!< Bit mask for IOMUXC_GPR_GPR1_WEIM_ADDRS2. */
#define BS_IOMUXC_GPR_GPR1_WEIM_ADDRS2 (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_WEIM_ADDRS2. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_WEIM_ADDRS2 field. */
#define BR_IOMUXC_GPR_GPR1_WEIM_ADDRS2(x) (HW_IOMUXC_GPR_GPR1(x).B.WEIM_ADDRS2)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_WEIM_ADDRS2. */
#define BF_IOMUXC_GPR_GPR1_WEIM_ADDRS2(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_WEIM_ADDRS2) & BM_IOMUXC_GPR_GPR1_WEIM_ADDRS2)

/*! @brief Set the WEIM_ADDRS2 field to a new value. */
#define BW_IOMUXC_GPR_GPR1_WEIM_ADDRS2(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_WEIM_ADDRS2) | BF_IOMUXC_GPR_GPR1_WEIM_ADDRS2(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field WEIM_ACT_CS3[9] (RW)
 *
 * WEIM Active Chip Select 3 See description for WEIM_ADDRS3
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_WEIM_ACT_CS3 (9U) /*!< Bit position for IOMUXC_GPR_GPR1_WEIM_ACT_CS3. */
#define BM_IOMUXC_GPR_GPR1_WEIM_ACT_CS3 (0x00000200U) /*!< Bit mask for IOMUXC_GPR_GPR1_WEIM_ACT_CS3. */
#define BS_IOMUXC_GPR_GPR1_WEIM_ACT_CS3 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_WEIM_ACT_CS3. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_WEIM_ACT_CS3 field. */
#define BR_IOMUXC_GPR_GPR1_WEIM_ACT_CS3(x) (HW_IOMUXC_GPR_GPR1(x).B.WEIM_ACT_CS3)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_WEIM_ACT_CS3. */
#define BF_IOMUXC_GPR_GPR1_WEIM_ACT_CS3(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_WEIM_ACT_CS3) & BM_IOMUXC_GPR_GPR1_WEIM_ACT_CS3)

/*! @brief Set the WEIM_ACT_CS3 field to a new value. */
#define BW_IOMUXC_GPR_GPR1_WEIM_ACT_CS3(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_WEIM_ACT_CS3) | BF_IOMUXC_GPR_GPR1_WEIM_ACT_CS3(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field WEIM_ADDRS3[11:10] (RW)
 *
 * WEIM Address Space 3 Active Chip Select and Address Space. Each of the
 * WEIM_ACT_CSx represents one of the four chip selects of the EIM. When ACT_CSx=1'b1,
 * the corresponding chip select is active and has a valid address space
 * according to its address space configuration determined by WEIM_ADDRSx[1:0] bits.
 * WEIM_ADDRSx[1:0] is setting the space for each chip select which is active. The
 * address space of the first active chip select must be the biggest one, the
 * following active chip select address spaces may be equal or lower. Total address
 * space size is 128 MByte. The supported configurations are: CS0(128M), CS1 (0M),
 * CS2 (0M), CS3(0M) [default configuration] CS0(64M), CS1(64M), CS2(0M), CS3(0M)
 * CS0(64M), CS1(32M), CS2(32M), CS3(0M) CS0(32M), CS1(32M), CS2(32M), CS3(32M)
 * Address Space Configuration options (WEIM_ADDRSx[10]):
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_WEIM_ADDRS3 (10U) /*!< Bit position for IOMUXC_GPR_GPR1_WEIM_ADDRS3. */
#define BM_IOMUXC_GPR_GPR1_WEIM_ADDRS3 (0x00000C00U) /*!< Bit mask for IOMUXC_GPR_GPR1_WEIM_ADDRS3. */
#define BS_IOMUXC_GPR_GPR1_WEIM_ADDRS3 (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_WEIM_ADDRS3. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_WEIM_ADDRS3 field. */
#define BR_IOMUXC_GPR_GPR1_WEIM_ADDRS3(x) (HW_IOMUXC_GPR_GPR1(x).B.WEIM_ADDRS3)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_WEIM_ADDRS3. */
#define BF_IOMUXC_GPR_GPR1_WEIM_ADDRS3(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_WEIM_ADDRS3) & BM_IOMUXC_GPR_GPR1_WEIM_ADDRS3)

/*! @brief Set the WEIM_ADDRS3 field to a new value. */
#define BW_IOMUXC_GPR_GPR1_WEIM_ADDRS3(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_WEIM_ADDRS3) | BF_IOMUXC_GPR_GPR1_WEIM_ADDRS3(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field IRQ[12] (RW)
 *
 * Interrupt signal which is connected to CPU IRQS[0]. Used to notify cores on
 * exception condition while boot.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_IRQ (12U)       /*!< Bit position for IOMUXC_GPR_GPR1_IRQ. */
#define BM_IOMUXC_GPR_GPR1_IRQ (0x00001000U) /*!< Bit mask for IOMUXC_GPR_GPR1_IRQ. */
#define BS_IOMUXC_GPR_GPR1_IRQ (1U)        /*!< Bit field size in bits for IOMUXC_GPR_GPR1_IRQ. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_IRQ field. */
#define BR_IOMUXC_GPR_GPR1_IRQ(x) (HW_IOMUXC_GPR_GPR1(x).B.IRQ)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_IRQ. */
#define BF_IOMUXC_GPR_GPR1_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_IRQ) & BM_IOMUXC_GPR_GPR1_IRQ)

/*! @brief Set the IRQ field to a new value. */
#define BW_IOMUXC_GPR_GPR1_IRQ(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_IRQ) | BF_IOMUXC_GPR_GPR1_IRQ(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ENET1_TX_CLK_SEL[13] (RW)
 *
 * ENET1 reference clock mode select
 *
 * Values:
 * - 0 - Gets ENET1 TX reference clk. This clock is also output to pins via the
 *     IOMUX. ENET_REF_CLK1 function.
 * - 1 - Gets ENET1 TX reference clk from the ENET1_TX_CLK pin. In this use
 *     case, an external OSC provides the clock for both the external PHY and the
 *     internal controller
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ENET1_TX_CLK_SEL (13U) /*!< Bit position for IOMUXC_GPR_GPR1_ENET1_TX_CLK_SEL. */
#define BM_IOMUXC_GPR_GPR1_ENET1_TX_CLK_SEL (0x00002000U) /*!< Bit mask for IOMUXC_GPR_GPR1_ENET1_TX_CLK_SEL. */
#define BS_IOMUXC_GPR_GPR1_ENET1_TX_CLK_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ENET1_TX_CLK_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ENET1_TX_CLK_SEL field. */
#define BR_IOMUXC_GPR_GPR1_ENET1_TX_CLK_SEL(x) (HW_IOMUXC_GPR_GPR1(x).B.ENET1_TX_CLK_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ENET1_TX_CLK_SEL. */
#define BF_IOMUXC_GPR_GPR1_ENET1_TX_CLK_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ENET1_TX_CLK_SEL) & BM_IOMUXC_GPR_GPR1_ENET1_TX_CLK_SEL)

/*! @brief Set the ENET1_TX_CLK_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ENET1_TX_CLK_SEL(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ENET1_TX_CLK_SEL) | BF_IOMUXC_GPR_GPR1_ENET1_TX_CLK_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ENET2_TX_CLK_SEL[14] (RW)
 *
 * ENET2 reference clock mode select
 *
 * Values:
 * - 0 - Gets ENET2 TX reference clk. This clock is also output to pins via the
 *     IOMUX. ENET_REF_CLK2 function.
 * - 1 - Gets ENET2 TX reference clk from the ENET2_TX_CLK pin. In this use
 *     case, an external OSC provides the clock for both the external PHY and the
 *     internal controller
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ENET2_TX_CLK_SEL (14U) /*!< Bit position for IOMUXC_GPR_GPR1_ENET2_TX_CLK_SEL. */
#define BM_IOMUXC_GPR_GPR1_ENET2_TX_CLK_SEL (0x00004000U) /*!< Bit mask for IOMUXC_GPR_GPR1_ENET2_TX_CLK_SEL. */
#define BS_IOMUXC_GPR_GPR1_ENET2_TX_CLK_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ENET2_TX_CLK_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ENET2_TX_CLK_SEL field. */
#define BR_IOMUXC_GPR_GPR1_ENET2_TX_CLK_SEL(x) (HW_IOMUXC_GPR_GPR1(x).B.ENET2_TX_CLK_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ENET2_TX_CLK_SEL. */
#define BF_IOMUXC_GPR_GPR1_ENET2_TX_CLK_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ENET2_TX_CLK_SEL) & BM_IOMUXC_GPR_GPR1_ENET2_TX_CLK_SEL)

/*! @brief Set the ENET2_TX_CLK_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ENET2_TX_CLK_SEL(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ENET2_TX_CLK_SEL) | BF_IOMUXC_GPR_GPR1_ENET2_TX_CLK_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field PAD_ADD_DS[16] (RW)
 *
 * Setting ADD_DS to 0 will make the output driver of the SD3 pins ~10% stronger
 * at highest drive strength (DSE=111). This is for use if the I/O buffer
 * operation at WCS and 200MHz is marginal.
 *
 * Values:
 * - 0 - output driver ~10% stronger
 * - 1 - output driver is normal
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_PAD_ADD_DS (16U) /*!< Bit position for IOMUXC_GPR_GPR1_PAD_ADD_DS. */
#define BM_IOMUXC_GPR_GPR1_PAD_ADD_DS (0x00010000U) /*!< Bit mask for IOMUXC_GPR_GPR1_PAD_ADD_DS. */
#define BS_IOMUXC_GPR_GPR1_PAD_ADD_DS (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_PAD_ADD_DS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_PAD_ADD_DS field. */
#define BR_IOMUXC_GPR_GPR1_PAD_ADD_DS(x) (HW_IOMUXC_GPR_GPR1(x).B.PAD_ADD_DS)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_PAD_ADD_DS. */
#define BF_IOMUXC_GPR_GPR1_PAD_ADD_DS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_PAD_ADD_DS) & BM_IOMUXC_GPR_GPR1_PAD_ADD_DS)

/*! @brief Set the PAD_ADD_DS field to a new value. */
#define BW_IOMUXC_GPR_GPR1_PAD_ADD_DS(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_PAD_ADD_DS) | BF_IOMUXC_GPR_GPR1_PAD_ADD_DS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ENET1_CLK_DIR[17] (RW)
 *
 * ENET1_TX_CLK data direction control when ANATOP ENET_REF_CLK1 is selected
 * (ALT1)
 *
 * Values:
 * - 0 - ENET1_TX_CLK output driver is disabled when configured for ALT1
 * - 1 - ENET1_TX_CLK output driver is enabled when configured for ALT1
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ENET1_CLK_DIR (17U) /*!< Bit position for IOMUXC_GPR_GPR1_ENET1_CLK_DIR. */
#define BM_IOMUXC_GPR_GPR1_ENET1_CLK_DIR (0x00020000U) /*!< Bit mask for IOMUXC_GPR_GPR1_ENET1_CLK_DIR. */
#define BS_IOMUXC_GPR_GPR1_ENET1_CLK_DIR (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ENET1_CLK_DIR. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ENET1_CLK_DIR field. */
#define BR_IOMUXC_GPR_GPR1_ENET1_CLK_DIR(x) (HW_IOMUXC_GPR_GPR1(x).B.ENET1_CLK_DIR)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ENET1_CLK_DIR. */
#define BF_IOMUXC_GPR_GPR1_ENET1_CLK_DIR(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ENET1_CLK_DIR) & BM_IOMUXC_GPR_GPR1_ENET1_CLK_DIR)

/*! @brief Set the ENET1_CLK_DIR field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ENET1_CLK_DIR(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ENET1_CLK_DIR) | BF_IOMUXC_GPR_GPR1_ENET1_CLK_DIR(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ENET2_CLK_DIR[18] (RW)
 *
 * ENET2_TX_CLK data direction control when ANATOP ENET_REF_CLK2 is selected
 * (ALT1)
 *
 * Values:
 * - 0 - ENET2_TX_CLK output driver is disabled when configured for ALT1
 * - 1 - ENET2_TX_CLK output driver is enabled when configured for ALT1
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ENET2_CLK_DIR (18U) /*!< Bit position for IOMUXC_GPR_GPR1_ENET2_CLK_DIR. */
#define BM_IOMUXC_GPR_GPR1_ENET2_CLK_DIR (0x00040000U) /*!< Bit mask for IOMUXC_GPR_GPR1_ENET2_CLK_DIR. */
#define BS_IOMUXC_GPR_GPR1_ENET2_CLK_DIR (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ENET2_CLK_DIR. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ENET2_CLK_DIR field. */
#define BR_IOMUXC_GPR_GPR1_ENET2_CLK_DIR(x) (HW_IOMUXC_GPR_GPR1(x).B.ENET2_CLK_DIR)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ENET2_CLK_DIR. */
#define BF_IOMUXC_GPR_GPR1_ENET2_CLK_DIR(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ENET2_CLK_DIR) & BM_IOMUXC_GPR_GPR1_ENET2_CLK_DIR)

/*! @brief Set the ENET2_CLK_DIR field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ENET2_CLK_DIR(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ENET2_CLK_DIR) | BF_IOMUXC_GPR_GPR1_ENET2_CLK_DIR(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field EXC_ERR_RESP_EN[22] (RW)
 *
 * Security exclusive access error response enable for all security gaskets (on
 * both AHB and AXI busses). Enables an ERR response on the AXI vs an OK response
 * for an exclusive access error.
 *
 * Values:
 * - 0 - OK response on the AXI for an exclusive access error
 * - 1 - ERR response on the AXI for an exclusive access error
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_EXC_ERR_RESP_EN (22U) /*!< Bit position for IOMUXC_GPR_GPR1_EXC_ERR_RESP_EN. */
#define BM_IOMUXC_GPR_GPR1_EXC_ERR_RESP_EN (0x00400000U) /*!< Bit mask for IOMUXC_GPR_GPR1_EXC_ERR_RESP_EN. */
#define BS_IOMUXC_GPR_GPR1_EXC_ERR_RESP_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_EXC_ERR_RESP_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_EXC_ERR_RESP_EN field. */
#define BR_IOMUXC_GPR_GPR1_EXC_ERR_RESP_EN(x) (HW_IOMUXC_GPR_GPR1(x).B.EXC_ERR_RESP_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_EXC_ERR_RESP_EN. */
#define BF_IOMUXC_GPR_GPR1_EXC_ERR_RESP_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_EXC_ERR_RESP_EN) & BM_IOMUXC_GPR_GPR1_EXC_ERR_RESP_EN)

/*! @brief Set the EXC_ERR_RESP_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR1_EXC_ERR_RESP_EN(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_EXC_ERR_RESP_EN) | BF_IOMUXC_GPR_GPR1_EXC_ERR_RESP_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field TZASC1_SECURE_BOOT_LOCK[23] (RW)
 *
 * TZASC-1 Secure Boot Lock
 *
 * Values:
 * - 0 - Secure boot lock is disabled
 * - 1 - Secure boot lock is enabled
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_TZASC1_SECURE_BOOT_LOCK (23U) /*!< Bit position for IOMUXC_GPR_GPR1_TZASC1_SECURE_BOOT_LOCK. */
#define BM_IOMUXC_GPR_GPR1_TZASC1_SECURE_BOOT_LOCK (0x00800000U) /*!< Bit mask for IOMUXC_GPR_GPR1_TZASC1_SECURE_BOOT_LOCK. */
#define BS_IOMUXC_GPR_GPR1_TZASC1_SECURE_BOOT_LOCK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_TZASC1_SECURE_BOOT_LOCK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_TZASC1_SECURE_BOOT_LOCK field. */
#define BR_IOMUXC_GPR_GPR1_TZASC1_SECURE_BOOT_LOCK(x) (HW_IOMUXC_GPR_GPR1(x).B.TZASC1_SECURE_BOOT_LOCK)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_TZASC1_SECURE_BOOT_LOCK. */
#define BF_IOMUXC_GPR_GPR1_TZASC1_SECURE_BOOT_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_TZASC1_SECURE_BOOT_LOCK) & BM_IOMUXC_GPR_GPR1_TZASC1_SECURE_BOOT_LOCK)

/*! @brief Set the TZASC1_SECURE_BOOT_LOCK field to a new value. */
#define BW_IOMUXC_GPR_GPR1_TZASC1_SECURE_BOOT_LOCK(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_TZASC1_SECURE_BOOT_LOCK) | BF_IOMUXC_GPR_GPR1_TZASC1_SECURE_BOOT_LOCK(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field DBG_ACK[29:28] (RW)
 *
 * Debug Acknowledge, used in sec_wrapper
 *
 * Values:
 * - 00 - None of the two cores are treated as debug mode by peripherals
 * - 01 - CA7 platform treated as debug mode when CA7 core0 in debug mode by
 *     peripherals
 * - 10 - CA7 platform treated as debug mode when CA7 core1 in debug mode by
 *     peripherals
 * - 11 - CA7 platform treated as debug mode when any CA7 cores in debug mode by
 *     peripherals
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_DBG_ACK (28U)   /*!< Bit position for IOMUXC_GPR_GPR1_DBG_ACK. */
#define BM_IOMUXC_GPR_GPR1_DBG_ACK (0x30000000U) /*!< Bit mask for IOMUXC_GPR_GPR1_DBG_ACK. */
#define BS_IOMUXC_GPR_GPR1_DBG_ACK (2U)    /*!< Bit field size in bits for IOMUXC_GPR_GPR1_DBG_ACK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_DBG_ACK field. */
#define BR_IOMUXC_GPR_GPR1_DBG_ACK(x) (HW_IOMUXC_GPR_GPR1(x).B.DBG_ACK)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_DBG_ACK. */
#define BF_IOMUXC_GPR_GPR1_DBG_ACK(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_DBG_ACK) & BM_IOMUXC_GPR_GPR1_DBG_ACK)

/*! @brief Set the DBG_ACK field to a new value. */
#define BW_IOMUXC_GPR_GPR1_DBG_ACK(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_DBG_ACK) | BF_IOMUXC_GPR_GPR1_DBG_ACK(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR1, field ENABLE_OCRAM_EPDC[30] (RW)
 *
 * Enable On-chip RAM EPDC Function
 *
 * Values:
 * - 0 - Disable On-chip RAM EPDC Function
 * - 1 - Enable On-chip RAM EPDC Function
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR1_ENABLE_OCRAM_EPDC (30U) /*!< Bit position for IOMUXC_GPR_GPR1_ENABLE_OCRAM_EPDC. */
#define BM_IOMUXC_GPR_GPR1_ENABLE_OCRAM_EPDC (0x40000000U) /*!< Bit mask for IOMUXC_GPR_GPR1_ENABLE_OCRAM_EPDC. */
#define BS_IOMUXC_GPR_GPR1_ENABLE_OCRAM_EPDC (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR1_ENABLE_OCRAM_EPDC. */

/*! @brief Read current value of the IOMUXC_GPR_GPR1_ENABLE_OCRAM_EPDC field. */
#define BR_IOMUXC_GPR_GPR1_ENABLE_OCRAM_EPDC(x) (HW_IOMUXC_GPR_GPR1(x).B.ENABLE_OCRAM_EPDC)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR1_ENABLE_OCRAM_EPDC. */
#define BF_IOMUXC_GPR_GPR1_ENABLE_OCRAM_EPDC(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR1_ENABLE_OCRAM_EPDC) & BM_IOMUXC_GPR_GPR1_ENABLE_OCRAM_EPDC)

/*! @brief Set the ENABLE_OCRAM_EPDC field to a new value. */
#define BW_IOMUXC_GPR_GPR1_ENABLE_OCRAM_EPDC(x, v) (HW_IOMUXC_GPR_GPR1_WR(x, (HW_IOMUXC_GPR_GPR1_RD(x) & ~BM_IOMUXC_GPR_GPR1_ENABLE_OCRAM_EPDC) | BF_IOMUXC_GPR_GPR1_ENABLE_OCRAM_EPDC(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR2 - GPR2 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR2 - GPR2 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr2
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr2_bitfields
    {
        uint32_t MEM_PXP_LOWPOWER : 1; /*!< [0]  */
        uint32_t MEM_PXP_SD : 1;       /*!< [1]  */
        uint32_t MEM_PXP_DS : 1;       /*!< [2]  */
        uint32_t MEM_PXP_LS : 1;       /*!< [3]  */
        uint32_t MEM_LCDIF_LOWPOWER : 1; /*!< [4]  */
        uint32_t MEM_LCDIF_SD : 1;     /*!< [5]  */
        uint32_t MEM_LCDIF_DS : 1;     /*!< [6]  */
        uint32_t MEM_LCDIF_LS : 1;     /*!< [7]  */
        uint32_t MEM_EPDC_LOWPOWER : 1; /*!< [8]  */
        uint32_t MEM_EPDC_SD : 1;      /*!< [9]  */
        uint32_t MEM_EPDC_DS : 1;      /*!< [10]  */
        uint32_t MEM_EPDC_LS : 1;      /*!< [11]  */
        uint32_t MEM_CPU_LOWPOWER : 1; /*!< [12]  */
        uint32_t MEM_CPU_SD : 1;       /*!< [13]  */
        uint32_t MEM_CPU_DS : 1;       /*!< [14]  */
        uint32_t MEM_CPU_LS : 1;       /*!< [15]  */
        uint32_t MQS_CLK_DIV : 8;      /*!< [23:16]  */
        uint32_t MQS_SW_RST : 1;       /*!< [24]  */
        uint32_t MQS_EN : 1;           /*!< [25]  */
        uint32_t MQS_OVERSAMPLE : 1;   /*!< [26]  */
        uint32_t DRAM_RESET_BYPASS : 1; /*!< [27]  */
        uint32_t DRAM_RESET : 1;       /*!< [28]  */
        uint32_t DRAM_CKE0 : 1;        /*!< [29]  */
        uint32_t DRAM_CKE1 : 1;        /*!< [30]  */
        uint32_t DRAM_CKE_BYPASS : 1;  /*!< [31]  */
    } B;
} hw_iomuxc_gpr_gpr2_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR2 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR2_ADDR(x) ((uintptr_t)(x) + 0x8U)

#define HW_IOMUXC_GPR_GPR2(x)    (*(__IO hw_iomuxc_gpr_gpr2_t *) HW_IOMUXC_GPR_GPR2_ADDR(x))
#define HW_IOMUXC_GPR_GPR2_RD(x) (HW_IOMUXC_GPR_GPR2(x).U)
#define HW_IOMUXC_GPR_GPR2_WR(x, v) (HW_IOMUXC_GPR_GPR2(x).U = (v))
#define HW_IOMUXC_GPR_GPR2_SET(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, HW_IOMUXC_GPR_GPR2_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR2_CLR(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, HW_IOMUXC_GPR_GPR2_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR2_TOG(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, HW_IOMUXC_GPR_GPR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR2 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR2, field MEM_PXP_LOWPOWER[0] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MEM_PXP_LOWPOWER (0U) /*!< Bit position for IOMUXC_GPR_GPR2_MEM_PXP_LOWPOWER. */
#define BM_IOMUXC_GPR_GPR2_MEM_PXP_LOWPOWER (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR2_MEM_PXP_LOWPOWER. */
#define BS_IOMUXC_GPR_GPR2_MEM_PXP_LOWPOWER (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MEM_PXP_LOWPOWER. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MEM_PXP_LOWPOWER field. */
#define BR_IOMUXC_GPR_GPR2_MEM_PXP_LOWPOWER(x) (HW_IOMUXC_GPR_GPR2(x).B.MEM_PXP_LOWPOWER)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MEM_PXP_LOWPOWER. */
#define BF_IOMUXC_GPR_GPR2_MEM_PXP_LOWPOWER(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MEM_PXP_LOWPOWER) & BM_IOMUXC_GPR_GPR2_MEM_PXP_LOWPOWER)

/*! @brief Set the MEM_PXP_LOWPOWER field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MEM_PXP_LOWPOWER(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MEM_PXP_LOWPOWER) | BF_IOMUXC_GPR_GPR2_MEM_PXP_LOWPOWER(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MEM_PXP_SD[1] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MEM_PXP_SD (1U) /*!< Bit position for IOMUXC_GPR_GPR2_MEM_PXP_SD. */
#define BM_IOMUXC_GPR_GPR2_MEM_PXP_SD (0x00000002U) /*!< Bit mask for IOMUXC_GPR_GPR2_MEM_PXP_SD. */
#define BS_IOMUXC_GPR_GPR2_MEM_PXP_SD (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MEM_PXP_SD. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MEM_PXP_SD field. */
#define BR_IOMUXC_GPR_GPR2_MEM_PXP_SD(x) (HW_IOMUXC_GPR_GPR2(x).B.MEM_PXP_SD)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MEM_PXP_SD. */
#define BF_IOMUXC_GPR_GPR2_MEM_PXP_SD(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MEM_PXP_SD) & BM_IOMUXC_GPR_GPR2_MEM_PXP_SD)

/*! @brief Set the MEM_PXP_SD field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MEM_PXP_SD(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MEM_PXP_SD) | BF_IOMUXC_GPR_GPR2_MEM_PXP_SD(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MEM_PXP_DS[2] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MEM_PXP_DS (2U) /*!< Bit position for IOMUXC_GPR_GPR2_MEM_PXP_DS. */
#define BM_IOMUXC_GPR_GPR2_MEM_PXP_DS (0x00000004U) /*!< Bit mask for IOMUXC_GPR_GPR2_MEM_PXP_DS. */
#define BS_IOMUXC_GPR_GPR2_MEM_PXP_DS (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MEM_PXP_DS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MEM_PXP_DS field. */
#define BR_IOMUXC_GPR_GPR2_MEM_PXP_DS(x) (HW_IOMUXC_GPR_GPR2(x).B.MEM_PXP_DS)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MEM_PXP_DS. */
#define BF_IOMUXC_GPR_GPR2_MEM_PXP_DS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MEM_PXP_DS) & BM_IOMUXC_GPR_GPR2_MEM_PXP_DS)

/*! @brief Set the MEM_PXP_DS field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MEM_PXP_DS(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MEM_PXP_DS) | BF_IOMUXC_GPR_GPR2_MEM_PXP_DS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MEM_PXP_LS[3] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MEM_PXP_LS (3U) /*!< Bit position for IOMUXC_GPR_GPR2_MEM_PXP_LS. */
#define BM_IOMUXC_GPR_GPR2_MEM_PXP_LS (0x00000008U) /*!< Bit mask for IOMUXC_GPR_GPR2_MEM_PXP_LS. */
#define BS_IOMUXC_GPR_GPR2_MEM_PXP_LS (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MEM_PXP_LS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MEM_PXP_LS field. */
#define BR_IOMUXC_GPR_GPR2_MEM_PXP_LS(x) (HW_IOMUXC_GPR_GPR2(x).B.MEM_PXP_LS)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MEM_PXP_LS. */
#define BF_IOMUXC_GPR_GPR2_MEM_PXP_LS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MEM_PXP_LS) & BM_IOMUXC_GPR_GPR2_MEM_PXP_LS)

/*! @brief Set the MEM_PXP_LS field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MEM_PXP_LS(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MEM_PXP_LS) | BF_IOMUXC_GPR_GPR2_MEM_PXP_LS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MEM_LCDIF_LOWPOWER[4] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MEM_LCDIF_LOWPOWER (4U) /*!< Bit position for IOMUXC_GPR_GPR2_MEM_LCDIF_LOWPOWER. */
#define BM_IOMUXC_GPR_GPR2_MEM_LCDIF_LOWPOWER (0x00000010U) /*!< Bit mask for IOMUXC_GPR_GPR2_MEM_LCDIF_LOWPOWER. */
#define BS_IOMUXC_GPR_GPR2_MEM_LCDIF_LOWPOWER (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MEM_LCDIF_LOWPOWER. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MEM_LCDIF_LOWPOWER field. */
#define BR_IOMUXC_GPR_GPR2_MEM_LCDIF_LOWPOWER(x) (HW_IOMUXC_GPR_GPR2(x).B.MEM_LCDIF_LOWPOWER)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MEM_LCDIF_LOWPOWER. */
#define BF_IOMUXC_GPR_GPR2_MEM_LCDIF_LOWPOWER(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MEM_LCDIF_LOWPOWER) & BM_IOMUXC_GPR_GPR2_MEM_LCDIF_LOWPOWER)

/*! @brief Set the MEM_LCDIF_LOWPOWER field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MEM_LCDIF_LOWPOWER(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MEM_LCDIF_LOWPOWER) | BF_IOMUXC_GPR_GPR2_MEM_LCDIF_LOWPOWER(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MEM_LCDIF_SD[5] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MEM_LCDIF_SD (5U) /*!< Bit position for IOMUXC_GPR_GPR2_MEM_LCDIF_SD. */
#define BM_IOMUXC_GPR_GPR2_MEM_LCDIF_SD (0x00000020U) /*!< Bit mask for IOMUXC_GPR_GPR2_MEM_LCDIF_SD. */
#define BS_IOMUXC_GPR_GPR2_MEM_LCDIF_SD (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MEM_LCDIF_SD. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MEM_LCDIF_SD field. */
#define BR_IOMUXC_GPR_GPR2_MEM_LCDIF_SD(x) (HW_IOMUXC_GPR_GPR2(x).B.MEM_LCDIF_SD)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MEM_LCDIF_SD. */
#define BF_IOMUXC_GPR_GPR2_MEM_LCDIF_SD(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MEM_LCDIF_SD) & BM_IOMUXC_GPR_GPR2_MEM_LCDIF_SD)

/*! @brief Set the MEM_LCDIF_SD field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MEM_LCDIF_SD(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MEM_LCDIF_SD) | BF_IOMUXC_GPR_GPR2_MEM_LCDIF_SD(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MEM_LCDIF_DS[6] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MEM_LCDIF_DS (6U) /*!< Bit position for IOMUXC_GPR_GPR2_MEM_LCDIF_DS. */
#define BM_IOMUXC_GPR_GPR2_MEM_LCDIF_DS (0x00000040U) /*!< Bit mask for IOMUXC_GPR_GPR2_MEM_LCDIF_DS. */
#define BS_IOMUXC_GPR_GPR2_MEM_LCDIF_DS (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MEM_LCDIF_DS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MEM_LCDIF_DS field. */
#define BR_IOMUXC_GPR_GPR2_MEM_LCDIF_DS(x) (HW_IOMUXC_GPR_GPR2(x).B.MEM_LCDIF_DS)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MEM_LCDIF_DS. */
#define BF_IOMUXC_GPR_GPR2_MEM_LCDIF_DS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MEM_LCDIF_DS) & BM_IOMUXC_GPR_GPR2_MEM_LCDIF_DS)

/*! @brief Set the MEM_LCDIF_DS field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MEM_LCDIF_DS(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MEM_LCDIF_DS) | BF_IOMUXC_GPR_GPR2_MEM_LCDIF_DS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MEM_LCDIF_LS[7] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MEM_LCDIF_LS (7U) /*!< Bit position for IOMUXC_GPR_GPR2_MEM_LCDIF_LS. */
#define BM_IOMUXC_GPR_GPR2_MEM_LCDIF_LS (0x00000080U) /*!< Bit mask for IOMUXC_GPR_GPR2_MEM_LCDIF_LS. */
#define BS_IOMUXC_GPR_GPR2_MEM_LCDIF_LS (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MEM_LCDIF_LS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MEM_LCDIF_LS field. */
#define BR_IOMUXC_GPR_GPR2_MEM_LCDIF_LS(x) (HW_IOMUXC_GPR_GPR2(x).B.MEM_LCDIF_LS)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MEM_LCDIF_LS. */
#define BF_IOMUXC_GPR_GPR2_MEM_LCDIF_LS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MEM_LCDIF_LS) & BM_IOMUXC_GPR_GPR2_MEM_LCDIF_LS)

/*! @brief Set the MEM_LCDIF_LS field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MEM_LCDIF_LS(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MEM_LCDIF_LS) | BF_IOMUXC_GPR_GPR2_MEM_LCDIF_LS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MEM_EPDC_LOWPOWER[8] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MEM_EPDC_LOWPOWER (8U) /*!< Bit position for IOMUXC_GPR_GPR2_MEM_EPDC_LOWPOWER. */
#define BM_IOMUXC_GPR_GPR2_MEM_EPDC_LOWPOWER (0x00000100U) /*!< Bit mask for IOMUXC_GPR_GPR2_MEM_EPDC_LOWPOWER. */
#define BS_IOMUXC_GPR_GPR2_MEM_EPDC_LOWPOWER (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MEM_EPDC_LOWPOWER. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MEM_EPDC_LOWPOWER field. */
#define BR_IOMUXC_GPR_GPR2_MEM_EPDC_LOWPOWER(x) (HW_IOMUXC_GPR_GPR2(x).B.MEM_EPDC_LOWPOWER)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MEM_EPDC_LOWPOWER. */
#define BF_IOMUXC_GPR_GPR2_MEM_EPDC_LOWPOWER(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MEM_EPDC_LOWPOWER) & BM_IOMUXC_GPR_GPR2_MEM_EPDC_LOWPOWER)

/*! @brief Set the MEM_EPDC_LOWPOWER field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MEM_EPDC_LOWPOWER(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MEM_EPDC_LOWPOWER) | BF_IOMUXC_GPR_GPR2_MEM_EPDC_LOWPOWER(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MEM_EPDC_SD[9] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MEM_EPDC_SD (9U) /*!< Bit position for IOMUXC_GPR_GPR2_MEM_EPDC_SD. */
#define BM_IOMUXC_GPR_GPR2_MEM_EPDC_SD (0x00000200U) /*!< Bit mask for IOMUXC_GPR_GPR2_MEM_EPDC_SD. */
#define BS_IOMUXC_GPR_GPR2_MEM_EPDC_SD (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MEM_EPDC_SD. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MEM_EPDC_SD field. */
#define BR_IOMUXC_GPR_GPR2_MEM_EPDC_SD(x) (HW_IOMUXC_GPR_GPR2(x).B.MEM_EPDC_SD)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MEM_EPDC_SD. */
#define BF_IOMUXC_GPR_GPR2_MEM_EPDC_SD(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MEM_EPDC_SD) & BM_IOMUXC_GPR_GPR2_MEM_EPDC_SD)

/*! @brief Set the MEM_EPDC_SD field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MEM_EPDC_SD(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MEM_EPDC_SD) | BF_IOMUXC_GPR_GPR2_MEM_EPDC_SD(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MEM_EPDC_DS[10] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MEM_EPDC_DS (10U) /*!< Bit position for IOMUXC_GPR_GPR2_MEM_EPDC_DS. */
#define BM_IOMUXC_GPR_GPR2_MEM_EPDC_DS (0x00000400U) /*!< Bit mask for IOMUXC_GPR_GPR2_MEM_EPDC_DS. */
#define BS_IOMUXC_GPR_GPR2_MEM_EPDC_DS (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MEM_EPDC_DS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MEM_EPDC_DS field. */
#define BR_IOMUXC_GPR_GPR2_MEM_EPDC_DS(x) (HW_IOMUXC_GPR_GPR2(x).B.MEM_EPDC_DS)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MEM_EPDC_DS. */
#define BF_IOMUXC_GPR_GPR2_MEM_EPDC_DS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MEM_EPDC_DS) & BM_IOMUXC_GPR_GPR2_MEM_EPDC_DS)

/*! @brief Set the MEM_EPDC_DS field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MEM_EPDC_DS(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MEM_EPDC_DS) | BF_IOMUXC_GPR_GPR2_MEM_EPDC_DS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MEM_EPDC_LS[11] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MEM_EPDC_LS (11U) /*!< Bit position for IOMUXC_GPR_GPR2_MEM_EPDC_LS. */
#define BM_IOMUXC_GPR_GPR2_MEM_EPDC_LS (0x00000800U) /*!< Bit mask for IOMUXC_GPR_GPR2_MEM_EPDC_LS. */
#define BS_IOMUXC_GPR_GPR2_MEM_EPDC_LS (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MEM_EPDC_LS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MEM_EPDC_LS field. */
#define BR_IOMUXC_GPR_GPR2_MEM_EPDC_LS(x) (HW_IOMUXC_GPR_GPR2(x).B.MEM_EPDC_LS)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MEM_EPDC_LS. */
#define BF_IOMUXC_GPR_GPR2_MEM_EPDC_LS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MEM_EPDC_LS) & BM_IOMUXC_GPR_GPR2_MEM_EPDC_LS)

/*! @brief Set the MEM_EPDC_LS field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MEM_EPDC_LS(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MEM_EPDC_LS) | BF_IOMUXC_GPR_GPR2_MEM_EPDC_LS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MEM_CPU_LOWPOWER[12] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MEM_CPU_LOWPOWER (12U) /*!< Bit position for IOMUXC_GPR_GPR2_MEM_CPU_LOWPOWER. */
#define BM_IOMUXC_GPR_GPR2_MEM_CPU_LOWPOWER (0x00001000U) /*!< Bit mask for IOMUXC_GPR_GPR2_MEM_CPU_LOWPOWER. */
#define BS_IOMUXC_GPR_GPR2_MEM_CPU_LOWPOWER (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MEM_CPU_LOWPOWER. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MEM_CPU_LOWPOWER field. */
#define BR_IOMUXC_GPR_GPR2_MEM_CPU_LOWPOWER(x) (HW_IOMUXC_GPR_GPR2(x).B.MEM_CPU_LOWPOWER)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MEM_CPU_LOWPOWER. */
#define BF_IOMUXC_GPR_GPR2_MEM_CPU_LOWPOWER(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MEM_CPU_LOWPOWER) & BM_IOMUXC_GPR_GPR2_MEM_CPU_LOWPOWER)

/*! @brief Set the MEM_CPU_LOWPOWER field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MEM_CPU_LOWPOWER(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MEM_CPU_LOWPOWER) | BF_IOMUXC_GPR_GPR2_MEM_CPU_LOWPOWER(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MEM_CPU_SD[13] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MEM_CPU_SD (13U) /*!< Bit position for IOMUXC_GPR_GPR2_MEM_CPU_SD. */
#define BM_IOMUXC_GPR_GPR2_MEM_CPU_SD (0x00002000U) /*!< Bit mask for IOMUXC_GPR_GPR2_MEM_CPU_SD. */
#define BS_IOMUXC_GPR_GPR2_MEM_CPU_SD (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MEM_CPU_SD. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MEM_CPU_SD field. */
#define BR_IOMUXC_GPR_GPR2_MEM_CPU_SD(x) (HW_IOMUXC_GPR_GPR2(x).B.MEM_CPU_SD)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MEM_CPU_SD. */
#define BF_IOMUXC_GPR_GPR2_MEM_CPU_SD(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MEM_CPU_SD) & BM_IOMUXC_GPR_GPR2_MEM_CPU_SD)

/*! @brief Set the MEM_CPU_SD field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MEM_CPU_SD(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MEM_CPU_SD) | BF_IOMUXC_GPR_GPR2_MEM_CPU_SD(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MEM_CPU_DS[14] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MEM_CPU_DS (14U) /*!< Bit position for IOMUXC_GPR_GPR2_MEM_CPU_DS. */
#define BM_IOMUXC_GPR_GPR2_MEM_CPU_DS (0x00004000U) /*!< Bit mask for IOMUXC_GPR_GPR2_MEM_CPU_DS. */
#define BS_IOMUXC_GPR_GPR2_MEM_CPU_DS (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MEM_CPU_DS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MEM_CPU_DS field. */
#define BR_IOMUXC_GPR_GPR2_MEM_CPU_DS(x) (HW_IOMUXC_GPR_GPR2(x).B.MEM_CPU_DS)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MEM_CPU_DS. */
#define BF_IOMUXC_GPR_GPR2_MEM_CPU_DS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MEM_CPU_DS) & BM_IOMUXC_GPR_GPR2_MEM_CPU_DS)

/*! @brief Set the MEM_CPU_DS field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MEM_CPU_DS(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MEM_CPU_DS) | BF_IOMUXC_GPR_GPR2_MEM_CPU_DS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MEM_CPU_LS[15] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MEM_CPU_LS (15U) /*!< Bit position for IOMUXC_GPR_GPR2_MEM_CPU_LS. */
#define BM_IOMUXC_GPR_GPR2_MEM_CPU_LS (0x00008000U) /*!< Bit mask for IOMUXC_GPR_GPR2_MEM_CPU_LS. */
#define BS_IOMUXC_GPR_GPR2_MEM_CPU_LS (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MEM_CPU_LS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MEM_CPU_LS field. */
#define BR_IOMUXC_GPR_GPR2_MEM_CPU_LS(x) (HW_IOMUXC_GPR_GPR2(x).B.MEM_CPU_LS)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MEM_CPU_LS. */
#define BF_IOMUXC_GPR_GPR2_MEM_CPU_LS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MEM_CPU_LS) & BM_IOMUXC_GPR_GPR2_MEM_CPU_LS)

/*! @brief Set the MEM_CPU_LS field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MEM_CPU_LS(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MEM_CPU_LS) | BF_IOMUXC_GPR_GPR2_MEM_CPU_LS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MQS_CLK_DIV[23:16] (RW)
 *
 * MQS clock divider control
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MQS_CLK_DIV (16U) /*!< Bit position for IOMUXC_GPR_GPR2_MQS_CLK_DIV. */
#define BM_IOMUXC_GPR_GPR2_MQS_CLK_DIV (0x00FF0000U) /*!< Bit mask for IOMUXC_GPR_GPR2_MQS_CLK_DIV. */
#define BS_IOMUXC_GPR_GPR2_MQS_CLK_DIV (8U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MQS_CLK_DIV. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MQS_CLK_DIV field. */
#define BR_IOMUXC_GPR_GPR2_MQS_CLK_DIV(x) (HW_IOMUXC_GPR_GPR2(x).B.MQS_CLK_DIV)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MQS_CLK_DIV. */
#define BF_IOMUXC_GPR_GPR2_MQS_CLK_DIV(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MQS_CLK_DIV) & BM_IOMUXC_GPR_GPR2_MQS_CLK_DIV)

/*! @brief Set the MQS_CLK_DIV field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MQS_CLK_DIV(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MQS_CLK_DIV) | BF_IOMUXC_GPR_GPR2_MQS_CLK_DIV(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MQS_SW_RST[24] (RW)
 *
 * MQS software reset
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MQS_SW_RST (24U) /*!< Bit position for IOMUXC_GPR_GPR2_MQS_SW_RST. */
#define BM_IOMUXC_GPR_GPR2_MQS_SW_RST (0x01000000U) /*!< Bit mask for IOMUXC_GPR_GPR2_MQS_SW_RST. */
#define BS_IOMUXC_GPR_GPR2_MQS_SW_RST (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MQS_SW_RST. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MQS_SW_RST field. */
#define BR_IOMUXC_GPR_GPR2_MQS_SW_RST(x) (HW_IOMUXC_GPR_GPR2(x).B.MQS_SW_RST)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MQS_SW_RST. */
#define BF_IOMUXC_GPR_GPR2_MQS_SW_RST(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MQS_SW_RST) & BM_IOMUXC_GPR_GPR2_MQS_SW_RST)

/*! @brief Set the MQS_SW_RST field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MQS_SW_RST(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MQS_SW_RST) | BF_IOMUXC_GPR_GPR2_MQS_SW_RST(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MQS_EN[25] (RW)
 *
 * MQS enable
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MQS_EN (25U)    /*!< Bit position for IOMUXC_GPR_GPR2_MQS_EN. */
#define BM_IOMUXC_GPR_GPR2_MQS_EN (0x02000000U) /*!< Bit mask for IOMUXC_GPR_GPR2_MQS_EN. */
#define BS_IOMUXC_GPR_GPR2_MQS_EN (1U)     /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MQS_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MQS_EN field. */
#define BR_IOMUXC_GPR_GPR2_MQS_EN(x) (HW_IOMUXC_GPR_GPR2(x).B.MQS_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MQS_EN. */
#define BF_IOMUXC_GPR_GPR2_MQS_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MQS_EN) & BM_IOMUXC_GPR_GPR2_MQS_EN)

/*! @brief Set the MQS_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MQS_EN(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MQS_EN) | BF_IOMUXC_GPR_GPR2_MQS_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field MQS_OVERSAMPLE[26] (RW)
 *
 * MQS PWM over-sampling rate option
 *
 * Values:
 * - 0 - 32
 * - 1 - 64
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE (26U) /*!< Bit position for IOMUXC_GPR_GPR2_MQS_OVERSAMPLE. */
#define BM_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE (0x04000000U) /*!< Bit mask for IOMUXC_GPR_GPR2_MQS_OVERSAMPLE. */
#define BS_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_MQS_OVERSAMPLE. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_MQS_OVERSAMPLE field. */
#define BR_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE(x) (HW_IOMUXC_GPR_GPR2(x).B.MQS_OVERSAMPLE)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_MQS_OVERSAMPLE. */
#define BF_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE) & BM_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE)

/*! @brief Set the MQS_OVERSAMPLE field to a new value. */
#define BW_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE) | BF_IOMUXC_GPR_GPR2_MQS_OVERSAMPLE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field DRAM_RESET_BYPASS[27] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS (27U) /*!< Bit position for IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS. */
#define BM_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS (0x08000000U) /*!< Bit mask for IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS. */
#define BS_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS field. */
#define BR_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS(x) (HW_IOMUXC_GPR_GPR2(x).B.DRAM_RESET_BYPASS)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS. */
#define BF_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS) & BM_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS)

/*! @brief Set the DRAM_RESET_BYPASS field to a new value. */
#define BW_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS) | BF_IOMUXC_GPR_GPR2_DRAM_RESET_BYPASS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field DRAM_RESET[28] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_DRAM_RESET (28U) /*!< Bit position for IOMUXC_GPR_GPR2_DRAM_RESET. */
#define BM_IOMUXC_GPR_GPR2_DRAM_RESET (0x10000000U) /*!< Bit mask for IOMUXC_GPR_GPR2_DRAM_RESET. */
#define BS_IOMUXC_GPR_GPR2_DRAM_RESET (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_DRAM_RESET. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_DRAM_RESET field. */
#define BR_IOMUXC_GPR_GPR2_DRAM_RESET(x) (HW_IOMUXC_GPR_GPR2(x).B.DRAM_RESET)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_DRAM_RESET. */
#define BF_IOMUXC_GPR_GPR2_DRAM_RESET(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_DRAM_RESET) & BM_IOMUXC_GPR_GPR2_DRAM_RESET)

/*! @brief Set the DRAM_RESET field to a new value. */
#define BW_IOMUXC_GPR_GPR2_DRAM_RESET(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_DRAM_RESET) | BF_IOMUXC_GPR_GPR2_DRAM_RESET(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field DRAM_CKE0[29] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_DRAM_CKE0 (29U) /*!< Bit position for IOMUXC_GPR_GPR2_DRAM_CKE0. */
#define BM_IOMUXC_GPR_GPR2_DRAM_CKE0 (0x20000000U) /*!< Bit mask for IOMUXC_GPR_GPR2_DRAM_CKE0. */
#define BS_IOMUXC_GPR_GPR2_DRAM_CKE0 (1U)  /*!< Bit field size in bits for IOMUXC_GPR_GPR2_DRAM_CKE0. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_DRAM_CKE0 field. */
#define BR_IOMUXC_GPR_GPR2_DRAM_CKE0(x) (HW_IOMUXC_GPR_GPR2(x).B.DRAM_CKE0)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_DRAM_CKE0. */
#define BF_IOMUXC_GPR_GPR2_DRAM_CKE0(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_DRAM_CKE0) & BM_IOMUXC_GPR_GPR2_DRAM_CKE0)

/*! @brief Set the DRAM_CKE0 field to a new value. */
#define BW_IOMUXC_GPR_GPR2_DRAM_CKE0(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_DRAM_CKE0) | BF_IOMUXC_GPR_GPR2_DRAM_CKE0(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field DRAM_CKE1[30] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_DRAM_CKE1 (30U) /*!< Bit position for IOMUXC_GPR_GPR2_DRAM_CKE1. */
#define BM_IOMUXC_GPR_GPR2_DRAM_CKE1 (0x40000000U) /*!< Bit mask for IOMUXC_GPR_GPR2_DRAM_CKE1. */
#define BS_IOMUXC_GPR_GPR2_DRAM_CKE1 (1U)  /*!< Bit field size in bits for IOMUXC_GPR_GPR2_DRAM_CKE1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_DRAM_CKE1 field. */
#define BR_IOMUXC_GPR_GPR2_DRAM_CKE1(x) (HW_IOMUXC_GPR_GPR2(x).B.DRAM_CKE1)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_DRAM_CKE1. */
#define BF_IOMUXC_GPR_GPR2_DRAM_CKE1(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_DRAM_CKE1) & BM_IOMUXC_GPR_GPR2_DRAM_CKE1)

/*! @brief Set the DRAM_CKE1 field to a new value. */
#define BW_IOMUXC_GPR_GPR2_DRAM_CKE1(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_DRAM_CKE1) | BF_IOMUXC_GPR_GPR2_DRAM_CKE1(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR2, field DRAM_CKE_BYPASS[31] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS (31U) /*!< Bit position for IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS. */
#define BM_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS (0x80000000U) /*!< Bit mask for IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS. */
#define BS_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS field. */
#define BR_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS(x) (HW_IOMUXC_GPR_GPR2(x).B.DRAM_CKE_BYPASS)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS. */
#define BF_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS) & BM_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS)

/*! @brief Set the DRAM_CKE_BYPASS field to a new value. */
#define BW_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS(x, v) (HW_IOMUXC_GPR_GPR2_WR(x, (HW_IOMUXC_GPR_GPR2_RD(x) & ~BM_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS) | BF_IOMUXC_GPR_GPR2_DRAM_CKE_BYPASS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR3 - GPR3 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR3 - GPR3 General Purpose Register (RW)
 *
 * Reset value: 0x0000FFFFU
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr3
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr3_bitfields
    {
        uint32_t RDATA_WAIT_EN : 1;    /*!< [0]  */
        uint32_t RADDR_PIPE_EN : 1;    /*!< [1]  */
        uint32_t WDATA_PIPE_EN : 1;    /*!< [2]  */
        uint32_t WADDR_PIPE_EN : 1;    /*!< [3]  */
        uint32_t S_RDATA_WAIT_EN : 1;  /*!< [4]  */
        uint32_t S_RADDR_PIPE_EN : 1;  /*!< [5]  */
        uint32_t S_WDATA_PIPE_EN : 1;  /*!< [6]  */
        uint32_t S_WADDR_PIPE_EN : 1;  /*!< [7]  */
        uint32_t E_RDATA_WAIT_EN : 1;  /*!< [8]  */
        uint32_t E_RADDR_PIPE_EN : 1;  /*!< [9]  */
        uint32_t E_WDATA_PIPE_EN : 1;  /*!< [10]  */
        uint32_t E_WADDR_PIPE_EN : 1;  /*!< [11]  */
        uint32_t P_RDATA_WAIT_EN : 1;  /*!< [12]  */
        uint32_t P_RADDR_PIPE_EN : 1;  /*!< [13]  */
        uint32_t P_WDATA_PIPE_EN : 1;  /*!< [14]  */
        uint32_t P_WADDR_PIPE_EN : 1;  /*!< [15]  */
        uint32_t RDATA_WAIT_EN_PDG : 1; /*!< [16]  */
        uint32_t RADDR_PIPE_EN_PDG : 1; /*!< [17]  */
        uint32_t WDATA_PIPE_EN_PDG : 1; /*!< [18]  */
        uint32_t WADDR_PIPE_EN_PNDG : 1; /*!< [19]  */
        uint32_t S_RDATA_WAIT_EN_PNDG : 1; /*!< [20]  */
        uint32_t S_RADDR_PIPE_EN_PNDG : 1; /*!< [21]  */
        uint32_t S_WDATA_PIPE_EN_PNDG : 1; /*!< [22]  */
        uint32_t S_WADDR_PIPE_EN_PNDG : 1; /*!< [23]  */
        uint32_t E_RDATA_WAIT_EN_PNDG : 1; /*!< [24]  */
        uint32_t E_RADDR_PIPE_EN_PNDG : 1; /*!< [25]  */
        uint32_t E_WDATA_PIPE_EN_PNDG : 1; /*!< [26]  */
        uint32_t E_WADDR_PIPE_EN_PNDG : 1; /*!< [27]  */
        uint32_t P_RDATA_WAIT_EN_PNDG : 1; /*!< [28]  */
        uint32_t P_RADDR_PIPE_EN_PNDG : 1; /*!< [29]  */
        uint32_t P_WDATA_PIPE_EN_PNDG : 1; /*!< [30]  */
        uint32_t P_WADDR_PIPE_EN_PNDG : 1; /*!< [31]  */
    } B;
} hw_iomuxc_gpr_gpr3_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR3 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR3_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_IOMUXC_GPR_GPR3(x)    (*(__IO hw_iomuxc_gpr_gpr3_t *) HW_IOMUXC_GPR_GPR3_ADDR(x))
#define HW_IOMUXC_GPR_GPR3_RD(x) (HW_IOMUXC_GPR_GPR3(x).U)
#define HW_IOMUXC_GPR_GPR3_WR(x, v) (HW_IOMUXC_GPR_GPR3(x).U = (v))
#define HW_IOMUXC_GPR_GPR3_SET(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, HW_IOMUXC_GPR_GPR3_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR3_CLR(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, HW_IOMUXC_GPR_GPR3_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR3_TOG(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, HW_IOMUXC_GPR_GPR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR3 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR3, field RDATA_WAIT_EN[0] (RW)
 *
 * On-chip RAM read data wait state control When the read data wait state is
 * enabled, it will cost 2 cycles for each read access, (each beat of a read burst).
 * This can avoid the potential timing problem caused by the relatively longer
 * memory access time at higher frequency. When this feature is disabled, it only
 * costs 1 clock cycle to finish a read transaction, i.e., get read data back in
 * the next cycle of read request becomes valid on the bus.
 *
 * Values:
 * - 0 - read data wait state disabled
 * - 1 - read data wait state enabled
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_RDATA_WAIT_EN (0U) /*!< Bit position for IOMUXC_GPR_GPR3_RDATA_WAIT_EN. */
#define BM_IOMUXC_GPR_GPR3_RDATA_WAIT_EN (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR3_RDATA_WAIT_EN. */
#define BS_IOMUXC_GPR_GPR3_RDATA_WAIT_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_RDATA_WAIT_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_RDATA_WAIT_EN field. */
#define BR_IOMUXC_GPR_GPR3_RDATA_WAIT_EN(x) (HW_IOMUXC_GPR_GPR3(x).B.RDATA_WAIT_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_RDATA_WAIT_EN. */
#define BF_IOMUXC_GPR_GPR3_RDATA_WAIT_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_RDATA_WAIT_EN) & BM_IOMUXC_GPR_GPR3_RDATA_WAIT_EN)

/*! @brief Set the RDATA_WAIT_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR3_RDATA_WAIT_EN(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_RDATA_WAIT_EN) | BF_IOMUXC_GPR_GPR3_RDATA_WAIT_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field RADDR_PIPE_EN[1] (RW)
 *
 * On-chip RAM read address pipeline enable When this feature is enabled, the
 * read address from the AXI master would be delayed 1 cycle before it can be
 * accepted by the on-chip RAM. This can avoid setup time issue for the read access on
 * the memory cell at high frequency. Enable this feature would cost at most 1
 * more clock cycle for each AXI read transaction, i.e., at most 1 more clock
 * cycle for each read burst with multiple beats of data. When this feature is
 * disabled, the read address from the AXI master can be accepted by the on-chip RAM
 * without delay, and data can become ready for master at next clock cycle (if no
 * other access and no read data wait).
 *
 * Values:
 * - 0 - read address pipeline is disabled
 * - 1 - read address pipeline is enabled
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_RADDR_PIPE_EN (1U) /*!< Bit position for IOMUXC_GPR_GPR3_RADDR_PIPE_EN. */
#define BM_IOMUXC_GPR_GPR3_RADDR_PIPE_EN (0x00000002U) /*!< Bit mask for IOMUXC_GPR_GPR3_RADDR_PIPE_EN. */
#define BS_IOMUXC_GPR_GPR3_RADDR_PIPE_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_RADDR_PIPE_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_RADDR_PIPE_EN field. */
#define BR_IOMUXC_GPR_GPR3_RADDR_PIPE_EN(x) (HW_IOMUXC_GPR_GPR3(x).B.RADDR_PIPE_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_RADDR_PIPE_EN. */
#define BF_IOMUXC_GPR_GPR3_RADDR_PIPE_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_RADDR_PIPE_EN) & BM_IOMUXC_GPR_GPR3_RADDR_PIPE_EN)

/*! @brief Set the RADDR_PIPE_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR3_RADDR_PIPE_EN(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_RADDR_PIPE_EN) | BF_IOMUXC_GPR_GPR3_RADDR_PIPE_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field WDATA_PIPE_EN[2] (RW)
 *
 * On-chip RAM write data pipeline enable When this feature is enabled, the
 * write data from the AXI master would be delayed 1 cycle before it can be accepted
 * by the on-chip RAM. This can avoid setup time issue for the write access on
 * the memory cell at high frequency. Enable this feature would cost at most 1 more
 * clock cycle for each AXI write transaction, i.e., at most 1 more clock cycle
 * for each write burst with multiple beats of data. When this feature is
 * disabled, the write data from the AXI master can be accepted by the on-chip RAM
 * without delay, and data can be written to memory at this cycle (if no other access
 * and write address is also ready at this cycle).
 *
 * Values:
 * - 0 - write data pipeline is disabled
 * - 1 - write data pipeline is enabled
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_WDATA_PIPE_EN (2U) /*!< Bit position for IOMUXC_GPR_GPR3_WDATA_PIPE_EN. */
#define BM_IOMUXC_GPR_GPR3_WDATA_PIPE_EN (0x00000004U) /*!< Bit mask for IOMUXC_GPR_GPR3_WDATA_PIPE_EN. */
#define BS_IOMUXC_GPR_GPR3_WDATA_PIPE_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_WDATA_PIPE_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_WDATA_PIPE_EN field. */
#define BR_IOMUXC_GPR_GPR3_WDATA_PIPE_EN(x) (HW_IOMUXC_GPR_GPR3(x).B.WDATA_PIPE_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_WDATA_PIPE_EN. */
#define BF_IOMUXC_GPR_GPR3_WDATA_PIPE_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_WDATA_PIPE_EN) & BM_IOMUXC_GPR_GPR3_WDATA_PIPE_EN)

/*! @brief Set the WDATA_PIPE_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR3_WDATA_PIPE_EN(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_WDATA_PIPE_EN) | BF_IOMUXC_GPR_GPR3_WDATA_PIPE_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field WADDR_PIPE_EN[3] (RW)
 *
 * On-chip RAM write address pipeline enable When this feature is enabled, the
 * write address from the AXI master would be delayed 1 cycle before it can be
 * accepted by the on-chip RAM. This can avoid setup time issue for the write access
 * on the memory cell at high frequency. Enable this feature would cost at most
 * 1 more clock cycle for each AXI write transaction, i.e., at most 1 more clock
 * cycle for each write burst with multiple beats of data. When this feature is
 * disabled, the write address from the AXI master can be accepted by the on-chip
 * RAM without delay, and data can be written to memory at this cycle (if no
 * other access and write data is also ready at this cycle). 0 write address pipeline
 * is disabled
 *
 * Values:
 * - 0 - write address pipeline is disabled
 * - 1 - write address pipeline is enabled
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_WADDR_PIPE_EN (3U) /*!< Bit position for IOMUXC_GPR_GPR3_WADDR_PIPE_EN. */
#define BM_IOMUXC_GPR_GPR3_WADDR_PIPE_EN (0x00000008U) /*!< Bit mask for IOMUXC_GPR_GPR3_WADDR_PIPE_EN. */
#define BS_IOMUXC_GPR_GPR3_WADDR_PIPE_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_WADDR_PIPE_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_WADDR_PIPE_EN field. */
#define BR_IOMUXC_GPR_GPR3_WADDR_PIPE_EN(x) (HW_IOMUXC_GPR_GPR3(x).B.WADDR_PIPE_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_WADDR_PIPE_EN. */
#define BF_IOMUXC_GPR_GPR3_WADDR_PIPE_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_WADDR_PIPE_EN) & BM_IOMUXC_GPR_GPR3_WADDR_PIPE_EN)

/*! @brief Set the WADDR_PIPE_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR3_WADDR_PIPE_EN(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_WADDR_PIPE_EN) | BF_IOMUXC_GPR_GPR3_WADDR_PIPE_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field S_RDATA_WAIT_EN[4] (RW)
 *
 * State Retention On-chip RAM read data wait state control For description,
 * please refer to RDATA_WAIT_EN bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN (4U) /*!< Bit position for IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN. */
#define BM_IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN (0x00000010U) /*!< Bit mask for IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN. */
#define BS_IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN field. */
#define BR_IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN(x) (HW_IOMUXC_GPR_GPR3(x).B.S_RDATA_WAIT_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN. */
#define BF_IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN) & BM_IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN)

/*! @brief Set the S_RDATA_WAIT_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN) | BF_IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field S_RADDR_PIPE_EN[5] (RW)
 *
 * State Retention On-chip RAM read address pipeline enable For description,
 * please refer to RADDR_PIPE_EN bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN (5U) /*!< Bit position for IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN. */
#define BM_IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN (0x00000020U) /*!< Bit mask for IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN. */
#define BS_IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN field. */
#define BR_IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN(x) (HW_IOMUXC_GPR_GPR3(x).B.S_RADDR_PIPE_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN. */
#define BF_IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN) & BM_IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN)

/*! @brief Set the S_RADDR_PIPE_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN) | BF_IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field S_WDATA_PIPE_EN[6] (RW)
 *
 * State Retention On-chip RAM write data pipeline enable For description,
 * please refer to WDATA_PIPE_EN bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN (6U) /*!< Bit position for IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN. */
#define BM_IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN (0x00000040U) /*!< Bit mask for IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN. */
#define BS_IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN field. */
#define BR_IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN(x) (HW_IOMUXC_GPR_GPR3(x).B.S_WDATA_PIPE_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN. */
#define BF_IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN) & BM_IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN)

/*! @brief Set the S_WDATA_PIPE_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN) | BF_IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field S_WADDR_PIPE_EN[7] (RW)
 *
 * State Retention On-chip RAM write address pipeline enable For description,
 * please refer to WADDR_PIPE_EN bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN (7U) /*!< Bit position for IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN. */
#define BM_IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN (0x00000080U) /*!< Bit mask for IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN. */
#define BS_IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN field. */
#define BR_IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN(x) (HW_IOMUXC_GPR_GPR3(x).B.S_WADDR_PIPE_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN. */
#define BF_IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN) & BM_IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN)

/*! @brief Set the S_WADDR_PIPE_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN) | BF_IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field E_RDATA_WAIT_EN[8] (RW)
 *
 * EPDC On-chip RAM read data wait state control For description, please refer
 * to RDATA_WAIT_EN bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN (8U) /*!< Bit position for IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN. */
#define BM_IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN (0x00000100U) /*!< Bit mask for IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN. */
#define BS_IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN field. */
#define BR_IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN(x) (HW_IOMUXC_GPR_GPR3(x).B.E_RDATA_WAIT_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN. */
#define BF_IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN) & BM_IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN)

/*! @brief Set the E_RDATA_WAIT_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN) | BF_IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field E_RADDR_PIPE_EN[9] (RW)
 *
 * EPDC On-chip RAM read address pipeline enable For description, please refer
 * to RADDR_PIPE_EN bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN (9U) /*!< Bit position for IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN. */
#define BM_IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN (0x00000200U) /*!< Bit mask for IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN. */
#define BS_IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN field. */
#define BR_IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN(x) (HW_IOMUXC_GPR_GPR3(x).B.E_RADDR_PIPE_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN. */
#define BF_IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN) & BM_IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN)

/*! @brief Set the E_RADDR_PIPE_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN) | BF_IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field E_WDATA_PIPE_EN[10] (RW)
 *
 * EPDC On-chip RAM write data pipeline enable For description, please refer to
 * WDATA_PIPE_EN bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN (10U) /*!< Bit position for IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN. */
#define BM_IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN (0x00000400U) /*!< Bit mask for IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN. */
#define BS_IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN field. */
#define BR_IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN(x) (HW_IOMUXC_GPR_GPR3(x).B.E_WDATA_PIPE_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN. */
#define BF_IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN) & BM_IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN)

/*! @brief Set the E_WDATA_PIPE_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN) | BF_IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field E_WADDR_PIPE_EN[11] (RW)
 *
 * EPDC On-chip RAM write address pipeline enable For description, please refer
 * to WADDR_PIPE_EN bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN (11U) /*!< Bit position for IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN. */
#define BM_IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN (0x00000800U) /*!< Bit mask for IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN. */
#define BS_IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN field. */
#define BR_IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN(x) (HW_IOMUXC_GPR_GPR3(x).B.E_WADDR_PIPE_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN. */
#define BF_IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN) & BM_IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN)

/*! @brief Set the E_WADDR_PIPE_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN) | BF_IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field P_RDATA_WAIT_EN[12] (RW)
 *
 * PXP On-chip RAM read data wait state control For description, please refer to
 * RDATA_WAIT_EN bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN (12U) /*!< Bit position for IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN. */
#define BM_IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN (0x00001000U) /*!< Bit mask for IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN. */
#define BS_IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN field. */
#define BR_IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN(x) (HW_IOMUXC_GPR_GPR3(x).B.P_RDATA_WAIT_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN. */
#define BF_IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN) & BM_IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN)

/*! @brief Set the P_RDATA_WAIT_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN) | BF_IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field P_RADDR_PIPE_EN[13] (RW)
 *
 * PXP On-chip RAM read address pipeline enable For description, please refer to
 * RADDR_PIPE_EN bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN (13U) /*!< Bit position for IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN. */
#define BM_IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN (0x00002000U) /*!< Bit mask for IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN. */
#define BS_IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN field. */
#define BR_IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN(x) (HW_IOMUXC_GPR_GPR3(x).B.P_RADDR_PIPE_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN. */
#define BF_IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN) & BM_IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN)

/*! @brief Set the P_RADDR_PIPE_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN) | BF_IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field P_WDATA_PIPE_EN[14] (RW)
 *
 * PXP On-chip RAM write data pipeline enable For description, please refer to
 * WDATA_PIPE_EN bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN (14U) /*!< Bit position for IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN. */
#define BM_IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN (0x00004000U) /*!< Bit mask for IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN. */
#define BS_IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN field. */
#define BR_IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN(x) (HW_IOMUXC_GPR_GPR3(x).B.P_WDATA_PIPE_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN. */
#define BF_IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN) & BM_IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN)

/*! @brief Set the P_WDATA_PIPE_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN) | BF_IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field P_WADDR_PIPE_EN[15] (RW)
 *
 * PXP On-chip RAM write address pipeline enable For description, please refer
 * to WADDR_PIPE_EN bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN (15U) /*!< Bit position for IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN. */
#define BM_IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN (0x00008000U) /*!< Bit mask for IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN. */
#define BS_IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN field. */
#define BR_IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN(x) (HW_IOMUXC_GPR_GPR3(x).B.P_WADDR_PIPE_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN. */
#define BF_IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN) & BM_IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN)

/*! @brief Set the P_WADDR_PIPE_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN(x, v) (HW_IOMUXC_GPR_GPR3_WR(x, (HW_IOMUXC_GPR_GPR3_RD(x) & ~BM_IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN) | BF_IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field RDATA_WAIT_EN_PDG[16] (RO)
 *
 * On-chip RAM read data wait state control update is pending
 *
 * Values:
 * - 0 - read data wait state control configuration valid
 * - 1 - read data wait state control bit changed
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_RDATA_WAIT_EN_PDG (16U) /*!< Bit position for IOMUXC_GPR_GPR3_RDATA_WAIT_EN_PDG. */
#define BM_IOMUXC_GPR_GPR3_RDATA_WAIT_EN_PDG (0x00010000U) /*!< Bit mask for IOMUXC_GPR_GPR3_RDATA_WAIT_EN_PDG. */
#define BS_IOMUXC_GPR_GPR3_RDATA_WAIT_EN_PDG (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_RDATA_WAIT_EN_PDG. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_RDATA_WAIT_EN_PDG field. */
#define BR_IOMUXC_GPR_GPR3_RDATA_WAIT_EN_PDG(x) (HW_IOMUXC_GPR_GPR3(x).B.RDATA_WAIT_EN_PDG)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field RADDR_PIPE_EN_PDG[17] (RO)
 *
 * On-chip RAM read address pipeline enable update is pending
 *
 * Values:
 * - 0 - read address pipeline enable configuration valid
 * - 1 - read address pipeline enable bit changed
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_RADDR_PIPE_EN_PDG (17U) /*!< Bit position for IOMUXC_GPR_GPR3_RADDR_PIPE_EN_PDG. */
#define BM_IOMUXC_GPR_GPR3_RADDR_PIPE_EN_PDG (0x00020000U) /*!< Bit mask for IOMUXC_GPR_GPR3_RADDR_PIPE_EN_PDG. */
#define BS_IOMUXC_GPR_GPR3_RADDR_PIPE_EN_PDG (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_RADDR_PIPE_EN_PDG. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_RADDR_PIPE_EN_PDG field. */
#define BR_IOMUXC_GPR_GPR3_RADDR_PIPE_EN_PDG(x) (HW_IOMUXC_GPR_GPR3(x).B.RADDR_PIPE_EN_PDG)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field WDATA_PIPE_EN_PDG[18] (RO)
 *
 * On-chip RAM write data pipeline enable update is pending
 *
 * Values:
 * - 0 - write data pipeline enable configuration valid
 * - 1 - write data pipeline enable bit changed
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_WDATA_PIPE_EN_PDG (18U) /*!< Bit position for IOMUXC_GPR_GPR3_WDATA_PIPE_EN_PDG. */
#define BM_IOMUXC_GPR_GPR3_WDATA_PIPE_EN_PDG (0x00040000U) /*!< Bit mask for IOMUXC_GPR_GPR3_WDATA_PIPE_EN_PDG. */
#define BS_IOMUXC_GPR_GPR3_WDATA_PIPE_EN_PDG (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_WDATA_PIPE_EN_PDG. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_WDATA_PIPE_EN_PDG field. */
#define BR_IOMUXC_GPR_GPR3_WDATA_PIPE_EN_PDG(x) (HW_IOMUXC_GPR_GPR3(x).B.WDATA_PIPE_EN_PDG)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field WADDR_PIPE_EN_PNDG[19] (RO)
 *
 * On-chip RAM write address pipeline enable update is pending
 *
 * Values:
 * - 0 - write address pipeline enable configuration valid
 * - 1 - write address pipeline enable bit changed
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_WADDR_PIPE_EN_PNDG (19U) /*!< Bit position for IOMUXC_GPR_GPR3_WADDR_PIPE_EN_PNDG. */
#define BM_IOMUXC_GPR_GPR3_WADDR_PIPE_EN_PNDG (0x00080000U) /*!< Bit mask for IOMUXC_GPR_GPR3_WADDR_PIPE_EN_PNDG. */
#define BS_IOMUXC_GPR_GPR3_WADDR_PIPE_EN_PNDG (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_WADDR_PIPE_EN_PNDG. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_WADDR_PIPE_EN_PNDG field. */
#define BR_IOMUXC_GPR_GPR3_WADDR_PIPE_EN_PNDG(x) (HW_IOMUXC_GPR_GPR3(x).B.WADDR_PIPE_EN_PNDG)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field S_RDATA_WAIT_EN_PNDG[20] (RO)
 *
 * State Retention On-chip RAM read data wait state control update is pending
 *
 * Values:
 * - 0 - read data wait state control configuration valid
 * - 1 - read data wait state control bit changed
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN_PNDG (20U) /*!< Bit position for IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN_PNDG. */
#define BM_IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN_PNDG (0x00100000U) /*!< Bit mask for IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN_PNDG. */
#define BS_IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN_PNDG (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN_PNDG. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN_PNDG field. */
#define BR_IOMUXC_GPR_GPR3_S_RDATA_WAIT_EN_PNDG(x) (HW_IOMUXC_GPR_GPR3(x).B.S_RDATA_WAIT_EN_PNDG)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field S_RADDR_PIPE_EN_PNDG[21] (RO)
 *
 * State Retention On-chip RAM read address pipeline enable update is pending
 *
 * Values:
 * - 0 - read address pipeline enable configuration valid
 * - 1 - read address pipeline enable bit changed
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN_PNDG (21U) /*!< Bit position for IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN_PNDG. */
#define BM_IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN_PNDG (0x00200000U) /*!< Bit mask for IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN_PNDG. */
#define BS_IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN_PNDG (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN_PNDG. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN_PNDG field. */
#define BR_IOMUXC_GPR_GPR3_S_RADDR_PIPE_EN_PNDG(x) (HW_IOMUXC_GPR_GPR3(x).B.S_RADDR_PIPE_EN_PNDG)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field S_WDATA_PIPE_EN_PNDG[22] (RO)
 *
 * State Retention On-chip RAM write data pipeline enable update is pending
 *
 * Values:
 * - 0 - write data pipeline enable configuration valid
 * - 1 - write data pipeline enable bit changed
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN_PNDG (22U) /*!< Bit position for IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN_PNDG. */
#define BM_IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN_PNDG (0x00400000U) /*!< Bit mask for IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN_PNDG. */
#define BS_IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN_PNDG (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN_PNDG. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN_PNDG field. */
#define BR_IOMUXC_GPR_GPR3_S_WDATA_PIPE_EN_PNDG(x) (HW_IOMUXC_GPR_GPR3(x).B.S_WDATA_PIPE_EN_PNDG)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field S_WADDR_PIPE_EN_PNDG[23] (RO)
 *
 * State Retention On-chip RAM write address pipeline enable update is pending
 *
 * Values:
 * - 0 - write address pipeline enable configuration valid
 * - 1 - write address pipeline enable bit changed
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN_PNDG (23U) /*!< Bit position for IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN_PNDG. */
#define BM_IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN_PNDG (0x00800000U) /*!< Bit mask for IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN_PNDG. */
#define BS_IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN_PNDG (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN_PNDG. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN_PNDG field. */
#define BR_IOMUXC_GPR_GPR3_S_WADDR_PIPE_EN_PNDG(x) (HW_IOMUXC_GPR_GPR3(x).B.S_WADDR_PIPE_EN_PNDG)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field E_RDATA_WAIT_EN_PNDG[24] (RO)
 *
 * EPDC On-chip RAM read data wait state control update is pending
 *
 * Values:
 * - 0 - read data wait state control configuration valid
 * - 1 - read data wait state control bit changed
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN_PNDG (24U) /*!< Bit position for IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN_PNDG. */
#define BM_IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN_PNDG (0x01000000U) /*!< Bit mask for IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN_PNDG. */
#define BS_IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN_PNDG (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN_PNDG. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN_PNDG field. */
#define BR_IOMUXC_GPR_GPR3_E_RDATA_WAIT_EN_PNDG(x) (HW_IOMUXC_GPR_GPR3(x).B.E_RDATA_WAIT_EN_PNDG)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field E_RADDR_PIPE_EN_PNDG[25] (RO)
 *
 * EPDC On-chip RAM read address pipeline enable update is pending
 *
 * Values:
 * - 0 - read address pipeline enable configuration valid
 * - 1 - read address pipeline enable bit changed
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN_PNDG (25U) /*!< Bit position for IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN_PNDG. */
#define BM_IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN_PNDG (0x02000000U) /*!< Bit mask for IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN_PNDG. */
#define BS_IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN_PNDG (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN_PNDG. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN_PNDG field. */
#define BR_IOMUXC_GPR_GPR3_E_RADDR_PIPE_EN_PNDG(x) (HW_IOMUXC_GPR_GPR3(x).B.E_RADDR_PIPE_EN_PNDG)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field E_WDATA_PIPE_EN_PNDG[26] (RO)
 *
 * EPDC On-chip RAM write data pipeline enable update is pending
 *
 * Values:
 * - 0 - write data pipeline enable configuration valid
 * - 1 - write data pipeline enable bit changed
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN_PNDG (26U) /*!< Bit position for IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN_PNDG. */
#define BM_IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN_PNDG (0x04000000U) /*!< Bit mask for IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN_PNDG. */
#define BS_IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN_PNDG (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN_PNDG. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN_PNDG field. */
#define BR_IOMUXC_GPR_GPR3_E_WDATA_PIPE_EN_PNDG(x) (HW_IOMUXC_GPR_GPR3(x).B.E_WDATA_PIPE_EN_PNDG)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field E_WADDR_PIPE_EN_PNDG[27] (RO)
 *
 * EPDC On-chip RAM write address pipeline enable update is pending
 *
 * Values:
 * - 0 - write address pipeline enable configuration valid
 * - 1 - write address pipeline enable bit changed
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN_PNDG (27U) /*!< Bit position for IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN_PNDG. */
#define BM_IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN_PNDG (0x08000000U) /*!< Bit mask for IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN_PNDG. */
#define BS_IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN_PNDG (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN_PNDG. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN_PNDG field. */
#define BR_IOMUXC_GPR_GPR3_E_WADDR_PIPE_EN_PNDG(x) (HW_IOMUXC_GPR_GPR3(x).B.E_WADDR_PIPE_EN_PNDG)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field P_RDATA_WAIT_EN_PNDG[28] (RO)
 *
 * PXP On-chip RAM read data wait state control update is pending
 *
 * Values:
 * - 0 - read data wait state control configuration valid
 * - 1 - read data wait state control bit changed
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN_PNDG (28U) /*!< Bit position for IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN_PNDG. */
#define BM_IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN_PNDG (0x10000000U) /*!< Bit mask for IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN_PNDG. */
#define BS_IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN_PNDG (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN_PNDG. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN_PNDG field. */
#define BR_IOMUXC_GPR_GPR3_P_RDATA_WAIT_EN_PNDG(x) (HW_IOMUXC_GPR_GPR3(x).B.P_RDATA_WAIT_EN_PNDG)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field P_RADDR_PIPE_EN_PNDG[29] (RO)
 *
 * PXP On-chip RAM read address pipeline enable update is pending
 *
 * Values:
 * - 0 - read address pipeline enable configuration valid
 * - 1 - read address pipeline enable bit changed
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN_PNDG (29U) /*!< Bit position for IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN_PNDG. */
#define BM_IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN_PNDG (0x20000000U) /*!< Bit mask for IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN_PNDG. */
#define BS_IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN_PNDG (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN_PNDG. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN_PNDG field. */
#define BR_IOMUXC_GPR_GPR3_P_RADDR_PIPE_EN_PNDG(x) (HW_IOMUXC_GPR_GPR3(x).B.P_RADDR_PIPE_EN_PNDG)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field P_WDATA_PIPE_EN_PNDG[30] (RO)
 *
 * PXP On-chip RAM write data pipeline enable update is pending
 *
 * Values:
 * - 0 - write data pipeline enable configuration valid
 * - 1 - write data pipeline enable bit changed
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN_PNDG (30U) /*!< Bit position for IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN_PNDG. */
#define BM_IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN_PNDG (0x40000000U) /*!< Bit mask for IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN_PNDG. */
#define BS_IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN_PNDG (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN_PNDG. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN_PNDG field. */
#define BR_IOMUXC_GPR_GPR3_P_WDATA_PIPE_EN_PNDG(x) (HW_IOMUXC_GPR_GPR3(x).B.P_WDATA_PIPE_EN_PNDG)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR3, field P_WADDR_PIPE_EN_PNDG[31] (RO)
 *
 * PXP On-chip RAM write address pipeline enable update is pending
 *
 * Values:
 * - 0 - write address pipeline enable configuration valid
 * - 1 - write address pipeline enable bit changed
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN_PNDG (31U) /*!< Bit position for IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN_PNDG. */
#define BM_IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN_PNDG (0x80000000U) /*!< Bit mask for IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN_PNDG. */
#define BS_IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN_PNDG (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN_PNDG. */

/*! @brief Read current value of the IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN_PNDG field. */
#define BR_IOMUXC_GPR_GPR3_P_WADDR_PIPE_EN_PNDG(x) (HW_IOMUXC_GPR_GPR3(x).B.P_WADDR_PIPE_EN_PNDG)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR4 - GPR4 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR4 - GPR4 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr4
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr4_bitfields
    {
        uint32_t SDMA_IPG_STOP : 1;    /*!< [0]  */
        uint32_t CAN1_IPG_STOP : 1;    /*!< [1]  */
        uint32_t CAN2_IPG_STOP : 1;    /*!< [2]  */
        uint32_t ENET1_IPG_STOP : 1;   /*!< [3]  */
        uint32_t ENET2_IPG_STOP : 1;   /*!< [4]  */
        uint32_t SAI1_IPG_STOP : 1;    /*!< [5]  */
        uint32_t SAI2_IPG_STOP : 1;    /*!< [6]  */
        uint32_t SAI3_IPG_STOP : 1;    /*!< [7]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t SDMA_IPG_STOP_ACK : 1; /*!< [16]  */
        uint32_t CAN1_IPG_STOP_ACK : 1; /*!< [17]  */
        uint32_t CAN2_IPG_STOP_ACK : 1; /*!< [18]  */
        uint32_t ENET1_IPG_STOP_ACK : 1; /*!< [19]  */
        uint32_t ENET2_IPG_STOP_ACK : 1; /*!< [20]  */
        uint32_t SAI1_IPG_STOP_ACK : 1; /*!< [21]  */
        uint32_t SAI2_IPG_STOP_ACK : 1; /*!< [22]  */
        uint32_t SAI3_IPG_STOP_ACK : 1; /*!< [23]  */
        uint32_t RESERVED1 : 1;        /*!< [24]  */
        uint32_t CPU_STANDBYWFI : 2;   /*!< [26:25]  */
        uint32_t CPU_STANDBYWFE : 2;   /*!< [28:27]  */
        uint32_t RESERVED2 : 3;        /*!< [31:29]  */
    } B;
} hw_iomuxc_gpr_gpr4_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR4 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR4_ADDR(x) ((uintptr_t)(x) + 0x10U)

#define HW_IOMUXC_GPR_GPR4(x)    (*(__IO hw_iomuxc_gpr_gpr4_t *) HW_IOMUXC_GPR_GPR4_ADDR(x))
#define HW_IOMUXC_GPR_GPR4_RD(x) (HW_IOMUXC_GPR_GPR4(x).U)
#define HW_IOMUXC_GPR_GPR4_WR(x, v) (HW_IOMUXC_GPR_GPR4(x).U = (v))
#define HW_IOMUXC_GPR_GPR4_SET(x, v) (HW_IOMUXC_GPR_GPR4_WR(x, HW_IOMUXC_GPR_GPR4_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR4_CLR(x, v) (HW_IOMUXC_GPR_GPR4_WR(x, HW_IOMUXC_GPR_GPR4_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR4_TOG(x, v) (HW_IOMUXC_GPR_GPR4_WR(x, HW_IOMUXC_GPR_GPR4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR4 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR4, field SDMA_IPG_STOP[0] (RW)
 *
 * SDMA stop request
 *
 * Values:
 * - 0 - stop request off
 * - 1 - stop request on
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_SDMA_IPG_STOP (0U) /*!< Bit position for IOMUXC_GPR_GPR4_SDMA_IPG_STOP. */
#define BM_IOMUXC_GPR_GPR4_SDMA_IPG_STOP (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR4_SDMA_IPG_STOP. */
#define BS_IOMUXC_GPR_GPR4_SDMA_IPG_STOP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_SDMA_IPG_STOP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_SDMA_IPG_STOP field. */
#define BR_IOMUXC_GPR_GPR4_SDMA_IPG_STOP(x) (HW_IOMUXC_GPR_GPR4(x).B.SDMA_IPG_STOP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR4_SDMA_IPG_STOP. */
#define BF_IOMUXC_GPR_GPR4_SDMA_IPG_STOP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR4_SDMA_IPG_STOP) & BM_IOMUXC_GPR_GPR4_SDMA_IPG_STOP)

/*! @brief Set the SDMA_IPG_STOP field to a new value. */
#define BW_IOMUXC_GPR_GPR4_SDMA_IPG_STOP(x, v) (HW_IOMUXC_GPR_GPR4_WR(x, (HW_IOMUXC_GPR_GPR4_RD(x) & ~BM_IOMUXC_GPR_GPR4_SDMA_IPG_STOP) | BF_IOMUXC_GPR_GPR4_SDMA_IPG_STOP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field CAN1_IPG_STOP[1] (RW)
 *
 * CAN1 stop request
 *
 * Values:
 * - 0 - stop request off
 * - 1 - stop request on
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_CAN1_IPG_STOP (1U) /*!< Bit position for IOMUXC_GPR_GPR4_CAN1_IPG_STOP. */
#define BM_IOMUXC_GPR_GPR4_CAN1_IPG_STOP (0x00000002U) /*!< Bit mask for IOMUXC_GPR_GPR4_CAN1_IPG_STOP. */
#define BS_IOMUXC_GPR_GPR4_CAN1_IPG_STOP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_CAN1_IPG_STOP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_CAN1_IPG_STOP field. */
#define BR_IOMUXC_GPR_GPR4_CAN1_IPG_STOP(x) (HW_IOMUXC_GPR_GPR4(x).B.CAN1_IPG_STOP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR4_CAN1_IPG_STOP. */
#define BF_IOMUXC_GPR_GPR4_CAN1_IPG_STOP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR4_CAN1_IPG_STOP) & BM_IOMUXC_GPR_GPR4_CAN1_IPG_STOP)

/*! @brief Set the CAN1_IPG_STOP field to a new value. */
#define BW_IOMUXC_GPR_GPR4_CAN1_IPG_STOP(x, v) (HW_IOMUXC_GPR_GPR4_WR(x, (HW_IOMUXC_GPR_GPR4_RD(x) & ~BM_IOMUXC_GPR_GPR4_CAN1_IPG_STOP) | BF_IOMUXC_GPR_GPR4_CAN1_IPG_STOP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field CAN2_IPG_STOP[2] (RW)
 *
 * CAN2 stop request
 *
 * Values:
 * - 0 - stop request off
 * - 1 - stop request on
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_CAN2_IPG_STOP (2U) /*!< Bit position for IOMUXC_GPR_GPR4_CAN2_IPG_STOP. */
#define BM_IOMUXC_GPR_GPR4_CAN2_IPG_STOP (0x00000004U) /*!< Bit mask for IOMUXC_GPR_GPR4_CAN2_IPG_STOP. */
#define BS_IOMUXC_GPR_GPR4_CAN2_IPG_STOP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_CAN2_IPG_STOP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_CAN2_IPG_STOP field. */
#define BR_IOMUXC_GPR_GPR4_CAN2_IPG_STOP(x) (HW_IOMUXC_GPR_GPR4(x).B.CAN2_IPG_STOP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR4_CAN2_IPG_STOP. */
#define BF_IOMUXC_GPR_GPR4_CAN2_IPG_STOP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR4_CAN2_IPG_STOP) & BM_IOMUXC_GPR_GPR4_CAN2_IPG_STOP)

/*! @brief Set the CAN2_IPG_STOP field to a new value. */
#define BW_IOMUXC_GPR_GPR4_CAN2_IPG_STOP(x, v) (HW_IOMUXC_GPR_GPR4_WR(x, (HW_IOMUXC_GPR_GPR4_RD(x) & ~BM_IOMUXC_GPR_GPR4_CAN2_IPG_STOP) | BF_IOMUXC_GPR_GPR4_CAN2_IPG_STOP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field ENET1_IPG_STOP[3] (RW)
 *
 * ENET1 stop request
 *
 * Values:
 * - 0 - stop request off
 * - 1 - stop request on
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_ENET1_IPG_STOP (3U) /*!< Bit position for IOMUXC_GPR_GPR4_ENET1_IPG_STOP. */
#define BM_IOMUXC_GPR_GPR4_ENET1_IPG_STOP (0x00000008U) /*!< Bit mask for IOMUXC_GPR_GPR4_ENET1_IPG_STOP. */
#define BS_IOMUXC_GPR_GPR4_ENET1_IPG_STOP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_ENET1_IPG_STOP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_ENET1_IPG_STOP field. */
#define BR_IOMUXC_GPR_GPR4_ENET1_IPG_STOP(x) (HW_IOMUXC_GPR_GPR4(x).B.ENET1_IPG_STOP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR4_ENET1_IPG_STOP. */
#define BF_IOMUXC_GPR_GPR4_ENET1_IPG_STOP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR4_ENET1_IPG_STOP) & BM_IOMUXC_GPR_GPR4_ENET1_IPG_STOP)

/*! @brief Set the ENET1_IPG_STOP field to a new value. */
#define BW_IOMUXC_GPR_GPR4_ENET1_IPG_STOP(x, v) (HW_IOMUXC_GPR_GPR4_WR(x, (HW_IOMUXC_GPR_GPR4_RD(x) & ~BM_IOMUXC_GPR_GPR4_ENET1_IPG_STOP) | BF_IOMUXC_GPR_GPR4_ENET1_IPG_STOP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field ENET2_IPG_STOP[4] (RW)
 *
 * ENET2 stop request
 *
 * Values:
 * - 0 - stop request off
 * - 1 - stop request on
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_ENET2_IPG_STOP (4U) /*!< Bit position for IOMUXC_GPR_GPR4_ENET2_IPG_STOP. */
#define BM_IOMUXC_GPR_GPR4_ENET2_IPG_STOP (0x00000010U) /*!< Bit mask for IOMUXC_GPR_GPR4_ENET2_IPG_STOP. */
#define BS_IOMUXC_GPR_GPR4_ENET2_IPG_STOP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_ENET2_IPG_STOP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_ENET2_IPG_STOP field. */
#define BR_IOMUXC_GPR_GPR4_ENET2_IPG_STOP(x) (HW_IOMUXC_GPR_GPR4(x).B.ENET2_IPG_STOP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR4_ENET2_IPG_STOP. */
#define BF_IOMUXC_GPR_GPR4_ENET2_IPG_STOP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR4_ENET2_IPG_STOP) & BM_IOMUXC_GPR_GPR4_ENET2_IPG_STOP)

/*! @brief Set the ENET2_IPG_STOP field to a new value. */
#define BW_IOMUXC_GPR_GPR4_ENET2_IPG_STOP(x, v) (HW_IOMUXC_GPR_GPR4_WR(x, (HW_IOMUXC_GPR_GPR4_RD(x) & ~BM_IOMUXC_GPR_GPR4_ENET2_IPG_STOP) | BF_IOMUXC_GPR_GPR4_ENET2_IPG_STOP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field SAI1_IPG_STOP[5] (RW)
 *
 * SAI1 stop request
 *
 * Values:
 * - 0 - stop request off
 * - 1 - stop request on
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_SAI1_IPG_STOP (5U) /*!< Bit position for IOMUXC_GPR_GPR4_SAI1_IPG_STOP. */
#define BM_IOMUXC_GPR_GPR4_SAI1_IPG_STOP (0x00000020U) /*!< Bit mask for IOMUXC_GPR_GPR4_SAI1_IPG_STOP. */
#define BS_IOMUXC_GPR_GPR4_SAI1_IPG_STOP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_SAI1_IPG_STOP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_SAI1_IPG_STOP field. */
#define BR_IOMUXC_GPR_GPR4_SAI1_IPG_STOP(x) (HW_IOMUXC_GPR_GPR4(x).B.SAI1_IPG_STOP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR4_SAI1_IPG_STOP. */
#define BF_IOMUXC_GPR_GPR4_SAI1_IPG_STOP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR4_SAI1_IPG_STOP) & BM_IOMUXC_GPR_GPR4_SAI1_IPG_STOP)

/*! @brief Set the SAI1_IPG_STOP field to a new value. */
#define BW_IOMUXC_GPR_GPR4_SAI1_IPG_STOP(x, v) (HW_IOMUXC_GPR_GPR4_WR(x, (HW_IOMUXC_GPR_GPR4_RD(x) & ~BM_IOMUXC_GPR_GPR4_SAI1_IPG_STOP) | BF_IOMUXC_GPR_GPR4_SAI1_IPG_STOP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field SAI2_IPG_STOP[6] (RW)
 *
 * SAI2 stop request
 *
 * Values:
 * - 0 - stop request off
 * - 1 - stop request on
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_SAI2_IPG_STOP (6U) /*!< Bit position for IOMUXC_GPR_GPR4_SAI2_IPG_STOP. */
#define BM_IOMUXC_GPR_GPR4_SAI2_IPG_STOP (0x00000040U) /*!< Bit mask for IOMUXC_GPR_GPR4_SAI2_IPG_STOP. */
#define BS_IOMUXC_GPR_GPR4_SAI2_IPG_STOP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_SAI2_IPG_STOP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_SAI2_IPG_STOP field. */
#define BR_IOMUXC_GPR_GPR4_SAI2_IPG_STOP(x) (HW_IOMUXC_GPR_GPR4(x).B.SAI2_IPG_STOP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR4_SAI2_IPG_STOP. */
#define BF_IOMUXC_GPR_GPR4_SAI2_IPG_STOP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR4_SAI2_IPG_STOP) & BM_IOMUXC_GPR_GPR4_SAI2_IPG_STOP)

/*! @brief Set the SAI2_IPG_STOP field to a new value. */
#define BW_IOMUXC_GPR_GPR4_SAI2_IPG_STOP(x, v) (HW_IOMUXC_GPR_GPR4_WR(x, (HW_IOMUXC_GPR_GPR4_RD(x) & ~BM_IOMUXC_GPR_GPR4_SAI2_IPG_STOP) | BF_IOMUXC_GPR_GPR4_SAI2_IPG_STOP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field SAI3_IPG_STOP[7] (RW)
 *
 * SAI3 stop request
 *
 * Values:
 * - 0 - stop request off
 * - 1 - stop request on
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_SAI3_IPG_STOP (7U) /*!< Bit position for IOMUXC_GPR_GPR4_SAI3_IPG_STOP. */
#define BM_IOMUXC_GPR_GPR4_SAI3_IPG_STOP (0x00000080U) /*!< Bit mask for IOMUXC_GPR_GPR4_SAI3_IPG_STOP. */
#define BS_IOMUXC_GPR_GPR4_SAI3_IPG_STOP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_SAI3_IPG_STOP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_SAI3_IPG_STOP field. */
#define BR_IOMUXC_GPR_GPR4_SAI3_IPG_STOP(x) (HW_IOMUXC_GPR_GPR4(x).B.SAI3_IPG_STOP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR4_SAI3_IPG_STOP. */
#define BF_IOMUXC_GPR_GPR4_SAI3_IPG_STOP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR4_SAI3_IPG_STOP) & BM_IOMUXC_GPR_GPR4_SAI3_IPG_STOP)

/*! @brief Set the SAI3_IPG_STOP field to a new value. */
#define BW_IOMUXC_GPR_GPR4_SAI3_IPG_STOP(x, v) (HW_IOMUXC_GPR_GPR4_WR(x, (HW_IOMUXC_GPR_GPR4_RD(x) & ~BM_IOMUXC_GPR_GPR4_SAI3_IPG_STOP) | BF_IOMUXC_GPR_GPR4_SAI3_IPG_STOP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field SDMA_IPG_STOP_ACK[16] (RO)
 *
 * SDMA stop acknowledge
 *
 * Values:
 * - 0 - stop acknowledge is not asserted
 * - 1 - stop acknowledge is asserted, peripheral is in STOP mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_SDMA_IPG_STOP_ACK (16U) /*!< Bit position for IOMUXC_GPR_GPR4_SDMA_IPG_STOP_ACK. */
#define BM_IOMUXC_GPR_GPR4_SDMA_IPG_STOP_ACK (0x00010000U) /*!< Bit mask for IOMUXC_GPR_GPR4_SDMA_IPG_STOP_ACK. */
#define BS_IOMUXC_GPR_GPR4_SDMA_IPG_STOP_ACK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_SDMA_IPG_STOP_ACK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_SDMA_IPG_STOP_ACK field. */
#define BR_IOMUXC_GPR_GPR4_SDMA_IPG_STOP_ACK(x) (HW_IOMUXC_GPR_GPR4(x).B.SDMA_IPG_STOP_ACK)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field CAN1_IPG_STOP_ACK[17] (RO)
 *
 * CAN1 stop acknowledge
 *
 * Values:
 * - 0 - stop acknowledge is not asserted
 * - 1 - stop acknowledge is asserted, peripheral is in STOP mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_CAN1_IPG_STOP_ACK (17U) /*!< Bit position for IOMUXC_GPR_GPR4_CAN1_IPG_STOP_ACK. */
#define BM_IOMUXC_GPR_GPR4_CAN1_IPG_STOP_ACK (0x00020000U) /*!< Bit mask for IOMUXC_GPR_GPR4_CAN1_IPG_STOP_ACK. */
#define BS_IOMUXC_GPR_GPR4_CAN1_IPG_STOP_ACK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_CAN1_IPG_STOP_ACK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_CAN1_IPG_STOP_ACK field. */
#define BR_IOMUXC_GPR_GPR4_CAN1_IPG_STOP_ACK(x) (HW_IOMUXC_GPR_GPR4(x).B.CAN1_IPG_STOP_ACK)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field CAN2_IPG_STOP_ACK[18] (RO)
 *
 * CAN2 stop acknowledge
 *
 * Values:
 * - 0 - stop acknowledge is not asserted
 * - 1 - stop acknowledge is asserted, peripheral is in STOP mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_CAN2_IPG_STOP_ACK (18U) /*!< Bit position for IOMUXC_GPR_GPR4_CAN2_IPG_STOP_ACK. */
#define BM_IOMUXC_GPR_GPR4_CAN2_IPG_STOP_ACK (0x00040000U) /*!< Bit mask for IOMUXC_GPR_GPR4_CAN2_IPG_STOP_ACK. */
#define BS_IOMUXC_GPR_GPR4_CAN2_IPG_STOP_ACK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_CAN2_IPG_STOP_ACK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_CAN2_IPG_STOP_ACK field. */
#define BR_IOMUXC_GPR_GPR4_CAN2_IPG_STOP_ACK(x) (HW_IOMUXC_GPR_GPR4(x).B.CAN2_IPG_STOP_ACK)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field ENET1_IPG_STOP_ACK[19] (RO)
 *
 * ENET1 stop acknowledge
 *
 * Values:
 * - 0 - stop acknowledge is not asserted
 * - 1 - stop acknowledge is asserted, peripheral is in STOP mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_ENET1_IPG_STOP_ACK (19U) /*!< Bit position for IOMUXC_GPR_GPR4_ENET1_IPG_STOP_ACK. */
#define BM_IOMUXC_GPR_GPR4_ENET1_IPG_STOP_ACK (0x00080000U) /*!< Bit mask for IOMUXC_GPR_GPR4_ENET1_IPG_STOP_ACK. */
#define BS_IOMUXC_GPR_GPR4_ENET1_IPG_STOP_ACK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_ENET1_IPG_STOP_ACK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_ENET1_IPG_STOP_ACK field. */
#define BR_IOMUXC_GPR_GPR4_ENET1_IPG_STOP_ACK(x) (HW_IOMUXC_GPR_GPR4(x).B.ENET1_IPG_STOP_ACK)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field ENET2_IPG_STOP_ACK[20] (RO)
 *
 * ENET2 stop acknowledge
 *
 * Values:
 * - 0 - stop acknowledge is not asserted
 * - 1 - stop acknowledge is asserted, peripheral is in STOP mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_ENET2_IPG_STOP_ACK (20U) /*!< Bit position for IOMUXC_GPR_GPR4_ENET2_IPG_STOP_ACK. */
#define BM_IOMUXC_GPR_GPR4_ENET2_IPG_STOP_ACK (0x00100000U) /*!< Bit mask for IOMUXC_GPR_GPR4_ENET2_IPG_STOP_ACK. */
#define BS_IOMUXC_GPR_GPR4_ENET2_IPG_STOP_ACK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_ENET2_IPG_STOP_ACK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_ENET2_IPG_STOP_ACK field. */
#define BR_IOMUXC_GPR_GPR4_ENET2_IPG_STOP_ACK(x) (HW_IOMUXC_GPR_GPR4(x).B.ENET2_IPG_STOP_ACK)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field SAI1_IPG_STOP_ACK[21] (RO)
 *
 * SAI1 stop acknowledge
 *
 * Values:
 * - 0 - stop acknowledge is not asserted
 * - 1 - stop acknowledge is asserted, peripheral is in STOP mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_SAI1_IPG_STOP_ACK (21U) /*!< Bit position for IOMUXC_GPR_GPR4_SAI1_IPG_STOP_ACK. */
#define BM_IOMUXC_GPR_GPR4_SAI1_IPG_STOP_ACK (0x00200000U) /*!< Bit mask for IOMUXC_GPR_GPR4_SAI1_IPG_STOP_ACK. */
#define BS_IOMUXC_GPR_GPR4_SAI1_IPG_STOP_ACK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_SAI1_IPG_STOP_ACK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_SAI1_IPG_STOP_ACK field. */
#define BR_IOMUXC_GPR_GPR4_SAI1_IPG_STOP_ACK(x) (HW_IOMUXC_GPR_GPR4(x).B.SAI1_IPG_STOP_ACK)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field SAI2_IPG_STOP_ACK[22] (RO)
 *
 * SAI2 stop acknowledge
 *
 * Values:
 * - 0 - stop acknowledge is not asserted
 * - 1 - stop acknowledge is asserted, peripheral is in STOP mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_SAI2_IPG_STOP_ACK (22U) /*!< Bit position for IOMUXC_GPR_GPR4_SAI2_IPG_STOP_ACK. */
#define BM_IOMUXC_GPR_GPR4_SAI2_IPG_STOP_ACK (0x00400000U) /*!< Bit mask for IOMUXC_GPR_GPR4_SAI2_IPG_STOP_ACK. */
#define BS_IOMUXC_GPR_GPR4_SAI2_IPG_STOP_ACK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_SAI2_IPG_STOP_ACK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_SAI2_IPG_STOP_ACK field. */
#define BR_IOMUXC_GPR_GPR4_SAI2_IPG_STOP_ACK(x) (HW_IOMUXC_GPR_GPR4(x).B.SAI2_IPG_STOP_ACK)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field SAI3_IPG_STOP_ACK[23] (RO)
 *
 * SAI3 stop acknowledge
 *
 * Values:
 * - 0 - stop acknowledge is not asserted
 * - 1 - stop acknowledge is asserted, peripheral is in STOP mode
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_SAI3_IPG_STOP_ACK (23U) /*!< Bit position for IOMUXC_GPR_GPR4_SAI3_IPG_STOP_ACK. */
#define BM_IOMUXC_GPR_GPR4_SAI3_IPG_STOP_ACK (0x00800000U) /*!< Bit mask for IOMUXC_GPR_GPR4_SAI3_IPG_STOP_ACK. */
#define BS_IOMUXC_GPR_GPR4_SAI3_IPG_STOP_ACK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_SAI3_IPG_STOP_ACK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_SAI3_IPG_STOP_ACK field. */
#define BR_IOMUXC_GPR_GPR4_SAI3_IPG_STOP_ACK(x) (HW_IOMUXC_GPR_GPR4(x).B.SAI3_IPG_STOP_ACK)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field CPU_STANDBYWFI[26:25] (RO)
 *
 * Status of CPU STANDBYWFI low power states MSB: status of A7 core 1 STANDBYWFI
 * low power state LSB: status of A7 core 0 STANDBYWFI low power state
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_CPU_STANDBYWFI (25U) /*!< Bit position for IOMUXC_GPR_GPR4_CPU_STANDBYWFI. */
#define BM_IOMUXC_GPR_GPR4_CPU_STANDBYWFI (0x06000000U) /*!< Bit mask for IOMUXC_GPR_GPR4_CPU_STANDBYWFI. */
#define BS_IOMUXC_GPR_GPR4_CPU_STANDBYWFI (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_CPU_STANDBYWFI. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_CPU_STANDBYWFI field. */
#define BR_IOMUXC_GPR_GPR4_CPU_STANDBYWFI(x) (HW_IOMUXC_GPR_GPR4(x).B.CPU_STANDBYWFI)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR4, field CPU_STANDBYWFE[28:27] (RO)
 *
 * Status of CPU STANDBYWFE low power states MSB: status of A7 core 1 STANDBYWFE
 * low power state LSB: status of A7 core 0 STANDBYWFE low power state
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR4_CPU_STANDBYWFE (27U) /*!< Bit position for IOMUXC_GPR_GPR4_CPU_STANDBYWFE. */
#define BM_IOMUXC_GPR_GPR4_CPU_STANDBYWFE (0x18000000U) /*!< Bit mask for IOMUXC_GPR_GPR4_CPU_STANDBYWFE. */
#define BS_IOMUXC_GPR_GPR4_CPU_STANDBYWFE (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR4_CPU_STANDBYWFE. */

/*! @brief Read current value of the IOMUXC_GPR_GPR4_CPU_STANDBYWFE field. */
#define BR_IOMUXC_GPR_GPR4_CPU_STANDBYWFE(x) (HW_IOMUXC_GPR_GPR4(x).B.CPU_STANDBYWFE)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR5 - GPR5 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR5 - GPR5 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr5
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr5_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t CSI_MUX_CONTROL : 1;  /*!< [4]  */
        uint32_t LVDS_MUX_CONTROL : 1; /*!< [5]  */
        uint32_t WDOG1_MASK : 1;       /*!< [6]  */
        uint32_t WDOG2_MASK : 1;       /*!< [7]  */
        uint32_t RESERVED1 : 4;        /*!< [11:8]  */
        uint32_t LCDIF_HANDSHAKE : 1;  /*!< [12]  */
        uint32_t RESERVED2 : 6;        /*!< [18:13]  */
        uint32_t PCIE_BTNRST : 1;      /*!< [19]  */
        uint32_t WDOG3_MASK : 1;       /*!< [20]  */
        uint32_t LCDIF_CSI_VSYNC_SEL : 1; /*!< [21]  */
        uint32_t WDOG4_MASK : 1;       /*!< [22]  */
        uint32_t RESERVED3 : 1;        /*!< [23]  */
        uint32_t GPT4_CAPIN1_SEL : 1;  /*!< [24]  */
        uint32_t GPT4_CAPIN2_SEL : 1;  /*!< [25]  */
        uint32_t ENET1_EVENT3IN_SEL : 1; /*!< [26]  */
        uint32_t ENET2_EVENT3IN_SEL : 1; /*!< [27]  */
        uint32_t REF_1M_CLK_GPT1 : 1;  /*!< [28]  */
        uint32_t REF_1M_CLK_GPT2 : 1;  /*!< [29]  */
        uint32_t REF_1M_CLK_GPT3 : 1;  /*!< [30]  */
        uint32_t REF_1M_CLK_GPT4 : 1;  /*!< [31]  */
    } B;
} hw_iomuxc_gpr_gpr5_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR5 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR5_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_IOMUXC_GPR_GPR5(x)    (*(__IO hw_iomuxc_gpr_gpr5_t *) HW_IOMUXC_GPR_GPR5_ADDR(x))
#define HW_IOMUXC_GPR_GPR5_RD(x) (HW_IOMUXC_GPR_GPR5(x).U)
#define HW_IOMUXC_GPR_GPR5_WR(x, v) (HW_IOMUXC_GPR_GPR5(x).U = (v))
#define HW_IOMUXC_GPR_GPR5_SET(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, HW_IOMUXC_GPR_GPR5_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR5_CLR(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, HW_IOMUXC_GPR_GPR5_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR5_TOG(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, HW_IOMUXC_GPR_GPR5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR5 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR5, field CSI_MUX_CONTROL[4] (RW)
 *
 * CSI Input MUX Control
 *
 * Values:
 * - 0 - CSI input is driven by Parallel CSI
 * - 1 - CSI input is driven by MIPI CSI
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_CSI_MUX_CONTROL (4U) /*!< Bit position for IOMUXC_GPR_GPR5_CSI_MUX_CONTROL. */
#define BM_IOMUXC_GPR_GPR5_CSI_MUX_CONTROL (0x00000010U) /*!< Bit mask for IOMUXC_GPR_GPR5_CSI_MUX_CONTROL. */
#define BS_IOMUXC_GPR_GPR5_CSI_MUX_CONTROL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_CSI_MUX_CONTROL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_CSI_MUX_CONTROL field. */
#define BR_IOMUXC_GPR_GPR5_CSI_MUX_CONTROL(x) (HW_IOMUXC_GPR_GPR5(x).B.CSI_MUX_CONTROL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_CSI_MUX_CONTROL. */
#define BF_IOMUXC_GPR_GPR5_CSI_MUX_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_CSI_MUX_CONTROL) & BM_IOMUXC_GPR_GPR5_CSI_MUX_CONTROL)

/*! @brief Set the CSI_MUX_CONTROL field to a new value. */
#define BW_IOMUXC_GPR_GPR5_CSI_MUX_CONTROL(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_CSI_MUX_CONTROL) | BF_IOMUXC_GPR_GPR5_CSI_MUX_CONTROL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field LVDS_MUX_CONTROL[5] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_LVDS_MUX_CONTROL (5U) /*!< Bit position for IOMUXC_GPR_GPR5_LVDS_MUX_CONTROL. */
#define BM_IOMUXC_GPR_GPR5_LVDS_MUX_CONTROL (0x00000020U) /*!< Bit mask for IOMUXC_GPR_GPR5_LVDS_MUX_CONTROL. */
#define BS_IOMUXC_GPR_GPR5_LVDS_MUX_CONTROL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_LVDS_MUX_CONTROL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_LVDS_MUX_CONTROL field. */
#define BR_IOMUXC_GPR_GPR5_LVDS_MUX_CONTROL(x) (HW_IOMUXC_GPR_GPR5(x).B.LVDS_MUX_CONTROL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_LVDS_MUX_CONTROL. */
#define BF_IOMUXC_GPR_GPR5_LVDS_MUX_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_LVDS_MUX_CONTROL) & BM_IOMUXC_GPR_GPR5_LVDS_MUX_CONTROL)

/*! @brief Set the LVDS_MUX_CONTROL field to a new value. */
#define BW_IOMUXC_GPR_GPR5_LVDS_MUX_CONTROL(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_LVDS_MUX_CONTROL) | BF_IOMUXC_GPR_GPR5_LVDS_MUX_CONTROL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field WDOG1_MASK[6] (RW)
 *
 * WDOG1 Timeout Mask
 *
 * Values:
 * - 0 - WDOG1 Timeout behaves normally
 * - 1 - WDOG1 Timeout is masked
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_WDOG1_MASK (6U) /*!< Bit position for IOMUXC_GPR_GPR5_WDOG1_MASK. */
#define BM_IOMUXC_GPR_GPR5_WDOG1_MASK (0x00000040U) /*!< Bit mask for IOMUXC_GPR_GPR5_WDOG1_MASK. */
#define BS_IOMUXC_GPR_GPR5_WDOG1_MASK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_WDOG1_MASK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_WDOG1_MASK field. */
#define BR_IOMUXC_GPR_GPR5_WDOG1_MASK(x) (HW_IOMUXC_GPR_GPR5(x).B.WDOG1_MASK)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_WDOG1_MASK. */
#define BF_IOMUXC_GPR_GPR5_WDOG1_MASK(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_WDOG1_MASK) & BM_IOMUXC_GPR_GPR5_WDOG1_MASK)

/*! @brief Set the WDOG1_MASK field to a new value. */
#define BW_IOMUXC_GPR_GPR5_WDOG1_MASK(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_WDOG1_MASK) | BF_IOMUXC_GPR_GPR5_WDOG1_MASK(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field WDOG2_MASK[7] (RW)
 *
 * WDOG2 Timeout Mask
 *
 * Values:
 * - 0 - WDOG2 Timeout behaves normally
 * - 1 - WDOG2 Timeout is masked
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_WDOG2_MASK (7U) /*!< Bit position for IOMUXC_GPR_GPR5_WDOG2_MASK. */
#define BM_IOMUXC_GPR_GPR5_WDOG2_MASK (0x00000080U) /*!< Bit mask for IOMUXC_GPR_GPR5_WDOG2_MASK. */
#define BS_IOMUXC_GPR_GPR5_WDOG2_MASK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_WDOG2_MASK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_WDOG2_MASK field. */
#define BR_IOMUXC_GPR_GPR5_WDOG2_MASK(x) (HW_IOMUXC_GPR_GPR5(x).B.WDOG2_MASK)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_WDOG2_MASK. */
#define BF_IOMUXC_GPR_GPR5_WDOG2_MASK(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_WDOG2_MASK) & BM_IOMUXC_GPR_GPR5_WDOG2_MASK)

/*! @brief Set the WDOG2_MASK field to a new value. */
#define BW_IOMUXC_GPR_GPR5_WDOG2_MASK(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_WDOG2_MASK) | BF_IOMUXC_GPR_GPR5_WDOG2_MASK(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field LCDIF_HANDSHAKE[12] (RW)
 *
 * LCDIF Input Handshake Select
 *
 * Values:
 * - 0 - LCDIF input handshake signals come from CSI
 * - 1 - LCDIF input handshake signals come from PXP
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE (12U) /*!< Bit position for IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE. */
#define BM_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE (0x00001000U) /*!< Bit mask for IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE. */
#define BS_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE field. */
#define BR_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE(x) (HW_IOMUXC_GPR_GPR5(x).B.LCDIF_HANDSHAKE)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE. */
#define BF_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE) & BM_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE)

/*! @brief Set the LCDIF_HANDSHAKE field to a new value. */
#define BW_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE) | BF_IOMUXC_GPR_GPR5_LCDIF_HANDSHAKE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field PCIE_BTNRST[19] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_PCIE_BTNRST (19U) /*!< Bit position for IOMUXC_GPR_GPR5_PCIE_BTNRST. */
#define BM_IOMUXC_GPR_GPR5_PCIE_BTNRST (0x00080000U) /*!< Bit mask for IOMUXC_GPR_GPR5_PCIE_BTNRST. */
#define BS_IOMUXC_GPR_GPR5_PCIE_BTNRST (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_PCIE_BTNRST. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_PCIE_BTNRST field. */
#define BR_IOMUXC_GPR_GPR5_PCIE_BTNRST(x) (HW_IOMUXC_GPR_GPR5(x).B.PCIE_BTNRST)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_PCIE_BTNRST. */
#define BF_IOMUXC_GPR_GPR5_PCIE_BTNRST(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_PCIE_BTNRST) & BM_IOMUXC_GPR_GPR5_PCIE_BTNRST)

/*! @brief Set the PCIE_BTNRST field to a new value. */
#define BW_IOMUXC_GPR_GPR5_PCIE_BTNRST(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_PCIE_BTNRST) | BF_IOMUXC_GPR_GPR5_PCIE_BTNRST(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field WDOG3_MASK[20] (RW)
 *
 * WDOG3 Timeout Mask
 *
 * Values:
 * - 0 - WDOG3 Timeout behaves normally
 * - 1 - WDOG3 Timeout is masked
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_WDOG3_MASK (20U) /*!< Bit position for IOMUXC_GPR_GPR5_WDOG3_MASK. */
#define BM_IOMUXC_GPR_GPR5_WDOG3_MASK (0x00100000U) /*!< Bit mask for IOMUXC_GPR_GPR5_WDOG3_MASK. */
#define BS_IOMUXC_GPR_GPR5_WDOG3_MASK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_WDOG3_MASK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_WDOG3_MASK field. */
#define BR_IOMUXC_GPR_GPR5_WDOG3_MASK(x) (HW_IOMUXC_GPR_GPR5(x).B.WDOG3_MASK)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_WDOG3_MASK. */
#define BF_IOMUXC_GPR_GPR5_WDOG3_MASK(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_WDOG3_MASK) & BM_IOMUXC_GPR_GPR5_WDOG3_MASK)

/*! @brief Set the WDOG3_MASK field to a new value. */
#define BW_IOMUXC_GPR_GPR5_WDOG3_MASK(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_WDOG3_MASK) | BF_IOMUXC_GPR_GPR5_WDOG3_MASK(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field LCDIF_CSI_VSYNC_SEL[21] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_LCDIF_CSI_VSYNC_SEL (21U) /*!< Bit position for IOMUXC_GPR_GPR5_LCDIF_CSI_VSYNC_SEL. */
#define BM_IOMUXC_GPR_GPR5_LCDIF_CSI_VSYNC_SEL (0x00200000U) /*!< Bit mask for IOMUXC_GPR_GPR5_LCDIF_CSI_VSYNC_SEL. */
#define BS_IOMUXC_GPR_GPR5_LCDIF_CSI_VSYNC_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_LCDIF_CSI_VSYNC_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_LCDIF_CSI_VSYNC_SEL field. */
#define BR_IOMUXC_GPR_GPR5_LCDIF_CSI_VSYNC_SEL(x) (HW_IOMUXC_GPR_GPR5(x).B.LCDIF_CSI_VSYNC_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_LCDIF_CSI_VSYNC_SEL. */
#define BF_IOMUXC_GPR_GPR5_LCDIF_CSI_VSYNC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_LCDIF_CSI_VSYNC_SEL) & BM_IOMUXC_GPR_GPR5_LCDIF_CSI_VSYNC_SEL)

/*! @brief Set the LCDIF_CSI_VSYNC_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR5_LCDIF_CSI_VSYNC_SEL(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_LCDIF_CSI_VSYNC_SEL) | BF_IOMUXC_GPR_GPR5_LCDIF_CSI_VSYNC_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field WDOG4_MASK[22] (RW)
 *
 * WDOG4 Timeout Mask
 *
 * Values:
 * - 0 - WDOG4 Timeout behaves normally
 * - 1 - WDOG4 Timeout is masked
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_WDOG4_MASK (22U) /*!< Bit position for IOMUXC_GPR_GPR5_WDOG4_MASK. */
#define BM_IOMUXC_GPR_GPR5_WDOG4_MASK (0x00400000U) /*!< Bit mask for IOMUXC_GPR_GPR5_WDOG4_MASK. */
#define BS_IOMUXC_GPR_GPR5_WDOG4_MASK (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_WDOG4_MASK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_WDOG4_MASK field. */
#define BR_IOMUXC_GPR_GPR5_WDOG4_MASK(x) (HW_IOMUXC_GPR_GPR5(x).B.WDOG4_MASK)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_WDOG4_MASK. */
#define BF_IOMUXC_GPR_GPR5_WDOG4_MASK(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_WDOG4_MASK) & BM_IOMUXC_GPR_GPR5_WDOG4_MASK)

/*! @brief Set the WDOG4_MASK field to a new value. */
#define BW_IOMUXC_GPR_GPR5_WDOG4_MASK(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_WDOG4_MASK) | BF_IOMUXC_GPR_GPR5_WDOG4_MASK(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field GPT4_CAPIN1_SEL[24] (RW)
 *
 * GPT4 Capture Channel 1 Trigger Signal Select
 *
 * Values:
 * - 0 - Select GPT4 CAPTURE1 signal from PAD
 * - 1 - Select ENET1 1588 Event 3
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_GPT4_CAPIN1_SEL (24U) /*!< Bit position for IOMUXC_GPR_GPR5_GPT4_CAPIN1_SEL. */
#define BM_IOMUXC_GPR_GPR5_GPT4_CAPIN1_SEL (0x01000000U) /*!< Bit mask for IOMUXC_GPR_GPR5_GPT4_CAPIN1_SEL. */
#define BS_IOMUXC_GPR_GPR5_GPT4_CAPIN1_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_GPT4_CAPIN1_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_GPT4_CAPIN1_SEL field. */
#define BR_IOMUXC_GPR_GPR5_GPT4_CAPIN1_SEL(x) (HW_IOMUXC_GPR_GPR5(x).B.GPT4_CAPIN1_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_GPT4_CAPIN1_SEL. */
#define BF_IOMUXC_GPR_GPR5_GPT4_CAPIN1_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_GPT4_CAPIN1_SEL) & BM_IOMUXC_GPR_GPR5_GPT4_CAPIN1_SEL)

/*! @brief Set the GPT4_CAPIN1_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR5_GPT4_CAPIN1_SEL(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_GPT4_CAPIN1_SEL) | BF_IOMUXC_GPR_GPR5_GPT4_CAPIN1_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field GPT4_CAPIN2_SEL[25] (RW)
 *
 * GPT4 Capture Channel 2 Trigger Signal Select
 *
 * Values:
 * - 0 - Select GPT4 CAPTURE2 signal from PAD
 * - 1 - Select ENET2 1588 Event 3
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_GPT4_CAPIN2_SEL (25U) /*!< Bit position for IOMUXC_GPR_GPR5_GPT4_CAPIN2_SEL. */
#define BM_IOMUXC_GPR_GPR5_GPT4_CAPIN2_SEL (0x02000000U) /*!< Bit mask for IOMUXC_GPR_GPR5_GPT4_CAPIN2_SEL. */
#define BS_IOMUXC_GPR_GPR5_GPT4_CAPIN2_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_GPT4_CAPIN2_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_GPT4_CAPIN2_SEL field. */
#define BR_IOMUXC_GPR_GPR5_GPT4_CAPIN2_SEL(x) (HW_IOMUXC_GPR_GPR5(x).B.GPT4_CAPIN2_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_GPT4_CAPIN2_SEL. */
#define BF_IOMUXC_GPR_GPR5_GPT4_CAPIN2_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_GPT4_CAPIN2_SEL) & BM_IOMUXC_GPR_GPR5_GPT4_CAPIN2_SEL)

/*! @brief Set the GPT4_CAPIN2_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR5_GPT4_CAPIN2_SEL(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_GPT4_CAPIN2_SEL) | BF_IOMUXC_GPR_GPR5_GPT4_CAPIN2_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field ENET1_EVENT3IN_SEL[26] (RW)
 *
 * ENET1 Mac 0 1588 Timer Event 3 Select
 *
 * Values:
 * - 0 - Timer event is driven by PAD
 * - 1 - Timer event is driven by GPT4 Channel 1 Compare Output
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_ENET1_EVENT3IN_SEL (26U) /*!< Bit position for IOMUXC_GPR_GPR5_ENET1_EVENT3IN_SEL. */
#define BM_IOMUXC_GPR_GPR5_ENET1_EVENT3IN_SEL (0x04000000U) /*!< Bit mask for IOMUXC_GPR_GPR5_ENET1_EVENT3IN_SEL. */
#define BS_IOMUXC_GPR_GPR5_ENET1_EVENT3IN_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_ENET1_EVENT3IN_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_ENET1_EVENT3IN_SEL field. */
#define BR_IOMUXC_GPR_GPR5_ENET1_EVENT3IN_SEL(x) (HW_IOMUXC_GPR_GPR5(x).B.ENET1_EVENT3IN_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_ENET1_EVENT3IN_SEL. */
#define BF_IOMUXC_GPR_GPR5_ENET1_EVENT3IN_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_ENET1_EVENT3IN_SEL) & BM_IOMUXC_GPR_GPR5_ENET1_EVENT3IN_SEL)

/*! @brief Set the ENET1_EVENT3IN_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR5_ENET1_EVENT3IN_SEL(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_ENET1_EVENT3IN_SEL) | BF_IOMUXC_GPR_GPR5_ENET1_EVENT3IN_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field ENET2_EVENT3IN_SEL[27] (RW)
 *
 * ENET2 Mac 0 1588 Timer Event 3 Select
 *
 * Values:
 * - 0 - Timer event is driven by PAD
 * - 1 - Timer event is driven by GPT4 Channel 2 Compare Output
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_ENET2_EVENT3IN_SEL (27U) /*!< Bit position for IOMUXC_GPR_GPR5_ENET2_EVENT3IN_SEL. */
#define BM_IOMUXC_GPR_GPR5_ENET2_EVENT3IN_SEL (0x08000000U) /*!< Bit mask for IOMUXC_GPR_GPR5_ENET2_EVENT3IN_SEL. */
#define BS_IOMUXC_GPR_GPR5_ENET2_EVENT3IN_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_ENET2_EVENT3IN_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_ENET2_EVENT3IN_SEL field. */
#define BR_IOMUXC_GPR_GPR5_ENET2_EVENT3IN_SEL(x) (HW_IOMUXC_GPR_GPR5(x).B.ENET2_EVENT3IN_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_ENET2_EVENT3IN_SEL. */
#define BF_IOMUXC_GPR_GPR5_ENET2_EVENT3IN_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_ENET2_EVENT3IN_SEL) & BM_IOMUXC_GPR_GPR5_ENET2_EVENT3IN_SEL)

/*! @brief Set the ENET2_EVENT3IN_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR5_ENET2_EVENT3IN_SEL(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_ENET2_EVENT3IN_SEL) | BF_IOMUXC_GPR_GPR5_ENET2_EVENT3IN_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field REF_1M_CLK_GPT1[28] (RW)
 *
 * GPT1 1MHz clock source select
 *
 * Values:
 * - 0 - GPT ipg_clk_highfreq driven by CCM GPT clock
 * - 1 - GPT ipg_clk_highfreq driven by anatop 1MHz clock
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT1 (28U) /*!< Bit position for IOMUXC_GPR_GPR5_REF_1M_CLK_GPT1. */
#define BM_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT1 (0x10000000U) /*!< Bit mask for IOMUXC_GPR_GPR5_REF_1M_CLK_GPT1. */
#define BS_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT1 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_REF_1M_CLK_GPT1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_REF_1M_CLK_GPT1 field. */
#define BR_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT1(x) (HW_IOMUXC_GPR_GPR5(x).B.REF_1M_CLK_GPT1)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_REF_1M_CLK_GPT1. */
#define BF_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT1(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT1) & BM_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT1)

/*! @brief Set the REF_1M_CLK_GPT1 field to a new value. */
#define BW_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT1(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT1) | BF_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT1(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field REF_1M_CLK_GPT2[29] (RW)
 *
 * GPT2 1MHz clock source select
 *
 * Values:
 * - 0 - GPT ipg_clk_highfreq driven by CCM GPT clock
 * - 1 - GPT ipg_clk_highfreq driven by anatop 1MHz clock
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT2 (29U) /*!< Bit position for IOMUXC_GPR_GPR5_REF_1M_CLK_GPT2. */
#define BM_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT2 (0x20000000U) /*!< Bit mask for IOMUXC_GPR_GPR5_REF_1M_CLK_GPT2. */
#define BS_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT2 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_REF_1M_CLK_GPT2. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_REF_1M_CLK_GPT2 field. */
#define BR_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT2(x) (HW_IOMUXC_GPR_GPR5(x).B.REF_1M_CLK_GPT2)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_REF_1M_CLK_GPT2. */
#define BF_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT2(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT2) & BM_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT2)

/*! @brief Set the REF_1M_CLK_GPT2 field to a new value. */
#define BW_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT2(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT2) | BF_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT2(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field REF_1M_CLK_GPT3[30] (RW)
 *
 * GPT3 1MHz clock source select
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT3 (30U) /*!< Bit position for IOMUXC_GPR_GPR5_REF_1M_CLK_GPT3. */
#define BM_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT3 (0x40000000U) /*!< Bit mask for IOMUXC_GPR_GPR5_REF_1M_CLK_GPT3. */
#define BS_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT3 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_REF_1M_CLK_GPT3. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_REF_1M_CLK_GPT3 field. */
#define BR_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT3(x) (HW_IOMUXC_GPR_GPR5(x).B.REF_1M_CLK_GPT3)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_REF_1M_CLK_GPT3. */
#define BF_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT3(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT3) & BM_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT3)

/*! @brief Set the REF_1M_CLK_GPT3 field to a new value. */
#define BW_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT3(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT3) | BF_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT3(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR5, field REF_1M_CLK_GPT4[31] (RW)
 *
 * Reference 1M clock GPT4
 *
 * Values:
 * - 0 - GPT ipg_clk_highfreq driven by CCM GPT clock
 * - 1 - GPT ipg_clk_highfreq driven by anatop 1MHz clock
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT4 (31U) /*!< Bit position for IOMUXC_GPR_GPR5_REF_1M_CLK_GPT4. */
#define BM_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT4 (0x80000000U) /*!< Bit mask for IOMUXC_GPR_GPR5_REF_1M_CLK_GPT4. */
#define BS_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT4 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR5_REF_1M_CLK_GPT4. */

/*! @brief Read current value of the IOMUXC_GPR_GPR5_REF_1M_CLK_GPT4 field. */
#define BR_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT4(x) (HW_IOMUXC_GPR_GPR5(x).B.REF_1M_CLK_GPT4)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR5_REF_1M_CLK_GPT4. */
#define BF_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT4(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT4) & BM_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT4)

/*! @brief Set the REF_1M_CLK_GPT4 field to a new value. */
#define BW_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT4(x, v) (HW_IOMUXC_GPR_GPR5_WR(x, (HW_IOMUXC_GPR_GPR5_RD(x) & ~BM_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT4) | BF_IOMUXC_GPR_GPR5_REF_1M_CLK_GPT4(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR6 - GPR6 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR6 - GPR6 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr6
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr6_bitfields
    {
        uint32_t ARCACHE_PXP6 : 1;     /*!< [0]  */
        uint32_t AWCACHE_PXP6 : 1;     /*!< [1]  */
        uint32_t ARCACHE_PXP6_EN : 1;  /*!< [2]  */
        uint32_t AWCACHE_PXP6_EN : 1;  /*!< [3]  */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_iomuxc_gpr_gpr6_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR6 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR6_ADDR(x) ((uintptr_t)(x) + 0x18U)

#define HW_IOMUXC_GPR_GPR6(x)    (*(__IO hw_iomuxc_gpr_gpr6_t *) HW_IOMUXC_GPR_GPR6_ADDR(x))
#define HW_IOMUXC_GPR_GPR6_RD(x) (HW_IOMUXC_GPR_GPR6(x).U)
#define HW_IOMUXC_GPR_GPR6_WR(x, v) (HW_IOMUXC_GPR_GPR6(x).U = (v))
#define HW_IOMUXC_GPR_GPR6_SET(x, v) (HW_IOMUXC_GPR_GPR6_WR(x, HW_IOMUXC_GPR_GPR6_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR6_CLR(x, v) (HW_IOMUXC_GPR_GPR6_WR(x, HW_IOMUXC_GPR_GPR6_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR6_TOG(x, v) (HW_IOMUXC_GPR_GPR6_WR(x, HW_IOMUXC_GPR_GPR6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR6 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR6, field ARCACHE_PXP6[0] (RW)
 *
 * PXP Secondary AXI Master Port ARCACHE Override Value Note: this bit only
 * takes effect when ARCACHE_PXP6_EN = 1
 *
 * Values:
 * - 0 - Drive PXP Secondary AXI Master Port ARCACHE[1] to 0
 * - 1 - Drive PXP Secondary AXI Master Port ARCACHE[1] to 1
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR6_ARCACHE_PXP6 (0U) /*!< Bit position for IOMUXC_GPR_GPR6_ARCACHE_PXP6. */
#define BM_IOMUXC_GPR_GPR6_ARCACHE_PXP6 (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR6_ARCACHE_PXP6. */
#define BS_IOMUXC_GPR_GPR6_ARCACHE_PXP6 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR6_ARCACHE_PXP6. */

/*! @brief Read current value of the IOMUXC_GPR_GPR6_ARCACHE_PXP6 field. */
#define BR_IOMUXC_GPR_GPR6_ARCACHE_PXP6(x) (HW_IOMUXC_GPR_GPR6(x).B.ARCACHE_PXP6)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR6_ARCACHE_PXP6. */
#define BF_IOMUXC_GPR_GPR6_ARCACHE_PXP6(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR6_ARCACHE_PXP6) & BM_IOMUXC_GPR_GPR6_ARCACHE_PXP6)

/*! @brief Set the ARCACHE_PXP6 field to a new value. */
#define BW_IOMUXC_GPR_GPR6_ARCACHE_PXP6(x, v) (HW_IOMUXC_GPR_GPR6_WR(x, (HW_IOMUXC_GPR_GPR6_RD(x) & ~BM_IOMUXC_GPR_GPR6_ARCACHE_PXP6) | BF_IOMUXC_GPR_GPR6_ARCACHE_PXP6(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR6, field AWCACHE_PXP6[1] (RW)
 *
 * PXP Secondary AXI Master Port AWCACHE Override Value Note: this bit only
 * takes effect when AWCACHE_PXP6_EN = 1
 *
 * Values:
 * - 0 - Drive PXP Secondary AXI Master Port AWCACHE[1] to 0
 * - 1 - Drive PXP Secondary AXI Master Port AWCACHE[1] to 1
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR6_AWCACHE_PXP6 (1U) /*!< Bit position for IOMUXC_GPR_GPR6_AWCACHE_PXP6. */
#define BM_IOMUXC_GPR_GPR6_AWCACHE_PXP6 (0x00000002U) /*!< Bit mask for IOMUXC_GPR_GPR6_AWCACHE_PXP6. */
#define BS_IOMUXC_GPR_GPR6_AWCACHE_PXP6 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR6_AWCACHE_PXP6. */

/*! @brief Read current value of the IOMUXC_GPR_GPR6_AWCACHE_PXP6 field. */
#define BR_IOMUXC_GPR_GPR6_AWCACHE_PXP6(x) (HW_IOMUXC_GPR_GPR6(x).B.AWCACHE_PXP6)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR6_AWCACHE_PXP6. */
#define BF_IOMUXC_GPR_GPR6_AWCACHE_PXP6(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR6_AWCACHE_PXP6) & BM_IOMUXC_GPR_GPR6_AWCACHE_PXP6)

/*! @brief Set the AWCACHE_PXP6 field to a new value. */
#define BW_IOMUXC_GPR_GPR6_AWCACHE_PXP6(x, v) (HW_IOMUXC_GPR_GPR6_WR(x, (HW_IOMUXC_GPR_GPR6_RD(x) & ~BM_IOMUXC_GPR_GPR6_AWCACHE_PXP6) | BF_IOMUXC_GPR_GPR6_AWCACHE_PXP6(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR6, field ARCACHE_PXP6_EN[2] (RW)
 *
 * PXP Secondary AXI Master Port ARCACHE Override Enable
 *
 * Values:
 * - 0 - PXP Secondary AXI Master Port ARCACHE[1] driven by PXP
 * - 1 - PXP Secondary AXI Master Port ARCACHE[1] driven to constant value
 *     specified by the ARCACHE_PXP6 bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR6_ARCACHE_PXP6_EN (2U) /*!< Bit position for IOMUXC_GPR_GPR6_ARCACHE_PXP6_EN. */
#define BM_IOMUXC_GPR_GPR6_ARCACHE_PXP6_EN (0x00000004U) /*!< Bit mask for IOMUXC_GPR_GPR6_ARCACHE_PXP6_EN. */
#define BS_IOMUXC_GPR_GPR6_ARCACHE_PXP6_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR6_ARCACHE_PXP6_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR6_ARCACHE_PXP6_EN field. */
#define BR_IOMUXC_GPR_GPR6_ARCACHE_PXP6_EN(x) (HW_IOMUXC_GPR_GPR6(x).B.ARCACHE_PXP6_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR6_ARCACHE_PXP6_EN. */
#define BF_IOMUXC_GPR_GPR6_ARCACHE_PXP6_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR6_ARCACHE_PXP6_EN) & BM_IOMUXC_GPR_GPR6_ARCACHE_PXP6_EN)

/*! @brief Set the ARCACHE_PXP6_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR6_ARCACHE_PXP6_EN(x, v) (HW_IOMUXC_GPR_GPR6_WR(x, (HW_IOMUXC_GPR_GPR6_RD(x) & ~BM_IOMUXC_GPR_GPR6_ARCACHE_PXP6_EN) | BF_IOMUXC_GPR_GPR6_ARCACHE_PXP6_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR6, field AWCACHE_PXP6_EN[3] (RW)
 *
 * PXP Secondary AXI Master Port AWCACHE Override Enable
 *
 * Values:
 * - 0 - PXP Secondary AXI Master Port AWCACHE[1] driven by PXP
 * - 1 - PXP Secondary AXI Master Port AWCACHE[1] driven to constant value
 *     specified by the AWCACHE_PXP6 bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR6_AWCACHE_PXP6_EN (3U) /*!< Bit position for IOMUXC_GPR_GPR6_AWCACHE_PXP6_EN. */
#define BM_IOMUXC_GPR_GPR6_AWCACHE_PXP6_EN (0x00000008U) /*!< Bit mask for IOMUXC_GPR_GPR6_AWCACHE_PXP6_EN. */
#define BS_IOMUXC_GPR_GPR6_AWCACHE_PXP6_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR6_AWCACHE_PXP6_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR6_AWCACHE_PXP6_EN field. */
#define BR_IOMUXC_GPR_GPR6_AWCACHE_PXP6_EN(x) (HW_IOMUXC_GPR_GPR6(x).B.AWCACHE_PXP6_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR6_AWCACHE_PXP6_EN. */
#define BF_IOMUXC_GPR_GPR6_AWCACHE_PXP6_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR6_AWCACHE_PXP6_EN) & BM_IOMUXC_GPR_GPR6_AWCACHE_PXP6_EN)

/*! @brief Set the AWCACHE_PXP6_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR6_AWCACHE_PXP6_EN(x, v) (HW_IOMUXC_GPR_GPR6_WR(x, (HW_IOMUXC_GPR_GPR6_RD(x) & ~BM_IOMUXC_GPR_GPR6_AWCACHE_PXP6_EN) | BF_IOMUXC_GPR_GPR6_AWCACHE_PXP6_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR7 - GPR7 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR7 - GPR7 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr7
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr7_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t OTG1_LDO_USB_1P0_EN_PWRUPLOAD : 1; /*!< [3]  */
        uint32_t RESERVED1 : 5;        /*!< [8:4]  */
        uint32_t OTG2_LDO_USB_1P0_EN_PWRUPLOAD : 1; /*!< [9]  */
        uint32_t RESERVED2 : 22;       /*!< [31:10]  */
    } B;
} hw_iomuxc_gpr_gpr7_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR7 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR7_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_IOMUXC_GPR_GPR7(x)    (*(__IO hw_iomuxc_gpr_gpr7_t *) HW_IOMUXC_GPR_GPR7_ADDR(x))
#define HW_IOMUXC_GPR_GPR7_RD(x) (HW_IOMUXC_GPR_GPR7(x).U)
#define HW_IOMUXC_GPR_GPR7_WR(x, v) (HW_IOMUXC_GPR_GPR7(x).U = (v))
#define HW_IOMUXC_GPR_GPR7_SET(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, HW_IOMUXC_GPR_GPR7_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR7_CLR(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, HW_IOMUXC_GPR_GPR7_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR7_TOG(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, HW_IOMUXC_GPR_GPR7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR7 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR7, field OTG1_LDO_USB_1P0_EN_PWRUPLOAD[3] (RW)
 *
 * This bit field controls an internal resistive load on the OTG1 PHY's
 * LDO_USB_1P0 output pin, VDD_USB_OTG1_1P0_CAP. Enabling this load pulls the LDO_USB_1P0
 * supply to ground when no 3.3v USB power is present on the VDD_USB_OTG1_3P3_IN
 * pin.
 *
 * Values:
 * - 0 - Internal resistive pulldown for LDO_USB_1P0 is disabled. (Default)
 * - 1 - Internal resistive pulldown for LDO_USB_1P0 is enabled.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR7_OTG1_LDO_USB_1P0_EN_PWRUPLOAD (3U) /*!< Bit position for IOMUXC_GPR_GPR7_OTG1_LDO_USB_1P0_EN_PWRUPLOAD. */
#define BM_IOMUXC_GPR_GPR7_OTG1_LDO_USB_1P0_EN_PWRUPLOAD (0x00000008U) /*!< Bit mask for IOMUXC_GPR_GPR7_OTG1_LDO_USB_1P0_EN_PWRUPLOAD. */
#define BS_IOMUXC_GPR_GPR7_OTG1_LDO_USB_1P0_EN_PWRUPLOAD (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR7_OTG1_LDO_USB_1P0_EN_PWRUPLOAD. */

/*! @brief Read current value of the IOMUXC_GPR_GPR7_OTG1_LDO_USB_1P0_EN_PWRUPLOAD field. */
#define BR_IOMUXC_GPR_GPR7_OTG1_LDO_USB_1P0_EN_PWRUPLOAD(x) (HW_IOMUXC_GPR_GPR7(x).B.OTG1_LDO_USB_1P0_EN_PWRUPLOAD)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR7_OTG1_LDO_USB_1P0_EN_PWRUPLOAD. */
#define BF_IOMUXC_GPR_GPR7_OTG1_LDO_USB_1P0_EN_PWRUPLOAD(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR7_OTG1_LDO_USB_1P0_EN_PWRUPLOAD) & BM_IOMUXC_GPR_GPR7_OTG1_LDO_USB_1P0_EN_PWRUPLOAD)

/*! @brief Set the OTG1_LDO_USB_1P0_EN_PWRUPLOAD field to a new value. */
#define BW_IOMUXC_GPR_GPR7_OTG1_LDO_USB_1P0_EN_PWRUPLOAD(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, (HW_IOMUXC_GPR_GPR7_RD(x) & ~BM_IOMUXC_GPR_GPR7_OTG1_LDO_USB_1P0_EN_PWRUPLOAD) | BF_IOMUXC_GPR_GPR7_OTG1_LDO_USB_1P0_EN_PWRUPLOAD(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR7, field OTG2_LDO_USB_1P0_EN_PWRUPLOAD[9] (RW)
 *
 * This bit field controls an internal resistive load on the OTG2 PHY's
 * LDO_USB_1P0 output pin, VDD_USB_OTG2_1P0_CAP. Enabling this load pulls the LDO_USB_1P0
 * supply to ground when no 3.3v USB power is present on the VDD_USB_OTG2_3P3_IN
 * pin.
 *
 * Values:
 * - 0 - Internal resistive pulldown for LDO_USB_1P0 is disabled. (Default)
 * - 1 - Internal resistive pulldown for LDO_USB_1P0 is enabled.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR7_OTG2_LDO_USB_1P0_EN_PWRUPLOAD (9U) /*!< Bit position for IOMUXC_GPR_GPR7_OTG2_LDO_USB_1P0_EN_PWRUPLOAD. */
#define BM_IOMUXC_GPR_GPR7_OTG2_LDO_USB_1P0_EN_PWRUPLOAD (0x00000200U) /*!< Bit mask for IOMUXC_GPR_GPR7_OTG2_LDO_USB_1P0_EN_PWRUPLOAD. */
#define BS_IOMUXC_GPR_GPR7_OTG2_LDO_USB_1P0_EN_PWRUPLOAD (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR7_OTG2_LDO_USB_1P0_EN_PWRUPLOAD. */

/*! @brief Read current value of the IOMUXC_GPR_GPR7_OTG2_LDO_USB_1P0_EN_PWRUPLOAD field. */
#define BR_IOMUXC_GPR_GPR7_OTG2_LDO_USB_1P0_EN_PWRUPLOAD(x) (HW_IOMUXC_GPR_GPR7(x).B.OTG2_LDO_USB_1P0_EN_PWRUPLOAD)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR7_OTG2_LDO_USB_1P0_EN_PWRUPLOAD. */
#define BF_IOMUXC_GPR_GPR7_OTG2_LDO_USB_1P0_EN_PWRUPLOAD(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR7_OTG2_LDO_USB_1P0_EN_PWRUPLOAD) & BM_IOMUXC_GPR_GPR7_OTG2_LDO_USB_1P0_EN_PWRUPLOAD)

/*! @brief Set the OTG2_LDO_USB_1P0_EN_PWRUPLOAD field to a new value. */
#define BW_IOMUXC_GPR_GPR7_OTG2_LDO_USB_1P0_EN_PWRUPLOAD(x, v) (HW_IOMUXC_GPR_GPR7_WR(x, (HW_IOMUXC_GPR_GPR7_RD(x) & ~BM_IOMUXC_GPR_GPR7_OTG2_LDO_USB_1P0_EN_PWRUPLOAD) | BF_IOMUXC_GPR_GPR7_OTG2_LDO_USB_1P0_EN_PWRUPLOAD(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR8 - GPR8 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR8 - GPR8 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr8
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr8_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t DDR_PHY_CTRL_WAKE_UP : 5; /*!< [7:3]  */
        uint32_t DDR_PHY_DFI_INIT_START : 1; /*!< [8]  */
        uint32_t RESERVED1 : 23;       /*!< [31:9]  */
    } B;
} hw_iomuxc_gpr_gpr8_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR8 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR8_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_IOMUXC_GPR_GPR8(x)    (*(__IO hw_iomuxc_gpr_gpr8_t *) HW_IOMUXC_GPR_GPR8_ADDR(x))
#define HW_IOMUXC_GPR_GPR8_RD(x) (HW_IOMUXC_GPR_GPR8(x).U)
#define HW_IOMUXC_GPR_GPR8_WR(x, v) (HW_IOMUXC_GPR_GPR8(x).U = (v))
#define HW_IOMUXC_GPR_GPR8_SET(x, v) (HW_IOMUXC_GPR_GPR8_WR(x, HW_IOMUXC_GPR_GPR8_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR8_CLR(x, v) (HW_IOMUXC_GPR_GPR8_WR(x, HW_IOMUXC_GPR_GPR8_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR8_TOG(x, v) (HW_IOMUXC_GPR_GPR8_WR(x, HW_IOMUXC_GPR_GPR8_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR8 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR8, field DDR_PHY_CTRL_WAKE_UP[7:3] (RW)
 *
 * Drives ctrl_wake_up[4:0] inputs on DDR PHY
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP (3U) /*!< Bit position for IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP. */
#define BM_IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP (0x000000F8U) /*!< Bit mask for IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP. */
#define BS_IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP (5U) /*!< Bit field size in bits for IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP field. */
#define BR_IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP(x) (HW_IOMUXC_GPR_GPR8(x).B.DDR_PHY_CTRL_WAKE_UP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP. */
#define BF_IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP) & BM_IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP)

/*! @brief Set the DDR_PHY_CTRL_WAKE_UP field to a new value. */
#define BW_IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP(x, v) (HW_IOMUXC_GPR_GPR8_WR(x, (HW_IOMUXC_GPR_GPR8_RD(x) & ~BM_IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP) | BF_IOMUXC_GPR_GPR8_DDR_PHY_CTRL_WAKE_UP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR8, field DDR_PHY_DFI_INIT_START[8] (RW)
 *
 * Drives dfi_init_start input on DDR PHY
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR8_DDR_PHY_DFI_INIT_START (8U) /*!< Bit position for IOMUXC_GPR_GPR8_DDR_PHY_DFI_INIT_START. */
#define BM_IOMUXC_GPR_GPR8_DDR_PHY_DFI_INIT_START (0x00000100U) /*!< Bit mask for IOMUXC_GPR_GPR8_DDR_PHY_DFI_INIT_START. */
#define BS_IOMUXC_GPR_GPR8_DDR_PHY_DFI_INIT_START (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR8_DDR_PHY_DFI_INIT_START. */

/*! @brief Read current value of the IOMUXC_GPR_GPR8_DDR_PHY_DFI_INIT_START field. */
#define BR_IOMUXC_GPR_GPR8_DDR_PHY_DFI_INIT_START(x) (HW_IOMUXC_GPR_GPR8(x).B.DDR_PHY_DFI_INIT_START)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR8_DDR_PHY_DFI_INIT_START. */
#define BF_IOMUXC_GPR_GPR8_DDR_PHY_DFI_INIT_START(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR8_DDR_PHY_DFI_INIT_START) & BM_IOMUXC_GPR_GPR8_DDR_PHY_DFI_INIT_START)

/*! @brief Set the DDR_PHY_DFI_INIT_START field to a new value. */
#define BW_IOMUXC_GPR_GPR8_DDR_PHY_DFI_INIT_START(x, v) (HW_IOMUXC_GPR_GPR8_WR(x, (HW_IOMUXC_GPR_GPR8_RD(x) & ~BM_IOMUXC_GPR_GPR8_DDR_PHY_DFI_INIT_START) | BF_IOMUXC_GPR_GPR8_DDR_PHY_DFI_INIT_START(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR9 - GPR9 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR9 - GPR9 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr9
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr9_bitfields
    {
        uint32_t TZASC1_MUX_CONTROL : 1; /*!< [0]  */
        uint32_t DDR_PHY_CTRL_PD : 5;  /*!< [5:1]  */
        uint32_t RESERVED0 : 26;       /*!< [31:6]  */
    } B;
} hw_iomuxc_gpr_gpr9_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR9 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR9_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_IOMUXC_GPR_GPR9(x)    (*(__IO hw_iomuxc_gpr_gpr9_t *) HW_IOMUXC_GPR_GPR9_ADDR(x))
#define HW_IOMUXC_GPR_GPR9_RD(x) (HW_IOMUXC_GPR_GPR9(x).U)
#define HW_IOMUXC_GPR_GPR9_WR(x, v) (HW_IOMUXC_GPR_GPR9(x).U = (v))
#define HW_IOMUXC_GPR_GPR9_SET(x, v) (HW_IOMUXC_GPR_GPR9_WR(x, HW_IOMUXC_GPR_GPR9_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR9_CLR(x, v) (HW_IOMUXC_GPR_GPR9_WR(x, HW_IOMUXC_GPR_GPR9_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR9_TOG(x, v) (HW_IOMUXC_GPR_GPR9_WR(x, HW_IOMUXC_GPR_GPR9_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR9 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR9, field TZASC1_MUX_CONTROL[0] (RW)
 *
 * TrustZone Address Space Controller Select This bit is "sticky" to 1. Once
 * this bit is written to 1, it cannot be written back to 0.
 *
 * Values:
 * - 0 - AXI bus connected to DDR Controller bypasses the TrustZone Address
 *     Space Controller
 * - 1 - AXI bus connected to DDR Controller passes through the TrustZone
 *     Address Space Controller
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR9_TZASC1_MUX_CONTROL (0U) /*!< Bit position for IOMUXC_GPR_GPR9_TZASC1_MUX_CONTROL. */
#define BM_IOMUXC_GPR_GPR9_TZASC1_MUX_CONTROL (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR9_TZASC1_MUX_CONTROL. */
#define BS_IOMUXC_GPR_GPR9_TZASC1_MUX_CONTROL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR9_TZASC1_MUX_CONTROL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR9_TZASC1_MUX_CONTROL field. */
#define BR_IOMUXC_GPR_GPR9_TZASC1_MUX_CONTROL(x) (HW_IOMUXC_GPR_GPR9(x).B.TZASC1_MUX_CONTROL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR9_TZASC1_MUX_CONTROL. */
#define BF_IOMUXC_GPR_GPR9_TZASC1_MUX_CONTROL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR9_TZASC1_MUX_CONTROL) & BM_IOMUXC_GPR_GPR9_TZASC1_MUX_CONTROL)

/*! @brief Set the TZASC1_MUX_CONTROL field to a new value. */
#define BW_IOMUXC_GPR_GPR9_TZASC1_MUX_CONTROL(x, v) (HW_IOMUXC_GPR_GPR9_WR(x, (HW_IOMUXC_GPR_GPR9_RD(x) & ~BM_IOMUXC_GPR_GPR9_TZASC1_MUX_CONTROL) | BF_IOMUXC_GPR_GPR9_TZASC1_MUX_CONTROL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR9, field DDR_PHY_CTRL_PD[5:1] (RW)
 *
 * Drives ctrl_pd[4:0] inputs on DDR PHY Each bit is "sticky" to 1. Once a bit
 * is written to 1, it cannot be written back to 0.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD (1U) /*!< Bit position for IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD. */
#define BM_IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD (0x0000003EU) /*!< Bit mask for IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD. */
#define BS_IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD (5U) /*!< Bit field size in bits for IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD. */

/*! @brief Read current value of the IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD field. */
#define BR_IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD(x) (HW_IOMUXC_GPR_GPR9(x).B.DDR_PHY_CTRL_PD)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD. */
#define BF_IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD) & BM_IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD)

/*! @brief Set the DDR_PHY_CTRL_PD field to a new value. */
#define BW_IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD(x, v) (HW_IOMUXC_GPR_GPR9_WR(x, (HW_IOMUXC_GPR_GPR9_RD(x) & ~BM_IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD) | BF_IOMUXC_GPR_GPR9_DDR_PHY_CTRL_PD(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR10 - GPR10 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR10 - GPR10 General Purpose Register (RW)
 *
 * Reset value: 0x00000003U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr10
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr10_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t SEC_ERR_RESP_EN : 1;  /*!< [2]  */
        uint32_t OCRAM_EPDC_TZ_EN : 1; /*!< [3]  */
        uint32_t OCRAM_EPDC_TZ_ADDR : 6; /*!< [9:4]  */
        uint32_t GPR10_LOCK : 22;      /*!< [31:10]  */
    } B;
} hw_iomuxc_gpr_gpr10_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR10 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR10_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_IOMUXC_GPR_GPR10(x)   (*(__IO hw_iomuxc_gpr_gpr10_t *) HW_IOMUXC_GPR_GPR10_ADDR(x))
#define HW_IOMUXC_GPR_GPR10_RD(x) (HW_IOMUXC_GPR_GPR10(x).U)
#define HW_IOMUXC_GPR_GPR10_WR(x, v) (HW_IOMUXC_GPR_GPR10(x).U = (v))
#define HW_IOMUXC_GPR_GPR10_SET(x, v) (HW_IOMUXC_GPR_GPR10_WR(x, HW_IOMUXC_GPR_GPR10_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR10_CLR(x, v) (HW_IOMUXC_GPR_GPR10_WR(x, HW_IOMUXC_GPR_GPR10_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR10_TOG(x, v) (HW_IOMUXC_GPR_GPR10_WR(x, HW_IOMUXC_GPR_GPR10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR10 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR10, field SEC_ERR_RESP_EN[2] (RW)
 *
 * Security error response enable for all security gaskets (on both AHB and AXI
 * busses) This is a "lock" type bit
 *
 * Values:
 * - 0 - OKAY response
 * - 1 - SLVERR response
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR10_SEC_ERR_RESP_EN (2U) /*!< Bit position for IOMUXC_GPR_GPR10_SEC_ERR_RESP_EN. */
#define BM_IOMUXC_GPR_GPR10_SEC_ERR_RESP_EN (0x00000004U) /*!< Bit mask for IOMUXC_GPR_GPR10_SEC_ERR_RESP_EN. */
#define BS_IOMUXC_GPR_GPR10_SEC_ERR_RESP_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR10_SEC_ERR_RESP_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR10_SEC_ERR_RESP_EN field. */
#define BR_IOMUXC_GPR_GPR10_SEC_ERR_RESP_EN(x) (HW_IOMUXC_GPR_GPR10(x).B.SEC_ERR_RESP_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR10_SEC_ERR_RESP_EN. */
#define BF_IOMUXC_GPR_GPR10_SEC_ERR_RESP_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR10_SEC_ERR_RESP_EN) & BM_IOMUXC_GPR_GPR10_SEC_ERR_RESP_EN)

/*! @brief Set the SEC_ERR_RESP_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR10_SEC_ERR_RESP_EN(x, v) (HW_IOMUXC_GPR_GPR10_WR(x, (HW_IOMUXC_GPR_GPR10_RD(x) & ~BM_IOMUXC_GPR_GPR10_SEC_ERR_RESP_EN) | BF_IOMUXC_GPR_GPR10_SEC_ERR_RESP_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR10, field OCRAM_EPDC_TZ_EN[3] (RW)
 *
 * EPDC OCRAM TrustZone (TZ) enable This is a "lock" type bit
 *
 * Values:
 * - 0 - The TrustZone feature is disabled. Entire EPDC OCRAM space is available
 *     for all access types (secure/non-secure/user/supervisor).
 * - 1 - The TrustZone feature is enabled. Access to address in the range
 *     specified by [ENDADDR:STARTADDR] follows the execution mode access policy
 *     described in CSU chapter.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_EN (3U) /*!< Bit position for IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_EN. */
#define BM_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_EN (0x00000008U) /*!< Bit mask for IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_EN. */
#define BS_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_EN field. */
#define BR_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_EN(x) (HW_IOMUXC_GPR_GPR10(x).B.OCRAM_EPDC_TZ_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_EN. */
#define BF_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_EN) & BM_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_EN)

/*! @brief Set the OCRAM_EPDC_TZ_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_EN(x, v) (HW_IOMUXC_GPR_GPR10_WR(x, (HW_IOMUXC_GPR_GPR10_RD(x) & ~BM_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_EN) | BF_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR10, field OCRAM_EPDC_TZ_ADDR[9:4] (RW)
 *
 * EPDC OCRAM TrustZone (TZ) start address. This is the start address of the
 * secure memory region within the EPDC OCRAM memory space is 4KB granularity. The
 * start address affects the EPDC OCRAM transactions only if OCRAM_EPDC_TZ_EN bit
 * is set. The EPDC OCRAM TZ ENDADDR is not configurable and is set to the end of
 * EPDC OCRAM memory space. These are "lock" type bits
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR (4U) /*!< Bit position for IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR. */
#define BM_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR (0x000003F0U) /*!< Bit mask for IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR. */
#define BS_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR (6U) /*!< Bit field size in bits for IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR. */

/*! @brief Read current value of the IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR field. */
#define BR_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR(x) (HW_IOMUXC_GPR_GPR10(x).B.OCRAM_EPDC_TZ_ADDR)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR. */
#define BF_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR) & BM_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR)

/*! @brief Set the OCRAM_EPDC_TZ_ADDR field to a new value. */
#define BW_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR(x, v) (HW_IOMUXC_GPR_GPR10_WR(x, (HW_IOMUXC_GPR_GPR10_RD(x) & ~BM_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR) | BF_IOMUXC_GPR_GPR10_OCRAM_EPDC_TZ_ADDR(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR10, field GPR10_LOCK[31:10] (RW)
 *
 * Bits [25:18] are Lock Bits for bits [9:2] Other bits are Reserved
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR10_GPR10_LOCK (10U) /*!< Bit position for IOMUXC_GPR_GPR10_GPR10_LOCK. */
#define BM_IOMUXC_GPR_GPR10_GPR10_LOCK (0xFFFFFC00U) /*!< Bit mask for IOMUXC_GPR_GPR10_GPR10_LOCK. */
#define BS_IOMUXC_GPR_GPR10_GPR10_LOCK (22U) /*!< Bit field size in bits for IOMUXC_GPR_GPR10_GPR10_LOCK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR10_GPR10_LOCK field. */
#define BR_IOMUXC_GPR_GPR10_GPR10_LOCK(x) (HW_IOMUXC_GPR_GPR10(x).B.GPR10_LOCK)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR10_GPR10_LOCK. */
#define BF_IOMUXC_GPR_GPR10_GPR10_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR10_GPR10_LOCK) & BM_IOMUXC_GPR_GPR10_GPR10_LOCK)

/*! @brief Set the GPR10_LOCK field to a new value. */
#define BW_IOMUXC_GPR_GPR10_GPR10_LOCK(x, v) (HW_IOMUXC_GPR_GPR10_WR(x, (HW_IOMUXC_GPR_GPR10_RD(x) & ~BM_IOMUXC_GPR_GPR10_GPR10_LOCK) | BF_IOMUXC_GPR_GPR10_GPR10_LOCK(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR11 - GPR11 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR11 - GPR11 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr11
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr11_bitfields
    {
        uint32_t OCRAM_TZ_EN : 1;      /*!< [0]  */
        uint32_t OCRAM_TZ_ADDR : 5;    /*!< [5:1]  */
        uint32_t OCRAM_PXP_TZ_EN : 1;  /*!< [6]  */
        uint32_t OCRAM_PXP_TZ_ADDR : 3; /*!< [9:7]  */
        uint32_t OCRAM_S_TZ_EN : 1;    /*!< [10]  */
        uint32_t OCRAM_S_TZ_ADDR : 3;  /*!< [13:11]  */
        uint32_t GPR11_LOCK : 18;      /*!< [31:14]  */
    } B;
} hw_iomuxc_gpr_gpr11_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR11 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR11_ADDR(x) ((uintptr_t)(x) + 0x2CU)

#define HW_IOMUXC_GPR_GPR11(x)   (*(__IO hw_iomuxc_gpr_gpr11_t *) HW_IOMUXC_GPR_GPR11_ADDR(x))
#define HW_IOMUXC_GPR_GPR11_RD(x) (HW_IOMUXC_GPR_GPR11(x).U)
#define HW_IOMUXC_GPR_GPR11_WR(x, v) (HW_IOMUXC_GPR_GPR11(x).U = (v))
#define HW_IOMUXC_GPR_GPR11_SET(x, v) (HW_IOMUXC_GPR_GPR11_WR(x, HW_IOMUXC_GPR_GPR11_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR11_CLR(x, v) (HW_IOMUXC_GPR_GPR11_WR(x, HW_IOMUXC_GPR_GPR11_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR11_TOG(x, v) (HW_IOMUXC_GPR_GPR11_WR(x, HW_IOMUXC_GPR_GPR11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR11 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR11, field OCRAM_TZ_EN[0] (RW)
 *
 * OCRAM TrustZone (TZ) enable This is a "lock" type bit
 *
 * Values:
 * - 0 - The TrustZone feature is disabled. Entire OCRAM space is available for
 *     all access types (secure/non-secure/user/supervisor).
 * - 1 - The TrustZone feature is enabled. Access to address in the range
 *     specified by [ENDADDR:STARTADDR] follows the execution mode access policy
 *     described in CSU chapter.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR11_OCRAM_TZ_EN (0U) /*!< Bit position for IOMUXC_GPR_GPR11_OCRAM_TZ_EN. */
#define BM_IOMUXC_GPR_GPR11_OCRAM_TZ_EN (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR11_OCRAM_TZ_EN. */
#define BS_IOMUXC_GPR_GPR11_OCRAM_TZ_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR11_OCRAM_TZ_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR11_OCRAM_TZ_EN field. */
#define BR_IOMUXC_GPR_GPR11_OCRAM_TZ_EN(x) (HW_IOMUXC_GPR_GPR11(x).B.OCRAM_TZ_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR11_OCRAM_TZ_EN. */
#define BF_IOMUXC_GPR_GPR11_OCRAM_TZ_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR11_OCRAM_TZ_EN) & BM_IOMUXC_GPR_GPR11_OCRAM_TZ_EN)

/*! @brief Set the OCRAM_TZ_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR11_OCRAM_TZ_EN(x, v) (HW_IOMUXC_GPR_GPR11_WR(x, (HW_IOMUXC_GPR_GPR11_RD(x) & ~BM_IOMUXC_GPR_GPR11_OCRAM_TZ_EN) | BF_IOMUXC_GPR_GPR11_OCRAM_TZ_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR11, field OCRAM_TZ_ADDR[5:1] (RW)
 *
 * OCRAM TrustZone (TZ) start address. This is the start address of the secure
 * memory region within the OCRAM memory space is 4KB granularity. The start
 * address affects the OCRAM transactions only if OCRAM_TZ_EN bit is set. The OCRAM TZ
 * ENDADDR is not configurable and is set to the end of OCRAM memory space.
 * These are "lock" type bits
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR (1U) /*!< Bit position for IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR. */
#define BM_IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR (0x0000003EU) /*!< Bit mask for IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR. */
#define BS_IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR (5U) /*!< Bit field size in bits for IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR. */

/*! @brief Read current value of the IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR field. */
#define BR_IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR(x) (HW_IOMUXC_GPR_GPR11(x).B.OCRAM_TZ_ADDR)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR. */
#define BF_IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR) & BM_IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR)

/*! @brief Set the OCRAM_TZ_ADDR field to a new value. */
#define BW_IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR(x, v) (HW_IOMUXC_GPR_GPR11_WR(x, (HW_IOMUXC_GPR_GPR11_RD(x) & ~BM_IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR) | BF_IOMUXC_GPR_GPR11_OCRAM_TZ_ADDR(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR11, field OCRAM_PXP_TZ_EN[6] (RW)
 *
 * PXP OCRAM TrustZone (TZ) enable This is a "lock" type bit
 *
 * Values:
 * - 0 - The TrustZone feature is disabled. Entire PXP OCRAM space is available
 *     for all access types (secure/non-secure/user/supervisor).
 * - 1 - The TrustZone feature is enabled. Access to address in the range
 *     specified by [ENDADDR:STARTADDR] follows the execution mode access policy
 *     described in CSU chapter.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_EN (6U) /*!< Bit position for IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_EN. */
#define BM_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_EN (0x00000040U) /*!< Bit mask for IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_EN. */
#define BS_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_EN field. */
#define BR_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_EN(x) (HW_IOMUXC_GPR_GPR11(x).B.OCRAM_PXP_TZ_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_EN. */
#define BF_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_EN) & BM_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_EN)

/*! @brief Set the OCRAM_PXP_TZ_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_EN(x, v) (HW_IOMUXC_GPR_GPR11_WR(x, (HW_IOMUXC_GPR_GPR11_RD(x) & ~BM_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_EN) | BF_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR11, field OCRAM_PXP_TZ_ADDR[9:7] (RW)
 *
 * PXP OCRAM TrustZone (TZ) start address. This is the start address of the
 * secure memory region within the PXP OCRAM memory space is 4KB granularity. The
 * start address affects the PXP OCRAM transactions only if OCRAM_PXP_TZ_EN bit is
 * set. The PXP OCRAM TZ ENDADDR is not configurable and is set to the end of PXP
 * OCRAM memory space. These are "lock" type bits
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR (7U) /*!< Bit position for IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR. */
#define BM_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR (0x00000380U) /*!< Bit mask for IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR. */
#define BS_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR (3U) /*!< Bit field size in bits for IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR. */

/*! @brief Read current value of the IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR field. */
#define BR_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR(x) (HW_IOMUXC_GPR_GPR11(x).B.OCRAM_PXP_TZ_ADDR)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR. */
#define BF_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR) & BM_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR)

/*! @brief Set the OCRAM_PXP_TZ_ADDR field to a new value. */
#define BW_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR(x, v) (HW_IOMUXC_GPR_GPR11_WR(x, (HW_IOMUXC_GPR_GPR11_RD(x) & ~BM_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR) | BF_IOMUXC_GPR_GPR11_OCRAM_PXP_TZ_ADDR(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR11, field OCRAM_S_TZ_EN[10] (RW)
 *
 * State Retention OCRAM TrustZone (TZ) enable This is a "lock" type bit
 *
 * Values:
 * - 0 - The TrustZone feature is disabled. Entire State Retention OCRAM space
 *     is available for all access types (secure/non-secure/user/supervisor).
 * - 1 - The TrustZone feature is enabled. Access to address in the range
 *     specified by [ENDADDR:STARTADDR] follows the execution mode access policy
 *     described in CSU chapter.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN (10U) /*!< Bit position for IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN. */
#define BM_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN (0x00000400U) /*!< Bit mask for IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN. */
#define BS_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN field. */
#define BR_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN(x) (HW_IOMUXC_GPR_GPR11(x).B.OCRAM_S_TZ_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN. */
#define BF_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN) & BM_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN)

/*! @brief Set the OCRAM_S_TZ_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN(x, v) (HW_IOMUXC_GPR_GPR11_WR(x, (HW_IOMUXC_GPR_GPR11_RD(x) & ~BM_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN) | BF_IOMUXC_GPR_GPR11_OCRAM_S_TZ_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR11, field OCRAM_S_TZ_ADDR[13:11] (RW)
 *
 * State Retention OCRAM TrustZone (TZ) start address. This is the start address
 * of the secure memory region within the State Retention OCRAM memory space is
 * 4KB granularity. The start address affects the State Retention OCRAM
 * transactions only if OCRAM_S_TZ_EN bit is set. The State Retention OCRAM TZ ENDADDR is
 * not configurable and is set to the end of State Retention OCRAM memory space.
 * These are "lock" type bits
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR (11U) /*!< Bit position for IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR. */
#define BM_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR (0x00003800U) /*!< Bit mask for IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR. */
#define BS_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR (3U) /*!< Bit field size in bits for IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR. */

/*! @brief Read current value of the IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR field. */
#define BR_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR(x) (HW_IOMUXC_GPR_GPR11(x).B.OCRAM_S_TZ_ADDR)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR. */
#define BF_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR) & BM_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR)

/*! @brief Set the OCRAM_S_TZ_ADDR field to a new value. */
#define BW_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR(x, v) (HW_IOMUXC_GPR_GPR11_WR(x, (HW_IOMUXC_GPR_GPR11_RD(x) & ~BM_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR) | BF_IOMUXC_GPR_GPR11_OCRAM_S_TZ_ADDR(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR11, field GPR11_LOCK[31:14] (RW)
 *
 * Bits [29:16] are Lock Bits for bits [13:0] Other bits are Reserved
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR11_GPR11_LOCK (14U) /*!< Bit position for IOMUXC_GPR_GPR11_GPR11_LOCK. */
#define BM_IOMUXC_GPR_GPR11_GPR11_LOCK (0xFFFFC000U) /*!< Bit mask for IOMUXC_GPR_GPR11_GPR11_LOCK. */
#define BS_IOMUXC_GPR_GPR11_GPR11_LOCK (18U) /*!< Bit field size in bits for IOMUXC_GPR_GPR11_GPR11_LOCK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR11_GPR11_LOCK field. */
#define BR_IOMUXC_GPR_GPR11_GPR11_LOCK(x) (HW_IOMUXC_GPR_GPR11(x).B.GPR11_LOCK)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR11_GPR11_LOCK. */
#define BF_IOMUXC_GPR_GPR11_GPR11_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR11_GPR11_LOCK) & BM_IOMUXC_GPR_GPR11_GPR11_LOCK)

/*! @brief Set the GPR11_LOCK field to a new value. */
#define BW_IOMUXC_GPR_GPR11_GPR11_LOCK(x, v) (HW_IOMUXC_GPR_GPR11_WR(x, (HW_IOMUXC_GPR_GPR11_RD(x) & ~BM_IOMUXC_GPR_GPR11_GPR11_LOCK) | BF_IOMUXC_GPR_GPR11_GPR11_LOCK(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR12 - GPR12 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR12 - GPR12 General Purpose Register (RW)
 *
 * Reset value: 0x30000080U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr12
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr12_bitfields
    {
        uint32_t PCIE_PHY_TRSV_REG_RST_CH0 : 1; /*!< [0]  */
        uint32_t PCIE_PHY_TRSV_RST_CH0 : 1; /*!< [1]  */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t PCIE_PHY_SSC_EN : 1;  /*!< [3]  */
        uint32_t PCIE_PHY_CMN_REG_RST : 1; /*!< [4]  */
        uint32_t PCIE_PHY_REFCLK_SEL : 1; /*!< [5]  */
        uint32_t RESERVED1 : 6;        /*!< [11:6]  */
        uint32_t PCIE_CTRL_DEVICE_TYPE : 4; /*!< [15:12]  */
        uint32_t RESERVED2 : 1;        /*!< [16]  */
        uint32_t PCIE_CTRL_DIAG_STATUS_BUS_SELECT : 4; /*!< [20:17]  */
        uint32_t PCIE_CTRL_DIAG_CTRL_BUS : 3; /*!< [23:21]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_iomuxc_gpr_gpr12_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR12 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR12_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_IOMUXC_GPR_GPR12(x)   (*(__IO hw_iomuxc_gpr_gpr12_t *) HW_IOMUXC_GPR_GPR12_ADDR(x))
#define HW_IOMUXC_GPR_GPR12_RD(x) (HW_IOMUXC_GPR_GPR12(x).U)
#define HW_IOMUXC_GPR_GPR12_WR(x, v) (HW_IOMUXC_GPR_GPR12(x).U = (v))
#define HW_IOMUXC_GPR_GPR12_SET(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, HW_IOMUXC_GPR_GPR12_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR12_CLR(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, HW_IOMUXC_GPR_GPR12_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR12_TOG(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, HW_IOMUXC_GPR_GPR12_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR12 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR12, field PCIE_PHY_TRSV_REG_RST_CH0[0] (RW)
 *
 * Reset of TRANSCEIVER APB or I2C Function. When driven high, TRSV_REG_RST
 * resets Transceiver APB or I2C registers only.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_REG_RST_CH0 (0U) /*!< Bit position for IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_REG_RST_CH0. */
#define BM_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_REG_RST_CH0 (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_REG_RST_CH0. */
#define BS_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_REG_RST_CH0 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_REG_RST_CH0. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_REG_RST_CH0 field. */
#define BR_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_REG_RST_CH0(x) (HW_IOMUXC_GPR_GPR12(x).B.PCIE_PHY_TRSV_REG_RST_CH0)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_REG_RST_CH0. */
#define BF_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_REG_RST_CH0(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_REG_RST_CH0) & BM_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_REG_RST_CH0)

/*! @brief Set the PCIE_PHY_TRSV_REG_RST_CH0 field to a new value. */
#define BW_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_REG_RST_CH0(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_REG_RST_CH0) | BF_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_REG_RST_CH0(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field PCIE_PHY_TRSV_RST_CH0[1] (RW)
 *
 * Transceiver Block Reset Function. When driven high, TRSV_RST resets all
 * internal state information in the Transceiver block of the PHY to its default
 * condition.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_RST_CH0 (1U) /*!< Bit position for IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_RST_CH0. */
#define BM_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_RST_CH0 (0x00000002U) /*!< Bit mask for IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_RST_CH0. */
#define BS_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_RST_CH0 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_RST_CH0. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_RST_CH0 field. */
#define BR_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_RST_CH0(x) (HW_IOMUXC_GPR_GPR12(x).B.PCIE_PHY_TRSV_RST_CH0)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_RST_CH0. */
#define BF_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_RST_CH0(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_RST_CH0) & BM_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_RST_CH0)

/*! @brief Set the PCIE_PHY_TRSV_RST_CH0 field to a new value. */
#define BW_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_RST_CH0(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_RST_CH0) | BF_IOMUXC_GPR_GPR12_PCIE_PHY_TRSV_RST_CH0(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field PCIE_PHY_SSC_EN[3] (RW)
 *
 * Transmitter Spread Spectrum Clocking Enable. When driven high, TX SSC
 * generation would be enabled.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_PCIE_PHY_SSC_EN (3U) /*!< Bit position for IOMUXC_GPR_GPR12_PCIE_PHY_SSC_EN. */
#define BM_IOMUXC_GPR_GPR12_PCIE_PHY_SSC_EN (0x00000008U) /*!< Bit mask for IOMUXC_GPR_GPR12_PCIE_PHY_SSC_EN. */
#define BS_IOMUXC_GPR_GPR12_PCIE_PHY_SSC_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_PCIE_PHY_SSC_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_PCIE_PHY_SSC_EN field. */
#define BR_IOMUXC_GPR_GPR12_PCIE_PHY_SSC_EN(x) (HW_IOMUXC_GPR_GPR12(x).B.PCIE_PHY_SSC_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_PCIE_PHY_SSC_EN. */
#define BF_IOMUXC_GPR_GPR12_PCIE_PHY_SSC_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_PCIE_PHY_SSC_EN) & BM_IOMUXC_GPR_GPR12_PCIE_PHY_SSC_EN)

/*! @brief Set the PCIE_PHY_SSC_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR12_PCIE_PHY_SSC_EN(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_PCIE_PHY_SSC_EN) | BF_IOMUXC_GPR_GPR12_PCIE_PHY_SSC_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field PCIE_PHY_CMN_REG_RST[4] (RW)
 *
 * Reset of COMMON APB Function. When driven high, CMN_ REG_RST resets COMMON
 * APB registers.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_PCIE_PHY_CMN_REG_RST (4U) /*!< Bit position for IOMUXC_GPR_GPR12_PCIE_PHY_CMN_REG_RST. */
#define BM_IOMUXC_GPR_GPR12_PCIE_PHY_CMN_REG_RST (0x00000010U) /*!< Bit mask for IOMUXC_GPR_GPR12_PCIE_PHY_CMN_REG_RST. */
#define BS_IOMUXC_GPR_GPR12_PCIE_PHY_CMN_REG_RST (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_PCIE_PHY_CMN_REG_RST. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_PCIE_PHY_CMN_REG_RST field. */
#define BR_IOMUXC_GPR_GPR12_PCIE_PHY_CMN_REG_RST(x) (HW_IOMUXC_GPR_GPR12(x).B.PCIE_PHY_CMN_REG_RST)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_PCIE_PHY_CMN_REG_RST. */
#define BF_IOMUXC_GPR_GPR12_PCIE_PHY_CMN_REG_RST(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_PCIE_PHY_CMN_REG_RST) & BM_IOMUXC_GPR_GPR12_PCIE_PHY_CMN_REG_RST)

/*! @brief Set the PCIE_PHY_CMN_REG_RST field to a new value. */
#define BW_IOMUXC_GPR_GPR12_PCIE_PHY_CMN_REG_RST(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_PCIE_PHY_CMN_REG_RST) | BF_IOMUXC_GPR_GPR12_PCIE_PHY_CMN_REG_RST(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field PCIE_PHY_REFCLK_SEL[5] (RW)
 *
 * Internal Reference Clock Enable. When driven high, REFCLK_EXT is reference
 * clock of PHY.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_PCIE_PHY_REFCLK_SEL (5U) /*!< Bit position for IOMUXC_GPR_GPR12_PCIE_PHY_REFCLK_SEL. */
#define BM_IOMUXC_GPR_GPR12_PCIE_PHY_REFCLK_SEL (0x00000020U) /*!< Bit mask for IOMUXC_GPR_GPR12_PCIE_PHY_REFCLK_SEL. */
#define BS_IOMUXC_GPR_GPR12_PCIE_PHY_REFCLK_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_PCIE_PHY_REFCLK_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_PCIE_PHY_REFCLK_SEL field. */
#define BR_IOMUXC_GPR_GPR12_PCIE_PHY_REFCLK_SEL(x) (HW_IOMUXC_GPR_GPR12(x).B.PCIE_PHY_REFCLK_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_PCIE_PHY_REFCLK_SEL. */
#define BF_IOMUXC_GPR_GPR12_PCIE_PHY_REFCLK_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_PCIE_PHY_REFCLK_SEL) & BM_IOMUXC_GPR_GPR12_PCIE_PHY_REFCLK_SEL)

/*! @brief Set the PCIE_PHY_REFCLK_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR12_PCIE_PHY_REFCLK_SEL(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_PCIE_PHY_REFCLK_SEL) | BF_IOMUXC_GPR_GPR12_PCIE_PHY_REFCLK_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field PCIE_CTRL_DEVICE_TYPE[15:12] (RW)
 *
 * PCI Express device/port type
 *
 * Values:
 * - 0000 - PCI Express endpoint
 * - 0001 - Legacy PCI Express endpoint
 * - 0100 - Root port of PCI Express root complex
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE (12U) /*!< Bit position for IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE. */
#define BM_IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE (0x0000F000U) /*!< Bit mask for IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE. */
#define BS_IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE (4U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE field. */
#define BR_IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE(x) (HW_IOMUXC_GPR_GPR12(x).B.PCIE_CTRL_DEVICE_TYPE)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE. */
#define BF_IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE) & BM_IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE)

/*! @brief Set the PCIE_CTRL_DEVICE_TYPE field to a new value. */
#define BW_IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE) | BF_IOMUXC_GPR_GPR12_PCIE_CTRL_DEVICE_TYPE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field PCIE_CTRL_DIAG_STATUS_BUS_SELECT[20:17] (RW)
 *
 * PCI Express Diagnostic Status Bus Select
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT (17U) /*!< Bit position for IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT. */
#define BM_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT (0x001E0000U) /*!< Bit mask for IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT. */
#define BS_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT (4U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT field. */
#define BR_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT(x) (HW_IOMUXC_GPR_GPR12(x).B.PCIE_CTRL_DIAG_STATUS_BUS_SELECT)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT. */
#define BF_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT) & BM_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT)

/*! @brief Set the PCIE_CTRL_DIAG_STATUS_BUS_SELECT field to a new value. */
#define BW_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT) | BF_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_STATUS_BUS_SELECT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR12, field PCIE_CTRL_DIAG_CTRL_BUS[23:21] (RW)
 *
 * PCI Express Diagnostic Control Bus
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS (21U) /*!< Bit position for IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS. */
#define BM_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS (0x00E00000U) /*!< Bit mask for IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS. */
#define BS_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS (3U) /*!< Bit field size in bits for IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS field. */
#define BR_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS(x) (HW_IOMUXC_GPR_GPR12(x).B.PCIE_CTRL_DIAG_CTRL_BUS)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS. */
#define BF_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS) & BM_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS)

/*! @brief Set the PCIE_CTRL_DIAG_CTRL_BUS field to a new value. */
#define BW_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS(x, v) (HW_IOMUXC_GPR_GPR12_WR(x, (HW_IOMUXC_GPR_GPR12_RD(x) & ~BM_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS) | BF_IOMUXC_GPR_GPR12_PCIE_CTRL_DIAG_CTRL_BUS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR13 - GPR13 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR13 - GPR13 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr13
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr13_bitfields
    {
        uint32_t ARCACHE_USDHC : 1;    /*!< [0]  */
        uint32_t AWCACHE_USDHC : 1;    /*!< [1]  */
        uint32_t ARCACHE_PXP : 1;      /*!< [2]  */
        uint32_t AWCACHE_PXP : 1;      /*!< [3]  */
        uint32_t ARCACHE_PCIE : 1;     /*!< [4]  */
        uint32_t AWCACHE_PCIE : 1;     /*!< [5]  */
        uint32_t ARCACHE_LCDIF : 1;    /*!< [6]  */
        uint32_t ARCACHE_EPDC : 1;     /*!< [7]  */
        uint32_t ARCACHE_PXP_EN : 1;   /*!< [8]  */
        uint32_t AWCACHE_PXP_EN : 1;   /*!< [9]  */
        uint32_t ARCACHE_PCIE_EN : 1;  /*!< [10]  */
        uint32_t AWCACHE_PCIE_EN : 1;  /*!< [11]  */
        uint32_t ARCACHE_LCDIF_EN : 1; /*!< [12]  */
        uint32_t ARCACHE_EPDC_EN : 1;  /*!< [13]  */
        uint32_t AWCACHE_EPDC : 1;     /*!< [14]  */
        uint32_t AWCACHE_EPDC_EN : 1;  /*!< [15]  */
        uint32_t PCIE_PHY_AFC_CODE_OUT_CH0 : 8; /*!< [23:16]  */
        uint32_t PCIE_PHY_VCO_BAND : 4; /*!< [27:24]  */
        uint32_t PCIE_PHY_PMA_CDR_LOCKED_CH0 : 1; /*!< [28]  */
        uint32_t PCIE_PHY_PMA_RX_PRESENT_CH0 : 1; /*!< [29]  */
        uint32_t PCIE_PHY_CDR_VCO_MON_CH0 : 1; /*!< [30]  */
        uint32_t PCIE_PHY_PCS_REFCLK_DISABLE : 1; /*!< [31]  */
    } B;
} hw_iomuxc_gpr_gpr13_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR13 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR13_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_IOMUXC_GPR_GPR13(x)   (*(__IO hw_iomuxc_gpr_gpr13_t *) HW_IOMUXC_GPR_GPR13_ADDR(x))
#define HW_IOMUXC_GPR_GPR13_RD(x) (HW_IOMUXC_GPR_GPR13(x).U)
#define HW_IOMUXC_GPR_GPR13_WR(x, v) (HW_IOMUXC_GPR_GPR13(x).U = (v))
#define HW_IOMUXC_GPR_GPR13_SET(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, HW_IOMUXC_GPR_GPR13_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR13_CLR(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, HW_IOMUXC_GPR_GPR13_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR13_TOG(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, HW_IOMUXC_GPR_GPR13_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR13 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR13, field ARCACHE_USDHC[0] (RW)
 *
 * USDHC 1-3 AXI Master ARCACHE Override Value Note: this bit always overrides
 *
 * Values:
 * - 0 - Drive USDHC AXI Master ARCACHE[1] to 0
 * - 1 - Drive USDHC AXI Master ARCACHE[1] to 1
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_ARCACHE_USDHC (0U) /*!< Bit position for IOMUXC_GPR_GPR13_ARCACHE_USDHC. */
#define BM_IOMUXC_GPR_GPR13_ARCACHE_USDHC (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR13_ARCACHE_USDHC. */
#define BS_IOMUXC_GPR_GPR13_ARCACHE_USDHC (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_ARCACHE_USDHC. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_ARCACHE_USDHC field. */
#define BR_IOMUXC_GPR_GPR13_ARCACHE_USDHC(x) (HW_IOMUXC_GPR_GPR13(x).B.ARCACHE_USDHC)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_ARCACHE_USDHC. */
#define BF_IOMUXC_GPR_GPR13_ARCACHE_USDHC(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_ARCACHE_USDHC) & BM_IOMUXC_GPR_GPR13_ARCACHE_USDHC)

/*! @brief Set the ARCACHE_USDHC field to a new value. */
#define BW_IOMUXC_GPR_GPR13_ARCACHE_USDHC(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_ARCACHE_USDHC) | BF_IOMUXC_GPR_GPR13_ARCACHE_USDHC(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field AWCACHE_USDHC[1] (RW)
 *
 * USDHC 1-3 AXI Master AWCACHE Override Value Note: this bit always overrides
 *
 * Values:
 * - 0 - Drive USDHC AXI Master AWCACHE[1] to 0
 * - 1 - Drive USDHC AXI Master AWCACHE[1] to 1
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_AWCACHE_USDHC (1U) /*!< Bit position for IOMUXC_GPR_GPR13_AWCACHE_USDHC. */
#define BM_IOMUXC_GPR_GPR13_AWCACHE_USDHC (0x00000002U) /*!< Bit mask for IOMUXC_GPR_GPR13_AWCACHE_USDHC. */
#define BS_IOMUXC_GPR_GPR13_AWCACHE_USDHC (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_AWCACHE_USDHC. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_AWCACHE_USDHC field. */
#define BR_IOMUXC_GPR_GPR13_AWCACHE_USDHC(x) (HW_IOMUXC_GPR_GPR13(x).B.AWCACHE_USDHC)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_AWCACHE_USDHC. */
#define BF_IOMUXC_GPR_GPR13_AWCACHE_USDHC(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_AWCACHE_USDHC) & BM_IOMUXC_GPR_GPR13_AWCACHE_USDHC)

/*! @brief Set the AWCACHE_USDHC field to a new value. */
#define BW_IOMUXC_GPR_GPR13_AWCACHE_USDHC(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_AWCACHE_USDHC) | BF_IOMUXC_GPR_GPR13_AWCACHE_USDHC(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field ARCACHE_PXP[2] (RW)
 *
 * PXP Primary AXI Master Port ARCACHE Override Value Note: this bit only takes
 * effect when ARCACHE_PXP_EN = 1
 *
 * Values:
 * - 0 - Drive PXP Primary AXI Master Port ARCACHE[1] to 0
 * - 1 - Drive PXP Primary AXI Master Port ARCACHE[1] to 1
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_ARCACHE_PXP (2U) /*!< Bit position for IOMUXC_GPR_GPR13_ARCACHE_PXP. */
#define BM_IOMUXC_GPR_GPR13_ARCACHE_PXP (0x00000004U) /*!< Bit mask for IOMUXC_GPR_GPR13_ARCACHE_PXP. */
#define BS_IOMUXC_GPR_GPR13_ARCACHE_PXP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_ARCACHE_PXP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_ARCACHE_PXP field. */
#define BR_IOMUXC_GPR_GPR13_ARCACHE_PXP(x) (HW_IOMUXC_GPR_GPR13(x).B.ARCACHE_PXP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_ARCACHE_PXP. */
#define BF_IOMUXC_GPR_GPR13_ARCACHE_PXP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_ARCACHE_PXP) & BM_IOMUXC_GPR_GPR13_ARCACHE_PXP)

/*! @brief Set the ARCACHE_PXP field to a new value. */
#define BW_IOMUXC_GPR_GPR13_ARCACHE_PXP(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_ARCACHE_PXP) | BF_IOMUXC_GPR_GPR13_ARCACHE_PXP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field AWCACHE_PXP[3] (RW)
 *
 * PXP Primary AXI Master Port AWCACHE Override Value Note: this bit only takes
 * effect when AWCACHE_PXP_EN = 1
 *
 * Values:
 * - 0 - Drive PXP Primary AXI Master Port AWCACHE[1] to 0
 * - 1 - Drive PXP Primary AXI Master Port AWCACHE[1] to 1
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_AWCACHE_PXP (3U) /*!< Bit position for IOMUXC_GPR_GPR13_AWCACHE_PXP. */
#define BM_IOMUXC_GPR_GPR13_AWCACHE_PXP (0x00000008U) /*!< Bit mask for IOMUXC_GPR_GPR13_AWCACHE_PXP. */
#define BS_IOMUXC_GPR_GPR13_AWCACHE_PXP (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_AWCACHE_PXP. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_AWCACHE_PXP field. */
#define BR_IOMUXC_GPR_GPR13_AWCACHE_PXP(x) (HW_IOMUXC_GPR_GPR13(x).B.AWCACHE_PXP)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_AWCACHE_PXP. */
#define BF_IOMUXC_GPR_GPR13_AWCACHE_PXP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_AWCACHE_PXP) & BM_IOMUXC_GPR_GPR13_AWCACHE_PXP)

/*! @brief Set the AWCACHE_PXP field to a new value. */
#define BW_IOMUXC_GPR_GPR13_AWCACHE_PXP(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_AWCACHE_PXP) | BF_IOMUXC_GPR_GPR13_AWCACHE_PXP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field ARCACHE_PCIE[4] (RW)
 *
 * PCIe AXI Master Port ARCACHE Override Value Note: this bit only takes effect
 * when ARCACHE_PCIE_EN = 1
 *
 * Values:
 * - 0 - Drive PCIe AXI Master Port ARCACHE[1] to 0
 * - 1 - Drive PCIe AXI Master Port ARCACHE[1] to 1
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_ARCACHE_PCIE (4U) /*!< Bit position for IOMUXC_GPR_GPR13_ARCACHE_PCIE. */
#define BM_IOMUXC_GPR_GPR13_ARCACHE_PCIE (0x00000010U) /*!< Bit mask for IOMUXC_GPR_GPR13_ARCACHE_PCIE. */
#define BS_IOMUXC_GPR_GPR13_ARCACHE_PCIE (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_ARCACHE_PCIE. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_ARCACHE_PCIE field. */
#define BR_IOMUXC_GPR_GPR13_ARCACHE_PCIE(x) (HW_IOMUXC_GPR_GPR13(x).B.ARCACHE_PCIE)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_ARCACHE_PCIE. */
#define BF_IOMUXC_GPR_GPR13_ARCACHE_PCIE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_ARCACHE_PCIE) & BM_IOMUXC_GPR_GPR13_ARCACHE_PCIE)

/*! @brief Set the ARCACHE_PCIE field to a new value. */
#define BW_IOMUXC_GPR_GPR13_ARCACHE_PCIE(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_ARCACHE_PCIE) | BF_IOMUXC_GPR_GPR13_ARCACHE_PCIE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field AWCACHE_PCIE[5] (RW)
 *
 * PCIe AXI Master Port AWCACHE Override Value Note: this bit only takes effect
 * when AWCACHE_PCIE_EN = 1
 *
 * Values:
 * - 0 - Drive PCIe AXI Master Port AWCACHE[1] to 0
 * - 1 - Drive PCIe AXI Master Port AWCACHE[1] to 1
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_AWCACHE_PCIE (5U) /*!< Bit position for IOMUXC_GPR_GPR13_AWCACHE_PCIE. */
#define BM_IOMUXC_GPR_GPR13_AWCACHE_PCIE (0x00000020U) /*!< Bit mask for IOMUXC_GPR_GPR13_AWCACHE_PCIE. */
#define BS_IOMUXC_GPR_GPR13_AWCACHE_PCIE (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_AWCACHE_PCIE. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_AWCACHE_PCIE field. */
#define BR_IOMUXC_GPR_GPR13_AWCACHE_PCIE(x) (HW_IOMUXC_GPR_GPR13(x).B.AWCACHE_PCIE)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_AWCACHE_PCIE. */
#define BF_IOMUXC_GPR_GPR13_AWCACHE_PCIE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_AWCACHE_PCIE) & BM_IOMUXC_GPR_GPR13_AWCACHE_PCIE)

/*! @brief Set the AWCACHE_PCIE field to a new value. */
#define BW_IOMUXC_GPR_GPR13_AWCACHE_PCIE(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_AWCACHE_PCIE) | BF_IOMUXC_GPR_GPR13_AWCACHE_PCIE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field ARCACHE_LCDIF[6] (RW)
 *
 * LCDIF AXI Master Port ARCACHE Override Value Note: this bit only takes effect
 * when ARCACHE_LCDIF_EN = 1
 *
 * Values:
 * - 0 - Drive LCDIF AXI Master Port ARCACHE[1] to 0
 * - 1 - Drive LCDIF AXI Master Port ARCACHE[1] to 1
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_ARCACHE_LCDIF (6U) /*!< Bit position for IOMUXC_GPR_GPR13_ARCACHE_LCDIF. */
#define BM_IOMUXC_GPR_GPR13_ARCACHE_LCDIF (0x00000040U) /*!< Bit mask for IOMUXC_GPR_GPR13_ARCACHE_LCDIF. */
#define BS_IOMUXC_GPR_GPR13_ARCACHE_LCDIF (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_ARCACHE_LCDIF. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_ARCACHE_LCDIF field. */
#define BR_IOMUXC_GPR_GPR13_ARCACHE_LCDIF(x) (HW_IOMUXC_GPR_GPR13(x).B.ARCACHE_LCDIF)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_ARCACHE_LCDIF. */
#define BF_IOMUXC_GPR_GPR13_ARCACHE_LCDIF(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_ARCACHE_LCDIF) & BM_IOMUXC_GPR_GPR13_ARCACHE_LCDIF)

/*! @brief Set the ARCACHE_LCDIF field to a new value. */
#define BW_IOMUXC_GPR_GPR13_ARCACHE_LCDIF(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_ARCACHE_LCDIF) | BF_IOMUXC_GPR_GPR13_ARCACHE_LCDIF(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field ARCACHE_EPDC[7] (RW)
 *
 * EPDC AXI Master Port ARCACHE Override Value Note: this bit only takes effect
 * when ARCACHE_EPDC_EN = 1
 *
 * Values:
 * - 0 - Drive EPDC AXI Master Port ARCACHE[1] to 0
 * - 1 - Drive EPDC AXI Master Port ARCACHE[1] to 1
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_ARCACHE_EPDC (7U) /*!< Bit position for IOMUXC_GPR_GPR13_ARCACHE_EPDC. */
#define BM_IOMUXC_GPR_GPR13_ARCACHE_EPDC (0x00000080U) /*!< Bit mask for IOMUXC_GPR_GPR13_ARCACHE_EPDC. */
#define BS_IOMUXC_GPR_GPR13_ARCACHE_EPDC (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_ARCACHE_EPDC. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_ARCACHE_EPDC field. */
#define BR_IOMUXC_GPR_GPR13_ARCACHE_EPDC(x) (HW_IOMUXC_GPR_GPR13(x).B.ARCACHE_EPDC)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_ARCACHE_EPDC. */
#define BF_IOMUXC_GPR_GPR13_ARCACHE_EPDC(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_ARCACHE_EPDC) & BM_IOMUXC_GPR_GPR13_ARCACHE_EPDC)

/*! @brief Set the ARCACHE_EPDC field to a new value. */
#define BW_IOMUXC_GPR_GPR13_ARCACHE_EPDC(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_ARCACHE_EPDC) | BF_IOMUXC_GPR_GPR13_ARCACHE_EPDC(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field ARCACHE_PXP_EN[8] (RW)
 *
 * 0 PXP Primary AXI Master Port ARCACHE Override Enable
 *
 * Values:
 * - 0 - PXP Primary AXI Master Port ARCACHE[1] driven by PXP
 * - 1 - PXP Primary AXI Master Port ARCACHE[1] driven to constant value
 *     specified by the ARCACHE_PXP bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_ARCACHE_PXP_EN (8U) /*!< Bit position for IOMUXC_GPR_GPR13_ARCACHE_PXP_EN. */
#define BM_IOMUXC_GPR_GPR13_ARCACHE_PXP_EN (0x00000100U) /*!< Bit mask for IOMUXC_GPR_GPR13_ARCACHE_PXP_EN. */
#define BS_IOMUXC_GPR_GPR13_ARCACHE_PXP_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_ARCACHE_PXP_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_ARCACHE_PXP_EN field. */
#define BR_IOMUXC_GPR_GPR13_ARCACHE_PXP_EN(x) (HW_IOMUXC_GPR_GPR13(x).B.ARCACHE_PXP_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_ARCACHE_PXP_EN. */
#define BF_IOMUXC_GPR_GPR13_ARCACHE_PXP_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_ARCACHE_PXP_EN) & BM_IOMUXC_GPR_GPR13_ARCACHE_PXP_EN)

/*! @brief Set the ARCACHE_PXP_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR13_ARCACHE_PXP_EN(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_ARCACHE_PXP_EN) | BF_IOMUXC_GPR_GPR13_ARCACHE_PXP_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field AWCACHE_PXP_EN[9] (RW)
 *
 * PXP Primary AXI Master Port AWCACHE Override Enable
 *
 * Values:
 * - 0 - PXP Primary AXI Master Port AWCACHE[1] driven by PXP
 * - 1 - PXP Primary AXI Master Port AWCACHE[1] driven to constant value
 *     specified by the AWCACHE_PXP bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_AWCACHE_PXP_EN (9U) /*!< Bit position for IOMUXC_GPR_GPR13_AWCACHE_PXP_EN. */
#define BM_IOMUXC_GPR_GPR13_AWCACHE_PXP_EN (0x00000200U) /*!< Bit mask for IOMUXC_GPR_GPR13_AWCACHE_PXP_EN. */
#define BS_IOMUXC_GPR_GPR13_AWCACHE_PXP_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_AWCACHE_PXP_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_AWCACHE_PXP_EN field. */
#define BR_IOMUXC_GPR_GPR13_AWCACHE_PXP_EN(x) (HW_IOMUXC_GPR_GPR13(x).B.AWCACHE_PXP_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_AWCACHE_PXP_EN. */
#define BF_IOMUXC_GPR_GPR13_AWCACHE_PXP_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_AWCACHE_PXP_EN) & BM_IOMUXC_GPR_GPR13_AWCACHE_PXP_EN)

/*! @brief Set the AWCACHE_PXP_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR13_AWCACHE_PXP_EN(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_AWCACHE_PXP_EN) | BF_IOMUXC_GPR_GPR13_AWCACHE_PXP_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field ARCACHE_PCIE_EN[10] (RW)
 *
 * PCIe AXI Master Port ARCACHE Override Enable
 *
 * Values:
 * - 0 - PCIe AXI Master Port ARCACHE[1] driven by PCIe
 * - 1 - PCIe AXI Master Port ARCACHE[1] driven to constant value specified by
 *     the ARCACHE_PXP bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_ARCACHE_PCIE_EN (10U) /*!< Bit position for IOMUXC_GPR_GPR13_ARCACHE_PCIE_EN. */
#define BM_IOMUXC_GPR_GPR13_ARCACHE_PCIE_EN (0x00000400U) /*!< Bit mask for IOMUXC_GPR_GPR13_ARCACHE_PCIE_EN. */
#define BS_IOMUXC_GPR_GPR13_ARCACHE_PCIE_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_ARCACHE_PCIE_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_ARCACHE_PCIE_EN field. */
#define BR_IOMUXC_GPR_GPR13_ARCACHE_PCIE_EN(x) (HW_IOMUXC_GPR_GPR13(x).B.ARCACHE_PCIE_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_ARCACHE_PCIE_EN. */
#define BF_IOMUXC_GPR_GPR13_ARCACHE_PCIE_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_ARCACHE_PCIE_EN) & BM_IOMUXC_GPR_GPR13_ARCACHE_PCIE_EN)

/*! @brief Set the ARCACHE_PCIE_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR13_ARCACHE_PCIE_EN(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_ARCACHE_PCIE_EN) | BF_IOMUXC_GPR_GPR13_ARCACHE_PCIE_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field AWCACHE_PCIE_EN[11] (RW)
 *
 * PCIe AXI Master Port AWCACHE Override Enable
 *
 * Values:
 * - 0 - PCIe AXI Master Port AWCACHE[1] driven by PCIe
 * - 1 - PCIe AXI Master Port AWCACHE[1] driven to constant value specified by
 *     the AWCACHE_PXP bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_AWCACHE_PCIE_EN (11U) /*!< Bit position for IOMUXC_GPR_GPR13_AWCACHE_PCIE_EN. */
#define BM_IOMUXC_GPR_GPR13_AWCACHE_PCIE_EN (0x00000800U) /*!< Bit mask for IOMUXC_GPR_GPR13_AWCACHE_PCIE_EN. */
#define BS_IOMUXC_GPR_GPR13_AWCACHE_PCIE_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_AWCACHE_PCIE_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_AWCACHE_PCIE_EN field. */
#define BR_IOMUXC_GPR_GPR13_AWCACHE_PCIE_EN(x) (HW_IOMUXC_GPR_GPR13(x).B.AWCACHE_PCIE_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_AWCACHE_PCIE_EN. */
#define BF_IOMUXC_GPR_GPR13_AWCACHE_PCIE_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_AWCACHE_PCIE_EN) & BM_IOMUXC_GPR_GPR13_AWCACHE_PCIE_EN)

/*! @brief Set the AWCACHE_PCIE_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR13_AWCACHE_PCIE_EN(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_AWCACHE_PCIE_EN) | BF_IOMUXC_GPR_GPR13_AWCACHE_PCIE_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field ARCACHE_LCDIF_EN[12] (RW)
 *
 * LCDIF AXI Master Port ARCACHE Override Enable
 *
 * Values:
 * - 0 - LCDIF AXI Master Port ARCACHE[1] driven by LCDIF
 * - 1 - LCDIF AXI Master Port ARCACHE[1] driven to constant value specified by
 *     the ARCACHE_LCDIF bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_ARCACHE_LCDIF_EN (12U) /*!< Bit position for IOMUXC_GPR_GPR13_ARCACHE_LCDIF_EN. */
#define BM_IOMUXC_GPR_GPR13_ARCACHE_LCDIF_EN (0x00001000U) /*!< Bit mask for IOMUXC_GPR_GPR13_ARCACHE_LCDIF_EN. */
#define BS_IOMUXC_GPR_GPR13_ARCACHE_LCDIF_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_ARCACHE_LCDIF_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_ARCACHE_LCDIF_EN field. */
#define BR_IOMUXC_GPR_GPR13_ARCACHE_LCDIF_EN(x) (HW_IOMUXC_GPR_GPR13(x).B.ARCACHE_LCDIF_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_ARCACHE_LCDIF_EN. */
#define BF_IOMUXC_GPR_GPR13_ARCACHE_LCDIF_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_ARCACHE_LCDIF_EN) & BM_IOMUXC_GPR_GPR13_ARCACHE_LCDIF_EN)

/*! @brief Set the ARCACHE_LCDIF_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR13_ARCACHE_LCDIF_EN(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_ARCACHE_LCDIF_EN) | BF_IOMUXC_GPR_GPR13_ARCACHE_LCDIF_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field ARCACHE_EPDC_EN[13] (RW)
 *
 * EPDC AXI Master Port ARCACHE Override Enable
 *
 * Values:
 * - 0 - EPDC AXI Master Port ARCACHE[1] driven by EPDC
 * - 1 - EPDC AXI Master Port ARCACHE[1] driven to constant value specified by
 *     the ARCACHE_EPDC bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_ARCACHE_EPDC_EN (13U) /*!< Bit position for IOMUXC_GPR_GPR13_ARCACHE_EPDC_EN. */
#define BM_IOMUXC_GPR_GPR13_ARCACHE_EPDC_EN (0x00002000U) /*!< Bit mask for IOMUXC_GPR_GPR13_ARCACHE_EPDC_EN. */
#define BS_IOMUXC_GPR_GPR13_ARCACHE_EPDC_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_ARCACHE_EPDC_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_ARCACHE_EPDC_EN field. */
#define BR_IOMUXC_GPR_GPR13_ARCACHE_EPDC_EN(x) (HW_IOMUXC_GPR_GPR13(x).B.ARCACHE_EPDC_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_ARCACHE_EPDC_EN. */
#define BF_IOMUXC_GPR_GPR13_ARCACHE_EPDC_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_ARCACHE_EPDC_EN) & BM_IOMUXC_GPR_GPR13_ARCACHE_EPDC_EN)

/*! @brief Set the ARCACHE_EPDC_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR13_ARCACHE_EPDC_EN(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_ARCACHE_EPDC_EN) | BF_IOMUXC_GPR_GPR13_ARCACHE_EPDC_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field AWCACHE_EPDC[14] (RW)
 *
 * EPDC AXI Master Port AWCACHE Override Value Note: this bit only takes effect
 * when AWCACHE_EPDC_EN = 1
 *
 * Values:
 * - 0 - Drive EPDC AXI Master Port AWCACHE[1] to 0
 * - 1 - Drive EPDC AXI Master Port AWCACHE[1] to 1
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_AWCACHE_EPDC (14U) /*!< Bit position for IOMUXC_GPR_GPR13_AWCACHE_EPDC. */
#define BM_IOMUXC_GPR_GPR13_AWCACHE_EPDC (0x00004000U) /*!< Bit mask for IOMUXC_GPR_GPR13_AWCACHE_EPDC. */
#define BS_IOMUXC_GPR_GPR13_AWCACHE_EPDC (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_AWCACHE_EPDC. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_AWCACHE_EPDC field. */
#define BR_IOMUXC_GPR_GPR13_AWCACHE_EPDC(x) (HW_IOMUXC_GPR_GPR13(x).B.AWCACHE_EPDC)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_AWCACHE_EPDC. */
#define BF_IOMUXC_GPR_GPR13_AWCACHE_EPDC(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_AWCACHE_EPDC) & BM_IOMUXC_GPR_GPR13_AWCACHE_EPDC)

/*! @brief Set the AWCACHE_EPDC field to a new value. */
#define BW_IOMUXC_GPR_GPR13_AWCACHE_EPDC(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_AWCACHE_EPDC) | BF_IOMUXC_GPR_GPR13_AWCACHE_EPDC(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field AWCACHE_EPDC_EN[15] (RW)
 *
 * EPDC AXI Master Port AWCACHE Override Enable
 *
 * Values:
 * - 0 - EPDC AXI Master Port AWCACHE[1] driven by EPDC
 * - 1 - EPDC AXI Master Port AWCACHE[1] driven to constant value specified by
 *     the AWCACHE_EPDC bit
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_AWCACHE_EPDC_EN (15U) /*!< Bit position for IOMUXC_GPR_GPR13_AWCACHE_EPDC_EN. */
#define BM_IOMUXC_GPR_GPR13_AWCACHE_EPDC_EN (0x00008000U) /*!< Bit mask for IOMUXC_GPR_GPR13_AWCACHE_EPDC_EN. */
#define BS_IOMUXC_GPR_GPR13_AWCACHE_EPDC_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_AWCACHE_EPDC_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_AWCACHE_EPDC_EN field. */
#define BR_IOMUXC_GPR_GPR13_AWCACHE_EPDC_EN(x) (HW_IOMUXC_GPR_GPR13(x).B.AWCACHE_EPDC_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR13_AWCACHE_EPDC_EN. */
#define BF_IOMUXC_GPR_GPR13_AWCACHE_EPDC_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR13_AWCACHE_EPDC_EN) & BM_IOMUXC_GPR_GPR13_AWCACHE_EPDC_EN)

/*! @brief Set the AWCACHE_EPDC_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR13_AWCACHE_EPDC_EN(x, v) (HW_IOMUXC_GPR_GPR13_WR(x, (HW_IOMUXC_GPR_GPR13_RD(x) & ~BM_IOMUXC_GPR_GPR13_AWCACHE_EPDC_EN) | BF_IOMUXC_GPR_GPR13_AWCACHE_EPDC_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field PCIE_PHY_AFC_CODE_OUT_CH0[23:16] (RO)
 *
 * Monitoring AFC Code, Channel 0. This signal is the code of AFC.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_PCIE_PHY_AFC_CODE_OUT_CH0 (16U) /*!< Bit position for IOMUXC_GPR_GPR13_PCIE_PHY_AFC_CODE_OUT_CH0. */
#define BM_IOMUXC_GPR_GPR13_PCIE_PHY_AFC_CODE_OUT_CH0 (0x00FF0000U) /*!< Bit mask for IOMUXC_GPR_GPR13_PCIE_PHY_AFC_CODE_OUT_CH0. */
#define BS_IOMUXC_GPR_GPR13_PCIE_PHY_AFC_CODE_OUT_CH0 (8U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_PCIE_PHY_AFC_CODE_OUT_CH0. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_PCIE_PHY_AFC_CODE_OUT_CH0 field. */
#define BR_IOMUXC_GPR_GPR13_PCIE_PHY_AFC_CODE_OUT_CH0(x) (HW_IOMUXC_GPR_GPR13(x).B.PCIE_PHY_AFC_CODE_OUT_CH0)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field PCIE_PHY_VCO_BAND[27:24] (RO)
 *
 * Monitoring Code of VCO Calibration. This signal is the code of VCO
 * calibration.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_PCIE_PHY_VCO_BAND (24U) /*!< Bit position for IOMUXC_GPR_GPR13_PCIE_PHY_VCO_BAND. */
#define BM_IOMUXC_GPR_GPR13_PCIE_PHY_VCO_BAND (0x0F000000U) /*!< Bit mask for IOMUXC_GPR_GPR13_PCIE_PHY_VCO_BAND. */
#define BS_IOMUXC_GPR_GPR13_PCIE_PHY_VCO_BAND (4U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_PCIE_PHY_VCO_BAND. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_PCIE_PHY_VCO_BAND field. */
#define BR_IOMUXC_GPR_GPR13_PCIE_PHY_VCO_BAND(x) (HW_IOMUXC_GPR_GPR13(x).B.PCIE_PHY_VCO_BAND)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field PCIE_PHY_PMA_CDR_LOCKED_CH0[28] (RO)
 *
 * PLL Lock Indication for PCIe Test. When CDR locking is done, this signal goes
 * to high.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_PCIE_PHY_PMA_CDR_LOCKED_CH0 (28U) /*!< Bit position for IOMUXC_GPR_GPR13_PCIE_PHY_PMA_CDR_LOCKED_CH0. */
#define BM_IOMUXC_GPR_GPR13_PCIE_PHY_PMA_CDR_LOCKED_CH0 (0x10000000U) /*!< Bit mask for IOMUXC_GPR_GPR13_PCIE_PHY_PMA_CDR_LOCKED_CH0. */
#define BS_IOMUXC_GPR_GPR13_PCIE_PHY_PMA_CDR_LOCKED_CH0 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_PCIE_PHY_PMA_CDR_LOCKED_CH0. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_PCIE_PHY_PMA_CDR_LOCKED_CH0 field. */
#define BR_IOMUXC_GPR_GPR13_PCIE_PHY_PMA_CDR_LOCKED_CH0(x) (HW_IOMUXC_GPR_GPR13(x).B.PCIE_PHY_PMA_CDR_LOCKED_CH0)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field PCIE_PHY_PMA_RX_PRESENT_CH0[29] (RO)
 *
 * Receiver Detected Indication for PCIe Test. When receiver is detected in P1,
 * this signal goes to high.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_PCIE_PHY_PMA_RX_PRESENT_CH0 (29U) /*!< Bit position for IOMUXC_GPR_GPR13_PCIE_PHY_PMA_RX_PRESENT_CH0. */
#define BM_IOMUXC_GPR_GPR13_PCIE_PHY_PMA_RX_PRESENT_CH0 (0x20000000U) /*!< Bit mask for IOMUXC_GPR_GPR13_PCIE_PHY_PMA_RX_PRESENT_CH0. */
#define BS_IOMUXC_GPR_GPR13_PCIE_PHY_PMA_RX_PRESENT_CH0 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_PCIE_PHY_PMA_RX_PRESENT_CH0. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_PCIE_PHY_PMA_RX_PRESENT_CH0 field. */
#define BR_IOMUXC_GPR_GPR13_PCIE_PHY_PMA_RX_PRESENT_CH0(x) (HW_IOMUXC_GPR_GPR13(x).B.PCIE_PHY_PMA_RX_PRESENT_CH0)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field PCIE_PHY_CDR_VCO_MON_CH0[30] (RO)
 *
 * CDR VCO Monitor Channel 0
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_PCIE_PHY_CDR_VCO_MON_CH0 (30U) /*!< Bit position for IOMUXC_GPR_GPR13_PCIE_PHY_CDR_VCO_MON_CH0. */
#define BM_IOMUXC_GPR_GPR13_PCIE_PHY_CDR_VCO_MON_CH0 (0x40000000U) /*!< Bit mask for IOMUXC_GPR_GPR13_PCIE_PHY_CDR_VCO_MON_CH0. */
#define BS_IOMUXC_GPR_GPR13_PCIE_PHY_CDR_VCO_MON_CH0 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_PCIE_PHY_CDR_VCO_MON_CH0. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_PCIE_PHY_CDR_VCO_MON_CH0 field. */
#define BR_IOMUXC_GPR_GPR13_PCIE_PHY_CDR_VCO_MON_CH0(x) (HW_IOMUXC_GPR_GPR13(x).B.PCIE_PHY_CDR_VCO_MON_CH0)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR13, field PCIE_PHY_PCS_REFCLK_DISABLE[31] (RO)
 *
 * PCS Clock Request. When high, indicates that PHY is ready for reference clock
 * to be disabled. When MAC_CLKREQ_N goes high, PHY will assert this
 * PCS_REFCLK_DISABLE if it's okay for the external reference clock to be disabled. This
 * feature is not supported with internal reference clock, REFCLK_EXT. Timing: N/A
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR13_PCIE_PHY_PCS_REFCLK_DISABLE (31U) /*!< Bit position for IOMUXC_GPR_GPR13_PCIE_PHY_PCS_REFCLK_DISABLE. */
#define BM_IOMUXC_GPR_GPR13_PCIE_PHY_PCS_REFCLK_DISABLE (0x80000000U) /*!< Bit mask for IOMUXC_GPR_GPR13_PCIE_PHY_PCS_REFCLK_DISABLE. */
#define BS_IOMUXC_GPR_GPR13_PCIE_PHY_PCS_REFCLK_DISABLE (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR13_PCIE_PHY_PCS_REFCLK_DISABLE. */

/*! @brief Read current value of the IOMUXC_GPR_GPR13_PCIE_PHY_PCS_REFCLK_DISABLE field. */
#define BR_IOMUXC_GPR_GPR13_PCIE_PHY_PCS_REFCLK_DISABLE(x) (HW_IOMUXC_GPR_GPR13(x).B.PCIE_PHY_PCS_REFCLK_DISABLE)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR14 - GPR14 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR14 - GPR14 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr14
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr14_bitfields
    {
        uint32_t SIM1_SIMV2_EMV_SEL : 1; /*!< [0]  */
        uint32_t SIM2_SIMV2_EMV_SEL : 1; /*!< [1]  */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_iomuxc_gpr_gpr14_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR14 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR14_ADDR(x) ((uintptr_t)(x) + 0x38U)

#define HW_IOMUXC_GPR_GPR14(x)   (*(__IO hw_iomuxc_gpr_gpr14_t *) HW_IOMUXC_GPR_GPR14_ADDR(x))
#define HW_IOMUXC_GPR_GPR14_RD(x) (HW_IOMUXC_GPR_GPR14(x).U)
#define HW_IOMUXC_GPR_GPR14_WR(x, v) (HW_IOMUXC_GPR_GPR14(x).U = (v))
#define HW_IOMUXC_GPR_GPR14_SET(x, v) (HW_IOMUXC_GPR_GPR14_WR(x, HW_IOMUXC_GPR_GPR14_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR14_CLR(x, v) (HW_IOMUXC_GPR_GPR14_WR(x, HW_IOMUXC_GPR_GPR14_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR14_TOG(x, v) (HW_IOMUXC_GPR_GPR14_WR(x, HW_IOMUXC_GPR_GPR14_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR14 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR14, field SIM1_SIMV2_EMV_SEL[0] (RW)
 *
 * SIM1 EMV Select This bit should be programmed to 0 since EMV not supported
 *
 * Values:
 * - 0 - Select SIMv2
 * - 1 - Select EMV
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR14_SIM1_SIMV2_EMV_SEL (0U) /*!< Bit position for IOMUXC_GPR_GPR14_SIM1_SIMV2_EMV_SEL. */
#define BM_IOMUXC_GPR_GPR14_SIM1_SIMV2_EMV_SEL (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR14_SIM1_SIMV2_EMV_SEL. */
#define BS_IOMUXC_GPR_GPR14_SIM1_SIMV2_EMV_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR14_SIM1_SIMV2_EMV_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR14_SIM1_SIMV2_EMV_SEL field. */
#define BR_IOMUXC_GPR_GPR14_SIM1_SIMV2_EMV_SEL(x) (HW_IOMUXC_GPR_GPR14(x).B.SIM1_SIMV2_EMV_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR14_SIM1_SIMV2_EMV_SEL. */
#define BF_IOMUXC_GPR_GPR14_SIM1_SIMV2_EMV_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR14_SIM1_SIMV2_EMV_SEL) & BM_IOMUXC_GPR_GPR14_SIM1_SIMV2_EMV_SEL)

/*! @brief Set the SIM1_SIMV2_EMV_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR14_SIM1_SIMV2_EMV_SEL(x, v) (HW_IOMUXC_GPR_GPR14_WR(x, (HW_IOMUXC_GPR_GPR14_RD(x) & ~BM_IOMUXC_GPR_GPR14_SIM1_SIMV2_EMV_SEL) | BF_IOMUXC_GPR_GPR14_SIM1_SIMV2_EMV_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR14, field SIM2_SIMV2_EMV_SEL[1] (RW)
 *
 * SIM2 EMV Select This bit should be programmed to 0 since EMV not supported
 *
 * Values:
 * - 0 - Select SIMv2
 * - 1 - Select EMV
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR14_SIM2_SIMV2_EMV_SEL (1U) /*!< Bit position for IOMUXC_GPR_GPR14_SIM2_SIMV2_EMV_SEL. */
#define BM_IOMUXC_GPR_GPR14_SIM2_SIMV2_EMV_SEL (0x00000002U) /*!< Bit mask for IOMUXC_GPR_GPR14_SIM2_SIMV2_EMV_SEL. */
#define BS_IOMUXC_GPR_GPR14_SIM2_SIMV2_EMV_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR14_SIM2_SIMV2_EMV_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR14_SIM2_SIMV2_EMV_SEL field. */
#define BR_IOMUXC_GPR_GPR14_SIM2_SIMV2_EMV_SEL(x) (HW_IOMUXC_GPR_GPR14(x).B.SIM2_SIMV2_EMV_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR14_SIM2_SIMV2_EMV_SEL. */
#define BF_IOMUXC_GPR_GPR14_SIM2_SIMV2_EMV_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR14_SIM2_SIMV2_EMV_SEL) & BM_IOMUXC_GPR_GPR14_SIM2_SIMV2_EMV_SEL)

/*! @brief Set the SIM2_SIMV2_EMV_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR14_SIM2_SIMV2_EMV_SEL(x, v) (HW_IOMUXC_GPR_GPR14_WR(x, (HW_IOMUXC_GPR_GPR14_RD(x) & ~BM_IOMUXC_GPR_GPR14_SIM2_SIMV2_EMV_SEL) | BF_IOMUXC_GPR_GPR14_SIM2_SIMV2_EMV_SEL(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR15 - GPR15 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR15 - GPR15 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr15
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr15_bitfields
    {
        uint32_t LVDS_I_VBLK_FLAG : 1; /*!< [0]  */
        uint32_t LVDS_I_AUTO_SEL : 1;  /*!< [1]  */
        uint32_t LVDS_I_DESKEW_CNT_SET : 12; /*!< [13:2]  */
        uint32_t RESERVED0 : 2;        /*!< [15:14]  */
        uint32_t LVDS_I_LOCK_PPM_SET : 6; /*!< [21:16]  */
        uint32_t RESERVED1 : 10;       /*!< [31:22]  */
    } B;
} hw_iomuxc_gpr_gpr15_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR15 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR15_ADDR(x) ((uintptr_t)(x) + 0x3CU)

#define HW_IOMUXC_GPR_GPR15(x)   (*(__IO hw_iomuxc_gpr_gpr15_t *) HW_IOMUXC_GPR_GPR15_ADDR(x))
#define HW_IOMUXC_GPR_GPR15_RD(x) (HW_IOMUXC_GPR_GPR15(x).U)
#define HW_IOMUXC_GPR_GPR15_WR(x, v) (HW_IOMUXC_GPR_GPR15(x).U = (v))
#define HW_IOMUXC_GPR_GPR15_SET(x, v) (HW_IOMUXC_GPR_GPR15_WR(x, HW_IOMUXC_GPR_GPR15_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR15_CLR(x, v) (HW_IOMUXC_GPR_GPR15_WR(x, HW_IOMUXC_GPR_GPR15_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR15_TOG(x, v) (HW_IOMUXC_GPR_GPR15_WR(x, HW_IOMUXC_GPR_GPR15_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR15 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR15, field LVDS_I_VBLK_FLAG[0] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR15_LVDS_I_VBLK_FLAG (0U) /*!< Bit position for IOMUXC_GPR_GPR15_LVDS_I_VBLK_FLAG. */
#define BM_IOMUXC_GPR_GPR15_LVDS_I_VBLK_FLAG (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR15_LVDS_I_VBLK_FLAG. */
#define BS_IOMUXC_GPR_GPR15_LVDS_I_VBLK_FLAG (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR15_LVDS_I_VBLK_FLAG. */

/*! @brief Read current value of the IOMUXC_GPR_GPR15_LVDS_I_VBLK_FLAG field. */
#define BR_IOMUXC_GPR_GPR15_LVDS_I_VBLK_FLAG(x) (HW_IOMUXC_GPR_GPR15(x).B.LVDS_I_VBLK_FLAG)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR15_LVDS_I_VBLK_FLAG. */
#define BF_IOMUXC_GPR_GPR15_LVDS_I_VBLK_FLAG(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR15_LVDS_I_VBLK_FLAG) & BM_IOMUXC_GPR_GPR15_LVDS_I_VBLK_FLAG)

/*! @brief Set the LVDS_I_VBLK_FLAG field to a new value. */
#define BW_IOMUXC_GPR_GPR15_LVDS_I_VBLK_FLAG(x, v) (HW_IOMUXC_GPR_GPR15_WR(x, (HW_IOMUXC_GPR_GPR15_RD(x) & ~BM_IOMUXC_GPR_GPR15_LVDS_I_VBLK_FLAG) | BF_IOMUXC_GPR_GPR15_LVDS_I_VBLK_FLAG(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR15, field LVDS_I_AUTO_SEL[1] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR15_LVDS_I_AUTO_SEL (1U) /*!< Bit position for IOMUXC_GPR_GPR15_LVDS_I_AUTO_SEL. */
#define BM_IOMUXC_GPR_GPR15_LVDS_I_AUTO_SEL (0x00000002U) /*!< Bit mask for IOMUXC_GPR_GPR15_LVDS_I_AUTO_SEL. */
#define BS_IOMUXC_GPR_GPR15_LVDS_I_AUTO_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR15_LVDS_I_AUTO_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR15_LVDS_I_AUTO_SEL field. */
#define BR_IOMUXC_GPR_GPR15_LVDS_I_AUTO_SEL(x) (HW_IOMUXC_GPR_GPR15(x).B.LVDS_I_AUTO_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR15_LVDS_I_AUTO_SEL. */
#define BF_IOMUXC_GPR_GPR15_LVDS_I_AUTO_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR15_LVDS_I_AUTO_SEL) & BM_IOMUXC_GPR_GPR15_LVDS_I_AUTO_SEL)

/*! @brief Set the LVDS_I_AUTO_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR15_LVDS_I_AUTO_SEL(x, v) (HW_IOMUXC_GPR_GPR15_WR(x, (HW_IOMUXC_GPR_GPR15_RD(x) & ~BM_IOMUXC_GPR_GPR15_LVDS_I_AUTO_SEL) | BF_IOMUXC_GPR_GPR15_LVDS_I_AUTO_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR15, field LVDS_I_DESKEW_CNT_SET[13:2] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET (2U) /*!< Bit position for IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET. */
#define BM_IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET (0x00003FFCU) /*!< Bit mask for IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET. */
#define BS_IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET (12U) /*!< Bit field size in bits for IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET. */

/*! @brief Read current value of the IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET field. */
#define BR_IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET(x) (HW_IOMUXC_GPR_GPR15(x).B.LVDS_I_DESKEW_CNT_SET)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET. */
#define BF_IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET) & BM_IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET)

/*! @brief Set the LVDS_I_DESKEW_CNT_SET field to a new value. */
#define BW_IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET(x, v) (HW_IOMUXC_GPR_GPR15_WR(x, (HW_IOMUXC_GPR_GPR15_RD(x) & ~BM_IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET) | BF_IOMUXC_GPR_GPR15_LVDS_I_DESKEW_CNT_SET(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR15, field LVDS_I_LOCK_PPM_SET[21:16] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET (16U) /*!< Bit position for IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET. */
#define BM_IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET (0x003F0000U) /*!< Bit mask for IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET. */
#define BS_IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET (6U) /*!< Bit field size in bits for IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET. */

/*! @brief Read current value of the IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET field. */
#define BR_IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET(x) (HW_IOMUXC_GPR_GPR15(x).B.LVDS_I_LOCK_PPM_SET)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET. */
#define BF_IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET) & BM_IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET)

/*! @brief Set the LVDS_I_LOCK_PPM_SET field to a new value. */
#define BW_IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET(x, v) (HW_IOMUXC_GPR_GPR15_WR(x, (HW_IOMUXC_GPR_GPR15_RD(x) & ~BM_IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET) | BF_IOMUXC_GPR_GPR15_LVDS_I_LOCK_PPM_SET(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR16 - GPR16 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR16 - GPR16 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr16
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr16_bitfields
    {
        uint32_t LVDS_SKEW_REG_CUR : 2; /*!< [1:0]  */
        uint32_t LVDS_SEL_DATABF : 1;  /*!< [2]  */
        uint32_t LVDS_CNTB_TDLY : 1;   /*!< [3]  */
        uint32_t LVDS_SKEW_EN_H : 1;   /*!< [4]  */
        uint32_t LVDS_SKEWINI : 1;     /*!< [5]  */
        uint32_t LVDS_SK_BIAS : 4;     /*!< [9:6]  */
        uint32_t LVDS_AUTO_DSK_SEL : 1; /*!< [10]  */
        uint32_t LVDS_LOCK_CNT : 1;    /*!< [11]  */
        uint32_t LVDS_OUTCON : 1;      /*!< [12]  */
        uint32_t LVDS_FC_CODE : 3;     /*!< [15:13]  */
        uint32_t LVDS_SRC_TRH : 1;     /*!< [16]  */
        uint32_t LVDS_VOD_HIGH_S : 1;  /*!< [17]  */
        uint32_t RESERVED0 : 1;        /*!< [18]  */
        uint32_t LVDS_CNNCT_CNT : 2;   /*!< [20:19]  */
        uint32_t LVDS_CNNCT_MODE_SEL : 1; /*!< [21]  */
        uint32_t LVDS_FLT_CNT : 1;     /*!< [22]  */
        uint32_t LVDS_VOD_ONLY_CNT : 1; /*!< [23]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_iomuxc_gpr_gpr16_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR16 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR16_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_IOMUXC_GPR_GPR16(x)   (*(__IO hw_iomuxc_gpr_gpr16_t *) HW_IOMUXC_GPR_GPR16_ADDR(x))
#define HW_IOMUXC_GPR_GPR16_RD(x) (HW_IOMUXC_GPR_GPR16(x).U)
#define HW_IOMUXC_GPR_GPR16_WR(x, v) (HW_IOMUXC_GPR_GPR16(x).U = (v))
#define HW_IOMUXC_GPR_GPR16_SET(x, v) (HW_IOMUXC_GPR_GPR16_WR(x, HW_IOMUXC_GPR_GPR16_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR16_CLR(x, v) (HW_IOMUXC_GPR_GPR16_WR(x, HW_IOMUXC_GPR_GPR16_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR16_TOG(x, v) (HW_IOMUXC_GPR_GPR16_WR(x, HW_IOMUXC_GPR_GPR16_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR16 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR16, field LVDS_SKEW_REG_CUR[1:0] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR (0U) /*!< Bit position for IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR. */
#define BM_IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR (0x00000003U) /*!< Bit mask for IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR. */
#define BS_IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR. */

/*! @brief Read current value of the IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR field. */
#define BR_IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR(x) (HW_IOMUXC_GPR_GPR16(x).B.LVDS_SKEW_REG_CUR)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR. */
#define BF_IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR) & BM_IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR)

/*! @brief Set the LVDS_SKEW_REG_CUR field to a new value. */
#define BW_IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR(x, v) (HW_IOMUXC_GPR_GPR16_WR(x, (HW_IOMUXC_GPR_GPR16_RD(x) & ~BM_IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR) | BF_IOMUXC_GPR_GPR16_LVDS_SKEW_REG_CUR(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR16, field LVDS_SEL_DATABF[2] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR16_LVDS_SEL_DATABF (2U) /*!< Bit position for IOMUXC_GPR_GPR16_LVDS_SEL_DATABF. */
#define BM_IOMUXC_GPR_GPR16_LVDS_SEL_DATABF (0x00000004U) /*!< Bit mask for IOMUXC_GPR_GPR16_LVDS_SEL_DATABF. */
#define BS_IOMUXC_GPR_GPR16_LVDS_SEL_DATABF (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR16_LVDS_SEL_DATABF. */

/*! @brief Read current value of the IOMUXC_GPR_GPR16_LVDS_SEL_DATABF field. */
#define BR_IOMUXC_GPR_GPR16_LVDS_SEL_DATABF(x) (HW_IOMUXC_GPR_GPR16(x).B.LVDS_SEL_DATABF)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR16_LVDS_SEL_DATABF. */
#define BF_IOMUXC_GPR_GPR16_LVDS_SEL_DATABF(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR16_LVDS_SEL_DATABF) & BM_IOMUXC_GPR_GPR16_LVDS_SEL_DATABF)

/*! @brief Set the LVDS_SEL_DATABF field to a new value. */
#define BW_IOMUXC_GPR_GPR16_LVDS_SEL_DATABF(x, v) (HW_IOMUXC_GPR_GPR16_WR(x, (HW_IOMUXC_GPR_GPR16_RD(x) & ~BM_IOMUXC_GPR_GPR16_LVDS_SEL_DATABF) | BF_IOMUXC_GPR_GPR16_LVDS_SEL_DATABF(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR16, field LVDS_CNTB_TDLY[3] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR16_LVDS_CNTB_TDLY (3U) /*!< Bit position for IOMUXC_GPR_GPR16_LVDS_CNTB_TDLY. */
#define BM_IOMUXC_GPR_GPR16_LVDS_CNTB_TDLY (0x00000008U) /*!< Bit mask for IOMUXC_GPR_GPR16_LVDS_CNTB_TDLY. */
#define BS_IOMUXC_GPR_GPR16_LVDS_CNTB_TDLY (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR16_LVDS_CNTB_TDLY. */

/*! @brief Read current value of the IOMUXC_GPR_GPR16_LVDS_CNTB_TDLY field. */
#define BR_IOMUXC_GPR_GPR16_LVDS_CNTB_TDLY(x) (HW_IOMUXC_GPR_GPR16(x).B.LVDS_CNTB_TDLY)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR16_LVDS_CNTB_TDLY. */
#define BF_IOMUXC_GPR_GPR16_LVDS_CNTB_TDLY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR16_LVDS_CNTB_TDLY) & BM_IOMUXC_GPR_GPR16_LVDS_CNTB_TDLY)

/*! @brief Set the LVDS_CNTB_TDLY field to a new value. */
#define BW_IOMUXC_GPR_GPR16_LVDS_CNTB_TDLY(x, v) (HW_IOMUXC_GPR_GPR16_WR(x, (HW_IOMUXC_GPR_GPR16_RD(x) & ~BM_IOMUXC_GPR_GPR16_LVDS_CNTB_TDLY) | BF_IOMUXC_GPR_GPR16_LVDS_CNTB_TDLY(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR16, field LVDS_SKEW_EN_H[4] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR16_LVDS_SKEW_EN_H (4U) /*!< Bit position for IOMUXC_GPR_GPR16_LVDS_SKEW_EN_H. */
#define BM_IOMUXC_GPR_GPR16_LVDS_SKEW_EN_H (0x00000010U) /*!< Bit mask for IOMUXC_GPR_GPR16_LVDS_SKEW_EN_H. */
#define BS_IOMUXC_GPR_GPR16_LVDS_SKEW_EN_H (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR16_LVDS_SKEW_EN_H. */

/*! @brief Read current value of the IOMUXC_GPR_GPR16_LVDS_SKEW_EN_H field. */
#define BR_IOMUXC_GPR_GPR16_LVDS_SKEW_EN_H(x) (HW_IOMUXC_GPR_GPR16(x).B.LVDS_SKEW_EN_H)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR16_LVDS_SKEW_EN_H. */
#define BF_IOMUXC_GPR_GPR16_LVDS_SKEW_EN_H(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR16_LVDS_SKEW_EN_H) & BM_IOMUXC_GPR_GPR16_LVDS_SKEW_EN_H)

/*! @brief Set the LVDS_SKEW_EN_H field to a new value. */
#define BW_IOMUXC_GPR_GPR16_LVDS_SKEW_EN_H(x, v) (HW_IOMUXC_GPR_GPR16_WR(x, (HW_IOMUXC_GPR_GPR16_RD(x) & ~BM_IOMUXC_GPR_GPR16_LVDS_SKEW_EN_H) | BF_IOMUXC_GPR_GPR16_LVDS_SKEW_EN_H(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR16, field LVDS_SKEWINI[5] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR16_LVDS_SKEWINI (5U) /*!< Bit position for IOMUXC_GPR_GPR16_LVDS_SKEWINI. */
#define BM_IOMUXC_GPR_GPR16_LVDS_SKEWINI (0x00000020U) /*!< Bit mask for IOMUXC_GPR_GPR16_LVDS_SKEWINI. */
#define BS_IOMUXC_GPR_GPR16_LVDS_SKEWINI (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR16_LVDS_SKEWINI. */

/*! @brief Read current value of the IOMUXC_GPR_GPR16_LVDS_SKEWINI field. */
#define BR_IOMUXC_GPR_GPR16_LVDS_SKEWINI(x) (HW_IOMUXC_GPR_GPR16(x).B.LVDS_SKEWINI)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR16_LVDS_SKEWINI. */
#define BF_IOMUXC_GPR_GPR16_LVDS_SKEWINI(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR16_LVDS_SKEWINI) & BM_IOMUXC_GPR_GPR16_LVDS_SKEWINI)

/*! @brief Set the LVDS_SKEWINI field to a new value. */
#define BW_IOMUXC_GPR_GPR16_LVDS_SKEWINI(x, v) (HW_IOMUXC_GPR_GPR16_WR(x, (HW_IOMUXC_GPR_GPR16_RD(x) & ~BM_IOMUXC_GPR_GPR16_LVDS_SKEWINI) | BF_IOMUXC_GPR_GPR16_LVDS_SKEWINI(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR16, field LVDS_SK_BIAS[9:6] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR16_LVDS_SK_BIAS (6U) /*!< Bit position for IOMUXC_GPR_GPR16_LVDS_SK_BIAS. */
#define BM_IOMUXC_GPR_GPR16_LVDS_SK_BIAS (0x000003C0U) /*!< Bit mask for IOMUXC_GPR_GPR16_LVDS_SK_BIAS. */
#define BS_IOMUXC_GPR_GPR16_LVDS_SK_BIAS (4U) /*!< Bit field size in bits for IOMUXC_GPR_GPR16_LVDS_SK_BIAS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR16_LVDS_SK_BIAS field. */
#define BR_IOMUXC_GPR_GPR16_LVDS_SK_BIAS(x) (HW_IOMUXC_GPR_GPR16(x).B.LVDS_SK_BIAS)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR16_LVDS_SK_BIAS. */
#define BF_IOMUXC_GPR_GPR16_LVDS_SK_BIAS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR16_LVDS_SK_BIAS) & BM_IOMUXC_GPR_GPR16_LVDS_SK_BIAS)

/*! @brief Set the LVDS_SK_BIAS field to a new value. */
#define BW_IOMUXC_GPR_GPR16_LVDS_SK_BIAS(x, v) (HW_IOMUXC_GPR_GPR16_WR(x, (HW_IOMUXC_GPR_GPR16_RD(x) & ~BM_IOMUXC_GPR_GPR16_LVDS_SK_BIAS) | BF_IOMUXC_GPR_GPR16_LVDS_SK_BIAS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR16, field LVDS_AUTO_DSK_SEL[10] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR16_LVDS_AUTO_DSK_SEL (10U) /*!< Bit position for IOMUXC_GPR_GPR16_LVDS_AUTO_DSK_SEL. */
#define BM_IOMUXC_GPR_GPR16_LVDS_AUTO_DSK_SEL (0x00000400U) /*!< Bit mask for IOMUXC_GPR_GPR16_LVDS_AUTO_DSK_SEL. */
#define BS_IOMUXC_GPR_GPR16_LVDS_AUTO_DSK_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR16_LVDS_AUTO_DSK_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR16_LVDS_AUTO_DSK_SEL field. */
#define BR_IOMUXC_GPR_GPR16_LVDS_AUTO_DSK_SEL(x) (HW_IOMUXC_GPR_GPR16(x).B.LVDS_AUTO_DSK_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR16_LVDS_AUTO_DSK_SEL. */
#define BF_IOMUXC_GPR_GPR16_LVDS_AUTO_DSK_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR16_LVDS_AUTO_DSK_SEL) & BM_IOMUXC_GPR_GPR16_LVDS_AUTO_DSK_SEL)

/*! @brief Set the LVDS_AUTO_DSK_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR16_LVDS_AUTO_DSK_SEL(x, v) (HW_IOMUXC_GPR_GPR16_WR(x, (HW_IOMUXC_GPR_GPR16_RD(x) & ~BM_IOMUXC_GPR_GPR16_LVDS_AUTO_DSK_SEL) | BF_IOMUXC_GPR_GPR16_LVDS_AUTO_DSK_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR16, field LVDS_LOCK_CNT[11] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR16_LVDS_LOCK_CNT (11U) /*!< Bit position for IOMUXC_GPR_GPR16_LVDS_LOCK_CNT. */
#define BM_IOMUXC_GPR_GPR16_LVDS_LOCK_CNT (0x00000800U) /*!< Bit mask for IOMUXC_GPR_GPR16_LVDS_LOCK_CNT. */
#define BS_IOMUXC_GPR_GPR16_LVDS_LOCK_CNT (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR16_LVDS_LOCK_CNT. */

/*! @brief Read current value of the IOMUXC_GPR_GPR16_LVDS_LOCK_CNT field. */
#define BR_IOMUXC_GPR_GPR16_LVDS_LOCK_CNT(x) (HW_IOMUXC_GPR_GPR16(x).B.LVDS_LOCK_CNT)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR16_LVDS_LOCK_CNT. */
#define BF_IOMUXC_GPR_GPR16_LVDS_LOCK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR16_LVDS_LOCK_CNT) & BM_IOMUXC_GPR_GPR16_LVDS_LOCK_CNT)

/*! @brief Set the LVDS_LOCK_CNT field to a new value. */
#define BW_IOMUXC_GPR_GPR16_LVDS_LOCK_CNT(x, v) (HW_IOMUXC_GPR_GPR16_WR(x, (HW_IOMUXC_GPR_GPR16_RD(x) & ~BM_IOMUXC_GPR_GPR16_LVDS_LOCK_CNT) | BF_IOMUXC_GPR_GPR16_LVDS_LOCK_CNT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR16, field LVDS_OUTCON[12] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR16_LVDS_OUTCON (12U) /*!< Bit position for IOMUXC_GPR_GPR16_LVDS_OUTCON. */
#define BM_IOMUXC_GPR_GPR16_LVDS_OUTCON (0x00001000U) /*!< Bit mask for IOMUXC_GPR_GPR16_LVDS_OUTCON. */
#define BS_IOMUXC_GPR_GPR16_LVDS_OUTCON (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR16_LVDS_OUTCON. */

/*! @brief Read current value of the IOMUXC_GPR_GPR16_LVDS_OUTCON field. */
#define BR_IOMUXC_GPR_GPR16_LVDS_OUTCON(x) (HW_IOMUXC_GPR_GPR16(x).B.LVDS_OUTCON)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR16_LVDS_OUTCON. */
#define BF_IOMUXC_GPR_GPR16_LVDS_OUTCON(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR16_LVDS_OUTCON) & BM_IOMUXC_GPR_GPR16_LVDS_OUTCON)

/*! @brief Set the LVDS_OUTCON field to a new value. */
#define BW_IOMUXC_GPR_GPR16_LVDS_OUTCON(x, v) (HW_IOMUXC_GPR_GPR16_WR(x, (HW_IOMUXC_GPR_GPR16_RD(x) & ~BM_IOMUXC_GPR_GPR16_LVDS_OUTCON) | BF_IOMUXC_GPR_GPR16_LVDS_OUTCON(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR16, field LVDS_FC_CODE[15:13] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR16_LVDS_FC_CODE (13U) /*!< Bit position for IOMUXC_GPR_GPR16_LVDS_FC_CODE. */
#define BM_IOMUXC_GPR_GPR16_LVDS_FC_CODE (0x0000E000U) /*!< Bit mask for IOMUXC_GPR_GPR16_LVDS_FC_CODE. */
#define BS_IOMUXC_GPR_GPR16_LVDS_FC_CODE (3U) /*!< Bit field size in bits for IOMUXC_GPR_GPR16_LVDS_FC_CODE. */

/*! @brief Read current value of the IOMUXC_GPR_GPR16_LVDS_FC_CODE field. */
#define BR_IOMUXC_GPR_GPR16_LVDS_FC_CODE(x) (HW_IOMUXC_GPR_GPR16(x).B.LVDS_FC_CODE)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR16_LVDS_FC_CODE. */
#define BF_IOMUXC_GPR_GPR16_LVDS_FC_CODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR16_LVDS_FC_CODE) & BM_IOMUXC_GPR_GPR16_LVDS_FC_CODE)

/*! @brief Set the LVDS_FC_CODE field to a new value. */
#define BW_IOMUXC_GPR_GPR16_LVDS_FC_CODE(x, v) (HW_IOMUXC_GPR_GPR16_WR(x, (HW_IOMUXC_GPR_GPR16_RD(x) & ~BM_IOMUXC_GPR_GPR16_LVDS_FC_CODE) | BF_IOMUXC_GPR_GPR16_LVDS_FC_CODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR16, field LVDS_SRC_TRH[16] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR16_LVDS_SRC_TRH (16U) /*!< Bit position for IOMUXC_GPR_GPR16_LVDS_SRC_TRH. */
#define BM_IOMUXC_GPR_GPR16_LVDS_SRC_TRH (0x00010000U) /*!< Bit mask for IOMUXC_GPR_GPR16_LVDS_SRC_TRH. */
#define BS_IOMUXC_GPR_GPR16_LVDS_SRC_TRH (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR16_LVDS_SRC_TRH. */

/*! @brief Read current value of the IOMUXC_GPR_GPR16_LVDS_SRC_TRH field. */
#define BR_IOMUXC_GPR_GPR16_LVDS_SRC_TRH(x) (HW_IOMUXC_GPR_GPR16(x).B.LVDS_SRC_TRH)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR16_LVDS_SRC_TRH. */
#define BF_IOMUXC_GPR_GPR16_LVDS_SRC_TRH(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR16_LVDS_SRC_TRH) & BM_IOMUXC_GPR_GPR16_LVDS_SRC_TRH)

/*! @brief Set the LVDS_SRC_TRH field to a new value. */
#define BW_IOMUXC_GPR_GPR16_LVDS_SRC_TRH(x, v) (HW_IOMUXC_GPR_GPR16_WR(x, (HW_IOMUXC_GPR_GPR16_RD(x) & ~BM_IOMUXC_GPR_GPR16_LVDS_SRC_TRH) | BF_IOMUXC_GPR_GPR16_LVDS_SRC_TRH(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR16, field LVDS_VOD_HIGH_S[17] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR16_LVDS_VOD_HIGH_S (17U) /*!< Bit position for IOMUXC_GPR_GPR16_LVDS_VOD_HIGH_S. */
#define BM_IOMUXC_GPR_GPR16_LVDS_VOD_HIGH_S (0x00020000U) /*!< Bit mask for IOMUXC_GPR_GPR16_LVDS_VOD_HIGH_S. */
#define BS_IOMUXC_GPR_GPR16_LVDS_VOD_HIGH_S (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR16_LVDS_VOD_HIGH_S. */

/*! @brief Read current value of the IOMUXC_GPR_GPR16_LVDS_VOD_HIGH_S field. */
#define BR_IOMUXC_GPR_GPR16_LVDS_VOD_HIGH_S(x) (HW_IOMUXC_GPR_GPR16(x).B.LVDS_VOD_HIGH_S)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR16_LVDS_VOD_HIGH_S. */
#define BF_IOMUXC_GPR_GPR16_LVDS_VOD_HIGH_S(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR16_LVDS_VOD_HIGH_S) & BM_IOMUXC_GPR_GPR16_LVDS_VOD_HIGH_S)

/*! @brief Set the LVDS_VOD_HIGH_S field to a new value. */
#define BW_IOMUXC_GPR_GPR16_LVDS_VOD_HIGH_S(x, v) (HW_IOMUXC_GPR_GPR16_WR(x, (HW_IOMUXC_GPR_GPR16_RD(x) & ~BM_IOMUXC_GPR_GPR16_LVDS_VOD_HIGH_S) | BF_IOMUXC_GPR_GPR16_LVDS_VOD_HIGH_S(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR16, field LVDS_CNNCT_CNT[20:19] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT (19U) /*!< Bit position for IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT. */
#define BM_IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT (0x00180000U) /*!< Bit mask for IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT. */
#define BS_IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT. */

/*! @brief Read current value of the IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT field. */
#define BR_IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT(x) (HW_IOMUXC_GPR_GPR16(x).B.LVDS_CNNCT_CNT)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT. */
#define BF_IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT) & BM_IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT)

/*! @brief Set the LVDS_CNNCT_CNT field to a new value. */
#define BW_IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT(x, v) (HW_IOMUXC_GPR_GPR16_WR(x, (HW_IOMUXC_GPR_GPR16_RD(x) & ~BM_IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT) | BF_IOMUXC_GPR_GPR16_LVDS_CNNCT_CNT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR16, field LVDS_CNNCT_MODE_SEL[21] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR16_LVDS_CNNCT_MODE_SEL (21U) /*!< Bit position for IOMUXC_GPR_GPR16_LVDS_CNNCT_MODE_SEL. */
#define BM_IOMUXC_GPR_GPR16_LVDS_CNNCT_MODE_SEL (0x00200000U) /*!< Bit mask for IOMUXC_GPR_GPR16_LVDS_CNNCT_MODE_SEL. */
#define BS_IOMUXC_GPR_GPR16_LVDS_CNNCT_MODE_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR16_LVDS_CNNCT_MODE_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR16_LVDS_CNNCT_MODE_SEL field. */
#define BR_IOMUXC_GPR_GPR16_LVDS_CNNCT_MODE_SEL(x) (HW_IOMUXC_GPR_GPR16(x).B.LVDS_CNNCT_MODE_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR16_LVDS_CNNCT_MODE_SEL. */
#define BF_IOMUXC_GPR_GPR16_LVDS_CNNCT_MODE_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR16_LVDS_CNNCT_MODE_SEL) & BM_IOMUXC_GPR_GPR16_LVDS_CNNCT_MODE_SEL)

/*! @brief Set the LVDS_CNNCT_MODE_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR16_LVDS_CNNCT_MODE_SEL(x, v) (HW_IOMUXC_GPR_GPR16_WR(x, (HW_IOMUXC_GPR_GPR16_RD(x) & ~BM_IOMUXC_GPR_GPR16_LVDS_CNNCT_MODE_SEL) | BF_IOMUXC_GPR_GPR16_LVDS_CNNCT_MODE_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR16, field LVDS_FLT_CNT[22] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR16_LVDS_FLT_CNT (22U) /*!< Bit position for IOMUXC_GPR_GPR16_LVDS_FLT_CNT. */
#define BM_IOMUXC_GPR_GPR16_LVDS_FLT_CNT (0x00400000U) /*!< Bit mask for IOMUXC_GPR_GPR16_LVDS_FLT_CNT. */
#define BS_IOMUXC_GPR_GPR16_LVDS_FLT_CNT (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR16_LVDS_FLT_CNT. */

/*! @brief Read current value of the IOMUXC_GPR_GPR16_LVDS_FLT_CNT field. */
#define BR_IOMUXC_GPR_GPR16_LVDS_FLT_CNT(x) (HW_IOMUXC_GPR_GPR16(x).B.LVDS_FLT_CNT)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR16_LVDS_FLT_CNT. */
#define BF_IOMUXC_GPR_GPR16_LVDS_FLT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR16_LVDS_FLT_CNT) & BM_IOMUXC_GPR_GPR16_LVDS_FLT_CNT)

/*! @brief Set the LVDS_FLT_CNT field to a new value. */
#define BW_IOMUXC_GPR_GPR16_LVDS_FLT_CNT(x, v) (HW_IOMUXC_GPR_GPR16_WR(x, (HW_IOMUXC_GPR_GPR16_RD(x) & ~BM_IOMUXC_GPR_GPR16_LVDS_FLT_CNT) | BF_IOMUXC_GPR_GPR16_LVDS_FLT_CNT(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR16, field LVDS_VOD_ONLY_CNT[23] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR16_LVDS_VOD_ONLY_CNT (23U) /*!< Bit position for IOMUXC_GPR_GPR16_LVDS_VOD_ONLY_CNT. */
#define BM_IOMUXC_GPR_GPR16_LVDS_VOD_ONLY_CNT (0x00800000U) /*!< Bit mask for IOMUXC_GPR_GPR16_LVDS_VOD_ONLY_CNT. */
#define BS_IOMUXC_GPR_GPR16_LVDS_VOD_ONLY_CNT (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR16_LVDS_VOD_ONLY_CNT. */

/*! @brief Read current value of the IOMUXC_GPR_GPR16_LVDS_VOD_ONLY_CNT field. */
#define BR_IOMUXC_GPR_GPR16_LVDS_VOD_ONLY_CNT(x) (HW_IOMUXC_GPR_GPR16(x).B.LVDS_VOD_ONLY_CNT)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR16_LVDS_VOD_ONLY_CNT. */
#define BF_IOMUXC_GPR_GPR16_LVDS_VOD_ONLY_CNT(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR16_LVDS_VOD_ONLY_CNT) & BM_IOMUXC_GPR_GPR16_LVDS_VOD_ONLY_CNT)

/*! @brief Set the LVDS_VOD_ONLY_CNT field to a new value. */
#define BW_IOMUXC_GPR_GPR16_LVDS_VOD_ONLY_CNT(x, v) (HW_IOMUXC_GPR_GPR16_WR(x, (HW_IOMUXC_GPR_GPR16_RD(x) & ~BM_IOMUXC_GPR_GPR16_LVDS_VOD_ONLY_CNT) | BF_IOMUXC_GPR_GPR16_LVDS_VOD_ONLY_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR17 - GPR17 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR17 - GPR17 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr17
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr17_bitfields
    {
        uint32_t LVDS_CNT_PEN_H : 8;   /*!< [7:0]  */
        uint32_t LVDS_CNT_VOD_H : 8;   /*!< [15:8]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_iomuxc_gpr_gpr17_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR17 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR17_ADDR(x) ((uintptr_t)(x) + 0x44U)

#define HW_IOMUXC_GPR_GPR17(x)   (*(__IO hw_iomuxc_gpr_gpr17_t *) HW_IOMUXC_GPR_GPR17_ADDR(x))
#define HW_IOMUXC_GPR_GPR17_RD(x) (HW_IOMUXC_GPR_GPR17(x).U)
#define HW_IOMUXC_GPR_GPR17_WR(x, v) (HW_IOMUXC_GPR_GPR17(x).U = (v))
#define HW_IOMUXC_GPR_GPR17_SET(x, v) (HW_IOMUXC_GPR_GPR17_WR(x, HW_IOMUXC_GPR_GPR17_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR17_CLR(x, v) (HW_IOMUXC_GPR_GPR17_WR(x, HW_IOMUXC_GPR_GPR17_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR17_TOG(x, v) (HW_IOMUXC_GPR_GPR17_WR(x, HW_IOMUXC_GPR_GPR17_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR17 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR17, field LVDS_CNT_PEN_H[7:0] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H (0U) /*!< Bit position for IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H. */
#define BM_IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H (0x000000FFU) /*!< Bit mask for IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H. */
#define BS_IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H (8U) /*!< Bit field size in bits for IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H. */

/*! @brief Read current value of the IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H field. */
#define BR_IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H(x) (HW_IOMUXC_GPR_GPR17(x).B.LVDS_CNT_PEN_H)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H. */
#define BF_IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H) & BM_IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H)

/*! @brief Set the LVDS_CNT_PEN_H field to a new value. */
#define BW_IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H(x, v) (HW_IOMUXC_GPR_GPR17_WR(x, (HW_IOMUXC_GPR_GPR17_RD(x) & ~BM_IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H) | BF_IOMUXC_GPR_GPR17_LVDS_CNT_PEN_H(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR17, field LVDS_CNT_VOD_H[15:8] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H (8U) /*!< Bit position for IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H. */
#define BM_IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H (0x0000FF00U) /*!< Bit mask for IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H. */
#define BS_IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H (8U) /*!< Bit field size in bits for IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H. */

/*! @brief Read current value of the IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H field. */
#define BR_IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H(x) (HW_IOMUXC_GPR_GPR17(x).B.LVDS_CNT_VOD_H)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H. */
#define BF_IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H) & BM_IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H)

/*! @brief Set the LVDS_CNT_VOD_H field to a new value. */
#define BW_IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H(x, v) (HW_IOMUXC_GPR_GPR17_WR(x, (HW_IOMUXC_GPR_GPR17_RD(x) & ~BM_IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H) | BF_IOMUXC_GPR_GPR17_LVDS_CNT_VOD_H(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR18 - GPR18 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR18 - GPR18 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr18
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr18_bitfields
    {
        uint32_t LVDS_I_BIST_CH_SEL : 3; /*!< [2:0]  */
        uint32_t LVDS_I_BIST_DATA_INV : 2; /*!< [4:3]  */
        uint32_t LVDS_I_BIST_CLK_INV : 2; /*!< [6:5]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t LVDS_I_BIST_SKEW_CTRL : 6; /*!< [13:8]  */
        uint32_t LVDS_I_BIST_FORCE_ERROR : 1; /*!< [14]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t LVDS_I_BIST_USER_PATTERN : 7; /*!< [22:16]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t LVDS_I_BIST_PAT_SEL : 2; /*!< [25:24]  */
        uint32_t LVDS_I_BIST_EN : 1;   /*!< [26]  */
        uint32_t LVDS_I_BIST_RESETB : 1; /*!< [27]  */
        uint32_t LVDS_DLYS_BST : 1;    /*!< [28]  */
        uint32_t LVDS_SKINI_BST : 1;   /*!< [29]  */
        uint32_t RESERVED3 : 2;        /*!< [31:30]  */
    } B;
} hw_iomuxc_gpr_gpr18_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR18 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR18_ADDR(x) ((uintptr_t)(x) + 0x48U)

#define HW_IOMUXC_GPR_GPR18(x)   (*(__IO hw_iomuxc_gpr_gpr18_t *) HW_IOMUXC_GPR_GPR18_ADDR(x))
#define HW_IOMUXC_GPR_GPR18_RD(x) (HW_IOMUXC_GPR_GPR18(x).U)
#define HW_IOMUXC_GPR_GPR18_WR(x, v) (HW_IOMUXC_GPR_GPR18(x).U = (v))
#define HW_IOMUXC_GPR_GPR18_SET(x, v) (HW_IOMUXC_GPR_GPR18_WR(x, HW_IOMUXC_GPR_GPR18_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR18_CLR(x, v) (HW_IOMUXC_GPR_GPR18_WR(x, HW_IOMUXC_GPR_GPR18_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR18_TOG(x, v) (HW_IOMUXC_GPR_GPR18_WR(x, HW_IOMUXC_GPR_GPR18_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR18 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR18, field LVDS_I_BIST_CH_SEL[2:0] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL (0U) /*!< Bit position for IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL. */
#define BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL (0x00000007U) /*!< Bit mask for IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL. */
#define BS_IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL (3U) /*!< Bit field size in bits for IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL field. */
#define BR_IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL(x) (HW_IOMUXC_GPR_GPR18(x).B.LVDS_I_BIST_CH_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL. */
#define BF_IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL) & BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL)

/*! @brief Set the LVDS_I_BIST_CH_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL(x, v) (HW_IOMUXC_GPR_GPR18_WR(x, (HW_IOMUXC_GPR_GPR18_RD(x) & ~BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL) | BF_IOMUXC_GPR_GPR18_LVDS_I_BIST_CH_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR18, field LVDS_I_BIST_DATA_INV[4:3] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV (3U) /*!< Bit position for IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV. */
#define BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV (0x00000018U) /*!< Bit mask for IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV. */
#define BS_IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV. */

/*! @brief Read current value of the IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV field. */
#define BR_IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV(x) (HW_IOMUXC_GPR_GPR18(x).B.LVDS_I_BIST_DATA_INV)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV. */
#define BF_IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV) & BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV)

/*! @brief Set the LVDS_I_BIST_DATA_INV field to a new value. */
#define BW_IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV(x, v) (HW_IOMUXC_GPR_GPR18_WR(x, (HW_IOMUXC_GPR_GPR18_RD(x) & ~BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV) | BF_IOMUXC_GPR_GPR18_LVDS_I_BIST_DATA_INV(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR18, field LVDS_I_BIST_CLK_INV[6:5] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV (5U) /*!< Bit position for IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV. */
#define BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV (0x00000060U) /*!< Bit mask for IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV. */
#define BS_IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV. */

/*! @brief Read current value of the IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV field. */
#define BR_IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV(x) (HW_IOMUXC_GPR_GPR18(x).B.LVDS_I_BIST_CLK_INV)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV. */
#define BF_IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV) & BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV)

/*! @brief Set the LVDS_I_BIST_CLK_INV field to a new value. */
#define BW_IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV(x, v) (HW_IOMUXC_GPR_GPR18_WR(x, (HW_IOMUXC_GPR_GPR18_RD(x) & ~BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV) | BF_IOMUXC_GPR_GPR18_LVDS_I_BIST_CLK_INV(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR18, field LVDS_I_BIST_SKEW_CTRL[13:8] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL (8U) /*!< Bit position for IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL. */
#define BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL (0x00003F00U) /*!< Bit mask for IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL. */
#define BS_IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL (6U) /*!< Bit field size in bits for IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL field. */
#define BR_IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL(x) (HW_IOMUXC_GPR_GPR18(x).B.LVDS_I_BIST_SKEW_CTRL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL. */
#define BF_IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL) & BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL)

/*! @brief Set the LVDS_I_BIST_SKEW_CTRL field to a new value. */
#define BW_IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL(x, v) (HW_IOMUXC_GPR_GPR18_WR(x, (HW_IOMUXC_GPR_GPR18_RD(x) & ~BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL) | BF_IOMUXC_GPR_GPR18_LVDS_I_BIST_SKEW_CTRL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR18, field LVDS_I_BIST_FORCE_ERROR[14] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR18_LVDS_I_BIST_FORCE_ERROR (14U) /*!< Bit position for IOMUXC_GPR_GPR18_LVDS_I_BIST_FORCE_ERROR. */
#define BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_FORCE_ERROR (0x00004000U) /*!< Bit mask for IOMUXC_GPR_GPR18_LVDS_I_BIST_FORCE_ERROR. */
#define BS_IOMUXC_GPR_GPR18_LVDS_I_BIST_FORCE_ERROR (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR18_LVDS_I_BIST_FORCE_ERROR. */

/*! @brief Read current value of the IOMUXC_GPR_GPR18_LVDS_I_BIST_FORCE_ERROR field. */
#define BR_IOMUXC_GPR_GPR18_LVDS_I_BIST_FORCE_ERROR(x) (HW_IOMUXC_GPR_GPR18(x).B.LVDS_I_BIST_FORCE_ERROR)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR18_LVDS_I_BIST_FORCE_ERROR. */
#define BF_IOMUXC_GPR_GPR18_LVDS_I_BIST_FORCE_ERROR(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR18_LVDS_I_BIST_FORCE_ERROR) & BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_FORCE_ERROR)

/*! @brief Set the LVDS_I_BIST_FORCE_ERROR field to a new value. */
#define BW_IOMUXC_GPR_GPR18_LVDS_I_BIST_FORCE_ERROR(x, v) (HW_IOMUXC_GPR_GPR18_WR(x, (HW_IOMUXC_GPR_GPR18_RD(x) & ~BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_FORCE_ERROR) | BF_IOMUXC_GPR_GPR18_LVDS_I_BIST_FORCE_ERROR(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR18, field LVDS_I_BIST_USER_PATTERN[22:16] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN (16U) /*!< Bit position for IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN. */
#define BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN (0x007F0000U) /*!< Bit mask for IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN. */
#define BS_IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN (7U) /*!< Bit field size in bits for IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN field. */
#define BR_IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN(x) (HW_IOMUXC_GPR_GPR18(x).B.LVDS_I_BIST_USER_PATTERN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN. */
#define BF_IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN) & BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN)

/*! @brief Set the LVDS_I_BIST_USER_PATTERN field to a new value. */
#define BW_IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN(x, v) (HW_IOMUXC_GPR_GPR18_WR(x, (HW_IOMUXC_GPR_GPR18_RD(x) & ~BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN) | BF_IOMUXC_GPR_GPR18_LVDS_I_BIST_USER_PATTERN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR18, field LVDS_I_BIST_PAT_SEL[25:24] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL (24U) /*!< Bit position for IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL. */
#define BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL (0x03000000U) /*!< Bit mask for IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL. */
#define BS_IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL (2U) /*!< Bit field size in bits for IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL field. */
#define BR_IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL(x) (HW_IOMUXC_GPR_GPR18(x).B.LVDS_I_BIST_PAT_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL. */
#define BF_IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL) & BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL)

/*! @brief Set the LVDS_I_BIST_PAT_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL(x, v) (HW_IOMUXC_GPR_GPR18_WR(x, (HW_IOMUXC_GPR_GPR18_RD(x) & ~BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL) | BF_IOMUXC_GPR_GPR18_LVDS_I_BIST_PAT_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR18, field LVDS_I_BIST_EN[26] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR18_LVDS_I_BIST_EN (26U) /*!< Bit position for IOMUXC_GPR_GPR18_LVDS_I_BIST_EN. */
#define BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_EN (0x04000000U) /*!< Bit mask for IOMUXC_GPR_GPR18_LVDS_I_BIST_EN. */
#define BS_IOMUXC_GPR_GPR18_LVDS_I_BIST_EN (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR18_LVDS_I_BIST_EN. */

/*! @brief Read current value of the IOMUXC_GPR_GPR18_LVDS_I_BIST_EN field. */
#define BR_IOMUXC_GPR_GPR18_LVDS_I_BIST_EN(x) (HW_IOMUXC_GPR_GPR18(x).B.LVDS_I_BIST_EN)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR18_LVDS_I_BIST_EN. */
#define BF_IOMUXC_GPR_GPR18_LVDS_I_BIST_EN(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR18_LVDS_I_BIST_EN) & BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_EN)

/*! @brief Set the LVDS_I_BIST_EN field to a new value. */
#define BW_IOMUXC_GPR_GPR18_LVDS_I_BIST_EN(x, v) (HW_IOMUXC_GPR_GPR18_WR(x, (HW_IOMUXC_GPR_GPR18_RD(x) & ~BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_EN) | BF_IOMUXC_GPR_GPR18_LVDS_I_BIST_EN(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR18, field LVDS_I_BIST_RESETB[27] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR18_LVDS_I_BIST_RESETB (27U) /*!< Bit position for IOMUXC_GPR_GPR18_LVDS_I_BIST_RESETB. */
#define BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_RESETB (0x08000000U) /*!< Bit mask for IOMUXC_GPR_GPR18_LVDS_I_BIST_RESETB. */
#define BS_IOMUXC_GPR_GPR18_LVDS_I_BIST_RESETB (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR18_LVDS_I_BIST_RESETB. */

/*! @brief Read current value of the IOMUXC_GPR_GPR18_LVDS_I_BIST_RESETB field. */
#define BR_IOMUXC_GPR_GPR18_LVDS_I_BIST_RESETB(x) (HW_IOMUXC_GPR_GPR18(x).B.LVDS_I_BIST_RESETB)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR18_LVDS_I_BIST_RESETB. */
#define BF_IOMUXC_GPR_GPR18_LVDS_I_BIST_RESETB(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR18_LVDS_I_BIST_RESETB) & BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_RESETB)

/*! @brief Set the LVDS_I_BIST_RESETB field to a new value. */
#define BW_IOMUXC_GPR_GPR18_LVDS_I_BIST_RESETB(x, v) (HW_IOMUXC_GPR_GPR18_WR(x, (HW_IOMUXC_GPR_GPR18_RD(x) & ~BM_IOMUXC_GPR_GPR18_LVDS_I_BIST_RESETB) | BF_IOMUXC_GPR_GPR18_LVDS_I_BIST_RESETB(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR18, field LVDS_DLYS_BST[28] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR18_LVDS_DLYS_BST (28U) /*!< Bit position for IOMUXC_GPR_GPR18_LVDS_DLYS_BST. */
#define BM_IOMUXC_GPR_GPR18_LVDS_DLYS_BST (0x10000000U) /*!< Bit mask for IOMUXC_GPR_GPR18_LVDS_DLYS_BST. */
#define BS_IOMUXC_GPR_GPR18_LVDS_DLYS_BST (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR18_LVDS_DLYS_BST. */

/*! @brief Read current value of the IOMUXC_GPR_GPR18_LVDS_DLYS_BST field. */
#define BR_IOMUXC_GPR_GPR18_LVDS_DLYS_BST(x) (HW_IOMUXC_GPR_GPR18(x).B.LVDS_DLYS_BST)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR18_LVDS_DLYS_BST. */
#define BF_IOMUXC_GPR_GPR18_LVDS_DLYS_BST(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR18_LVDS_DLYS_BST) & BM_IOMUXC_GPR_GPR18_LVDS_DLYS_BST)

/*! @brief Set the LVDS_DLYS_BST field to a new value. */
#define BW_IOMUXC_GPR_GPR18_LVDS_DLYS_BST(x, v) (HW_IOMUXC_GPR_GPR18_WR(x, (HW_IOMUXC_GPR_GPR18_RD(x) & ~BM_IOMUXC_GPR_GPR18_LVDS_DLYS_BST) | BF_IOMUXC_GPR_GPR18_LVDS_DLYS_BST(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR18, field LVDS_SKINI_BST[29] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR18_LVDS_SKINI_BST (29U) /*!< Bit position for IOMUXC_GPR_GPR18_LVDS_SKINI_BST. */
#define BM_IOMUXC_GPR_GPR18_LVDS_SKINI_BST (0x20000000U) /*!< Bit mask for IOMUXC_GPR_GPR18_LVDS_SKINI_BST. */
#define BS_IOMUXC_GPR_GPR18_LVDS_SKINI_BST (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR18_LVDS_SKINI_BST. */

/*! @brief Read current value of the IOMUXC_GPR_GPR18_LVDS_SKINI_BST field. */
#define BR_IOMUXC_GPR_GPR18_LVDS_SKINI_BST(x) (HW_IOMUXC_GPR_GPR18(x).B.LVDS_SKINI_BST)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR18_LVDS_SKINI_BST. */
#define BF_IOMUXC_GPR_GPR18_LVDS_SKINI_BST(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR18_LVDS_SKINI_BST) & BM_IOMUXC_GPR_GPR18_LVDS_SKINI_BST)

/*! @brief Set the LVDS_SKINI_BST field to a new value. */
#define BW_IOMUXC_GPR_GPR18_LVDS_SKINI_BST(x, v) (HW_IOMUXC_GPR_GPR18_WR(x, (HW_IOMUXC_GPR_GPR18_RD(x) & ~BM_IOMUXC_GPR_GPR18_LVDS_SKINI_BST) | BF_IOMUXC_GPR_GPR18_LVDS_SKINI_BST(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR19 - GPR19 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR19 - GPR19 General Purpose Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr19
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr19_bitfields
    {
        uint32_t LVDS_O_BIST_STATUS : 1; /*!< [0]  */
        uint32_t RESERVED0 : 7;        /*!< [7:1]  */
        uint32_t LVDS_O_BIST_ERR_COUNT : 8; /*!< [15:8]  */
        uint32_t LVDS_O_BIST_SYNC : 1; /*!< [16]  */
        uint32_t LVDS_MON_FOR_CNNCT : 1; /*!< [17]  */
        uint32_t RESERVED1 : 14;       /*!< [31:18]  */
    } B;
} hw_iomuxc_gpr_gpr19_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR19 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR19_ADDR(x) ((uintptr_t)(x) + 0x4CU)

#define HW_IOMUXC_GPR_GPR19(x)   (*(__I hw_iomuxc_gpr_gpr19_t *) HW_IOMUXC_GPR_GPR19_ADDR(x))
#define HW_IOMUXC_GPR_GPR19_RD(x) (HW_IOMUXC_GPR_GPR19(x).U)
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR19 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR19, field LVDS_O_BIST_STATUS[0] (RO)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR19_LVDS_O_BIST_STATUS (0U) /*!< Bit position for IOMUXC_GPR_GPR19_LVDS_O_BIST_STATUS. */
#define BM_IOMUXC_GPR_GPR19_LVDS_O_BIST_STATUS (0x00000001U) /*!< Bit mask for IOMUXC_GPR_GPR19_LVDS_O_BIST_STATUS. */
#define BS_IOMUXC_GPR_GPR19_LVDS_O_BIST_STATUS (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR19_LVDS_O_BIST_STATUS. */

/*! @brief Read current value of the IOMUXC_GPR_GPR19_LVDS_O_BIST_STATUS field. */
#define BR_IOMUXC_GPR_GPR19_LVDS_O_BIST_STATUS(x) (HW_IOMUXC_GPR_GPR19(x).B.LVDS_O_BIST_STATUS)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR19, field LVDS_O_BIST_ERR_COUNT[15:8] (RO)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR19_LVDS_O_BIST_ERR_COUNT (8U) /*!< Bit position for IOMUXC_GPR_GPR19_LVDS_O_BIST_ERR_COUNT. */
#define BM_IOMUXC_GPR_GPR19_LVDS_O_BIST_ERR_COUNT (0x0000FF00U) /*!< Bit mask for IOMUXC_GPR_GPR19_LVDS_O_BIST_ERR_COUNT. */
#define BS_IOMUXC_GPR_GPR19_LVDS_O_BIST_ERR_COUNT (8U) /*!< Bit field size in bits for IOMUXC_GPR_GPR19_LVDS_O_BIST_ERR_COUNT. */

/*! @brief Read current value of the IOMUXC_GPR_GPR19_LVDS_O_BIST_ERR_COUNT field. */
#define BR_IOMUXC_GPR_GPR19_LVDS_O_BIST_ERR_COUNT(x) (HW_IOMUXC_GPR_GPR19(x).B.LVDS_O_BIST_ERR_COUNT)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR19, field LVDS_O_BIST_SYNC[16] (RO)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR19_LVDS_O_BIST_SYNC (16U) /*!< Bit position for IOMUXC_GPR_GPR19_LVDS_O_BIST_SYNC. */
#define BM_IOMUXC_GPR_GPR19_LVDS_O_BIST_SYNC (0x00010000U) /*!< Bit mask for IOMUXC_GPR_GPR19_LVDS_O_BIST_SYNC. */
#define BS_IOMUXC_GPR_GPR19_LVDS_O_BIST_SYNC (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR19_LVDS_O_BIST_SYNC. */

/*! @brief Read current value of the IOMUXC_GPR_GPR19_LVDS_O_BIST_SYNC field. */
#define BR_IOMUXC_GPR_GPR19_LVDS_O_BIST_SYNC(x) (HW_IOMUXC_GPR_GPR19(x).B.LVDS_O_BIST_SYNC)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR19, field LVDS_MON_FOR_CNNCT[17] (RO)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR19_LVDS_MON_FOR_CNNCT (17U) /*!< Bit position for IOMUXC_GPR_GPR19_LVDS_MON_FOR_CNNCT. */
#define BM_IOMUXC_GPR_GPR19_LVDS_MON_FOR_CNNCT (0x00020000U) /*!< Bit mask for IOMUXC_GPR_GPR19_LVDS_MON_FOR_CNNCT. */
#define BS_IOMUXC_GPR_GPR19_LVDS_MON_FOR_CNNCT (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR19_LVDS_MON_FOR_CNNCT. */

/*! @brief Read current value of the IOMUXC_GPR_GPR19_LVDS_MON_FOR_CNNCT field. */
#define BR_IOMUXC_GPR_GPR19_LVDS_MON_FOR_CNNCT(x) (HW_IOMUXC_GPR_GPR19(x).B.LVDS_MON_FOR_CNNCT)
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR20 - GPR20 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR20 - GPR20 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr20
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr20_bitfields
    {
        uint32_t LVDS_P : 6;           /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t LVDS_M : 6;           /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t LVDS_S : 2;           /*!< [17:16]  */
        uint32_t RESERVED2 : 6;        /*!< [23:18]  */
        uint32_t LVDS_VSEL : 1;        /*!< [24]  */
        uint32_t LVDS_CK_POL_SEL : 1;  /*!< [25]  */
        uint32_t RESERVED3 : 1;        /*!< [26]  */
        uint32_t LVDS_I_TX2801X_DUMMY : 3; /*!< [29:27]  */
        uint32_t RESERVED4 : 2;        /*!< [31:30]  */
    } B;
} hw_iomuxc_gpr_gpr20_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR20 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR20_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_IOMUXC_GPR_GPR20(x)   (*(__IO hw_iomuxc_gpr_gpr20_t *) HW_IOMUXC_GPR_GPR20_ADDR(x))
#define HW_IOMUXC_GPR_GPR20_RD(x) (HW_IOMUXC_GPR_GPR20(x).U)
#define HW_IOMUXC_GPR_GPR20_WR(x, v) (HW_IOMUXC_GPR_GPR20(x).U = (v))
#define HW_IOMUXC_GPR_GPR20_SET(x, v) (HW_IOMUXC_GPR_GPR20_WR(x, HW_IOMUXC_GPR_GPR20_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR20_CLR(x, v) (HW_IOMUXC_GPR_GPR20_WR(x, HW_IOMUXC_GPR_GPR20_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR20_TOG(x, v) (HW_IOMUXC_GPR_GPR20_WR(x, HW_IOMUXC_GPR_GPR20_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR20 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR20, field LVDS_P[5:0] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR20_LVDS_P (0U)    /*!< Bit position for IOMUXC_GPR_GPR20_LVDS_P. */
#define BM_IOMUXC_GPR_GPR20_LVDS_P (0x0000003FU) /*!< Bit mask for IOMUXC_GPR_GPR20_LVDS_P. */
#define BS_IOMUXC_GPR_GPR20_LVDS_P (6U)    /*!< Bit field size in bits for IOMUXC_GPR_GPR20_LVDS_P. */

/*! @brief Read current value of the IOMUXC_GPR_GPR20_LVDS_P field. */
#define BR_IOMUXC_GPR_GPR20_LVDS_P(x) (HW_IOMUXC_GPR_GPR20(x).B.LVDS_P)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR20_LVDS_P. */
#define BF_IOMUXC_GPR_GPR20_LVDS_P(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR20_LVDS_P) & BM_IOMUXC_GPR_GPR20_LVDS_P)

/*! @brief Set the LVDS_P field to a new value. */
#define BW_IOMUXC_GPR_GPR20_LVDS_P(x, v) (HW_IOMUXC_GPR_GPR20_WR(x, (HW_IOMUXC_GPR_GPR20_RD(x) & ~BM_IOMUXC_GPR_GPR20_LVDS_P) | BF_IOMUXC_GPR_GPR20_LVDS_P(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR20, field LVDS_M[13:8] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR20_LVDS_M (8U)    /*!< Bit position for IOMUXC_GPR_GPR20_LVDS_M. */
#define BM_IOMUXC_GPR_GPR20_LVDS_M (0x00003F00U) /*!< Bit mask for IOMUXC_GPR_GPR20_LVDS_M. */
#define BS_IOMUXC_GPR_GPR20_LVDS_M (6U)    /*!< Bit field size in bits for IOMUXC_GPR_GPR20_LVDS_M. */

/*! @brief Read current value of the IOMUXC_GPR_GPR20_LVDS_M field. */
#define BR_IOMUXC_GPR_GPR20_LVDS_M(x) (HW_IOMUXC_GPR_GPR20(x).B.LVDS_M)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR20_LVDS_M. */
#define BF_IOMUXC_GPR_GPR20_LVDS_M(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR20_LVDS_M) & BM_IOMUXC_GPR_GPR20_LVDS_M)

/*! @brief Set the LVDS_M field to a new value. */
#define BW_IOMUXC_GPR_GPR20_LVDS_M(x, v) (HW_IOMUXC_GPR_GPR20_WR(x, (HW_IOMUXC_GPR_GPR20_RD(x) & ~BM_IOMUXC_GPR_GPR20_LVDS_M) | BF_IOMUXC_GPR_GPR20_LVDS_M(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR20, field LVDS_S[17:16] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR20_LVDS_S (16U)   /*!< Bit position for IOMUXC_GPR_GPR20_LVDS_S. */
#define BM_IOMUXC_GPR_GPR20_LVDS_S (0x00030000U) /*!< Bit mask for IOMUXC_GPR_GPR20_LVDS_S. */
#define BS_IOMUXC_GPR_GPR20_LVDS_S (2U)    /*!< Bit field size in bits for IOMUXC_GPR_GPR20_LVDS_S. */

/*! @brief Read current value of the IOMUXC_GPR_GPR20_LVDS_S field. */
#define BR_IOMUXC_GPR_GPR20_LVDS_S(x) (HW_IOMUXC_GPR_GPR20(x).B.LVDS_S)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR20_LVDS_S. */
#define BF_IOMUXC_GPR_GPR20_LVDS_S(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR20_LVDS_S) & BM_IOMUXC_GPR_GPR20_LVDS_S)

/*! @brief Set the LVDS_S field to a new value. */
#define BW_IOMUXC_GPR_GPR20_LVDS_S(x, v) (HW_IOMUXC_GPR_GPR20_WR(x, (HW_IOMUXC_GPR_GPR20_RD(x) & ~BM_IOMUXC_GPR_GPR20_LVDS_S) | BF_IOMUXC_GPR_GPR20_LVDS_S(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR20, field LVDS_VSEL[24] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR20_LVDS_VSEL (24U) /*!< Bit position for IOMUXC_GPR_GPR20_LVDS_VSEL. */
#define BM_IOMUXC_GPR_GPR20_LVDS_VSEL (0x01000000U) /*!< Bit mask for IOMUXC_GPR_GPR20_LVDS_VSEL. */
#define BS_IOMUXC_GPR_GPR20_LVDS_VSEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR20_LVDS_VSEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR20_LVDS_VSEL field. */
#define BR_IOMUXC_GPR_GPR20_LVDS_VSEL(x) (HW_IOMUXC_GPR_GPR20(x).B.LVDS_VSEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR20_LVDS_VSEL. */
#define BF_IOMUXC_GPR_GPR20_LVDS_VSEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR20_LVDS_VSEL) & BM_IOMUXC_GPR_GPR20_LVDS_VSEL)

/*! @brief Set the LVDS_VSEL field to a new value. */
#define BW_IOMUXC_GPR_GPR20_LVDS_VSEL(x, v) (HW_IOMUXC_GPR_GPR20_WR(x, (HW_IOMUXC_GPR_GPR20_RD(x) & ~BM_IOMUXC_GPR_GPR20_LVDS_VSEL) | BF_IOMUXC_GPR_GPR20_LVDS_VSEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR20, field LVDS_CK_POL_SEL[25] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR20_LVDS_CK_POL_SEL (25U) /*!< Bit position for IOMUXC_GPR_GPR20_LVDS_CK_POL_SEL. */
#define BM_IOMUXC_GPR_GPR20_LVDS_CK_POL_SEL (0x02000000U) /*!< Bit mask for IOMUXC_GPR_GPR20_LVDS_CK_POL_SEL. */
#define BS_IOMUXC_GPR_GPR20_LVDS_CK_POL_SEL (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR20_LVDS_CK_POL_SEL. */

/*! @brief Read current value of the IOMUXC_GPR_GPR20_LVDS_CK_POL_SEL field. */
#define BR_IOMUXC_GPR_GPR20_LVDS_CK_POL_SEL(x) (HW_IOMUXC_GPR_GPR20(x).B.LVDS_CK_POL_SEL)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR20_LVDS_CK_POL_SEL. */
#define BF_IOMUXC_GPR_GPR20_LVDS_CK_POL_SEL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR20_LVDS_CK_POL_SEL) & BM_IOMUXC_GPR_GPR20_LVDS_CK_POL_SEL)

/*! @brief Set the LVDS_CK_POL_SEL field to a new value. */
#define BW_IOMUXC_GPR_GPR20_LVDS_CK_POL_SEL(x, v) (HW_IOMUXC_GPR_GPR20_WR(x, (HW_IOMUXC_GPR_GPR20_RD(x) & ~BM_IOMUXC_GPR_GPR20_LVDS_CK_POL_SEL) | BF_IOMUXC_GPR_GPR20_LVDS_CK_POL_SEL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR20, field LVDS_I_TX2801X_DUMMY[29:27] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY (27U) /*!< Bit position for IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY. */
#define BM_IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY (0x38000000U) /*!< Bit mask for IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY. */
#define BS_IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY (3U) /*!< Bit field size in bits for IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY. */

/*! @brief Read current value of the IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY field. */
#define BR_IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY(x) (HW_IOMUXC_GPR_GPR20(x).B.LVDS_I_TX2801X_DUMMY)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY. */
#define BF_IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY) & BM_IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY)

/*! @brief Set the LVDS_I_TX2801X_DUMMY field to a new value. */
#define BW_IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY(x, v) (HW_IOMUXC_GPR_GPR20_WR(x, (HW_IOMUXC_GPR_GPR20_RD(x) & ~BM_IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY) | BF_IOMUXC_GPR_GPR20_LVDS_I_TX2801X_DUMMY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR21 - GPR21 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR21 - GPR21 General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr21
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr21_bitfields
    {
        uint32_t LVDS_SKC0 : 3;        /*!< [2:0]  */
        uint32_t LVDS_SKC1 : 3;        /*!< [5:3]  */
        uint32_t LVDS_SKC2 : 3;        /*!< [8:6]  */
        uint32_t LVDS_SKCCK : 3;       /*!< [11:9]  */
        uint32_t LVDS_SKC3 : 3;        /*!< [14:12]  */
        uint32_t LVDS_SKC4 : 3;        /*!< [17:15]  */
        uint32_t SJC_BYPASS_CJTAGC : 1; /*!< [18]  */
        uint32_t DAP_BYPASS_CJTAGC : 1; /*!< [19]  */
        uint32_t RESERVED0 : 12;       /*!< [31:20]  */
    } B;
} hw_iomuxc_gpr_gpr21_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR21 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR21_ADDR(x) ((uintptr_t)(x) + 0x54U)

#define HW_IOMUXC_GPR_GPR21(x)   (*(__IO hw_iomuxc_gpr_gpr21_t *) HW_IOMUXC_GPR_GPR21_ADDR(x))
#define HW_IOMUXC_GPR_GPR21_RD(x) (HW_IOMUXC_GPR_GPR21(x).U)
#define HW_IOMUXC_GPR_GPR21_WR(x, v) (HW_IOMUXC_GPR_GPR21(x).U = (v))
#define HW_IOMUXC_GPR_GPR21_SET(x, v) (HW_IOMUXC_GPR_GPR21_WR(x, HW_IOMUXC_GPR_GPR21_RD(x) |  (v)))
#define HW_IOMUXC_GPR_GPR21_CLR(x, v) (HW_IOMUXC_GPR_GPR21_WR(x, HW_IOMUXC_GPR_GPR21_RD(x) & ~(v)))
#define HW_IOMUXC_GPR_GPR21_TOG(x, v) (HW_IOMUXC_GPR_GPR21_WR(x, HW_IOMUXC_GPR_GPR21_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR21 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR21, field LVDS_SKC0[2:0] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR21_LVDS_SKC0 (0U) /*!< Bit position for IOMUXC_GPR_GPR21_LVDS_SKC0. */
#define BM_IOMUXC_GPR_GPR21_LVDS_SKC0 (0x00000007U) /*!< Bit mask for IOMUXC_GPR_GPR21_LVDS_SKC0. */
#define BS_IOMUXC_GPR_GPR21_LVDS_SKC0 (3U) /*!< Bit field size in bits for IOMUXC_GPR_GPR21_LVDS_SKC0. */

/*! @brief Read current value of the IOMUXC_GPR_GPR21_LVDS_SKC0 field. */
#define BR_IOMUXC_GPR_GPR21_LVDS_SKC0(x) (HW_IOMUXC_GPR_GPR21(x).B.LVDS_SKC0)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR21_LVDS_SKC0. */
#define BF_IOMUXC_GPR_GPR21_LVDS_SKC0(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR21_LVDS_SKC0) & BM_IOMUXC_GPR_GPR21_LVDS_SKC0)

/*! @brief Set the LVDS_SKC0 field to a new value. */
#define BW_IOMUXC_GPR_GPR21_LVDS_SKC0(x, v) (HW_IOMUXC_GPR_GPR21_WR(x, (HW_IOMUXC_GPR_GPR21_RD(x) & ~BM_IOMUXC_GPR_GPR21_LVDS_SKC0) | BF_IOMUXC_GPR_GPR21_LVDS_SKC0(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR21, field LVDS_SKC1[5:3] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR21_LVDS_SKC1 (3U) /*!< Bit position for IOMUXC_GPR_GPR21_LVDS_SKC1. */
#define BM_IOMUXC_GPR_GPR21_LVDS_SKC1 (0x00000038U) /*!< Bit mask for IOMUXC_GPR_GPR21_LVDS_SKC1. */
#define BS_IOMUXC_GPR_GPR21_LVDS_SKC1 (3U) /*!< Bit field size in bits for IOMUXC_GPR_GPR21_LVDS_SKC1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR21_LVDS_SKC1 field. */
#define BR_IOMUXC_GPR_GPR21_LVDS_SKC1(x) (HW_IOMUXC_GPR_GPR21(x).B.LVDS_SKC1)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR21_LVDS_SKC1. */
#define BF_IOMUXC_GPR_GPR21_LVDS_SKC1(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR21_LVDS_SKC1) & BM_IOMUXC_GPR_GPR21_LVDS_SKC1)

/*! @brief Set the LVDS_SKC1 field to a new value. */
#define BW_IOMUXC_GPR_GPR21_LVDS_SKC1(x, v) (HW_IOMUXC_GPR_GPR21_WR(x, (HW_IOMUXC_GPR_GPR21_RD(x) & ~BM_IOMUXC_GPR_GPR21_LVDS_SKC1) | BF_IOMUXC_GPR_GPR21_LVDS_SKC1(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR21, field LVDS_SKC2[8:6] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR21_LVDS_SKC2 (6U) /*!< Bit position for IOMUXC_GPR_GPR21_LVDS_SKC2. */
#define BM_IOMUXC_GPR_GPR21_LVDS_SKC2 (0x000001C0U) /*!< Bit mask for IOMUXC_GPR_GPR21_LVDS_SKC2. */
#define BS_IOMUXC_GPR_GPR21_LVDS_SKC2 (3U) /*!< Bit field size in bits for IOMUXC_GPR_GPR21_LVDS_SKC2. */

/*! @brief Read current value of the IOMUXC_GPR_GPR21_LVDS_SKC2 field. */
#define BR_IOMUXC_GPR_GPR21_LVDS_SKC2(x) (HW_IOMUXC_GPR_GPR21(x).B.LVDS_SKC2)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR21_LVDS_SKC2. */
#define BF_IOMUXC_GPR_GPR21_LVDS_SKC2(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR21_LVDS_SKC2) & BM_IOMUXC_GPR_GPR21_LVDS_SKC2)

/*! @brief Set the LVDS_SKC2 field to a new value. */
#define BW_IOMUXC_GPR_GPR21_LVDS_SKC2(x, v) (HW_IOMUXC_GPR_GPR21_WR(x, (HW_IOMUXC_GPR_GPR21_RD(x) & ~BM_IOMUXC_GPR_GPR21_LVDS_SKC2) | BF_IOMUXC_GPR_GPR21_LVDS_SKC2(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR21, field LVDS_SKCCK[11:9] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR21_LVDS_SKCCK (9U) /*!< Bit position for IOMUXC_GPR_GPR21_LVDS_SKCCK. */
#define BM_IOMUXC_GPR_GPR21_LVDS_SKCCK (0x00000E00U) /*!< Bit mask for IOMUXC_GPR_GPR21_LVDS_SKCCK. */
#define BS_IOMUXC_GPR_GPR21_LVDS_SKCCK (3U) /*!< Bit field size in bits for IOMUXC_GPR_GPR21_LVDS_SKCCK. */

/*! @brief Read current value of the IOMUXC_GPR_GPR21_LVDS_SKCCK field. */
#define BR_IOMUXC_GPR_GPR21_LVDS_SKCCK(x) (HW_IOMUXC_GPR_GPR21(x).B.LVDS_SKCCK)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR21_LVDS_SKCCK. */
#define BF_IOMUXC_GPR_GPR21_LVDS_SKCCK(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR21_LVDS_SKCCK) & BM_IOMUXC_GPR_GPR21_LVDS_SKCCK)

/*! @brief Set the LVDS_SKCCK field to a new value. */
#define BW_IOMUXC_GPR_GPR21_LVDS_SKCCK(x, v) (HW_IOMUXC_GPR_GPR21_WR(x, (HW_IOMUXC_GPR_GPR21_RD(x) & ~BM_IOMUXC_GPR_GPR21_LVDS_SKCCK) | BF_IOMUXC_GPR_GPR21_LVDS_SKCCK(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR21, field LVDS_SKC3[14:12] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR21_LVDS_SKC3 (12U) /*!< Bit position for IOMUXC_GPR_GPR21_LVDS_SKC3. */
#define BM_IOMUXC_GPR_GPR21_LVDS_SKC3 (0x00007000U) /*!< Bit mask for IOMUXC_GPR_GPR21_LVDS_SKC3. */
#define BS_IOMUXC_GPR_GPR21_LVDS_SKC3 (3U) /*!< Bit field size in bits for IOMUXC_GPR_GPR21_LVDS_SKC3. */

/*! @brief Read current value of the IOMUXC_GPR_GPR21_LVDS_SKC3 field. */
#define BR_IOMUXC_GPR_GPR21_LVDS_SKC3(x) (HW_IOMUXC_GPR_GPR21(x).B.LVDS_SKC3)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR21_LVDS_SKC3. */
#define BF_IOMUXC_GPR_GPR21_LVDS_SKC3(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR21_LVDS_SKC3) & BM_IOMUXC_GPR_GPR21_LVDS_SKC3)

/*! @brief Set the LVDS_SKC3 field to a new value. */
#define BW_IOMUXC_GPR_GPR21_LVDS_SKC3(x, v) (HW_IOMUXC_GPR_GPR21_WR(x, (HW_IOMUXC_GPR_GPR21_RD(x) & ~BM_IOMUXC_GPR_GPR21_LVDS_SKC3) | BF_IOMUXC_GPR_GPR21_LVDS_SKC3(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR21, field LVDS_SKC4[17:15] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR21_LVDS_SKC4 (15U) /*!< Bit position for IOMUXC_GPR_GPR21_LVDS_SKC4. */
#define BM_IOMUXC_GPR_GPR21_LVDS_SKC4 (0x00038000U) /*!< Bit mask for IOMUXC_GPR_GPR21_LVDS_SKC4. */
#define BS_IOMUXC_GPR_GPR21_LVDS_SKC4 (3U) /*!< Bit field size in bits for IOMUXC_GPR_GPR21_LVDS_SKC4. */

/*! @brief Read current value of the IOMUXC_GPR_GPR21_LVDS_SKC4 field. */
#define BR_IOMUXC_GPR_GPR21_LVDS_SKC4(x) (HW_IOMUXC_GPR_GPR21(x).B.LVDS_SKC4)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR21_LVDS_SKC4. */
#define BF_IOMUXC_GPR_GPR21_LVDS_SKC4(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR21_LVDS_SKC4) & BM_IOMUXC_GPR_GPR21_LVDS_SKC4)

/*! @brief Set the LVDS_SKC4 field to a new value. */
#define BW_IOMUXC_GPR_GPR21_LVDS_SKC4(x, v) (HW_IOMUXC_GPR_GPR21_WR(x, (HW_IOMUXC_GPR_GPR21_RD(x) & ~BM_IOMUXC_GPR_GPR21_LVDS_SKC4) | BF_IOMUXC_GPR_GPR21_LVDS_SKC4(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR21, field SJC_BYPASS_CJTAGC[18] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR21_SJC_BYPASS_CJTAGC (18U) /*!< Bit position for IOMUXC_GPR_GPR21_SJC_BYPASS_CJTAGC. */
#define BM_IOMUXC_GPR_GPR21_SJC_BYPASS_CJTAGC (0x00040000U) /*!< Bit mask for IOMUXC_GPR_GPR21_SJC_BYPASS_CJTAGC. */
#define BS_IOMUXC_GPR_GPR21_SJC_BYPASS_CJTAGC (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR21_SJC_BYPASS_CJTAGC. */

/*! @brief Read current value of the IOMUXC_GPR_GPR21_SJC_BYPASS_CJTAGC field. */
#define BR_IOMUXC_GPR_GPR21_SJC_BYPASS_CJTAGC(x) (HW_IOMUXC_GPR_GPR21(x).B.SJC_BYPASS_CJTAGC)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR21_SJC_BYPASS_CJTAGC. */
#define BF_IOMUXC_GPR_GPR21_SJC_BYPASS_CJTAGC(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR21_SJC_BYPASS_CJTAGC) & BM_IOMUXC_GPR_GPR21_SJC_BYPASS_CJTAGC)

/*! @brief Set the SJC_BYPASS_CJTAGC field to a new value. */
#define BW_IOMUXC_GPR_GPR21_SJC_BYPASS_CJTAGC(x, v) (HW_IOMUXC_GPR_GPR21_WR(x, (HW_IOMUXC_GPR_GPR21_RD(x) & ~BM_IOMUXC_GPR_GPR21_SJC_BYPASS_CJTAGC) | BF_IOMUXC_GPR_GPR21_SJC_BYPASS_CJTAGC(v)))
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR21, field DAP_BYPASS_CJTAGC[19] (RW)
 *
 * Not Used
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR21_DAP_BYPASS_CJTAGC (19U) /*!< Bit position for IOMUXC_GPR_GPR21_DAP_BYPASS_CJTAGC. */
#define BM_IOMUXC_GPR_GPR21_DAP_BYPASS_CJTAGC (0x00080000U) /*!< Bit mask for IOMUXC_GPR_GPR21_DAP_BYPASS_CJTAGC. */
#define BS_IOMUXC_GPR_GPR21_DAP_BYPASS_CJTAGC (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR21_DAP_BYPASS_CJTAGC. */

/*! @brief Read current value of the IOMUXC_GPR_GPR21_DAP_BYPASS_CJTAGC field. */
#define BR_IOMUXC_GPR_GPR21_DAP_BYPASS_CJTAGC(x) (HW_IOMUXC_GPR_GPR21(x).B.DAP_BYPASS_CJTAGC)

/*! @brief Format value for bitfield IOMUXC_GPR_GPR21_DAP_BYPASS_CJTAGC. */
#define BF_IOMUXC_GPR_GPR21_DAP_BYPASS_CJTAGC(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_GPR_GPR21_DAP_BYPASS_CJTAGC) & BM_IOMUXC_GPR_GPR21_DAP_BYPASS_CJTAGC)

/*! @brief Set the DAP_BYPASS_CJTAGC field to a new value. */
#define BW_IOMUXC_GPR_GPR21_DAP_BYPASS_CJTAGC(x, v) (HW_IOMUXC_GPR_GPR21_WR(x, (HW_IOMUXC_GPR_GPR21_RD(x) & ~BM_IOMUXC_GPR_GPR21_DAP_BYPASS_CJTAGC) | BF_IOMUXC_GPR_GPR21_DAP_BYPASS_CJTAGC(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_GPR_GPR22 - GPR22 General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_GPR_GPR22 - GPR22 General Purpose Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * GPR Register
 */
typedef union _hw_iomuxc_gpr_gpr22
{
    uint32_t U;
    struct _hw_iomuxc_gpr_gpr22_bitfields
    {
        uint32_t RESERVED0 : 16;       /*!< [15:0]  */
        uint32_t DDRC_MRR_DATA : 8;    /*!< [23:16]  */
        uint32_t DDRC_MRR_VALID : 1;   /*!< [24]  */
        uint32_t DFI_INIT_COMPLETE : 1; /*!< [25]  */
        uint32_t CHD2_DVDD_STABLE : 1; /*!< [26]  */
        uint32_t CHD2_ISO_ENA_1 : 1;   /*!< [27]  */
        uint32_t CHD1_DVDD_STABLE : 1; /*!< [28]  */
        uint32_t CHD1_ISO_ENA_1 : 1;   /*!< [29]  */
        uint32_t RESERVED1 : 1;        /*!< [30]  */
        uint32_t PCIE_PHY_PLL_LOCKED : 1; /*!< [31]  */
    } B;
} hw_iomuxc_gpr_gpr22_t;

/*!
 * @name Constants and macros for entire IOMUXC_GPR_GPR22 register
 */
/*@{*/
#define HW_IOMUXC_GPR_GPR22_ADDR(x) ((uintptr_t)(x) + 0x58U)

#define HW_IOMUXC_GPR_GPR22(x)   (*(__I hw_iomuxc_gpr_gpr22_t *) HW_IOMUXC_GPR_GPR22_ADDR(x))
#define HW_IOMUXC_GPR_GPR22_RD(x) (HW_IOMUXC_GPR_GPR22(x).U)
/*@}*/

/*
 * Constants & macros for individual IOMUXC_GPR_GPR22 bitfields
 */

/*!
 * @name Register IOMUXC_GPR_GPR22, field DDRC_MRR_DATA[23:16] (RO)
 *
 * DDR Controller Mode Register Read Data
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR22_DDRC_MRR_DATA (16U) /*!< Bit position for IOMUXC_GPR_GPR22_DDRC_MRR_DATA. */
#define BM_IOMUXC_GPR_GPR22_DDRC_MRR_DATA (0x00FF0000U) /*!< Bit mask for IOMUXC_GPR_GPR22_DDRC_MRR_DATA. */
#define BS_IOMUXC_GPR_GPR22_DDRC_MRR_DATA (8U) /*!< Bit field size in bits for IOMUXC_GPR_GPR22_DDRC_MRR_DATA. */

/*! @brief Read current value of the IOMUXC_GPR_GPR22_DDRC_MRR_DATA field. */
#define BR_IOMUXC_GPR_GPR22_DDRC_MRR_DATA(x) (HW_IOMUXC_GPR_GPR22(x).B.DDRC_MRR_DATA)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR22, field DDRC_MRR_VALID[24] (RO)
 *
 * DDR Controller Mode Register Read Data Valid
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR22_DDRC_MRR_VALID (24U) /*!< Bit position for IOMUXC_GPR_GPR22_DDRC_MRR_VALID. */
#define BM_IOMUXC_GPR_GPR22_DDRC_MRR_VALID (0x01000000U) /*!< Bit mask for IOMUXC_GPR_GPR22_DDRC_MRR_VALID. */
#define BS_IOMUXC_GPR_GPR22_DDRC_MRR_VALID (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR22_DDRC_MRR_VALID. */

/*! @brief Read current value of the IOMUXC_GPR_GPR22_DDRC_MRR_VALID field. */
#define BR_IOMUXC_GPR_GPR22_DDRC_MRR_VALID(x) (HW_IOMUXC_GPR_GPR22(x).B.DDRC_MRR_VALID)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR22, field DFI_INIT_COMPLETE[25] (RO)
 *
 * DDR PHY initialization complete. This signal indicates that the PHY is able
 * to respond to any proper stimulus on the DFI.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR22_DFI_INIT_COMPLETE (25U) /*!< Bit position for IOMUXC_GPR_GPR22_DFI_INIT_COMPLETE. */
#define BM_IOMUXC_GPR_GPR22_DFI_INIT_COMPLETE (0x02000000U) /*!< Bit mask for IOMUXC_GPR_GPR22_DFI_INIT_COMPLETE. */
#define BS_IOMUXC_GPR_GPR22_DFI_INIT_COMPLETE (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR22_DFI_INIT_COMPLETE. */

/*! @brief Read current value of the IOMUXC_GPR_GPR22_DFI_INIT_COMPLETE field. */
#define BR_IOMUXC_GPR_GPR22_DFI_INIT_COMPLETE(x) (HW_IOMUXC_GPR_GPR22(x).B.DFI_INIT_COMPLETE)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR22, field CHD2_DVDD_STABLE[26] (RO)
 *
 * USB OTG2 Auxiliary Charge Detector power stable signal for LDO_USB_1P0 to
 * allow vdd_soc domain to monitor when dvdd_usb domain is valid. This signal is in
 * the vdd_soc domain.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR22_CHD2_DVDD_STABLE (26U) /*!< Bit position for IOMUXC_GPR_GPR22_CHD2_DVDD_STABLE. */
#define BM_IOMUXC_GPR_GPR22_CHD2_DVDD_STABLE (0x04000000U) /*!< Bit mask for IOMUXC_GPR_GPR22_CHD2_DVDD_STABLE. */
#define BS_IOMUXC_GPR_GPR22_CHD2_DVDD_STABLE (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR22_CHD2_DVDD_STABLE. */

/*! @brief Read current value of the IOMUXC_GPR_GPR22_CHD2_DVDD_STABLE field. */
#define BR_IOMUXC_GPR_GPR22_CHD2_DVDD_STABLE(x) (HW_IOMUXC_GPR_GPR22(x).B.CHD2_DVDD_STABLE)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR22, field CHD2_ISO_ENA_1[27] (RO)
 *
 * USB OTG2 Auxiliary Charge Detector isolation control signal, high when
 * dvdd_usb domain is unpowered and vdd_soc domain is powered. This signal is in the
 * vdd_soc domain.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR22_CHD2_ISO_ENA_1 (27U) /*!< Bit position for IOMUXC_GPR_GPR22_CHD2_ISO_ENA_1. */
#define BM_IOMUXC_GPR_GPR22_CHD2_ISO_ENA_1 (0x08000000U) /*!< Bit mask for IOMUXC_GPR_GPR22_CHD2_ISO_ENA_1. */
#define BS_IOMUXC_GPR_GPR22_CHD2_ISO_ENA_1 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR22_CHD2_ISO_ENA_1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR22_CHD2_ISO_ENA_1 field. */
#define BR_IOMUXC_GPR_GPR22_CHD2_ISO_ENA_1(x) (HW_IOMUXC_GPR_GPR22(x).B.CHD2_ISO_ENA_1)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR22, field CHD1_DVDD_STABLE[28] (RO)
 *
 * USB OTG1 Auxiliary Charge Detector power stable signal for LDO_USB_1P0 to
 * allow vdd_soc domain to monitor when dvdd_usb domain is valid. This signal is in
 * the vdd_soc domain.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR22_CHD1_DVDD_STABLE (28U) /*!< Bit position for IOMUXC_GPR_GPR22_CHD1_DVDD_STABLE. */
#define BM_IOMUXC_GPR_GPR22_CHD1_DVDD_STABLE (0x10000000U) /*!< Bit mask for IOMUXC_GPR_GPR22_CHD1_DVDD_STABLE. */
#define BS_IOMUXC_GPR_GPR22_CHD1_DVDD_STABLE (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR22_CHD1_DVDD_STABLE. */

/*! @brief Read current value of the IOMUXC_GPR_GPR22_CHD1_DVDD_STABLE field. */
#define BR_IOMUXC_GPR_GPR22_CHD1_DVDD_STABLE(x) (HW_IOMUXC_GPR_GPR22(x).B.CHD1_DVDD_STABLE)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR22, field CHD1_ISO_ENA_1[29] (RO)
 *
 * USB OTG1 Auxiliary Charge Detector isolation control signal, high when
 * dvdd_usb domain is unpowered and vdd_soc domain is powered. This signal is in the
 * vdd_soc domain.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR22_CHD1_ISO_ENA_1 (29U) /*!< Bit position for IOMUXC_GPR_GPR22_CHD1_ISO_ENA_1. */
#define BM_IOMUXC_GPR_GPR22_CHD1_ISO_ENA_1 (0x20000000U) /*!< Bit mask for IOMUXC_GPR_GPR22_CHD1_ISO_ENA_1. */
#define BS_IOMUXC_GPR_GPR22_CHD1_ISO_ENA_1 (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR22_CHD1_ISO_ENA_1. */

/*! @brief Read current value of the IOMUXC_GPR_GPR22_CHD1_ISO_ENA_1 field. */
#define BR_IOMUXC_GPR_GPR22_CHD1_ISO_ENA_1(x) (HW_IOMUXC_GPR_GPR22(x).B.CHD1_ISO_ENA_1)
/*@}*/

/*!
 * @name Register IOMUXC_GPR_GPR22, field PCIE_PHY_PLL_LOCKED[31] (RO)
 *
 * PLL Lock Indication. When PLL locking is done, PLL_LOCKED goes to high.
 */
/*@{*/
#define BP_IOMUXC_GPR_GPR22_PCIE_PHY_PLL_LOCKED (31U) /*!< Bit position for IOMUXC_GPR_GPR22_PCIE_PHY_PLL_LOCKED. */
#define BM_IOMUXC_GPR_GPR22_PCIE_PHY_PLL_LOCKED (0x80000000U) /*!< Bit mask for IOMUXC_GPR_GPR22_PCIE_PHY_PLL_LOCKED. */
#define BS_IOMUXC_GPR_GPR22_PCIE_PHY_PLL_LOCKED (1U) /*!< Bit field size in bits for IOMUXC_GPR_GPR22_PCIE_PHY_PLL_LOCKED. */

/*! @brief Read current value of the IOMUXC_GPR_GPR22_PCIE_PHY_PLL_LOCKED field. */
#define BR_IOMUXC_GPR_GPR22_PCIE_PHY_PLL_LOCKED(x) (HW_IOMUXC_GPR_GPR22(x).B.PCIE_PHY_PLL_LOCKED)
/*@}*/

/*******************************************************************************
 * hw_iomuxc_gpr_t - module struct
 ******************************************************************************/
/*!
 * @brief All IOMUXC_GPR module registers.
 */
#pragma pack(1)
typedef struct _hw_iomuxc_gpr
{
    __IO hw_iomuxc_gpr_gpr0_t GPR0;        /*!< [0x0] GPR0 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr1_t GPR1;        /*!< [0x4] GPR1 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr2_t GPR2;        /*!< [0x8] GPR2 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr3_t GPR3;        /*!< [0xC] GPR3 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr4_t GPR4;        /*!< [0x10] GPR4 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr5_t GPR5;        /*!< [0x14] GPR5 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr6_t GPR6;        /*!< [0x18] GPR6 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr7_t GPR7;        /*!< [0x1C] GPR7 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr8_t GPR8;        /*!< [0x20] GPR8 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr9_t GPR9;        /*!< [0x24] GPR9 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr10_t GPR10;      /*!< [0x28] GPR10 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr11_t GPR11;      /*!< [0x2C] GPR11 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr12_t GPR12;      /*!< [0x30] GPR12 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr13_t GPR13;      /*!< [0x34] GPR13 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr14_t GPR14;      /*!< [0x38] GPR14 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr15_t GPR15;      /*!< [0x3C] GPR15 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr16_t GPR16;      /*!< [0x40] GPR16 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr17_t GPR17;      /*!< [0x44] GPR17 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr18_t GPR18;      /*!< [0x48] GPR18 General Purpose Register */
    __I hw_iomuxc_gpr_gpr19_t GPR19;       /*!< [0x4C] GPR19 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr20_t GPR20;      /*!< [0x50] GPR20 General Purpose Register */
    __IO hw_iomuxc_gpr_gpr21_t GPR21;      /*!< [0x54] GPR21 General Purpose Register */
    __I hw_iomuxc_gpr_gpr22_t GPR22;       /*!< [0x58] GPR22 General Purpose Register */
} hw_iomuxc_gpr_t;
#pragma pack()

/*! @brief Macro to access all IOMUXC_GPR registers. */
/*! @param x IOMUXC_GPR module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_IOMUXC_GPR_REGS(IOMUXC_GPR_BASE)</code>. */
#define HW_IOMUXC_GPR_REGS(x) (*(hw_iomuxc_gpr_t *)(x))

/*
 * iMX7D IOMUXC_LPSR
 *
 * IOMUXC_LPSR
 *
 * Registers defined in this header file:
 * - HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00 - SW_MUX_CTL_PAD_GPIO1_IO00 SW MUX Control Register
 * - HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01 - SW_MUX_CTL_PAD_GPIO1_IO01 SW MUX Control Register
 * - HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02 - SW_MUX_CTL_PAD_GPIO1_IO02 SW MUX Control Register
 * - HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03 - SW_MUX_CTL_PAD_GPIO1_IO03 SW MUX Control Register
 * - HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04 - SW_MUX_CTL_PAD_GPIO1_IO04 SW MUX Control Register
 * - HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05 - SW_MUX_CTL_PAD_GPIO1_IO05 SW MUX Control Register
 * - HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06 - SW_MUX_CTL_PAD_GPIO1_IO06 SW MUX Control Register
 * - HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07 - SW_MUX_CTL_PAD_GPIO1_IO07 SW MUX Control Register
 * - HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE - SW_PAD_CTL_PAD_TEST_MODE SW PAD Control Register
 * - HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B - SW_PAD_CTL_PAD_SRC_POR_B SW PAD Control Register
 * - HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0 - SW_PAD_CTL_PAD_BOOT_MODE0 SW PAD Control Register
 * - HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1 - SW_PAD_CTL_PAD_BOOT_MODE1 SW PAD Control Register
 * - HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00 - SW_PAD_CTL_PAD_GPIO1_IO00 SW PAD Control Register
 * - HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01 - SW_PAD_CTL_PAD_GPIO1_IO01 SW PAD Control Register
 * - HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02 - SW_PAD_CTL_PAD_GPIO1_IO02 SW PAD Control Register
 * - HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03 - SW_PAD_CTL_PAD_GPIO1_IO03 SW PAD Control Register
 * - HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04 - SW_PAD_CTL_PAD_GPIO1_IO04 SW PAD Control Register
 * - HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05 - SW_PAD_CTL_PAD_GPIO1_IO05 SW PAD Control Register
 * - HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06 - SW_PAD_CTL_PAD_GPIO1_IO06 SW PAD Control Register
 * - HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07 - SW_PAD_CTL_PAD_GPIO1_IO07 SW PAD Control Register
 *
 * - hw_iomuxc_lpsr_t - Struct containing all module registers.
 */

#define HW_IOMUXC_LPSR_INSTANCE_COUNT (1U) /*!< Number of instances of the IOMUXC_LPSR module. */
#define HW_IOMUXC_LPSR (0U) /*!< Instance number for IOMUXC_LPSR. */
#define IOMUXC_LPSR_BASE      (0x302C0000U) /*!< Base address for IOMUXC_LPSR. */
/*! Array initializer of IOMUXC_LPSR base addresses. */
#define IOMUXC_LPSR_BASE_ADDRS { IOMUXC_LPSR_BASE }

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00 - SW_MUX_CTL_PAD_GPIO1_IO00 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00 - SW_MUX_CTL_PAD_GPIO1_IO00 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io00
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io00_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io00_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_ADDR(x) ((uintptr_t)(x) + 0x0U)

#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00(x) (*(__IO hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io00_t *) HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_ADDR(x))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_RD(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00(x).U)
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_WR(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00(x).U = (v))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SET(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_CLR(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_TOG(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 5 iomux modes to be used for pad: GPIO1_IO00.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: IO0 of instance: GPIO1
 * - 001 - Select mux mode: ALT1 mux port: OUT of instance: PWM4
 * - 010 - Select mux mode: ALT2 mux port: WDOG_ANY of instance: WDOG1
 * - 011 - Select mux mode: ALT3 mux port: WDOG_B of instance: WDOG1
 * - 100 - Select mux mode: ALT4 mux port: WDOG_RST_B_DEB of instance: WDOG1
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE (0U) /*!< Bit position for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE. */
#define BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE. */
#define BS_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE. */

#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE_ALT0_GPIO1_IO0 (0U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE: Select mux mode: ALT0 mux port: IO0 of instance: GPIO1 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE_ALT1_PWM4_OUT (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE: Select mux mode: ALT1 mux port: OUT of instance: PWM4 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE_ALT2_WDOG1_WDOG_ANY (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE: Select mux mode: ALT2 mux port: WDOG_ANY of instance: WDOG1 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE_ALT3_WDOG1_WDOG_B (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE: Select mux mode: ALT3 mux port: WDOG_B of instance: WDOG1 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE_ALT4_WDOG1_WDOG_RST_B_DEB (0x4U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE: Select mux mode: ALT4 mux port: WDOG_RST_B_DEB of instance: WDOG1 */

/*! @brief Read current value of the IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE field. */
#define BR_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE. */
#define BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE) & BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_WR(x, (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_RD(x) & ~BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE) | BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO00
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SION (4U) /*!< Bit position for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SION. */
#define BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SION (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SION. */
#define BS_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SION (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SION. */

#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SION: Force input path of pad GPIO1_IO00 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SION field. */
#define BR_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SION(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SION. */
#define BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SION) & BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SION(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_WR(x, (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_RD(x) & ~BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SION) | BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO00_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01 - SW_MUX_CTL_PAD_GPIO1_IO01 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01 - SW_MUX_CTL_PAD_GPIO1_IO01 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io01
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io01_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io01_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_ADDR(x) ((uintptr_t)(x) + 0x4U)

#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01(x) (*(__IO hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io01_t *) HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_ADDR(x))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_RD(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01(x).U)
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_WR(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01(x).U = (v))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SET(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_CLR(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_TOG(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: GPIO1_IO01.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: IO1 of instance: GPIO1
 * - 001 - Select mux mode: ALT1 mux port: OUT of instance: PWM1
 * - 010 - Select mux mode: ALT2 mux port: ENET_REF_CLK3 of instance: CCM
 * - 011 - Select mux mode: ALT3 mux port: MCLK of instance: SAI1
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE (0U) /*!< Bit position for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE. */
#define BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE. */
#define BS_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE. */

#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE_ALT0_GPIO1_IO1 (0U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE: Select mux mode: ALT0 mux port: IO1 of instance: GPIO1 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE_ALT1_PWM1_OUT (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE: Select mux mode: ALT1 mux port: OUT of instance: PWM1 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE_ALT2_CCM_ENET_REF_CLK3 (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE: Select mux mode: ALT2 mux port: ENET_REF_CLK3 of instance: CCM */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE_ALT3_SAI1_MCLK (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE: Select mux mode: ALT3 mux port: MCLK of instance: SAI1 */

/*! @brief Read current value of the IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE field. */
#define BR_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE. */
#define BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE) & BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_WR(x, (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_RD(x) & ~BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE) | BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO01
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SION (4U) /*!< Bit position for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SION. */
#define BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SION (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SION. */
#define BS_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SION (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SION. */

#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SION: Force input path of pad GPIO1_IO01 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SION field. */
#define BR_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SION(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SION. */
#define BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SION) & BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SION(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_WR(x, (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_RD(x) & ~BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SION) | BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO01_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02 - SW_MUX_CTL_PAD_GPIO1_IO02 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02 - SW_MUX_CTL_PAD_GPIO1_IO02 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io02
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io02_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io02_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_ADDR(x) ((uintptr_t)(x) + 0x8U)

#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02(x) (*(__IO hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io02_t *) HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_ADDR(x))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_RD(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02(x).U)
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_WR(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02(x).U = (v))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SET(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_CLR(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_TOG(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: GPIO1_IO02.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: IO2 of instance: GPIO1
 * - 001 - Select mux mode: ALT1 mux port: OUT of instance: PWM2
 * - 010 - Select mux mode: ALT2 mux port: ENET_REF_CLK1 of instance: CCM
 * - 011 - Select mux mode: ALT3 mux port: MCLK of instance: SAI2
 * - 101 - Select mux mode: ALT5 mux port: CLKO1 of instance: CCM
 * - 111 - Select mux mode: ALT7 mux port: OTG1_ID of instance: USB
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE (0U) /*!< Bit position for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE. */
#define BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE. */
#define BS_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE. */

#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE_ALT0_GPIO1_IO2 (0U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE: Select mux mode: ALT0 mux port: IO2 of instance: GPIO1 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE_ALT1_PWM2_OUT (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE: Select mux mode: ALT1 mux port: OUT of instance: PWM2 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE_ALT2_CCM_ENET_REF_CLK1 (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE: Select mux mode: ALT2 mux port: ENET_REF_CLK1 of instance: CCM */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE_ALT3_SAI2_MCLK (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE: Select mux mode: ALT3 mux port: MCLK of instance: SAI2 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE_ALT5_CCM_CLKO1 (0x5U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE: Select mux mode: ALT5 mux port: CLKO1 of instance: CCM */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE_ALT7_USB_OTG1_ID (0x7U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE: Select mux mode: ALT7 mux port: OTG1_ID of instance: USB */

/*! @brief Read current value of the IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE field. */
#define BR_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE. */
#define BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE) & BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_WR(x, (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_RD(x) & ~BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE) | BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO02
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SION (4U) /*!< Bit position for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SION. */
#define BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SION (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SION. */
#define BS_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SION (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SION. */

#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SION: Force input path of pad GPIO1_IO02 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SION field. */
#define BR_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SION(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SION. */
#define BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SION) & BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SION(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_WR(x, (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_RD(x) & ~BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SION) | BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO02_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03 - SW_MUX_CTL_PAD_GPIO1_IO03 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03 - SW_MUX_CTL_PAD_GPIO1_IO03 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io03
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io03_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io03_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03(x) (*(__IO hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io03_t *) HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_ADDR(x))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_RD(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03(x).U)
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_WR(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03(x).U = (v))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SET(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_CLR(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_TOG(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: GPIO1_IO03.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: IO3 of instance: GPIO1
 * - 001 - Select mux mode: ALT1 mux port: OUT of instance: PWM3
 * - 010 - Select mux mode: ALT2 mux port: ENET_REF_CLK2 of instance: CCM
 * - 011 - Select mux mode: ALT3 mux port: MCLK of instance: SAI3
 * - 101 - Select mux mode: ALT5 mux port: CLKO2 of instance: CCM
 * - 111 - Select mux mode: ALT7 mux port: OTG2_ID of instance: USB
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE (0U) /*!< Bit position for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE. */
#define BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE. */
#define BS_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE. */

#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE_ALT0_GPIO1_IO3 (0U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE: Select mux mode: ALT0 mux port: IO3 of instance: GPIO1 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE_ALT1_PWM3_OUT (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE: Select mux mode: ALT1 mux port: OUT of instance: PWM3 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE_ALT2_CCM_ENET_REF_CLK2 (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE: Select mux mode: ALT2 mux port: ENET_REF_CLK2 of instance: CCM */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE_ALT3_SAI3_MCLK (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE: Select mux mode: ALT3 mux port: MCLK of instance: SAI3 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE_ALT5_CCM_CLKO2 (0x5U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE: Select mux mode: ALT5 mux port: CLKO2 of instance: CCM */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE_ALT7_USB_OTG2_ID (0x7U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE: Select mux mode: ALT7 mux port: OTG2_ID of instance: USB */

/*! @brief Read current value of the IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE field. */
#define BR_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE. */
#define BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE) & BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_WR(x, (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_RD(x) & ~BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE) | BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO03
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SION (4U) /*!< Bit position for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SION. */
#define BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SION (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SION. */
#define BS_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SION (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SION. */

#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SION: Force input path of pad GPIO1_IO03 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SION field. */
#define BR_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SION(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SION. */
#define BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SION) & BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SION(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_WR(x, (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_RD(x) & ~BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SION) | BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO03_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04 - SW_MUX_CTL_PAD_GPIO1_IO04 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04 - SW_MUX_CTL_PAD_GPIO1_IO04 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io04
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io04_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io04_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_ADDR(x) ((uintptr_t)(x) + 0x10U)

#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04(x) (*(__IO hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io04_t *) HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_ADDR(x))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_RD(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04(x).U)
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_WR(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04(x).U = (v))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SET(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_CLR(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_TOG(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: GPIO1_IO04.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: IO4 of instance: GPIO1
 * - 001 - Select mux mode: ALT1 mux port: OTG1_OC of instance: USB
 * - 010 - Select mux mode: ALT2 mux port: CH4 of instance: FLEXTIMER1
 * - 011 - Select mux mode: ALT3 mux port: CTS_B of instance: UART5
 * - 100 - Select mux mode: ALT4 mux port: SCL of instance: I2C1
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE (0U) /*!< Bit position for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE. */
#define BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE. */
#define BS_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE. */

#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE_ALT0_GPIO1_IO4 (0U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE: Select mux mode: ALT0 mux port: IO4 of instance: GPIO1 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE_ALT1_USB_OTG1_OC (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE: Select mux mode: ALT1 mux port: OTG1_OC of instance: USB */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE_ALT2_FLEXTIMER1_CH4 (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE: Select mux mode: ALT2 mux port: CH4 of instance: FLEXTIMER1 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE_ALT3_UART5_CTS_B (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE: Select mux mode: ALT3 mux port: CTS_B of instance: UART5 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE_ALT4_I2C1_SCL (0x4U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE: Select mux mode: ALT4 mux port: SCL of instance: I2C1 */

/*! @brief Read current value of the IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE field. */
#define BR_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE. */
#define BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE) & BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_WR(x, (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_RD(x) & ~BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE) | BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO04
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SION (4U) /*!< Bit position for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SION. */
#define BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SION (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SION. */
#define BS_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SION (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SION. */

#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SION: Force input path of pad GPIO1_IO04 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SION field. */
#define BR_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SION(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SION. */
#define BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SION) & BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SION(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_WR(x, (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_RD(x) & ~BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SION) | BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO04_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05 - SW_MUX_CTL_PAD_GPIO1_IO05 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05 - SW_MUX_CTL_PAD_GPIO1_IO05 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io05
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io05_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io05_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05(x) (*(__IO hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io05_t *) HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_ADDR(x))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_RD(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05(x).U)
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_WR(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05(x).U = (v))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SET(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_CLR(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_TOG(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 7 iomux modes to be used for pad: GPIO1_IO05.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: IO5 of instance: GPIO1
 * - 001 - Select mux mode: ALT1 mux port: OTG1_PWR of instance: USB
 * - 010 - Select mux mode: ALT2 mux port: CH5 of instance: FLEXTIMER1
 * - 011 - Select mux mode: ALT3 mux port: RTS_B of instance: UART5
 * - 100 - Select mux mode: ALT4 mux port: SDA of instance: I2C1
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE (0U) /*!< Bit position for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE. */
#define BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE. */
#define BS_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE. */

#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE_ALT0_GPIO1_IO5 (0U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE: Select mux mode: ALT0 mux port: IO5 of instance: GPIO1 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE_ALT1_USB_OTG1_PWR (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE: Select mux mode: ALT1 mux port: OTG1_PWR of instance: USB */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE_ALT2_FLEXTIMER1_CH5 (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE: Select mux mode: ALT2 mux port: CH5 of instance: FLEXTIMER1 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE_ALT3_UART5_RTS_B (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE: Select mux mode: ALT3 mux port: RTS_B of instance: UART5 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE_ALT4_I2C1_SDA (0x4U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE: Select mux mode: ALT4 mux port: SDA of instance: I2C1 */

/*! @brief Read current value of the IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE field. */
#define BR_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE. */
#define BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE) & BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_WR(x, (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_RD(x) & ~BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE) | BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO05
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SION (4U) /*!< Bit position for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SION. */
#define BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SION (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SION. */
#define BS_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SION (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SION. */

#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SION: Force input path of pad GPIO1_IO05 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SION field. */
#define BR_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SION(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SION. */
#define BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SION) & BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SION(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_WR(x, (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_RD(x) & ~BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SION) | BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO05_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06 - SW_MUX_CTL_PAD_GPIO1_IO06 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06 - SW_MUX_CTL_PAD_GPIO1_IO06 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io06
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io06_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io06_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_ADDR(x) ((uintptr_t)(x) + 0x18U)

#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06(x) (*(__IO hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io06_t *) HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_ADDR(x))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_RD(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06(x).U)
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_WR(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06(x).U = (v))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SET(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_CLR(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_TOG(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: GPIO1_IO06.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: IO6 of instance: GPIO1
 * - 001 - Select mux mode: ALT1 mux port: OTG2_OC of instance: USB
 * - 010 - Select mux mode: ALT2 mux port: CH6 of instance: FLEXTIMER1
 * - 011 - Select mux mode: ALT3 mux port: RX_DATA of instance: UART5
 * - 100 - Select mux mode: ALT4 mux port: SCL of instance: I2C2
 * - 101 - Select mux mode: ALT5 mux port: WAIT of instance: CCM
 * - 110 - Select mux mode: ALT6 mux port: ROW4 of instance: KPP
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE (0U) /*!< Bit position for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE. */
#define BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE. */
#define BS_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE. */

#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE_ALT0_GPIO1_IO6 (0U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE: Select mux mode: ALT0 mux port: IO6 of instance: GPIO1 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE_ALT1_USB_OTG2_OC (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE: Select mux mode: ALT1 mux port: OTG2_OC of instance: USB */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE_ALT2_FLEXTIMER1_CH6 (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE: Select mux mode: ALT2 mux port: CH6 of instance: FLEXTIMER1 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE_ALT3_UART5_RX_DATA (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE: Select mux mode: ALT3 mux port: RX_DATA of instance: UART5 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE_ALT4_I2C2_SCL (0x4U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE: Select mux mode: ALT4 mux port: SCL of instance: I2C2 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE_ALT5_CCM_WAIT (0x5U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE: Select mux mode: ALT5 mux port: WAIT of instance: CCM */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE_ALT6_KPP_ROW4 (0x6U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE: Select mux mode: ALT6 mux port: ROW4 of instance: KPP */

/*! @brief Read current value of the IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE field. */
#define BR_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE. */
#define BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE) & BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_WR(x, (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_RD(x) & ~BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE) | BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO06
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION (4U) /*!< Bit position for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION. */
#define BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION. */
#define BS_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION. */

#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION: Force input path of pad GPIO1_IO06 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION field. */
#define BR_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION. */
#define BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION) & BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_WR(x, (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_RD(x) & ~BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION) | BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO06_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07 - SW_MUX_CTL_PAD_GPIO1_IO07 SW MUX Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07 - SW_MUX_CTL_PAD_GPIO1_IO07 SW MUX Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * SW_MUX_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io07
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io07_bitfields
    {
        uint32_t MUX_MODE : 3;         /*!< [2:0] MUX Mode Select Field. */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t SION : 1;             /*!< [4] Software Input On Field. */
        uint32_t RESERVED1 : 27;       /*!< [31:5]  */
    } B;
} hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io07_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07(x) (*(__IO hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io07_t *) HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_ADDR(x))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_RD(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07(x).U)
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_WR(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07(x).U = (v))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SET(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_CLR(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_TOG(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_WR(x, HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07, field MUX_MODE[2:0] (RW)
 *
 * Select 1 of 8 iomux modes to be used for pad: GPIO1_IO07.
 *
 * Values:
 * - 000 - Select mux mode: ALT0 mux port: IO7 of instance: GPIO1
 * - 001 - Select mux mode: ALT1 mux port: OTG2_PWR of instance: USB
 * - 010 - Select mux mode: ALT2 mux port: CH7 of instance: FLEXTIMER1
 * - 011 - Select mux mode: ALT3 mux port: TX_DATA of instance: UART5
 * - 100 - Select mux mode: ALT4 mux port: SDA of instance: I2C2
 * - 101 - Select mux mode: ALT5 mux port: STOP of instance: CCM
 * - 110 - Select mux mode: ALT6 mux port: COL4 of instance: KPP
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE (0U) /*!< Bit position for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE. */
#define BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE (0x00000007U) /*!< Bit mask for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE. */
#define BS_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE (3U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE. */

#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE_ALT0_GPIO1_IO7 (0U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE: Select mux mode: ALT0 mux port: IO7 of instance: GPIO1 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE_ALT1_USB_OTG2_PWR (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE: Select mux mode: ALT1 mux port: OTG2_PWR of instance: USB */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE_ALT2_FLEXTIMER1_CH7 (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE: Select mux mode: ALT2 mux port: CH7 of instance: FLEXTIMER1 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE_ALT3_UART5_TX_DATA (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE: Select mux mode: ALT3 mux port: TX_DATA of instance: UART5 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE_ALT4_I2C2_SDA (0x4U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE: Select mux mode: ALT4 mux port: SDA of instance: I2C2 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE_ALT5_CCM_STOP (0x5U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE: Select mux mode: ALT5 mux port: STOP of instance: CCM */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE_ALT6_KPP_COL4 (0x6U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE: Select mux mode: ALT6 mux port: COL4 of instance: KPP */

/*! @brief Read current value of the IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE field. */
#define BR_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07(x).B.MUX_MODE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE. */
#define BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE) & BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE)

/*! @brief Set the MUX_MODE field to a new value. */
#define BW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_WR(x, (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_RD(x) & ~BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE) | BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_MUX_MODE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07, field SION[4] (RW)
 *
 * Force the selected mux mode Input path no matter of MUX_MODE functionality.
 *
 * Values:
 * - 1 - Force input path of pad GPIO1_IO07
 * - 0 - Input Path is determined by functionality
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION (4U) /*!< Bit position for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION. */
#define BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION. */
#define BS_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION. */

#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION_ENABLED (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION: Force input path of pad GPIO1_IO07 */
#define BV_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION_DISABLED (0U) /*!< Bit field value for IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION: Input Path is determined by functionality */

/*! @brief Read current value of the IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION field. */
#define BR_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION(x) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07(x).B.SION)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION. */
#define BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION) & BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION)

/*! @brief Set the SION field to a new value. */
#define BW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION(x, v) (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_WR(x, (HW_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_RD(x) & ~BM_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION) | BF_IOMUXC_LPSR_SW_MUX_CTL_PAD_GPIO1_IO07_SION(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE - SW_PAD_CTL_PAD_TEST_MODE SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE - SW_PAD_CTL_PAD_TEST_MODE SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_pad_ctl_pad_test_mode
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_pad_ctl_pad_test_mode_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_lpsr_sw_pad_ctl_pad_test_mode_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE(x) (*(__IO hw_iomuxc_lpsr_sw_pad_ctl_pad_test_mode_t *) HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_ADDR(x))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_RD(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE(x).U)
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_WR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE(x).U = (v))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_SET(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_CLR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_TOG(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE, field DSE[1:0] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 00 - X1
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_DSE (0U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_DSE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_DSE (0x00000003U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_DSE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_DSE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_DSE_DSE (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_DSE: X1 */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_DSE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_DSE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE, field SRE[2] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_SRE (2U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_SRE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_SRE (0x00000004U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_SRE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_SRE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_SRE_SRE (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_SRE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_SRE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE(x).B.SRE)
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE, field HYS[3] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 0 - Hysteresis Disabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_HYS (3U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_HYS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_HYS (0x00000008U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_HYS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_HYS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_HYS_HYS (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_HYS: Hysteresis Disabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_HYS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_HYS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE(x).B.HYS)
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE, field PE[4] (RW)
 *
 * Select one out of next values for pad: TEST_MODE
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PE (4U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PE (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PE: Pull Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: TEST_MODE
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS (5U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS (0x00000060U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS: 100K PD */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS: 5K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS: 47K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_TEST_MODE_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B - SW_PAD_CTL_PAD_SRC_POR_B SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B - SW_PAD_CTL_PAD_SRC_POR_B SW PAD Control Register (RW)
 *
 * Reset value: 0x0000007CU
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_pad_ctl_pad_src_por_b
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_pad_ctl_pad_src_por_b_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_lpsr_sw_pad_ctl_pad_src_por_b_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B(x) (*(__IO hw_iomuxc_lpsr_sw_pad_ctl_pad_src_por_b_t *) HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_ADDR(x))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_RD(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B(x).U)
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_WR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B(x).U = (v))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_SET(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_CLR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_TOG(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B, field DSE[1:0] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 00 - X1
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_DSE (0U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_DSE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_DSE (0x00000003U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_DSE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_DSE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_DSE_DSE (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_DSE: X1 */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_DSE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_DSE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B, field SRE[2] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_SRE (2U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_SRE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_SRE (0x00000004U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_SRE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_SRE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_SRE_SRE (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_SRE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_SRE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B(x).B.SRE)
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B, field HYS[3] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_HYS (3U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_HYS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_HYS (0x00000008U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_HYS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_HYS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_HYS_HYS (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_HYS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_HYS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B(x).B.HYS)
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B, field PE[4] (RW)
 *
 * Select one out of next values for pad: SRC_POR_B
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PE (4U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PE (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PE: Pull Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: SRC_POR_B
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS (5U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS (0x00000060U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS: 100K PD */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS: 5K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS: 47K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_SRC_POR_B_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0 - SW_PAD_CTL_PAD_BOOT_MODE0 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0 - SW_PAD_CTL_PAD_BOOT_MODE0 SW PAD Control Register (RW)
 *
 * Reset value: 0x0000001CU
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_pad_ctl_pad_boot_mode0
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_pad_ctl_pad_boot_mode0_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_lpsr_sw_pad_ctl_pad_boot_mode0_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0(x) (*(__IO hw_iomuxc_lpsr_sw_pad_ctl_pad_boot_mode0_t *) HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_ADDR(x))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_RD(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0(x).U)
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_WR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0(x).U = (v))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_SET(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_CLR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_TOG(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0, field DSE[1:0] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 00 - X1
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_DSE (0U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_DSE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_DSE (0x00000003U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_DSE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_DSE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_DSE_DSE (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_DSE: X1 */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_DSE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_DSE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0, field SRE[2] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_SRE (2U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_SRE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_SRE (0x00000004U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_SRE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_SRE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_SRE_SRE (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_SRE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_SRE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0(x).B.SRE)
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0, field HYS[3] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_HYS (3U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_HYS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_HYS (0x00000008U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_HYS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_HYS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_HYS_HYS (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_HYS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_HYS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0(x).B.HYS)
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0, field PE[4] (RW)
 *
 * Select one out of next values for pad: BOOT_MODE0
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PE (4U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PE (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PE: Pull Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: BOOT_MODE0
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS (5U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS (0x00000060U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS: 100K PD */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS: 5K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS: 47K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE0_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1 - SW_PAD_CTL_PAD_BOOT_MODE1 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1 - SW_PAD_CTL_PAD_BOOT_MODE1 SW PAD Control Register (RW)
 *
 * Reset value: 0x0000001CU
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_pad_ctl_pad_boot_mode1
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_pad_ctl_pad_boot_mode1_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_lpsr_sw_pad_ctl_pad_boot_mode1_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_ADDR(x) ((uintptr_t)(x) + 0x2CU)

#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1(x) (*(__IO hw_iomuxc_lpsr_sw_pad_ctl_pad_boot_mode1_t *) HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_ADDR(x))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_RD(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1(x).U)
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_WR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1(x).U = (v))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_SET(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_CLR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_TOG(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1, field DSE[1:0] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 00 - X1
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_DSE (0U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_DSE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_DSE (0x00000003U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_DSE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_DSE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_DSE_DSE (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_DSE: X1 */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_DSE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_DSE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1(x).B.DSE)
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1, field SRE[2] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_SRE (2U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_SRE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_SRE (0x00000004U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_SRE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_SRE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_SRE_SRE (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_SRE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_SRE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1(x).B.SRE)
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1, field HYS[3] (RO)
 *
 * Read Only Field
 *
 * Values:
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_HYS (3U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_HYS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_HYS (0x00000008U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_HYS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_HYS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_HYS_HYS (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_HYS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_HYS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1(x).B.HYS)
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1, field PE[4] (RW)
 *
 * Select one out of next values for pad: BOOT_MODE1
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PE (4U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PE (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PE: Pull Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: BOOT_MODE1
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS (5U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS (0x00000060U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS: 100K PD */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS: 5K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS: 47K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_BOOT_MODE1_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00 - SW_PAD_CTL_PAD_GPIO1_IO00 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00 - SW_PAD_CTL_PAD_GPIO1_IO00 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000074U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io00
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io00_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io00_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00(x) (*(__IO hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io00_t *) HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_ADDR(x))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00(x).U)
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00(x).U = (v))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SET(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_CLR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_TOG(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO00
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE (0U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE (0x00000003U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE: X1 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE: X4 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE: X2 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE: X6 */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00, field SRE[2] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO00
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SRE (2U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SRE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SRE (0x00000004U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SRE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SRE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SRE: Fast Slew Rate */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SRE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SRE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SRE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SRE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SRE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SRE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00, field HYS[3] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO00
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_HYS (3U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_HYS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_HYS (0x00000008U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_HYS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_HYS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_HYS: Hysteresis Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_HYS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_HYS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_HYS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_HYS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_HYS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_HYS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00, field PE[4] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO00
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PE (4U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PE (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PE: Pull Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO00
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS (5U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS (0x00000060U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS: 100K PD */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS: 5K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS: 47K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO00_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01 - SW_PAD_CTL_PAD_GPIO1_IO01 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01 - SW_PAD_CTL_PAD_GPIO1_IO01 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io01
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io01_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io01_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01(x) (*(__IO hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io01_t *) HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_ADDR(x))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01(x).U)
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01(x).U = (v))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SET(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_CLR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_TOG(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO01
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE (0U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE (0x00000003U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE: X1 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE: X4 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE: X2 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE: X6 */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01, field SRE[2] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO01
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SRE (2U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SRE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SRE (0x00000004U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SRE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SRE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SRE: Fast Slew Rate */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SRE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SRE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SRE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SRE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SRE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SRE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01, field HYS[3] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO01
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_HYS (3U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_HYS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_HYS (0x00000008U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_HYS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_HYS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_HYS: Hysteresis Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_HYS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_HYS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_HYS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_HYS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_HYS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_HYS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01, field PE[4] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO01
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PE (4U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PE (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PE: Pull Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO01
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS (5U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS (0x00000060U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS: 100K PD */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS: 5K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS: 47K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO01_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02 - SW_PAD_CTL_PAD_GPIO1_IO02 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02 - SW_PAD_CTL_PAD_GPIO1_IO02 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io02
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io02_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io02_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_ADDR(x) ((uintptr_t)(x) + 0x38U)

#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02(x) (*(__IO hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io02_t *) HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_ADDR(x))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02(x).U)
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02(x).U = (v))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SET(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_CLR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_TOG(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO02
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE (0U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE (0x00000003U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE: X1 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE: X4 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE: X2 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE: X6 */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02, field SRE[2] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO02
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SRE (2U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SRE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SRE (0x00000004U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SRE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SRE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SRE: Fast Slew Rate */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SRE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SRE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SRE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SRE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SRE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SRE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02, field HYS[3] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO02
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_HYS (3U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_HYS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_HYS (0x00000008U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_HYS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_HYS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_HYS: Hysteresis Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_HYS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_HYS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_HYS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_HYS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_HYS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_HYS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02, field PE[4] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO02
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PE (4U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PE (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PE: Pull Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO02
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS (5U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS (0x00000060U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS: 100K PD */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS: 5K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS: 47K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO02_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03 - SW_PAD_CTL_PAD_GPIO1_IO03 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03 - SW_PAD_CTL_PAD_GPIO1_IO03 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io03
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io03_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io03_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_ADDR(x) ((uintptr_t)(x) + 0x3CU)

#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03(x) (*(__IO hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io03_t *) HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_ADDR(x))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03(x).U)
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03(x).U = (v))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SET(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_CLR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_TOG(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO03
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE (0U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE (0x00000003U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE: X1 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE: X4 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE: X2 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE: X6 */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03, field SRE[2] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO03
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SRE (2U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SRE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SRE (0x00000004U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SRE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SRE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SRE: Fast Slew Rate */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SRE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SRE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SRE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SRE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SRE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SRE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03, field HYS[3] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO03
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_HYS (3U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_HYS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_HYS (0x00000008U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_HYS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_HYS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_HYS: Hysteresis Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_HYS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_HYS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_HYS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_HYS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_HYS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_HYS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03, field PE[4] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO03
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PE (4U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PE (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PE: Pull Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO03
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS (5U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS (0x00000060U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS: 100K PD */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS: 5K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS: 47K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO03_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04 - SW_PAD_CTL_PAD_GPIO1_IO04 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04 - SW_PAD_CTL_PAD_GPIO1_IO04 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io04
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io04_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io04_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04(x) (*(__IO hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io04_t *) HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_ADDR(x))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04(x).U)
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04(x).U = (v))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SET(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_CLR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_TOG(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO04
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE (0U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE (0x00000003U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE: X1 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE: X4 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE: X2 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE: X6 */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04, field SRE[2] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO04
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SRE (2U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SRE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SRE (0x00000004U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SRE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SRE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SRE: Fast Slew Rate */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SRE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SRE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SRE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SRE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SRE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SRE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04, field HYS[3] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO04
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_HYS (3U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_HYS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_HYS (0x00000008U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_HYS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_HYS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_HYS: Hysteresis Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_HYS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_HYS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_HYS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_HYS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_HYS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_HYS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04, field PE[4] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO04
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PE (4U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PE (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PE: Pull Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO04
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS (5U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS (0x00000060U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS: 100K PD */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS: 5K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS: 47K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO04_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05 - SW_PAD_CTL_PAD_GPIO1_IO05 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05 - SW_PAD_CTL_PAD_GPIO1_IO05 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io05
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io05_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io05_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_ADDR(x) ((uintptr_t)(x) + 0x44U)

#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05(x) (*(__IO hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io05_t *) HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_ADDR(x))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05(x).U)
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05(x).U = (v))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SET(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_CLR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_TOG(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO05
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE (0U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE (0x00000003U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE: X1 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE: X4 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE: X2 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE: X6 */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05, field SRE[2] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO05
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SRE (2U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SRE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SRE (0x00000004U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SRE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SRE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SRE: Fast Slew Rate */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SRE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SRE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SRE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SRE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SRE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SRE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05, field HYS[3] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO05
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_HYS (3U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_HYS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_HYS (0x00000008U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_HYS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_HYS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_HYS: Hysteresis Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_HYS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_HYS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_HYS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_HYS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_HYS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_HYS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05, field PE[4] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO05
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PE (4U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PE (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PE: Pull Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO05
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS (5U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS (0x00000060U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS: 100K PD */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS: 5K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS: 47K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO05_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06 - SW_PAD_CTL_PAD_GPIO1_IO06 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06 - SW_PAD_CTL_PAD_GPIO1_IO06 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io06
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io06_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io06_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_ADDR(x) ((uintptr_t)(x) + 0x48U)

#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06(x) (*(__IO hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io06_t *) HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_ADDR(x))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06(x).U)
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06(x).U = (v))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SET(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_CLR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_TOG(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO06
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE (0U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE (0x00000003U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE: X1 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE: X4 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE: X2 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE: X6 */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06, field SRE[2] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO06
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SRE (2U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SRE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SRE (0x00000004U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SRE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SRE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SRE: Fast Slew Rate */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SRE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SRE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SRE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SRE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SRE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SRE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06, field HYS[3] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO06
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS (3U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS (0x00000008U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS: Hysteresis Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06, field PE[4] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO06
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE (4U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE: Pull Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO06
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS (5U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS (0x00000060U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS: 100K PD */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS: 5K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS: 47K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO06_PS(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07 - SW_PAD_CTL_PAD_GPIO1_IO07 SW PAD Control Register
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07 - SW_PAD_CTL_PAD_GPIO1_IO07 SW PAD Control Register (RW)
 *
 * Reset value: 0x00000014U
 *
 * SW_PAD_CTL Register
 */
typedef union _hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io07
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io07_bitfields
    {
        uint32_t DSE : 2;              /*!< [1:0] Drive Strength Field */
        uint32_t SRE : 1;              /*!< [2] Slew Rate Field */
        uint32_t HYS : 1;              /*!< [3] Hyst. Enable Field */
        uint32_t PE : 1;               /*!< [4] Pull Enable Field */
        uint32_t PS : 2;               /*!< [6:5] Pull Select Field */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io07_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_ADDR(x) ((uintptr_t)(x) + 0x4CU)

#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07(x) (*(__IO hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io07_t *) HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_ADDR(x))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07(x).U)
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07(x).U = (v))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SET(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_CLR(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_TOG(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07, field DSE[1:0] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO07
 *
 * Values:
 * - 00 - X1
 * - 01 - X4
 * - 10 - X2
 * - 11 - X6
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE (0U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE (0x00000003U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE_DSE_0_X1 (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE: X1 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE_DSE_1_X4 (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE: X4 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE_DSE_2_X2 (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE: X2 */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE_DSE_3_X6 (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE: X6 */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07(x).B.DSE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE)

/*! @brief Set the DSE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07, field SRE[2] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO07
 *
 * Values:
 * - 0 - Fast Slew Rate
 * - 1 - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SRE (2U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SRE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SRE (0x00000004U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SRE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SRE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SRE_SRE_0_Fast_Slew_Rate (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SRE: Fast Slew Rate */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SRE_SRE_1_Slow_Slew_Rate (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SRE: Slow Slew Rate */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SRE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SRE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07(x).B.SRE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SRE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SRE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SRE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SRE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07, field HYS[3] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO07
 *
 * Values:
 * - 0 - Hysteresis Disabled
 * - 1 - Hysteresis Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS (3U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS (0x00000008U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS_HYS_0_Hysteresis_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS: Hysteresis Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS_HYS_1_Hysteresis_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS: Hysteresis Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07(x).B.HYS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS)

/*! @brief Set the HYS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07, field PE[4] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO07
 *
 * Values:
 * - 0 - Pull Disabled
 * - 1 - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE (4U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE_PE_0_Pull_Disabled (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE: Pull Disabled */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE_PE_1_Pull_Enabled (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE: Pull Enabled */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07(x).B.PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE)

/*! @brief Set the PE field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07, field PS[6:5] (RW)
 *
 * Select one out of next values for pad: GPIO1_IO07
 *
 * Values:
 * - 00 - 100K PD
 * - 01 - 5K PU
 * - 10 - 47K PU
 * - 11 - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS (5U) /*!< Bit position for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS. */
#define BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS (0x00000060U) /*!< Bit mask for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS. */
#define BS_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS. */

#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS_PS_0_100K_PD (0U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS: 100K PD */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS_PS_1_5K_PU (0x1U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS: 5K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS_PS_2_47K_PU (0x2U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS: 47K PU */
#define BV_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS_PS_3_100K_PU (0x3U) /*!< Bit field value for IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS: 100K PU */

/*! @brief Read current value of the IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS field. */
#define BR_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS(x) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07(x).B.PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS. */
#define BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS) & BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS)

/*! @brief Set the PS field to a new value. */
#define BW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS(x, v) (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_WR(x, (HW_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_RD(x) & ~BM_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS) | BF_IOMUXC_LPSR_SW_PAD_CTL_PAD_GPIO1_IO07_PS(v)))
/*@}*/

/*******************************************************************************
 * hw_iomuxc_lpsr_t - module struct
 ******************************************************************************/
/*!
 * @brief All IOMUXC_LPSR module registers.
 */
#pragma pack(1)
typedef struct _hw_iomuxc_lpsr
{
    __IO hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io00_t SW_MUX_CTL_PAD_GPIO1_IO00; /*!< [0x0] SW_MUX_CTL_PAD_GPIO1_IO00 SW MUX Control Register */
    __IO hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io01_t SW_MUX_CTL_PAD_GPIO1_IO01; /*!< [0x4] SW_MUX_CTL_PAD_GPIO1_IO01 SW MUX Control Register */
    __IO hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io02_t SW_MUX_CTL_PAD_GPIO1_IO02; /*!< [0x8] SW_MUX_CTL_PAD_GPIO1_IO02 SW MUX Control Register */
    __IO hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io03_t SW_MUX_CTL_PAD_GPIO1_IO03; /*!< [0xC] SW_MUX_CTL_PAD_GPIO1_IO03 SW MUX Control Register */
    __IO hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io04_t SW_MUX_CTL_PAD_GPIO1_IO04; /*!< [0x10] SW_MUX_CTL_PAD_GPIO1_IO04 SW MUX Control Register */
    __IO hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io05_t SW_MUX_CTL_PAD_GPIO1_IO05; /*!< [0x14] SW_MUX_CTL_PAD_GPIO1_IO05 SW MUX Control Register */
    __IO hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io06_t SW_MUX_CTL_PAD_GPIO1_IO06; /*!< [0x18] SW_MUX_CTL_PAD_GPIO1_IO06 SW MUX Control Register */
    __IO hw_iomuxc_lpsr_sw_mux_ctl_pad_gpio1_io07_t SW_MUX_CTL_PAD_GPIO1_IO07; /*!< [0x1C] SW_MUX_CTL_PAD_GPIO1_IO07 SW MUX Control Register */
    __IO hw_iomuxc_lpsr_sw_pad_ctl_pad_test_mode_t SW_PAD_CTL_PAD_TEST_MODE; /*!< [0x20] SW_PAD_CTL_PAD_TEST_MODE SW PAD Control Register */
    __IO hw_iomuxc_lpsr_sw_pad_ctl_pad_src_por_b_t SW_PAD_CTL_PAD_SRC_POR_B; /*!< [0x24] SW_PAD_CTL_PAD_SRC_POR_B SW PAD Control Register */
    __IO hw_iomuxc_lpsr_sw_pad_ctl_pad_boot_mode0_t SW_PAD_CTL_PAD_BOOT_MODE0; /*!< [0x28] SW_PAD_CTL_PAD_BOOT_MODE0 SW PAD Control Register */
    __IO hw_iomuxc_lpsr_sw_pad_ctl_pad_boot_mode1_t SW_PAD_CTL_PAD_BOOT_MODE1; /*!< [0x2C] SW_PAD_CTL_PAD_BOOT_MODE1 SW PAD Control Register */
    __IO hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io00_t SW_PAD_CTL_PAD_GPIO1_IO00; /*!< [0x30] SW_PAD_CTL_PAD_GPIO1_IO00 SW PAD Control Register */
    __IO hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io01_t SW_PAD_CTL_PAD_GPIO1_IO01; /*!< [0x34] SW_PAD_CTL_PAD_GPIO1_IO01 SW PAD Control Register */
    __IO hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io02_t SW_PAD_CTL_PAD_GPIO1_IO02; /*!< [0x38] SW_PAD_CTL_PAD_GPIO1_IO02 SW PAD Control Register */
    __IO hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io03_t SW_PAD_CTL_PAD_GPIO1_IO03; /*!< [0x3C] SW_PAD_CTL_PAD_GPIO1_IO03 SW PAD Control Register */
    __IO hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io04_t SW_PAD_CTL_PAD_GPIO1_IO04; /*!< [0x40] SW_PAD_CTL_PAD_GPIO1_IO04 SW PAD Control Register */
    __IO hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io05_t SW_PAD_CTL_PAD_GPIO1_IO05; /*!< [0x44] SW_PAD_CTL_PAD_GPIO1_IO05 SW PAD Control Register */
    __IO hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io06_t SW_PAD_CTL_PAD_GPIO1_IO06; /*!< [0x48] SW_PAD_CTL_PAD_GPIO1_IO06 SW PAD Control Register */
    __IO hw_iomuxc_lpsr_sw_pad_ctl_pad_gpio1_io07_t SW_PAD_CTL_PAD_GPIO1_IO07; /*!< [0x4C] SW_PAD_CTL_PAD_GPIO1_IO07 SW PAD Control Register */
} hw_iomuxc_lpsr_t;
#pragma pack()

/*! @brief Macro to access all IOMUXC_LPSR registers. */
/*! @param x IOMUXC_LPSR module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_IOMUXC_LPSR_REGS(IOMUXC_LPSR_BASE)</code>. */
#define HW_IOMUXC_LPSR_REGS(x) (*(hw_iomuxc_lpsr_t *)(x))

/*
 * iMX7D IOMUXC_LPSR_GPR
 *
 * IOMUXC_LPSR_GPR
 *
 * Registers defined in this header file:
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0 - IOMUXC_LPSR General Purpose Register 0
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1 - IOMUXC_LPSR General Purpose Register 1
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2 - IOMUXC_LPSR General Purpose Register 2
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3 - IOMUXC_LPSR General Purpose Register 3
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4 - IOMUXC_LPSR General Purpose Register 4
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5 - IOMUXC_LPSR General Purpose Register 5
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6 - IOMUXC_LPSR General Purpose Register 6
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7 - IOMUXC_LPSR General Purpose Register 7
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8 - IOMUXC_LPSR General Purpose Register 8
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9 - IOMUXC_LPSR General Purpose Register 9
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10 - IOMUXC_LPSR General Purpose Register 10
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11 - IOMUXC_LPSR General Purpose Register 11
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12 - IOMUXC_LPSR General Purpose Register 12
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13 - IOMUXC_LPSR General Purpose Register 13
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14 - IOMUXC_LPSR General Purpose Register 14
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15 - IOMUXC_LPSR General Purpose Register 15
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16 - IOMUXC_LPSR General Purpose Register 16
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17 - IOMUXC_LPSR General Purpose Register 17
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18 - IOMUXC_LPSR General Purpose Register 18
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19 - IOMUXC_LPSR General Purpose Register 19
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20 - IOMUXC_LPSR General Purpose Register 20
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21 - IOMUXC_LPSR General Purpose Register 21
 * - HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22 - IOMUXC_LPSR General Purpose Register 22
 *
 * - hw_iomuxc_lpsr_gpr_t - Struct containing all module registers.
 */

#define HW_IOMUXC_LPSR_GPR_INSTANCE_COUNT (1U) /*!< Number of instances of the IOMUXC_LPSR_GPR module. */
#define HW_IOMUXC_LPSR_GPR (0U) /*!< Instance number for IOMUXC_LPSR_GPR. */
#define IOMUXC_LPSR_GPR_BASE  (0x30270000U) /*!< Base address for IOMUXC_LPSR_GPR. */
/*! Array initializer of IOMUXC_LPSR_GPR base addresses. */
#define IOMUXC_LPSR_GPR_BASE_ADDRS { IOMUXC_LPSR_GPR_BASE }

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0 - IOMUXC_LPSR General Purpose Register 0
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0 - IOMUXC_LPSR General Purpose Register 0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr0
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr0_bitfields
    {
        uint32_t GP : 32;              /*!< [31:0]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr0_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_ADDR(x) ((uintptr_t)(x) + 0x0U)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr0_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0, field GP[31:0] (RW)
 *
 * Common bits can be R/W freely
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_GP (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_GP. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_GP (0xFFFFFFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_GP. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_GP (32U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_GP. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_GP field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_GP(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0(x).U)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_GP. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_GP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_GP) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_GP)

/*! @brief Set the GP field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_GP(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1 - IOMUXC_LPSR General Purpose Register 1
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1 - IOMUXC_LPSR General Purpose Register 1 (RW)
 *
 * Reset value: 0x0F400005U
 *
 * IOMUXC LPSR General Purpose Register 1
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr1
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr1_bitfields
    {
        uint32_t GP : 32;              /*!< [31:0]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr1_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_ADDR(x) ((uintptr_t)(x) + 0x4U)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr1_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1, field GP[31:0] (RW)
 *
 * Common bits can be R/W freely
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_GP (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_GP. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_GP (0xFFFFFFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_GP. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_GP (32U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_GP. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_GP field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_GP(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1(x).U)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_GP. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_GP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_GP) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_GP)

/*! @brief Set the GP field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_GP(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2 - IOMUXC_LPSR General Purpose Register 2
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2 - IOMUXC_LPSR General Purpose Register 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr2
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr2_bitfields
    {
        uint32_t GP : 32;              /*!< [31:0]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr2_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_ADDR(x) ((uintptr_t)(x) + 0x8U)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr2_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2, field GP[31:0] (RW)
 *
 * Common bits can be R/W freely
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_GP (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_GP. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_GP (0xFFFFFFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_GP. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_GP (32U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_GP. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_GP field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_GP(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2(x).U)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_GP. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_GP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_GP) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_GP)

/*! @brief Set the GP field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_GP(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3 - IOMUXC_LPSR General Purpose Register 3
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3 - IOMUXC_LPSR General Purpose Register 3 (RW)
 *
 * Reset value: 0x00000FFFU
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr3
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr3_bitfields
    {
        uint32_t GP : 16;              /*!< [15:0]  */
        uint32_t RO : 16;              /*!< [31:16]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr3_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr3_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3, field GP[15:0] (RW)
 *
 * Common bits can be R/W freely
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP (0x0000FFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP (16U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3(x).B.GP)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP)

/*! @brief Set the GP field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_GP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3, field RO[31:16] (RW)
 *
 * Read only bits, always 16'h0
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO (16U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO (0xFFFF0000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO (16U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3(x).B.RO)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO)

/*! @brief Set the RO field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR3_RO(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4 - IOMUXC_LPSR General Purpose Register 4
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4 - IOMUXC_LPSR General Purpose Register 4 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr4
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr4_bitfields
    {
        uint32_t GP : 16;              /*!< [15:0]  */
        uint32_t RO : 16;              /*!< [31:16]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr4_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_ADDR(x) ((uintptr_t)(x) + 0x10U)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr4_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4, field GP[15:0] (RW)
 *
 * Common bits can be R/W freely
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP (0x0000FFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP (16U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4(x).B.GP)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP)

/*! @brief Set the GP field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_GP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4, field RO[31:16] (RW)
 *
 * Read only bits, always 16'h0
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO (16U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO (0xFFFF0000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO (16U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4(x).B.RO)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO)

/*! @brief Set the RO field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR4_RO(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5 - IOMUXC_LPSR General Purpose Register 5
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5 - IOMUXC_LPSR General Purpose Register 5 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr5
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr5_bitfields
    {
        uint32_t GP : 32;              /*!< [31:0]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr5_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr5_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5, field GP[31:0] (RW)
 *
 * Common bits can be R/W freely
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_GP (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_GP. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_GP (0xFFFFFFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_GP. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_GP (32U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_GP. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_GP field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_GP(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5(x).U)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_GP. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_GP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_GP) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_GP)

/*! @brief Set the GP field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_GP(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR5_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6 - IOMUXC_LPSR General Purpose Register 6
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6 - IOMUXC_LPSR General Purpose Register 6 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr6
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr6_bitfields
    {
        uint32_t GP : 32;              /*!< [31:0]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr6_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_ADDR(x) ((uintptr_t)(x) + 0x18U)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr6_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6, field GP[31:0] (RW)
 *
 * Common bits can be R/W freely
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_GP (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_GP. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_GP (0xFFFFFFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_GP. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_GP (32U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_GP. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_GP field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_GP(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6(x).U)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_GP. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_GP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_GP) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_GP)

/*! @brief Set the GP field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_GP(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR6_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7 - IOMUXC_LPSR General Purpose Register 7
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7 - IOMUXC_LPSR General Purpose Register 7 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr7
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr7_bitfields
    {
        uint32_t GP : 32;              /*!< [31:0]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr7_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr7_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7, field GP[31:0] (RW)
 *
 * Common bits can be R/W freely
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_GP (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_GP. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_GP (0xFFFFFFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_GP. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_GP (32U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_GP. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_GP field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_GP(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7(x).U)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_GP. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_GP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_GP) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_GP)

/*! @brief Set the GP field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_GP(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR7_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8 - IOMUXC_LPSR General Purpose Register 8
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8 - IOMUXC_LPSR General Purpose Register 8 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr8
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr8_bitfields
    {
        uint32_t GP : 32;              /*!< [31:0]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr8_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr8_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8, field GP[31:0] (RW)
 *
 * Common bits can be R/W freely
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_GP (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_GP. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_GP (0xFFFFFFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_GP. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_GP (32U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_GP. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_GP field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_GP(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8(x).U)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_GP. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_GP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_GP) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_GP)

/*! @brief Set the GP field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_GP(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR8_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9 - IOMUXC_LPSR General Purpose Register 9
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9 - IOMUXC_LPSR General Purpose Register 9 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr9
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr9_bitfields
    {
        uint32_t STICKY : 32;          /*!< [31:0]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr9_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr9_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9, field STICKY[31:0] (RW)
 *
 * Each bit is sticky. Once it's written to 1'b1, it cannot be written back to
 * 1'b0.
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_STICKY (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_STICKY. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_STICKY (0xFFFFFFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_STICKY. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_STICKY (32U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_STICKY. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_STICKY field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_STICKY(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9(x).U)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_STICKY. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_STICKY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_STICKY) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_STICKY)

/*! @brief Set the STICKY field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_STICKY(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR9_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10 - IOMUXC_LPSR General Purpose Register 10
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10 - IOMUXC_LPSR General Purpose Register 10 (RW)
 *
 * Reset value: 0x00000007U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr10
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr10_bitfields
    {
        uint32_t LOCK : 16;            /*!< [15:0]  */
        uint32_t STICKY : 16;          /*!< [31:16]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr10_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr10_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10, field LOCK[15:0] (RW)
 *
 * These are lock type bits. For example, bit [15] can't be written to new value
 * when bit [31] is 1'b1 or new written value of bit [31] is 1'b1.
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK (0x0000FFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK (16U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10(x).B.LOCK)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_LOCK(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10, field STICKY[31:16] (RW)
 *
 * Bits [31:16] are lock bits for [15:0]. Each of bits [31:16] are sticky. Once
 * it's written to 1'b1, it can not be written back to 1'b0.
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY (16U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY (0xFFFF0000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY (16U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10(x).B.STICKY)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY)

/*! @brief Set the STICKY field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR10_STICKY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11 - IOMUXC_LPSR General Purpose Register 11
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11 - IOMUXC_LPSR General Purpose Register 11 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr11
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr11_bitfields
    {
        uint32_t LOCK : 16;            /*!< [15:0]  */
        uint32_t STICKY : 16;          /*!< [31:16]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr11_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_ADDR(x) ((uintptr_t)(x) + 0x2CU)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr11_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11, field LOCK[15:0] (RW)
 *
 * These are lock type bits. For example, bit [15] can't be written to new value
 * when bit [31] is 1'b1 or new written value of bit [31] is 1'b1.
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK (0x0000FFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK (16U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11(x).B.LOCK)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_LOCK(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11, field STICKY[31:16] (RW)
 *
 * Bits [31:16] are lock bits for [15:0]. Each of bits [31:16] are sticky. Once
 * it's written to 1'b1, it can not be written back to 1'b0.
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY (16U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY (0xFFFF0000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY (16U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11(x).B.STICKY)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY)

/*! @brief Set the STICKY field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR11_STICKY(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12 - IOMUXC_LPSR General Purpose Register 12
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12 - IOMUXC_LPSR General Purpose Register 12 (RW)
 *
 * Reset value: 0x30000080U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr12
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr12_bitfields
    {
        uint32_t GP : 32;              /*!< [31:0]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr12_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr12_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12, field GP[31:0] (RW)
 *
 * Common bits can be R/W freely
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_GP (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_GP. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_GP (0xFFFFFFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_GP. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_GP (32U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_GP. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_GP field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_GP(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12(x).U)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_GP. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_GP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_GP) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_GP)

/*! @brief Set the GP field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_GP(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR12_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13 - IOMUXC_LPSR General Purpose Register 13
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13 - IOMUXC_LPSR General Purpose Register 13 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr13
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr13_bitfields
    {
        uint32_t GP : 16;              /*!< [15:0]  */
        uint32_t RO : 16;              /*!< [31:16]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr13_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr13_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13, field GP[15:0] (RW)
 *
 * Common bits can be R/W freely
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP (0x0000FFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP (16U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13(x).B.GP)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP)

/*! @brief Set the GP field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_GP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13, field RO[31:16] (RW)
 *
 * Read only bits, always 16'h0
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO (16U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO (0xFFFF0000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO (16U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13(x).B.RO)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO)

/*! @brief Set the RO field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR13_RO(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14 - IOMUXC_LPSR General Purpose Register 14
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14 - IOMUXC_LPSR General Purpose Register 14 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr14
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr14_bitfields
    {
        uint32_t GP : 32;              /*!< [31:0]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr14_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_ADDR(x) ((uintptr_t)(x) + 0x38U)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr14_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14, field GP[31:0] (RW)
 *
 * Common bits can be R/W freely
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_GP (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_GP. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_GP (0xFFFFFFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_GP. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_GP (32U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_GP. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_GP field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_GP(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14(x).U)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_GP. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_GP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_GP) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_GP)

/*! @brief Set the GP field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_GP(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR14_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15 - IOMUXC_LPSR General Purpose Register 15
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15 - IOMUXC_LPSR General Purpose Register 15 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr15
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr15_bitfields
    {
        uint32_t GP : 32;              /*!< [31:0]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr15_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_ADDR(x) ((uintptr_t)(x) + 0x3CU)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr15_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15, field GP[31:0] (RW)
 *
 * Common bits can be R/W freely
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_GP (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_GP. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_GP (0xFFFFFFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_GP. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_GP (32U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_GP. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_GP field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_GP(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15(x).U)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_GP. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_GP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_GP) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_GP)

/*! @brief Set the GP field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_GP(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR15_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16 - IOMUXC_LPSR General Purpose Register 16
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16 - IOMUXC_LPSR General Purpose Register 16 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr16
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr16_bitfields
    {
        uint32_t GP : 32;              /*!< [31:0]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr16_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr16_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16, field GP[31:0] (RW)
 *
 * Common bits can be R/W freely
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_GP (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_GP. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_GP (0xFFFFFFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_GP. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_GP (32U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_GP. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_GP field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_GP(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16(x).U)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_GP. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_GP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_GP) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_GP)

/*! @brief Set the GP field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_GP(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR16_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17 - IOMUXC_LPSR General Purpose Register 17
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17 - IOMUXC_LPSR General Purpose Register 17 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr17
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr17_bitfields
    {
        uint32_t GP : 32;              /*!< [31:0]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr17_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_ADDR(x) ((uintptr_t)(x) + 0x44U)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr17_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17, field GP[31:0] (RW)
 *
 * Common bits can be R/W freely
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_GP (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_GP. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_GP (0xFFFFFFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_GP. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_GP (32U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_GP. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_GP field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_GP(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17(x).U)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_GP. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_GP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_GP) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_GP)

/*! @brief Set the GP field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_GP(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR17_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18 - IOMUXC_LPSR General Purpose Register 18
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18 - IOMUXC_LPSR General Purpose Register 18 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr18
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr18_bitfields
    {
        uint32_t GP : 32;              /*!< [31:0]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr18_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_ADDR(x) ((uintptr_t)(x) + 0x48U)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr18_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18, field GP[31:0] (RW)
 *
 * Common bits can be R/W freely
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_GP (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_GP. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_GP (0xFFFFFFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_GP. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_GP (32U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_GP. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_GP field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_GP(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18(x).U)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_GP. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_GP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_GP) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_GP)

/*! @brief Set the GP field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_GP(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR18_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19 - IOMUXC_LPSR General Purpose Register 19
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19 - IOMUXC_LPSR General Purpose Register 19 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr19
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr19_bitfields
    {
        uint32_t GP : 32;              /*!< [31:0]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr19_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_ADDR(x) ((uintptr_t)(x) + 0x4CU)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr19_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19, field GP[31:0] (RW)
 *
 * Common bits can be R/W freely
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_GP (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_GP. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_GP (0xFFFFFFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_GP. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_GP (32U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_GP. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_GP field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_GP(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19(x).U)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_GP. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_GP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_GP) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_GP)

/*! @brief Set the GP field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_GP(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR19_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20 - IOMUXC_LPSR General Purpose Register 20
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20 - IOMUXC_LPSR General Purpose Register 20 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr20
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr20_bitfields
    {
        uint32_t GPIO1_IO08_DSE : 2;   /*!< [1:0]  */
        uint32_t GPIO1_IO08_SRE : 1;   /*!< [2]  */
        uint32_t GPIO1_IO08_HYS : 1;   /*!< [3]  */
        uint32_t GPIO1_IO08_PE : 1;    /*!< [4]  */
        uint32_t GPIO1_IO08_PS : 2;    /*!< [6:5]  */
        uint32_t GPIO1_IO08_MUX_CTL : 1; /*!< [7]  */
        uint32_t GPIO1_IO09_DSE : 2;   /*!< [9:8]  */
        uint32_t GPIO1_IO09_SRE : 1;   /*!< [10]  */
        uint32_t GPIO1_IO09_HYS : 1;   /*!< [11]  */
        uint32_t GPIO1_IO09_PE : 1;    /*!< [12]  */
        uint32_t GPIO1_IO09_PS : 2;    /*!< [14:13]  */
        uint32_t GPIO1_IO09_MUX_CTL : 1; /*!< [15]  */
        uint32_t GPIO1_IO10_DSE : 2;   /*!< [17:16]  */
        uint32_t GPIO1_IO10_SRE : 1;   /*!< [18]  */
        uint32_t GPIO1_IO10_HYS : 1;   /*!< [19]  */
        uint32_t GPIO1_IO10_PE : 1;    /*!< [20]  */
        uint32_t GPIO1_IO10_PS : 2;    /*!< [22:21]  */
        uint32_t GPIO1_IO10_MUX_CTL : 1; /*!< [23]  */
        uint32_t GPIO1_IO11_DSE : 2;   /*!< [25:24]  */
        uint32_t GPIO1_IO11_SRE : 1;   /*!< [26]  */
        uint32_t GPIO1_IO11_HYS : 1;   /*!< [27]  */
        uint32_t GPIO1_IO11_PE : 1;    /*!< [28]  */
        uint32_t GPIO1_IO11_PS : 2;    /*!< [30:29]  */
        uint32_t GPIO1_IO11_MUX_CTL : 1; /*!< [31]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr20_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr20_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO08_DSE[1:0] (RW)
 *
 * Drive Strength Field Select one out of next values for pad: GPIO1_IO08
 *
 * Values:
 * - 00 - DSE_0_X1 - X1
 * - 01 - DSE_1_X1 - X2
 * - 10 - DSE_2_X1 - X4
 * - 11 - DSE_3_X1 - X6
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE (0x00000003U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO08_DSE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE)

/*! @brief Set the GPIO1_IO08_DSE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO08_SRE[2] (RW)
 *
 * Slew Rate Field Select one out of next values for pad: GPIO1_IO08
 *
 * Values:
 * - 0 - SRE_0_Fast_Slew_Rate - Fast Slew Rate
 * - 1 - SRE_1_Slow_Slew_Rate - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_SRE (2U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_SRE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_SRE (0x00000004U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_SRE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_SRE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_SRE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_SRE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO08_SRE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_SRE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_SRE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_SRE)

/*! @brief Set the GPIO1_IO08_SRE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_SRE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_SRE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO08_HYS[3] (RW)
 *
 * Hyst. Enable Field Select one out of next values for pad: GPIO1_IO08
 *
 * Values:
 * - 0 - HYS_0_Hysteresis_Disabled - Hysteresis Disabled
 * - 1 - HYS_1_Hysteresis_Enabled - Hysteresis Enable
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_HYS (3U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_HYS. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_HYS (0x00000008U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_HYS. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_HYS. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_HYS field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_HYS(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO08_HYS)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_HYS. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_HYS) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_HYS)

/*! @brief Set the GPIO1_IO08_HYS field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_HYS(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_HYS) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO08_PE[4] (RW)
 *
 * Pull Enable Field Select one out of next values for pad: GPIO1_IO08
 *
 * Values:
 * - 0 - PE_0_Pull_Disabled - Pull Disabled
 * - 1 - PE_1_Pull_Enabled - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PE (4U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PE (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO08_PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PE)

/*! @brief Set the GPIO1_IO08_PE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO08_PS[6:5] (RW)
 *
 * Pull Select Field Select one out of next values for pad: GPIO1_IO08
 *
 * Values:
 * - 00 - PS_0_100K_PD - 100K PD
 * - 01 - PS_1_5K_PU - 5K PU
 * - 10 - PS_2_47K_PU - 47K PU
 * - 11 - PS_3_100K_PU - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS (5U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS (0x00000060U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO08_PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS)

/*! @brief Set the GPIO1_IO08_PS field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_PS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO08_MUX_CTL[7] (RW)
 *
 * Mux control for PAD
 *
 * Values:
 * - 0 - Pad control from SOC IOMUX
 * - 1 - Pad control from LPSR GPR
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_MUX_CTL (7U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_MUX_CTL. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_MUX_CTL (0x00000080U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_MUX_CTL. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_MUX_CTL (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_MUX_CTL. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_MUX_CTL field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_MUX_CTL(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO08_MUX_CTL)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_MUX_CTL. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_MUX_CTL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_MUX_CTL) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_MUX_CTL)

/*! @brief Set the GPIO1_IO08_MUX_CTL field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_MUX_CTL(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_MUX_CTL) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO08_MUX_CTL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO09_DSE[9:8] (RW)
 *
 * Drive Strength Field Select one out of next values for pad: GPIO1_IO09
 *
 * Values:
 * - 00 - DSE_0_X1 - X1
 * - 01 - DSE_1_X1 - X2
 * - 10 - DSE_2_X1 - X4
 * - 11 - DSE_3_X1 - X6
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE (8U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE (0x00000300U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO09_DSE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE)

/*! @brief Set the GPIO1_IO09_DSE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO09_SRE[10] (RW)
 *
 * Slew Rate Field Select one out of next values for pad: GPIO1_IO09
 *
 * Values:
 * - 0 - SRE_0_Fast_Slew_Rate - Fast Slew Rate
 * - 1 - SRE_1_Slow_Slew_Rate - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_SRE (10U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_SRE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_SRE (0x00000400U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_SRE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_SRE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_SRE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_SRE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO09_SRE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_SRE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_SRE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_SRE)

/*! @brief Set the GPIO1_IO09_SRE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_SRE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_SRE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO09_HYS[11] (RW)
 *
 * Hyst. Enable Field Select one out of next values for pad: GPIO1_IO09
 *
 * Values:
 * - 0 - HYS_0_Hysteresis_Disabled - Hysteresis Disabled
 * - 1 - HYS_1_Hysteresis_Enabled - Hysteresis Enable
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_HYS (11U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_HYS. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_HYS (0x00000800U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_HYS. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_HYS. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_HYS field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_HYS(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO09_HYS)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_HYS. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_HYS) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_HYS)

/*! @brief Set the GPIO1_IO09_HYS field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_HYS(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_HYS) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO09_PE[12] (RW)
 *
 * Pull Enable Field Select one out of next values for pad: GPIO1_IO09
 *
 * Values:
 * - 0 - PE_0_Pull_Disabled - Pull Disabled
 * - 1 - PE_1_Pull_Enabled - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PE (12U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PE (0x00001000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO09_PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PE)

/*! @brief Set the GPIO1_IO09_PE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO09_PS[14:13] (RW)
 *
 * Pull Select Field Select one out of next values for pad: GPIO1_IO09
 *
 * Values:
 * - 00 - PS_0_100K_PD - 100K PD
 * - 01 - PS_1_5K_PU - 5K PU
 * - 10 - PS_2_47K_PU - 47K PU
 * - 11 - PS_3_100K_PU - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS (13U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS (0x00006000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO09_PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS)

/*! @brief Set the GPIO1_IO09_PS field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_PS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO09_MUX_CTL[15] (RW)
 *
 * Mux control for PAD
 *
 * Values:
 * - 0 - Pad control from SOC IOMUX
 * - 1 - Pad control from LPSR GPR
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_MUX_CTL (15U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_MUX_CTL. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_MUX_CTL (0x00008000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_MUX_CTL. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_MUX_CTL (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_MUX_CTL. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_MUX_CTL field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_MUX_CTL(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO09_MUX_CTL)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_MUX_CTL. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_MUX_CTL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_MUX_CTL) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_MUX_CTL)

/*! @brief Set the GPIO1_IO09_MUX_CTL field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_MUX_CTL(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_MUX_CTL) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO09_MUX_CTL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO10_DSE[17:16] (RW)
 *
 * Drive Strength Field Select one out of next values for pad: GPIO1_IO10
 *
 * Values:
 * - 00 - DSE_0_X1 - X1
 * - 01 - DSE_1_X1 - X2
 * - 10 - DSE_2_X1 - X4
 * - 11 - DSE_3_X1 - X6
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE (16U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE (0x00030000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO10_DSE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE)

/*! @brief Set the GPIO1_IO10_DSE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO10_SRE[18] (RW)
 *
 * Slew Rate Field Select one out of next values for pad: GPIO1_IO10
 *
 * Values:
 * - 0 - SRE_0_Fast_Slew_Rate - Fast Slew Rate
 * - 1 - SRE_1_Slow_Slew_Rate - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_SRE (18U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_SRE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_SRE (0x00040000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_SRE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_SRE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_SRE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_SRE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO10_SRE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_SRE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_SRE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_SRE)

/*! @brief Set the GPIO1_IO10_SRE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_SRE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_SRE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO10_HYS[19] (RW)
 *
 * Hyst. Enable Field Select one out of next values for pad: GPIO1_IO10
 *
 * Values:
 * - 0 - HYS_0_Hysteresis_Disabled - Hysteresis Disabled
 * - 1 - HYS_1_Hysteresis_Enabled - Hysteresis Enable
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_HYS (19U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_HYS. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_HYS (0x00080000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_HYS. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_HYS. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_HYS field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_HYS(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO10_HYS)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_HYS. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_HYS) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_HYS)

/*! @brief Set the GPIO1_IO10_HYS field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_HYS(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_HYS) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO10_PE[20] (RW)
 *
 * Pull Enable Field Select one out of next values for pad: GPIO1_IO10
 *
 * Values:
 * - 0 - PE_0_Pull_Disabled - Pull Disabled
 * - 1 - PE_1_Pull_Enabled - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PE (20U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PE (0x00100000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO10_PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PE)

/*! @brief Set the GPIO1_IO10_PE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO10_PS[22:21] (RW)
 *
 * Pull Select Field Select one out of next values for pad: GPIO1_IO10
 *
 * Values:
 * - 00 - PS_0_100K_PD - 100K PD
 * - 01 - PS_1_5K_PU - 5K PU
 * - 10 - PS_2_47K_PU - 47K PU
 * - 11 - PS_3_100K_PU - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS (21U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS (0x00600000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO10_PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS)

/*! @brief Set the GPIO1_IO10_PS field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_PS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO10_MUX_CTL[23] (RW)
 *
 * Mux control for PAD
 *
 * Values:
 * - 0 - Pad control from SOC IOMUX
 * - 1 - Pad control from LPSR GPR
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_MUX_CTL (23U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_MUX_CTL. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_MUX_CTL (0x00800000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_MUX_CTL. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_MUX_CTL (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_MUX_CTL. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_MUX_CTL field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_MUX_CTL(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO10_MUX_CTL)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_MUX_CTL. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_MUX_CTL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_MUX_CTL) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_MUX_CTL)

/*! @brief Set the GPIO1_IO10_MUX_CTL field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_MUX_CTL(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_MUX_CTL) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO10_MUX_CTL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO11_DSE[25:24] (RW)
 *
 * Drive Strength Field Select one out of next values for pad: GPIO1_IO11
 *
 * Values:
 * - 00 - DSE_0_X1 - X1
 * - 01 - DSE_1_X1 - X2
 * - 10 - DSE_2_X1 - X4
 * - 11 - DSE_3_X1 - X6
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE (24U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE (0x03000000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO11_DSE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE)

/*! @brief Set the GPIO1_IO11_DSE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO11_SRE[26] (RW)
 *
 * Slew Rate Field Select one out of next values for pad: GPIO1_IO11
 *
 * Values:
 * - 0 - SRE_0_Fast_Slew_Rate - Fast Slew Rate
 * - 1 - SRE_1_Slow_Slew_Rate - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_SRE (26U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_SRE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_SRE (0x04000000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_SRE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_SRE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_SRE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_SRE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO11_SRE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_SRE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_SRE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_SRE)

/*! @brief Set the GPIO1_IO11_SRE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_SRE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_SRE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO11_HYS[27] (RW)
 *
 * Hyst. Enable Field Select one out of next values for pad: GPIO1_IO11
 *
 * Values:
 * - 0 - HYS_0_Hysteresis_Disabled - Hysteresis Disabled
 * - 1 - HYS_1_Hysteresis_Enabled - Hysteresis Enable
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_HYS (27U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_HYS. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_HYS (0x08000000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_HYS. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_HYS. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_HYS field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_HYS(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO11_HYS)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_HYS. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_HYS) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_HYS)

/*! @brief Set the GPIO1_IO11_HYS field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_HYS(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_HYS) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO11_PE[28] (RW)
 *
 * Pull Enable Field Select one out of next values for pad: GPIO1_IO11
 *
 * Values:
 * - 0 - PE_0_Pull_Disabled - Pull Disabled
 * - 1 - PE_1_Pull_Enabled - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PE (28U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PE (0x10000000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO11_PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PE)

/*! @brief Set the GPIO1_IO11_PE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO11_PS[30:29] (RW)
 *
 * Pull Select Field Select one out of next values for pad: GPIO1_IO11
 *
 * Values:
 * - 00 - PS_0_100K_PD - 100K PD
 * - 01 - PS_1_5K_PU - 5K PU
 * - 10 - PS_2_47K_PU - 47K PU
 * - 11 - PS_3_100K_PU - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS (29U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS (0x60000000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO11_PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS)

/*! @brief Set the GPIO1_IO11_PS field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_PS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20, field GPIO1_IO11_MUX_CTL[31] (RW)
 *
 * Mux control for PAD
 *
 * Values:
 * - 0 - Pad control from SOC IOMUX
 * - 1 - Pad control from LPSR GPR
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_MUX_CTL (31U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_MUX_CTL. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_MUX_CTL (0x80000000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_MUX_CTL. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_MUX_CTL (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_MUX_CTL. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_MUX_CTL field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_MUX_CTL(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20(x).B.GPIO1_IO11_MUX_CTL)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_MUX_CTL. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_MUX_CTL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_MUX_CTL) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_MUX_CTL)

/*! @brief Set the GPIO1_IO11_MUX_CTL field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_MUX_CTL(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_MUX_CTL) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR20_GPIO1_IO11_MUX_CTL(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21 - IOMUXC_LPSR General Purpose Register 21
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21 - IOMUXC_LPSR General Purpose Register 21 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr21
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr21_bitfields
    {
        uint32_t GPIO1_IO12_DSE : 2;   /*!< [1:0]  */
        uint32_t GPIO1_IO12_SRE : 1;   /*!< [2]  */
        uint32_t GPIO1_IO12_HYS : 1;   /*!< [3]  */
        uint32_t GPIO1_IO12_PE : 1;    /*!< [4]  */
        uint32_t GPIO1_IO12_PS : 2;    /*!< [6:5]  */
        uint32_t GPIO1_IO12_MUX_CTL : 1; /*!< [7]  */
        uint32_t GPIO1_IO13_DSE : 2;   /*!< [9:8]  */
        uint32_t GPIO1_IO13_SRE : 1;   /*!< [10]  */
        uint32_t GPIO1_IO13_HYS : 1;   /*!< [11]  */
        uint32_t GPIO1_IO13_PE : 1;    /*!< [12]  */
        uint32_t GPIO1_IO13_PS : 2;    /*!< [14:13]  */
        uint32_t GPIO1_IO13_MUX_CTL : 1; /*!< [15]  */
        uint32_t GPIO1_IO14_DSE : 2;   /*!< [17:16]  */
        uint32_t GPIO1_IO14_SRE : 1;   /*!< [18]  */
        uint32_t GPIO1_IO14_HYS : 1;   /*!< [19]  */
        uint32_t GPIO1_IO14_PE : 1;    /*!< [20]  */
        uint32_t GPIO1_IO14_PS : 2;    /*!< [22:21]  */
        uint32_t GPIO1_IO14_MUX_CTL : 1; /*!< [23]  */
        uint32_t GPIO1_IO15_DSE : 2;   /*!< [25:24]  */
        uint32_t GPIO1_IO15_SRE : 1;   /*!< [26]  */
        uint32_t GPIO1_IO15_HYS : 1;   /*!< [27]  */
        uint32_t GPIO1_IO15_PE : 1;    /*!< [28]  */
        uint32_t GPIO1_IO15_PS : 2;    /*!< [30:29]  */
        uint32_t GPIO1_IO15_MUX_CTL : 1; /*!< [31]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr21_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_ADDR(x) ((uintptr_t)(x) + 0x54U)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr21_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO12_DSE[1:0] (RW)
 *
 * Drive Strength Field Select one out of next values for pad: GPIO1_IO12
 *
 * Values:
 * - 00 - DSE_0_X1 - X1
 * - 01 - DSE_1_X1 - X2
 * - 10 - DSE_2_X1 - X4
 * - 11 - DSE_3_X1 - X6
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE (0x00000003U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO12_DSE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE)

/*! @brief Set the GPIO1_IO12_DSE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO12_SRE[2] (RW)
 *
 * Slew Rate Field Select one out of next values for pad: GPIO1_IO12
 *
 * Values:
 * - 0 - SRE_0_Fast_Slew_Rate - Fast Slew Rate
 * - 1 - SRE_1_Slow_Slew_Rate - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_SRE (2U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_SRE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_SRE (0x00000004U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_SRE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_SRE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_SRE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_SRE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO12_SRE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_SRE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_SRE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_SRE)

/*! @brief Set the GPIO1_IO12_SRE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_SRE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_SRE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO12_HYS[3] (RW)
 *
 * Hyst. Enable Field Select one out of next values for pad: GPIO1_IO12
 *
 * Values:
 * - 0 - HYS_0_Hysteresis_Disabled - Hysteresis Disabled
 * - 1 - HYS_1_Hysteresis_Enabled - Hysteresis Enable
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_HYS (3U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_HYS. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_HYS (0x00000008U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_HYS. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_HYS. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_HYS field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_HYS(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO12_HYS)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_HYS. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_HYS) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_HYS)

/*! @brief Set the GPIO1_IO12_HYS field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_HYS(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_HYS) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO12_PE[4] (RW)
 *
 * Pull Enable Field Select one out of next values for pad: GPIO1_IO12
 *
 * Values:
 * - 0 - PE_0_Pull_Disabled - Pull Disabled
 * - 1 - PE_1_Pull_Enabled - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PE (4U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PE (0x00000010U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO12_PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PE)

/*! @brief Set the GPIO1_IO12_PE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO12_PS[6:5] (RW)
 *
 * Pull Select Field Select one out of next values for pad: GPIO1_IO12
 *
 * Values:
 * - 00 - PS_0_100K_PD - 100K PD
 * - 01 - PS_1_5K_PU - 5K PU
 * - 10 - PS_2_47K_PU - 47K PU
 * - 11 - PS_3_100K_PU - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS (5U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS (0x00000060U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO12_PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS)

/*! @brief Set the GPIO1_IO12_PS field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_PS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO12_MUX_CTL[7] (RW)
 *
 * Mux control for PAD
 *
 * Values:
 * - 0 - Pad control from SOC IOMUX
 * - 1 - Pad control from LPSR GPR
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_MUX_CTL (7U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_MUX_CTL. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_MUX_CTL (0x00000080U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_MUX_CTL. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_MUX_CTL (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_MUX_CTL. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_MUX_CTL field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_MUX_CTL(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO12_MUX_CTL)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_MUX_CTL. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_MUX_CTL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_MUX_CTL) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_MUX_CTL)

/*! @brief Set the GPIO1_IO12_MUX_CTL field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_MUX_CTL(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_MUX_CTL) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO12_MUX_CTL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO13_DSE[9:8] (RW)
 *
 * Drive Strength Field Select one out of next values for pad: GPIO1_IO13
 *
 * Values:
 * - 00 - DSE_0_X1 - X1
 * - 01 - DSE_1_X1 - X2
 * - 10 - DSE_2_X1 - X4
 * - 11 - DSE_3_X1 - X6
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE (8U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE (0x00000300U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO13_DSE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE)

/*! @brief Set the GPIO1_IO13_DSE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO13_SRE[10] (RW)
 *
 * Slew Rate Field Select one out of next values for pad: GPIO1_IO13
 *
 * Values:
 * - 0 - SRE_0_Fast_Slew_Rate - Fast Slew Rate
 * - 1 - SRE_1_Slow_Slew_Rate - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_SRE (10U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_SRE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_SRE (0x00000400U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_SRE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_SRE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_SRE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_SRE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO13_SRE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_SRE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_SRE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_SRE)

/*! @brief Set the GPIO1_IO13_SRE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_SRE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_SRE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO13_HYS[11] (RW)
 *
 * Hyst. Enable Field Select one out of next values for pad: GPIO1_IO13
 *
 * Values:
 * - 0 - HYS_0_Hysteresis_Disabled - Hysteresis Disabled
 * - 1 - HYS_1_Hysteresis_Enabled - Hysteresis Enable
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_HYS (11U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_HYS. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_HYS (0x00000800U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_HYS. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_HYS. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_HYS field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_HYS(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO13_HYS)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_HYS. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_HYS) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_HYS)

/*! @brief Set the GPIO1_IO13_HYS field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_HYS(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_HYS) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO13_PE[12] (RW)
 *
 * Pull Enable Field Select one out of next values for pad: GPIO1_IO13
 *
 * Values:
 * - 0 - PE_0_Pull_Disabled - Pull Disabled
 * - 1 - PE_1_Pull_Enabled - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PE (12U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PE (0x00001000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO13_PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PE)

/*! @brief Set the GPIO1_IO13_PE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO13_PS[14:13] (RW)
 *
 * Pull Select Field Select one out of next values for pad: GPIO1_IO13
 *
 * Values:
 * - 00 - PS_0_100K_PD - 100K PD
 * - 01 - PS_1_5K_PU - 5K PU
 * - 10 - PS_2_47K_PU - 47K PU
 * - 11 - PS_3_100K_PU - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS (13U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS (0x00006000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO13_PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS)

/*! @brief Set the GPIO1_IO13_PS field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_PS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO13_MUX_CTL[15] (RW)
 *
 * Mux control for PAD
 *
 * Values:
 * - 0 - Pad control from SOC IOMUX
 * - 1 - Pad control from LPSR GPR
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_MUX_CTL (15U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_MUX_CTL. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_MUX_CTL (0x00008000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_MUX_CTL. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_MUX_CTL (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_MUX_CTL. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_MUX_CTL field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_MUX_CTL(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO13_MUX_CTL)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_MUX_CTL. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_MUX_CTL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_MUX_CTL) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_MUX_CTL)

/*! @brief Set the GPIO1_IO13_MUX_CTL field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_MUX_CTL(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_MUX_CTL) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO13_MUX_CTL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO14_DSE[17:16] (RW)
 *
 * Drive Strength Field Select one out of next values for pad: GPIO1_IO14
 *
 * Values:
 * - 00 - DSE_0_X1 - X1
 * - 01 - DSE_1_X1 - X2
 * - 10 - DSE_2_X1 - X4
 * - 11 - DSE_3_X1 - X6
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE (16U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE (0x00030000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO14_DSE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE)

/*! @brief Set the GPIO1_IO14_DSE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO14_SRE[18] (RW)
 *
 * Slew Rate Field Select one out of next values for pad: GPIO1_IO14
 *
 * Values:
 * - 0 - SRE_0_Fast_Slew_Rate - Fast Slew Rate
 * - 1 - SRE_1_Slow_Slew_Rate - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_SRE (18U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_SRE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_SRE (0x00040000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_SRE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_SRE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_SRE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_SRE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO14_SRE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_SRE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_SRE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_SRE)

/*! @brief Set the GPIO1_IO14_SRE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_SRE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_SRE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO14_HYS[19] (RW)
 *
 * Hyst. Enable Field Select one out of next values for pad: GPIO1_IO14
 *
 * Values:
 * - 0 - HYS_0_Hysteresis_Disabled - Hysteresis Disabled
 * - 1 - HYS_1_Hysteresis_Enabled - Hysteresis Enable
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_HYS (19U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_HYS. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_HYS (0x00080000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_HYS. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_HYS. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_HYS field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_HYS(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO14_HYS)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_HYS. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_HYS) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_HYS)

/*! @brief Set the GPIO1_IO14_HYS field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_HYS(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_HYS) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO14_PE[20] (RW)
 *
 * Pull Enable Field Select one out of next values for pad: GPIO1_IO14
 *
 * Values:
 * - 0 - PE_0_Pull_Disabled - Pull Disabled
 * - 1 - PE_1_Pull_Enabled - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PE (20U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PE (0x00100000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO14_PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PE)

/*! @brief Set the GPIO1_IO14_PE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO14_PS[22:21] (RW)
 *
 * Pull Select Field Select one out of next values for pad: GPIO1_IO14
 *
 * Values:
 * - 00 - PS_0_100K_PD - 100K PD
 * - 01 - PS_1_5K_PU - 5K PU
 * - 10 - PS_2_47K_PU - 47K PU
 * - 11 - PS_3_100K_PU - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS (21U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS (0x00600000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO14_PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS)

/*! @brief Set the GPIO1_IO14_PS field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_PS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO14_MUX_CTL[23] (RW)
 *
 * Mux control for PAD
 *
 * Values:
 * - 0 - Pad control from SOC IOMUX
 * - 1 - Pad control from LPSR GPR
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_MUX_CTL (23U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_MUX_CTL. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_MUX_CTL (0x00800000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_MUX_CTL. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_MUX_CTL (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_MUX_CTL. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_MUX_CTL field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_MUX_CTL(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO14_MUX_CTL)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_MUX_CTL. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_MUX_CTL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_MUX_CTL) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_MUX_CTL)

/*! @brief Set the GPIO1_IO14_MUX_CTL field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_MUX_CTL(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_MUX_CTL) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO14_MUX_CTL(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO15_DSE[25:24] (RW)
 *
 * Drive Strength Field Select one out of next values for pad: GPIO1_IO15
 *
 * Values:
 * - 00 - DSE_0_X1 - X1
 * - 01 - DSE_1_X1 - X2
 * - 10 - DSE_2_X1 - X4
 * - 11 - DSE_3_X1 - X6
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE (24U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE (0x03000000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE (2U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO15_DSE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE)

/*! @brief Set the GPIO1_IO15_DSE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_DSE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO15_SRE[26] (RW)
 *
 * Slew Rate Field Select one out of next values for pad: GPIO1_IO15
 *
 * Values:
 * - 0 - SRE_0_Fast_Slew_Rate - Fast Slew Rate
 * - 1 - SRE_1_Slow_Slew_Rate - Slow Slew Rate
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_SRE (26U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_SRE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_SRE (0x04000000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_SRE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_SRE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_SRE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_SRE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_SRE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO15_SRE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_SRE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_SRE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_SRE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_SRE)

/*! @brief Set the GPIO1_IO15_SRE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_SRE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_SRE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_SRE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO15_HYS[27] (RW)
 *
 * Hyst. Enable Field Select one out of next values for pad: GPIO1_IO15
 *
 * Values:
 * - 0 - HYS_0_Hysteresis_Disabled - Hysteresis Disabled
 * - 1 - HYS_1_Hysteresis_Enabled - Hysteresis Enable
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_HYS (27U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_HYS. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_HYS (0x08000000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_HYS. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_HYS (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_HYS. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_HYS field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_HYS(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO15_HYS)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_HYS. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_HYS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_HYS) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_HYS)

/*! @brief Set the GPIO1_IO15_HYS field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_HYS(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_HYS) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_HYS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO15_PE[28] (RW)
 *
 * Pull Enable Field Select one out of next values for pad: GPIO1_IO15
 *
 * Values:
 * - 0 - PE_0_Pull_Disabled - Pull Disabled
 * - 1 - PE_1_Pull_Enabled - Pull Enabled
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PE (28U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PE. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PE (0x10000000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PE. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PE (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PE. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PE field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PE(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO15_PE)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PE. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PE(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PE) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PE)

/*! @brief Set the GPIO1_IO15_PE field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PE(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PE) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PE(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO15_PS[30:29] (RW)
 *
 * Pull Select Field Select one out of next values for pad: GPIO1_IO15
 *
 * Values:
 * - 00 - PS_0_100K_PD - 100K PD
 * - 01 - PS_1_5K_PU - 5K PU
 * - 10 - PS_2_47K_PU - 47K PU
 * - 11 - PS_3_100K_PU - 100K PU
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS (29U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS (0x60000000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS (2U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO15_PS)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS)

/*! @brief Set the GPIO1_IO15_PS field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_PS(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21, field GPIO1_IO15_MUX_CTL[31] (RW)
 *
 * Mux control for PAD
 *
 * Values:
 * - 0 - Pad control from SOC IOMUX
 * - 1 - Pad control from LPSR GPR
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_MUX_CTL (31U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_MUX_CTL. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_MUX_CTL (0x80000000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_MUX_CTL. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_MUX_CTL (1U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_MUX_CTL. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_MUX_CTL field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_MUX_CTL(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21(x).B.GPIO1_IO15_MUX_CTL)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_MUX_CTL. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_MUX_CTL(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_MUX_CTL) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_MUX_CTL)

/*! @brief Set the GPIO1_IO15_MUX_CTL field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_MUX_CTL(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_MUX_CTL) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR21_GPIO1_IO15_MUX_CTL(v)))
/*@}*/

/*******************************************************************************
 * HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22 - IOMUXC_LPSR General Purpose Register 22
 ******************************************************************************/

/*!
 * @brief HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22 - IOMUXC_LPSR General Purpose Register 22 (RW)
 *
 * Reset value: 0x00000000U
 *
 * IOMUXC LPSR General Purpose Register
 */
typedef union _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr22
{
    uint32_t U;
    struct _hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr22_bitfields
    {
        uint32_t GP : 16;              /*!< [15:0]  */
        uint32_t RO : 16;              /*!< [31:16]  */
    } B;
} hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr22_t;

/*!
 * @name Constants and macros for entire IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22 register
 */
/*@{*/
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_ADDR(x) ((uintptr_t)(x) + 0x58U)

#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22(x) (*(__IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr22_t *) HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_ADDR(x))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RD(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22(x).U)
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_WR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22(x).U = (v))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_SET(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RD(x) |  (v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_CLR(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RD(x) & ~(v)))
#define HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_TOG(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_WR(x, HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22 bitfields
 */

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22, field GP[15:0] (RW)
 *
 * Common bits can be R/W freely
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP (0U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP (0x0000FFFFU) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP (16U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22(x).B.GP)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP)

/*! @brief Set the GP field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_GP(v)))
/*@}*/

/*!
 * @name Register IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22, field RO[31:16] (RW)
 *
 * Read only bits, always 16'h0
 */
/*@{*/
#define BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO (16U) /*!< Bit position for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO. */
#define BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO (0xFFFF0000U) /*!< Bit mask for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO. */
#define BS_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO (16U) /*!< Bit field size in bits for IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO. */

/*! @brief Read current value of the IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO field. */
#define BR_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO(x) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22(x).B.RO)

/*! @brief Format value for bitfield IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO. */
#define BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO(v) ((uint32_t)((uint32_t)(v) << BP_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO) & BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO)

/*! @brief Set the RO field to a new value. */
#define BW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO(x, v) (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_WR(x, (HW_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RD(x) & ~BM_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO) | BF_IOMUXC_LPSR_GPR_IOMUXC_LPSR_GPR22_RO(v)))
/*@}*/

/*******************************************************************************
 * hw_iomuxc_lpsr_gpr_t - module struct
 ******************************************************************************/
/*!
 * @brief All IOMUXC_LPSR_GPR module registers.
 */
#pragma pack(1)
typedef struct _hw_iomuxc_lpsr_gpr
{
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr0_t IOMUXC_LPSR_GPR0; /*!< [0x0] IOMUXC_LPSR General Purpose Register 0 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr1_t IOMUXC_LPSR_GPR1; /*!< [0x4] IOMUXC_LPSR General Purpose Register 1 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr2_t IOMUXC_LPSR_GPR2; /*!< [0x8] IOMUXC_LPSR General Purpose Register 2 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr3_t IOMUXC_LPSR_GPR3; /*!< [0xC] IOMUXC_LPSR General Purpose Register 3 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr4_t IOMUXC_LPSR_GPR4; /*!< [0x10] IOMUXC_LPSR General Purpose Register 4 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr5_t IOMUXC_LPSR_GPR5; /*!< [0x14] IOMUXC_LPSR General Purpose Register 5 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr6_t IOMUXC_LPSR_GPR6; /*!< [0x18] IOMUXC_LPSR General Purpose Register 6 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr7_t IOMUXC_LPSR_GPR7; /*!< [0x1C] IOMUXC_LPSR General Purpose Register 7 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr8_t IOMUXC_LPSR_GPR8; /*!< [0x20] IOMUXC_LPSR General Purpose Register 8 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr9_t IOMUXC_LPSR_GPR9; /*!< [0x24] IOMUXC_LPSR General Purpose Register 9 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr10_t IOMUXC_LPSR_GPR10; /*!< [0x28] IOMUXC_LPSR General Purpose Register 10 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr11_t IOMUXC_LPSR_GPR11; /*!< [0x2C] IOMUXC_LPSR General Purpose Register 11 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr12_t IOMUXC_LPSR_GPR12; /*!< [0x30] IOMUXC_LPSR General Purpose Register 12 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr13_t IOMUXC_LPSR_GPR13; /*!< [0x34] IOMUXC_LPSR General Purpose Register 13 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr14_t IOMUXC_LPSR_GPR14; /*!< [0x38] IOMUXC_LPSR General Purpose Register 14 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr15_t IOMUXC_LPSR_GPR15; /*!< [0x3C] IOMUXC_LPSR General Purpose Register 15 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr16_t IOMUXC_LPSR_GPR16; /*!< [0x40] IOMUXC_LPSR General Purpose Register 16 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr17_t IOMUXC_LPSR_GPR17; /*!< [0x44] IOMUXC_LPSR General Purpose Register 17 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr18_t IOMUXC_LPSR_GPR18; /*!< [0x48] IOMUXC_LPSR General Purpose Register 18 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr19_t IOMUXC_LPSR_GPR19; /*!< [0x4C] IOMUXC_LPSR General Purpose Register 19 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr20_t IOMUXC_LPSR_GPR20; /*!< [0x50] IOMUXC_LPSR General Purpose Register 20 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr21_t IOMUXC_LPSR_GPR21; /*!< [0x54] IOMUXC_LPSR General Purpose Register 21 */
    __IO hw_iomuxc_lpsr_gpr_iomuxc_lpsr_gpr22_t IOMUXC_LPSR_GPR22; /*!< [0x58] IOMUXC_LPSR General Purpose Register 22 */
} hw_iomuxc_lpsr_gpr_t;
#pragma pack()

/*! @brief Macro to access all IOMUXC_LPSR_GPR registers. */
/*! @param x IOMUXC_LPSR_GPR module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_IOMUXC_LPSR_GPR_REGS(IOMUXC_LPSR_GPR_BASE)</code>. */
#define HW_IOMUXC_LPSR_GPR_REGS(x) (*(hw_iomuxc_lpsr_gpr_t *)(x))

/*
 * iMX7D KPP
 *
 * Keypad Port (KPP)
 *
 * Registers defined in this header file:
 * - HW_KPP_KPCR - Keypad Control Register
 * - HW_KPP_KPSR - Keypad Status Register
 * - HW_KPP_KDDR - Keypad Data Direction Register
 * - HW_KPP_KPDR - Keypad Data Register
 *
 * - hw_kpp_t - Struct containing all module registers.
 */

#define HW_KPP_INSTANCE_COUNT (1U) /*!< Number of instances of the KPP module. */
#define HW_KPP (0U) /*!< Instance number for KPP. */
#define KPP_BASE              (0x30320000U) /*!< Base address for KPP. */
/*! Array initializer of KPP base addresses. */
#define KPP_BASE_ADDRS        { KPP_BASE }

/*******************************************************************************
 * HW_KPP_KPCR - Keypad Control Register
 ******************************************************************************/

/*!
 * @brief HW_KPP_KPCR - Keypad Control Register (RW)
 *
 * Reset value: 0x0000U
 *
 * The Keypad Control Register determines which of the eight possible column
 * strobes are to be open drain when configured as outputs, and which of the eight
 * row sense lines are considered in generating an interrupt to the core. It is up
 * to the programmer to ensure that pins being used for functions other than the
 * keypad are properly disabled. The KPP_KPCR register is byte- or
 * half-word-addressable.
 */
typedef union _hw_kpp_kpcr
{
    uint16_t U;
    struct _hw_kpp_kpcr_bitfields
    {
        uint16_t KRE : 8;              /*!< [7:0]  */
        uint16_t KCO : 8;              /*!< [15:8]  */
    } B;
} hw_kpp_kpcr_t;

/*!
 * @name Constants and macros for entire KPP_KPCR register
 */
/*@{*/
#define HW_KPP_KPCR_ADDR(x)      ((uintptr_t)(x) + 0x0U)

#define HW_KPP_KPCR(x)           (*(__IO hw_kpp_kpcr_t *) HW_KPP_KPCR_ADDR(x))
#define HW_KPP_KPCR_RD(x)        (HW_KPP_KPCR(x).U)
#define HW_KPP_KPCR_WR(x, v)     (HW_KPP_KPCR(x).U = (v))
#define HW_KPP_KPCR_SET(x, v)    (HW_KPP_KPCR_WR(x, HW_KPP_KPCR_RD(x) |  (v)))
#define HW_KPP_KPCR_CLR(x, v)    (HW_KPP_KPCR_WR(x, HW_KPP_KPCR_RD(x) & ~(v)))
#define HW_KPP_KPCR_TOG(x, v)    (HW_KPP_KPCR_WR(x, HW_KPP_KPCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual KPP_KPCR bitfields
 */

/*!
 * @name Register KPP_KPCR, field KRE[7:0] (RW)
 *
 * Keypad Row Enable. Setting a row enable control bit in this register enables
 * the corresponding row line to participate in interrupt generation. Likewise,
 * clearing a bit disables that row from being used to generate an interrupt. This
 * register is cleared by a reset, disabling all rows. The row-enable logic is
 * independent of the programmed direction of the pin. Writing a "0" to the data
 * register of the pins configured as outputs will cause a keypad interrupt to be
 * generated if the row enable associated with that bit is set.
 *
 * Values:
 * - 0 - Row is not included in the keypad key press detect.
 * - 1 - Row is included in the keypad key press detect.
 */
/*@{*/
#define BP_KPP_KPCR_KRE      (0U)          /*!< Bit position for KPP_KPCR_KRE. */
#define BM_KPP_KPCR_KRE      (0x00FFU)     /*!< Bit mask for KPP_KPCR_KRE. */
#define BS_KPP_KPCR_KRE      (8U)          /*!< Bit field size in bits for KPP_KPCR_KRE. */

/*! @brief Read current value of the KPP_KPCR_KRE field. */
#define BR_KPP_KPCR_KRE(x)   (HW_KPP_KPCR(x).B.KRE)

/*! @brief Format value for bitfield KPP_KPCR_KRE. */
#define BF_KPP_KPCR_KRE(v)   ((uint16_t)((uint16_t)(v) << BP_KPP_KPCR_KRE) & BM_KPP_KPCR_KRE)

/*! @brief Set the KRE field to a new value. */
#define BW_KPP_KPCR_KRE(x, v) (HW_KPP_KPCR_WR(x, (HW_KPP_KPCR_RD(x) & ~BM_KPP_KPCR_KRE) | BF_KPP_KPCR_KRE(v)))
/*@}*/

/*!
 * @name Register KPP_KPCR, field KCO[15:8] (RW)
 *
 * Keypad Column Strobe Open-Drain Enable. Setting a column open-drain enable
 * bit (KCO7-KCO0) disables the pull-up driver on that pin. Clearing the bit allows
 * the pin to drive to the high state. This bit has no effect when the pin is
 * configured as an input. Configuration of external port control logic (for
 * example, IOMUX) should be done properly so that the KPP controls an open-drain
 * enable of the pin.
 *
 * Values:
 * - 0 - Column strobe output is totem pole drive.
 * - 1 - Column strobe output is open drain.
 */
/*@{*/
#define BP_KPP_KPCR_KCO      (8U)          /*!< Bit position for KPP_KPCR_KCO. */
#define BM_KPP_KPCR_KCO      (0xFF00U)     /*!< Bit mask for KPP_KPCR_KCO. */
#define BS_KPP_KPCR_KCO      (8U)          /*!< Bit field size in bits for KPP_KPCR_KCO. */

#define BV_KPP_KPCR_KCO_TOTEM_POLE     (0U)          /*!< Bit field value for KPP_KPCR_KCO: Column strobe output is totem pole drive. */
#define BV_KPP_KPCR_KCO_OPEN_DRAIN     (0x1U)        /*!< Bit field value for KPP_KPCR_KCO: Column strobe output is open drain. */

/*! @brief Read current value of the KPP_KPCR_KCO field. */
#define BR_KPP_KPCR_KCO(x)   (HW_KPP_KPCR(x).B.KCO)

/*! @brief Format value for bitfield KPP_KPCR_KCO. */
#define BF_KPP_KPCR_KCO(v)   ((uint16_t)((uint16_t)(v) << BP_KPP_KPCR_KCO) & BM_KPP_KPCR_KCO)

/*! @brief Set the KCO field to a new value. */
#define BW_KPP_KPCR_KCO(x, v) (HW_KPP_KPCR_WR(x, (HW_KPP_KPCR_RD(x) & ~BM_KPP_KPCR_KCO) | BF_KPP_KPCR_KCO(v)))
/*@}*/

/*******************************************************************************
 * HW_KPP_KPSR - Keypad Status Register
 ******************************************************************************/

/*!
 * @brief HW_KPP_KPSR - Keypad Status Register (RW)
 *
 * Reset value: 0x0400U
 *
 * The Keypad Status Register reflects the state of the key press detect
 * circuit. The KPP_KPSR register is byte- or half-word-addressable.
 */
typedef union _hw_kpp_kpsr
{
    uint16_t U;
    struct _hw_kpp_kpsr_bitfields
    {
        uint16_t KPKD : 1;             /*!< [0]  */
        uint16_t KPKR : 1;             /*!< [1]  */
        uint16_t KDSC : 1;             /*!< [2]  */
        uint16_t KRSS : 1;             /*!< [3]  */
        uint16_t RESERVED0 : 4;        /*!< [7:4]  */
        uint16_t KDIE : 1;             /*!< [8]  */
        uint16_t KRIE : 1;             /*!< [9]  */
        uint16_t RESERVED1 : 6;        /*!< [15:10]  */
    } B;
} hw_kpp_kpsr_t;

/*!
 * @name Constants and macros for entire KPP_KPSR register
 */
/*@{*/
#define HW_KPP_KPSR_ADDR(x)      ((uintptr_t)(x) + 0x2U)

#define HW_KPP_KPSR(x)           (*(__IO hw_kpp_kpsr_t *) HW_KPP_KPSR_ADDR(x))
#define HW_KPP_KPSR_RD(x)        (HW_KPP_KPSR(x).U)
#define HW_KPP_KPSR_WR(x, v)     (HW_KPP_KPSR(x).U = (v))
#define HW_KPP_KPSR_SET(x, v)    (HW_KPP_KPSR_WR(x, HW_KPP_KPSR_RD(x) |  (v)))
#define HW_KPP_KPSR_CLR(x, v)    (HW_KPP_KPSR_WR(x, HW_KPP_KPSR_RD(x) & ~(v)))
#define HW_KPP_KPSR_TOG(x, v)    (HW_KPP_KPSR_WR(x, HW_KPP_KPSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual KPP_KPSR bitfields
 */

/*!
 * @name Register KPP_KPSR, field KPKD[0] (W1C)
 *
 * Keypad Key Depress. The keypad key depress (KPKD) status bit is set when one
 * or more enabled rows are detected low after synchronization. The KPKD status
 * bit remains set until cleared by the software. The KPKD bit may be used to
 * generate a maskable key depress interrupt. If desired, the software may clear the
 * key press synchronizer chain to allow a repeated interrupt to be generated
 * while a key remains pressed. In this case, a new interrupt will be generated
 * after the synchronizer delay (4 cycles of the low frequency reference clock
 * elapses if a key remains pressed. This functionality can be used to detect a long
 * key press. This allows detection of additional key presses of the same key or
 * other keys. Due to the logic function of the release and depress synchronizer
 * chains, it is possible to see the re-assertion of a status flag (KPKD or KPKR)
 * if it is cleared by the software prior to the system exiting the state it
 * represents.
 *
 * Values:
 * - 0 - No key presses detected
 * - 1 - A key has been depressed
 */
/*@{*/
#define BP_KPP_KPSR_KPKD     (0U)          /*!< Bit position for KPP_KPSR_KPKD. */
#define BM_KPP_KPSR_KPKD     (0x0001U)     /*!< Bit mask for KPP_KPSR_KPKD. */
#define BS_KPP_KPSR_KPKD     (1U)          /*!< Bit field size in bits for KPP_KPSR_KPKD. */

/*! @brief Read current value of the KPP_KPSR_KPKD field. */
#define BR_KPP_KPSR_KPKD(x)  (HW_KPP_KPSR(x).B.KPKD)

/*! @brief Format value for bitfield KPP_KPSR_KPKD. */
#define BF_KPP_KPSR_KPKD(v)  ((uint16_t)((uint16_t)(v) << BP_KPP_KPSR_KPKD) & BM_KPP_KPSR_KPKD)

/*! @brief Set the KPKD field to a new value. */
#define BW_KPP_KPSR_KPKD(x, v) (HW_KPP_KPSR_WR(x, (HW_KPP_KPSR_RD(x) & ~(BM_KPP_KPSR_KPKD | BM_KPP_KPSR_KPKR)) | BF_KPP_KPSR_KPKD(v)))
/*@}*/

/*!
 * @name Register KPP_KPSR, field KPKR[1] (W1C)
 *
 * Keypad Key Release. The keypad key release (KPKR) status bit is set when all
 * enabled rows are detected high after synchronization (the KPKR status bit will
 * be set when cleared by a reset). The KPKR bit may be used to generate a
 * maskable key release interrupt. The key release synchronizer may be set high by
 * software after scanning the keypad to ensure a known state. Due to the logic
 * function of the release and depress synchronizer chains, it is possible to see the
 * re-assertion of a status flag (KPKD or KPKR) if it is cleared by software
 * prior to the system exiting the state it represents. Reset value of register is
 * "0" as long as reset is asserted. However when reset is de-asserted, the value
 * of the register depends upon the external row pins and can become "1".
 *
 * Values:
 * - 0 - No key release detected
 * - 1 - All keys have been released
 */
/*@{*/
#define BP_KPP_KPSR_KPKR     (1U)          /*!< Bit position for KPP_KPSR_KPKR. */
#define BM_KPP_KPSR_KPKR     (0x0002U)     /*!< Bit mask for KPP_KPSR_KPKR. */
#define BS_KPP_KPSR_KPKR     (1U)          /*!< Bit field size in bits for KPP_KPSR_KPKR. */

/*! @brief Read current value of the KPP_KPSR_KPKR field. */
#define BR_KPP_KPSR_KPKR(x)  (HW_KPP_KPSR(x).B.KPKR)

/*! @brief Format value for bitfield KPP_KPSR_KPKR. */
#define BF_KPP_KPSR_KPKR(v)  ((uint16_t)((uint16_t)(v) << BP_KPP_KPSR_KPKR) & BM_KPP_KPSR_KPKR)

/*! @brief Set the KPKR field to a new value. */
#define BW_KPP_KPSR_KPKR(x, v) (HW_KPP_KPSR_WR(x, (HW_KPP_KPSR_RD(x) & ~(BM_KPP_KPSR_KPKR | BM_KPP_KPSR_KPKD)) | BF_KPP_KPSR_KPKR(v)))
/*@}*/

/*!
 * @name Register KPP_KPSR, field KDSC[2] (WORZ)
 *
 * Key Depress Synchronizer Clear. Self-clear bit. The Key depress synchronizer
 * is cleared by writing a logic "1" into this bit. Reads return a value of "0".
 *
 * Values:
 * - 0 - No effect
 * - 1 - Set bits that clear the keypad depress synchronizer chain
 */
/*@{*/
#define BP_KPP_KPSR_KDSC     (2U)          /*!< Bit position for KPP_KPSR_KDSC. */
#define BM_KPP_KPSR_KDSC     (0x0004U)     /*!< Bit mask for KPP_KPSR_KDSC. */
#define BS_KPP_KPSR_KDSC     (1U)          /*!< Bit field size in bits for KPP_KPSR_KDSC. */

/*! @brief Format value for bitfield KPP_KPSR_KDSC. */
#define BF_KPP_KPSR_KDSC(v)  ((uint16_t)((uint16_t)(v) << BP_KPP_KPSR_KDSC) & BM_KPP_KPSR_KDSC)

/*! @brief Set the KDSC field to a new value. */
#define BW_KPP_KPSR_KDSC(x, v) (HW_KPP_KPSR_WR(x, (HW_KPP_KPSR_RD(x) & ~(BM_KPP_KPSR_KDSC | BM_KPP_KPSR_KPKD | BM_KPP_KPSR_KPKR)) | BF_KPP_KPSR_KDSC(v)))
/*@}*/

/*!
 * @name Register KPP_KPSR, field KRSS[3] (WORZ)
 *
 * Key Release Synchronizer Set. Self-clear bit. The Key release synchronizer is
 * set by writing a logic one into this bit. Reads return a value of "0".
 *
 * Values:
 * - 0 - No effect
 * - 1 - Set bits which sets keypad release synchronizer chain
 */
/*@{*/
#define BP_KPP_KPSR_KRSS     (3U)          /*!< Bit position for KPP_KPSR_KRSS. */
#define BM_KPP_KPSR_KRSS     (0x0008U)     /*!< Bit mask for KPP_KPSR_KRSS. */
#define BS_KPP_KPSR_KRSS     (1U)          /*!< Bit field size in bits for KPP_KPSR_KRSS. */

/*! @brief Format value for bitfield KPP_KPSR_KRSS. */
#define BF_KPP_KPSR_KRSS(v)  ((uint16_t)((uint16_t)(v) << BP_KPP_KPSR_KRSS) & BM_KPP_KPSR_KRSS)

/*! @brief Set the KRSS field to a new value. */
#define BW_KPP_KPSR_KRSS(x, v) (HW_KPP_KPSR_WR(x, (HW_KPP_KPSR_RD(x) & ~(BM_KPP_KPSR_KRSS | BM_KPP_KPSR_KPKD | BM_KPP_KPSR_KPKR)) | BF_KPP_KPSR_KRSS(v)))
/*@}*/

/*!
 * @name Register KPP_KPSR, field KDIE[8] (RW)
 *
 * Keypad Key Depress Interrupt Enable. Software should ensure that the
 * interrupt for a Key Release event is masked until it has entered the key pressed
 * state, and vice-versa, unless this activity is desired (as might be the case when a
 * repeated interrupt is to be generated). The synchronizer chains are capable
 * of being initialized to detect repeated key presses or releases. If they are
 * not initialized when the corresponding event flag is cleared, false interrupts
 * may be generated for depress (or release) events shorter than the length of the
 * corresponding chain.
 *
 * Values:
 * - 0 - No interrupt request is generated when KPKD is set.
 * - 1 - An interrupt request is generated when KPKD is set.
 */
/*@{*/
#define BP_KPP_KPSR_KDIE     (8U)          /*!< Bit position for KPP_KPSR_KDIE. */
#define BM_KPP_KPSR_KDIE     (0x0100U)     /*!< Bit mask for KPP_KPSR_KDIE. */
#define BS_KPP_KPSR_KDIE     (1U)          /*!< Bit field size in bits for KPP_KPSR_KDIE. */

/*! @brief Read current value of the KPP_KPSR_KDIE field. */
#define BR_KPP_KPSR_KDIE(x)  (HW_KPP_KPSR(x).B.KDIE)

/*! @brief Format value for bitfield KPP_KPSR_KDIE. */
#define BF_KPP_KPSR_KDIE(v)  ((uint16_t)((uint16_t)(v) << BP_KPP_KPSR_KDIE) & BM_KPP_KPSR_KDIE)

/*! @brief Set the KDIE field to a new value. */
#define BW_KPP_KPSR_KDIE(x, v) (HW_KPP_KPSR_WR(x, (HW_KPP_KPSR_RD(x) & ~(BM_KPP_KPSR_KDIE | BM_KPP_KPSR_KPKD | BM_KPP_KPSR_KPKR)) | BF_KPP_KPSR_KDIE(v)))
/*@}*/

/*!
 * @name Register KPP_KPSR, field KRIE[9] (RW)
 *
 * Keypad Release Interrupt Enable. The software should ensure that the
 * interrupt for a Key Release event is masked until it has entered the key pressed
 * state, and vice versa, unless this activity is desired (as might be the case when a
 * repeated interrupt is to be generated). The synchronizer chains are capable
 * of being initialized to detect repeated key presses or releases. If they are
 * not initialized when the corresponding event flag is cleared, false interrupts
 * may be generated for depress (or release) events shorter than the length of the
 * corresponding chain.
 *
 * Values:
 * - 0 - No interrupt request is generated when KPKR is set.
 * - 1 - An interrupt request is generated when KPKR is set.
 */
/*@{*/
#define BP_KPP_KPSR_KRIE     (9U)          /*!< Bit position for KPP_KPSR_KRIE. */
#define BM_KPP_KPSR_KRIE     (0x0200U)     /*!< Bit mask for KPP_KPSR_KRIE. */
#define BS_KPP_KPSR_KRIE     (1U)          /*!< Bit field size in bits for KPP_KPSR_KRIE. */

/*! @brief Read current value of the KPP_KPSR_KRIE field. */
#define BR_KPP_KPSR_KRIE(x)  (HW_KPP_KPSR(x).B.KRIE)

/*! @brief Format value for bitfield KPP_KPSR_KRIE. */
#define BF_KPP_KPSR_KRIE(v)  ((uint16_t)((uint16_t)(v) << BP_KPP_KPSR_KRIE) & BM_KPP_KPSR_KRIE)

/*! @brief Set the KRIE field to a new value. */
#define BW_KPP_KPSR_KRIE(x, v) (HW_KPP_KPSR_WR(x, (HW_KPP_KPSR_RD(x) & ~(BM_KPP_KPSR_KRIE | BM_KPP_KPSR_KPKD | BM_KPP_KPSR_KPKR)) | BF_KPP_KPSR_KRIE(v)))
/*@}*/

/*******************************************************************************
 * HW_KPP_KDDR - Keypad Data Direction Register
 ******************************************************************************/

/*!
 * @brief HW_KPP_KDDR - Keypad Data Direction Register (RW)
 *
 * Reset value: 0x0000U
 *
 * The bits in the KPP_KDDR control the direction of the keypad port pins. The
 * upper eight bits in the register affect the pins designated as column strobes,
 * while the lower eight bits affect the row sense pins. Setting any bit in this
 * register configures the corresponding pin as an output. Clearing any bit in
 * this register configures the corresponding port pin as an input. For the Keypad
 * Row DDR, an internal pull-up is enabled if the corresponding bit is clear.
 * This register is cleared by a reset, configuring all pins as inputs. The KPP_KDDR
 * register is byte- or half-word addressable. When a pin is used as row pin for
 * keypad purposes, all corresponding pull-ups should be enabled at the upper
 * level (for example, IOMUX) when the bit in KRDD is cleared.
 */
typedef union _hw_kpp_kddr
{
    uint16_t U;
    struct _hw_kpp_kddr_bitfields
    {
        uint16_t KRDD : 8;             /*!< [7:0]  */
        uint16_t KCDD : 8;             /*!< [15:8]  */
    } B;
} hw_kpp_kddr_t;

/*!
 * @name Constants and macros for entire KPP_KDDR register
 */
/*@{*/
#define HW_KPP_KDDR_ADDR(x)      ((uintptr_t)(x) + 0x4U)

#define HW_KPP_KDDR(x)           (*(__IO hw_kpp_kddr_t *) HW_KPP_KDDR_ADDR(x))
#define HW_KPP_KDDR_RD(x)        (HW_KPP_KDDR(x).U)
#define HW_KPP_KDDR_WR(x, v)     (HW_KPP_KDDR(x).U = (v))
#define HW_KPP_KDDR_SET(x, v)    (HW_KPP_KDDR_WR(x, HW_KPP_KDDR_RD(x) |  (v)))
#define HW_KPP_KDDR_CLR(x, v)    (HW_KPP_KDDR_WR(x, HW_KPP_KDDR_RD(x) & ~(v)))
#define HW_KPP_KDDR_TOG(x, v)    (HW_KPP_KDDR_WR(x, HW_KPP_KDDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual KPP_KDDR bitfields
 */

/*!
 * @name Register KPP_KDDR, field KRDD[7:0] (RW)
 *
 * Keypad Row Data Direction. Setting a bit configures the corresponding ROWn
 * pin as an output (where n = 7 through 0).
 *
 * Values:
 * - 0 - ROWn pin configured as an input.
 * - 1 - ROWn pin configured as an output.
 */
/*@{*/
#define BP_KPP_KDDR_KRDD     (0U)          /*!< Bit position for KPP_KDDR_KRDD. */
#define BM_KPP_KDDR_KRDD     (0x00FFU)     /*!< Bit mask for KPP_KDDR_KRDD. */
#define BS_KPP_KDDR_KRDD     (8U)          /*!< Bit field size in bits for KPP_KDDR_KRDD. */

#define BV_KPP_KDDR_KRDD_INPUT         (0U)          /*!< Bit field value for KPP_KDDR_KRDD: ROWn pin configured as an input. */
#define BV_KPP_KDDR_KRDD_OUTPUT        (0x1U)        /*!< Bit field value for KPP_KDDR_KRDD: ROWn pin configured as an output. */

/*! @brief Read current value of the KPP_KDDR_KRDD field. */
#define BR_KPP_KDDR_KRDD(x)  (HW_KPP_KDDR(x).B.KRDD)

/*! @brief Format value for bitfield KPP_KDDR_KRDD. */
#define BF_KPP_KDDR_KRDD(v)  ((uint16_t)((uint16_t)(v) << BP_KPP_KDDR_KRDD) & BM_KPP_KDDR_KRDD)

/*! @brief Set the KRDD field to a new value. */
#define BW_KPP_KDDR_KRDD(x, v) (HW_KPP_KDDR_WR(x, (HW_KPP_KDDR_RD(x) & ~BM_KPP_KDDR_KRDD) | BF_KPP_KDDR_KRDD(v)))
/*@}*/

/*!
 * @name Register KPP_KDDR, field KCDD[15:8] (RW)
 *
 * Keypad Column Data Direction Register. Setting a bit configures the
 * corresponding COLn pin as an output (where n = 7 through 0).
 *
 * Values:
 * - 0 - COLn pin is configured as an input.
 * - 1 - COLn pin is configured as an output.
 */
/*@{*/
#define BP_KPP_KDDR_KCDD     (8U)          /*!< Bit position for KPP_KDDR_KCDD. */
#define BM_KPP_KDDR_KCDD     (0xFF00U)     /*!< Bit mask for KPP_KDDR_KCDD. */
#define BS_KPP_KDDR_KCDD     (8U)          /*!< Bit field size in bits for KPP_KDDR_KCDD. */

#define BV_KPP_KDDR_KCDD_INPUT         (0U)          /*!< Bit field value for KPP_KDDR_KCDD: COLn pin is configured as an input. */
#define BV_KPP_KDDR_KCDD_OUTPUT        (0x1U)        /*!< Bit field value for KPP_KDDR_KCDD: COLn pin is configured as an output. */

/*! @brief Read current value of the KPP_KDDR_KCDD field. */
#define BR_KPP_KDDR_KCDD(x)  (HW_KPP_KDDR(x).B.KCDD)

/*! @brief Format value for bitfield KPP_KDDR_KCDD. */
#define BF_KPP_KDDR_KCDD(v)  ((uint16_t)((uint16_t)(v) << BP_KPP_KDDR_KCDD) & BM_KPP_KDDR_KCDD)

/*! @brief Set the KCDD field to a new value. */
#define BW_KPP_KDDR_KCDD(x, v) (HW_KPP_KDDR_WR(x, (HW_KPP_KDDR_RD(x) & ~BM_KPP_KDDR_KCDD) | BF_KPP_KDDR_KCDD(v)))
/*@}*/

/*******************************************************************************
 * HW_KPP_KPDR - Keypad Data Register
 ******************************************************************************/

/*!
 * @brief HW_KPP_KPDR - Keypad Data Register (RW)
 *
 * Reset value: 0x0000U
 *
 * This 16-bit register is used to access the column and row data. Data written
 * to this register is stored in an internal latch, and for each pin configured
 * as an output, the stored data is driven onto the pin. A read of this register
 * returns the value on the pin for those bits configured as inputs. Otherwise,
 * the value read is the value stored in the register. The KPP_KPDR register is
 * byte- or half-word addressable. This register is not initialized by a reset.
 * Valid data should be written to this register before any bits are configured as
 * outputs.
 */
typedef union _hw_kpp_kpdr
{
    uint16_t U;
    struct _hw_kpp_kpdr_bitfields
    {
        uint16_t KRD : 8;              /*!< [7:0]  */
        uint16_t KCD : 8;              /*!< [15:8]  */
    } B;
} hw_kpp_kpdr_t;

/*!
 * @name Constants and macros for entire KPP_KPDR register
 */
/*@{*/
#define HW_KPP_KPDR_ADDR(x)      ((uintptr_t)(x) + 0x6U)

#define HW_KPP_KPDR(x)           (*(__IO hw_kpp_kpdr_t *) HW_KPP_KPDR_ADDR(x))
#define HW_KPP_KPDR_RD(x)        (HW_KPP_KPDR(x).U)
#define HW_KPP_KPDR_WR(x, v)     (HW_KPP_KPDR(x).U = (v))
#define HW_KPP_KPDR_SET(x, v)    (HW_KPP_KPDR_WR(x, HW_KPP_KPDR_RD(x) |  (v)))
#define HW_KPP_KPDR_CLR(x, v)    (HW_KPP_KPDR_WR(x, HW_KPP_KPDR_RD(x) & ~(v)))
#define HW_KPP_KPDR_TOG(x, v)    (HW_KPP_KPDR_WR(x, HW_KPP_KPDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual KPP_KPDR bitfields
 */

/*!
 * @name Register KPP_KPDR, field KRD[7:0] (RW)
 *
 * Keypad Row Data. A read of these bits returns the value on the pin for those
 * bits configured as inputs. Otherwise, the value read is the value stored in
 * the register. 0 Read/Write "0" from/to row ports 1 Read/Write "1" from/to row
 * ports
 */
/*@{*/
#define BP_KPP_KPDR_KRD      (0U)          /*!< Bit position for KPP_KPDR_KRD. */
#define BM_KPP_KPDR_KRD      (0x00FFU)     /*!< Bit mask for KPP_KPDR_KRD. */
#define BS_KPP_KPDR_KRD      (8U)          /*!< Bit field size in bits for KPP_KPDR_KRD. */

/*! @brief Read current value of the KPP_KPDR_KRD field. */
#define BR_KPP_KPDR_KRD(x)   (HW_KPP_KPDR(x).B.KRD)

/*! @brief Format value for bitfield KPP_KPDR_KRD. */
#define BF_KPP_KPDR_KRD(v)   ((uint16_t)((uint16_t)(v) << BP_KPP_KPDR_KRD) & BM_KPP_KPDR_KRD)

/*! @brief Set the KRD field to a new value. */
#define BW_KPP_KPDR_KRD(x, v) (HW_KPP_KPDR_WR(x, (HW_KPP_KPDR_RD(x) & ~BM_KPP_KPDR_KRD) | BF_KPP_KPDR_KRD(v)))
/*@}*/

/*!
 * @name Register KPP_KPDR, field KCD[15:8] (RW)
 *
 * Keypad Column Data. A read of these bits returns the value on the pin for
 * those bits configured as inputs. Otherwise, the value read is the value stored in
 * the register. 0 Read/Write "0" from/to column ports 1 Read/Write "1" from/to
 * column ports
 */
/*@{*/
#define BP_KPP_KPDR_KCD      (8U)          /*!< Bit position for KPP_KPDR_KCD. */
#define BM_KPP_KPDR_KCD      (0xFF00U)     /*!< Bit mask for KPP_KPDR_KCD. */
#define BS_KPP_KPDR_KCD      (8U)          /*!< Bit field size in bits for KPP_KPDR_KCD. */

/*! @brief Read current value of the KPP_KPDR_KCD field. */
#define BR_KPP_KPDR_KCD(x)   (HW_KPP_KPDR(x).B.KCD)

/*! @brief Format value for bitfield KPP_KPDR_KCD. */
#define BF_KPP_KPDR_KCD(v)   ((uint16_t)((uint16_t)(v) << BP_KPP_KPDR_KCD) & BM_KPP_KPDR_KCD)

/*! @brief Set the KCD field to a new value. */
#define BW_KPP_KPDR_KCD(x, v) (HW_KPP_KPDR_WR(x, (HW_KPP_KPDR_RD(x) & ~BM_KPP_KPDR_KCD) | BF_KPP_KPDR_KCD(v)))
/*@}*/

/*******************************************************************************
 * hw_kpp_t - module struct
 ******************************************************************************/
/*!
 * @brief All KPP module registers.
 */
#pragma pack(1)
typedef struct _hw_kpp
{
    __IO hw_kpp_kpcr_t KPCR;               /*!< [0x0] Keypad Control Register */
    __IO hw_kpp_kpsr_t KPSR;               /*!< [0x2] Keypad Status Register */
    __IO hw_kpp_kddr_t KDDR;               /*!< [0x4] Keypad Data Direction Register */
    __IO hw_kpp_kpdr_t KPDR;               /*!< [0x6] Keypad Data Register */
} hw_kpp_t;
#pragma pack()

/*! @brief Macro to access all KPP registers. */
/*! @param x KPP module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_KPP_REGS(KPP_BASE)</code>. */
#define HW_KPP_REGS(x) (*(hw_kpp_t *)(x))

/*
 * iMX7D LCDIF
 *
 * eLCDIF Register Reference Index
 *
 * Registers defined in this header file:
 * - HW_LCDIF_RL - eLCDIF General Control Register
 * - HW_LCDIF_CTRL1 - eLCDIF General Control1 Register
 * - HW_LCDIF_CTRL2 - eLCDIF General Control2 Register
 * - HW_LCDIF_TRANSFER_COUNT - eLCDIF Horizontal and Vertical Valid Data Count Register
 * - HW_LCDIF_CUR_BUF - LCD Interface Current Buffer Address Register
 * - HW_LCDIF_NEXT_BUF - LCD Interface Next Buffer Address Register
 * - HW_LCDIF_TIMING - LCD Interface Timing Register
 * - HW_LCDIF_VDCTRL0 - eLCDIF VSYNC Mode and Dotclk Mode Control Register0
 * - HW_LCDIF_VDCTRL1 - eLCDIF VSYNC Mode and Dotclk Mode Control Register1
 * - HW_LCDIF_VDCTRL2 - LCDIF VSYNC Mode and Dotclk Mode Control Register2
 * - HW_LCDIF_VDCTRL3 - eLCDIF VSYNC Mode and Dotclk Mode Control Register3
 * - HW_LCDIF_VDCTRL4 - eLCDIF VSYNC Mode and Dotclk Mode Control Register4
 * - HW_LCDIF_DVICTRL0 - Digital Video Interface Control0 Register
 * - HW_LCDIF_DVICTRL1 - Digital Video Interface Control1 Register
 * - HW_LCDIF_DVICTRL2 - Digital Video Interface Control2 Register
 * - HW_LCDIF_DVICTRL3 - Digital Video Interface Control3 Register
 * - HW_LCDIF_DVICTRL4 - Digital Video Interface Control4 Register
 * - HW_LCDIF_CSC_COEFF0 - RGB to YCbCr 4:2:2 CSC Coefficient0 Register
 * - HW_LCDIF_CSC_COEFF1 - RGB to YCbCr 4:2:2 CSC Coefficient1 Register
 * - HW_LCDIF_CSC_COEFF2 - RGB to YCbCr 4:2:2 CSC Coefficent2 Register
 * - HW_LCDIF_CSC_COEFF3 - RGB to YCbCr 4:2:2 CSC Coefficient3 Register
 * - HW_LCDIF_CSC_COEFF4 - RGB to YCbCr 4:2:2 CSC Coefficient4 Register
 * - HW_LCDIF_CSC_OFFSET - RGB to YCbCr 4:2:2 CSC Offset Register
 * - HW_LCDIF_CSC_LIMIT - RGB to YCbCr 4:2:2 CSC Limit Register
 * - HW_LCDIF_DATA - LCD Interface Data Register
 * - HW_LCDIF_BM_ERROR_STAT - Bus Master Error Status Register
 * - HW_LCDIF_CRC_STAT - CRC Status Register
 * - HW_LCDIF_STAT - LCD Interface Status Register
 * - HW_LCDIF_VERSION - LCD Interface Version Register
 * - HW_LCDIF_DEBUG0 - LCD Interface Debug0 Register
 * - HW_LCDIF_DEBUG1 - LCD Interface Debug1 Register
 * - HW_LCDIF_DEBUG2 - LCD Interface Debug2 Register
 * - HW_LCDIF_THRES - eLCDIF Threshold Register
 * - HW_LCDIF_AS_CTRL - eLCDIF AS Buffer Control Register
 * - HW_LCDIF_AS_BUF - Alpha Surface Buffer Pointer
 * - HW_LCDIF_AS_NEXT_BUF -
 * - HW_LCDIF_AS_CLRKEYLOW - eLCDIF Overlay Color Key Low
 * - HW_LCDIF_AS_CLRKEYHIGH - eLCDIF Overlay Color Key High
 * - HW_LCDIF_SYNC_DELAY - LCD working insync mode with CSI for VSYNC delay
 * - HW_LCDIF_DEBUG3 - eLCDIF Interface Debug3 Register
 * - HW_LCDIF_DEBUG4 - LCD Interface Debug4
 * - HW_LCDIF_DEBUG5 - LCD Interface Debug5
 *
 * - hw_lcdif_t - Struct containing all module registers.
 */

#define HW_LCDIF_INSTANCE_COUNT (2U) /*!< Number of instances of the LCDIF module. */
#define HW_LCDIF1 (0U) /*!< Instance number for LCDIF1. */
#define HW_LCDIF2 (1U) /*!< Instance number for LCDIF2. */
#define LCDIF1_BASE           (0x30730000U) /*!< Base address for LCDIF1. */
#define LCDIF2_BASE           (0x30734000U) /*!< Base address for LCDIF2. */
/*! Array initializer of LCDIF base addresses. */
#define LCDIF_BASE_ADDRS      { LCDIF1_BASE, LCDIF2_BASE }

/*******************************************************************************
 * HW_LCDIF_RL - eLCDIF General Control Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_RL - eLCDIF General Control Register (RW)
 *
 * Reset value: 0xC0000000U
 *
 * The LCD Interface Control Register provides overall control of the eLCDIF
 * block. The eLCDIF Control Register provides a variety of control functions to the
 * programmer. These functions allow the interface to be very flexible to work
 * with a variety of LCD controllers, and to minimize overhead and increase
 * performance of LCD programming. The register has been organized such that switching
 * between the different LCD modes can be done with minimum PIO writes.
 */
typedef union _hw_lcdif_rl
{
    uint32_t U;
    struct _hw_lcdif_rl_bitfields
    {
        uint32_t RUN : 1;              /*!< [0]  */
        uint32_t DATA_FORMAT_24_BIT : 1; /*!< [1]  */
        uint32_t DATA_FORMAT_18_BIT : 1; /*!< [2]  */
        uint32_t DATA_FORMAT_16_BIT : 1; /*!< [3]  */
        uint32_t RSRVD0 : 1;           /*!< [4]  */
        uint32_t MASTER : 1;           /*!< [5]  */
        uint32_t ENABLE_PXP_HANDSHAKE : 1; /*!< [6]  */
        uint32_t RGB_TO_YCBCR422_CSC : 1; /*!< [7]  */
        uint32_t WORD_LENGTH : 2;      /*!< [9:8]  */
        uint32_t LCD_DATABUS_WIDTH : 2; /*!< [11:10]  */
        uint32_t CSC_DATA_SWIZZLE : 2; /*!< [13:12]  */
        uint32_t INPUT_DATA_SWIZZLE : 2; /*!< [15:14]  */
        uint32_t DATA_SELECT : 1;      /*!< [16]  */
        uint32_t DOTCLK_MODE : 1;      /*!< [17]  */
        uint32_t VSYNC_MODE : 1;       /*!< [18]  */
        uint32_t BYPASS_COUNT : 1;     /*!< [19]  */
        uint32_t DVI_MODE : 1;         /*!< [20]  */
        uint32_t SHIFT_NUM_BITS : 5;   /*!< [25:21]  */
        uint32_t DATA_SHIFT_DIR : 1;   /*!< [26]  */
        uint32_t WAIT_FOR_VSYNC_EDGE : 1; /*!< [27]  */
        uint32_t READ_WRITEB : 1;      /*!< [28]  */
        uint32_t YCBCR422_INPUT : 1;   /*!< [29]  */
        uint32_t CLKGATE : 1;          /*!< [30]  */
        uint32_t SFTRST : 1;           /*!< [31]  */
    } B;
} hw_lcdif_rl_t;

/*!
 * @name Constants and macros for entire LCDIF_RL register
 */
/*@{*/
#define HW_LCDIF_RL_ADDR(x)      ((uintptr_t)(x) + 0x0U)
#define HW_LCDIF_RL_SET_ADDR(x)  (HW_LCDIF_RL_ADDR(x) + 0x4U)
#define HW_LCDIF_RL_CLR_ADDR(x)  (HW_LCDIF_RL_ADDR(x) + 0x8U)
#define HW_LCDIF_RL_TOG_ADDR(x)  (HW_LCDIF_RL_ADDR(x) + 0xCU)

#define HW_LCDIF_RL(x)           (*(__IO hw_lcdif_rl_t *) HW_LCDIF_RL_ADDR(x))
#define HW_LCDIF_RL_RD(x)        (HW_LCDIF_RL(x).U)
#define HW_LCDIF_RL_WR(x, v)     (HW_LCDIF_RL(x).U = (v))
#define HW_LCDIF_RL_SET(x, v)    ((*(uint32_t *) HW_LCDIF_RL_SET_ADDR(x)) = (v))
#define HW_LCDIF_RL_CLR(x, v)    ((*(uint32_t *) HW_LCDIF_RL_CLR_ADDR(x)) = (v))
#define HW_LCDIF_RL_TOG(x, v)    ((*(uint32_t *) HW_LCDIF_RL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual LCDIF_RL bitfields
 */

/*!
 * @name Register LCDIF_RL, field RUN[0] (RW)
 *
 * When this bit is set by software, the eLCDIF will begin transferring data
 * between the SoC and the display. This bit must remain set until the operation is
 * complete.
 */
/*@{*/
#define BP_LCDIF_RL_RUN      (0U)          /*!< Bit position for LCDIF_RL_RUN. */
#define BM_LCDIF_RL_RUN      (0x00000001U) /*!< Bit mask for LCDIF_RL_RUN. */
#define BS_LCDIF_RL_RUN      (1U)          /*!< Bit field size in bits for LCDIF_RL_RUN. */

/*! @brief Read current value of the LCDIF_RL_RUN field. */
#define BR_LCDIF_RL_RUN(x)   (HW_LCDIF_RL(x).B.RUN)

/*! @brief Format value for bitfield LCDIF_RL_RUN. */
#define BF_LCDIF_RL_RUN(v)   ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_RUN) & BM_LCDIF_RL_RUN)

/*! @brief Set the RUN field to a new value. */
#define BW_LCDIF_RL_RUN(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_RUN) | BF_LCDIF_RL_RUN(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field DATA_FORMAT_24_BIT[1] (RW)
 *
 * Used only when WORD_LENGTH = 3, i.e. 24-bit. Note that this applies to both
 * packed and unpacked 24-bit data.
 *
 * Values:
 * - 0 - Data input to the block is in 24 bpp format, such that all RGB 888 data
 *     is contained in 24 bits.
 * - 1 - Data input to the block is actually RGB 18 bpp, but there is 1 color
 *     per byte, hence the upper 2 bits in each byte do not contain any useful
 *     data, and should be dropped.
 */
/*@{*/
#define BP_LCDIF_RL_DATA_FORMAT_24_BIT (1U) /*!< Bit position for LCDIF_RL_DATA_FORMAT_24_BIT. */
#define BM_LCDIF_RL_DATA_FORMAT_24_BIT (0x00000002U) /*!< Bit mask for LCDIF_RL_DATA_FORMAT_24_BIT. */
#define BS_LCDIF_RL_DATA_FORMAT_24_BIT (1U) /*!< Bit field size in bits for LCDIF_RL_DATA_FORMAT_24_BIT. */

#define BV_LCDIF_RL_DATA_FORMAT_24_BIT_ALL_24_BITS_VALID (0U) /*!< Bit field value for LCDIF_RL_DATA_FORMAT_24_BIT: Data input to the block is in 24 bpp format, such that all RGB 888 data is contained in 24 bits. */
#define BV_LCDIF_RL_DATA_FORMAT_24_BIT_DROP_UPPER_2_BITS_PER_BYTE (0x1U) /*!< Bit field value for LCDIF_RL_DATA_FORMAT_24_BIT: Data input to the block is actually RGB 18 bpp, but there is 1 color per byte, hence the upper 2 bits in each byte do not contain any useful data, and should be dropped. */

/*! @brief Read current value of the LCDIF_RL_DATA_FORMAT_24_BIT field. */
#define BR_LCDIF_RL_DATA_FORMAT_24_BIT(x) (HW_LCDIF_RL(x).B.DATA_FORMAT_24_BIT)

/*! @brief Format value for bitfield LCDIF_RL_DATA_FORMAT_24_BIT. */
#define BF_LCDIF_RL_DATA_FORMAT_24_BIT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_DATA_FORMAT_24_BIT) & BM_LCDIF_RL_DATA_FORMAT_24_BIT)

/*! @brief Set the DATA_FORMAT_24_BIT field to a new value. */
#define BW_LCDIF_RL_DATA_FORMAT_24_BIT(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_DATA_FORMAT_24_BIT) | BF_LCDIF_RL_DATA_FORMAT_24_BIT(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field DATA_FORMAT_18_BIT[2] (RW)
 *
 * Used only when WORD_LENGTH = 2, i.e. 18-bit.
 *
 * Values:
 * - 0 - Data input to the block is in 18 bpp format, such that lower 18 bits
 *     contain RGB 666 and upper 14 bits do not contain any useful data.
 * - 1 - Data input to the block is in 18 bpp format, such that upper 18 bits
 *     contain RGB 666 and lower 14 bits do not contain any useful data.
 */
/*@{*/
#define BP_LCDIF_RL_DATA_FORMAT_18_BIT (2U) /*!< Bit position for LCDIF_RL_DATA_FORMAT_18_BIT. */
#define BM_LCDIF_RL_DATA_FORMAT_18_BIT (0x00000004U) /*!< Bit mask for LCDIF_RL_DATA_FORMAT_18_BIT. */
#define BS_LCDIF_RL_DATA_FORMAT_18_BIT (1U) /*!< Bit field size in bits for LCDIF_RL_DATA_FORMAT_18_BIT. */

#define BV_LCDIF_RL_DATA_FORMAT_18_BIT_LOWER_18_BITS_VALID (0U) /*!< Bit field value for LCDIF_RL_DATA_FORMAT_18_BIT: Data input to the block is in 18 bpp format, such that lower 18 bits contain RGB 666 and upper 14 bits do not contain any useful data. */
#define BV_LCDIF_RL_DATA_FORMAT_18_BIT_UPPER_18_BITS_VALID (0x1U) /*!< Bit field value for LCDIF_RL_DATA_FORMAT_18_BIT: Data input to the block is in 18 bpp format, such that upper 18 bits contain RGB 666 and lower 14 bits do not contain any useful data. */

/*! @brief Read current value of the LCDIF_RL_DATA_FORMAT_18_BIT field. */
#define BR_LCDIF_RL_DATA_FORMAT_18_BIT(x) (HW_LCDIF_RL(x).B.DATA_FORMAT_18_BIT)

/*! @brief Format value for bitfield LCDIF_RL_DATA_FORMAT_18_BIT. */
#define BF_LCDIF_RL_DATA_FORMAT_18_BIT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_DATA_FORMAT_18_BIT) & BM_LCDIF_RL_DATA_FORMAT_18_BIT)

/*! @brief Set the DATA_FORMAT_18_BIT field to a new value. */
#define BW_LCDIF_RL_DATA_FORMAT_18_BIT(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_DATA_FORMAT_18_BIT) | BF_LCDIF_RL_DATA_FORMAT_18_BIT(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field DATA_FORMAT_16_BIT[3] (RW)
 *
 * When this bit is 1 and WORD_LENGTH = 0, it implies that the 16-bit data is in
 * ARGB555 format. When this bit is 0 and WORD_LENGTH = 0, it implies that the
 * 16-bit data is in RGB565 format. When WORD_LENGTH is not 0, this bit does not
 * care.
 */
/*@{*/
#define BP_LCDIF_RL_DATA_FORMAT_16_BIT (3U) /*!< Bit position for LCDIF_RL_DATA_FORMAT_16_BIT. */
#define BM_LCDIF_RL_DATA_FORMAT_16_BIT (0x00000008U) /*!< Bit mask for LCDIF_RL_DATA_FORMAT_16_BIT. */
#define BS_LCDIF_RL_DATA_FORMAT_16_BIT (1U) /*!< Bit field size in bits for LCDIF_RL_DATA_FORMAT_16_BIT. */

/*! @brief Read current value of the LCDIF_RL_DATA_FORMAT_16_BIT field. */
#define BR_LCDIF_RL_DATA_FORMAT_16_BIT(x) (HW_LCDIF_RL(x).B.DATA_FORMAT_16_BIT)

/*! @brief Format value for bitfield LCDIF_RL_DATA_FORMAT_16_BIT. */
#define BF_LCDIF_RL_DATA_FORMAT_16_BIT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_DATA_FORMAT_16_BIT) & BM_LCDIF_RL_DATA_FORMAT_16_BIT)

/*! @brief Set the DATA_FORMAT_16_BIT field to a new value. */
#define BW_LCDIF_RL_DATA_FORMAT_16_BIT(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_DATA_FORMAT_16_BIT) | BF_LCDIF_RL_DATA_FORMAT_16_BIT(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field RSRVD0[4] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_RL_RSRVD0   (4U)          /*!< Bit position for LCDIF_RL_RSRVD0. */
#define BM_LCDIF_RL_RSRVD0   (0x00000010U) /*!< Bit mask for LCDIF_RL_RSRVD0. */
#define BS_LCDIF_RL_RSRVD0   (1U)          /*!< Bit field size in bits for LCDIF_RL_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_RL, field MASTER[5] (RW)
 *
 * Set this bit to make the eLCDIF act as a bus master. If this bit is reset,
 * the eLCDIF will support or PIO mode.
 */
/*@{*/
#define BP_LCDIF_RL_MASTER   (5U)          /*!< Bit position for LCDIF_RL_MASTER. */
#define BM_LCDIF_RL_MASTER   (0x00000020U) /*!< Bit mask for LCDIF_RL_MASTER. */
#define BS_LCDIF_RL_MASTER   (1U)          /*!< Bit field size in bits for LCDIF_RL_MASTER. */

/*! @brief Read current value of the LCDIF_RL_MASTER field. */
#define BR_LCDIF_RL_MASTER(x) (HW_LCDIF_RL(x).B.MASTER)

/*! @brief Format value for bitfield LCDIF_RL_MASTER. */
#define BF_LCDIF_RL_MASTER(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_MASTER) & BM_LCDIF_RL_MASTER)

/*! @brief Set the MASTER field to a new value. */
#define BW_LCDIF_RL_MASTER(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_MASTER) | BF_LCDIF_RL_MASTER(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field ENABLE_PXP_HANDSHAKE[6] (RW)
 *
 * If this bit is set and LCDIF_MASTER bit is set, the eLCDIF will act as bus
 * master and the handshake mechanism between eLCDIF and PXP will be turned on. If
 * LCDIF_MASTER bit is not set, this bit becomes a don't care.
 */
/*@{*/
#define BP_LCDIF_RL_ENABLE_PXP_HANDSHAKE (6U) /*!< Bit position for LCDIF_RL_ENABLE_PXP_HANDSHAKE. */
#define BM_LCDIF_RL_ENABLE_PXP_HANDSHAKE (0x00000040U) /*!< Bit mask for LCDIF_RL_ENABLE_PXP_HANDSHAKE. */
#define BS_LCDIF_RL_ENABLE_PXP_HANDSHAKE (1U) /*!< Bit field size in bits for LCDIF_RL_ENABLE_PXP_HANDSHAKE. */

/*! @brief Read current value of the LCDIF_RL_ENABLE_PXP_HANDSHAKE field. */
#define BR_LCDIF_RL_ENABLE_PXP_HANDSHAKE(x) (HW_LCDIF_RL(x).B.ENABLE_PXP_HANDSHAKE)

/*! @brief Format value for bitfield LCDIF_RL_ENABLE_PXP_HANDSHAKE. */
#define BF_LCDIF_RL_ENABLE_PXP_HANDSHAKE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_ENABLE_PXP_HANDSHAKE) & BM_LCDIF_RL_ENABLE_PXP_HANDSHAKE)

/*! @brief Set the ENABLE_PXP_HANDSHAKE field to a new value. */
#define BW_LCDIF_RL_ENABLE_PXP_HANDSHAKE(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_ENABLE_PXP_HANDSHAKE) | BF_LCDIF_RL_ENABLE_PXP_HANDSHAKE(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field RGB_TO_YCBCR422_CSC[7] (RW)
 *
 * Set this bit to 1 to enable conversion from RGB to YCbCr colorspace. See the
 * LCDIF_CSC_ registers for further details.
 */
/*@{*/
#define BP_LCDIF_RL_RGB_TO_YCBCR422_CSC (7U) /*!< Bit position for LCDIF_RL_RGB_TO_YCBCR422_CSC. */
#define BM_LCDIF_RL_RGB_TO_YCBCR422_CSC (0x00000080U) /*!< Bit mask for LCDIF_RL_RGB_TO_YCBCR422_CSC. */
#define BS_LCDIF_RL_RGB_TO_YCBCR422_CSC (1U) /*!< Bit field size in bits for LCDIF_RL_RGB_TO_YCBCR422_CSC. */

/*! @brief Read current value of the LCDIF_RL_RGB_TO_YCBCR422_CSC field. */
#define BR_LCDIF_RL_RGB_TO_YCBCR422_CSC(x) (HW_LCDIF_RL(x).B.RGB_TO_YCBCR422_CSC)

/*! @brief Format value for bitfield LCDIF_RL_RGB_TO_YCBCR422_CSC. */
#define BF_LCDIF_RL_RGB_TO_YCBCR422_CSC(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_RGB_TO_YCBCR422_CSC) & BM_LCDIF_RL_RGB_TO_YCBCR422_CSC)

/*! @brief Set the RGB_TO_YCBCR422_CSC field to a new value. */
#define BW_LCDIF_RL_RGB_TO_YCBCR422_CSC(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_RGB_TO_YCBCR422_CSC) | BF_LCDIF_RL_RGB_TO_YCBCR422_CSC(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field WORD_LENGTH[9:8] (RW)
 *
 * Input data format.
 *
 * Values:
 * - 0 - Input data is 16 bits per pixel.
 * - 1 - Input data is 8 bits wide.
 * - 10 - Input data is 18 bits per pixel.
 * - 11 - Input data is 24 bits per pixel.
 */
/*@{*/
#define BP_LCDIF_RL_WORD_LENGTH (8U)       /*!< Bit position for LCDIF_RL_WORD_LENGTH. */
#define BM_LCDIF_RL_WORD_LENGTH (0x00000300U) /*!< Bit mask for LCDIF_RL_WORD_LENGTH. */
#define BS_LCDIF_RL_WORD_LENGTH (2U)       /*!< Bit field size in bits for LCDIF_RL_WORD_LENGTH. */

#define BV_LCDIF_RL_WORD_LENGTH_16_BIT (0U)          /*!< Bit field value for LCDIF_RL_WORD_LENGTH: Input data is 16 bits per pixel. */
#define BV_LCDIF_RL_WORD_LENGTH_8_BIT  (0x1U)        /*!< Bit field value for LCDIF_RL_WORD_LENGTH: Input data is 8 bits wide. */
#define BV_LCDIF_RL_WORD_LENGTH_18_BIT (0x2U)        /*!< Bit field value for LCDIF_RL_WORD_LENGTH: Input data is 18 bits per pixel. */
#define BV_LCDIF_RL_WORD_LENGTH_24_BIT (0x3U)        /*!< Bit field value for LCDIF_RL_WORD_LENGTH: Input data is 24 bits per pixel. */

/*! @brief Read current value of the LCDIF_RL_WORD_LENGTH field. */
#define BR_LCDIF_RL_WORD_LENGTH(x) (HW_LCDIF_RL(x).B.WORD_LENGTH)

/*! @brief Format value for bitfield LCDIF_RL_WORD_LENGTH. */
#define BF_LCDIF_RL_WORD_LENGTH(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_WORD_LENGTH) & BM_LCDIF_RL_WORD_LENGTH)

/*! @brief Set the WORD_LENGTH field to a new value. */
#define BW_LCDIF_RL_WORD_LENGTH(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_WORD_LENGTH) | BF_LCDIF_RL_WORD_LENGTH(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field LCD_DATABUS_WIDTH[11:10] (RW)
 *
 * LCD Data bus transfer width.
 *
 * Values:
 * - 0 - 16-bit data bus mode.
 * - 1 - 8-bit data bus mode.
 * - 10 - 18-bit data bus mode.
 * - 11 - 24-bit data bus mode.
 */
/*@{*/
#define BP_LCDIF_RL_LCD_DATABUS_WIDTH (10U) /*!< Bit position for LCDIF_RL_LCD_DATABUS_WIDTH. */
#define BM_LCDIF_RL_LCD_DATABUS_WIDTH (0x00000C00U) /*!< Bit mask for LCDIF_RL_LCD_DATABUS_WIDTH. */
#define BS_LCDIF_RL_LCD_DATABUS_WIDTH (2U) /*!< Bit field size in bits for LCDIF_RL_LCD_DATABUS_WIDTH. */

#define BV_LCDIF_RL_LCD_DATABUS_WIDTH_16_BIT (0U)    /*!< Bit field value for LCDIF_RL_LCD_DATABUS_WIDTH: 16-bit data bus mode. */
#define BV_LCDIF_RL_LCD_DATABUS_WIDTH_8_BIT (0x1U)   /*!< Bit field value for LCDIF_RL_LCD_DATABUS_WIDTH: 8-bit data bus mode. */
#define BV_LCDIF_RL_LCD_DATABUS_WIDTH_18_BIT (0x2U)  /*!< Bit field value for LCDIF_RL_LCD_DATABUS_WIDTH: 18-bit data bus mode. */
#define BV_LCDIF_RL_LCD_DATABUS_WIDTH_24_BIT (0x3U)  /*!< Bit field value for LCDIF_RL_LCD_DATABUS_WIDTH: 24-bit data bus mode. */

/*! @brief Read current value of the LCDIF_RL_LCD_DATABUS_WIDTH field. */
#define BR_LCDIF_RL_LCD_DATABUS_WIDTH(x) (HW_LCDIF_RL(x).B.LCD_DATABUS_WIDTH)

/*! @brief Format value for bitfield LCDIF_RL_LCD_DATABUS_WIDTH. */
#define BF_LCDIF_RL_LCD_DATABUS_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_LCD_DATABUS_WIDTH) & BM_LCDIF_RL_LCD_DATABUS_WIDTH)

/*! @brief Set the LCD_DATABUS_WIDTH field to a new value. */
#define BW_LCDIF_RL_LCD_DATABUS_WIDTH(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_LCD_DATABUS_WIDTH) | BF_LCDIF_RL_LCD_DATABUS_WIDTH(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field CSC_DATA_SWIZZLE[13:12] (RW)
 *
 * This field specifies how to swap the bytes after the data has been converted
 * into an internal representation of 24 bits per pixel and before it is
 * transmitted over the LCD interface bus. The data is always transmitted with the least
 * significant byte/hword (half word) first after the swizzle takes place. So,
 * INPUT_DATA_SWIZZLE takes place first on the incoming data, and then
 * CSC_DATA_SWIZZLE is applied. The swizzle function is independent of the WORD_LENGTH or the
 * LCD_DATABUS_WIDTH fields. If RGB_TO_YCRCB422_CSC bit is set, the swizzle
 * occurs on the Y, Cb, Cr values. The supported swizzle configurations are:
 *
 * Values:
 * - 0 - No byte swapping.(Little endian)
 * - 0 - Little Endian byte ordering (same as NO_SWAP).
 * - 1 - Big Endian swap (swap bytes 0,3 and 1,2).
 * - 1 - Swizzle all bytes, swap bytes 0,3 and 1,2 (aka Big Endian).
 * - 10 - Swap half-words.
 * - 11 - Swap bytes within each half-word.
 */
/*@{*/
#define BP_LCDIF_RL_CSC_DATA_SWIZZLE (12U) /*!< Bit position for LCDIF_RL_CSC_DATA_SWIZZLE. */
#define BM_LCDIF_RL_CSC_DATA_SWIZZLE (0x00003000U) /*!< Bit mask for LCDIF_RL_CSC_DATA_SWIZZLE. */
#define BS_LCDIF_RL_CSC_DATA_SWIZZLE (2U)  /*!< Bit field size in bits for LCDIF_RL_CSC_DATA_SWIZZLE. */

#define BV_LCDIF_RL_CSC_DATA_SWIZZLE_NO_SWAP (0U)    /*!< Bit field value for LCDIF_RL_CSC_DATA_SWIZZLE: No byte swapping.(Little endian) */
#define BV_LCDIF_RL_CSC_DATA_SWIZZLE_LITTLE_ENDIAN (0U) /*!< Bit field value for LCDIF_RL_CSC_DATA_SWIZZLE: Little Endian byte ordering (same as NO_SWAP). */
#define BV_LCDIF_RL_CSC_DATA_SWIZZLE_BIG_ENDIAN_SWAP (0x1U) /*!< Bit field value for LCDIF_RL_CSC_DATA_SWIZZLE: Big Endian swap (swap bytes 0,3 and 1,2). */
#define BV_LCDIF_RL_CSC_DATA_SWIZZLE_SWAP_ALL_BYTES (0x1U) /*!< Bit field value for LCDIF_RL_CSC_DATA_SWIZZLE: Swizzle all bytes, swap bytes 0,3 and 1,2 (aka Big Endian). */
#define BV_LCDIF_RL_CSC_DATA_SWIZZLE_HWD_SWAP (0x2U) /*!< Bit field value for LCDIF_RL_CSC_DATA_SWIZZLE: Swap half-words. */
#define BV_LCDIF_RL_CSC_DATA_SWIZZLE_HWD_BYTE_SWAP (0x3U) /*!< Bit field value for LCDIF_RL_CSC_DATA_SWIZZLE: Swap bytes within each half-word. */

/*! @brief Read current value of the LCDIF_RL_CSC_DATA_SWIZZLE field. */
#define BR_LCDIF_RL_CSC_DATA_SWIZZLE(x) (HW_LCDIF_RL(x).B.CSC_DATA_SWIZZLE)

/*! @brief Format value for bitfield LCDIF_RL_CSC_DATA_SWIZZLE. */
#define BF_LCDIF_RL_CSC_DATA_SWIZZLE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_CSC_DATA_SWIZZLE) & BM_LCDIF_RL_CSC_DATA_SWIZZLE)

/*! @brief Set the CSC_DATA_SWIZZLE field to a new value. */
#define BW_LCDIF_RL_CSC_DATA_SWIZZLE(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_CSC_DATA_SWIZZLE) | BF_LCDIF_RL_CSC_DATA_SWIZZLE(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field INPUT_DATA_SWIZZLE[15:14] (RW)
 *
 * This field specifies how to swap the bytes fetched by the bus master
 * interface. The swizzle function is independent of the WORD_LENGTH bit. The supported
 * swizzle configurations are:
 *
 * Values:
 * - 0 - No byte swapping.(Little endian)
 * - 0 - Little Endian byte ordering (same as NO_SWAP).
 * - 1 - Big Endian swap (swap bytes 0,3 and 1,2).
 * - 1 - Swizzle all bytes, swap bytes 0,3 and 1,2 (aka Big Endian).
 * - 10 - Swap half-words.
 * - 11 - Swap bytes within each half-word.
 */
/*@{*/
#define BP_LCDIF_RL_INPUT_DATA_SWIZZLE (14U) /*!< Bit position for LCDIF_RL_INPUT_DATA_SWIZZLE. */
#define BM_LCDIF_RL_INPUT_DATA_SWIZZLE (0x0000C000U) /*!< Bit mask for LCDIF_RL_INPUT_DATA_SWIZZLE. */
#define BS_LCDIF_RL_INPUT_DATA_SWIZZLE (2U) /*!< Bit field size in bits for LCDIF_RL_INPUT_DATA_SWIZZLE. */

#define BV_LCDIF_RL_INPUT_DATA_SWIZZLE_NO_SWAP (0U)  /*!< Bit field value for LCDIF_RL_INPUT_DATA_SWIZZLE: No byte swapping.(Little endian) */
#define BV_LCDIF_RL_INPUT_DATA_SWIZZLE_LITTLE_ENDIAN (0U) /*!< Bit field value for LCDIF_RL_INPUT_DATA_SWIZZLE: Little Endian byte ordering (same as NO_SWAP). */
#define BV_LCDIF_RL_INPUT_DATA_SWIZZLE_BIG_ENDIAN_SWAP (0x1U) /*!< Bit field value for LCDIF_RL_INPUT_DATA_SWIZZLE: Big Endian swap (swap bytes 0,3 and 1,2). */
#define BV_LCDIF_RL_INPUT_DATA_SWIZZLE_SWAP_ALL_BYTES (0x1U) /*!< Bit field value for LCDIF_RL_INPUT_DATA_SWIZZLE: Swizzle all bytes, swap bytes 0,3 and 1,2 (aka Big Endian). */
#define BV_LCDIF_RL_INPUT_DATA_SWIZZLE_HWD_SWAP (0x2U) /*!< Bit field value for LCDIF_RL_INPUT_DATA_SWIZZLE: Swap half-words. */
#define BV_LCDIF_RL_INPUT_DATA_SWIZZLE_HWD_BYTE_SWAP (0x3U) /*!< Bit field value for LCDIF_RL_INPUT_DATA_SWIZZLE: Swap bytes within each half-word. */

/*! @brief Read current value of the LCDIF_RL_INPUT_DATA_SWIZZLE field. */
#define BR_LCDIF_RL_INPUT_DATA_SWIZZLE(x) (HW_LCDIF_RL(x).B.INPUT_DATA_SWIZZLE)

/*! @brief Format value for bitfield LCDIF_RL_INPUT_DATA_SWIZZLE. */
#define BF_LCDIF_RL_INPUT_DATA_SWIZZLE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_INPUT_DATA_SWIZZLE) & BM_LCDIF_RL_INPUT_DATA_SWIZZLE)

/*! @brief Set the INPUT_DATA_SWIZZLE field to a new value. */
#define BW_LCDIF_RL_INPUT_DATA_SWIZZLE(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_INPUT_DATA_SWIZZLE) | BF_LCDIF_RL_INPUT_DATA_SWIZZLE(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field DATA_SELECT[16] (RW)
 *
 * Command Mode polarity bit. This bit should only be changed when RUN is 0.
 *
 * Values:
 * - 0 - Command Mode. DCn signal is Low.
 * - 1 - Data Mode. DCn signal is High.
 */
/*@{*/
#define BP_LCDIF_RL_DATA_SELECT (16U)      /*!< Bit position for LCDIF_RL_DATA_SELECT. */
#define BM_LCDIF_RL_DATA_SELECT (0x00010000U) /*!< Bit mask for LCDIF_RL_DATA_SELECT. */
#define BS_LCDIF_RL_DATA_SELECT (1U)       /*!< Bit field size in bits for LCDIF_RL_DATA_SELECT. */

#define BV_LCDIF_RL_DATA_SELECT_CMD_MODE (0U)        /*!< Bit field value for LCDIF_RL_DATA_SELECT: Command Mode. DCn signal is Low. */
#define BV_LCDIF_RL_DATA_SELECT_DATA_MODE (0x1U)     /*!< Bit field value for LCDIF_RL_DATA_SELECT: Data Mode. DCn signal is High. */

/*! @brief Read current value of the LCDIF_RL_DATA_SELECT field. */
#define BR_LCDIF_RL_DATA_SELECT(x) (HW_LCDIF_RL(x).B.DATA_SELECT)

/*! @brief Format value for bitfield LCDIF_RL_DATA_SELECT. */
#define BF_LCDIF_RL_DATA_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_DATA_SELECT) & BM_LCDIF_RL_DATA_SELECT)

/*! @brief Set the DATA_SELECT field to a new value. */
#define BW_LCDIF_RL_DATA_SELECT(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_DATA_SELECT) | BF_LCDIF_RL_DATA_SELECT(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field DOTCLK_MODE[17] (RW)
 *
 * Set this bit to 1 to make the hardware go into the DOTCLK mode, i.e.
 * VSYNC/HSYNC/DOTCLK/ENABLE interface mode. ENABLE is optional, selected by the
 * ENABLE_PRESENT bit. Toggle this bit from 1 to 0 to make the hardware go out of DOTCLK
 * mode after completing all data transfer and deasserting the RUN bit.
 */
/*@{*/
#define BP_LCDIF_RL_DOTCLK_MODE (17U)      /*!< Bit position for LCDIF_RL_DOTCLK_MODE. */
#define BM_LCDIF_RL_DOTCLK_MODE (0x00020000U) /*!< Bit mask for LCDIF_RL_DOTCLK_MODE. */
#define BS_LCDIF_RL_DOTCLK_MODE (1U)       /*!< Bit field size in bits for LCDIF_RL_DOTCLK_MODE. */

/*! @brief Read current value of the LCDIF_RL_DOTCLK_MODE field. */
#define BR_LCDIF_RL_DOTCLK_MODE(x) (HW_LCDIF_RL(x).B.DOTCLK_MODE)

/*! @brief Format value for bitfield LCDIF_RL_DOTCLK_MODE. */
#define BF_LCDIF_RL_DOTCLK_MODE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_DOTCLK_MODE) & BM_LCDIF_RL_DOTCLK_MODE)

/*! @brief Set the DOTCLK_MODE field to a new value. */
#define BW_LCDIF_RL_DOTCLK_MODE(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_DOTCLK_MODE) | BF_LCDIF_RL_DOTCLK_MODE(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field VSYNC_MODE[18] (RW)
 *
 * Setting this bit to 1 will make the eLCDIF hardware go into VSYNC mode.
 * WAIT_FOR_VSYNC_EDGE can be used only if this bit is set. If VSYNC signal is
 * required to be an output from the block, SYNC_SIGNALS_ON bit in LCDIF_VDCTRL4
 * register must be set.
 */
/*@{*/
#define BP_LCDIF_RL_VSYNC_MODE (18U)       /*!< Bit position for LCDIF_RL_VSYNC_MODE. */
#define BM_LCDIF_RL_VSYNC_MODE (0x00040000U) /*!< Bit mask for LCDIF_RL_VSYNC_MODE. */
#define BS_LCDIF_RL_VSYNC_MODE (1U)        /*!< Bit field size in bits for LCDIF_RL_VSYNC_MODE. */

/*! @brief Read current value of the LCDIF_RL_VSYNC_MODE field. */
#define BR_LCDIF_RL_VSYNC_MODE(x) (HW_LCDIF_RL(x).B.VSYNC_MODE)

/*! @brief Format value for bitfield LCDIF_RL_VSYNC_MODE. */
#define BF_LCDIF_RL_VSYNC_MODE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_VSYNC_MODE) & BM_LCDIF_RL_VSYNC_MODE)

/*! @brief Set the VSYNC_MODE field to a new value. */
#define BW_LCDIF_RL_VSYNC_MODE(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_VSYNC_MODE) | BF_LCDIF_RL_VSYNC_MODE(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field BYPASS_COUNT[19] (RW)
 *
 * When this bit is 0, it means that eLCDIF will stop the block operation and
 * turn off the RUN bit after the amount of data indicated by the
 * LCDIF_TRANSFER_COUNT register has been transferred out. When this bit is set to 1, the block
 * will continue normal operation indefinitely until it is told to stop. This bit
 * must be 0 in MPU and VSYNC modes, and must be 1 in DOTCLK and DVI modes of
 * operation.
 */
/*@{*/
#define BP_LCDIF_RL_BYPASS_COUNT (19U)     /*!< Bit position for LCDIF_RL_BYPASS_COUNT. */
#define BM_LCDIF_RL_BYPASS_COUNT (0x00080000U) /*!< Bit mask for LCDIF_RL_BYPASS_COUNT. */
#define BS_LCDIF_RL_BYPASS_COUNT (1U)      /*!< Bit field size in bits for LCDIF_RL_BYPASS_COUNT. */

/*! @brief Read current value of the LCDIF_RL_BYPASS_COUNT field. */
#define BR_LCDIF_RL_BYPASS_COUNT(x) (HW_LCDIF_RL(x).B.BYPASS_COUNT)

/*! @brief Format value for bitfield LCDIF_RL_BYPASS_COUNT. */
#define BF_LCDIF_RL_BYPASS_COUNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_BYPASS_COUNT) & BM_LCDIF_RL_BYPASS_COUNT)

/*! @brief Set the BYPASS_COUNT field to a new value. */
#define BW_LCDIF_RL_BYPASS_COUNT(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_BYPASS_COUNT) | BF_LCDIF_RL_BYPASS_COUNT(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field DVI_MODE[20] (RW)
 *
 * Set this bit to 1 to get into the ITU-R BT.656 digital video interface mode.
 * Toggle this bit from 1 to 0 to make the hardware go out of DVI mode after
 * completing all data transfer and after the RUN bit has been deasserted.
 */
/*@{*/
#define BP_LCDIF_RL_DVI_MODE (20U)         /*!< Bit position for LCDIF_RL_DVI_MODE. */
#define BM_LCDIF_RL_DVI_MODE (0x00100000U) /*!< Bit mask for LCDIF_RL_DVI_MODE. */
#define BS_LCDIF_RL_DVI_MODE (1U)          /*!< Bit field size in bits for LCDIF_RL_DVI_MODE. */

/*! @brief Read current value of the LCDIF_RL_DVI_MODE field. */
#define BR_LCDIF_RL_DVI_MODE(x) (HW_LCDIF_RL(x).B.DVI_MODE)

/*! @brief Format value for bitfield LCDIF_RL_DVI_MODE. */
#define BF_LCDIF_RL_DVI_MODE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_DVI_MODE) & BM_LCDIF_RL_DVI_MODE)

/*! @brief Set the DVI_MODE field to a new value. */
#define BW_LCDIF_RL_DVI_MODE(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_DVI_MODE) | BF_LCDIF_RL_DVI_MODE(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field SHIFT_NUM_BITS[25:21] (RW)
 *
 * The data to be transmitted is shifted left or right by this number of bits.
 */
/*@{*/
#define BP_LCDIF_RL_SHIFT_NUM_BITS (21U)   /*!< Bit position for LCDIF_RL_SHIFT_NUM_BITS. */
#define BM_LCDIF_RL_SHIFT_NUM_BITS (0x03E00000U) /*!< Bit mask for LCDIF_RL_SHIFT_NUM_BITS. */
#define BS_LCDIF_RL_SHIFT_NUM_BITS (5U)    /*!< Bit field size in bits for LCDIF_RL_SHIFT_NUM_BITS. */

/*! @brief Read current value of the LCDIF_RL_SHIFT_NUM_BITS field. */
#define BR_LCDIF_RL_SHIFT_NUM_BITS(x) (HW_LCDIF_RL(x).B.SHIFT_NUM_BITS)

/*! @brief Format value for bitfield LCDIF_RL_SHIFT_NUM_BITS. */
#define BF_LCDIF_RL_SHIFT_NUM_BITS(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_SHIFT_NUM_BITS) & BM_LCDIF_RL_SHIFT_NUM_BITS)

/*! @brief Set the SHIFT_NUM_BITS field to a new value. */
#define BW_LCDIF_RL_SHIFT_NUM_BITS(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_SHIFT_NUM_BITS) | BF_LCDIF_RL_SHIFT_NUM_BITS(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field DATA_SHIFT_DIR[26] (RW)
 *
 * Use this bit to determine the direction of shift of transmit data. In the DVI
 * mode, it works only on the active data, not on the timing codes and ancillary
 * data.
 *
 * Values:
 * - 0 - Data to be transmitted is shifted LEFT by SHIFT_NUM_BITS bits.
 * - 1 - Data to be transmitted is shifted RIGHT by SHIFT_NUM_BITS bits.
 */
/*@{*/
#define BP_LCDIF_RL_DATA_SHIFT_DIR (26U)   /*!< Bit position for LCDIF_RL_DATA_SHIFT_DIR. */
#define BM_LCDIF_RL_DATA_SHIFT_DIR (0x04000000U) /*!< Bit mask for LCDIF_RL_DATA_SHIFT_DIR. */
#define BS_LCDIF_RL_DATA_SHIFT_DIR (1U)    /*!< Bit field size in bits for LCDIF_RL_DATA_SHIFT_DIR. */

#define BV_LCDIF_RL_DATA_SHIFT_DIR_TXDATA_SHIFT_LEFT (0U) /*!< Bit field value for LCDIF_RL_DATA_SHIFT_DIR: Data to be transmitted is shifted LEFT by SHIFT_NUM_BITS bits. */
#define BV_LCDIF_RL_DATA_SHIFT_DIR_TXDATA_SHIFT_RIGHT (0x1U) /*!< Bit field value for LCDIF_RL_DATA_SHIFT_DIR: Data to be transmitted is shifted RIGHT by SHIFT_NUM_BITS bits. */

/*! @brief Read current value of the LCDIF_RL_DATA_SHIFT_DIR field. */
#define BR_LCDIF_RL_DATA_SHIFT_DIR(x) (HW_LCDIF_RL(x).B.DATA_SHIFT_DIR)

/*! @brief Format value for bitfield LCDIF_RL_DATA_SHIFT_DIR. */
#define BF_LCDIF_RL_DATA_SHIFT_DIR(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_DATA_SHIFT_DIR) & BM_LCDIF_RL_DATA_SHIFT_DIR)

/*! @brief Set the DATA_SHIFT_DIR field to a new value. */
#define BW_LCDIF_RL_DATA_SHIFT_DIR(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_DATA_SHIFT_DIR) | BF_LCDIF_RL_DATA_SHIFT_DIR(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field WAIT_FOR_VSYNC_EDGE[27] (RW)
 *
 * Setting this bit to 1 will make the hardware wait for the triggering VSYNC
 * edge before starting write transfers to the LCD. Used only in the VSYNC mode of
 * operation.
 */
/*@{*/
#define BP_LCDIF_RL_WAIT_FOR_VSYNC_EDGE (27U) /*!< Bit position for LCDIF_RL_WAIT_FOR_VSYNC_EDGE. */
#define BM_LCDIF_RL_WAIT_FOR_VSYNC_EDGE (0x08000000U) /*!< Bit mask for LCDIF_RL_WAIT_FOR_VSYNC_EDGE. */
#define BS_LCDIF_RL_WAIT_FOR_VSYNC_EDGE (1U) /*!< Bit field size in bits for LCDIF_RL_WAIT_FOR_VSYNC_EDGE. */

/*! @brief Read current value of the LCDIF_RL_WAIT_FOR_VSYNC_EDGE field. */
#define BR_LCDIF_RL_WAIT_FOR_VSYNC_EDGE(x) (HW_LCDIF_RL(x).B.WAIT_FOR_VSYNC_EDGE)

/*! @brief Format value for bitfield LCDIF_RL_WAIT_FOR_VSYNC_EDGE. */
#define BF_LCDIF_RL_WAIT_FOR_VSYNC_EDGE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_WAIT_FOR_VSYNC_EDGE) & BM_LCDIF_RL_WAIT_FOR_VSYNC_EDGE)

/*! @brief Set the WAIT_FOR_VSYNC_EDGE field to a new value. */
#define BW_LCDIF_RL_WAIT_FOR_VSYNC_EDGE(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_WAIT_FOR_VSYNC_EDGE) | BF_LCDIF_RL_WAIT_FOR_VSYNC_EDGE(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field READ_WRITEB[28] (RW)
 *
 * By default, eLCDIF is in the write mode. Setting this bit to 1 will make the
 * hardware go into 6800/8080 MPU read mode. The LCDIF_MASTER bit must be 0,
 * since bus master mode can only be used for writing the display.
 */
/*@{*/
#define BP_LCDIF_RL_READ_WRITEB (28U)      /*!< Bit position for LCDIF_RL_READ_WRITEB. */
#define BM_LCDIF_RL_READ_WRITEB (0x10000000U) /*!< Bit mask for LCDIF_RL_READ_WRITEB. */
#define BS_LCDIF_RL_READ_WRITEB (1U)       /*!< Bit field size in bits for LCDIF_RL_READ_WRITEB. */

/*! @brief Read current value of the LCDIF_RL_READ_WRITEB field. */
#define BR_LCDIF_RL_READ_WRITEB(x) (HW_LCDIF_RL(x).B.READ_WRITEB)

/*! @brief Format value for bitfield LCDIF_RL_READ_WRITEB. */
#define BF_LCDIF_RL_READ_WRITEB(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_READ_WRITEB) & BM_LCDIF_RL_READ_WRITEB)

/*! @brief Set the READ_WRITEB field to a new value. */
#define BW_LCDIF_RL_READ_WRITEB(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_READ_WRITEB) | BF_LCDIF_RL_READ_WRITEB(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field YCBCR422_INPUT[29] (RW)
 *
 * Zero implies input data is in RGB color space. One implies input data is in
 * YCbCr 4:2:2 format, such that YCbYCr are packed in a 32-bit word. It also means
 * that there are 2 pixels in 4 bytes. If this bit is set, software should
 * program the H_COUNT field in the TRANSFER_COUNT register to the total number of
 * pixels that will have to be fetched by the eLCDIF block per line and the
 * BYTE_PACKING_FORMAT should be 0xF. The WORD_LENGTH does not matter in this case.
 */
/*@{*/
#define BP_LCDIF_RL_YCBCR422_INPUT (29U)   /*!< Bit position for LCDIF_RL_YCBCR422_INPUT. */
#define BM_LCDIF_RL_YCBCR422_INPUT (0x20000000U) /*!< Bit mask for LCDIF_RL_YCBCR422_INPUT. */
#define BS_LCDIF_RL_YCBCR422_INPUT (1U)    /*!< Bit field size in bits for LCDIF_RL_YCBCR422_INPUT. */

/*! @brief Read current value of the LCDIF_RL_YCBCR422_INPUT field. */
#define BR_LCDIF_RL_YCBCR422_INPUT(x) (HW_LCDIF_RL(x).B.YCBCR422_INPUT)

/*! @brief Format value for bitfield LCDIF_RL_YCBCR422_INPUT. */
#define BF_LCDIF_RL_YCBCR422_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_YCBCR422_INPUT) & BM_LCDIF_RL_YCBCR422_INPUT)

/*! @brief Set the YCBCR422_INPUT field to a new value. */
#define BW_LCDIF_RL_YCBCR422_INPUT(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_YCBCR422_INPUT) | BF_LCDIF_RL_YCBCR422_INPUT(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field CLKGATE[30] (RW)
 *
 * This bit must be set to zero for normal operation. When set to one it gates
 * off the clocks to the block.
 */
/*@{*/
#define BP_LCDIF_RL_CLKGATE  (30U)         /*!< Bit position for LCDIF_RL_CLKGATE. */
#define BM_LCDIF_RL_CLKGATE  (0x40000000U) /*!< Bit mask for LCDIF_RL_CLKGATE. */
#define BS_LCDIF_RL_CLKGATE  (1U)          /*!< Bit field size in bits for LCDIF_RL_CLKGATE. */

/*! @brief Read current value of the LCDIF_RL_CLKGATE field. */
#define BR_LCDIF_RL_CLKGATE(x) (HW_LCDIF_RL(x).B.CLKGATE)

/*! @brief Format value for bitfield LCDIF_RL_CLKGATE. */
#define BF_LCDIF_RL_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_CLKGATE) & BM_LCDIF_RL_CLKGATE)

/*! @brief Set the CLKGATE field to a new value. */
#define BW_LCDIF_RL_CLKGATE(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_CLKGATE) | BF_LCDIF_RL_CLKGATE(v)))
/*@}*/

/*!
 * @name Register LCDIF_RL, field SFTRST[31] (RW)
 *
 * This bit must be set to zero to enable normal operation of the eLCDIF. When
 * set to one, it forces a block level reset.
 */
/*@{*/
#define BP_LCDIF_RL_SFTRST   (31U)         /*!< Bit position for LCDIF_RL_SFTRST. */
#define BM_LCDIF_RL_SFTRST   (0x80000000U) /*!< Bit mask for LCDIF_RL_SFTRST. */
#define BS_LCDIF_RL_SFTRST   (1U)          /*!< Bit field size in bits for LCDIF_RL_SFTRST. */

/*! @brief Read current value of the LCDIF_RL_SFTRST field. */
#define BR_LCDIF_RL_SFTRST(x) (HW_LCDIF_RL(x).B.SFTRST)

/*! @brief Format value for bitfield LCDIF_RL_SFTRST. */
#define BF_LCDIF_RL_SFTRST(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_RL_SFTRST) & BM_LCDIF_RL_SFTRST)

/*! @brief Set the SFTRST field to a new value. */
#define BW_LCDIF_RL_SFTRST(x, v) (HW_LCDIF_RL_WR(x, (HW_LCDIF_RL_RD(x) & ~BM_LCDIF_RL_SFTRST) | BF_LCDIF_RL_SFTRST(v)))
/*@}*/




/*******************************************************************************
 * HW_LCDIF_CTRL1 - eLCDIF General Control1 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CTRL1 - eLCDIF General Control1 Register (RW)
 *
 * Reset value: 0x000F0000U
 *
 * The eLCDIF Control Register provides overall control of the eLCDIF block. The
 * eLCDIF Control1 Register provides additional programming to the eLCDIF. It
 * implements some bits which are unlikely to change often in a particular
 * application. It also carries interrupt-related bits which are common across more than
 * one mode of operation.
 */
typedef union _hw_lcdif_ctrl1
{
    uint32_t U;
    struct _hw_lcdif_ctrl1_bitfields
    {
        uint32_t RESET : 1;            /*!< [0]  */
        uint32_t MODE86 : 1;           /*!< [1]  */
        uint32_t BUSY_ENABLE : 1;      /*!< [2]  */
        uint32_t RSRVD0 : 5;           /*!< [7:3]  */
        uint32_t VSYNC_EDGE_IRQ : 1;   /*!< [8]  */
        uint32_t CUR_FRAME_DONE_IRQ : 1; /*!< [9]  */
        uint32_t UNDERFLOW_IRQ : 1;    /*!< [10]  */
        uint32_t OVERFLOW_IRQ : 1;     /*!< [11]  */
        uint32_t VSYNC_EDGE_IRQ_EN : 1; /*!< [12]  */
        uint32_t CUR_FRAME_DONE_IRQ_EN : 1; /*!< [13]  */
        uint32_t UNDERFLOW_IRQ_EN : 1; /*!< [14]  */
        uint32_t OVERFLOW_IRQ_EN : 1;  /*!< [15]  */
        uint32_t BYTE_PACKING_FORMAT : 4; /*!< [19:16]  */
        uint32_t IRQ_ON_ALTERNATE_FIELDS : 1; /*!< [20]  */
        uint32_t FIFO_CLEAR : 1;       /*!< [21]  */
        uint32_t START_INTERLACE_FROM_SECOND_FIELD : 1; /*!< [22]  */
        uint32_t INTERLACE_FIELDS : 1; /*!< [23]  */
        uint32_t RECOVER_ON_UNDERFLOW : 1; /*!< [24]  */
        uint32_t BM_ERROR_IRQ : 1;     /*!< [25]  */
        uint32_t BM_ERROR_IRQ_EN : 1;  /*!< [26]  */
        uint32_t COMBINE_MPU_WR_STRB : 1; /*!< [27]  */
        uint32_t RSRVD1 : 4;           /*!< [31:28]  */
    } B;
} hw_lcdif_ctrl1_t;

/*!
 * @name Constants and macros for entire LCDIF_CTRL1 register
 */
/*@{*/
#define HW_LCDIF_CTRL1_ADDR(x)   ((uintptr_t)(x) + 0x10U)
#define HW_LCDIF_CTRL1_SET_ADDR(x) (HW_LCDIF_CTRL1_ADDR(x) + 0x4U)
#define HW_LCDIF_CTRL1_CLR_ADDR(x) (HW_LCDIF_CTRL1_ADDR(x) + 0x8U)
#define HW_LCDIF_CTRL1_TOG_ADDR(x) (HW_LCDIF_CTRL1_ADDR(x) + 0xCU)

#define HW_LCDIF_CTRL1(x)        (*(__IO hw_lcdif_ctrl1_t *) HW_LCDIF_CTRL1_ADDR(x))
#define HW_LCDIF_CTRL1_RD(x)     (HW_LCDIF_CTRL1(x).U)
#define HW_LCDIF_CTRL1_WR(x, v)  (HW_LCDIF_CTRL1(x).U = (v))
#define HW_LCDIF_CTRL1_SET(x, v) ((*(uint32_t *) HW_LCDIF_CTRL1_SET_ADDR(x)) = (v))
#define HW_LCDIF_CTRL1_CLR(x, v) ((*(uint32_t *) HW_LCDIF_CTRL1_CLR_ADDR(x)) = (v))
#define HW_LCDIF_CTRL1_TOG(x, v) ((*(uint32_t *) HW_LCDIF_CTRL1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CTRL1 bitfields
 */

/*!
 * @name Register LCDIF_CTRL1, field RESET[0] (RW)
 *
 * Reset bit for the external LCD controller. This bit can be changed at any
 * time. It CANNOT be reset by SFTRST.
 *
 * Values:
 * - 0 - LCD_RESET output signal is low.
 * - 1 - LCD_RESET output signal is high.
 */
/*@{*/
#define BP_LCDIF_CTRL1_RESET (0U)          /*!< Bit position for LCDIF_CTRL1_RESET. */
#define BM_LCDIF_CTRL1_RESET (0x00000001U) /*!< Bit mask for LCDIF_CTRL1_RESET. */
#define BS_LCDIF_CTRL1_RESET (1U)          /*!< Bit field size in bits for LCDIF_CTRL1_RESET. */

#define BV_LCDIF_CTRL1_RESET_LCDRESET_LOW (0U)       /*!< Bit field value for LCDIF_CTRL1_RESET: LCD_RESET output signal is low. */
#define BV_LCDIF_CTRL1_RESET_LCDRESET_HIGH (0x1U)    /*!< Bit field value for LCDIF_CTRL1_RESET: LCD_RESET output signal is high. */

/*! @brief Read current value of the LCDIF_CTRL1_RESET field. */
#define BR_LCDIF_CTRL1_RESET(x) (HW_LCDIF_CTRL1(x).B.RESET)

/*! @brief Format value for bitfield LCDIF_CTRL1_RESET. */
#define BF_LCDIF_CTRL1_RESET(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_RESET) & BM_LCDIF_CTRL1_RESET)

/*! @brief Set the RESET field to a new value. */
#define BW_LCDIF_CTRL1_RESET(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_RESET) | BF_LCDIF_CTRL1_RESET(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field MODE86[1] (RW)
 *
 * This bit is used to select between the 8080 and 6800 series of microprocessor
 * modes. This bit should only be changed when RUN is 0.
 *
 * Values:
 * - 0 - Pins LCD_WR_RWn and LCD_RD_E function as active low WR and active low
 *     RD signals respectively.
 * - 1 - Pins LCD_WR_RWn and LCD_RD_E function as Read/Write and active high
 *     Enable signals respectively.
 */
/*@{*/
#define BP_LCDIF_CTRL1_MODE86 (1U)         /*!< Bit position for LCDIF_CTRL1_MODE86. */
#define BM_LCDIF_CTRL1_MODE86 (0x00000002U) /*!< Bit mask for LCDIF_CTRL1_MODE86. */
#define BS_LCDIF_CTRL1_MODE86 (1U)         /*!< Bit field size in bits for LCDIF_CTRL1_MODE86. */

#define BV_LCDIF_CTRL1_MODE86_8080_MODE (0U)         /*!< Bit field value for LCDIF_CTRL1_MODE86: Pins LCD_WR_RWn and LCD_RD_E function as active low WR and active low RD signals respectively. */
#define BV_LCDIF_CTRL1_MODE86_6800_MODE (0x1U)       /*!< Bit field value for LCDIF_CTRL1_MODE86: Pins LCD_WR_RWn and LCD_RD_E function as Read/Write and active high Enable signals respectively. */

/*! @brief Read current value of the LCDIF_CTRL1_MODE86 field. */
#define BR_LCDIF_CTRL1_MODE86(x) (HW_LCDIF_CTRL1(x).B.MODE86)

/*! @brief Format value for bitfield LCDIF_CTRL1_MODE86. */
#define BF_LCDIF_CTRL1_MODE86(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_MODE86) & BM_LCDIF_CTRL1_MODE86)

/*! @brief Set the MODE86 field to a new value. */
#define BW_LCDIF_CTRL1_MODE86(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_MODE86) | BF_LCDIF_CTRL1_MODE86(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field BUSY_ENABLE[2] (RW)
 *
 * This bit enables the use of the interface's busy signal input. This should be
 * enabled for LCD controllers that implement a busy line (to stall the eLCDIF
 * from sending more data until ready). Otherwise this bit should be cleared.
 *
 * Values:
 * - 0 - The busy signal from the LCD controller will be ignored.
 * - 1 - Enable the use of the busy signal from the LCD controller.
 */
/*@{*/
#define BP_LCDIF_CTRL1_BUSY_ENABLE (2U)    /*!< Bit position for LCDIF_CTRL1_BUSY_ENABLE. */
#define BM_LCDIF_CTRL1_BUSY_ENABLE (0x00000004U) /*!< Bit mask for LCDIF_CTRL1_BUSY_ENABLE. */
#define BS_LCDIF_CTRL1_BUSY_ENABLE (1U)    /*!< Bit field size in bits for LCDIF_CTRL1_BUSY_ENABLE. */

#define BV_LCDIF_CTRL1_BUSY_ENABLE_BUSY_DISABLED (0U) /*!< Bit field value for LCDIF_CTRL1_BUSY_ENABLE: The busy signal from the LCD controller will be ignored. */
#define BV_LCDIF_CTRL1_BUSY_ENABLE_BUSY_ENABLED (0x1U) /*!< Bit field value for LCDIF_CTRL1_BUSY_ENABLE: Enable the use of the busy signal from the LCD controller. */

/*! @brief Read current value of the LCDIF_CTRL1_BUSY_ENABLE field. */
#define BR_LCDIF_CTRL1_BUSY_ENABLE(x) (HW_LCDIF_CTRL1(x).B.BUSY_ENABLE)

/*! @brief Format value for bitfield LCDIF_CTRL1_BUSY_ENABLE. */
#define BF_LCDIF_CTRL1_BUSY_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_BUSY_ENABLE) & BM_LCDIF_CTRL1_BUSY_ENABLE)

/*! @brief Set the BUSY_ENABLE field to a new value. */
#define BW_LCDIF_CTRL1_BUSY_ENABLE(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_BUSY_ENABLE) | BF_LCDIF_CTRL1_BUSY_ENABLE(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field RSRVD0[7:3] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_CTRL1_RSRVD0 (3U)         /*!< Bit position for LCDIF_CTRL1_RSRVD0. */
#define BM_LCDIF_CTRL1_RSRVD0 (0x000000F8U) /*!< Bit mask for LCDIF_CTRL1_RSRVD0. */
#define BS_LCDIF_CTRL1_RSRVD0 (5U)         /*!< Bit field size in bits for LCDIF_CTRL1_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field VSYNC_EDGE_IRQ[8] (RW)
 *
 * This bit is set to indicate that an interrupt is requested by the eLCDIF
 * block. This bit is cleared by software by writing a one to its SCT clear address.
 * It is set whenever the leading VSYNC edge is detected in the VSYNC and DOTCLK
 * modes. In the DVI mode, it is asserted every time the block enters a new field.
 *
 * Values:
 * - 0 - No Interrupt Request Pending.
 * - 1 - Interrupt Request Pending.
 */
/*@{*/
#define BP_LCDIF_CTRL1_VSYNC_EDGE_IRQ (8U) /*!< Bit position for LCDIF_CTRL1_VSYNC_EDGE_IRQ. */
#define BM_LCDIF_CTRL1_VSYNC_EDGE_IRQ (0x00000100U) /*!< Bit mask for LCDIF_CTRL1_VSYNC_EDGE_IRQ. */
#define BS_LCDIF_CTRL1_VSYNC_EDGE_IRQ (1U) /*!< Bit field size in bits for LCDIF_CTRL1_VSYNC_EDGE_IRQ. */

#define BV_LCDIF_CTRL1_VSYNC_EDGE_IRQ_NO_REQUEST (0U) /*!< Bit field value for LCDIF_CTRL1_VSYNC_EDGE_IRQ: No Interrupt Request Pending. */
#define BV_LCDIF_CTRL1_VSYNC_EDGE_IRQ_REQUEST (0x1U) /*!< Bit field value for LCDIF_CTRL1_VSYNC_EDGE_IRQ: Interrupt Request Pending. */

/*! @brief Read current value of the LCDIF_CTRL1_VSYNC_EDGE_IRQ field. */
#define BR_LCDIF_CTRL1_VSYNC_EDGE_IRQ(x) (HW_LCDIF_CTRL1(x).B.VSYNC_EDGE_IRQ)

/*! @brief Format value for bitfield LCDIF_CTRL1_VSYNC_EDGE_IRQ. */
#define BF_LCDIF_CTRL1_VSYNC_EDGE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_VSYNC_EDGE_IRQ) & BM_LCDIF_CTRL1_VSYNC_EDGE_IRQ)

/*! @brief Set the VSYNC_EDGE_IRQ field to a new value. */
#define BW_LCDIF_CTRL1_VSYNC_EDGE_IRQ(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_VSYNC_EDGE_IRQ) | BF_LCDIF_CTRL1_VSYNC_EDGE_IRQ(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field CUR_FRAME_DONE_IRQ[9] (RW)
 *
 * This bit is set to indicate that an interrupt is requested by the eLCDIF
 * block. This bit is cleared by software by writing a one to its SCT clear address.
 * It indicates that the hardware has completed transmitting the current frame
 * and is in the vertical blanking period in the DOTCLK/DVI modes. In the MPU and
 * VSYNC modes, this IRQ is asserted at the end of the data transfer indicated by
 * LCDIF_TRANSFER_COUNT register.
 *
 * Values:
 * - 0 - No Interrupt Request Pending.
 * - 1 - Interrupt Request Pending.
 */
/*@{*/
#define BP_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ (9U) /*!< Bit position for LCDIF_CTRL1_CUR_FRAME_DONE_IRQ. */
#define BM_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ (0x00000200U) /*!< Bit mask for LCDIF_CTRL1_CUR_FRAME_DONE_IRQ. */
#define BS_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ (1U) /*!< Bit field size in bits for LCDIF_CTRL1_CUR_FRAME_DONE_IRQ. */

#define BV_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_NO_REQUEST (0U) /*!< Bit field value for LCDIF_CTRL1_CUR_FRAME_DONE_IRQ: No Interrupt Request Pending. */
#define BV_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_REQUEST (0x1U) /*!< Bit field value for LCDIF_CTRL1_CUR_FRAME_DONE_IRQ: Interrupt Request Pending. */

/*! @brief Read current value of the LCDIF_CTRL1_CUR_FRAME_DONE_IRQ field. */
#define BR_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ(x) (HW_LCDIF_CTRL1(x).B.CUR_FRAME_DONE_IRQ)

/*! @brief Format value for bitfield LCDIF_CTRL1_CUR_FRAME_DONE_IRQ. */
#define BF_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ) & BM_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ)

/*! @brief Set the CUR_FRAME_DONE_IRQ field to a new value. */
#define BW_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ) | BF_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field UNDERFLOW_IRQ[10] (RW)
 *
 * This bit is set to indicate that an interrupt is requested by the eLCDIF
 * block. This bit is cleared by software by writing a one to its SCT clear address.
 * A TXFIFO underflow in the write mode (MPU/VSYNC/DOTCLK/DVI mode) was detected.
 * Could produce an error in the DOTCLK / DVI modes.
 *
 * Values:
 * - 0 - No Interrupt Request Pending.
 * - 1 - Interrupt Request Pending.
 */
/*@{*/
#define BP_LCDIF_CTRL1_UNDERFLOW_IRQ (10U) /*!< Bit position for LCDIF_CTRL1_UNDERFLOW_IRQ. */
#define BM_LCDIF_CTRL1_UNDERFLOW_IRQ (0x00000400U) /*!< Bit mask for LCDIF_CTRL1_UNDERFLOW_IRQ. */
#define BS_LCDIF_CTRL1_UNDERFLOW_IRQ (1U)  /*!< Bit field size in bits for LCDIF_CTRL1_UNDERFLOW_IRQ. */

#define BV_LCDIF_CTRL1_UNDERFLOW_IRQ_NO_REQUEST (0U) /*!< Bit field value for LCDIF_CTRL1_UNDERFLOW_IRQ: No Interrupt Request Pending. */
#define BV_LCDIF_CTRL1_UNDERFLOW_IRQ_REQUEST (0x1U)  /*!< Bit field value for LCDIF_CTRL1_UNDERFLOW_IRQ: Interrupt Request Pending. */

/*! @brief Read current value of the LCDIF_CTRL1_UNDERFLOW_IRQ field. */
#define BR_LCDIF_CTRL1_UNDERFLOW_IRQ(x) (HW_LCDIF_CTRL1(x).B.UNDERFLOW_IRQ)

/*! @brief Format value for bitfield LCDIF_CTRL1_UNDERFLOW_IRQ. */
#define BF_LCDIF_CTRL1_UNDERFLOW_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_UNDERFLOW_IRQ) & BM_LCDIF_CTRL1_UNDERFLOW_IRQ)

/*! @brief Set the UNDERFLOW_IRQ field to a new value. */
#define BW_LCDIF_CTRL1_UNDERFLOW_IRQ(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_UNDERFLOW_IRQ) | BF_LCDIF_CTRL1_UNDERFLOW_IRQ(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field OVERFLOW_IRQ[11] (RW)
 *
 * This bit is set to indicate that an interrupt is requested by the eLCDIF
 * block. This bit is cleared by software by writing a one to its SCT clear address.
 * A latency FIFO (LFIFO) overflow in the write mode (MPU/VSYNC/DOTCLK/DVI mode)
 * was detected, data samples have been lost.
 *
 * Values:
 * - 0 - No Interrupt Request Pending.
 * - 1 - Interrupt Request Pending.
 */
/*@{*/
#define BP_LCDIF_CTRL1_OVERFLOW_IRQ (11U)  /*!< Bit position for LCDIF_CTRL1_OVERFLOW_IRQ. */
#define BM_LCDIF_CTRL1_OVERFLOW_IRQ (0x00000800U) /*!< Bit mask for LCDIF_CTRL1_OVERFLOW_IRQ. */
#define BS_LCDIF_CTRL1_OVERFLOW_IRQ (1U)   /*!< Bit field size in bits for LCDIF_CTRL1_OVERFLOW_IRQ. */

#define BV_LCDIF_CTRL1_OVERFLOW_IRQ_NO_REQUEST (0U)  /*!< Bit field value for LCDIF_CTRL1_OVERFLOW_IRQ: No Interrupt Request Pending. */
#define BV_LCDIF_CTRL1_OVERFLOW_IRQ_REQUEST (0x1U)   /*!< Bit field value for LCDIF_CTRL1_OVERFLOW_IRQ: Interrupt Request Pending. */

/*! @brief Read current value of the LCDIF_CTRL1_OVERFLOW_IRQ field. */
#define BR_LCDIF_CTRL1_OVERFLOW_IRQ(x) (HW_LCDIF_CTRL1(x).B.OVERFLOW_IRQ)

/*! @brief Format value for bitfield LCDIF_CTRL1_OVERFLOW_IRQ. */
#define BF_LCDIF_CTRL1_OVERFLOW_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_OVERFLOW_IRQ) & BM_LCDIF_CTRL1_OVERFLOW_IRQ)

/*! @brief Set the OVERFLOW_IRQ field to a new value. */
#define BW_LCDIF_CTRL1_OVERFLOW_IRQ(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_OVERFLOW_IRQ) | BF_LCDIF_CTRL1_OVERFLOW_IRQ(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field VSYNC_EDGE_IRQ_EN[12] (RW)
 *
 * This bit is set to enable an interrupt every time the hardware encounters the
 * leading VSYNC edge in the VSYNC and DOTCLK modes, or the beginning of every
 * field in DVI mode.
 */
/*@{*/
#define BP_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN (12U) /*!< Bit position for LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN. */
#define BM_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN (0x00001000U) /*!< Bit mask for LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN. */
#define BS_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN (1U) /*!< Bit field size in bits for LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN. */

/*! @brief Read current value of the LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN field. */
#define BR_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN(x) (HW_LCDIF_CTRL1(x).B.VSYNC_EDGE_IRQ_EN)

/*! @brief Format value for bitfield LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN. */
#define BF_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN) & BM_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN)

/*! @brief Set the VSYNC_EDGE_IRQ_EN field to a new value. */
#define BW_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN) | BF_LCDIF_CTRL1_VSYNC_EDGE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field CUR_FRAME_DONE_IRQ_EN[13] (RW)
 *
 * This bit is set to 1 enable an interrupt every time the hardware enters in
 * the vertical blanking state.
 */
/*@{*/
#define BP_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN (13U) /*!< Bit position for LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN. */
#define BM_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN (0x00002000U) /*!< Bit mask for LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN. */
#define BS_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN (1U) /*!< Bit field size in bits for LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN. */

/*! @brief Read current value of the LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN field. */
#define BR_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN(x) (HW_LCDIF_CTRL1(x).B.CUR_FRAME_DONE_IRQ_EN)

/*! @brief Format value for bitfield LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN. */
#define BF_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN) & BM_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN)

/*! @brief Set the CUR_FRAME_DONE_IRQ_EN field to a new value. */
#define BW_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN) | BF_LCDIF_CTRL1_CUR_FRAME_DONE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field UNDERFLOW_IRQ_EN[14] (RW)
 *
 * This bit is set to enable an underflow interrupt in the TXFIFO in the write
 * mode.
 */
/*@{*/
#define BP_LCDIF_CTRL1_UNDERFLOW_IRQ_EN (14U) /*!< Bit position for LCDIF_CTRL1_UNDERFLOW_IRQ_EN. */
#define BM_LCDIF_CTRL1_UNDERFLOW_IRQ_EN (0x00004000U) /*!< Bit mask for LCDIF_CTRL1_UNDERFLOW_IRQ_EN. */
#define BS_LCDIF_CTRL1_UNDERFLOW_IRQ_EN (1U) /*!< Bit field size in bits for LCDIF_CTRL1_UNDERFLOW_IRQ_EN. */

/*! @brief Read current value of the LCDIF_CTRL1_UNDERFLOW_IRQ_EN field. */
#define BR_LCDIF_CTRL1_UNDERFLOW_IRQ_EN(x) (HW_LCDIF_CTRL1(x).B.UNDERFLOW_IRQ_EN)

/*! @brief Format value for bitfield LCDIF_CTRL1_UNDERFLOW_IRQ_EN. */
#define BF_LCDIF_CTRL1_UNDERFLOW_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_UNDERFLOW_IRQ_EN) & BM_LCDIF_CTRL1_UNDERFLOW_IRQ_EN)

/*! @brief Set the UNDERFLOW_IRQ_EN field to a new value. */
#define BW_LCDIF_CTRL1_UNDERFLOW_IRQ_EN(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_UNDERFLOW_IRQ_EN) | BF_LCDIF_CTRL1_UNDERFLOW_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field OVERFLOW_IRQ_EN[15] (RW)
 *
 * This bit is set to enable an overflow interrupt in the TXFIFO in the write
 * mode.
 */
/*@{*/
#define BP_LCDIF_CTRL1_OVERFLOW_IRQ_EN (15U) /*!< Bit position for LCDIF_CTRL1_OVERFLOW_IRQ_EN. */
#define BM_LCDIF_CTRL1_OVERFLOW_IRQ_EN (0x00008000U) /*!< Bit mask for LCDIF_CTRL1_OVERFLOW_IRQ_EN. */
#define BS_LCDIF_CTRL1_OVERFLOW_IRQ_EN (1U) /*!< Bit field size in bits for LCDIF_CTRL1_OVERFLOW_IRQ_EN. */

/*! @brief Read current value of the LCDIF_CTRL1_OVERFLOW_IRQ_EN field. */
#define BR_LCDIF_CTRL1_OVERFLOW_IRQ_EN(x) (HW_LCDIF_CTRL1(x).B.OVERFLOW_IRQ_EN)

/*! @brief Format value for bitfield LCDIF_CTRL1_OVERFLOW_IRQ_EN. */
#define BF_LCDIF_CTRL1_OVERFLOW_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_OVERFLOW_IRQ_EN) & BM_LCDIF_CTRL1_OVERFLOW_IRQ_EN)

/*! @brief Set the OVERFLOW_IRQ_EN field to a new value. */
#define BW_LCDIF_CTRL1_OVERFLOW_IRQ_EN(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_OVERFLOW_IRQ_EN) | BF_LCDIF_CTRL1_OVERFLOW_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field BYTE_PACKING_FORMAT[19:16] (RW)
 *
 * This bitfield is used to show which data bytes in a 32-bit word are valid.
 * Default value 0xf indicates that all bytes are valid. For 8-bit transfers, any
 * combination in this bitfield will mean valid data is present in the
 * corresponding bytes. In the 16-bit mode, a 16-bit half-word is valid only if adjacent
 * bits [1:0] or [3:2] or both are 1. A value of 0x0 will mean that none of the
 * bytes are valid and should not be used. For example, set the bit field value to
 * 0x7 if the display data is arranged in the 24-bit unpacked format (A-R-G-B where
 * A value does not have be transmitted). When input data is in YCbCr 4:2:2
 * format (YCBCR422_INPUT is 1), H_COUNT should be the number of pixels that should
 * be fetched by the block and the BYTE_PACKING_FORMAT should be 0xF.(Note -
 * YCBCR422_INPUT = 1 implies 2 pixels per 32 bits).
 */
/*@{*/
#define BP_LCDIF_CTRL1_BYTE_PACKING_FORMAT (16U) /*!< Bit position for LCDIF_CTRL1_BYTE_PACKING_FORMAT. */
#define BM_LCDIF_CTRL1_BYTE_PACKING_FORMAT (0x000F0000U) /*!< Bit mask for LCDIF_CTRL1_BYTE_PACKING_FORMAT. */
#define BS_LCDIF_CTRL1_BYTE_PACKING_FORMAT (4U) /*!< Bit field size in bits for LCDIF_CTRL1_BYTE_PACKING_FORMAT. */

/*! @brief Read current value of the LCDIF_CTRL1_BYTE_PACKING_FORMAT field. */
#define BR_LCDIF_CTRL1_BYTE_PACKING_FORMAT(x) (HW_LCDIF_CTRL1(x).B.BYTE_PACKING_FORMAT)

/*! @brief Format value for bitfield LCDIF_CTRL1_BYTE_PACKING_FORMAT. */
#define BF_LCDIF_CTRL1_BYTE_PACKING_FORMAT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_BYTE_PACKING_FORMAT) & BM_LCDIF_CTRL1_BYTE_PACKING_FORMAT)

/*! @brief Set the BYTE_PACKING_FORMAT field to a new value. */
#define BW_LCDIF_CTRL1_BYTE_PACKING_FORMAT(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_BYTE_PACKING_FORMAT) | BF_LCDIF_CTRL1_BYTE_PACKING_FORMAT(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field IRQ_ON_ALTERNATE_FIELDS[20] (RW)
 *
 * If this bit is set, the eLCDIF block will assert the cur_frame_done interrupt
 * only on alternate fields, otherwise it will issue the interrupt on both odd
 * and even field. This bit is mostly relevant if INTERLACE_FIELDS is set. This
 * feature is only available in DOTCLK and DVI modes.
 */
/*@{*/
#define BP_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS (20U) /*!< Bit position for LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS. */
#define BM_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS (0x00100000U) /*!< Bit mask for LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS. */
#define BS_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS (1U) /*!< Bit field size in bits for LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS. */

/*! @brief Read current value of the LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS field. */
#define BR_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS(x) (HW_LCDIF_CTRL1(x).B.IRQ_ON_ALTERNATE_FIELDS)

/*! @brief Format value for bitfield LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS. */
#define BF_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS) & BM_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS)

/*! @brief Set the IRQ_ON_ALTERNATE_FIELDS field to a new value. */
#define BW_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS) | BF_LCDIF_CTRL1_IRQ_ON_ALTERNATE_FIELDS(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field FIFO_CLEAR[21] (RW)
 *
 * Set this bit to clear all the data in the latency FIFO (LFIFO), TXFIFO and
 * the RXFIFO.
 */
/*@{*/
#define BP_LCDIF_CTRL1_FIFO_CLEAR (21U)    /*!< Bit position for LCDIF_CTRL1_FIFO_CLEAR. */
#define BM_LCDIF_CTRL1_FIFO_CLEAR (0x00200000U) /*!< Bit mask for LCDIF_CTRL1_FIFO_CLEAR. */
#define BS_LCDIF_CTRL1_FIFO_CLEAR (1U)     /*!< Bit field size in bits for LCDIF_CTRL1_FIFO_CLEAR. */

/*! @brief Read current value of the LCDIF_CTRL1_FIFO_CLEAR field. */
#define BR_LCDIF_CTRL1_FIFO_CLEAR(x) (HW_LCDIF_CTRL1(x).B.FIFO_CLEAR)

/*! @brief Format value for bitfield LCDIF_CTRL1_FIFO_CLEAR. */
#define BF_LCDIF_CTRL1_FIFO_CLEAR(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_FIFO_CLEAR) & BM_LCDIF_CTRL1_FIFO_CLEAR)

/*! @brief Set the FIFO_CLEAR field to a new value. */
#define BW_LCDIF_CTRL1_FIFO_CLEAR(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_FIFO_CLEAR) | BF_LCDIF_CTRL1_FIFO_CLEAR(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field START_INTERLACE_FROM_SECOND_FIELD[22] (RW)
 *
 * The default is to grab the odd lines first and then the even lines. Set this
 * bit if it is required to grab the even lines first and then the odd lines.
 * (Line numbers start from 1, so odd lines are 1,3,5,etc. and even lines are 2,4,6,
 * etc.)
 */
/*@{*/
#define BP_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD (22U) /*!< Bit position for LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD. */
#define BM_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD (0x00400000U) /*!< Bit mask for LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD. */
#define BS_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD (1U) /*!< Bit field size in bits for LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD. */

/*! @brief Read current value of the LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD field. */
#define BR_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD(x) (HW_LCDIF_CTRL1(x).B.START_INTERLACE_FROM_SECOND_FIELD)

/*! @brief Format value for bitfield LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD. */
#define BF_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD) & BM_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD)

/*! @brief Set the START_INTERLACE_FROM_SECOND_FIELD field to a new value. */
#define BW_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD) | BF_LCDIF_CTRL1_START_INTERLACE_FROM_SECOND_FIELD(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field INTERLACE_FIELDS[23] (RW)
 *
 * Set this bit if it is required that the eLCDIF block fetches odd lines in one
 * field and even lines in the other field. It will work only in LCDIF_MASTER is
 * set to 1.
 */
/*@{*/
#define BP_LCDIF_CTRL1_INTERLACE_FIELDS (23U) /*!< Bit position for LCDIF_CTRL1_INTERLACE_FIELDS. */
#define BM_LCDIF_CTRL1_INTERLACE_FIELDS (0x00800000U) /*!< Bit mask for LCDIF_CTRL1_INTERLACE_FIELDS. */
#define BS_LCDIF_CTRL1_INTERLACE_FIELDS (1U) /*!< Bit field size in bits for LCDIF_CTRL1_INTERLACE_FIELDS. */

/*! @brief Read current value of the LCDIF_CTRL1_INTERLACE_FIELDS field. */
#define BR_LCDIF_CTRL1_INTERLACE_FIELDS(x) (HW_LCDIF_CTRL1(x).B.INTERLACE_FIELDS)

/*! @brief Format value for bitfield LCDIF_CTRL1_INTERLACE_FIELDS. */
#define BF_LCDIF_CTRL1_INTERLACE_FIELDS(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_INTERLACE_FIELDS) & BM_LCDIF_CTRL1_INTERLACE_FIELDS)

/*! @brief Set the INTERLACE_FIELDS field to a new value. */
#define BW_LCDIF_CTRL1_INTERLACE_FIELDS(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_INTERLACE_FIELDS) | BF_LCDIF_CTRL1_INTERLACE_FIELDS(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field RECOVER_ON_UNDERFLOW[24] (RW)
 *
 * Set this bit to enable the eLCDIF block to recover in the next field/frame if
 * there was an underflow in the current field/frame.
 */
/*@{*/
#define BP_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW (24U) /*!< Bit position for LCDIF_CTRL1_RECOVER_ON_UNDERFLOW. */
#define BM_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW (0x01000000U) /*!< Bit mask for LCDIF_CTRL1_RECOVER_ON_UNDERFLOW. */
#define BS_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW (1U) /*!< Bit field size in bits for LCDIF_CTRL1_RECOVER_ON_UNDERFLOW. */

/*! @brief Read current value of the LCDIF_CTRL1_RECOVER_ON_UNDERFLOW field. */
#define BR_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW(x) (HW_LCDIF_CTRL1(x).B.RECOVER_ON_UNDERFLOW)

/*! @brief Format value for bitfield LCDIF_CTRL1_RECOVER_ON_UNDERFLOW. */
#define BF_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW) & BM_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW)

/*! @brief Set the RECOVER_ON_UNDERFLOW field to a new value. */
#define BW_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW) | BF_LCDIF_CTRL1_RECOVER_ON_UNDERFLOW(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field BM_ERROR_IRQ[25] (RW)
 *
 * This bit is set to indicate that an interrupt is requested by the eLCDIF
 * block. This bit is cleared by software by writing a one to its SCT clear address.
 * This bit will be set when the eLCDIF is in master mode and an error response
 * was returned by the slave.
 *
 * Values:
 * - 0 - No Interrupt Request Pending.
 * - 1 - Interrupt Request Pending.
 */
/*@{*/
#define BP_LCDIF_CTRL1_BM_ERROR_IRQ (25U)  /*!< Bit position for LCDIF_CTRL1_BM_ERROR_IRQ. */
#define BM_LCDIF_CTRL1_BM_ERROR_IRQ (0x02000000U) /*!< Bit mask for LCDIF_CTRL1_BM_ERROR_IRQ. */
#define BS_LCDIF_CTRL1_BM_ERROR_IRQ (1U)   /*!< Bit field size in bits for LCDIF_CTRL1_BM_ERROR_IRQ. */

#define BV_LCDIF_CTRL1_BM_ERROR_IRQ_NO_REQUEST (0U)  /*!< Bit field value for LCDIF_CTRL1_BM_ERROR_IRQ: No Interrupt Request Pending. */
#define BV_LCDIF_CTRL1_BM_ERROR_IRQ_REQUEST (0x1U)   /*!< Bit field value for LCDIF_CTRL1_BM_ERROR_IRQ: Interrupt Request Pending. */

/*! @brief Read current value of the LCDIF_CTRL1_BM_ERROR_IRQ field. */
#define BR_LCDIF_CTRL1_BM_ERROR_IRQ(x) (HW_LCDIF_CTRL1(x).B.BM_ERROR_IRQ)

/*! @brief Format value for bitfield LCDIF_CTRL1_BM_ERROR_IRQ. */
#define BF_LCDIF_CTRL1_BM_ERROR_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_BM_ERROR_IRQ) & BM_LCDIF_CTRL1_BM_ERROR_IRQ)

/*! @brief Set the BM_ERROR_IRQ field to a new value. */
#define BW_LCDIF_CTRL1_BM_ERROR_IRQ(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_BM_ERROR_IRQ) | BF_LCDIF_CTRL1_BM_ERROR_IRQ(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field BM_ERROR_IRQ_EN[26] (RW)
 *
 * This bit is set to enable bus master error interrupt in the eLCDIF master
 * mode.
 */
/*@{*/
#define BP_LCDIF_CTRL1_BM_ERROR_IRQ_EN (26U) /*!< Bit position for LCDIF_CTRL1_BM_ERROR_IRQ_EN. */
#define BM_LCDIF_CTRL1_BM_ERROR_IRQ_EN (0x04000000U) /*!< Bit mask for LCDIF_CTRL1_BM_ERROR_IRQ_EN. */
#define BS_LCDIF_CTRL1_BM_ERROR_IRQ_EN (1U) /*!< Bit field size in bits for LCDIF_CTRL1_BM_ERROR_IRQ_EN. */

/*! @brief Read current value of the LCDIF_CTRL1_BM_ERROR_IRQ_EN field. */
#define BR_LCDIF_CTRL1_BM_ERROR_IRQ_EN(x) (HW_LCDIF_CTRL1(x).B.BM_ERROR_IRQ_EN)

/*! @brief Format value for bitfield LCDIF_CTRL1_BM_ERROR_IRQ_EN. */
#define BF_LCDIF_CTRL1_BM_ERROR_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_BM_ERROR_IRQ_EN) & BM_LCDIF_CTRL1_BM_ERROR_IRQ_EN)

/*! @brief Set the BM_ERROR_IRQ_EN field to a new value. */
#define BW_LCDIF_CTRL1_BM_ERROR_IRQ_EN(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_BM_ERROR_IRQ_EN) | BF_LCDIF_CTRL1_BM_ERROR_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field COMBINE_MPU_WR_STRB[27] (RW)
 *
 * If this bit is not set, the write strobe will be driven on LCD_WR_RWn pin in
 * the 8080 mode and on the LCD_RD_E pin in the 6800 mode. If it is set, the
 * write strobe of both the 6800 and 8080 modes will be driven only on the LCD_WR_RWn
 * pin. Note that this does not work for read strobe.
 */
/*@{*/
#define BP_LCDIF_CTRL1_COMBINE_MPU_WR_STRB (27U) /*!< Bit position for LCDIF_CTRL1_COMBINE_MPU_WR_STRB. */
#define BM_LCDIF_CTRL1_COMBINE_MPU_WR_STRB (0x08000000U) /*!< Bit mask for LCDIF_CTRL1_COMBINE_MPU_WR_STRB. */
#define BS_LCDIF_CTRL1_COMBINE_MPU_WR_STRB (1U) /*!< Bit field size in bits for LCDIF_CTRL1_COMBINE_MPU_WR_STRB. */

/*! @brief Read current value of the LCDIF_CTRL1_COMBINE_MPU_WR_STRB field. */
#define BR_LCDIF_CTRL1_COMBINE_MPU_WR_STRB(x) (HW_LCDIF_CTRL1(x).B.COMBINE_MPU_WR_STRB)

/*! @brief Format value for bitfield LCDIF_CTRL1_COMBINE_MPU_WR_STRB. */
#define BF_LCDIF_CTRL1_COMBINE_MPU_WR_STRB(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL1_COMBINE_MPU_WR_STRB) & BM_LCDIF_CTRL1_COMBINE_MPU_WR_STRB)

/*! @brief Set the COMBINE_MPU_WR_STRB field to a new value. */
#define BW_LCDIF_CTRL1_COMBINE_MPU_WR_STRB(x, v) (HW_LCDIF_CTRL1_WR(x, (HW_LCDIF_CTRL1_RD(x) & ~BM_LCDIF_CTRL1_COMBINE_MPU_WR_STRB) | BF_LCDIF_CTRL1_COMBINE_MPU_WR_STRB(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL1, field RSRVD1[31:28] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_CTRL1_RSRVD1 (28U)        /*!< Bit position for LCDIF_CTRL1_RSRVD1. */
#define BM_LCDIF_CTRL1_RSRVD1 (0xF0000000U) /*!< Bit mask for LCDIF_CTRL1_RSRVD1. */
#define BS_LCDIF_CTRL1_RSRVD1 (4U)         /*!< Bit field size in bits for LCDIF_CTRL1_RSRVD1. */
/*@}*/




/*******************************************************************************
 * HW_LCDIF_CTRL2 - eLCDIF General Control2 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CTRL2 - eLCDIF General Control2 Register (RW)
 *
 * Reset value: 0x00200000U
 *
 * The eLCDIF Control Register provides overall control of the eLCDIF block. The
 * eLCDIF Control2 Register provides additional programming to the eLCDIF. It
 * implements some bits which are unlikely to change often in a particular
 * application.
 */
typedef union _hw_lcdif_ctrl2
{
    uint32_t U;
    struct _hw_lcdif_ctrl2_bitfields
    {
        uint32_t RSRVD0 : 1;           /*!< [0]  */
        uint32_t INITIAL_DUMMY_READ : 3; /*!< [3:1]  */
        uint32_t READ_MODE_NUM_PACKED_SUBWORDS : 3; /*!< [6:4]  */
        uint32_t RSRVD1 : 1;           /*!< [7]  */
        uint32_t READ_MODE_6_BIT_INPUT : 1; /*!< [8]  */
        uint32_t READ_MODE_OUTPUT_IN_RGB_FORMAT : 1; /*!< [9]  */
        uint32_t READ_PACK_DIR : 1;    /*!< [10]  */
        uint32_t RSRVD2 : 1;           /*!< [11]  */
        uint32_t EVEN_LINE_PATTERN : 3; /*!< [14:12]  */
        uint32_t RSRVD3 : 1;           /*!< [15]  */
        uint32_t ODD_LINE_PATTERN : 3; /*!< [18:16]  */
        uint32_t RSRVD4 : 1;           /*!< [19]  */
        uint32_t BURST_LEN_8 : 1;      /*!< [20]  */
        uint32_t OUTSTANDING_REQS : 3; /*!< [23:21]  */
        uint32_t RSRVD5 : 8;           /*!< [31:24]  */
    } B;
} hw_lcdif_ctrl2_t;

/*!
 * @name Constants and macros for entire LCDIF_CTRL2 register
 */
/*@{*/
#define HW_LCDIF_CTRL2_ADDR(x)   ((uintptr_t)(x) + 0x20U)
#define HW_LCDIF_CTRL2_SET_ADDR(x) (HW_LCDIF_CTRL2_ADDR(x) + 0x4U)
#define HW_LCDIF_CTRL2_CLR_ADDR(x) (HW_LCDIF_CTRL2_ADDR(x) + 0x8U)
#define HW_LCDIF_CTRL2_TOG_ADDR(x) (HW_LCDIF_CTRL2_ADDR(x) + 0xCU)

#define HW_LCDIF_CTRL2(x)        (*(__IO hw_lcdif_ctrl2_t *) HW_LCDIF_CTRL2_ADDR(x))
#define HW_LCDIF_CTRL2_RD(x)     (HW_LCDIF_CTRL2(x).U)
#define HW_LCDIF_CTRL2_WR(x, v)  (HW_LCDIF_CTRL2(x).U = (v))
#define HW_LCDIF_CTRL2_SET(x, v) ((*(uint32_t *) HW_LCDIF_CTRL2_SET_ADDR(x)) = (v))
#define HW_LCDIF_CTRL2_CLR(x, v) ((*(uint32_t *) HW_LCDIF_CTRL2_CLR_ADDR(x)) = (v))
#define HW_LCDIF_CTRL2_TOG(x, v) ((*(uint32_t *) HW_LCDIF_CTRL2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CTRL2 bitfields
 */

/*!
 * @name Register LCDIF_CTRL2, field RSRVD0[0] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_CTRL2_RSRVD0 (0U)         /*!< Bit position for LCDIF_CTRL2_RSRVD0. */
#define BM_LCDIF_CTRL2_RSRVD0 (0x00000001U) /*!< Bit mask for LCDIF_CTRL2_RSRVD0. */
#define BS_LCDIF_CTRL2_RSRVD0 (1U)         /*!< Bit field size in bits for LCDIF_CTRL2_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field INITIAL_DUMMY_READ[3:1] (RW)
 *
 * The value in this field determines the number of dummy 8/16/18/24-bit
 * subwords that have to be read back from the LCD panel/controller. They will then not
 * be stored in the read FIFO.
 */
/*@{*/
#define BP_LCDIF_CTRL2_INITIAL_DUMMY_READ (1U) /*!< Bit position for LCDIF_CTRL2_INITIAL_DUMMY_READ. */
#define BM_LCDIF_CTRL2_INITIAL_DUMMY_READ (0x0000000EU) /*!< Bit mask for LCDIF_CTRL2_INITIAL_DUMMY_READ. */
#define BS_LCDIF_CTRL2_INITIAL_DUMMY_READ (3U) /*!< Bit field size in bits for LCDIF_CTRL2_INITIAL_DUMMY_READ. */

/*! @brief Read current value of the LCDIF_CTRL2_INITIAL_DUMMY_READ field. */
#define BR_LCDIF_CTRL2_INITIAL_DUMMY_READ(x) (HW_LCDIF_CTRL2(x).B.INITIAL_DUMMY_READ)

/*! @brief Format value for bitfield LCDIF_CTRL2_INITIAL_DUMMY_READ. */
#define BF_LCDIF_CTRL2_INITIAL_DUMMY_READ(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL2_INITIAL_DUMMY_READ) & BM_LCDIF_CTRL2_INITIAL_DUMMY_READ)

/*! @brief Set the INITIAL_DUMMY_READ field to a new value. */
#define BW_LCDIF_CTRL2_INITIAL_DUMMY_READ(x, v) (HW_LCDIF_CTRL2_WR(x, (HW_LCDIF_CTRL2_RD(x) & ~BM_LCDIF_CTRL2_INITIAL_DUMMY_READ) | BF_LCDIF_CTRL2_INITIAL_DUMMY_READ(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field READ_MODE_NUM_PACKED_SUBWORDS[6:4] (RW)
 *
 * Indicates the number of valid 8/16/18/24-bit subwords that will be packed
 * into the 32-bit word in read mode. The subword size (8,16, 18 or 24 bits) is
 * determined by the LCD_DATABUS_WIDTH field. The swizzle operation is performed
 * after READ_MODE_NUM_PACKED_SUBWORDS number of subwords has been received and
 * stored in little-endian format. For example, if LCD_DATABUS_WIDTH is set to 8-bit
 * and data to be read back has to be stored in memory in 24-bit unpacked RGB
 * format, set READ_MODE_NUM_PACKED_SUBWORDS to 0x3 so that each 32-bit word will
 * contain only 3 valid bytes (RGB). Maximum value of READ_MODE_NUM_PACKED_SUBWORDS
 * is 4 for 8-bit databus, 2 for 16-bit databus and 1 for 18/24-bit databus.
 */
/*@{*/
#define BP_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS (4U) /*!< Bit position for LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS. */
#define BM_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS (0x00000070U) /*!< Bit mask for LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS. */
#define BS_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS (3U) /*!< Bit field size in bits for LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS. */

/*! @brief Read current value of the LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS field. */
#define BR_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS(x) (HW_LCDIF_CTRL2(x).B.READ_MODE_NUM_PACKED_SUBWORDS)

/*! @brief Format value for bitfield LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS. */
#define BF_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS) & BM_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS)

/*! @brief Set the READ_MODE_NUM_PACKED_SUBWORDS field to a new value. */
#define BW_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS(x, v) (HW_LCDIF_CTRL2_WR(x, (HW_LCDIF_CTRL2_RD(x) & ~BM_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS) | BF_LCDIF_CTRL2_READ_MODE_NUM_PACKED_SUBWORDS(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field RSRVD1[7] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_CTRL2_RSRVD1 (7U)         /*!< Bit position for LCDIF_CTRL2_RSRVD1. */
#define BM_LCDIF_CTRL2_RSRVD1 (0x00000080U) /*!< Bit mask for LCDIF_CTRL2_RSRVD1. */
#define BS_LCDIF_CTRL2_RSRVD1 (1U)         /*!< Bit field size in bits for LCDIF_CTRL2_RSRVD1. */
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field READ_MODE_6_BIT_INPUT[8] (RW)
 *
 * Setting this bit to 1 indicates to eLCDIF that even though LCD_DATABUS_WIDTH
 * is set to 8 bits, the input data is actually only 6 bits wide and exists on
 * D5-D0.
 */
/*@{*/
#define BP_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT (8U) /*!< Bit position for LCDIF_CTRL2_READ_MODE_6_BIT_INPUT. */
#define BM_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT (0x00000100U) /*!< Bit mask for LCDIF_CTRL2_READ_MODE_6_BIT_INPUT. */
#define BS_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT (1U) /*!< Bit field size in bits for LCDIF_CTRL2_READ_MODE_6_BIT_INPUT. */

/*! @brief Read current value of the LCDIF_CTRL2_READ_MODE_6_BIT_INPUT field. */
#define BR_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT(x) (HW_LCDIF_CTRL2(x).B.READ_MODE_6_BIT_INPUT)

/*! @brief Format value for bitfield LCDIF_CTRL2_READ_MODE_6_BIT_INPUT. */
#define BF_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT) & BM_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT)

/*! @brief Set the READ_MODE_6_BIT_INPUT field to a new value. */
#define BW_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT(x, v) (HW_LCDIF_CTRL2_WR(x, (HW_LCDIF_CTRL2_RD(x) & ~BM_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT) | BF_LCDIF_CTRL2_READ_MODE_6_BIT_INPUT(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field READ_MODE_OUTPUT_IN_RGB_FORMAT[9] (RW)
 *
 * Setting this bit will enable the eLCDIF to convert the incoming data to the
 * RGB format given by WORD_LENGTH bitfield. This feature is not available when
 * WORD_LENGTH is set to 8 bits. eLCDIF performs this operation of converting to
 * RGB format after the endianness has been determined by the READ_PACK_DIR
 * bitfield.
 */
/*@{*/
#define BP_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT (9U) /*!< Bit position for LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT. */
#define BM_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT (0x00000200U) /*!< Bit mask for LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT. */
#define BS_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT (1U) /*!< Bit field size in bits for LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT. */

/*! @brief Read current value of the LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT field. */
#define BR_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT(x) (HW_LCDIF_CTRL2(x).B.READ_MODE_OUTPUT_IN_RGB_FORMAT)

/*! @brief Format value for bitfield LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT. */
#define BF_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT) & BM_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT)

/*! @brief Set the READ_MODE_OUTPUT_IN_RGB_FORMAT field to a new value. */
#define BW_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT(x, v) (HW_LCDIF_CTRL2_WR(x, (HW_LCDIF_CTRL2_RD(x) & ~BM_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT) | BF_LCDIF_CTRL2_READ_MODE_OUTPUT_IN_RGB_FORMAT(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field READ_PACK_DIR[10] (RW)
 *
 * The default value of 0 indicates data is stored in the little endian format.
 * When LCD_DATABUS_WIDTH is 8-bit, this bit provides the option of rearranging
 * the data byte-wise in the big endian format. For example, if
 * READ_MODE_NUM_PACKED_SUBWORDS = 3 and the order of incoming data is 0x11, 0x22 and 0x33, then
 * setting this bit to 1 will cause the data to be stored as 0x00112233 as opposed
 * to the default 0x00332211. This operation occurs after the shifting operation
 * done by SHIFT_NUM_BITS bitfield.
 */
/*@{*/
#define BP_LCDIF_CTRL2_READ_PACK_DIR (10U) /*!< Bit position for LCDIF_CTRL2_READ_PACK_DIR. */
#define BM_LCDIF_CTRL2_READ_PACK_DIR (0x00000400U) /*!< Bit mask for LCDIF_CTRL2_READ_PACK_DIR. */
#define BS_LCDIF_CTRL2_READ_PACK_DIR (1U)  /*!< Bit field size in bits for LCDIF_CTRL2_READ_PACK_DIR. */

/*! @brief Read current value of the LCDIF_CTRL2_READ_PACK_DIR field. */
#define BR_LCDIF_CTRL2_READ_PACK_DIR(x) (HW_LCDIF_CTRL2(x).B.READ_PACK_DIR)

/*! @brief Format value for bitfield LCDIF_CTRL2_READ_PACK_DIR. */
#define BF_LCDIF_CTRL2_READ_PACK_DIR(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL2_READ_PACK_DIR) & BM_LCDIF_CTRL2_READ_PACK_DIR)

/*! @brief Set the READ_PACK_DIR field to a new value. */
#define BW_LCDIF_CTRL2_READ_PACK_DIR(x, v) (HW_LCDIF_CTRL2_WR(x, (HW_LCDIF_CTRL2_RD(x) & ~BM_LCDIF_CTRL2_READ_PACK_DIR) | BF_LCDIF_CTRL2_READ_PACK_DIR(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field RSRVD2[11] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_CTRL2_RSRVD2 (11U)        /*!< Bit position for LCDIF_CTRL2_RSRVD2. */
#define BM_LCDIF_CTRL2_RSRVD2 (0x00000800U) /*!< Bit mask for LCDIF_CTRL2_RSRVD2. */
#define BS_LCDIF_CTRL2_RSRVD2 (1U)         /*!< Bit field size in bits for LCDIF_CTRL2_RSRVD2. */
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field EVEN_LINE_PATTERN[14:12] (RW)
 *
 * This field determines the order of the RGB components of each pixel in EVEN
 * lines (line numbers 2,4,6,..). This bitfield must be 0 in DVI mode.
 *
 * Values:
 * - 0 -
 * - 1 -
 * - 10 -
 * - 11 -
 * - 100 -
 * - 101 -
 */
/*@{*/
#define BP_LCDIF_CTRL2_EVEN_LINE_PATTERN (12U) /*!< Bit position for LCDIF_CTRL2_EVEN_LINE_PATTERN. */
#define BM_LCDIF_CTRL2_EVEN_LINE_PATTERN (0x00007000U) /*!< Bit mask for LCDIF_CTRL2_EVEN_LINE_PATTERN. */
#define BS_LCDIF_CTRL2_EVEN_LINE_PATTERN (3U) /*!< Bit field size in bits for LCDIF_CTRL2_EVEN_LINE_PATTERN. */

#define BV_LCDIF_CTRL2_EVEN_LINE_PATTERN_RGB (0U)    /*!< Bit field value for LCDIF_CTRL2_EVEN_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_EVEN_LINE_PATTERN_RBG (0x1U)  /*!< Bit field value for LCDIF_CTRL2_EVEN_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_EVEN_LINE_PATTERN_GBR (0x2U)  /*!< Bit field value for LCDIF_CTRL2_EVEN_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_EVEN_LINE_PATTERN_GRB (0x3U)  /*!< Bit field value for LCDIF_CTRL2_EVEN_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_EVEN_LINE_PATTERN_BRG (0x4U)  /*!< Bit field value for LCDIF_CTRL2_EVEN_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_EVEN_LINE_PATTERN_BGR (0x5U)  /*!< Bit field value for LCDIF_CTRL2_EVEN_LINE_PATTERN:  */

/*! @brief Read current value of the LCDIF_CTRL2_EVEN_LINE_PATTERN field. */
#define BR_LCDIF_CTRL2_EVEN_LINE_PATTERN(x) (HW_LCDIF_CTRL2(x).B.EVEN_LINE_PATTERN)

/*! @brief Format value for bitfield LCDIF_CTRL2_EVEN_LINE_PATTERN. */
#define BF_LCDIF_CTRL2_EVEN_LINE_PATTERN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL2_EVEN_LINE_PATTERN) & BM_LCDIF_CTRL2_EVEN_LINE_PATTERN)

/*! @brief Set the EVEN_LINE_PATTERN field to a new value. */
#define BW_LCDIF_CTRL2_EVEN_LINE_PATTERN(x, v) (HW_LCDIF_CTRL2_WR(x, (HW_LCDIF_CTRL2_RD(x) & ~BM_LCDIF_CTRL2_EVEN_LINE_PATTERN) | BF_LCDIF_CTRL2_EVEN_LINE_PATTERN(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field RSRVD3[15] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_CTRL2_RSRVD3 (15U)        /*!< Bit position for LCDIF_CTRL2_RSRVD3. */
#define BM_LCDIF_CTRL2_RSRVD3 (0x00008000U) /*!< Bit mask for LCDIF_CTRL2_RSRVD3. */
#define BS_LCDIF_CTRL2_RSRVD3 (1U)         /*!< Bit field size in bits for LCDIF_CTRL2_RSRVD3. */
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field ODD_LINE_PATTERN[18:16] (RW)
 *
 * This field determines the order of the RGB components of each pixel in ODD
 * lines (line numbers 1,3,5,..). This bitfield must be 0 in DVI mode.
 *
 * Values:
 * - 0 -
 * - 1 -
 * - 10 -
 * - 11 -
 * - 100 -
 * - 101 -
 */
/*@{*/
#define BP_LCDIF_CTRL2_ODD_LINE_PATTERN (16U) /*!< Bit position for LCDIF_CTRL2_ODD_LINE_PATTERN. */
#define BM_LCDIF_CTRL2_ODD_LINE_PATTERN (0x00070000U) /*!< Bit mask for LCDIF_CTRL2_ODD_LINE_PATTERN. */
#define BS_LCDIF_CTRL2_ODD_LINE_PATTERN (3U) /*!< Bit field size in bits for LCDIF_CTRL2_ODD_LINE_PATTERN. */

#define BV_LCDIF_CTRL2_ODD_LINE_PATTERN_RGB (0U)     /*!< Bit field value for LCDIF_CTRL2_ODD_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_ODD_LINE_PATTERN_RBG (0x1U)   /*!< Bit field value for LCDIF_CTRL2_ODD_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_ODD_LINE_PATTERN_GBR (0x2U)   /*!< Bit field value for LCDIF_CTRL2_ODD_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_ODD_LINE_PATTERN_GRB (0x3U)   /*!< Bit field value for LCDIF_CTRL2_ODD_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_ODD_LINE_PATTERN_BRG (0x4U)   /*!< Bit field value for LCDIF_CTRL2_ODD_LINE_PATTERN:  */
#define BV_LCDIF_CTRL2_ODD_LINE_PATTERN_BGR (0x5U)   /*!< Bit field value for LCDIF_CTRL2_ODD_LINE_PATTERN:  */

/*! @brief Read current value of the LCDIF_CTRL2_ODD_LINE_PATTERN field. */
#define BR_LCDIF_CTRL2_ODD_LINE_PATTERN(x) (HW_LCDIF_CTRL2(x).B.ODD_LINE_PATTERN)

/*! @brief Format value for bitfield LCDIF_CTRL2_ODD_LINE_PATTERN. */
#define BF_LCDIF_CTRL2_ODD_LINE_PATTERN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL2_ODD_LINE_PATTERN) & BM_LCDIF_CTRL2_ODD_LINE_PATTERN)

/*! @brief Set the ODD_LINE_PATTERN field to a new value. */
#define BW_LCDIF_CTRL2_ODD_LINE_PATTERN(x, v) (HW_LCDIF_CTRL2_WR(x, (HW_LCDIF_CTRL2_RD(x) & ~BM_LCDIF_CTRL2_ODD_LINE_PATTERN) | BF_LCDIF_CTRL2_ODD_LINE_PATTERN(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field RSRVD4[19] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_CTRL2_RSRVD4 (19U)        /*!< Bit position for LCDIF_CTRL2_RSRVD4. */
#define BM_LCDIF_CTRL2_RSRVD4 (0x00080000U) /*!< Bit mask for LCDIF_CTRL2_RSRVD4. */
#define BS_LCDIF_CTRL2_RSRVD4 (1U)         /*!< Bit field size in bits for LCDIF_CTRL2_RSRVD4. */
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field BURST_LEN_8[20] (RW)
 *
 * By default, when the eLCDIF is in the bus master mode, it will issue AXI
 * bursts of length 16 (except when in packed 24 bpp mode, it will issue bursts of
 * length 15). When this bit is set to 1, the block will issue bursts of length 8
 * (except when in packed 24 bpp mode, it will issue bursts of length 9). Note
 * that this bitfield is only applicable when LCDIF_MASTER is set to 1.
 */
/*@{*/
#define BP_LCDIF_CTRL2_BURST_LEN_8 (20U)   /*!< Bit position for LCDIF_CTRL2_BURST_LEN_8. */
#define BM_LCDIF_CTRL2_BURST_LEN_8 (0x00100000U) /*!< Bit mask for LCDIF_CTRL2_BURST_LEN_8. */
#define BS_LCDIF_CTRL2_BURST_LEN_8 (1U)    /*!< Bit field size in bits for LCDIF_CTRL2_BURST_LEN_8. */

/*! @brief Read current value of the LCDIF_CTRL2_BURST_LEN_8 field. */
#define BR_LCDIF_CTRL2_BURST_LEN_8(x) (HW_LCDIF_CTRL2(x).B.BURST_LEN_8)

/*! @brief Format value for bitfield LCDIF_CTRL2_BURST_LEN_8. */
#define BF_LCDIF_CTRL2_BURST_LEN_8(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL2_BURST_LEN_8) & BM_LCDIF_CTRL2_BURST_LEN_8)

/*! @brief Set the BURST_LEN_8 field to a new value. */
#define BW_LCDIF_CTRL2_BURST_LEN_8(x, v) (HW_LCDIF_CTRL2_WR(x, (HW_LCDIF_CTRL2_RD(x) & ~BM_LCDIF_CTRL2_BURST_LEN_8) | BF_LCDIF_CTRL2_BURST_LEN_8(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field OUTSTANDING_REQS[23:21] (RW)
 *
 * This bitfield indicates the maximum number of outstanding transactions that
 * eLCDIF should request when it is acting as a bus master. Default is 2
 * outstanding transactions.
 *
 * Values:
 * - 0 -
 * - 1 -
 * - 10 -
 * - 11 -
 * - 100 -
 */
/*@{*/
#define BP_LCDIF_CTRL2_OUTSTANDING_REQS (21U) /*!< Bit position for LCDIF_CTRL2_OUTSTANDING_REQS. */
#define BM_LCDIF_CTRL2_OUTSTANDING_REQS (0x00E00000U) /*!< Bit mask for LCDIF_CTRL2_OUTSTANDING_REQS. */
#define BS_LCDIF_CTRL2_OUTSTANDING_REQS (3U) /*!< Bit field size in bits for LCDIF_CTRL2_OUTSTANDING_REQS. */

#define BV_LCDIF_CTRL2_OUTSTANDING_REQS_REQ_1 (0U)   /*!< Bit field value for LCDIF_CTRL2_OUTSTANDING_REQS:  */
#define BV_LCDIF_CTRL2_OUTSTANDING_REQS_REQ_2 (0x1U) /*!< Bit field value for LCDIF_CTRL2_OUTSTANDING_REQS:  */
#define BV_LCDIF_CTRL2_OUTSTANDING_REQS_REQ_4 (0x2U) /*!< Bit field value for LCDIF_CTRL2_OUTSTANDING_REQS:  */
#define BV_LCDIF_CTRL2_OUTSTANDING_REQS_REQ_8 (0x3U) /*!< Bit field value for LCDIF_CTRL2_OUTSTANDING_REQS:  */
#define BV_LCDIF_CTRL2_OUTSTANDING_REQS_REQ_16 (0x4U) /*!< Bit field value for LCDIF_CTRL2_OUTSTANDING_REQS:  */

/*! @brief Read current value of the LCDIF_CTRL2_OUTSTANDING_REQS field. */
#define BR_LCDIF_CTRL2_OUTSTANDING_REQS(x) (HW_LCDIF_CTRL2(x).B.OUTSTANDING_REQS)

/*! @brief Format value for bitfield LCDIF_CTRL2_OUTSTANDING_REQS. */
#define BF_LCDIF_CTRL2_OUTSTANDING_REQS(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CTRL2_OUTSTANDING_REQS) & BM_LCDIF_CTRL2_OUTSTANDING_REQS)

/*! @brief Set the OUTSTANDING_REQS field to a new value. */
#define BW_LCDIF_CTRL2_OUTSTANDING_REQS(x, v) (HW_LCDIF_CTRL2_WR(x, (HW_LCDIF_CTRL2_RD(x) & ~BM_LCDIF_CTRL2_OUTSTANDING_REQS) | BF_LCDIF_CTRL2_OUTSTANDING_REQS(v)))
/*@}*/

/*!
 * @name Register LCDIF_CTRL2, field RSRVD5[31:24] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_CTRL2_RSRVD5 (24U)        /*!< Bit position for LCDIF_CTRL2_RSRVD5. */
#define BM_LCDIF_CTRL2_RSRVD5 (0xFF000000U) /*!< Bit mask for LCDIF_CTRL2_RSRVD5. */
#define BS_LCDIF_CTRL2_RSRVD5 (8U)         /*!< Bit field size in bits for LCDIF_CTRL2_RSRVD5. */
/*@}*/




/*******************************************************************************
 * HW_LCDIF_TRANSFER_COUNT - eLCDIF Horizontal and Vertical Valid Data Count Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_TRANSFER_COUNT - eLCDIF Horizontal and Vertical Valid Data Count Register (RW)
 *
 * Reset value: 0x00010000U
 *
 * This register tells the eLCDIF how much data will be sent for this frame, or
 * transaction. The total number of words is a product of the V_COUNT and H_COUNT
 * fields. The word size is specified by the WORD_LENGTH field. This register
 * gives the dimensions of the input frame. For normal operation, but V_COUNT and
 * H_COUNT should be non-zero.
 */
typedef union _hw_lcdif_transfer_count
{
    uint32_t U;
    struct _hw_lcdif_transfer_count_bitfields
    {
        uint32_t H_COUNT : 16;         /*!< [15:0]  */
        uint32_t V_COUNT : 16;         /*!< [31:16]  */
    } B;
} hw_lcdif_transfer_count_t;

/*!
 * @name Constants and macros for entire LCDIF_TRANSFER_COUNT register
 */
/*@{*/
#define HW_LCDIF_TRANSFER_COUNT_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_LCDIF_TRANSFER_COUNT(x) (*(__IO hw_lcdif_transfer_count_t *) HW_LCDIF_TRANSFER_COUNT_ADDR(x))
#define HW_LCDIF_TRANSFER_COUNT_RD(x) (HW_LCDIF_TRANSFER_COUNT(x).U)
#define HW_LCDIF_TRANSFER_COUNT_WR(x, v) (HW_LCDIF_TRANSFER_COUNT(x).U = (v))
#define HW_LCDIF_TRANSFER_COUNT_SET(x, v) (HW_LCDIF_TRANSFER_COUNT_WR(x, HW_LCDIF_TRANSFER_COUNT_RD(x) |  (v)))
#define HW_LCDIF_TRANSFER_COUNT_CLR(x, v) (HW_LCDIF_TRANSFER_COUNT_WR(x, HW_LCDIF_TRANSFER_COUNT_RD(x) & ~(v)))
#define HW_LCDIF_TRANSFER_COUNT_TOG(x, v) (HW_LCDIF_TRANSFER_COUNT_WR(x, HW_LCDIF_TRANSFER_COUNT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_TRANSFER_COUNT bitfields
 */

/*!
 * @name Register LCDIF_TRANSFER_COUNT, field H_COUNT[15:0] (RW)
 *
 * Total valid data (pixels) in each horizontal line. The data size is given by
 * the WORD_LENGTH. When input data is in YCbCr 4:2:2 format (YCBCR422_INPUT is
 * 1), H_COUNT should be the number of 32-bit words that should be fetched by the
 * block and the BYTE_PACKING_FORMAT should be 0xF. In 24-bit packed format
 * (WORD_LENGTH=0x3, BYTE_PACKING_FORMAT=0xF), the H_COUNT must be a multiple of 4
 * pixels. In 16-bit packed format (WORD_LENGTH=0x0, BYTE_PACKING_FORMAT=0xF), the
 * H_COUNT must be a multiple of 2 pixels.
 */
/*@{*/
#define BP_LCDIF_TRANSFER_COUNT_H_COUNT (0U) /*!< Bit position for LCDIF_TRANSFER_COUNT_H_COUNT. */
#define BM_LCDIF_TRANSFER_COUNT_H_COUNT (0x0000FFFFU) /*!< Bit mask for LCDIF_TRANSFER_COUNT_H_COUNT. */
#define BS_LCDIF_TRANSFER_COUNT_H_COUNT (16U) /*!< Bit field size in bits for LCDIF_TRANSFER_COUNT_H_COUNT. */

/*! @brief Read current value of the LCDIF_TRANSFER_COUNT_H_COUNT field. */
#define BR_LCDIF_TRANSFER_COUNT_H_COUNT(x) (HW_LCDIF_TRANSFER_COUNT(x).B.H_COUNT)

/*! @brief Format value for bitfield LCDIF_TRANSFER_COUNT_H_COUNT. */
#define BF_LCDIF_TRANSFER_COUNT_H_COUNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_TRANSFER_COUNT_H_COUNT) & BM_LCDIF_TRANSFER_COUNT_H_COUNT)

/*! @brief Set the H_COUNT field to a new value. */
#define BW_LCDIF_TRANSFER_COUNT_H_COUNT(x, v) (HW_LCDIF_TRANSFER_COUNT_WR(x, (HW_LCDIF_TRANSFER_COUNT_RD(x) & ~BM_LCDIF_TRANSFER_COUNT_H_COUNT) | BF_LCDIF_TRANSFER_COUNT_H_COUNT(v)))
/*@}*/

/*!
 * @name Register LCDIF_TRANSFER_COUNT, field V_COUNT[31:16] (RW)
 *
 * Number of horizontal lines per frame which contain valid data. In DOTCLK
 * mode, V_COUNT should be the same as the number of active horizontal lines in a
 * progressive frame. In DVI mode, V_COUNT should be the number of active horizontal
 * lines per frame, and not per field.
 */
/*@{*/
#define BP_LCDIF_TRANSFER_COUNT_V_COUNT (16U) /*!< Bit position for LCDIF_TRANSFER_COUNT_V_COUNT. */
#define BM_LCDIF_TRANSFER_COUNT_V_COUNT (0xFFFF0000U) /*!< Bit mask for LCDIF_TRANSFER_COUNT_V_COUNT. */
#define BS_LCDIF_TRANSFER_COUNT_V_COUNT (16U) /*!< Bit field size in bits for LCDIF_TRANSFER_COUNT_V_COUNT. */

/*! @brief Read current value of the LCDIF_TRANSFER_COUNT_V_COUNT field. */
#define BR_LCDIF_TRANSFER_COUNT_V_COUNT(x) (HW_LCDIF_TRANSFER_COUNT(x).B.V_COUNT)

/*! @brief Format value for bitfield LCDIF_TRANSFER_COUNT_V_COUNT. */
#define BF_LCDIF_TRANSFER_COUNT_V_COUNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_TRANSFER_COUNT_V_COUNT) & BM_LCDIF_TRANSFER_COUNT_V_COUNT)

/*! @brief Set the V_COUNT field to a new value. */
#define BW_LCDIF_TRANSFER_COUNT_V_COUNT(x, v) (HW_LCDIF_TRANSFER_COUNT_WR(x, (HW_LCDIF_TRANSFER_COUNT_RD(x) & ~BM_LCDIF_TRANSFER_COUNT_V_COUNT) | BF_LCDIF_TRANSFER_COUNT_V_COUNT(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_CUR_BUF - LCD Interface Current Buffer Address Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CUR_BUF - LCD Interface Current Buffer Address Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register indicates the address of the current frame being transmitted by
 * eLCDIF. When the eLCDIF is behaving as a master, this address points to the
 * address of the current frame of data being sent out via the LCDIF. When the
 * current frame is done, the LCDIF block will assert the cur_frame_done interrupt
 * for software to take action. The block will also copy the LCDIF_NEXT_BUF_ADDR
 * into this bitfield so that the software can program the next frame address into
 * the LCDIF_NEXT_BUF_ADDR bitfield. This address must always be double-word
 * aligned.
 */
typedef union _hw_lcdif_cur_buf
{
    uint32_t U;
    struct _hw_lcdif_cur_buf_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_lcdif_cur_buf_t;

/*!
 * @name Constants and macros for entire LCDIF_CUR_BUF register
 */
/*@{*/
#define HW_LCDIF_CUR_BUF_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_LCDIF_CUR_BUF(x)      (*(__IO hw_lcdif_cur_buf_t *) HW_LCDIF_CUR_BUF_ADDR(x))
#define HW_LCDIF_CUR_BUF_RD(x)   (HW_LCDIF_CUR_BUF(x).U)
#define HW_LCDIF_CUR_BUF_WR(x, v) (HW_LCDIF_CUR_BUF(x).U = (v))
#define HW_LCDIF_CUR_BUF_SET(x, v) (HW_LCDIF_CUR_BUF_WR(x, HW_LCDIF_CUR_BUF_RD(x) |  (v)))
#define HW_LCDIF_CUR_BUF_CLR(x, v) (HW_LCDIF_CUR_BUF_WR(x, HW_LCDIF_CUR_BUF_RD(x) & ~(v)))
#define HW_LCDIF_CUR_BUF_TOG(x, v) (HW_LCDIF_CUR_BUF_WR(x, HW_LCDIF_CUR_BUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CUR_BUF bitfields
 */

/*!
 * @name Register LCDIF_CUR_BUF, field ADDR[31:0] (RW)
 *
 * Address of the current frame being transmitted by eLCDIF.
 */
/*@{*/
#define BP_LCDIF_CUR_BUF_ADDR (0U)         /*!< Bit position for LCDIF_CUR_BUF_ADDR. */
#define BM_LCDIF_CUR_BUF_ADDR (0xFFFFFFFFU) /*!< Bit mask for LCDIF_CUR_BUF_ADDR. */
#define BS_LCDIF_CUR_BUF_ADDR (32U)        /*!< Bit field size in bits for LCDIF_CUR_BUF_ADDR. */

/*! @brief Read current value of the LCDIF_CUR_BUF_ADDR field. */
#define BR_LCDIF_CUR_BUF_ADDR(x) (HW_LCDIF_CUR_BUF(x).U)

/*! @brief Format value for bitfield LCDIF_CUR_BUF_ADDR. */
#define BF_LCDIF_CUR_BUF_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CUR_BUF_ADDR) & BM_LCDIF_CUR_BUF_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_LCDIF_CUR_BUF_ADDR(x, v) (HW_LCDIF_CUR_BUF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_NEXT_BUF - LCD Interface Next Buffer Address Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_NEXT_BUF - LCD Interface Next Buffer Address Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register indicates the address of next frame that will be transmitted by
 * eLCDIF. When the eLCDIF is behaving as a master, this address points to the
 * address of the next frame of data that will be sent out via the eLCDIF. It is
 * up to the software to make sure that this register is programmed before the end
 * of the current frame, otherwise it might result in old data going out the
 * eLCDIF. This address must always be double-word aligned.
 */
typedef union _hw_lcdif_next_buf
{
    uint32_t U;
    struct _hw_lcdif_next_buf_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_lcdif_next_buf_t;

/*!
 * @name Constants and macros for entire LCDIF_NEXT_BUF register
 */
/*@{*/
#define HW_LCDIF_NEXT_BUF_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_LCDIF_NEXT_BUF(x)     (*(__IO hw_lcdif_next_buf_t *) HW_LCDIF_NEXT_BUF_ADDR(x))
#define HW_LCDIF_NEXT_BUF_RD(x)  (HW_LCDIF_NEXT_BUF(x).U)
#define HW_LCDIF_NEXT_BUF_WR(x, v) (HW_LCDIF_NEXT_BUF(x).U = (v))
#define HW_LCDIF_NEXT_BUF_SET(x, v) (HW_LCDIF_NEXT_BUF_WR(x, HW_LCDIF_NEXT_BUF_RD(x) |  (v)))
#define HW_LCDIF_NEXT_BUF_CLR(x, v) (HW_LCDIF_NEXT_BUF_WR(x, HW_LCDIF_NEXT_BUF_RD(x) & ~(v)))
#define HW_LCDIF_NEXT_BUF_TOG(x, v) (HW_LCDIF_NEXT_BUF_WR(x, HW_LCDIF_NEXT_BUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_NEXT_BUF bitfields
 */

/*!
 * @name Register LCDIF_NEXT_BUF, field ADDR[31:0] (RW)
 *
 * Address of the next frame that will be transmitted by eLCDIF.
 */
/*@{*/
#define BP_LCDIF_NEXT_BUF_ADDR (0U)        /*!< Bit position for LCDIF_NEXT_BUF_ADDR. */
#define BM_LCDIF_NEXT_BUF_ADDR (0xFFFFFFFFU) /*!< Bit mask for LCDIF_NEXT_BUF_ADDR. */
#define BS_LCDIF_NEXT_BUF_ADDR (32U)       /*!< Bit field size in bits for LCDIF_NEXT_BUF_ADDR. */

/*! @brief Read current value of the LCDIF_NEXT_BUF_ADDR field. */
#define BR_LCDIF_NEXT_BUF_ADDR(x) (HW_LCDIF_NEXT_BUF(x).U)

/*! @brief Format value for bitfield LCDIF_NEXT_BUF_ADDR. */
#define BF_LCDIF_NEXT_BUF_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_NEXT_BUF_ADDR) & BM_LCDIF_NEXT_BUF_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_LCDIF_NEXT_BUF_ADDR(x, v) (HW_LCDIF_NEXT_BUF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_TIMING - LCD Interface Timing Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_TIMING - LCD Interface Timing Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LCD interface timing register controls the various setup and hold times
 * enforced by the LCD interface in the 6800/8080 MPU and VSYNC modes of
 * operation. The values used in this register are dependent on the particular LCD
 * controller used, consult the users manual for the particular controller for required
 * timings. Each field of the register must be non-zero, therefore the minimum
 * value is: 0x01010101. NOTE: the timings are not automatically adjusted if the
 * CLK_DIS_LCDIFn frequency changes-it may be necessary to adjust the timings if
 * CLK_DIS_LCDIFn changes. NOTE: Each field in this register must be non-zero for
 * the MPU and VSYNC modes to function. The settings in this register do not
 * affect the DOTCLK and DVI modes.
 */
typedef union _hw_lcdif_timing
{
    uint32_t U;
    struct _hw_lcdif_timing_bitfields
    {
        uint32_t DATA_SETUP : 8;       /*!< [7:0]  */
        uint32_t DATA_HOLD : 8;        /*!< [15:8]  */
        uint32_t CMD_SETUP : 8;        /*!< [23:16]  */
        uint32_t CMD_HOLD : 8;         /*!< [31:24]  */
    } B;
} hw_lcdif_timing_t;

/*!
 * @name Constants and macros for entire LCDIF_TIMING register
 */
/*@{*/
#define HW_LCDIF_TIMING_ADDR(x)  ((uintptr_t)(x) + 0x60U)

#define HW_LCDIF_TIMING(x)       (*(__IO hw_lcdif_timing_t *) HW_LCDIF_TIMING_ADDR(x))
#define HW_LCDIF_TIMING_RD(x)    (HW_LCDIF_TIMING(x).U)
#define HW_LCDIF_TIMING_WR(x, v) (HW_LCDIF_TIMING(x).U = (v))
#define HW_LCDIF_TIMING_SET(x, v) (HW_LCDIF_TIMING_WR(x, HW_LCDIF_TIMING_RD(x) |  (v)))
#define HW_LCDIF_TIMING_CLR(x, v) (HW_LCDIF_TIMING_WR(x, HW_LCDIF_TIMING_RD(x) & ~(v)))
#define HW_LCDIF_TIMING_TOG(x, v) (HW_LCDIF_TIMING_WR(x, HW_LCDIF_TIMING_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_TIMING bitfields
 */

/*!
 * @name Register LCDIF_TIMING, field DATA_SETUP[7:0] (RW)
 *
 * Data bus setup time in CLK_DIS_LCDIFn cycles. Also the time that the data
 * strobe is asserted in a cycle.
 */
/*@{*/
#define BP_LCDIF_TIMING_DATA_SETUP (0U)    /*!< Bit position for LCDIF_TIMING_DATA_SETUP. */
#define BM_LCDIF_TIMING_DATA_SETUP (0x000000FFU) /*!< Bit mask for LCDIF_TIMING_DATA_SETUP. */
#define BS_LCDIF_TIMING_DATA_SETUP (8U)    /*!< Bit field size in bits for LCDIF_TIMING_DATA_SETUP. */

/*! @brief Read current value of the LCDIF_TIMING_DATA_SETUP field. */
#define BR_LCDIF_TIMING_DATA_SETUP(x) (HW_LCDIF_TIMING(x).B.DATA_SETUP)

/*! @brief Format value for bitfield LCDIF_TIMING_DATA_SETUP. */
#define BF_LCDIF_TIMING_DATA_SETUP(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_TIMING_DATA_SETUP) & BM_LCDIF_TIMING_DATA_SETUP)

/*! @brief Set the DATA_SETUP field to a new value. */
#define BW_LCDIF_TIMING_DATA_SETUP(x, v) (HW_LCDIF_TIMING_WR(x, (HW_LCDIF_TIMING_RD(x) & ~BM_LCDIF_TIMING_DATA_SETUP) | BF_LCDIF_TIMING_DATA_SETUP(v)))
/*@}*/

/*!
 * @name Register LCDIF_TIMING, field DATA_HOLD[15:8] (RW)
 *
 * Data bus hold time in CLK_DIS_LCDIFn cycles. Also the time that the data
 * strobe is deasserted in a cycle
 */
/*@{*/
#define BP_LCDIF_TIMING_DATA_HOLD (8U)     /*!< Bit position for LCDIF_TIMING_DATA_HOLD. */
#define BM_LCDIF_TIMING_DATA_HOLD (0x0000FF00U) /*!< Bit mask for LCDIF_TIMING_DATA_HOLD. */
#define BS_LCDIF_TIMING_DATA_HOLD (8U)     /*!< Bit field size in bits for LCDIF_TIMING_DATA_HOLD. */

/*! @brief Read current value of the LCDIF_TIMING_DATA_HOLD field. */
#define BR_LCDIF_TIMING_DATA_HOLD(x) (HW_LCDIF_TIMING(x).B.DATA_HOLD)

/*! @brief Format value for bitfield LCDIF_TIMING_DATA_HOLD. */
#define BF_LCDIF_TIMING_DATA_HOLD(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_TIMING_DATA_HOLD) & BM_LCDIF_TIMING_DATA_HOLD)

/*! @brief Set the DATA_HOLD field to a new value. */
#define BW_LCDIF_TIMING_DATA_HOLD(x, v) (HW_LCDIF_TIMING_WR(x, (HW_LCDIF_TIMING_RD(x) & ~BM_LCDIF_TIMING_DATA_HOLD) | BF_LCDIF_TIMING_DATA_HOLD(v)))
/*@}*/

/*!
 * @name Register LCDIF_TIMING, field CMD_SETUP[23:16] (RW)
 *
 * Number of CLK_DIS_LCDIFn cycles that the DCn signal is active before CEn is
 * asserted.
 */
/*@{*/
#define BP_LCDIF_TIMING_CMD_SETUP (16U)    /*!< Bit position for LCDIF_TIMING_CMD_SETUP. */
#define BM_LCDIF_TIMING_CMD_SETUP (0x00FF0000U) /*!< Bit mask for LCDIF_TIMING_CMD_SETUP. */
#define BS_LCDIF_TIMING_CMD_SETUP (8U)     /*!< Bit field size in bits for LCDIF_TIMING_CMD_SETUP. */

/*! @brief Read current value of the LCDIF_TIMING_CMD_SETUP field. */
#define BR_LCDIF_TIMING_CMD_SETUP(x) (HW_LCDIF_TIMING(x).B.CMD_SETUP)

/*! @brief Format value for bitfield LCDIF_TIMING_CMD_SETUP. */
#define BF_LCDIF_TIMING_CMD_SETUP(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_TIMING_CMD_SETUP) & BM_LCDIF_TIMING_CMD_SETUP)

/*! @brief Set the CMD_SETUP field to a new value. */
#define BW_LCDIF_TIMING_CMD_SETUP(x, v) (HW_LCDIF_TIMING_WR(x, (HW_LCDIF_TIMING_RD(x) & ~BM_LCDIF_TIMING_CMD_SETUP) | BF_LCDIF_TIMING_CMD_SETUP(v)))
/*@}*/

/*!
 * @name Register LCDIF_TIMING, field CMD_HOLD[31:24] (RW)
 *
 * Number of CLK_DIS_LCDIFn cycles that the DCn signal is active after CEn is
 * deasserted.
 */
/*@{*/
#define BP_LCDIF_TIMING_CMD_HOLD (24U)     /*!< Bit position for LCDIF_TIMING_CMD_HOLD. */
#define BM_LCDIF_TIMING_CMD_HOLD (0xFF000000U) /*!< Bit mask for LCDIF_TIMING_CMD_HOLD. */
#define BS_LCDIF_TIMING_CMD_HOLD (8U)      /*!< Bit field size in bits for LCDIF_TIMING_CMD_HOLD. */

/*! @brief Read current value of the LCDIF_TIMING_CMD_HOLD field. */
#define BR_LCDIF_TIMING_CMD_HOLD(x) (HW_LCDIF_TIMING(x).B.CMD_HOLD)

/*! @brief Format value for bitfield LCDIF_TIMING_CMD_HOLD. */
#define BF_LCDIF_TIMING_CMD_HOLD(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_TIMING_CMD_HOLD) & BM_LCDIF_TIMING_CMD_HOLD)

/*! @brief Set the CMD_HOLD field to a new value. */
#define BW_LCDIF_TIMING_CMD_HOLD(x, v) (HW_LCDIF_TIMING_WR(x, (HW_LCDIF_TIMING_RD(x) & ~BM_LCDIF_TIMING_CMD_HOLD) | BF_LCDIF_TIMING_CMD_HOLD(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_VDCTRL0 - eLCDIF VSYNC Mode and Dotclk Mode Control Register0
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_VDCTRL0 - eLCDIF VSYNC Mode and Dotclk Mode Control Register0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to control the VSYNC and DOTCLK modes of the LCDIF so
 * as to work with different types of LCDs like moving picture displays and delta
 * pixel displays. This register gives general programmability to the VSYNC
 * signal including polarity, direction, pulse width, etc.
 */
typedef union _hw_lcdif_vdctrl0
{
    uint32_t U;
    struct _hw_lcdif_vdctrl0_bitfields
    {
        uint32_t VSYNC_PULSE_WIDTH : 18; /*!< [17:0]  */
        uint32_t HALF_LINE_MODE : 1;   /*!< [18]  */
        uint32_t HALF_LINE : 1;        /*!< [19]  */
        uint32_t VSYNC_PULSE_WIDTH_UNIT : 1; /*!< [20]  */
        uint32_t VSYNC_PERIOD_UNIT : 1; /*!< [21]  */
        uint32_t RSRVD1 : 2;           /*!< [23:22]  */
        uint32_t ENABLE_POL : 1;       /*!< [24]  */
        uint32_t DOTCLK_POL : 1;       /*!< [25]  */
        uint32_t HSYNC_POL : 1;        /*!< [26]  */
        uint32_t VSYNC_POL : 1;        /*!< [27]  */
        uint32_t ENABLE_PRESENT : 1;   /*!< [28]  */
        uint32_t VSYNC_OEB : 1;        /*!< [29]  */
        uint32_t RSRVD2 : 2;           /*!< [31:30]  */
    } B;
} hw_lcdif_vdctrl0_t;

/*!
 * @name Constants and macros for entire LCDIF_VDCTRL0 register
 */
/*@{*/
#define HW_LCDIF_VDCTRL0_ADDR(x) ((uintptr_t)(x) + 0x70U)
#define HW_LCDIF_VDCTRL0_SET_ADDR(x) (HW_LCDIF_VDCTRL0_ADDR(x) + 0x4U)
#define HW_LCDIF_VDCTRL0_CLR_ADDR(x) (HW_LCDIF_VDCTRL0_ADDR(x) + 0x8U)
#define HW_LCDIF_VDCTRL0_TOG_ADDR(x) (HW_LCDIF_VDCTRL0_ADDR(x) + 0xCU)

#define HW_LCDIF_VDCTRL0(x)      (*(__IO hw_lcdif_vdctrl0_t *) HW_LCDIF_VDCTRL0_ADDR(x))
#define HW_LCDIF_VDCTRL0_RD(x)   (HW_LCDIF_VDCTRL0(x).U)
#define HW_LCDIF_VDCTRL0_WR(x, v) (HW_LCDIF_VDCTRL0(x).U = (v))
#define HW_LCDIF_VDCTRL0_SET(x, v) ((*(uint32_t *) HW_LCDIF_VDCTRL0_SET_ADDR(x)) = (v))
#define HW_LCDIF_VDCTRL0_CLR(x, v) ((*(uint32_t *) HW_LCDIF_VDCTRL0_CLR_ADDR(x)) = (v))
#define HW_LCDIF_VDCTRL0_TOG(x, v) ((*(uint32_t *) HW_LCDIF_VDCTRL0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual LCDIF_VDCTRL0 bitfields
 */

/*!
 * @name Register LCDIF_VDCTRL0, field VSYNC_PULSE_WIDTH[17:0] (RW)
 *
 * Number of units for which VSYNC signal is active. For the DOTCLK mode, the
 * unit is determined by the VSYNC_PULSE_WIDTH_UNIT. If the VSYNC_PULSE_WIDTH_UNIT
 * is 0 for DOTCLK mode, VSYNC_PULSE_WIDTH must be less than HSYNC_PERIOD. For
 * the VSYNC interface mode, it should be in terms of number of CLK_DIS_LCDIFn
 * cycles only.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH (0U) /*!< Bit position for LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH. */
#define BM_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH (0x0003FFFFU) /*!< Bit mask for LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH. */
#define BS_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH (18U) /*!< Bit field size in bits for LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH. */

/*! @brief Read current value of the LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH field. */
#define BR_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH(x) (HW_LCDIF_VDCTRL0(x).B.VSYNC_PULSE_WIDTH)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH. */
#define BF_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH) & BM_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH)

/*! @brief Set the VSYNC_PULSE_WIDTH field to a new value. */
#define BW_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH) | BF_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field HALF_LINE_MODE[18] (RW)
 *
 * When this bit is 0, the first field (VSYNC period) will end in half a
 * horizontal line and the second field will begin with half a horizontal line. When
 * this bit is 1, all fields will end with half a horizontal line, and none will
 * begin with half a horizontal line.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_HALF_LINE_MODE (18U) /*!< Bit position for LCDIF_VDCTRL0_HALF_LINE_MODE. */
#define BM_LCDIF_VDCTRL0_HALF_LINE_MODE (0x00040000U) /*!< Bit mask for LCDIF_VDCTRL0_HALF_LINE_MODE. */
#define BS_LCDIF_VDCTRL0_HALF_LINE_MODE (1U) /*!< Bit field size in bits for LCDIF_VDCTRL0_HALF_LINE_MODE. */

/*! @brief Read current value of the LCDIF_VDCTRL0_HALF_LINE_MODE field. */
#define BR_LCDIF_VDCTRL0_HALF_LINE_MODE(x) (HW_LCDIF_VDCTRL0(x).B.HALF_LINE_MODE)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_HALF_LINE_MODE. */
#define BF_LCDIF_VDCTRL0_HALF_LINE_MODE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_HALF_LINE_MODE) & BM_LCDIF_VDCTRL0_HALF_LINE_MODE)

/*! @brief Set the HALF_LINE_MODE field to a new value. */
#define BW_LCDIF_VDCTRL0_HALF_LINE_MODE(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_HALF_LINE_MODE) | BF_LCDIF_VDCTRL0_HALF_LINE_MODE(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field HALF_LINE[19] (RW)
 *
 * Setting this bit to 1 will make the total VSYNC period equal to the
 * VSYNC_PERIOD field plus half the HORIZONTAL_PERIOD field (i.e. VSYNC_PERIOD field plus
 * half horizontal line), otherwise it is just VSYNC_PERIOD. Should be only used
 * in the DOTCLK mode, not in the VSYNC interface mode.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_HALF_LINE (19U)   /*!< Bit position for LCDIF_VDCTRL0_HALF_LINE. */
#define BM_LCDIF_VDCTRL0_HALF_LINE (0x00080000U) /*!< Bit mask for LCDIF_VDCTRL0_HALF_LINE. */
#define BS_LCDIF_VDCTRL0_HALF_LINE (1U)    /*!< Bit field size in bits for LCDIF_VDCTRL0_HALF_LINE. */

/*! @brief Read current value of the LCDIF_VDCTRL0_HALF_LINE field. */
#define BR_LCDIF_VDCTRL0_HALF_LINE(x) (HW_LCDIF_VDCTRL0(x).B.HALF_LINE)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_HALF_LINE. */
#define BF_LCDIF_VDCTRL0_HALF_LINE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_HALF_LINE) & BM_LCDIF_VDCTRL0_HALF_LINE)

/*! @brief Set the HALF_LINE field to a new value. */
#define BW_LCDIF_VDCTRL0_HALF_LINE(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_HALF_LINE) | BF_LCDIF_VDCTRL0_HALF_LINE(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field VSYNC_PULSE_WIDTH_UNIT[20] (RW)
 *
 * Default 0 for counting VSYNC_PULSE_WIDTH in terms of CLK_DIS_LCDIFn cycles.
 * Set it to 1 to count in terms of complete horizontal lines.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT (20U) /*!< Bit position for LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT. */
#define BM_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT (0x00100000U) /*!< Bit mask for LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT. */
#define BS_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT (1U) /*!< Bit field size in bits for LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT. */

/*! @brief Read current value of the LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT field. */
#define BR_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT(x) (HW_LCDIF_VDCTRL0(x).B.VSYNC_PULSE_WIDTH_UNIT)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT. */
#define BF_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT) & BM_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT)

/*! @brief Set the VSYNC_PULSE_WIDTH_UNIT field to a new value. */
#define BW_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT) | BF_LCDIF_VDCTRL0_VSYNC_PULSE_WIDTH_UNIT(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field VSYNC_PERIOD_UNIT[21] (RW)
 *
 * Default 0 for counting VSYNC_PERIOD in terms of CLK_DIS_LCDIFn cycles. Set it
 * to 1 to count in terms of complete horizontal lines. CLK_DIS_LCDIFn cycles
 * should be used in the VSYNC mode, while horizontal line should be used in the
 * DOTCLK mode.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT (21U) /*!< Bit position for LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT. */
#define BM_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT (0x00200000U) /*!< Bit mask for LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT. */
#define BS_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT (1U) /*!< Bit field size in bits for LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT. */

/*! @brief Read current value of the LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT field. */
#define BR_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT(x) (HW_LCDIF_VDCTRL0(x).B.VSYNC_PERIOD_UNIT)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT. */
#define BF_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT) & BM_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT)

/*! @brief Set the VSYNC_PERIOD_UNIT field to a new value. */
#define BW_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT) | BF_LCDIF_VDCTRL0_VSYNC_PERIOD_UNIT(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field RSRVD1[23:22] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_RSRVD1 (22U)      /*!< Bit position for LCDIF_VDCTRL0_RSRVD1. */
#define BM_LCDIF_VDCTRL0_RSRVD1 (0x00C00000U) /*!< Bit mask for LCDIF_VDCTRL0_RSRVD1. */
#define BS_LCDIF_VDCTRL0_RSRVD1 (2U)       /*!< Bit field size in bits for LCDIF_VDCTRL0_RSRVD1. */
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field ENABLE_POL[24] (RW)
 *
 * Default 0 active low during valid data transfer on each horizontal line.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_ENABLE_POL (24U)  /*!< Bit position for LCDIF_VDCTRL0_ENABLE_POL. */
#define BM_LCDIF_VDCTRL0_ENABLE_POL (0x01000000U) /*!< Bit mask for LCDIF_VDCTRL0_ENABLE_POL. */
#define BS_LCDIF_VDCTRL0_ENABLE_POL (1U)   /*!< Bit field size in bits for LCDIF_VDCTRL0_ENABLE_POL. */

/*! @brief Read current value of the LCDIF_VDCTRL0_ENABLE_POL field. */
#define BR_LCDIF_VDCTRL0_ENABLE_POL(x) (HW_LCDIF_VDCTRL0(x).B.ENABLE_POL)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_ENABLE_POL. */
#define BF_LCDIF_VDCTRL0_ENABLE_POL(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_ENABLE_POL) & BM_LCDIF_VDCTRL0_ENABLE_POL)

/*! @brief Set the ENABLE_POL field to a new value. */
#define BW_LCDIF_VDCTRL0_ENABLE_POL(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_ENABLE_POL) | BF_LCDIF_VDCTRL0_ENABLE_POL(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field DOTCLK_POL[25] (RW)
 *
 * Default is data launched at negative edge of DOTCLK and captured at positive
 * edge. Set it to 1 to invert the polarity. Set it to 0 in DVI mode.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_DOTCLK_POL (25U)  /*!< Bit position for LCDIF_VDCTRL0_DOTCLK_POL. */
#define BM_LCDIF_VDCTRL0_DOTCLK_POL (0x02000000U) /*!< Bit mask for LCDIF_VDCTRL0_DOTCLK_POL. */
#define BS_LCDIF_VDCTRL0_DOTCLK_POL (1U)   /*!< Bit field size in bits for LCDIF_VDCTRL0_DOTCLK_POL. */

/*! @brief Read current value of the LCDIF_VDCTRL0_DOTCLK_POL field. */
#define BR_LCDIF_VDCTRL0_DOTCLK_POL(x) (HW_LCDIF_VDCTRL0(x).B.DOTCLK_POL)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_DOTCLK_POL. */
#define BF_LCDIF_VDCTRL0_DOTCLK_POL(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_DOTCLK_POL) & BM_LCDIF_VDCTRL0_DOTCLK_POL)

/*! @brief Set the DOTCLK_POL field to a new value. */
#define BW_LCDIF_VDCTRL0_DOTCLK_POL(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_DOTCLK_POL) | BF_LCDIF_VDCTRL0_DOTCLK_POL(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field HSYNC_POL[26] (RW)
 *
 * Default 0 active low during HSYNC_PULSE_WIDTH time and will be high during
 * the rest of the HSYNC period. Set it to 1 to invert the polarity.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_HSYNC_POL (26U)   /*!< Bit position for LCDIF_VDCTRL0_HSYNC_POL. */
#define BM_LCDIF_VDCTRL0_HSYNC_POL (0x04000000U) /*!< Bit mask for LCDIF_VDCTRL0_HSYNC_POL. */
#define BS_LCDIF_VDCTRL0_HSYNC_POL (1U)    /*!< Bit field size in bits for LCDIF_VDCTRL0_HSYNC_POL. */

/*! @brief Read current value of the LCDIF_VDCTRL0_HSYNC_POL field. */
#define BR_LCDIF_VDCTRL0_HSYNC_POL(x) (HW_LCDIF_VDCTRL0(x).B.HSYNC_POL)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_HSYNC_POL. */
#define BF_LCDIF_VDCTRL0_HSYNC_POL(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_HSYNC_POL) & BM_LCDIF_VDCTRL0_HSYNC_POL)

/*! @brief Set the HSYNC_POL field to a new value. */
#define BW_LCDIF_VDCTRL0_HSYNC_POL(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_HSYNC_POL) | BF_LCDIF_VDCTRL0_HSYNC_POL(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field VSYNC_POL[27] (RW)
 *
 * Default 0 active low during VSYNC_PULSE_WIDTH time and will be high during
 * the rest of the VSYNC period. Set it to 1 to invert the polarity.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_VSYNC_POL (27U)   /*!< Bit position for LCDIF_VDCTRL0_VSYNC_POL. */
#define BM_LCDIF_VDCTRL0_VSYNC_POL (0x08000000U) /*!< Bit mask for LCDIF_VDCTRL0_VSYNC_POL. */
#define BS_LCDIF_VDCTRL0_VSYNC_POL (1U)    /*!< Bit field size in bits for LCDIF_VDCTRL0_VSYNC_POL. */

/*! @brief Read current value of the LCDIF_VDCTRL0_VSYNC_POL field. */
#define BR_LCDIF_VDCTRL0_VSYNC_POL(x) (HW_LCDIF_VDCTRL0(x).B.VSYNC_POL)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_VSYNC_POL. */
#define BF_LCDIF_VDCTRL0_VSYNC_POL(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_VSYNC_POL) & BM_LCDIF_VDCTRL0_VSYNC_POL)

/*! @brief Set the VSYNC_POL field to a new value. */
#define BW_LCDIF_VDCTRL0_VSYNC_POL(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_VSYNC_POL) | BF_LCDIF_VDCTRL0_VSYNC_POL(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field ENABLE_PRESENT[28] (RW)
 *
 * Setting this bit to 1 will make the hardware generate the ENABLE signal in
 * the DOTCLK mode, thereby making it the true RGB interface along with the
 * remaining three signals VSYNC, HSYNC and DOTCLK.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_ENABLE_PRESENT (28U) /*!< Bit position for LCDIF_VDCTRL0_ENABLE_PRESENT. */
#define BM_LCDIF_VDCTRL0_ENABLE_PRESENT (0x10000000U) /*!< Bit mask for LCDIF_VDCTRL0_ENABLE_PRESENT. */
#define BS_LCDIF_VDCTRL0_ENABLE_PRESENT (1U) /*!< Bit field size in bits for LCDIF_VDCTRL0_ENABLE_PRESENT. */

/*! @brief Read current value of the LCDIF_VDCTRL0_ENABLE_PRESENT field. */
#define BR_LCDIF_VDCTRL0_ENABLE_PRESENT(x) (HW_LCDIF_VDCTRL0(x).B.ENABLE_PRESENT)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_ENABLE_PRESENT. */
#define BF_LCDIF_VDCTRL0_ENABLE_PRESENT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_ENABLE_PRESENT) & BM_LCDIF_VDCTRL0_ENABLE_PRESENT)

/*! @brief Set the ENABLE_PRESENT field to a new value. */
#define BW_LCDIF_VDCTRL0_ENABLE_PRESENT(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_ENABLE_PRESENT) | BF_LCDIF_VDCTRL0_ENABLE_PRESENT(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field VSYNC_OEB[29] (RW)
 *
 * 0 means the VSYNC signal is an output, 1 means it is an input. Should be set
 * to 0 in the DOTCLK mode.
 *
 * Values:
 * - 0 - The VSYNC pin is in the output mode and the VSYNC signal has to be
 *     generated by the eLCDIF block.
 * - 1 - The VSYNC pin is in the input mode and the LCD controller sends the
 *     VSYNC signal to the block.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_VSYNC_OEB (29U)   /*!< Bit position for LCDIF_VDCTRL0_VSYNC_OEB. */
#define BM_LCDIF_VDCTRL0_VSYNC_OEB (0x20000000U) /*!< Bit mask for LCDIF_VDCTRL0_VSYNC_OEB. */
#define BS_LCDIF_VDCTRL0_VSYNC_OEB (1U)    /*!< Bit field size in bits for LCDIF_VDCTRL0_VSYNC_OEB. */

#define BV_LCDIF_VDCTRL0_VSYNC_OEB_VSYNC_OUTPUT (0U) /*!< Bit field value for LCDIF_VDCTRL0_VSYNC_OEB: The VSYNC pin is in the output mode and the VSYNC signal has to be generated by the eLCDIF block. */
#define BV_LCDIF_VDCTRL0_VSYNC_OEB_VSYNC_INPUT (0x1U) /*!< Bit field value for LCDIF_VDCTRL0_VSYNC_OEB: The VSYNC pin is in the input mode and the LCD controller sends the VSYNC signal to the block. */

/*! @brief Read current value of the LCDIF_VDCTRL0_VSYNC_OEB field. */
#define BR_LCDIF_VDCTRL0_VSYNC_OEB(x) (HW_LCDIF_VDCTRL0(x).B.VSYNC_OEB)

/*! @brief Format value for bitfield LCDIF_VDCTRL0_VSYNC_OEB. */
#define BF_LCDIF_VDCTRL0_VSYNC_OEB(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL0_VSYNC_OEB) & BM_LCDIF_VDCTRL0_VSYNC_OEB)

/*! @brief Set the VSYNC_OEB field to a new value. */
#define BW_LCDIF_VDCTRL0_VSYNC_OEB(x, v) (HW_LCDIF_VDCTRL0_WR(x, (HW_LCDIF_VDCTRL0_RD(x) & ~BM_LCDIF_VDCTRL0_VSYNC_OEB) | BF_LCDIF_VDCTRL0_VSYNC_OEB(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL0, field RSRVD2[31:30] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_VDCTRL0_RSRVD2 (30U)      /*!< Bit position for LCDIF_VDCTRL0_RSRVD2. */
#define BM_LCDIF_VDCTRL0_RSRVD2 (0xC0000000U) /*!< Bit mask for LCDIF_VDCTRL0_RSRVD2. */
#define BS_LCDIF_VDCTRL0_RSRVD2 (2U)       /*!< Bit field size in bits for LCDIF_VDCTRL0_RSRVD2. */
/*@}*/




/*******************************************************************************
 * HW_LCDIF_VDCTRL1 - eLCDIF VSYNC Mode and Dotclk Mode Control Register1
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_VDCTRL1 - eLCDIF VSYNC Mode and Dotclk Mode Control Register1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to control the VSYNC signal in the VSYNC and DOTCLK
 * modes of the block. This register determines the period and duty cycle of the
 * VSYNC signal when it is generated in the block.
 */
typedef union _hw_lcdif_vdctrl1
{
    uint32_t U;
    struct _hw_lcdif_vdctrl1_bitfields
    {
        uint32_t VSYNC_PERIOD : 32;    /*!< [31:0]  */
    } B;
} hw_lcdif_vdctrl1_t;

/*!
 * @name Constants and macros for entire LCDIF_VDCTRL1 register
 */
/*@{*/
#define HW_LCDIF_VDCTRL1_ADDR(x) ((uintptr_t)(x) + 0x80U)

#define HW_LCDIF_VDCTRL1(x)      (*(__IO hw_lcdif_vdctrl1_t *) HW_LCDIF_VDCTRL1_ADDR(x))
#define HW_LCDIF_VDCTRL1_RD(x)   (HW_LCDIF_VDCTRL1(x).U)
#define HW_LCDIF_VDCTRL1_WR(x, v) (HW_LCDIF_VDCTRL1(x).U = (v))
#define HW_LCDIF_VDCTRL1_SET(x, v) (HW_LCDIF_VDCTRL1_WR(x, HW_LCDIF_VDCTRL1_RD(x) |  (v)))
#define HW_LCDIF_VDCTRL1_CLR(x, v) (HW_LCDIF_VDCTRL1_WR(x, HW_LCDIF_VDCTRL1_RD(x) & ~(v)))
#define HW_LCDIF_VDCTRL1_TOG(x, v) (HW_LCDIF_VDCTRL1_WR(x, HW_LCDIF_VDCTRL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_VDCTRL1 bitfields
 */

/*!
 * @name Register LCDIF_VDCTRL1, field VSYNC_PERIOD[31:0] (RW)
 *
 * Total number of units between two positive or two negative edges of the VSYNC
 * signal. If HALF_LINE is set, it is implicitly calculated to be VSYNC_PERIOD
 * plus half HSYNC_PERIOD.
 */
/*@{*/
#define BP_LCDIF_VDCTRL1_VSYNC_PERIOD (0U) /*!< Bit position for LCDIF_VDCTRL1_VSYNC_PERIOD. */
#define BM_LCDIF_VDCTRL1_VSYNC_PERIOD (0xFFFFFFFFU) /*!< Bit mask for LCDIF_VDCTRL1_VSYNC_PERIOD. */
#define BS_LCDIF_VDCTRL1_VSYNC_PERIOD (32U) /*!< Bit field size in bits for LCDIF_VDCTRL1_VSYNC_PERIOD. */

/*! @brief Read current value of the LCDIF_VDCTRL1_VSYNC_PERIOD field. */
#define BR_LCDIF_VDCTRL1_VSYNC_PERIOD(x) (HW_LCDIF_VDCTRL1(x).U)

/*! @brief Format value for bitfield LCDIF_VDCTRL1_VSYNC_PERIOD. */
#define BF_LCDIF_VDCTRL1_VSYNC_PERIOD(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL1_VSYNC_PERIOD) & BM_LCDIF_VDCTRL1_VSYNC_PERIOD)

/*! @brief Set the VSYNC_PERIOD field to a new value. */
#define BW_LCDIF_VDCTRL1_VSYNC_PERIOD(x, v) (HW_LCDIF_VDCTRL1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_VDCTRL2 - LCDIF VSYNC Mode and Dotclk Mode Control Register2
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_VDCTRL2 - LCDIF VSYNC Mode and Dotclk Mode Control Register2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to control the HSYNC signal in the DOTCLK mode of the
 * block. This register determines the period and duty cycle of the HSYNC signal
 * when it is generated in the block.
 */
typedef union _hw_lcdif_vdctrl2
{
    uint32_t U;
    struct _hw_lcdif_vdctrl2_bitfields
    {
        uint32_t HSYNC_PERIOD : 18;    /*!< [17:0]  */
        uint32_t HSYNC_PULSE_WIDTH : 14; /*!< [31:18]  */
    } B;
} hw_lcdif_vdctrl2_t;

/*!
 * @name Constants and macros for entire LCDIF_VDCTRL2 register
 */
/*@{*/
#define HW_LCDIF_VDCTRL2_ADDR(x) ((uintptr_t)(x) + 0x90U)

#define HW_LCDIF_VDCTRL2(x)      (*(__IO hw_lcdif_vdctrl2_t *) HW_LCDIF_VDCTRL2_ADDR(x))
#define HW_LCDIF_VDCTRL2_RD(x)   (HW_LCDIF_VDCTRL2(x).U)
#define HW_LCDIF_VDCTRL2_WR(x, v) (HW_LCDIF_VDCTRL2(x).U = (v))
#define HW_LCDIF_VDCTRL2_SET(x, v) (HW_LCDIF_VDCTRL2_WR(x, HW_LCDIF_VDCTRL2_RD(x) |  (v)))
#define HW_LCDIF_VDCTRL2_CLR(x, v) (HW_LCDIF_VDCTRL2_WR(x, HW_LCDIF_VDCTRL2_RD(x) & ~(v)))
#define HW_LCDIF_VDCTRL2_TOG(x, v) (HW_LCDIF_VDCTRL2_WR(x, HW_LCDIF_VDCTRL2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_VDCTRL2 bitfields
 */

/*!
 * @name Register LCDIF_VDCTRL2, field HSYNC_PERIOD[17:0] (RW)
 *
 * Total number of CLK_DIS_LCDIFn cycles between two positive or two negative
 * edges of the HSYNC signal.
 */
/*@{*/
#define BP_LCDIF_VDCTRL2_HSYNC_PERIOD (0U) /*!< Bit position for LCDIF_VDCTRL2_HSYNC_PERIOD. */
#define BM_LCDIF_VDCTRL2_HSYNC_PERIOD (0x0003FFFFU) /*!< Bit mask for LCDIF_VDCTRL2_HSYNC_PERIOD. */
#define BS_LCDIF_VDCTRL2_HSYNC_PERIOD (18U) /*!< Bit field size in bits for LCDIF_VDCTRL2_HSYNC_PERIOD. */

/*! @brief Read current value of the LCDIF_VDCTRL2_HSYNC_PERIOD field. */
#define BR_LCDIF_VDCTRL2_HSYNC_PERIOD(x) (HW_LCDIF_VDCTRL2(x).B.HSYNC_PERIOD)

/*! @brief Format value for bitfield LCDIF_VDCTRL2_HSYNC_PERIOD. */
#define BF_LCDIF_VDCTRL2_HSYNC_PERIOD(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL2_HSYNC_PERIOD) & BM_LCDIF_VDCTRL2_HSYNC_PERIOD)

/*! @brief Set the HSYNC_PERIOD field to a new value. */
#define BW_LCDIF_VDCTRL2_HSYNC_PERIOD(x, v) (HW_LCDIF_VDCTRL2_WR(x, (HW_LCDIF_VDCTRL2_RD(x) & ~BM_LCDIF_VDCTRL2_HSYNC_PERIOD) | BF_LCDIF_VDCTRL2_HSYNC_PERIOD(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL2, field HSYNC_PULSE_WIDTH[31:18] (RW)
 *
 * Number of CLK_DIS_LCDIFn cycles for which HSYNC signal is active.
 */
/*@{*/
#define BP_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH (18U) /*!< Bit position for LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH. */
#define BM_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH (0xFFFC0000U) /*!< Bit mask for LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH. */
#define BS_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH (14U) /*!< Bit field size in bits for LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH. */

/*! @brief Read current value of the LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH field. */
#define BR_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH(x) (HW_LCDIF_VDCTRL2(x).B.HSYNC_PULSE_WIDTH)

/*! @brief Format value for bitfield LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH. */
#define BF_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH) & BM_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH)

/*! @brief Set the HSYNC_PULSE_WIDTH field to a new value. */
#define BW_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH(x, v) (HW_LCDIF_VDCTRL2_WR(x, (HW_LCDIF_VDCTRL2_RD(x) & ~BM_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH) | BF_LCDIF_VDCTRL2_HSYNC_PULSE_WIDTH(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_VDCTRL3 - eLCDIF VSYNC Mode and Dotclk Mode Control Register3
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_VDCTRL3 - eLCDIF VSYNC Mode and Dotclk Mode Control Register3 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to determine the vertical and horizontal wait counts.
 * This register determines the back porches of HSYNC and VSYNC signals when they
 * are generated by the block.
 */
typedef union _hw_lcdif_vdctrl3
{
    uint32_t U;
    struct _hw_lcdif_vdctrl3_bitfields
    {
        uint32_t VERTICAL_WAIT_CNT : 16; /*!< [15:0]  */
        uint32_t HORIZONTAL_WAIT_CNT : 12; /*!< [27:16]  */
        uint32_t VSYNC_ONLY : 1;       /*!< [28]  */
        uint32_t MUX_SYNC_SIGNALS : 1; /*!< [29]  */
        uint32_t RSRVD0 : 2;           /*!< [31:30]  */
    } B;
} hw_lcdif_vdctrl3_t;

/*!
 * @name Constants and macros for entire LCDIF_VDCTRL3 register
 */
/*@{*/
#define HW_LCDIF_VDCTRL3_ADDR(x) ((uintptr_t)(x) + 0xA0U)

#define HW_LCDIF_VDCTRL3(x)      (*(__IO hw_lcdif_vdctrl3_t *) HW_LCDIF_VDCTRL3_ADDR(x))
#define HW_LCDIF_VDCTRL3_RD(x)   (HW_LCDIF_VDCTRL3(x).U)
#define HW_LCDIF_VDCTRL3_WR(x, v) (HW_LCDIF_VDCTRL3(x).U = (v))
#define HW_LCDIF_VDCTRL3_SET(x, v) (HW_LCDIF_VDCTRL3_WR(x, HW_LCDIF_VDCTRL3_RD(x) |  (v)))
#define HW_LCDIF_VDCTRL3_CLR(x, v) (HW_LCDIF_VDCTRL3_WR(x, HW_LCDIF_VDCTRL3_RD(x) & ~(v)))
#define HW_LCDIF_VDCTRL3_TOG(x, v) (HW_LCDIF_VDCTRL3_WR(x, HW_LCDIF_VDCTRL3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_VDCTRL3 bitfields
 */

/*!
 * @name Register LCDIF_VDCTRL3, field VERTICAL_WAIT_CNT[15:0] (RW)
 *
 * In the VSYNC interface mode, wait for this number of CLK_DIS_LCDIFn cycles
 * from the falling VSYNC edge (or rising if VSYNC_POL is 1) before starting LCD
 * transactions and is applicable only if WAIT_FOR_VSYNC_EDGE is set. Minimum is
 * CMD_SETUP+5. In the DOTCLK mode, it accounts for the vertical back porch lines
 * plus the number of horizontal lines before the moving picture begins. The unit
 * for this parameter is inherently the same as the VSYNC_PERIOD_UNIT.
 */
/*@{*/
#define BP_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT (0U) /*!< Bit position for LCDIF_VDCTRL3_VERTICAL_WAIT_CNT. */
#define BM_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT (0x0000FFFFU) /*!< Bit mask for LCDIF_VDCTRL3_VERTICAL_WAIT_CNT. */
#define BS_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT (16U) /*!< Bit field size in bits for LCDIF_VDCTRL3_VERTICAL_WAIT_CNT. */

/*! @brief Read current value of the LCDIF_VDCTRL3_VERTICAL_WAIT_CNT field. */
#define BR_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT(x) (HW_LCDIF_VDCTRL3(x).B.VERTICAL_WAIT_CNT)

/*! @brief Format value for bitfield LCDIF_VDCTRL3_VERTICAL_WAIT_CNT. */
#define BF_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT) & BM_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT)

/*! @brief Set the VERTICAL_WAIT_CNT field to a new value. */
#define BW_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT(x, v) (HW_LCDIF_VDCTRL3_WR(x, (HW_LCDIF_VDCTRL3_RD(x) & ~BM_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT) | BF_LCDIF_VDCTRL3_VERTICAL_WAIT_CNT(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL3, field HORIZONTAL_WAIT_CNT[27:16] (RW)
 *
 * In the DOTCLK mode, wait for this number of clocks from falling edge (or
 * rising if HSYNC_POL is 1) of HSYNC signal to account for horizontal back porch
 * plus the number of DOTCLKs before the moving picture information begins.
 */
/*@{*/
#define BP_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT (16U) /*!< Bit position for LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT. */
#define BM_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT (0x0FFF0000U) /*!< Bit mask for LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT. */
#define BS_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT (12U) /*!< Bit field size in bits for LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT. */

/*! @brief Read current value of the LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT field. */
#define BR_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT(x) (HW_LCDIF_VDCTRL3(x).B.HORIZONTAL_WAIT_CNT)

/*! @brief Format value for bitfield LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT. */
#define BF_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT) & BM_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT)

/*! @brief Set the HORIZONTAL_WAIT_CNT field to a new value. */
#define BW_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT(x, v) (HW_LCDIF_VDCTRL3_WR(x, (HW_LCDIF_VDCTRL3_RD(x) & ~BM_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT) | BF_LCDIF_VDCTRL3_HORIZONTAL_WAIT_CNT(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL3, field VSYNC_ONLY[28] (RW)
 *
 * This bit must be set to 1 in the VSYNC mode of operation, and 0 in the DOTCLK
 * mode of operation.
 */
/*@{*/
#define BP_LCDIF_VDCTRL3_VSYNC_ONLY (28U)  /*!< Bit position for LCDIF_VDCTRL3_VSYNC_ONLY. */
#define BM_LCDIF_VDCTRL3_VSYNC_ONLY (0x10000000U) /*!< Bit mask for LCDIF_VDCTRL3_VSYNC_ONLY. */
#define BS_LCDIF_VDCTRL3_VSYNC_ONLY (1U)   /*!< Bit field size in bits for LCDIF_VDCTRL3_VSYNC_ONLY. */

/*! @brief Read current value of the LCDIF_VDCTRL3_VSYNC_ONLY field. */
#define BR_LCDIF_VDCTRL3_VSYNC_ONLY(x) (HW_LCDIF_VDCTRL3(x).B.VSYNC_ONLY)

/*! @brief Format value for bitfield LCDIF_VDCTRL3_VSYNC_ONLY. */
#define BF_LCDIF_VDCTRL3_VSYNC_ONLY(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL3_VSYNC_ONLY) & BM_LCDIF_VDCTRL3_VSYNC_ONLY)

/*! @brief Set the VSYNC_ONLY field to a new value. */
#define BW_LCDIF_VDCTRL3_VSYNC_ONLY(x, v) (HW_LCDIF_VDCTRL3_WR(x, (HW_LCDIF_VDCTRL3_RD(x) & ~BM_LCDIF_VDCTRL3_VSYNC_ONLY) | BF_LCDIF_VDCTRL3_VSYNC_ONLY(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL3, field MUX_SYNC_SIGNALS[29] (RW)
 *
 * When this bit is set, the eLCDIF block will internally mux HSYNC with
 * LCD_D14, DOTCLK with LCD_D13 and ENABLE with LCD_D12, otherwise these signals will go
 * out on separate pins. This feature can be used to maintain backward
 * compatible with 37xx.
 */
/*@{*/
#define BP_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS (29U) /*!< Bit position for LCDIF_VDCTRL3_MUX_SYNC_SIGNALS. */
#define BM_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS (0x20000000U) /*!< Bit mask for LCDIF_VDCTRL3_MUX_SYNC_SIGNALS. */
#define BS_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS (1U) /*!< Bit field size in bits for LCDIF_VDCTRL3_MUX_SYNC_SIGNALS. */

/*! @brief Read current value of the LCDIF_VDCTRL3_MUX_SYNC_SIGNALS field. */
#define BR_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS(x) (HW_LCDIF_VDCTRL3(x).B.MUX_SYNC_SIGNALS)

/*! @brief Format value for bitfield LCDIF_VDCTRL3_MUX_SYNC_SIGNALS. */
#define BF_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS) & BM_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS)

/*! @brief Set the MUX_SYNC_SIGNALS field to a new value. */
#define BW_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS(x, v) (HW_LCDIF_VDCTRL3_WR(x, (HW_LCDIF_VDCTRL3_RD(x) & ~BM_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS) | BF_LCDIF_VDCTRL3_MUX_SYNC_SIGNALS(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL3, field RSRVD0[31:30] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_VDCTRL3_RSRVD0 (30U)      /*!< Bit position for LCDIF_VDCTRL3_RSRVD0. */
#define BM_LCDIF_VDCTRL3_RSRVD0 (0xC0000000U) /*!< Bit mask for LCDIF_VDCTRL3_RSRVD0. */
#define BS_LCDIF_VDCTRL3_RSRVD0 (2U)       /*!< Bit field size in bits for LCDIF_VDCTRL3_RSRVD0. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_VDCTRL4 - eLCDIF VSYNC Mode and Dotclk Mode Control Register4
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_VDCTRL4 - eLCDIF VSYNC Mode and Dotclk Mode Control Register4 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to control the DOTCLK mode of the block. This register
 * determines the active data in each horizontal line in the DOTCLK mode. Note
 * that the total number of active horizontal lines in the DOTCLK mode is the same
 * as the V_COUNT bitfield in the LCDIF_TRANSFER_COUNT register.
 */
typedef union _hw_lcdif_vdctrl4
{
    uint32_t U;
    struct _hw_lcdif_vdctrl4_bitfields
    {
        uint32_t DOTCLK_H_VALID_DATA_CNT : 18; /*!< [17:0]  */
        uint32_t SYNC_SIGNALS_ON : 1;  /*!< [18]  */
        uint32_t RSRVD0 : 10;          /*!< [28:19]  */
        uint32_t DOTCLK_DLY_SEL : 3;   /*!< [31:29]  */
    } B;
} hw_lcdif_vdctrl4_t;

/*!
 * @name Constants and macros for entire LCDIF_VDCTRL4 register
 */
/*@{*/
#define HW_LCDIF_VDCTRL4_ADDR(x) ((uintptr_t)(x) + 0xB0U)

#define HW_LCDIF_VDCTRL4(x)      (*(__IO hw_lcdif_vdctrl4_t *) HW_LCDIF_VDCTRL4_ADDR(x))
#define HW_LCDIF_VDCTRL4_RD(x)   (HW_LCDIF_VDCTRL4(x).U)
#define HW_LCDIF_VDCTRL4_WR(x, v) (HW_LCDIF_VDCTRL4(x).U = (v))
#define HW_LCDIF_VDCTRL4_SET(x, v) (HW_LCDIF_VDCTRL4_WR(x, HW_LCDIF_VDCTRL4_RD(x) |  (v)))
#define HW_LCDIF_VDCTRL4_CLR(x, v) (HW_LCDIF_VDCTRL4_WR(x, HW_LCDIF_VDCTRL4_RD(x) & ~(v)))
#define HW_LCDIF_VDCTRL4_TOG(x, v) (HW_LCDIF_VDCTRL4_WR(x, HW_LCDIF_VDCTRL4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_VDCTRL4 bitfields
 */

/*!
 * @name Register LCDIF_VDCTRL4, field DOTCLK_H_VALID_DATA_CNT[17:0] (RW)
 *
 * Total number of CLK_DIS_LCDIFn cycles on each horizontal line that carry
 * valid data in DOTCLK mode.
 */
/*@{*/
#define BP_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT (0U) /*!< Bit position for LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT. */
#define BM_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT (0x0003FFFFU) /*!< Bit mask for LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT. */
#define BS_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT (18U) /*!< Bit field size in bits for LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT. */

/*! @brief Read current value of the LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT field. */
#define BR_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT(x) (HW_LCDIF_VDCTRL4(x).B.DOTCLK_H_VALID_DATA_CNT)

/*! @brief Format value for bitfield LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT. */
#define BF_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT) & BM_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT)

/*! @brief Set the DOTCLK_H_VALID_DATA_CNT field to a new value. */
#define BW_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT(x, v) (HW_LCDIF_VDCTRL4_WR(x, (HW_LCDIF_VDCTRL4_RD(x) & ~BM_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT) | BF_LCDIF_VDCTRL4_DOTCLK_H_VALID_DATA_CNT(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL4, field SYNC_SIGNALS_ON[18] (RW)
 *
 * Set this field to 1 if the LCD controller requires that the VSYNC or
 * VSYNC/HSYNC/DOTCLK control signals should be active at least one frame before the data
 * transfers actually start and remain active at least one frame after the data
 * transfers end. The hardware does not count the number of frames automatically.
 * Rather, the VSYNC edge interrupt can be monitored by software to count the
 * number of frames that have occurred after this bit is set and then the RUN bit
 * can be set to start the data transactions. This bit must always be set in the
 * DOTCLK mode of operation, and it must be set in the VSYNC mode of operation
 * when VSYNC signal is an output.
 */
/*@{*/
#define BP_LCDIF_VDCTRL4_SYNC_SIGNALS_ON (18U) /*!< Bit position for LCDIF_VDCTRL4_SYNC_SIGNALS_ON. */
#define BM_LCDIF_VDCTRL4_SYNC_SIGNALS_ON (0x00040000U) /*!< Bit mask for LCDIF_VDCTRL4_SYNC_SIGNALS_ON. */
#define BS_LCDIF_VDCTRL4_SYNC_SIGNALS_ON (1U) /*!< Bit field size in bits for LCDIF_VDCTRL4_SYNC_SIGNALS_ON. */

/*! @brief Read current value of the LCDIF_VDCTRL4_SYNC_SIGNALS_ON field. */
#define BR_LCDIF_VDCTRL4_SYNC_SIGNALS_ON(x) (HW_LCDIF_VDCTRL4(x).B.SYNC_SIGNALS_ON)

/*! @brief Format value for bitfield LCDIF_VDCTRL4_SYNC_SIGNALS_ON. */
#define BF_LCDIF_VDCTRL4_SYNC_SIGNALS_ON(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL4_SYNC_SIGNALS_ON) & BM_LCDIF_VDCTRL4_SYNC_SIGNALS_ON)

/*! @brief Set the SYNC_SIGNALS_ON field to a new value. */
#define BW_LCDIF_VDCTRL4_SYNC_SIGNALS_ON(x, v) (HW_LCDIF_VDCTRL4_WR(x, (HW_LCDIF_VDCTRL4_RD(x) & ~BM_LCDIF_VDCTRL4_SYNC_SIGNALS_ON) | BF_LCDIF_VDCTRL4_SYNC_SIGNALS_ON(v)))
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL4, field RSRVD0[28:19] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_VDCTRL4_RSRVD0 (19U)      /*!< Bit position for LCDIF_VDCTRL4_RSRVD0. */
#define BM_LCDIF_VDCTRL4_RSRVD0 (0x1FF80000U) /*!< Bit mask for LCDIF_VDCTRL4_RSRVD0. */
#define BS_LCDIF_VDCTRL4_RSRVD0 (10U)      /*!< Bit field size in bits for LCDIF_VDCTRL4_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_VDCTRL4, field DOTCLK_DLY_SEL[31:29] (RW)
 *
 * This bitfield selects the amount of time by which the DOTCLK signal should be
 * delayed before coming out of the LCD_DOTCK pin. 0 = 2ns; 1=4ns;2=6ns;3=8ns.
 * Remaining values are reserved.
 */
/*@{*/
#define BP_LCDIF_VDCTRL4_DOTCLK_DLY_SEL (29U) /*!< Bit position for LCDIF_VDCTRL4_DOTCLK_DLY_SEL. */
#define BM_LCDIF_VDCTRL4_DOTCLK_DLY_SEL (0xE0000000U) /*!< Bit mask for LCDIF_VDCTRL4_DOTCLK_DLY_SEL. */
#define BS_LCDIF_VDCTRL4_DOTCLK_DLY_SEL (3U) /*!< Bit field size in bits for LCDIF_VDCTRL4_DOTCLK_DLY_SEL. */

/*! @brief Read current value of the LCDIF_VDCTRL4_DOTCLK_DLY_SEL field. */
#define BR_LCDIF_VDCTRL4_DOTCLK_DLY_SEL(x) (HW_LCDIF_VDCTRL4(x).B.DOTCLK_DLY_SEL)

/*! @brief Format value for bitfield LCDIF_VDCTRL4_DOTCLK_DLY_SEL. */
#define BF_LCDIF_VDCTRL4_DOTCLK_DLY_SEL(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_VDCTRL4_DOTCLK_DLY_SEL) & BM_LCDIF_VDCTRL4_DOTCLK_DLY_SEL)

/*! @brief Set the DOTCLK_DLY_SEL field to a new value. */
#define BW_LCDIF_VDCTRL4_DOTCLK_DLY_SEL(x, v) (HW_LCDIF_VDCTRL4_WR(x, (HW_LCDIF_VDCTRL4_RD(x) & ~BM_LCDIF_VDCTRL4_DOTCLK_DLY_SEL) | BF_LCDIF_VDCTRL4_DOTCLK_DLY_SEL(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DVICTRL0 - Digital Video Interface Control0 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DVICTRL0 - Digital Video Interface Control0 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Digital Video interface Control0 register provides the overall control of
 * the Digital Video interface. This register gives information about the
 * horizontal active, horizontal blanking and total number of lines in the ITU-R BT.656
 * interface. EXAMPLE //525/60 video system
 * HW_LCDIF_DVICTRL0_H_ACTIVE_CNT_WR(0x5A0);//1440 HW_LCDIF_DVICTRL0_H_BLANKING_CNT_WR(0x106);//262 //625/50 video
 * system HW_LCDIF_DVICTRL0_H_ACTIVE_CNT_WR(0x5A0);//1440
 * HW_LCDIF_DVICTRL0_H_BLANKING_CNT_WR(0x112);//274
 */
typedef union _hw_lcdif_dvictrl0
{
    uint32_t U;
    struct _hw_lcdif_dvictrl0_bitfields
    {
        uint32_t H_BLANKING_CNT : 12;  /*!< [11:0]  */
        uint32_t RSRVD0 : 4;           /*!< [15:12]  */
        uint32_t H_ACTIVE_CNT : 12;    /*!< [27:16]  */
        uint32_t RSRVD1 : 4;           /*!< [31:28]  */
    } B;
} hw_lcdif_dvictrl0_t;

/*!
 * @name Constants and macros for entire LCDIF_DVICTRL0 register
 */
/*@{*/
#define HW_LCDIF_DVICTRL0_ADDR(x) ((uintptr_t)(x) + 0xC0U)

#define HW_LCDIF_DVICTRL0(x)     (*(__IO hw_lcdif_dvictrl0_t *) HW_LCDIF_DVICTRL0_ADDR(x))
#define HW_LCDIF_DVICTRL0_RD(x)  (HW_LCDIF_DVICTRL0(x).U)
#define HW_LCDIF_DVICTRL0_WR(x, v) (HW_LCDIF_DVICTRL0(x).U = (v))
#define HW_LCDIF_DVICTRL0_SET(x, v) (HW_LCDIF_DVICTRL0_WR(x, HW_LCDIF_DVICTRL0_RD(x) |  (v)))
#define HW_LCDIF_DVICTRL0_CLR(x, v) (HW_LCDIF_DVICTRL0_WR(x, HW_LCDIF_DVICTRL0_RD(x) & ~(v)))
#define HW_LCDIF_DVICTRL0_TOG(x, v) (HW_LCDIF_DVICTRL0_WR(x, HW_LCDIF_DVICTRL0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_DVICTRL0 bitfields
 */

/*!
 * @name Register LCDIF_DVICTRL0, field H_BLANKING_CNT[11:0] (RW)
 *
 * Number of blanking samples to be inserted between EAV and SAV during
 * horizontal blanking interval.
 */
/*@{*/
#define BP_LCDIF_DVICTRL0_H_BLANKING_CNT (0U) /*!< Bit position for LCDIF_DVICTRL0_H_BLANKING_CNT. */
#define BM_LCDIF_DVICTRL0_H_BLANKING_CNT (0x00000FFFU) /*!< Bit mask for LCDIF_DVICTRL0_H_BLANKING_CNT. */
#define BS_LCDIF_DVICTRL0_H_BLANKING_CNT (12U) /*!< Bit field size in bits for LCDIF_DVICTRL0_H_BLANKING_CNT. */

/*! @brief Read current value of the LCDIF_DVICTRL0_H_BLANKING_CNT field. */
#define BR_LCDIF_DVICTRL0_H_BLANKING_CNT(x) (HW_LCDIF_DVICTRL0(x).B.H_BLANKING_CNT)

/*! @brief Format value for bitfield LCDIF_DVICTRL0_H_BLANKING_CNT. */
#define BF_LCDIF_DVICTRL0_H_BLANKING_CNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL0_H_BLANKING_CNT) & BM_LCDIF_DVICTRL0_H_BLANKING_CNT)

/*! @brief Set the H_BLANKING_CNT field to a new value. */
#define BW_LCDIF_DVICTRL0_H_BLANKING_CNT(x, v) (HW_LCDIF_DVICTRL0_WR(x, (HW_LCDIF_DVICTRL0_RD(x) & ~BM_LCDIF_DVICTRL0_H_BLANKING_CNT) | BF_LCDIF_DVICTRL0_H_BLANKING_CNT(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL0, field RSRVD0[15:12] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_DVICTRL0_RSRVD0 (12U)     /*!< Bit position for LCDIF_DVICTRL0_RSRVD0. */
#define BM_LCDIF_DVICTRL0_RSRVD0 (0x0000F000U) /*!< Bit mask for LCDIF_DVICTRL0_RSRVD0. */
#define BS_LCDIF_DVICTRL0_RSRVD0 (4U)      /*!< Bit field size in bits for LCDIF_DVICTRL0_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL0, field H_ACTIVE_CNT[27:16] (RW)
 *
 * Number of active video samples to be transmitted. (Mostly will be 1440 for
 * both PAL and NTSC). Must always be a multiple of 4.
 */
/*@{*/
#define BP_LCDIF_DVICTRL0_H_ACTIVE_CNT (16U) /*!< Bit position for LCDIF_DVICTRL0_H_ACTIVE_CNT. */
#define BM_LCDIF_DVICTRL0_H_ACTIVE_CNT (0x0FFF0000U) /*!< Bit mask for LCDIF_DVICTRL0_H_ACTIVE_CNT. */
#define BS_LCDIF_DVICTRL0_H_ACTIVE_CNT (12U) /*!< Bit field size in bits for LCDIF_DVICTRL0_H_ACTIVE_CNT. */

/*! @brief Read current value of the LCDIF_DVICTRL0_H_ACTIVE_CNT field. */
#define BR_LCDIF_DVICTRL0_H_ACTIVE_CNT(x) (HW_LCDIF_DVICTRL0(x).B.H_ACTIVE_CNT)

/*! @brief Format value for bitfield LCDIF_DVICTRL0_H_ACTIVE_CNT. */
#define BF_LCDIF_DVICTRL0_H_ACTIVE_CNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL0_H_ACTIVE_CNT) & BM_LCDIF_DVICTRL0_H_ACTIVE_CNT)

/*! @brief Set the H_ACTIVE_CNT field to a new value. */
#define BW_LCDIF_DVICTRL0_H_ACTIVE_CNT(x, v) (HW_LCDIF_DVICTRL0_WR(x, (HW_LCDIF_DVICTRL0_RD(x) & ~BM_LCDIF_DVICTRL0_H_ACTIVE_CNT) | BF_LCDIF_DVICTRL0_H_ACTIVE_CNT(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL0, field RSRVD1[31:28] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_DVICTRL0_RSRVD1 (28U)     /*!< Bit position for LCDIF_DVICTRL0_RSRVD1. */
#define BM_LCDIF_DVICTRL0_RSRVD1 (0xF0000000U) /*!< Bit mask for LCDIF_DVICTRL0_RSRVD1. */
#define BS_LCDIF_DVICTRL0_RSRVD1 (4U)      /*!< Bit field size in bits for LCDIF_DVICTRL0_RSRVD1. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DVICTRL1 - Digital Video Interface Control1 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DVICTRL1 - Digital Video Interface Control1 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Digital Video interface Control1 register provides the overall control of
 * the Digital Video interface. This register contains information about the
 * Field1 start and end, and the Field2 start in the ITU-R BT.656 interface. EXAMPLE
 * //525/60 video system HW_LCDIF_DVICTRL1_F1_START_LINE_WR(0x4);//4
 * HW_LCDIF_DVICTRL1_F1_END_LINE_WR(0x109);//265
 * HW_LCDIF_DVICTRL1_F2_START_LINE_WR(0x10A);//266 //625/50 video system HW_LCDIF_DVICTRL1_F1_START_LINE_WR(0x1);//1
 * HW_LCDIF_DVICTRL1_F1_END_LINE_WR(0x138);//312
 * HW_LCDIF_DVICTRL1_F2_START_LINE_WR(0x139);//313
 */
typedef union _hw_lcdif_dvictrl1
{
    uint32_t U;
    struct _hw_lcdif_dvictrl1_bitfields
    {
        uint32_t F2_START_LINE : 10;   /*!< [9:0]  */
        uint32_t F1_END_LINE : 10;     /*!< [19:10]  */
        uint32_t F1_START_LINE : 10;   /*!< [29:20]  */
        uint32_t RSRVD0 : 2;           /*!< [31:30]  */
    } B;
} hw_lcdif_dvictrl1_t;

/*!
 * @name Constants and macros for entire LCDIF_DVICTRL1 register
 */
/*@{*/
#define HW_LCDIF_DVICTRL1_ADDR(x) ((uintptr_t)(x) + 0xD0U)

#define HW_LCDIF_DVICTRL1(x)     (*(__IO hw_lcdif_dvictrl1_t *) HW_LCDIF_DVICTRL1_ADDR(x))
#define HW_LCDIF_DVICTRL1_RD(x)  (HW_LCDIF_DVICTRL1(x).U)
#define HW_LCDIF_DVICTRL1_WR(x, v) (HW_LCDIF_DVICTRL1(x).U = (v))
#define HW_LCDIF_DVICTRL1_SET(x, v) (HW_LCDIF_DVICTRL1_WR(x, HW_LCDIF_DVICTRL1_RD(x) |  (v)))
#define HW_LCDIF_DVICTRL1_CLR(x, v) (HW_LCDIF_DVICTRL1_WR(x, HW_LCDIF_DVICTRL1_RD(x) & ~(v)))
#define HW_LCDIF_DVICTRL1_TOG(x, v) (HW_LCDIF_DVICTRL1_WR(x, HW_LCDIF_DVICTRL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_DVICTRL1 bitfields
 */

/*!
 * @name Register LCDIF_DVICTRL1, field F2_START_LINE[9:0] (RW)
 *
 * Vertical line number from which Field 2 begins.
 */
/*@{*/
#define BP_LCDIF_DVICTRL1_F2_START_LINE (0U) /*!< Bit position for LCDIF_DVICTRL1_F2_START_LINE. */
#define BM_LCDIF_DVICTRL1_F2_START_LINE (0x000003FFU) /*!< Bit mask for LCDIF_DVICTRL1_F2_START_LINE. */
#define BS_LCDIF_DVICTRL1_F2_START_LINE (10U) /*!< Bit field size in bits for LCDIF_DVICTRL1_F2_START_LINE. */

/*! @brief Read current value of the LCDIF_DVICTRL1_F2_START_LINE field. */
#define BR_LCDIF_DVICTRL1_F2_START_LINE(x) (HW_LCDIF_DVICTRL1(x).B.F2_START_LINE)

/*! @brief Format value for bitfield LCDIF_DVICTRL1_F2_START_LINE. */
#define BF_LCDIF_DVICTRL1_F2_START_LINE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL1_F2_START_LINE) & BM_LCDIF_DVICTRL1_F2_START_LINE)

/*! @brief Set the F2_START_LINE field to a new value. */
#define BW_LCDIF_DVICTRL1_F2_START_LINE(x, v) (HW_LCDIF_DVICTRL1_WR(x, (HW_LCDIF_DVICTRL1_RD(x) & ~BM_LCDIF_DVICTRL1_F2_START_LINE) | BF_LCDIF_DVICTRL1_F2_START_LINE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL1, field F1_END_LINE[19:10] (RW)
 *
 * Vertical line number at which Field1 ends.
 */
/*@{*/
#define BP_LCDIF_DVICTRL1_F1_END_LINE (10U) /*!< Bit position for LCDIF_DVICTRL1_F1_END_LINE. */
#define BM_LCDIF_DVICTRL1_F1_END_LINE (0x000FFC00U) /*!< Bit mask for LCDIF_DVICTRL1_F1_END_LINE. */
#define BS_LCDIF_DVICTRL1_F1_END_LINE (10U) /*!< Bit field size in bits for LCDIF_DVICTRL1_F1_END_LINE. */

/*! @brief Read current value of the LCDIF_DVICTRL1_F1_END_LINE field. */
#define BR_LCDIF_DVICTRL1_F1_END_LINE(x) (HW_LCDIF_DVICTRL1(x).B.F1_END_LINE)

/*! @brief Format value for bitfield LCDIF_DVICTRL1_F1_END_LINE. */
#define BF_LCDIF_DVICTRL1_F1_END_LINE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL1_F1_END_LINE) & BM_LCDIF_DVICTRL1_F1_END_LINE)

/*! @brief Set the F1_END_LINE field to a new value. */
#define BW_LCDIF_DVICTRL1_F1_END_LINE(x, v) (HW_LCDIF_DVICTRL1_WR(x, (HW_LCDIF_DVICTRL1_RD(x) & ~BM_LCDIF_DVICTRL1_F1_END_LINE) | BF_LCDIF_DVICTRL1_F1_END_LINE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL1, field F1_START_LINE[29:20] (RW)
 *
 * Vertical line number from which Field 1 begins.
 */
/*@{*/
#define BP_LCDIF_DVICTRL1_F1_START_LINE (20U) /*!< Bit position for LCDIF_DVICTRL1_F1_START_LINE. */
#define BM_LCDIF_DVICTRL1_F1_START_LINE (0x3FF00000U) /*!< Bit mask for LCDIF_DVICTRL1_F1_START_LINE. */
#define BS_LCDIF_DVICTRL1_F1_START_LINE (10U) /*!< Bit field size in bits for LCDIF_DVICTRL1_F1_START_LINE. */

/*! @brief Read current value of the LCDIF_DVICTRL1_F1_START_LINE field. */
#define BR_LCDIF_DVICTRL1_F1_START_LINE(x) (HW_LCDIF_DVICTRL1(x).B.F1_START_LINE)

/*! @brief Format value for bitfield LCDIF_DVICTRL1_F1_START_LINE. */
#define BF_LCDIF_DVICTRL1_F1_START_LINE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL1_F1_START_LINE) & BM_LCDIF_DVICTRL1_F1_START_LINE)

/*! @brief Set the F1_START_LINE field to a new value. */
#define BW_LCDIF_DVICTRL1_F1_START_LINE(x, v) (HW_LCDIF_DVICTRL1_WR(x, (HW_LCDIF_DVICTRL1_RD(x) & ~BM_LCDIF_DVICTRL1_F1_START_LINE) | BF_LCDIF_DVICTRL1_F1_START_LINE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL1, field RSRVD0[31:30] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_DVICTRL1_RSRVD0 (30U)     /*!< Bit position for LCDIF_DVICTRL1_RSRVD0. */
#define BM_LCDIF_DVICTRL1_RSRVD0 (0xC0000000U) /*!< Bit mask for LCDIF_DVICTRL1_RSRVD0. */
#define BS_LCDIF_DVICTRL1_RSRVD0 (2U)      /*!< Bit field size in bits for LCDIF_DVICTRL1_RSRVD0. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DVICTRL2 - Digital Video Interface Control2 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DVICTRL2 - Digital Video Interface Control2 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Digital Video interface Control2 register provides the overall control of
 * the Digital Video interface. This register contains information about the
 * Field2 end, and the Vertical Blanking1 interval in the ITU-R BT.656 interface.
 * EXAMPLE //525/60 video system HW_LCDIF_DVICTRL2_F2_END_LINE_WR(0x3);//3
 * HW_LCDIF_DVICTRL2_V1_BLANK_START_LINE_WR(0x108);//264
 * HW_LCDIF_DVICTRL2_V1_BLANK_END_LINE_WR(0x11A);//282 //625/50 video system
 * HW_LCDIF_DVICTRL2_F2_END_LINE_WR(0x271);//625 HW_LCDIF_DVICTRL2_V1_BLANK_START_LINE_WR(0x137);//311
 * HW_LCDIF_DVICTRL2_V1_BLANK_END_LINE_WR(0x14F);//335
 */
typedef union _hw_lcdif_dvictrl2
{
    uint32_t U;
    struct _hw_lcdif_dvictrl2_bitfields
    {
        uint32_t V1_BLANK_END_LINE : 10; /*!< [9:0]  */
        uint32_t V1_BLANK_START_LINE : 10; /*!< [19:10]  */
        uint32_t F2_END_LINE : 10;     /*!< [29:20]  */
        uint32_t RSRVD0 : 2;           /*!< [31:30]  */
    } B;
} hw_lcdif_dvictrl2_t;

/*!
 * @name Constants and macros for entire LCDIF_DVICTRL2 register
 */
/*@{*/
#define HW_LCDIF_DVICTRL2_ADDR(x) ((uintptr_t)(x) + 0xE0U)

#define HW_LCDIF_DVICTRL2(x)     (*(__IO hw_lcdif_dvictrl2_t *) HW_LCDIF_DVICTRL2_ADDR(x))
#define HW_LCDIF_DVICTRL2_RD(x)  (HW_LCDIF_DVICTRL2(x).U)
#define HW_LCDIF_DVICTRL2_WR(x, v) (HW_LCDIF_DVICTRL2(x).U = (v))
#define HW_LCDIF_DVICTRL2_SET(x, v) (HW_LCDIF_DVICTRL2_WR(x, HW_LCDIF_DVICTRL2_RD(x) |  (v)))
#define HW_LCDIF_DVICTRL2_CLR(x, v) (HW_LCDIF_DVICTRL2_WR(x, HW_LCDIF_DVICTRL2_RD(x) & ~(v)))
#define HW_LCDIF_DVICTRL2_TOG(x, v) (HW_LCDIF_DVICTRL2_WR(x, HW_LCDIF_DVICTRL2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_DVICTRL2 bitfields
 */

/*!
 * @name Register LCDIF_DVICTRL2, field V1_BLANK_END_LINE[9:0] (RW)
 *
 * Vertical line number in the beginning part of Field2 where first Vertical
 * Blanking interval ends.
 */
/*@{*/
#define BP_LCDIF_DVICTRL2_V1_BLANK_END_LINE (0U) /*!< Bit position for LCDIF_DVICTRL2_V1_BLANK_END_LINE. */
#define BM_LCDIF_DVICTRL2_V1_BLANK_END_LINE (0x000003FFU) /*!< Bit mask for LCDIF_DVICTRL2_V1_BLANK_END_LINE. */
#define BS_LCDIF_DVICTRL2_V1_BLANK_END_LINE (10U) /*!< Bit field size in bits for LCDIF_DVICTRL2_V1_BLANK_END_LINE. */

/*! @brief Read current value of the LCDIF_DVICTRL2_V1_BLANK_END_LINE field. */
#define BR_LCDIF_DVICTRL2_V1_BLANK_END_LINE(x) (HW_LCDIF_DVICTRL2(x).B.V1_BLANK_END_LINE)

/*! @brief Format value for bitfield LCDIF_DVICTRL2_V1_BLANK_END_LINE. */
#define BF_LCDIF_DVICTRL2_V1_BLANK_END_LINE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL2_V1_BLANK_END_LINE) & BM_LCDIF_DVICTRL2_V1_BLANK_END_LINE)

/*! @brief Set the V1_BLANK_END_LINE field to a new value. */
#define BW_LCDIF_DVICTRL2_V1_BLANK_END_LINE(x, v) (HW_LCDIF_DVICTRL2_WR(x, (HW_LCDIF_DVICTRL2_RD(x) & ~BM_LCDIF_DVICTRL2_V1_BLANK_END_LINE) | BF_LCDIF_DVICTRL2_V1_BLANK_END_LINE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL2, field V1_BLANK_START_LINE[19:10] (RW)
 *
 * Vertical line number towards the end of Field1 where first Vertical Blanking
 * interval starts.
 */
/*@{*/
#define BP_LCDIF_DVICTRL2_V1_BLANK_START_LINE (10U) /*!< Bit position for LCDIF_DVICTRL2_V1_BLANK_START_LINE. */
#define BM_LCDIF_DVICTRL2_V1_BLANK_START_LINE (0x000FFC00U) /*!< Bit mask for LCDIF_DVICTRL2_V1_BLANK_START_LINE. */
#define BS_LCDIF_DVICTRL2_V1_BLANK_START_LINE (10U) /*!< Bit field size in bits for LCDIF_DVICTRL2_V1_BLANK_START_LINE. */

/*! @brief Read current value of the LCDIF_DVICTRL2_V1_BLANK_START_LINE field. */
#define BR_LCDIF_DVICTRL2_V1_BLANK_START_LINE(x) (HW_LCDIF_DVICTRL2(x).B.V1_BLANK_START_LINE)

/*! @brief Format value for bitfield LCDIF_DVICTRL2_V1_BLANK_START_LINE. */
#define BF_LCDIF_DVICTRL2_V1_BLANK_START_LINE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL2_V1_BLANK_START_LINE) & BM_LCDIF_DVICTRL2_V1_BLANK_START_LINE)

/*! @brief Set the V1_BLANK_START_LINE field to a new value. */
#define BW_LCDIF_DVICTRL2_V1_BLANK_START_LINE(x, v) (HW_LCDIF_DVICTRL2_WR(x, (HW_LCDIF_DVICTRL2_RD(x) & ~BM_LCDIF_DVICTRL2_V1_BLANK_START_LINE) | BF_LCDIF_DVICTRL2_V1_BLANK_START_LINE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL2, field F2_END_LINE[29:20] (RW)
 *
 * Vertical line number at which Field 2 ends.
 */
/*@{*/
#define BP_LCDIF_DVICTRL2_F2_END_LINE (20U) /*!< Bit position for LCDIF_DVICTRL2_F2_END_LINE. */
#define BM_LCDIF_DVICTRL2_F2_END_LINE (0x3FF00000U) /*!< Bit mask for LCDIF_DVICTRL2_F2_END_LINE. */
#define BS_LCDIF_DVICTRL2_F2_END_LINE (10U) /*!< Bit field size in bits for LCDIF_DVICTRL2_F2_END_LINE. */

/*! @brief Read current value of the LCDIF_DVICTRL2_F2_END_LINE field. */
#define BR_LCDIF_DVICTRL2_F2_END_LINE(x) (HW_LCDIF_DVICTRL2(x).B.F2_END_LINE)

/*! @brief Format value for bitfield LCDIF_DVICTRL2_F2_END_LINE. */
#define BF_LCDIF_DVICTRL2_F2_END_LINE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL2_F2_END_LINE) & BM_LCDIF_DVICTRL2_F2_END_LINE)

/*! @brief Set the F2_END_LINE field to a new value. */
#define BW_LCDIF_DVICTRL2_F2_END_LINE(x, v) (HW_LCDIF_DVICTRL2_WR(x, (HW_LCDIF_DVICTRL2_RD(x) & ~BM_LCDIF_DVICTRL2_F2_END_LINE) | BF_LCDIF_DVICTRL2_F2_END_LINE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL2, field RSRVD0[31:30] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_DVICTRL2_RSRVD0 (30U)     /*!< Bit position for LCDIF_DVICTRL2_RSRVD0. */
#define BM_LCDIF_DVICTRL2_RSRVD0 (0xC0000000U) /*!< Bit mask for LCDIF_DVICTRL2_RSRVD0. */
#define BS_LCDIF_DVICTRL2_RSRVD0 (2U)      /*!< Bit field size in bits for LCDIF_DVICTRL2_RSRVD0. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DVICTRL3 - Digital Video Interface Control3 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DVICTRL3 - Digital Video Interface Control3 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Digital Video interface Control3 register provides the overall control of
 * the Digital Video interface. This register contains information about the
 * Vertical Blanking2 interval in the ITU-R BT.656 interface. EXAMPLE //525/60 video
 * system HW_LCDIF_DVICTRL3_V2_BLANK_START_LINE_WR(0x1);//1
 * HW_LCDIF_DVICTRL3_V2_BLANK_END_LINE_WR(0x13);//19 HW_LCDIF_DVICTRL0_V_LINES_CNT_WR(0x20D);//525
 * //625/50 video system HW_LCDIF_DVICTRL3_V2_BLANK_START_LINE_WR(0x270);//624
 * HW_LCDIF_DVICTRL3_V2_BLANK_END_LINE_WR(0x16);//22
 * HW_LCDIF_DVICTRL0_V_LINES_CNT_WR(0x271);//625
 */
typedef union _hw_lcdif_dvictrl3
{
    uint32_t U;
    struct _hw_lcdif_dvictrl3_bitfields
    {
        uint32_t V_LINES_CNT : 10;     /*!< [9:0]  */
        uint32_t V2_BLANK_END_LINE : 10; /*!< [19:10]  */
        uint32_t V2_BLANK_START_LINE : 10; /*!< [29:20]  */
        uint32_t RSRVD0 : 2;           /*!< [31:30]  */
    } B;
} hw_lcdif_dvictrl3_t;

/*!
 * @name Constants and macros for entire LCDIF_DVICTRL3 register
 */
/*@{*/
#define HW_LCDIF_DVICTRL3_ADDR(x) ((uintptr_t)(x) + 0xF0U)

#define HW_LCDIF_DVICTRL3(x)     (*(__IO hw_lcdif_dvictrl3_t *) HW_LCDIF_DVICTRL3_ADDR(x))
#define HW_LCDIF_DVICTRL3_RD(x)  (HW_LCDIF_DVICTRL3(x).U)
#define HW_LCDIF_DVICTRL3_WR(x, v) (HW_LCDIF_DVICTRL3(x).U = (v))
#define HW_LCDIF_DVICTRL3_SET(x, v) (HW_LCDIF_DVICTRL3_WR(x, HW_LCDIF_DVICTRL3_RD(x) |  (v)))
#define HW_LCDIF_DVICTRL3_CLR(x, v) (HW_LCDIF_DVICTRL3_WR(x, HW_LCDIF_DVICTRL3_RD(x) & ~(v)))
#define HW_LCDIF_DVICTRL3_TOG(x, v) (HW_LCDIF_DVICTRL3_WR(x, HW_LCDIF_DVICTRL3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_DVICTRL3 bitfields
 */

/*!
 * @name Register LCDIF_DVICTRL3, field V_LINES_CNT[9:0] (RW)
 *
 * Total number of vertical lines per frame (generally 525 or 625)
 */
/*@{*/
#define BP_LCDIF_DVICTRL3_V_LINES_CNT (0U) /*!< Bit position for LCDIF_DVICTRL3_V_LINES_CNT. */
#define BM_LCDIF_DVICTRL3_V_LINES_CNT (0x000003FFU) /*!< Bit mask for LCDIF_DVICTRL3_V_LINES_CNT. */
#define BS_LCDIF_DVICTRL3_V_LINES_CNT (10U) /*!< Bit field size in bits for LCDIF_DVICTRL3_V_LINES_CNT. */

/*! @brief Read current value of the LCDIF_DVICTRL3_V_LINES_CNT field. */
#define BR_LCDIF_DVICTRL3_V_LINES_CNT(x) (HW_LCDIF_DVICTRL3(x).B.V_LINES_CNT)

/*! @brief Format value for bitfield LCDIF_DVICTRL3_V_LINES_CNT. */
#define BF_LCDIF_DVICTRL3_V_LINES_CNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL3_V_LINES_CNT) & BM_LCDIF_DVICTRL3_V_LINES_CNT)

/*! @brief Set the V_LINES_CNT field to a new value. */
#define BW_LCDIF_DVICTRL3_V_LINES_CNT(x, v) (HW_LCDIF_DVICTRL3_WR(x, (HW_LCDIF_DVICTRL3_RD(x) & ~BM_LCDIF_DVICTRL3_V_LINES_CNT) | BF_LCDIF_DVICTRL3_V_LINES_CNT(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL3, field V2_BLANK_END_LINE[19:10] (RW)
 *
 * Vertical line number in the beginning part of Field1 where second Vertical
 * Blanking interval ends.
 */
/*@{*/
#define BP_LCDIF_DVICTRL3_V2_BLANK_END_LINE (10U) /*!< Bit position for LCDIF_DVICTRL3_V2_BLANK_END_LINE. */
#define BM_LCDIF_DVICTRL3_V2_BLANK_END_LINE (0x000FFC00U) /*!< Bit mask for LCDIF_DVICTRL3_V2_BLANK_END_LINE. */
#define BS_LCDIF_DVICTRL3_V2_BLANK_END_LINE (10U) /*!< Bit field size in bits for LCDIF_DVICTRL3_V2_BLANK_END_LINE. */

/*! @brief Read current value of the LCDIF_DVICTRL3_V2_BLANK_END_LINE field. */
#define BR_LCDIF_DVICTRL3_V2_BLANK_END_LINE(x) (HW_LCDIF_DVICTRL3(x).B.V2_BLANK_END_LINE)

/*! @brief Format value for bitfield LCDIF_DVICTRL3_V2_BLANK_END_LINE. */
#define BF_LCDIF_DVICTRL3_V2_BLANK_END_LINE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL3_V2_BLANK_END_LINE) & BM_LCDIF_DVICTRL3_V2_BLANK_END_LINE)

/*! @brief Set the V2_BLANK_END_LINE field to a new value. */
#define BW_LCDIF_DVICTRL3_V2_BLANK_END_LINE(x, v) (HW_LCDIF_DVICTRL3_WR(x, (HW_LCDIF_DVICTRL3_RD(x) & ~BM_LCDIF_DVICTRL3_V2_BLANK_END_LINE) | BF_LCDIF_DVICTRL3_V2_BLANK_END_LINE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL3, field V2_BLANK_START_LINE[29:20] (RW)
 *
 * Vertical line number towards the end of Field2 where second Vertical Blanking
 * interval starts.
 */
/*@{*/
#define BP_LCDIF_DVICTRL3_V2_BLANK_START_LINE (20U) /*!< Bit position for LCDIF_DVICTRL3_V2_BLANK_START_LINE. */
#define BM_LCDIF_DVICTRL3_V2_BLANK_START_LINE (0x3FF00000U) /*!< Bit mask for LCDIF_DVICTRL3_V2_BLANK_START_LINE. */
#define BS_LCDIF_DVICTRL3_V2_BLANK_START_LINE (10U) /*!< Bit field size in bits for LCDIF_DVICTRL3_V2_BLANK_START_LINE. */

/*! @brief Read current value of the LCDIF_DVICTRL3_V2_BLANK_START_LINE field. */
#define BR_LCDIF_DVICTRL3_V2_BLANK_START_LINE(x) (HW_LCDIF_DVICTRL3(x).B.V2_BLANK_START_LINE)

/*! @brief Format value for bitfield LCDIF_DVICTRL3_V2_BLANK_START_LINE. */
#define BF_LCDIF_DVICTRL3_V2_BLANK_START_LINE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL3_V2_BLANK_START_LINE) & BM_LCDIF_DVICTRL3_V2_BLANK_START_LINE)

/*! @brief Set the V2_BLANK_START_LINE field to a new value. */
#define BW_LCDIF_DVICTRL3_V2_BLANK_START_LINE(x, v) (HW_LCDIF_DVICTRL3_WR(x, (HW_LCDIF_DVICTRL3_RD(x) & ~BM_LCDIF_DVICTRL3_V2_BLANK_START_LINE) | BF_LCDIF_DVICTRL3_V2_BLANK_START_LINE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL3, field RSRVD0[31:30] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_DVICTRL3_RSRVD0 (30U)     /*!< Bit position for LCDIF_DVICTRL3_RSRVD0. */
#define BM_LCDIF_DVICTRL3_RSRVD0 (0xC0000000U) /*!< Bit mask for LCDIF_DVICTRL3_RSRVD0. */
#define BS_LCDIF_DVICTRL3_RSRVD0 (2U)      /*!< Bit field size in bits for LCDIF_DVICTRL3_RSRVD0. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DVICTRL4 - Digital Video Interface Control4 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DVICTRL4 - Digital Video Interface Control4 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Digital Video interface Control4 register provides the overall control of
 * the Digital Video interface. This register is used to add side borders to the
 * output if the input frame width is less than 720 pixels. EXAMPLE //If input
 * frame has only 640 pixels per line, but output is supposed to have 720 pixels
 * per line. HW_LCDIF_DVICTRL4_H_FILL_CNT_WR(0x50);//80
 * HW_LCDIF_DVICTRL4_Y_FILL_VALUE_WR(0x10);//16 HW_LCDIF_DVICTRL4_CB_FILL_VALUE_WR(0x80);//128
 * HW_LCDIF_DVICTRL4_CR_FILL_VALUE_WR(0x80);//128
 */
typedef union _hw_lcdif_dvictrl4
{
    uint32_t U;
    struct _hw_lcdif_dvictrl4_bitfields
    {
        uint32_t H_FILL_CNT : 8;       /*!< [7:0]  */
        uint32_t CR_FILL_VALUE : 8;    /*!< [15:8]  */
        uint32_t CB_FILL_VALUE : 8;    /*!< [23:16]  */
        uint32_t Y_FILL_VALUE : 8;     /*!< [31:24]  */
    } B;
} hw_lcdif_dvictrl4_t;

/*!
 * @name Constants and macros for entire LCDIF_DVICTRL4 register
 */
/*@{*/
#define HW_LCDIF_DVICTRL4_ADDR(x) ((uintptr_t)(x) + 0x100U)

#define HW_LCDIF_DVICTRL4(x)     (*(__IO hw_lcdif_dvictrl4_t *) HW_LCDIF_DVICTRL4_ADDR(x))
#define HW_LCDIF_DVICTRL4_RD(x)  (HW_LCDIF_DVICTRL4(x).U)
#define HW_LCDIF_DVICTRL4_WR(x, v) (HW_LCDIF_DVICTRL4(x).U = (v))
#define HW_LCDIF_DVICTRL4_SET(x, v) (HW_LCDIF_DVICTRL4_WR(x, HW_LCDIF_DVICTRL4_RD(x) |  (v)))
#define HW_LCDIF_DVICTRL4_CLR(x, v) (HW_LCDIF_DVICTRL4_WR(x, HW_LCDIF_DVICTRL4_RD(x) & ~(v)))
#define HW_LCDIF_DVICTRL4_TOG(x, v) (HW_LCDIF_DVICTRL4_WR(x, HW_LCDIF_DVICTRL4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_DVICTRL4 bitfields
 */

/*!
 * @name Register LCDIF_DVICTRL4, field H_FILL_CNT[7:0] (RW)
 *
 * Number of active video samples that have to be filled with the filler data in
 * the front and back portions of the active horizontal interval. Must be a
 * multiple of 4. This field will have to be programmed if the input frame has less
 * than 720 pixels per line.
 */
/*@{*/
#define BP_LCDIF_DVICTRL4_H_FILL_CNT (0U)  /*!< Bit position for LCDIF_DVICTRL4_H_FILL_CNT. */
#define BM_LCDIF_DVICTRL4_H_FILL_CNT (0x000000FFU) /*!< Bit mask for LCDIF_DVICTRL4_H_FILL_CNT. */
#define BS_LCDIF_DVICTRL4_H_FILL_CNT (8U)  /*!< Bit field size in bits for LCDIF_DVICTRL4_H_FILL_CNT. */

/*! @brief Read current value of the LCDIF_DVICTRL4_H_FILL_CNT field. */
#define BR_LCDIF_DVICTRL4_H_FILL_CNT(x) (HW_LCDIF_DVICTRL4(x).B.H_FILL_CNT)

/*! @brief Format value for bitfield LCDIF_DVICTRL4_H_FILL_CNT. */
#define BF_LCDIF_DVICTRL4_H_FILL_CNT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL4_H_FILL_CNT) & BM_LCDIF_DVICTRL4_H_FILL_CNT)

/*! @brief Set the H_FILL_CNT field to a new value. */
#define BW_LCDIF_DVICTRL4_H_FILL_CNT(x, v) (HW_LCDIF_DVICTRL4_WR(x, (HW_LCDIF_DVICTRL4_RD(x) & ~BM_LCDIF_DVICTRL4_H_FILL_CNT) | BF_LCDIF_DVICTRL4_H_FILL_CNT(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL4, field CR_FILL_VALUE[15:8] (RW)
 *
 * Value of CR component of filler data.
 */
/*@{*/
#define BP_LCDIF_DVICTRL4_CR_FILL_VALUE (8U) /*!< Bit position for LCDIF_DVICTRL4_CR_FILL_VALUE. */
#define BM_LCDIF_DVICTRL4_CR_FILL_VALUE (0x0000FF00U) /*!< Bit mask for LCDIF_DVICTRL4_CR_FILL_VALUE. */
#define BS_LCDIF_DVICTRL4_CR_FILL_VALUE (8U) /*!< Bit field size in bits for LCDIF_DVICTRL4_CR_FILL_VALUE. */

/*! @brief Read current value of the LCDIF_DVICTRL4_CR_FILL_VALUE field. */
#define BR_LCDIF_DVICTRL4_CR_FILL_VALUE(x) (HW_LCDIF_DVICTRL4(x).B.CR_FILL_VALUE)

/*! @brief Format value for bitfield LCDIF_DVICTRL4_CR_FILL_VALUE. */
#define BF_LCDIF_DVICTRL4_CR_FILL_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL4_CR_FILL_VALUE) & BM_LCDIF_DVICTRL4_CR_FILL_VALUE)

/*! @brief Set the CR_FILL_VALUE field to a new value. */
#define BW_LCDIF_DVICTRL4_CR_FILL_VALUE(x, v) (HW_LCDIF_DVICTRL4_WR(x, (HW_LCDIF_DVICTRL4_RD(x) & ~BM_LCDIF_DVICTRL4_CR_FILL_VALUE) | BF_LCDIF_DVICTRL4_CR_FILL_VALUE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL4, field CB_FILL_VALUE[23:16] (RW)
 *
 * Value of CB component of filler data
 */
/*@{*/
#define BP_LCDIF_DVICTRL4_CB_FILL_VALUE (16U) /*!< Bit position for LCDIF_DVICTRL4_CB_FILL_VALUE. */
#define BM_LCDIF_DVICTRL4_CB_FILL_VALUE (0x00FF0000U) /*!< Bit mask for LCDIF_DVICTRL4_CB_FILL_VALUE. */
#define BS_LCDIF_DVICTRL4_CB_FILL_VALUE (8U) /*!< Bit field size in bits for LCDIF_DVICTRL4_CB_FILL_VALUE. */

/*! @brief Read current value of the LCDIF_DVICTRL4_CB_FILL_VALUE field. */
#define BR_LCDIF_DVICTRL4_CB_FILL_VALUE(x) (HW_LCDIF_DVICTRL4(x).B.CB_FILL_VALUE)

/*! @brief Format value for bitfield LCDIF_DVICTRL4_CB_FILL_VALUE. */
#define BF_LCDIF_DVICTRL4_CB_FILL_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL4_CB_FILL_VALUE) & BM_LCDIF_DVICTRL4_CB_FILL_VALUE)

/*! @brief Set the CB_FILL_VALUE field to a new value. */
#define BW_LCDIF_DVICTRL4_CB_FILL_VALUE(x, v) (HW_LCDIF_DVICTRL4_WR(x, (HW_LCDIF_DVICTRL4_RD(x) & ~BM_LCDIF_DVICTRL4_CB_FILL_VALUE) | BF_LCDIF_DVICTRL4_CB_FILL_VALUE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DVICTRL4, field Y_FILL_VALUE[31:24] (RW)
 *
 * Value of Y component of filler data
 */
/*@{*/
#define BP_LCDIF_DVICTRL4_Y_FILL_VALUE (24U) /*!< Bit position for LCDIF_DVICTRL4_Y_FILL_VALUE. */
#define BM_LCDIF_DVICTRL4_Y_FILL_VALUE (0xFF000000U) /*!< Bit mask for LCDIF_DVICTRL4_Y_FILL_VALUE. */
#define BS_LCDIF_DVICTRL4_Y_FILL_VALUE (8U) /*!< Bit field size in bits for LCDIF_DVICTRL4_Y_FILL_VALUE. */

/*! @brief Read current value of the LCDIF_DVICTRL4_Y_FILL_VALUE field. */
#define BR_LCDIF_DVICTRL4_Y_FILL_VALUE(x) (HW_LCDIF_DVICTRL4(x).B.Y_FILL_VALUE)

/*! @brief Format value for bitfield LCDIF_DVICTRL4_Y_FILL_VALUE. */
#define BF_LCDIF_DVICTRL4_Y_FILL_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DVICTRL4_Y_FILL_VALUE) & BM_LCDIF_DVICTRL4_Y_FILL_VALUE)

/*! @brief Set the Y_FILL_VALUE field to a new value. */
#define BW_LCDIF_DVICTRL4_Y_FILL_VALUE(x, v) (HW_LCDIF_DVICTRL4_WR(x, (HW_LCDIF_DVICTRL4_RD(x) & ~BM_LCDIF_DVICTRL4_Y_FILL_VALUE) | BF_LCDIF_DVICTRL4_Y_FILL_VALUE(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_CSC_COEFF0 - RGB to YCbCr 4:2:2 CSC Coefficient0 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CSC_COEFF0 - RGB to YCbCr 4:2:2 CSC Coefficient0 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * LCDIF_CSC_COEFF0 register provides overall control over color space
 * conversion from RGB to 4:2:2 YCbCr. The equations for the conversion are given by: Y =
 * C0*R + C1*G + C2*B + Y_offset Cb= C3*R + C4*G + C5*B + CbCr_offset Cr= C6*R +
 * C7*G + C8*B + CbCr_offset This register carries programming information about
 * RGB to YCbCr 4:2:2 CSC. EXAMPLE HW_LCDIF_CSC_COEFF0_C0_WR(0x41);//0.257x256=65
 * HW_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER_WR(0x3);
 */
typedef union _hw_lcdif_csc_coeff0
{
    uint32_t U;
    struct _hw_lcdif_csc_coeff0_bitfields
    {
        uint32_t CSC_SUBSAMPLE_FILTER : 2; /*!< [1:0]  */
        uint32_t RSRVD0 : 14;          /*!< [15:2]  */
        uint32_t C0 : 10;              /*!< [25:16]  */
        uint32_t RSRVD1 : 6;           /*!< [31:26]  */
    } B;
} hw_lcdif_csc_coeff0_t;

/*!
 * @name Constants and macros for entire LCDIF_CSC_COEFF0 register
 */
/*@{*/
#define HW_LCDIF_CSC_COEFF0_ADDR(x) ((uintptr_t)(x) + 0x110U)

#define HW_LCDIF_CSC_COEFF0(x)   (*(__IO hw_lcdif_csc_coeff0_t *) HW_LCDIF_CSC_COEFF0_ADDR(x))
#define HW_LCDIF_CSC_COEFF0_RD(x) (HW_LCDIF_CSC_COEFF0(x).U)
#define HW_LCDIF_CSC_COEFF0_WR(x, v) (HW_LCDIF_CSC_COEFF0(x).U = (v))
#define HW_LCDIF_CSC_COEFF0_SET(x, v) (HW_LCDIF_CSC_COEFF0_WR(x, HW_LCDIF_CSC_COEFF0_RD(x) |  (v)))
#define HW_LCDIF_CSC_COEFF0_CLR(x, v) (HW_LCDIF_CSC_COEFF0_WR(x, HW_LCDIF_CSC_COEFF0_RD(x) & ~(v)))
#define HW_LCDIF_CSC_COEFF0_TOG(x, v) (HW_LCDIF_CSC_COEFF0_WR(x, HW_LCDIF_CSC_COEFF0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CSC_COEFF0 bitfields
 */

/*!
 * @name Register LCDIF_CSC_COEFF0, field CSC_SUBSAMPLE_FILTER[1:0] (RW)
 *
 * This register describes the filtering and subsampling scheme to be performed
 * on the chroma components in order to convert from YCbCr 4:4:4 to YCbCr 4:2:2
 * space. Note that the following descriptions apply individually to Cb and Cr.
 *
 * Values:
 * - 0 - No filtering, simply keep every chroma value for samples numbered 2n
 *     and discard chroma values associated with all samples numbered 2n+1.
 * - 1 - Reserved
 * - 10 - Chroma samples numbered 2n and 2n+1 are averaged (weights 1/2, 1/2)
 *     and that chroma value replaces the two chroma values at 2n and 2n+1. This
 *     chroma now exists horizontally halfway between the two luma samples.
 * - 11 - Chroma samples numbered 2n-1, 2n, and 2n+1 are averaged (weights 1/4,
 *     1/2, 1/4) and that chroma value exists at the same site as the luma sample
 *     numbered 2n and the chroma samples at 2n+1 are discarded.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER (0U) /*!< Bit position for LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER. */
#define BM_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER (0x00000003U) /*!< Bit mask for LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER. */
#define BS_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER (2U) /*!< Bit field size in bits for LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER. */

#define BV_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER_SAMPLE_AND_HOLD (0U) /*!< Bit field value for LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER: No filtering, simply keep every chroma value for samples numbered 2n and discard chroma values associated with all samples numbered 2n+1. */
#define BV_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER_RSRVD (0x1U) /*!< Bit field value for LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER: Reserved */
#define BV_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER_INTERSTITIAL (0x2U) /*!< Bit field value for LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER: Chroma samples numbered 2n and 2n+1 are averaged (weights 1/2, 1/2) and that chroma value replaces the two chroma values at 2n and 2n+1. This chroma now exists horizontally halfway between the two luma samples. */
#define BV_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER_COSITED (0x3U) /*!< Bit field value for LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER: Chroma samples numbered 2n-1, 2n, and 2n+1 are averaged (weights 1/4, 1/2, 1/4) and that chroma value exists at the same site as the luma sample numbered 2n and the chroma samples at 2n+1 are discarded. */

/*! @brief Read current value of the LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER field. */
#define BR_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER(x) (HW_LCDIF_CSC_COEFF0(x).B.CSC_SUBSAMPLE_FILTER)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER. */
#define BF_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER) & BM_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER)

/*! @brief Set the CSC_SUBSAMPLE_FILTER field to a new value. */
#define BW_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER(x, v) (HW_LCDIF_CSC_COEFF0_WR(x, (HW_LCDIF_CSC_COEFF0_RD(x) & ~BM_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER) | BF_LCDIF_CSC_COEFF0_CSC_SUBSAMPLE_FILTER(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF0, field RSRVD0[15:2] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF0_RSRVD0 (2U)    /*!< Bit position for LCDIF_CSC_COEFF0_RSRVD0. */
#define BM_LCDIF_CSC_COEFF0_RSRVD0 (0x0000FFFCU) /*!< Bit mask for LCDIF_CSC_COEFF0_RSRVD0. */
#define BS_LCDIF_CSC_COEFF0_RSRVD0 (14U)   /*!< Bit field size in bits for LCDIF_CSC_COEFF0_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF0, field C0[25:16] (RW)
 *
 * Two's complement red multiplier coefficient for Y
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF0_C0 (16U)       /*!< Bit position for LCDIF_CSC_COEFF0_C0. */
#define BM_LCDIF_CSC_COEFF0_C0 (0x03FF0000U) /*!< Bit mask for LCDIF_CSC_COEFF0_C0. */
#define BS_LCDIF_CSC_COEFF0_C0 (10U)       /*!< Bit field size in bits for LCDIF_CSC_COEFF0_C0. */

/*! @brief Read current value of the LCDIF_CSC_COEFF0_C0 field. */
#define BR_LCDIF_CSC_COEFF0_C0(x) (HW_LCDIF_CSC_COEFF0(x).B.C0)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF0_C0. */
#define BF_LCDIF_CSC_COEFF0_C0(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF0_C0) & BM_LCDIF_CSC_COEFF0_C0)

/*! @brief Set the C0 field to a new value. */
#define BW_LCDIF_CSC_COEFF0_C0(x, v) (HW_LCDIF_CSC_COEFF0_WR(x, (HW_LCDIF_CSC_COEFF0_RD(x) & ~BM_LCDIF_CSC_COEFF0_C0) | BF_LCDIF_CSC_COEFF0_C0(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF0, field RSRVD1[31:26] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF0_RSRVD1 (26U)   /*!< Bit position for LCDIF_CSC_COEFF0_RSRVD1. */
#define BM_LCDIF_CSC_COEFF0_RSRVD1 (0xFC000000U) /*!< Bit mask for LCDIF_CSC_COEFF0_RSRVD1. */
#define BS_LCDIF_CSC_COEFF0_RSRVD1 (6U)    /*!< Bit field size in bits for LCDIF_CSC_COEFF0_RSRVD1. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_CSC_COEFF1 - RGB to YCbCr 4:2:2 CSC Coefficient1 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CSC_COEFF1 - RGB to YCbCr 4:2:2 CSC Coefficient1 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * LCDIF_CSC_COEFF1 register provides overall control over color space
 * conversion from RGB to 4:2:2 YCbCr. The equations for the conversion are given by: Y =
 * C0*R + C1*G + C2*B + Y_offset Cb= C3*R + C4*G + C5*B + CbCr_offset Cr= C6*R +
 * C7*G + C8*B + CbCr_offset This register carries programming information about
 * RGB to YCbCr 4:2:2 CSC. EXAMPLE
 * HW_LCDIF_CSC_COEFF1_C1_WR(0x81);//0.504x256=129 HW_LCDIF_CSC_COEFF1_C2_WR(0x19);//0.098x256=25
 */
typedef union _hw_lcdif_csc_coeff1
{
    uint32_t U;
    struct _hw_lcdif_csc_coeff1_bitfields
    {
        uint32_t C1 : 10;              /*!< [9:0]  */
        uint32_t RSRVD0 : 6;           /*!< [15:10]  */
        uint32_t C2 : 10;              /*!< [25:16]  */
        uint32_t RSRVD1 : 6;           /*!< [31:26]  */
    } B;
} hw_lcdif_csc_coeff1_t;

/*!
 * @name Constants and macros for entire LCDIF_CSC_COEFF1 register
 */
/*@{*/
#define HW_LCDIF_CSC_COEFF1_ADDR(x) ((uintptr_t)(x) + 0x120U)

#define HW_LCDIF_CSC_COEFF1(x)   (*(__IO hw_lcdif_csc_coeff1_t *) HW_LCDIF_CSC_COEFF1_ADDR(x))
#define HW_LCDIF_CSC_COEFF1_RD(x) (HW_LCDIF_CSC_COEFF1(x).U)
#define HW_LCDIF_CSC_COEFF1_WR(x, v) (HW_LCDIF_CSC_COEFF1(x).U = (v))
#define HW_LCDIF_CSC_COEFF1_SET(x, v) (HW_LCDIF_CSC_COEFF1_WR(x, HW_LCDIF_CSC_COEFF1_RD(x) |  (v)))
#define HW_LCDIF_CSC_COEFF1_CLR(x, v) (HW_LCDIF_CSC_COEFF1_WR(x, HW_LCDIF_CSC_COEFF1_RD(x) & ~(v)))
#define HW_LCDIF_CSC_COEFF1_TOG(x, v) (HW_LCDIF_CSC_COEFF1_WR(x, HW_LCDIF_CSC_COEFF1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CSC_COEFF1 bitfields
 */

/*!
 * @name Register LCDIF_CSC_COEFF1, field C1[9:0] (RW)
 *
 * Two's complement green multiplier coefficient for Y
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF1_C1 (0U)        /*!< Bit position for LCDIF_CSC_COEFF1_C1. */
#define BM_LCDIF_CSC_COEFF1_C1 (0x000003FFU) /*!< Bit mask for LCDIF_CSC_COEFF1_C1. */
#define BS_LCDIF_CSC_COEFF1_C1 (10U)       /*!< Bit field size in bits for LCDIF_CSC_COEFF1_C1. */

/*! @brief Read current value of the LCDIF_CSC_COEFF1_C1 field. */
#define BR_LCDIF_CSC_COEFF1_C1(x) (HW_LCDIF_CSC_COEFF1(x).B.C1)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF1_C1. */
#define BF_LCDIF_CSC_COEFF1_C1(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF1_C1) & BM_LCDIF_CSC_COEFF1_C1)

/*! @brief Set the C1 field to a new value. */
#define BW_LCDIF_CSC_COEFF1_C1(x, v) (HW_LCDIF_CSC_COEFF1_WR(x, (HW_LCDIF_CSC_COEFF1_RD(x) & ~BM_LCDIF_CSC_COEFF1_C1) | BF_LCDIF_CSC_COEFF1_C1(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF1, field RSRVD0[15:10] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF1_RSRVD0 (10U)   /*!< Bit position for LCDIF_CSC_COEFF1_RSRVD0. */
#define BM_LCDIF_CSC_COEFF1_RSRVD0 (0x0000FC00U) /*!< Bit mask for LCDIF_CSC_COEFF1_RSRVD0. */
#define BS_LCDIF_CSC_COEFF1_RSRVD0 (6U)    /*!< Bit field size in bits for LCDIF_CSC_COEFF1_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF1, field C2[25:16] (RW)
 *
 * Two's complement blue multiplier coefficient for Y
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF1_C2 (16U)       /*!< Bit position for LCDIF_CSC_COEFF1_C2. */
#define BM_LCDIF_CSC_COEFF1_C2 (0x03FF0000U) /*!< Bit mask for LCDIF_CSC_COEFF1_C2. */
#define BS_LCDIF_CSC_COEFF1_C2 (10U)       /*!< Bit field size in bits for LCDIF_CSC_COEFF1_C2. */

/*! @brief Read current value of the LCDIF_CSC_COEFF1_C2 field. */
#define BR_LCDIF_CSC_COEFF1_C2(x) (HW_LCDIF_CSC_COEFF1(x).B.C2)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF1_C2. */
#define BF_LCDIF_CSC_COEFF1_C2(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF1_C2) & BM_LCDIF_CSC_COEFF1_C2)

/*! @brief Set the C2 field to a new value. */
#define BW_LCDIF_CSC_COEFF1_C2(x, v) (HW_LCDIF_CSC_COEFF1_WR(x, (HW_LCDIF_CSC_COEFF1_RD(x) & ~BM_LCDIF_CSC_COEFF1_C2) | BF_LCDIF_CSC_COEFF1_C2(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF1, field RSRVD1[31:26] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF1_RSRVD1 (26U)   /*!< Bit position for LCDIF_CSC_COEFF1_RSRVD1. */
#define BM_LCDIF_CSC_COEFF1_RSRVD1 (0xFC000000U) /*!< Bit mask for LCDIF_CSC_COEFF1_RSRVD1. */
#define BS_LCDIF_CSC_COEFF1_RSRVD1 (6U)    /*!< Bit field size in bits for LCDIF_CSC_COEFF1_RSRVD1. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_CSC_COEFF2 - RGB to YCbCr 4:2:2 CSC Coefficent2 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CSC_COEFF2 - RGB to YCbCr 4:2:2 CSC Coefficent2 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * LCDIF_CSC_COEFF2 register provides overall control over color space
 * conversion from RGB to 4:2:2 YCbCr. The equations for the conversion are given by: Y =
 * C0*R + C1*G + C2*B + Y_offset Cb= C3*R + C4*G + C5*B + CbCr_offset Cr= C6*R +
 * C7*G + C8*B + CbCr_offset This register carries programming information about
 * RGB to YCbCr 4:2:2 CSC. EXAMPLE
 * HW_LCDIF_CSC_COEFF2_C3_WR(0x3DB);//-0.148x256=-37 HW_LCDIF_CSC_COEFF2_C4_WR(0x3B6);//-0.291x256=-74
 */
typedef union _hw_lcdif_csc_coeff2
{
    uint32_t U;
    struct _hw_lcdif_csc_coeff2_bitfields
    {
        uint32_t C3 : 10;              /*!< [9:0]  */
        uint32_t RSRVD0 : 6;           /*!< [15:10]  */
        uint32_t C4 : 10;              /*!< [25:16]  */
        uint32_t RSRVD1 : 6;           /*!< [31:26]  */
    } B;
} hw_lcdif_csc_coeff2_t;

/*!
 * @name Constants and macros for entire LCDIF_CSC_COEFF2 register
 */
/*@{*/
#define HW_LCDIF_CSC_COEFF2_ADDR(x) ((uintptr_t)(x) + 0x130U)

#define HW_LCDIF_CSC_COEFF2(x)   (*(__IO hw_lcdif_csc_coeff2_t *) HW_LCDIF_CSC_COEFF2_ADDR(x))
#define HW_LCDIF_CSC_COEFF2_RD(x) (HW_LCDIF_CSC_COEFF2(x).U)
#define HW_LCDIF_CSC_COEFF2_WR(x, v) (HW_LCDIF_CSC_COEFF2(x).U = (v))
#define HW_LCDIF_CSC_COEFF2_SET(x, v) (HW_LCDIF_CSC_COEFF2_WR(x, HW_LCDIF_CSC_COEFF2_RD(x) |  (v)))
#define HW_LCDIF_CSC_COEFF2_CLR(x, v) (HW_LCDIF_CSC_COEFF2_WR(x, HW_LCDIF_CSC_COEFF2_RD(x) & ~(v)))
#define HW_LCDIF_CSC_COEFF2_TOG(x, v) (HW_LCDIF_CSC_COEFF2_WR(x, HW_LCDIF_CSC_COEFF2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CSC_COEFF2 bitfields
 */

/*!
 * @name Register LCDIF_CSC_COEFF2, field C3[9:0] (RW)
 *
 * Two's complement red multiplier coefficient for Cb
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF2_C3 (0U)        /*!< Bit position for LCDIF_CSC_COEFF2_C3. */
#define BM_LCDIF_CSC_COEFF2_C3 (0x000003FFU) /*!< Bit mask for LCDIF_CSC_COEFF2_C3. */
#define BS_LCDIF_CSC_COEFF2_C3 (10U)       /*!< Bit field size in bits for LCDIF_CSC_COEFF2_C3. */

/*! @brief Read current value of the LCDIF_CSC_COEFF2_C3 field. */
#define BR_LCDIF_CSC_COEFF2_C3(x) (HW_LCDIF_CSC_COEFF2(x).B.C3)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF2_C3. */
#define BF_LCDIF_CSC_COEFF2_C3(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF2_C3) & BM_LCDIF_CSC_COEFF2_C3)

/*! @brief Set the C3 field to a new value. */
#define BW_LCDIF_CSC_COEFF2_C3(x, v) (HW_LCDIF_CSC_COEFF2_WR(x, (HW_LCDIF_CSC_COEFF2_RD(x) & ~BM_LCDIF_CSC_COEFF2_C3) | BF_LCDIF_CSC_COEFF2_C3(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF2, field RSRVD0[15:10] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF2_RSRVD0 (10U)   /*!< Bit position for LCDIF_CSC_COEFF2_RSRVD0. */
#define BM_LCDIF_CSC_COEFF2_RSRVD0 (0x0000FC00U) /*!< Bit mask for LCDIF_CSC_COEFF2_RSRVD0. */
#define BS_LCDIF_CSC_COEFF2_RSRVD0 (6U)    /*!< Bit field size in bits for LCDIF_CSC_COEFF2_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF2, field C4[25:16] (RW)
 *
 * Two's complement green multiplier coefficient for Cb
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF2_C4 (16U)       /*!< Bit position for LCDIF_CSC_COEFF2_C4. */
#define BM_LCDIF_CSC_COEFF2_C4 (0x03FF0000U) /*!< Bit mask for LCDIF_CSC_COEFF2_C4. */
#define BS_LCDIF_CSC_COEFF2_C4 (10U)       /*!< Bit field size in bits for LCDIF_CSC_COEFF2_C4. */

/*! @brief Read current value of the LCDIF_CSC_COEFF2_C4 field. */
#define BR_LCDIF_CSC_COEFF2_C4(x) (HW_LCDIF_CSC_COEFF2(x).B.C4)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF2_C4. */
#define BF_LCDIF_CSC_COEFF2_C4(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF2_C4) & BM_LCDIF_CSC_COEFF2_C4)

/*! @brief Set the C4 field to a new value. */
#define BW_LCDIF_CSC_COEFF2_C4(x, v) (HW_LCDIF_CSC_COEFF2_WR(x, (HW_LCDIF_CSC_COEFF2_RD(x) & ~BM_LCDIF_CSC_COEFF2_C4) | BF_LCDIF_CSC_COEFF2_C4(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF2, field RSRVD1[31:26] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF2_RSRVD1 (26U)   /*!< Bit position for LCDIF_CSC_COEFF2_RSRVD1. */
#define BM_LCDIF_CSC_COEFF2_RSRVD1 (0xFC000000U) /*!< Bit mask for LCDIF_CSC_COEFF2_RSRVD1. */
#define BS_LCDIF_CSC_COEFF2_RSRVD1 (6U)    /*!< Bit field size in bits for LCDIF_CSC_COEFF2_RSRVD1. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_CSC_COEFF3 - RGB to YCbCr 4:2:2 CSC Coefficient3 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CSC_COEFF3 - RGB to YCbCr 4:2:2 CSC Coefficient3 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * LCDIF_CSC_COEFF3 register provides overall control over color space
 * conversion from RGB to 4:2:2 YCbCr. The equations for the conversion are given by: Y =
 * C0*R + C1*G + C2*B + Y_offset Cb= C3*R + C4*G + C5*B + CbCr_offset Cr= C6*R +
 * C7*G + C8*B + CbCr_offset This register carries programming information about
 * RGB to YCbCr 4:2:2 CSC. EXAMPLE
 * HW_LCDIF_CSC_COEFF3_C5_WR(0x70);//0.439x256=112 HW_LCDIF_CSC_COEFF3_C6_WR(0x70);//0.439x256=112
 */
typedef union _hw_lcdif_csc_coeff3
{
    uint32_t U;
    struct _hw_lcdif_csc_coeff3_bitfields
    {
        uint32_t C5 : 10;              /*!< [9:0]  */
        uint32_t RSRVD0 : 6;           /*!< [15:10]  */
        uint32_t C6 : 10;              /*!< [25:16]  */
        uint32_t RSRVD1 : 6;           /*!< [31:26]  */
    } B;
} hw_lcdif_csc_coeff3_t;

/*!
 * @name Constants and macros for entire LCDIF_CSC_COEFF3 register
 */
/*@{*/
#define HW_LCDIF_CSC_COEFF3_ADDR(x) ((uintptr_t)(x) + 0x140U)

#define HW_LCDIF_CSC_COEFF3(x)   (*(__IO hw_lcdif_csc_coeff3_t *) HW_LCDIF_CSC_COEFF3_ADDR(x))
#define HW_LCDIF_CSC_COEFF3_RD(x) (HW_LCDIF_CSC_COEFF3(x).U)
#define HW_LCDIF_CSC_COEFF3_WR(x, v) (HW_LCDIF_CSC_COEFF3(x).U = (v))
#define HW_LCDIF_CSC_COEFF3_SET(x, v) (HW_LCDIF_CSC_COEFF3_WR(x, HW_LCDIF_CSC_COEFF3_RD(x) |  (v)))
#define HW_LCDIF_CSC_COEFF3_CLR(x, v) (HW_LCDIF_CSC_COEFF3_WR(x, HW_LCDIF_CSC_COEFF3_RD(x) & ~(v)))
#define HW_LCDIF_CSC_COEFF3_TOG(x, v) (HW_LCDIF_CSC_COEFF3_WR(x, HW_LCDIF_CSC_COEFF3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CSC_COEFF3 bitfields
 */

/*!
 * @name Register LCDIF_CSC_COEFF3, field C5[9:0] (RW)
 *
 * Two's complement blue multiplier coefficient for Cb
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF3_C5 (0U)        /*!< Bit position for LCDIF_CSC_COEFF3_C5. */
#define BM_LCDIF_CSC_COEFF3_C5 (0x000003FFU) /*!< Bit mask for LCDIF_CSC_COEFF3_C5. */
#define BS_LCDIF_CSC_COEFF3_C5 (10U)       /*!< Bit field size in bits for LCDIF_CSC_COEFF3_C5. */

/*! @brief Read current value of the LCDIF_CSC_COEFF3_C5 field. */
#define BR_LCDIF_CSC_COEFF3_C5(x) (HW_LCDIF_CSC_COEFF3(x).B.C5)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF3_C5. */
#define BF_LCDIF_CSC_COEFF3_C5(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF3_C5) & BM_LCDIF_CSC_COEFF3_C5)

/*! @brief Set the C5 field to a new value. */
#define BW_LCDIF_CSC_COEFF3_C5(x, v) (HW_LCDIF_CSC_COEFF3_WR(x, (HW_LCDIF_CSC_COEFF3_RD(x) & ~BM_LCDIF_CSC_COEFF3_C5) | BF_LCDIF_CSC_COEFF3_C5(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF3, field RSRVD0[15:10] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF3_RSRVD0 (10U)   /*!< Bit position for LCDIF_CSC_COEFF3_RSRVD0. */
#define BM_LCDIF_CSC_COEFF3_RSRVD0 (0x0000FC00U) /*!< Bit mask for LCDIF_CSC_COEFF3_RSRVD0. */
#define BS_LCDIF_CSC_COEFF3_RSRVD0 (6U)    /*!< Bit field size in bits for LCDIF_CSC_COEFF3_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF3, field C6[25:16] (RW)
 *
 * Two's complement red multiplier coefficient for Cr
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF3_C6 (16U)       /*!< Bit position for LCDIF_CSC_COEFF3_C6. */
#define BM_LCDIF_CSC_COEFF3_C6 (0x03FF0000U) /*!< Bit mask for LCDIF_CSC_COEFF3_C6. */
#define BS_LCDIF_CSC_COEFF3_C6 (10U)       /*!< Bit field size in bits for LCDIF_CSC_COEFF3_C6. */

/*! @brief Read current value of the LCDIF_CSC_COEFF3_C6 field. */
#define BR_LCDIF_CSC_COEFF3_C6(x) (HW_LCDIF_CSC_COEFF3(x).B.C6)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF3_C6. */
#define BF_LCDIF_CSC_COEFF3_C6(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF3_C6) & BM_LCDIF_CSC_COEFF3_C6)

/*! @brief Set the C6 field to a new value. */
#define BW_LCDIF_CSC_COEFF3_C6(x, v) (HW_LCDIF_CSC_COEFF3_WR(x, (HW_LCDIF_CSC_COEFF3_RD(x) & ~BM_LCDIF_CSC_COEFF3_C6) | BF_LCDIF_CSC_COEFF3_C6(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF3, field RSRVD1[31:26] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF3_RSRVD1 (26U)   /*!< Bit position for LCDIF_CSC_COEFF3_RSRVD1. */
#define BM_LCDIF_CSC_COEFF3_RSRVD1 (0xFC000000U) /*!< Bit mask for LCDIF_CSC_COEFF3_RSRVD1. */
#define BS_LCDIF_CSC_COEFF3_RSRVD1 (6U)    /*!< Bit field size in bits for LCDIF_CSC_COEFF3_RSRVD1. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_CSC_COEFF4 - RGB to YCbCr 4:2:2 CSC Coefficient4 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CSC_COEFF4 - RGB to YCbCr 4:2:2 CSC Coefficient4 Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * LCDIF_CSC_COEFF4 register provides overall control over color space
 * conversion from RGB to 4:2:2 YCbCr. The equations for the conversion are given by: Y =
 * C0*R + C1*G + C2*B + Y_offset Cb= C3*R + C4*G + C5*B + CbCr_offset Cr= C6*R +
 * C7*G + C8*B + CbCr_offset This register carries programming information about
 * RGB to YCbCr 4:2:2 CSC. EXAMPLE
 * HW_LCDIF_CSC_COEFF4_C7_WR(0x3A2);//-0.368x256=-94 HW_LCDIF_CSC_COEFF4_C8_WR(0x3EE);//-0.071x256=-18
 */
typedef union _hw_lcdif_csc_coeff4
{
    uint32_t U;
    struct _hw_lcdif_csc_coeff4_bitfields
    {
        uint32_t C7 : 10;              /*!< [9:0]  */
        uint32_t RSRVD0 : 6;           /*!< [15:10]  */
        uint32_t C8 : 10;              /*!< [25:16]  */
        uint32_t RSRVD1 : 6;           /*!< [31:26]  */
    } B;
} hw_lcdif_csc_coeff4_t;

/*!
 * @name Constants and macros for entire LCDIF_CSC_COEFF4 register
 */
/*@{*/
#define HW_LCDIF_CSC_COEFF4_ADDR(x) ((uintptr_t)(x) + 0x150U)

#define HW_LCDIF_CSC_COEFF4(x)   (*(__IO hw_lcdif_csc_coeff4_t *) HW_LCDIF_CSC_COEFF4_ADDR(x))
#define HW_LCDIF_CSC_COEFF4_RD(x) (HW_LCDIF_CSC_COEFF4(x).U)
#define HW_LCDIF_CSC_COEFF4_WR(x, v) (HW_LCDIF_CSC_COEFF4(x).U = (v))
#define HW_LCDIF_CSC_COEFF4_SET(x, v) (HW_LCDIF_CSC_COEFF4_WR(x, HW_LCDIF_CSC_COEFF4_RD(x) |  (v)))
#define HW_LCDIF_CSC_COEFF4_CLR(x, v) (HW_LCDIF_CSC_COEFF4_WR(x, HW_LCDIF_CSC_COEFF4_RD(x) & ~(v)))
#define HW_LCDIF_CSC_COEFF4_TOG(x, v) (HW_LCDIF_CSC_COEFF4_WR(x, HW_LCDIF_CSC_COEFF4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CSC_COEFF4 bitfields
 */

/*!
 * @name Register LCDIF_CSC_COEFF4, field C7[9:0] (RW)
 *
 * Two's complement green multiplier coefficient for Cr
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF4_C7 (0U)        /*!< Bit position for LCDIF_CSC_COEFF4_C7. */
#define BM_LCDIF_CSC_COEFF4_C7 (0x000003FFU) /*!< Bit mask for LCDIF_CSC_COEFF4_C7. */
#define BS_LCDIF_CSC_COEFF4_C7 (10U)       /*!< Bit field size in bits for LCDIF_CSC_COEFF4_C7. */

/*! @brief Read current value of the LCDIF_CSC_COEFF4_C7 field. */
#define BR_LCDIF_CSC_COEFF4_C7(x) (HW_LCDIF_CSC_COEFF4(x).B.C7)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF4_C7. */
#define BF_LCDIF_CSC_COEFF4_C7(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF4_C7) & BM_LCDIF_CSC_COEFF4_C7)

/*! @brief Set the C7 field to a new value. */
#define BW_LCDIF_CSC_COEFF4_C7(x, v) (HW_LCDIF_CSC_COEFF4_WR(x, (HW_LCDIF_CSC_COEFF4_RD(x) & ~BM_LCDIF_CSC_COEFF4_C7) | BF_LCDIF_CSC_COEFF4_C7(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF4, field RSRVD0[15:10] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF4_RSRVD0 (10U)   /*!< Bit position for LCDIF_CSC_COEFF4_RSRVD0. */
#define BM_LCDIF_CSC_COEFF4_RSRVD0 (0x0000FC00U) /*!< Bit mask for LCDIF_CSC_COEFF4_RSRVD0. */
#define BS_LCDIF_CSC_COEFF4_RSRVD0 (6U)    /*!< Bit field size in bits for LCDIF_CSC_COEFF4_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF4, field C8[25:16] (RW)
 *
 * Two's complement blue multiplier coefficient for Cr
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF4_C8 (16U)       /*!< Bit position for LCDIF_CSC_COEFF4_C8. */
#define BM_LCDIF_CSC_COEFF4_C8 (0x03FF0000U) /*!< Bit mask for LCDIF_CSC_COEFF4_C8. */
#define BS_LCDIF_CSC_COEFF4_C8 (10U)       /*!< Bit field size in bits for LCDIF_CSC_COEFF4_C8. */

/*! @brief Read current value of the LCDIF_CSC_COEFF4_C8 field. */
#define BR_LCDIF_CSC_COEFF4_C8(x) (HW_LCDIF_CSC_COEFF4(x).B.C8)

/*! @brief Format value for bitfield LCDIF_CSC_COEFF4_C8. */
#define BF_LCDIF_CSC_COEFF4_C8(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_COEFF4_C8) & BM_LCDIF_CSC_COEFF4_C8)

/*! @brief Set the C8 field to a new value. */
#define BW_LCDIF_CSC_COEFF4_C8(x, v) (HW_LCDIF_CSC_COEFF4_WR(x, (HW_LCDIF_CSC_COEFF4_RD(x) & ~BM_LCDIF_CSC_COEFF4_C8) | BF_LCDIF_CSC_COEFF4_C8(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_COEFF4, field RSRVD1[31:26] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_COEFF4_RSRVD1 (26U)   /*!< Bit position for LCDIF_CSC_COEFF4_RSRVD1. */
#define BM_LCDIF_CSC_COEFF4_RSRVD1 (0xFC000000U) /*!< Bit mask for LCDIF_CSC_COEFF4_RSRVD1. */
#define BS_LCDIF_CSC_COEFF4_RSRVD1 (6U)    /*!< Bit field size in bits for LCDIF_CSC_COEFF4_RSRVD1. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_CSC_OFFSET - RGB to YCbCr 4:2:2 CSC Offset Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CSC_OFFSET - RGB to YCbCr 4:2:2 CSC Offset Register (RW)
 *
 * Reset value: 0x00800010U
 *
 * LCDIF_CSC_ register provides overall control over color space conversion from
 * RGB to 4:2:2 YCbCr. The equations for the conversion are given by: Y = C0*R +
 * C1*G + C2*B + Y_offset Cb= C3*R + C4*G + C5*B + CbCr_offset Cr= C6*R + C7*G +
 * C8*B + CbCr_offset This register carries programming information about RGB to
 * YCbCr 4:2:2 CSC.
 */
typedef union _hw_lcdif_csc_offset
{
    uint32_t U;
    struct _hw_lcdif_csc_offset_bitfields
    {
        uint32_t Y_OFFSET : 9;         /*!< [8:0]  */
        uint32_t RSRVD0 : 7;           /*!< [15:9]  */
        uint32_t CBCR_OFFSET : 9;      /*!< [24:16]  */
        uint32_t RSRVD1 : 7;           /*!< [31:25]  */
    } B;
} hw_lcdif_csc_offset_t;

/*!
 * @name Constants and macros for entire LCDIF_CSC_OFFSET register
 */
/*@{*/
#define HW_LCDIF_CSC_OFFSET_ADDR(x) ((uintptr_t)(x) + 0x160U)

#define HW_LCDIF_CSC_OFFSET(x)   (*(__IO hw_lcdif_csc_offset_t *) HW_LCDIF_CSC_OFFSET_ADDR(x))
#define HW_LCDIF_CSC_OFFSET_RD(x) (HW_LCDIF_CSC_OFFSET(x).U)
#define HW_LCDIF_CSC_OFFSET_WR(x, v) (HW_LCDIF_CSC_OFFSET(x).U = (v))
#define HW_LCDIF_CSC_OFFSET_SET(x, v) (HW_LCDIF_CSC_OFFSET_WR(x, HW_LCDIF_CSC_OFFSET_RD(x) |  (v)))
#define HW_LCDIF_CSC_OFFSET_CLR(x, v) (HW_LCDIF_CSC_OFFSET_WR(x, HW_LCDIF_CSC_OFFSET_RD(x) & ~(v)))
#define HW_LCDIF_CSC_OFFSET_TOG(x, v) (HW_LCDIF_CSC_OFFSET_WR(x, HW_LCDIF_CSC_OFFSET_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CSC_OFFSET bitfields
 */

/*!
 * @name Register LCDIF_CSC_OFFSET, field Y_OFFSET[8:0] (RW)
 *
 * Two's complement offset for the Y component
 */
/*@{*/
#define BP_LCDIF_CSC_OFFSET_Y_OFFSET (0U)  /*!< Bit position for LCDIF_CSC_OFFSET_Y_OFFSET. */
#define BM_LCDIF_CSC_OFFSET_Y_OFFSET (0x000001FFU) /*!< Bit mask for LCDIF_CSC_OFFSET_Y_OFFSET. */
#define BS_LCDIF_CSC_OFFSET_Y_OFFSET (9U)  /*!< Bit field size in bits for LCDIF_CSC_OFFSET_Y_OFFSET. */

/*! @brief Read current value of the LCDIF_CSC_OFFSET_Y_OFFSET field. */
#define BR_LCDIF_CSC_OFFSET_Y_OFFSET(x) (HW_LCDIF_CSC_OFFSET(x).B.Y_OFFSET)

/*! @brief Format value for bitfield LCDIF_CSC_OFFSET_Y_OFFSET. */
#define BF_LCDIF_CSC_OFFSET_Y_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_OFFSET_Y_OFFSET) & BM_LCDIF_CSC_OFFSET_Y_OFFSET)

/*! @brief Set the Y_OFFSET field to a new value. */
#define BW_LCDIF_CSC_OFFSET_Y_OFFSET(x, v) (HW_LCDIF_CSC_OFFSET_WR(x, (HW_LCDIF_CSC_OFFSET_RD(x) & ~BM_LCDIF_CSC_OFFSET_Y_OFFSET) | BF_LCDIF_CSC_OFFSET_Y_OFFSET(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_OFFSET, field RSRVD0[15:9] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_OFFSET_RSRVD0 (9U)    /*!< Bit position for LCDIF_CSC_OFFSET_RSRVD0. */
#define BM_LCDIF_CSC_OFFSET_RSRVD0 (0x0000FE00U) /*!< Bit mask for LCDIF_CSC_OFFSET_RSRVD0. */
#define BS_LCDIF_CSC_OFFSET_RSRVD0 (7U)    /*!< Bit field size in bits for LCDIF_CSC_OFFSET_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_CSC_OFFSET, field CBCR_OFFSET[24:16] (RW)
 *
 * Two's complement offset for the Cb and Cr components
 */
/*@{*/
#define BP_LCDIF_CSC_OFFSET_CBCR_OFFSET (16U) /*!< Bit position for LCDIF_CSC_OFFSET_CBCR_OFFSET. */
#define BM_LCDIF_CSC_OFFSET_CBCR_OFFSET (0x01FF0000U) /*!< Bit mask for LCDIF_CSC_OFFSET_CBCR_OFFSET. */
#define BS_LCDIF_CSC_OFFSET_CBCR_OFFSET (9U) /*!< Bit field size in bits for LCDIF_CSC_OFFSET_CBCR_OFFSET. */

/*! @brief Read current value of the LCDIF_CSC_OFFSET_CBCR_OFFSET field. */
#define BR_LCDIF_CSC_OFFSET_CBCR_OFFSET(x) (HW_LCDIF_CSC_OFFSET(x).B.CBCR_OFFSET)

/*! @brief Format value for bitfield LCDIF_CSC_OFFSET_CBCR_OFFSET. */
#define BF_LCDIF_CSC_OFFSET_CBCR_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_OFFSET_CBCR_OFFSET) & BM_LCDIF_CSC_OFFSET_CBCR_OFFSET)

/*! @brief Set the CBCR_OFFSET field to a new value. */
#define BW_LCDIF_CSC_OFFSET_CBCR_OFFSET(x, v) (HW_LCDIF_CSC_OFFSET_WR(x, (HW_LCDIF_CSC_OFFSET_RD(x) & ~BM_LCDIF_CSC_OFFSET_CBCR_OFFSET) | BF_LCDIF_CSC_OFFSET_CBCR_OFFSET(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_OFFSET, field RSRVD1[31:25] (RU)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_CSC_OFFSET_RSRVD1 (25U)   /*!< Bit position for LCDIF_CSC_OFFSET_RSRVD1. */
#define BM_LCDIF_CSC_OFFSET_RSRVD1 (0xFE000000U) /*!< Bit mask for LCDIF_CSC_OFFSET_RSRVD1. */
#define BS_LCDIF_CSC_OFFSET_RSRVD1 (7U)    /*!< Bit field size in bits for LCDIF_CSC_OFFSET_RSRVD1. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_CSC_LIMIT - RGB to YCbCr 4:2:2 CSC Limit Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CSC_LIMIT - RGB to YCbCr 4:2:2 CSC Limit Register (RW)
 *
 * Reset value: 0x00FF00FFU
 *
 * LCDIF_CSC_CTRL0 register provides overall control over color space conversion
 * from RGB to 4:2:2 YCbCr. The equations for the conversion are given by: Y =
 * C0*R + C1*G + C2*B + Y_offset Cb= C3*R + C4*G + C5*B + CbCr_offset Cr= C6*R +
 * C7*G + C8*B + CbCr_offset This register carries programming information about
 * RGB to YCbCr 4:2:2 CSC. Note that the values in this register are unsigned.
 * EXAMPLE HW_LCDIF_CSC_LIMIT_CBCR_MIN_WR(0x10);//16
 * HW_LCDIF_CSC_LIMIT_CBCR_MAX_WR(0xF0);//240 HW_LCDIF_CSC_LIMIT_Y_MIN_WR(0x10);//16
 * HW_LCDIF_CSC_LIMIT_Y_MAX_WR(0xEB);//235
 */
typedef union _hw_lcdif_csc_limit
{
    uint32_t U;
    struct _hw_lcdif_csc_limit_bitfields
    {
        uint32_t Y_MAX : 8;            /*!< [7:0]  */
        uint32_t Y_MIN : 8;            /*!< [15:8]  */
        uint32_t CBCR_MAX : 8;         /*!< [23:16]  */
        uint32_t CBCR_MIN : 8;         /*!< [31:24]  */
    } B;
} hw_lcdif_csc_limit_t;

/*!
 * @name Constants and macros for entire LCDIF_CSC_LIMIT register
 */
/*@{*/
#define HW_LCDIF_CSC_LIMIT_ADDR(x) ((uintptr_t)(x) + 0x170U)

#define HW_LCDIF_CSC_LIMIT(x)    (*(__IO hw_lcdif_csc_limit_t *) HW_LCDIF_CSC_LIMIT_ADDR(x))
#define HW_LCDIF_CSC_LIMIT_RD(x) (HW_LCDIF_CSC_LIMIT(x).U)
#define HW_LCDIF_CSC_LIMIT_WR(x, v) (HW_LCDIF_CSC_LIMIT(x).U = (v))
#define HW_LCDIF_CSC_LIMIT_SET(x, v) (HW_LCDIF_CSC_LIMIT_WR(x, HW_LCDIF_CSC_LIMIT_RD(x) |  (v)))
#define HW_LCDIF_CSC_LIMIT_CLR(x, v) (HW_LCDIF_CSC_LIMIT_WR(x, HW_LCDIF_CSC_LIMIT_RD(x) & ~(v)))
#define HW_LCDIF_CSC_LIMIT_TOG(x, v) (HW_LCDIF_CSC_LIMIT_WR(x, HW_LCDIF_CSC_LIMIT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CSC_LIMIT bitfields
 */

/*!
 * @name Register LCDIF_CSC_LIMIT, field Y_MAX[7:0] (RW)
 *
 * Upper limit of Y after RGB to 4:2:2 YCbCr conversion
 */
/*@{*/
#define BP_LCDIF_CSC_LIMIT_Y_MAX (0U)      /*!< Bit position for LCDIF_CSC_LIMIT_Y_MAX. */
#define BM_LCDIF_CSC_LIMIT_Y_MAX (0x000000FFU) /*!< Bit mask for LCDIF_CSC_LIMIT_Y_MAX. */
#define BS_LCDIF_CSC_LIMIT_Y_MAX (8U)      /*!< Bit field size in bits for LCDIF_CSC_LIMIT_Y_MAX. */

/*! @brief Read current value of the LCDIF_CSC_LIMIT_Y_MAX field. */
#define BR_LCDIF_CSC_LIMIT_Y_MAX(x) (HW_LCDIF_CSC_LIMIT(x).B.Y_MAX)

/*! @brief Format value for bitfield LCDIF_CSC_LIMIT_Y_MAX. */
#define BF_LCDIF_CSC_LIMIT_Y_MAX(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_LIMIT_Y_MAX) & BM_LCDIF_CSC_LIMIT_Y_MAX)

/*! @brief Set the Y_MAX field to a new value. */
#define BW_LCDIF_CSC_LIMIT_Y_MAX(x, v) (HW_LCDIF_CSC_LIMIT_WR(x, (HW_LCDIF_CSC_LIMIT_RD(x) & ~BM_LCDIF_CSC_LIMIT_Y_MAX) | BF_LCDIF_CSC_LIMIT_Y_MAX(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_LIMIT, field Y_MIN[15:8] (RW)
 *
 * Lower limit of Y after RGB to 4:2:2 YCbCr conversion
 */
/*@{*/
#define BP_LCDIF_CSC_LIMIT_Y_MIN (8U)      /*!< Bit position for LCDIF_CSC_LIMIT_Y_MIN. */
#define BM_LCDIF_CSC_LIMIT_Y_MIN (0x0000FF00U) /*!< Bit mask for LCDIF_CSC_LIMIT_Y_MIN. */
#define BS_LCDIF_CSC_LIMIT_Y_MIN (8U)      /*!< Bit field size in bits for LCDIF_CSC_LIMIT_Y_MIN. */

/*! @brief Read current value of the LCDIF_CSC_LIMIT_Y_MIN field. */
#define BR_LCDIF_CSC_LIMIT_Y_MIN(x) (HW_LCDIF_CSC_LIMIT(x).B.Y_MIN)

/*! @brief Format value for bitfield LCDIF_CSC_LIMIT_Y_MIN. */
#define BF_LCDIF_CSC_LIMIT_Y_MIN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_LIMIT_Y_MIN) & BM_LCDIF_CSC_LIMIT_Y_MIN)

/*! @brief Set the Y_MIN field to a new value. */
#define BW_LCDIF_CSC_LIMIT_Y_MIN(x, v) (HW_LCDIF_CSC_LIMIT_WR(x, (HW_LCDIF_CSC_LIMIT_RD(x) & ~BM_LCDIF_CSC_LIMIT_Y_MIN) | BF_LCDIF_CSC_LIMIT_Y_MIN(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_LIMIT, field CBCR_MAX[23:16] (RW)
 *
 * Upper limit of Cb and Cr after RGB to 4:2:2 YCbCr conversion
 */
/*@{*/
#define BP_LCDIF_CSC_LIMIT_CBCR_MAX (16U)  /*!< Bit position for LCDIF_CSC_LIMIT_CBCR_MAX. */
#define BM_LCDIF_CSC_LIMIT_CBCR_MAX (0x00FF0000U) /*!< Bit mask for LCDIF_CSC_LIMIT_CBCR_MAX. */
#define BS_LCDIF_CSC_LIMIT_CBCR_MAX (8U)   /*!< Bit field size in bits for LCDIF_CSC_LIMIT_CBCR_MAX. */

/*! @brief Read current value of the LCDIF_CSC_LIMIT_CBCR_MAX field. */
#define BR_LCDIF_CSC_LIMIT_CBCR_MAX(x) (HW_LCDIF_CSC_LIMIT(x).B.CBCR_MAX)

/*! @brief Format value for bitfield LCDIF_CSC_LIMIT_CBCR_MAX. */
#define BF_LCDIF_CSC_LIMIT_CBCR_MAX(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_LIMIT_CBCR_MAX) & BM_LCDIF_CSC_LIMIT_CBCR_MAX)

/*! @brief Set the CBCR_MAX field to a new value. */
#define BW_LCDIF_CSC_LIMIT_CBCR_MAX(x, v) (HW_LCDIF_CSC_LIMIT_WR(x, (HW_LCDIF_CSC_LIMIT_RD(x) & ~BM_LCDIF_CSC_LIMIT_CBCR_MAX) | BF_LCDIF_CSC_LIMIT_CBCR_MAX(v)))
/*@}*/

/*!
 * @name Register LCDIF_CSC_LIMIT, field CBCR_MIN[31:24] (RW)
 *
 * Lower limit of Cb and Cr after RGB to 4:2:2 YCbCr conversion
 */
/*@{*/
#define BP_LCDIF_CSC_LIMIT_CBCR_MIN (24U)  /*!< Bit position for LCDIF_CSC_LIMIT_CBCR_MIN. */
#define BM_LCDIF_CSC_LIMIT_CBCR_MIN (0xFF000000U) /*!< Bit mask for LCDIF_CSC_LIMIT_CBCR_MIN. */
#define BS_LCDIF_CSC_LIMIT_CBCR_MIN (8U)   /*!< Bit field size in bits for LCDIF_CSC_LIMIT_CBCR_MIN. */

/*! @brief Read current value of the LCDIF_CSC_LIMIT_CBCR_MIN field. */
#define BR_LCDIF_CSC_LIMIT_CBCR_MIN(x) (HW_LCDIF_CSC_LIMIT(x).B.CBCR_MIN)

/*! @brief Format value for bitfield LCDIF_CSC_LIMIT_CBCR_MIN. */
#define BF_LCDIF_CSC_LIMIT_CBCR_MIN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CSC_LIMIT_CBCR_MIN) & BM_LCDIF_CSC_LIMIT_CBCR_MIN)

/*! @brief Set the CBCR_MIN field to a new value. */
#define BW_LCDIF_CSC_LIMIT_CBCR_MIN(x, v) (HW_LCDIF_CSC_LIMIT_WR(x, (HW_LCDIF_CSC_LIMIT_RD(x) & ~BM_LCDIF_CSC_LIMIT_CBCR_MIN) | BF_LCDIF_CSC_LIMIT_CBCR_MIN(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DATA - LCD Interface Data Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DATA - LCD Interface Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to transfer data using the PIO interface mode of
 * operation. In MPU mode, data written to this register will be transferred out to the
 * display device. When receiving data from the display, data is read from this
 * register using PIO operations. During write operations, data can be written to
 * this register (from the processor's perspective) as bytes, half-words (16
 * bits), or words (32 bits) as desired. This register holds the 32-bit word written
 * by the ARM platform into LCDIF. This data then gets sent out by the block
 * across the interface.
 */
typedef union _hw_lcdif_data
{
    uint32_t U;
    struct _hw_lcdif_data_bitfields
    {
        uint32_t DATA_ZERO : 8;        /*!< [7:0]  */
        uint32_t DATA_ONE : 8;         /*!< [15:8]  */
        uint32_t DATA_TWO : 8;         /*!< [23:16]  */
        uint32_t DATA_THREE : 8;       /*!< [31:24]  */
    } B;
} hw_lcdif_data_t;

/*!
 * @name Constants and macros for entire LCDIF_DATA register
 */
/*@{*/
#define HW_LCDIF_DATA_ADDR(x)    ((uintptr_t)(x) + 0x180U)

#define HW_LCDIF_DATA(x)         (*(__IO hw_lcdif_data_t *) HW_LCDIF_DATA_ADDR(x))
#define HW_LCDIF_DATA_RD(x)      (HW_LCDIF_DATA(x).U)
#define HW_LCDIF_DATA_WR(x, v)   (HW_LCDIF_DATA(x).U = (v))
#define HW_LCDIF_DATA_SET(x, v)  (HW_LCDIF_DATA_WR(x, HW_LCDIF_DATA_RD(x) |  (v)))
#define HW_LCDIF_DATA_CLR(x, v)  (HW_LCDIF_DATA_WR(x, HW_LCDIF_DATA_RD(x) & ~(v)))
#define HW_LCDIF_DATA_TOG(x, v)  (HW_LCDIF_DATA_WR(x, HW_LCDIF_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_DATA bitfields
 */

/*!
 * @name Register LCDIF_DATA, field DATA_ZERO[7:0] (RW)
 *
 * Byte 0 (least significant byte) of data written to eLCDIF.
 */
/*@{*/
#define BP_LCDIF_DATA_DATA_ZERO (0U)       /*!< Bit position for LCDIF_DATA_DATA_ZERO. */
#define BM_LCDIF_DATA_DATA_ZERO (0x000000FFU) /*!< Bit mask for LCDIF_DATA_DATA_ZERO. */
#define BS_LCDIF_DATA_DATA_ZERO (8U)       /*!< Bit field size in bits for LCDIF_DATA_DATA_ZERO. */

/*! @brief Read current value of the LCDIF_DATA_DATA_ZERO field. */
#define BR_LCDIF_DATA_DATA_ZERO(x) (HW_LCDIF_DATA(x).B.DATA_ZERO)

/*! @brief Format value for bitfield LCDIF_DATA_DATA_ZERO. */
#define BF_LCDIF_DATA_DATA_ZERO(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DATA_DATA_ZERO) & BM_LCDIF_DATA_DATA_ZERO)

/*! @brief Set the DATA_ZERO field to a new value. */
#define BW_LCDIF_DATA_DATA_ZERO(x, v) (HW_LCDIF_DATA_WR(x, (HW_LCDIF_DATA_RD(x) & ~BM_LCDIF_DATA_DATA_ZERO) | BF_LCDIF_DATA_DATA_ZERO(v)))
/*@}*/

/*!
 * @name Register LCDIF_DATA, field DATA_ONE[15:8] (RW)
 *
 * Byte 1 of data written to eLCDIF.
 */
/*@{*/
#define BP_LCDIF_DATA_DATA_ONE (8U)        /*!< Bit position for LCDIF_DATA_DATA_ONE. */
#define BM_LCDIF_DATA_DATA_ONE (0x0000FF00U) /*!< Bit mask for LCDIF_DATA_DATA_ONE. */
#define BS_LCDIF_DATA_DATA_ONE (8U)        /*!< Bit field size in bits for LCDIF_DATA_DATA_ONE. */

/*! @brief Read current value of the LCDIF_DATA_DATA_ONE field. */
#define BR_LCDIF_DATA_DATA_ONE(x) (HW_LCDIF_DATA(x).B.DATA_ONE)

/*! @brief Format value for bitfield LCDIF_DATA_DATA_ONE. */
#define BF_LCDIF_DATA_DATA_ONE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DATA_DATA_ONE) & BM_LCDIF_DATA_DATA_ONE)

/*! @brief Set the DATA_ONE field to a new value. */
#define BW_LCDIF_DATA_DATA_ONE(x, v) (HW_LCDIF_DATA_WR(x, (HW_LCDIF_DATA_RD(x) & ~BM_LCDIF_DATA_DATA_ONE) | BF_LCDIF_DATA_DATA_ONE(v)))
/*@}*/

/*!
 * @name Register LCDIF_DATA, field DATA_TWO[23:16] (RW)
 *
 * Byte 2 of data written to eLCDIF.
 */
/*@{*/
#define BP_LCDIF_DATA_DATA_TWO (16U)       /*!< Bit position for LCDIF_DATA_DATA_TWO. */
#define BM_LCDIF_DATA_DATA_TWO (0x00FF0000U) /*!< Bit mask for LCDIF_DATA_DATA_TWO. */
#define BS_LCDIF_DATA_DATA_TWO (8U)        /*!< Bit field size in bits for LCDIF_DATA_DATA_TWO. */

/*! @brief Read current value of the LCDIF_DATA_DATA_TWO field. */
#define BR_LCDIF_DATA_DATA_TWO(x) (HW_LCDIF_DATA(x).B.DATA_TWO)

/*! @brief Format value for bitfield LCDIF_DATA_DATA_TWO. */
#define BF_LCDIF_DATA_DATA_TWO(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DATA_DATA_TWO) & BM_LCDIF_DATA_DATA_TWO)

/*! @brief Set the DATA_TWO field to a new value. */
#define BW_LCDIF_DATA_DATA_TWO(x, v) (HW_LCDIF_DATA_WR(x, (HW_LCDIF_DATA_RD(x) & ~BM_LCDIF_DATA_DATA_TWO) | BF_LCDIF_DATA_DATA_TWO(v)))
/*@}*/

/*!
 * @name Register LCDIF_DATA, field DATA_THREE[31:24] (RW)
 *
 * Byte 3 (most significant byte) of data written to LCDIF.
 */
/*@{*/
#define BP_LCDIF_DATA_DATA_THREE (24U)     /*!< Bit position for LCDIF_DATA_DATA_THREE. */
#define BM_LCDIF_DATA_DATA_THREE (0xFF000000U) /*!< Bit mask for LCDIF_DATA_DATA_THREE. */
#define BS_LCDIF_DATA_DATA_THREE (8U)      /*!< Bit field size in bits for LCDIF_DATA_DATA_THREE. */

/*! @brief Read current value of the LCDIF_DATA_DATA_THREE field. */
#define BR_LCDIF_DATA_DATA_THREE(x) (HW_LCDIF_DATA(x).B.DATA_THREE)

/*! @brief Format value for bitfield LCDIF_DATA_DATA_THREE. */
#define BF_LCDIF_DATA_DATA_THREE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_DATA_DATA_THREE) & BM_LCDIF_DATA_DATA_THREE)

/*! @brief Set the DATA_THREE field to a new value. */
#define BW_LCDIF_DATA_DATA_THREE(x, v) (HW_LCDIF_DATA_WR(x, (HW_LCDIF_DATA_RD(x) & ~BM_LCDIF_DATA_DATA_THREE) | BF_LCDIF_DATA_DATA_THREE(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_BM_ERROR_STAT - Bus Master Error Status Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_BM_ERROR_STAT - Bus Master Error Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register reflects the virtual address at which the AXI master received
 * an error response from the slave. When the BM_ERROR_IRQ is asserted, the
 * address of the bus error is updated in the register.
 */
typedef union _hw_lcdif_bm_error_stat
{
    uint32_t U;
    struct _hw_lcdif_bm_error_stat_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_lcdif_bm_error_stat_t;

/*!
 * @name Constants and macros for entire LCDIF_BM_ERROR_STAT register
 */
/*@{*/
#define HW_LCDIF_BM_ERROR_STAT_ADDR(x) ((uintptr_t)(x) + 0x190U)

#define HW_LCDIF_BM_ERROR_STAT(x) (*(__IO hw_lcdif_bm_error_stat_t *) HW_LCDIF_BM_ERROR_STAT_ADDR(x))
#define HW_LCDIF_BM_ERROR_STAT_RD(x) (HW_LCDIF_BM_ERROR_STAT(x).U)
#define HW_LCDIF_BM_ERROR_STAT_WR(x, v) (HW_LCDIF_BM_ERROR_STAT(x).U = (v))
#define HW_LCDIF_BM_ERROR_STAT_SET(x, v) (HW_LCDIF_BM_ERROR_STAT_WR(x, HW_LCDIF_BM_ERROR_STAT_RD(x) |  (v)))
#define HW_LCDIF_BM_ERROR_STAT_CLR(x, v) (HW_LCDIF_BM_ERROR_STAT_WR(x, HW_LCDIF_BM_ERROR_STAT_RD(x) & ~(v)))
#define HW_LCDIF_BM_ERROR_STAT_TOG(x, v) (HW_LCDIF_BM_ERROR_STAT_WR(x, HW_LCDIF_BM_ERROR_STAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_BM_ERROR_STAT bitfields
 */

/*!
 * @name Register LCDIF_BM_ERROR_STAT, field ADDR[31:0] (RW)
 *
 * Virtual address at which bus master error occurred.
 */
/*@{*/
#define BP_LCDIF_BM_ERROR_STAT_ADDR (0U)   /*!< Bit position for LCDIF_BM_ERROR_STAT_ADDR. */
#define BM_LCDIF_BM_ERROR_STAT_ADDR (0xFFFFFFFFU) /*!< Bit mask for LCDIF_BM_ERROR_STAT_ADDR. */
#define BS_LCDIF_BM_ERROR_STAT_ADDR (32U)  /*!< Bit field size in bits for LCDIF_BM_ERROR_STAT_ADDR. */

/*! @brief Read current value of the LCDIF_BM_ERROR_STAT_ADDR field. */
#define BR_LCDIF_BM_ERROR_STAT_ADDR(x) (HW_LCDIF_BM_ERROR_STAT(x).U)

/*! @brief Format value for bitfield LCDIF_BM_ERROR_STAT_ADDR. */
#define BF_LCDIF_BM_ERROR_STAT_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_BM_ERROR_STAT_ADDR) & BM_LCDIF_BM_ERROR_STAT_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_LCDIF_BM_ERROR_STAT_ADDR(x, v) (HW_LCDIF_BM_ERROR_STAT_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_CRC_STAT - CRC Status Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_CRC_STAT - CRC Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register reflects the CRC value of each frame sent out by eLCDIF. The
 * CRC is done on the final output bus, so the value will be dependent on the
 * LCD_DATABUS_WIDTH bitfield even if the input data is the same. This register will
 * be updated when the CUR_FRAME_DONE_IRQ is asserted. In the case of DVI mode,
 * the CRC is calculated for the entire frame, not separately for each field in the
 * frame.
 */
typedef union _hw_lcdif_crc_stat
{
    uint32_t U;
    struct _hw_lcdif_crc_stat_bitfields
    {
        uint32_t CRC_VALUE : 32;       /*!< [31:0]  */
    } B;
} hw_lcdif_crc_stat_t;

/*!
 * @name Constants and macros for entire LCDIF_CRC_STAT register
 */
/*@{*/
#define HW_LCDIF_CRC_STAT_ADDR(x) ((uintptr_t)(x) + 0x1A0U)

#define HW_LCDIF_CRC_STAT(x)     (*(__IO hw_lcdif_crc_stat_t *) HW_LCDIF_CRC_STAT_ADDR(x))
#define HW_LCDIF_CRC_STAT_RD(x)  (HW_LCDIF_CRC_STAT(x).U)
#define HW_LCDIF_CRC_STAT_WR(x, v) (HW_LCDIF_CRC_STAT(x).U = (v))
#define HW_LCDIF_CRC_STAT_SET(x, v) (HW_LCDIF_CRC_STAT_WR(x, HW_LCDIF_CRC_STAT_RD(x) |  (v)))
#define HW_LCDIF_CRC_STAT_CLR(x, v) (HW_LCDIF_CRC_STAT_WR(x, HW_LCDIF_CRC_STAT_RD(x) & ~(v)))
#define HW_LCDIF_CRC_STAT_TOG(x, v) (HW_LCDIF_CRC_STAT_WR(x, HW_LCDIF_CRC_STAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_CRC_STAT bitfields
 */

/*!
 * @name Register LCDIF_CRC_STAT, field CRC_VALUE[31:0] (RW)
 *
 * Calculated CRC value.
 */
/*@{*/
#define BP_LCDIF_CRC_STAT_CRC_VALUE (0U)   /*!< Bit position for LCDIF_CRC_STAT_CRC_VALUE. */
#define BM_LCDIF_CRC_STAT_CRC_VALUE (0xFFFFFFFFU) /*!< Bit mask for LCDIF_CRC_STAT_CRC_VALUE. */
#define BS_LCDIF_CRC_STAT_CRC_VALUE (32U)  /*!< Bit field size in bits for LCDIF_CRC_STAT_CRC_VALUE. */

/*! @brief Read current value of the LCDIF_CRC_STAT_CRC_VALUE field. */
#define BR_LCDIF_CRC_STAT_CRC_VALUE(x) (HW_LCDIF_CRC_STAT(x).U)

/*! @brief Format value for bitfield LCDIF_CRC_STAT_CRC_VALUE. */
#define BF_LCDIF_CRC_STAT_CRC_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_CRC_STAT_CRC_VALUE) & BM_LCDIF_CRC_STAT_CRC_VALUE)

/*! @brief Set the CRC_VALUE field to a new value. */
#define BW_LCDIF_CRC_STAT_CRC_VALUE(x, v) (HW_LCDIF_CRC_STAT_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_STAT - LCD Interface Status Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_STAT - LCD Interface Status Register (RO)
 *
 * Reset value: 0x95000000U
 *
 * The LCD interface status register can be used to check the current status of
 * the eLCDIF block. The LCD interface status register that contains read only
 * views of some parameters or current state of the block.
 */
typedef union _hw_lcdif_stat
{
    uint32_t U;
    struct _hw_lcdif_stat_bitfields
    {
        uint32_t LFIFO_COUNT : 9;      /*!< [8:0]  */
        uint32_t RSRVD0 : 15;          /*!< [23:9]  */
        uint32_t DVI_CURRENT_FIELD : 1; /*!< [24]  */
        uint32_t BUSY : 1;             /*!< [25]  */
        uint32_t TXFIFO_EMPTY : 1;     /*!< [26]  */
        uint32_t TXFIFO_FULL : 1;      /*!< [27]  */
        uint32_t LFIFO_EMPTY : 1;      /*!< [28]  */
        uint32_t LFIFO_FULL : 1;       /*!< [29]  */
        uint32_t RESERVED0 : 1;        /*!< [30]  */
        uint32_t PRESENT : 1;          /*!< [31]  */
    } B;
} hw_lcdif_stat_t;

/*!
 * @name Constants and macros for entire LCDIF_STAT register
 */
/*@{*/
#define HW_LCDIF_STAT_ADDR(x)    ((uintptr_t)(x) + 0x1B0U)

#define HW_LCDIF_STAT(x)         (*(__I hw_lcdif_stat_t *) HW_LCDIF_STAT_ADDR(x))
#define HW_LCDIF_STAT_RD(x)      (HW_LCDIF_STAT(x).U)
/*@}*/

/*
 * Constants & macros for individual LCDIF_STAT bitfields
 */

/*!
 * @name Register LCDIF_STAT, field LFIFO_COUNT[8:0] (RO)
 *
 * Read only view of the current count in Latency buffer (LFIFO).
 */
/*@{*/
#define BP_LCDIF_STAT_LFIFO_COUNT (0U)     /*!< Bit position for LCDIF_STAT_LFIFO_COUNT. */
#define BM_LCDIF_STAT_LFIFO_COUNT (0x000001FFU) /*!< Bit mask for LCDIF_STAT_LFIFO_COUNT. */
#define BS_LCDIF_STAT_LFIFO_COUNT (9U)     /*!< Bit field size in bits for LCDIF_STAT_LFIFO_COUNT. */

/*! @brief Read current value of the LCDIF_STAT_LFIFO_COUNT field. */
#define BR_LCDIF_STAT_LFIFO_COUNT(x) (HW_LCDIF_STAT(x).B.LFIFO_COUNT)
/*@}*/

/*!
 * @name Register LCDIF_STAT, field RSRVD0[23:9] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_STAT_RSRVD0 (9U)          /*!< Bit position for LCDIF_STAT_RSRVD0. */
#define BM_LCDIF_STAT_RSRVD0 (0x00FFFE00U) /*!< Bit mask for LCDIF_STAT_RSRVD0. */
#define BS_LCDIF_STAT_RSRVD0 (15U)         /*!< Bit field size in bits for LCDIF_STAT_RSRVD0. */
/*@}*/

/*!
 * @name Register LCDIF_STAT, field DVI_CURRENT_FIELD[24] (RO)
 *
 * Read only view of the current field being transmitted. DVI_CURRENT_FIELD = 0
 * means field 1. DVI_CURRENT_FIELD = 1 means field 2.
 */
/*@{*/
#define BP_LCDIF_STAT_DVI_CURRENT_FIELD (24U) /*!< Bit position for LCDIF_STAT_DVI_CURRENT_FIELD. */
#define BM_LCDIF_STAT_DVI_CURRENT_FIELD (0x01000000U) /*!< Bit mask for LCDIF_STAT_DVI_CURRENT_FIELD. */
#define BS_LCDIF_STAT_DVI_CURRENT_FIELD (1U) /*!< Bit field size in bits for LCDIF_STAT_DVI_CURRENT_FIELD. */

/*! @brief Read current value of the LCDIF_STAT_DVI_CURRENT_FIELD field. */
#define BR_LCDIF_STAT_DVI_CURRENT_FIELD(x) (HW_LCDIF_STAT(x).B.DVI_CURRENT_FIELD)
/*@}*/

/*!
 * @name Register LCDIF_STAT, field BUSY[25] (RO)
 *
 * Read only view of the input busy signal from the external LCD controller.
 */
/*@{*/
#define BP_LCDIF_STAT_BUSY   (25U)         /*!< Bit position for LCDIF_STAT_BUSY. */
#define BM_LCDIF_STAT_BUSY   (0x02000000U) /*!< Bit mask for LCDIF_STAT_BUSY. */
#define BS_LCDIF_STAT_BUSY   (1U)          /*!< Bit field size in bits for LCDIF_STAT_BUSY. */

/*! @brief Read current value of the LCDIF_STAT_BUSY field. */
#define BR_LCDIF_STAT_BUSY(x) (HW_LCDIF_STAT(x).B.BUSY)
/*@}*/

/*!
 * @name Register LCDIF_STAT, field TXFIFO_EMPTY[26] (RO)
 *
 * Read only view of the signal that indicates that LCD write dapatath FIFO is
 * empty, will be generally used in the read mode of the LCD interface.
 */
/*@{*/
#define BP_LCDIF_STAT_TXFIFO_EMPTY (26U)   /*!< Bit position for LCDIF_STAT_TXFIFO_EMPTY. */
#define BM_LCDIF_STAT_TXFIFO_EMPTY (0x04000000U) /*!< Bit mask for LCDIF_STAT_TXFIFO_EMPTY. */
#define BS_LCDIF_STAT_TXFIFO_EMPTY (1U)    /*!< Bit field size in bits for LCDIF_STAT_TXFIFO_EMPTY. */

/*! @brief Read current value of the LCDIF_STAT_TXFIFO_EMPTY field. */
#define BR_LCDIF_STAT_TXFIFO_EMPTY(x) (HW_LCDIF_STAT(x).B.TXFIFO_EMPTY)
/*@}*/

/*!
 * @name Register LCDIF_STAT, field TXFIFO_FULL[27] (RO)
 *
 * Read only view of the signal that indicates that LCD write datapath FIFO is
 * full, will be generally used in the write mode of the LCD interface.
 */
/*@{*/
#define BP_LCDIF_STAT_TXFIFO_FULL (27U)    /*!< Bit position for LCDIF_STAT_TXFIFO_FULL. */
#define BM_LCDIF_STAT_TXFIFO_FULL (0x08000000U) /*!< Bit mask for LCDIF_STAT_TXFIFO_FULL. */
#define BS_LCDIF_STAT_TXFIFO_FULL (1U)     /*!< Bit field size in bits for LCDIF_STAT_TXFIFO_FULL. */

/*! @brief Read current value of the LCDIF_STAT_TXFIFO_FULL field. */
#define BR_LCDIF_STAT_TXFIFO_FULL(x) (HW_LCDIF_STAT(x).B.TXFIFO_FULL)
/*@}*/

/*!
 * @name Register LCDIF_STAT, field LFIFO_EMPTY[28] (RO)
 *
 * Read only view of the signal that indicates that LCD read dapatath FIFO is
 * empty, will be generally used in the read mode of the LCD interface.
 */
/*@{*/
#define BP_LCDIF_STAT_LFIFO_EMPTY (28U)    /*!< Bit position for LCDIF_STAT_LFIFO_EMPTY. */
#define BM_LCDIF_STAT_LFIFO_EMPTY (0x10000000U) /*!< Bit mask for LCDIF_STAT_LFIFO_EMPTY. */
#define BS_LCDIF_STAT_LFIFO_EMPTY (1U)     /*!< Bit field size in bits for LCDIF_STAT_LFIFO_EMPTY. */

/*! @brief Read current value of the LCDIF_STAT_LFIFO_EMPTY field. */
#define BR_LCDIF_STAT_LFIFO_EMPTY(x) (HW_LCDIF_STAT(x).B.LFIFO_EMPTY)
/*@}*/

/*!
 * @name Register LCDIF_STAT, field LFIFO_FULL[29] (RO)
 *
 * Read only view of the signal that indicates that LCD read datapath FIFO is
 * full, will be generally used in the write mode of the LCD interface.
 */
/*@{*/
#define BP_LCDIF_STAT_LFIFO_FULL (29U)     /*!< Bit position for LCDIF_STAT_LFIFO_FULL. */
#define BM_LCDIF_STAT_LFIFO_FULL (0x20000000U) /*!< Bit mask for LCDIF_STAT_LFIFO_FULL. */
#define BS_LCDIF_STAT_LFIFO_FULL (1U)      /*!< Bit field size in bits for LCDIF_STAT_LFIFO_FULL. */

/*! @brief Read current value of the LCDIF_STAT_LFIFO_FULL field. */
#define BR_LCDIF_STAT_LFIFO_FULL(x) (HW_LCDIF_STAT(x).B.LFIFO_FULL)
/*@}*/

/*!
 * @name Register LCDIF_STAT, field PRESENT[31] (RO)
 *
 * 0: eLCDIF not present on this product 1: eLCDIF is present.
 */
/*@{*/
#define BP_LCDIF_STAT_PRESENT (31U)        /*!< Bit position for LCDIF_STAT_PRESENT. */
#define BM_LCDIF_STAT_PRESENT (0x80000000U) /*!< Bit mask for LCDIF_STAT_PRESENT. */
#define BS_LCDIF_STAT_PRESENT (1U)         /*!< Bit field size in bits for LCDIF_STAT_PRESENT. */

/*! @brief Read current value of the LCDIF_STAT_PRESENT field. */
#define BR_LCDIF_STAT_PRESENT(x) (HW_LCDIF_STAT(x).B.PRESENT)
/*@}*/

/*******************************************************************************
 * HW_LCDIF_VERSION - LCD Interface Version Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_VERSION - LCD Interface Version Register (RO)
 *
 * Reset value: 0x04000000U
 *
 * The LCD interface version register can be used to read the version of the
 * eLCDIF IP being used in this SoC. The LCD interface debug register is for
 * diagnostic use only.
 */
typedef union _hw_lcdif_version
{
    uint32_t U;
    struct _hw_lcdif_version_bitfields
    {
        uint32_t STEP : 16;            /*!< [15:0]  */
        uint32_t MINOR : 8;            /*!< [23:16]  */
        uint32_t MAJOR : 8;            /*!< [31:24]  */
    } B;
} hw_lcdif_version_t;

/*!
 * @name Constants and macros for entire LCDIF_VERSION register
 */
/*@{*/
#define HW_LCDIF_VERSION_ADDR(x) ((uintptr_t)(x) + 0x1C0U)

#define HW_LCDIF_VERSION(x)      (*(__I hw_lcdif_version_t *) HW_LCDIF_VERSION_ADDR(x))
#define HW_LCDIF_VERSION_RD(x)   (HW_LCDIF_VERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual LCDIF_VERSION bitfields
 */

/*!
 * @name Register LCDIF_VERSION, field STEP[15:0] (RO)
 *
 * Fixed read-only value reflecting the stepping of RTL version.
 */
/*@{*/
#define BP_LCDIF_VERSION_STEP (0U)         /*!< Bit position for LCDIF_VERSION_STEP. */
#define BM_LCDIF_VERSION_STEP (0x0000FFFFU) /*!< Bit mask for LCDIF_VERSION_STEP. */
#define BS_LCDIF_VERSION_STEP (16U)        /*!< Bit field size in bits for LCDIF_VERSION_STEP. */

/*! @brief Read current value of the LCDIF_VERSION_STEP field. */
#define BR_LCDIF_VERSION_STEP(x) (HW_LCDIF_VERSION(x).B.STEP)
/*@}*/

/*!
 * @name Register LCDIF_VERSION, field MINOR[23:16] (RO)
 *
 * Fixed read-only value reflecting the MINOR field of RTL version.
 */
/*@{*/
#define BP_LCDIF_VERSION_MINOR (16U)       /*!< Bit position for LCDIF_VERSION_MINOR. */
#define BM_LCDIF_VERSION_MINOR (0x00FF0000U) /*!< Bit mask for LCDIF_VERSION_MINOR. */
#define BS_LCDIF_VERSION_MINOR (8U)        /*!< Bit field size in bits for LCDIF_VERSION_MINOR. */

/*! @brief Read current value of the LCDIF_VERSION_MINOR field. */
#define BR_LCDIF_VERSION_MINOR(x) (HW_LCDIF_VERSION(x).B.MINOR)
/*@}*/

/*!
 * @name Register LCDIF_VERSION, field MAJOR[31:24] (RO)
 *
 * Fixed read-only value reflecting the MAJOR field of RTL version.
 */
/*@{*/
#define BP_LCDIF_VERSION_MAJOR (24U)       /*!< Bit position for LCDIF_VERSION_MAJOR. */
#define BM_LCDIF_VERSION_MAJOR (0xFF000000U) /*!< Bit mask for LCDIF_VERSION_MAJOR. */
#define BS_LCDIF_VERSION_MAJOR (8U)        /*!< Bit field size in bits for LCDIF_VERSION_MAJOR. */

/*! @brief Read current value of the LCDIF_VERSION_MAJOR field. */
#define BR_LCDIF_VERSION_MAJOR(x) (HW_LCDIF_VERSION(x).B.MAJOR)
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DEBUG0 - LCD Interface Debug0 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DEBUG0 - LCD Interface Debug0 Register (RO)
 *
 * Reset value: 0x0E810000U
 *
 * The LCD interface debug0 register provides a diagnostic view of the state
 * machine and other useful internal signals. The LCD interface debug register is
 * for diagnostic use only.
 */
typedef union _hw_lcdif_debug0
{
    uint32_t U;
    struct _hw_lcdif_debug0_bitfields
    {
        uint32_t MST_WORDS : 4;        /*!< [3:0]  */
        uint32_t MST_OUTSTANDING_REQS : 5; /*!< [8:4]  */
        uint32_t MST_AVALID : 1;       /*!< [9]  */
        uint32_t CUR_REQ_STATE : 2;    /*!< [11:10]  */
        uint32_t PXP_B1_DONE : 1;      /*!< [12]  */
        uint32_t PXP_LCDIF_B1_READY : 1; /*!< [13]  */
        uint32_t PXP_B0_DONE : 1;      /*!< [14]  */
        uint32_t PXP_LCDIF_B0_READY : 1; /*!< [15]  */
        uint32_t CUR_STATE : 7;        /*!< [22:16]  */
        uint32_t EMPTY_WORD : 1;       /*!< [23]  */
        uint32_t CUR_FRAME_TX : 1;     /*!< [24]  */
        uint32_t VSYNC : 1;            /*!< [25]  */
        uint32_t HSYNC : 1;            /*!< [26]  */
        uint32_t ENABLE : 1;           /*!< [27]  */
        uint32_t RESERVED0 : 1;        /*!< [28]  */
        uint32_t SYNC_SIGNALS_ON_REG : 1; /*!< [29]  */
        uint32_t WAIT_FOR_VSYNC_EDGE_OUT : 1; /*!< [30]  */
        uint32_t STREAMING_END_DETECTED : 1; /*!< [31]  */
    } B;
} hw_lcdif_debug0_t;

/*!
 * @name Constants and macros for entire LCDIF_DEBUG0 register
 */
/*@{*/
#define HW_LCDIF_DEBUG0_ADDR(x)  ((uintptr_t)(x) + 0x1D0U)

#define HW_LCDIF_DEBUG0(x)       (*(__I hw_lcdif_debug0_t *) HW_LCDIF_DEBUG0_ADDR(x))
#define HW_LCDIF_DEBUG0_RD(x)    (HW_LCDIF_DEBUG0(x).U)
/*@}*/

/*
 * Constants & macros for individual LCDIF_DEBUG0 bitfields
 */

/*!
 * @name Register LCDIF_DEBUG0, field MST_WORDS[3:0] (RO)
 *
 * Read only view of the current bursts issued by the AXI bus master.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_MST_WORDS (0U)     /*!< Bit position for LCDIF_DEBUG0_MST_WORDS. */
#define BM_LCDIF_DEBUG0_MST_WORDS (0x0000000FU) /*!< Bit mask for LCDIF_DEBUG0_MST_WORDS. */
#define BS_LCDIF_DEBUG0_MST_WORDS (4U)     /*!< Bit field size in bits for LCDIF_DEBUG0_MST_WORDS. */

/*! @brief Read current value of the LCDIF_DEBUG0_MST_WORDS field. */
#define BR_LCDIF_DEBUG0_MST_WORDS(x) (HW_LCDIF_DEBUG0(x).B.MST_WORDS)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field MST_OUTSTANDING_REQS[8:4] (RO)
 *
 * Read only view of the current outstanding requests issued by the AXI bus
 * master.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_MST_OUTSTANDING_REQS (4U) /*!< Bit position for LCDIF_DEBUG0_MST_OUTSTANDING_REQS. */
#define BM_LCDIF_DEBUG0_MST_OUTSTANDING_REQS (0x000001F0U) /*!< Bit mask for LCDIF_DEBUG0_MST_OUTSTANDING_REQS. */
#define BS_LCDIF_DEBUG0_MST_OUTSTANDING_REQS (5U) /*!< Bit field size in bits for LCDIF_DEBUG0_MST_OUTSTANDING_REQS. */

/*! @brief Read current value of the LCDIF_DEBUG0_MST_OUTSTANDING_REQS field. */
#define BR_LCDIF_DEBUG0_MST_OUTSTANDING_REQS(x) (HW_LCDIF_DEBUG0(x).B.MST_OUTSTANDING_REQS)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field MST_AVALID[9] (RO)
 *
 * Read only view of the mst_avalid signal issued by the AXI bus master.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_MST_AVALID (9U)    /*!< Bit position for LCDIF_DEBUG0_MST_AVALID. */
#define BM_LCDIF_DEBUG0_MST_AVALID (0x00000200U) /*!< Bit mask for LCDIF_DEBUG0_MST_AVALID. */
#define BS_LCDIF_DEBUG0_MST_AVALID (1U)    /*!< Bit field size in bits for LCDIF_DEBUG0_MST_AVALID. */

/*! @brief Read current value of the LCDIF_DEBUG0_MST_AVALID field. */
#define BR_LCDIF_DEBUG0_MST_AVALID(x) (HW_LCDIF_DEBUG0(x).B.MST_AVALID)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field CUR_REQ_STATE[11:10] (RO)
 *
 * Read only view of the request state machine.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_CUR_REQ_STATE (10U) /*!< Bit position for LCDIF_DEBUG0_CUR_REQ_STATE. */
#define BM_LCDIF_DEBUG0_CUR_REQ_STATE (0x00000C00U) /*!< Bit mask for LCDIF_DEBUG0_CUR_REQ_STATE. */
#define BS_LCDIF_DEBUG0_CUR_REQ_STATE (2U) /*!< Bit field size in bits for LCDIF_DEBUG0_CUR_REQ_STATE. */

/*! @brief Read current value of the LCDIF_DEBUG0_CUR_REQ_STATE field. */
#define BR_LCDIF_DEBUG0_CUR_REQ_STATE(x) (HW_LCDIF_DEBUG0(x).B.CUR_REQ_STATE)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field PXP_B1_DONE[12] (RO)
 *
 * Buffer1 done signal issued by eLCDIF.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_PXP_B1_DONE (12U)  /*!< Bit position for LCDIF_DEBUG0_PXP_B1_DONE. */
#define BM_LCDIF_DEBUG0_PXP_B1_DONE (0x00001000U) /*!< Bit mask for LCDIF_DEBUG0_PXP_B1_DONE. */
#define BS_LCDIF_DEBUG0_PXP_B1_DONE (1U)   /*!< Bit field size in bits for LCDIF_DEBUG0_PXP_B1_DONE. */

/*! @brief Read current value of the LCDIF_DEBUG0_PXP_B1_DONE field. */
#define BR_LCDIF_DEBUG0_PXP_B1_DONE(x) (HW_LCDIF_DEBUG0(x).B.PXP_B1_DONE)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field PXP_LCDIF_B1_READY[13] (RO)
 *
 * Buffer1 ready signal issued by PXP.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_PXP_LCDIF_B1_READY (13U) /*!< Bit position for LCDIF_DEBUG0_PXP_LCDIF_B1_READY. */
#define BM_LCDIF_DEBUG0_PXP_LCDIF_B1_READY (0x00002000U) /*!< Bit mask for LCDIF_DEBUG0_PXP_LCDIF_B1_READY. */
#define BS_LCDIF_DEBUG0_PXP_LCDIF_B1_READY (1U) /*!< Bit field size in bits for LCDIF_DEBUG0_PXP_LCDIF_B1_READY. */

/*! @brief Read current value of the LCDIF_DEBUG0_PXP_LCDIF_B1_READY field. */
#define BR_LCDIF_DEBUG0_PXP_LCDIF_B1_READY(x) (HW_LCDIF_DEBUG0(x).B.PXP_LCDIF_B1_READY)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field PXP_B0_DONE[14] (RO)
 *
 * Buffer0 done signal issued by eLCDIF.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_PXP_B0_DONE (14U)  /*!< Bit position for LCDIF_DEBUG0_PXP_B0_DONE. */
#define BM_LCDIF_DEBUG0_PXP_B0_DONE (0x00004000U) /*!< Bit mask for LCDIF_DEBUG0_PXP_B0_DONE. */
#define BS_LCDIF_DEBUG0_PXP_B0_DONE (1U)   /*!< Bit field size in bits for LCDIF_DEBUG0_PXP_B0_DONE. */

/*! @brief Read current value of the LCDIF_DEBUG0_PXP_B0_DONE field. */
#define BR_LCDIF_DEBUG0_PXP_B0_DONE(x) (HW_LCDIF_DEBUG0(x).B.PXP_B0_DONE)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field PXP_LCDIF_B0_READY[15] (RO)
 *
 * Buffer0 ready signal issued by PXP.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_PXP_LCDIF_B0_READY (15U) /*!< Bit position for LCDIF_DEBUG0_PXP_LCDIF_B0_READY. */
#define BM_LCDIF_DEBUG0_PXP_LCDIF_B0_READY (0x00008000U) /*!< Bit mask for LCDIF_DEBUG0_PXP_LCDIF_B0_READY. */
#define BS_LCDIF_DEBUG0_PXP_LCDIF_B0_READY (1U) /*!< Bit field size in bits for LCDIF_DEBUG0_PXP_LCDIF_B0_READY. */

/*! @brief Read current value of the LCDIF_DEBUG0_PXP_LCDIF_B0_READY field. */
#define BR_LCDIF_DEBUG0_PXP_LCDIF_B0_READY(x) (HW_LCDIF_DEBUG0(x).B.PXP_LCDIF_B0_READY)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field CUR_STATE[22:16] (RO)
 *
 * Read only view of the current state machine state in the current mode of
 * operation.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_CUR_STATE (16U)    /*!< Bit position for LCDIF_DEBUG0_CUR_STATE. */
#define BM_LCDIF_DEBUG0_CUR_STATE (0x007F0000U) /*!< Bit mask for LCDIF_DEBUG0_CUR_STATE. */
#define BS_LCDIF_DEBUG0_CUR_STATE (7U)     /*!< Bit field size in bits for LCDIF_DEBUG0_CUR_STATE. */

/*! @brief Read current value of the LCDIF_DEBUG0_CUR_STATE field. */
#define BR_LCDIF_DEBUG0_CUR_STATE(x) (HW_LCDIF_DEBUG0(x).B.CUR_STATE)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field EMPTY_WORD[23] (RO)
 *
 * Indicates that the current word is empty.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_EMPTY_WORD (23U)   /*!< Bit position for LCDIF_DEBUG0_EMPTY_WORD. */
#define BM_LCDIF_DEBUG0_EMPTY_WORD (0x00800000U) /*!< Bit mask for LCDIF_DEBUG0_EMPTY_WORD. */
#define BS_LCDIF_DEBUG0_EMPTY_WORD (1U)    /*!< Bit field size in bits for LCDIF_DEBUG0_EMPTY_WORD. */

/*! @brief Read current value of the LCDIF_DEBUG0_EMPTY_WORD field. */
#define BR_LCDIF_DEBUG0_EMPTY_WORD(x) (HW_LCDIF_DEBUG0(x).B.EMPTY_WORD)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field CUR_FRAME_TX[24] (RO)
 *
 * This bit is 1 for the time the current frame is being transmitted in the
 * VSYNC mode. Useful for VSYNC mode debug.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_CUR_FRAME_TX (24U) /*!< Bit position for LCDIF_DEBUG0_CUR_FRAME_TX. */
#define BM_LCDIF_DEBUG0_CUR_FRAME_TX (0x01000000U) /*!< Bit mask for LCDIF_DEBUG0_CUR_FRAME_TX. */
#define BS_LCDIF_DEBUG0_CUR_FRAME_TX (1U)  /*!< Bit field size in bits for LCDIF_DEBUG0_CUR_FRAME_TX. */

/*! @brief Read current value of the LCDIF_DEBUG0_CUR_FRAME_TX field. */
#define BR_LCDIF_DEBUG0_CUR_FRAME_TX(x) (HW_LCDIF_DEBUG0(x).B.CUR_FRAME_TX)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field VSYNC[25] (RO)
 *
 * Read only view of VSYNC signal.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_VSYNC (25U)        /*!< Bit position for LCDIF_DEBUG0_VSYNC. */
#define BM_LCDIF_DEBUG0_VSYNC (0x02000000U) /*!< Bit mask for LCDIF_DEBUG0_VSYNC. */
#define BS_LCDIF_DEBUG0_VSYNC (1U)         /*!< Bit field size in bits for LCDIF_DEBUG0_VSYNC. */

/*! @brief Read current value of the LCDIF_DEBUG0_VSYNC field. */
#define BR_LCDIF_DEBUG0_VSYNC(x) (HW_LCDIF_DEBUG0(x).B.VSYNC)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field HSYNC[26] (RO)
 *
 * Read only view of HSYNC signal.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_HSYNC (26U)        /*!< Bit position for LCDIF_DEBUG0_HSYNC. */
#define BM_LCDIF_DEBUG0_HSYNC (0x04000000U) /*!< Bit mask for LCDIF_DEBUG0_HSYNC. */
#define BS_LCDIF_DEBUG0_HSYNC (1U)         /*!< Bit field size in bits for LCDIF_DEBUG0_HSYNC. */

/*! @brief Read current value of the LCDIF_DEBUG0_HSYNC field. */
#define BR_LCDIF_DEBUG0_HSYNC(x) (HW_LCDIF_DEBUG0(x).B.HSYNC)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field ENABLE[27] (RO)
 *
 * Read only view of ENABLE signal.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_ENABLE (27U)       /*!< Bit position for LCDIF_DEBUG0_ENABLE. */
#define BM_LCDIF_DEBUG0_ENABLE (0x08000000U) /*!< Bit mask for LCDIF_DEBUG0_ENABLE. */
#define BS_LCDIF_DEBUG0_ENABLE (1U)        /*!< Bit field size in bits for LCDIF_DEBUG0_ENABLE. */

/*! @brief Read current value of the LCDIF_DEBUG0_ENABLE field. */
#define BR_LCDIF_DEBUG0_ENABLE(x) (HW_LCDIF_DEBUG0(x).B.ENABLE)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field SYNC_SIGNALS_ON_REG[29] (RO)
 *
 * Read only view of internal sync_signals_on_reg signal.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_SYNC_SIGNALS_ON_REG (29U) /*!< Bit position for LCDIF_DEBUG0_SYNC_SIGNALS_ON_REG. */
#define BM_LCDIF_DEBUG0_SYNC_SIGNALS_ON_REG (0x20000000U) /*!< Bit mask for LCDIF_DEBUG0_SYNC_SIGNALS_ON_REG. */
#define BS_LCDIF_DEBUG0_SYNC_SIGNALS_ON_REG (1U) /*!< Bit field size in bits for LCDIF_DEBUG0_SYNC_SIGNALS_ON_REG. */

/*! @brief Read current value of the LCDIF_DEBUG0_SYNC_SIGNALS_ON_REG field. */
#define BR_LCDIF_DEBUG0_SYNC_SIGNALS_ON_REG(x) (HW_LCDIF_DEBUG0(x).B.SYNC_SIGNALS_ON_REG)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field WAIT_FOR_VSYNC_EDGE_OUT[30] (RO)
 *
 * Read only view of WAIT_FOR_VSYNC_EDGE bit in the VSYNC mode after it comes
 * out of the TXFIFO.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_WAIT_FOR_VSYNC_EDGE_OUT (30U) /*!< Bit position for LCDIF_DEBUG0_WAIT_FOR_VSYNC_EDGE_OUT. */
#define BM_LCDIF_DEBUG0_WAIT_FOR_VSYNC_EDGE_OUT (0x40000000U) /*!< Bit mask for LCDIF_DEBUG0_WAIT_FOR_VSYNC_EDGE_OUT. */
#define BS_LCDIF_DEBUG0_WAIT_FOR_VSYNC_EDGE_OUT (1U) /*!< Bit field size in bits for LCDIF_DEBUG0_WAIT_FOR_VSYNC_EDGE_OUT. */

/*! @brief Read current value of the LCDIF_DEBUG0_WAIT_FOR_VSYNC_EDGE_OUT field. */
#define BR_LCDIF_DEBUG0_WAIT_FOR_VSYNC_EDGE_OUT(x) (HW_LCDIF_DEBUG0(x).B.WAIT_FOR_VSYNC_EDGE_OUT)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG0, field STREAMING_END_DETECTED[31] (RO)
 *
 * Read only view of the DOTCLK_MODE or DVI_MODE bit going from 1 to 0.
 */
/*@{*/
#define BP_LCDIF_DEBUG0_STREAMING_END_DETECTED (31U) /*!< Bit position for LCDIF_DEBUG0_STREAMING_END_DETECTED. */
#define BM_LCDIF_DEBUG0_STREAMING_END_DETECTED (0x80000000U) /*!< Bit mask for LCDIF_DEBUG0_STREAMING_END_DETECTED. */
#define BS_LCDIF_DEBUG0_STREAMING_END_DETECTED (1U) /*!< Bit field size in bits for LCDIF_DEBUG0_STREAMING_END_DETECTED. */

/*! @brief Read current value of the LCDIF_DEBUG0_STREAMING_END_DETECTED field. */
#define BR_LCDIF_DEBUG0_STREAMING_END_DETECTED(x) (HW_LCDIF_DEBUG0(x).B.STREAMING_END_DETECTED)
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DEBUG1 - LCD Interface Debug1 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DEBUG1 - LCD Interface Debug1 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The LCD interface debug1 register provides a diagnostic view of the state
 * machine and other useful internal signals. The LCD interface debug register is
 * for diagnostic use only.
 */
typedef union _hw_lcdif_debug1
{
    uint32_t U;
    struct _hw_lcdif_debug1_bitfields
    {
        uint32_t V_DATA_COUNT : 16;    /*!< [15:0]  */
        uint32_t H_DATA_COUNT : 16;    /*!< [31:16]  */
    } B;
} hw_lcdif_debug1_t;

/*!
 * @name Constants and macros for entire LCDIF_DEBUG1 register
 */
/*@{*/
#define HW_LCDIF_DEBUG1_ADDR(x)  ((uintptr_t)(x) + 0x1E0U)

#define HW_LCDIF_DEBUG1(x)       (*(__I hw_lcdif_debug1_t *) HW_LCDIF_DEBUG1_ADDR(x))
#define HW_LCDIF_DEBUG1_RD(x)    (HW_LCDIF_DEBUG1(x).U)
/*@}*/

/*
 * Constants & macros for individual LCDIF_DEBUG1 bitfields
 */

/*!
 * @name Register LCDIF_DEBUG1, field V_DATA_COUNT[15:0] (RO)
 *
 * Read only view of the current state of the vertical data counter.
 */
/*@{*/
#define BP_LCDIF_DEBUG1_V_DATA_COUNT (0U)  /*!< Bit position for LCDIF_DEBUG1_V_DATA_COUNT. */
#define BM_LCDIF_DEBUG1_V_DATA_COUNT (0x0000FFFFU) /*!< Bit mask for LCDIF_DEBUG1_V_DATA_COUNT. */
#define BS_LCDIF_DEBUG1_V_DATA_COUNT (16U) /*!< Bit field size in bits for LCDIF_DEBUG1_V_DATA_COUNT. */

/*! @brief Read current value of the LCDIF_DEBUG1_V_DATA_COUNT field. */
#define BR_LCDIF_DEBUG1_V_DATA_COUNT(x) (HW_LCDIF_DEBUG1(x).B.V_DATA_COUNT)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG1, field H_DATA_COUNT[31:16] (RO)
 *
 * Read only view of the current state of the horizontal data counter.
 */
/*@{*/
#define BP_LCDIF_DEBUG1_H_DATA_COUNT (16U) /*!< Bit position for LCDIF_DEBUG1_H_DATA_COUNT. */
#define BM_LCDIF_DEBUG1_H_DATA_COUNT (0xFFFF0000U) /*!< Bit mask for LCDIF_DEBUG1_H_DATA_COUNT. */
#define BS_LCDIF_DEBUG1_H_DATA_COUNT (16U) /*!< Bit field size in bits for LCDIF_DEBUG1_H_DATA_COUNT. */

/*! @brief Read current value of the LCDIF_DEBUG1_H_DATA_COUNT field. */
#define BR_LCDIF_DEBUG1_H_DATA_COUNT(x) (HW_LCDIF_DEBUG1(x).B.H_DATA_COUNT)
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DEBUG2 - LCD Interface Debug2 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DEBUG2 - LCD Interface Debug2 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The LCD interface debug2 register provides a diagnostic view of the state
 * machine and other useful internal signals. The LCD interface debug register is
 * for diagnostic use only.
 */
typedef union _hw_lcdif_debug2
{
    uint32_t U;
    struct _hw_lcdif_debug2_bitfields
    {
        uint32_t MST_ADDRESS : 32;     /*!< [31:0]  */
    } B;
} hw_lcdif_debug2_t;

/*!
 * @name Constants and macros for entire LCDIF_DEBUG2 register
 */
/*@{*/
#define HW_LCDIF_DEBUG2_ADDR(x)  ((uintptr_t)(x) + 0x1F0U)

#define HW_LCDIF_DEBUG2(x)       (*(__I hw_lcdif_debug2_t *) HW_LCDIF_DEBUG2_ADDR(x))
#define HW_LCDIF_DEBUG2_RD(x)    (HW_LCDIF_DEBUG2(x).U)
/*@}*/

/*
 * Constants & macros for individual LCDIF_DEBUG2 bitfields
 */

/*!
 * @name Register LCDIF_DEBUG2, field MST_ADDRESS[31:0] (RO)
 *
 * Read only view of the current address issued by the AXI bus master.
 */
/*@{*/
#define BP_LCDIF_DEBUG2_MST_ADDRESS (0U)   /*!< Bit position for LCDIF_DEBUG2_MST_ADDRESS. */
#define BM_LCDIF_DEBUG2_MST_ADDRESS (0xFFFFFFFFU) /*!< Bit mask for LCDIF_DEBUG2_MST_ADDRESS. */
#define BS_LCDIF_DEBUG2_MST_ADDRESS (32U)  /*!< Bit field size in bits for LCDIF_DEBUG2_MST_ADDRESS. */

/*! @brief Read current value of the LCDIF_DEBUG2_MST_ADDRESS field. */
#define BR_LCDIF_DEBUG2_MST_ADDRESS(x) (HW_LCDIF_DEBUG2(x).U)
/*@}*/

/*******************************************************************************
 * HW_LCDIF_THRES - eLCDIF Threshold Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_THRES - eLCDIF Threshold Register (RW)
 *
 * Reset value: 0x0100000FU
 *
 * This register is used to activate control signals when the number of pixels
 * reaches the programmed threshold. These control signals, in turn, can be used
 * to manipulate access priority or dynamically change the input clock frequency
 * to meet the required pixel throughput. Memory request priority threshold
 * register.
 */
typedef union _hw_lcdif_thres
{
    uint32_t U;
    struct _hw_lcdif_thres_bitfields
    {
        uint32_t PANIC : 9;            /*!< [8:0]  */
        uint32_t RSRVD1 : 7;           /*!< [15:9]  */
        uint32_t FASTCLOCK : 9;        /*!< [24:16]  */
        uint32_t RSRVD2 : 7;           /*!< [31:25]  */
    } B;
} hw_lcdif_thres_t;

/*!
 * @name Constants and macros for entire LCDIF_THRES register
 */
/*@{*/
#define HW_LCDIF_THRES_ADDR(x)   ((uintptr_t)(x) + 0x200U)

#define HW_LCDIF_THRES(x)        (*(__IO hw_lcdif_thres_t *) HW_LCDIF_THRES_ADDR(x))
#define HW_LCDIF_THRES_RD(x)     (HW_LCDIF_THRES(x).U)
#define HW_LCDIF_THRES_WR(x, v)  (HW_LCDIF_THRES(x).U = (v))
#define HW_LCDIF_THRES_SET(x, v) (HW_LCDIF_THRES_WR(x, HW_LCDIF_THRES_RD(x) |  (v)))
#define HW_LCDIF_THRES_CLR(x, v) (HW_LCDIF_THRES_WR(x, HW_LCDIF_THRES_RD(x) & ~(v)))
#define HW_LCDIF_THRES_TOG(x, v) (HW_LCDIF_THRES_WR(x, HW_LCDIF_THRES_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_THRES bitfields
 */

/*!
 * @name Register LCDIF_THRES, field PANIC[8:0] (RW)
 *
 * This value should be set to a value of pixels from 0 to 511. When the number
 * of pixels in the input pixel FIFO is less than this value, the internal panic
 * control output will be raised. This signal can be used to raise the access
 * eLCDIF's access priority.
 */
/*@{*/
#define BP_LCDIF_THRES_PANIC (0U)          /*!< Bit position for LCDIF_THRES_PANIC. */
#define BM_LCDIF_THRES_PANIC (0x000001FFU) /*!< Bit mask for LCDIF_THRES_PANIC. */
#define BS_LCDIF_THRES_PANIC (9U)          /*!< Bit field size in bits for LCDIF_THRES_PANIC. */

/*! @brief Read current value of the LCDIF_THRES_PANIC field. */
#define BR_LCDIF_THRES_PANIC(x) (HW_LCDIF_THRES(x).B.PANIC)

/*! @brief Format value for bitfield LCDIF_THRES_PANIC. */
#define BF_LCDIF_THRES_PANIC(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_THRES_PANIC) & BM_LCDIF_THRES_PANIC)

/*! @brief Set the PANIC field to a new value. */
#define BW_LCDIF_THRES_PANIC(x, v) (HW_LCDIF_THRES_WR(x, (HW_LCDIF_THRES_RD(x) & ~BM_LCDIF_THRES_PANIC) | BF_LCDIF_THRES_PANIC(v)))
/*@}*/

/*!
 * @name Register LCDIF_THRES, field RSRVD1[15:9] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_THRES_RSRVD1 (9U)         /*!< Bit position for LCDIF_THRES_RSRVD1. */
#define BM_LCDIF_THRES_RSRVD1 (0x0000FE00U) /*!< Bit mask for LCDIF_THRES_RSRVD1. */
#define BS_LCDIF_THRES_RSRVD1 (7U)         /*!< Bit field size in bits for LCDIF_THRES_RSRVD1. */
/*@}*/

/*!
 * @name Register LCDIF_THRES, field FASTCLOCK[24:16] (RW)
 *
 * This value should be set to a value of pixels, from 0 to 511. When the number
 * of pixels in the input pixel FIFO is LESS than this value, the fast clock
 * control output will be raised. This signal can be used to reduce the system bus
 * clock frequency to save power during horizontal or vertical blanking intervals.
 * This value should also be programmed to a value that is greater than the
 * "PANIC" threshold value. This will allow a faster clock to recover the number of
 * pixels in the FIFO before a "panic" level is encountered.
 */
/*@{*/
#define BP_LCDIF_THRES_FASTCLOCK (16U)     /*!< Bit position for LCDIF_THRES_FASTCLOCK. */
#define BM_LCDIF_THRES_FASTCLOCK (0x01FF0000U) /*!< Bit mask for LCDIF_THRES_FASTCLOCK. */
#define BS_LCDIF_THRES_FASTCLOCK (9U)      /*!< Bit field size in bits for LCDIF_THRES_FASTCLOCK. */

/*! @brief Read current value of the LCDIF_THRES_FASTCLOCK field. */
#define BR_LCDIF_THRES_FASTCLOCK(x) (HW_LCDIF_THRES(x).B.FASTCLOCK)

/*! @brief Format value for bitfield LCDIF_THRES_FASTCLOCK. */
#define BF_LCDIF_THRES_FASTCLOCK(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_THRES_FASTCLOCK) & BM_LCDIF_THRES_FASTCLOCK)

/*! @brief Set the FASTCLOCK field to a new value. */
#define BW_LCDIF_THRES_FASTCLOCK(x, v) (HW_LCDIF_THRES_WR(x, (HW_LCDIF_THRES_RD(x) & ~BM_LCDIF_THRES_FASTCLOCK) | BF_LCDIF_THRES_FASTCLOCK(v)))
/*@}*/

/*!
 * @name Register LCDIF_THRES, field RSRVD2[31:25] (RU)
 *
 * Reserved bits. Write as 0.
 */
/*@{*/
#define BP_LCDIF_THRES_RSRVD2 (25U)        /*!< Bit position for LCDIF_THRES_RSRVD2. */
#define BM_LCDIF_THRES_RSRVD2 (0xFE000000U) /*!< Bit mask for LCDIF_THRES_RSRVD2. */
#define BS_LCDIF_THRES_RSRVD2 (7U)         /*!< Bit field size in bits for LCDIF_THRES_RSRVD2. */
/*@}*/

/*******************************************************************************
 * HW_LCDIF_AS_CTRL - eLCDIF AS Buffer Control Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_AS_CTRL - eLCDIF AS Buffer Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Alpha Surface Parameter register provides additional controls for AS.
 */
typedef union _hw_lcdif_as_ctrl
{
    uint32_t U;
    struct _hw_lcdif_as_ctrl_bitfields
    {
        uint32_t AS_ENABLE : 1;        /*!< [0]  */
        uint32_t ALPHA_CTRL : 2;       /*!< [2:1]  */
        uint32_t ENABLE_COLORKEY : 1;  /*!< [3]  */
        uint32_t FORMAT : 4;           /*!< [7:4]  */
        uint32_t ALPHA : 8;            /*!< [15:8]  */
        uint32_t ROP : 4;              /*!< [19:16]  */
        uint32_t ALPHA_INVERT : 1;     /*!< [20]  */
        uint32_t INPUT_DATA_SWIZZLE : 2; /*!< [22:21]  */
        uint32_t PS_DISABLE : 1;       /*!< [23]  */
        uint32_t RVDS1 : 3;            /*!< [26:24]  */
        uint32_t CSI_SYNC_ON_IRQ : 1;  /*!< [27]  */
        uint32_t CSI_SYNC_ON_IRQ_EN : 1; /*!< [28]  */
        uint32_t CSI_VSYNC_MODE : 1;   /*!< [29]  */
        uint32_t CSI_VSYNC_POL : 1;    /*!< [30]  */
        uint32_t CSI_VSYNC_ENABLE : 1; /*!< [31]  */
    } B;
} hw_lcdif_as_ctrl_t;

/*!
 * @name Constants and macros for entire LCDIF_AS_CTRL register
 */
/*@{*/
#define HW_LCDIF_AS_CTRL_ADDR(x) ((uintptr_t)(x) + 0x210U)

#define HW_LCDIF_AS_CTRL(x)      (*(__IO hw_lcdif_as_ctrl_t *) HW_LCDIF_AS_CTRL_ADDR(x))
#define HW_LCDIF_AS_CTRL_RD(x)   (HW_LCDIF_AS_CTRL(x).U)
#define HW_LCDIF_AS_CTRL_WR(x, v) (HW_LCDIF_AS_CTRL(x).U = (v))
#define HW_LCDIF_AS_CTRL_SET(x, v) (HW_LCDIF_AS_CTRL_WR(x, HW_LCDIF_AS_CTRL_RD(x) |  (v)))
#define HW_LCDIF_AS_CTRL_CLR(x, v) (HW_LCDIF_AS_CTRL_WR(x, HW_LCDIF_AS_CTRL_RD(x) & ~(v)))
#define HW_LCDIF_AS_CTRL_TOG(x, v) (HW_LCDIF_AS_CTRL_WR(x, HW_LCDIF_AS_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_AS_CTRL bitfields
 */

/*!
 * @name Register LCDIF_AS_CTRL, field AS_ENABLE[0] (RW)
 *
 * When this bit is set by software, the LCDIF will start fetching AS buffer
 * data in bus master mode and combine it with another buffer.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_AS_ENABLE (0U)    /*!< Bit position for LCDIF_AS_CTRL_AS_ENABLE. */
#define BM_LCDIF_AS_CTRL_AS_ENABLE (0x00000001U) /*!< Bit mask for LCDIF_AS_CTRL_AS_ENABLE. */
#define BS_LCDIF_AS_CTRL_AS_ENABLE (1U)    /*!< Bit field size in bits for LCDIF_AS_CTRL_AS_ENABLE. */

/*! @brief Read current value of the LCDIF_AS_CTRL_AS_ENABLE field. */
#define BR_LCDIF_AS_CTRL_AS_ENABLE(x) (HW_LCDIF_AS_CTRL(x).B.AS_ENABLE)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_AS_ENABLE. */
#define BF_LCDIF_AS_CTRL_AS_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_AS_ENABLE) & BM_LCDIF_AS_CTRL_AS_ENABLE)

/*! @brief Set the AS_ENABLE field to a new value. */
#define BW_LCDIF_AS_CTRL_AS_ENABLE(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_AS_ENABLE) | BF_LCDIF_AS_CTRL_AS_ENABLE(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field ALPHA_CTRL[2:1] (RW)
 *
 * Determines how the alpha value is constructed for this alpha surface.
 * Indicates that the value in the ALPHA field should be used instead of the alpha
 * values present in the input pixels. Embedded = 0x0 Indicates that the AS pixel
 * alpha value will be used to blend the AS with PS. The ALPHA field is ignored.
 * Override = 0x1 Indicates that the value in the ALPHA field should be used instead
 * of the alpha values present in the input pixels. Multiply = 0x2 Indicates that
 * the value in the ALPHA field should be used to scale all pixel alpha values.
 * Each pixel alpha is multiplied by the value in the ALPHA field. ROPs = 0x3
 * Enable ROPs. The ROP field indicates an operation to be performed on the alpha
 * surface and PS pixels.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_ALPHA_CTRL (1U)   /*!< Bit position for LCDIF_AS_CTRL_ALPHA_CTRL. */
#define BM_LCDIF_AS_CTRL_ALPHA_CTRL (0x00000006U) /*!< Bit mask for LCDIF_AS_CTRL_ALPHA_CTRL. */
#define BS_LCDIF_AS_CTRL_ALPHA_CTRL (2U)   /*!< Bit field size in bits for LCDIF_AS_CTRL_ALPHA_CTRL. */

/*! @brief Read current value of the LCDIF_AS_CTRL_ALPHA_CTRL field. */
#define BR_LCDIF_AS_CTRL_ALPHA_CTRL(x) (HW_LCDIF_AS_CTRL(x).B.ALPHA_CTRL)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_ALPHA_CTRL. */
#define BF_LCDIF_AS_CTRL_ALPHA_CTRL(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_ALPHA_CTRL) & BM_LCDIF_AS_CTRL_ALPHA_CTRL)

/*! @brief Set the ALPHA_CTRL field to a new value. */
#define BW_LCDIF_AS_CTRL_ALPHA_CTRL(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_ALPHA_CTRL) | BF_LCDIF_AS_CTRL_ALPHA_CTRL(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field ENABLE_COLORKEY[3] (RW)
 *
 * Indicates that colorkey functionality is enabled for this alpha surface.
 * Pixels found in the alpha surface colorkey range will be displayed as transparent
 * (the PS pixel will be used).
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_ENABLE_COLORKEY (3U) /*!< Bit position for LCDIF_AS_CTRL_ENABLE_COLORKEY. */
#define BM_LCDIF_AS_CTRL_ENABLE_COLORKEY (0x00000008U) /*!< Bit mask for LCDIF_AS_CTRL_ENABLE_COLORKEY. */
#define BS_LCDIF_AS_CTRL_ENABLE_COLORKEY (1U) /*!< Bit field size in bits for LCDIF_AS_CTRL_ENABLE_COLORKEY. */

/*! @brief Read current value of the LCDIF_AS_CTRL_ENABLE_COLORKEY field. */
#define BR_LCDIF_AS_CTRL_ENABLE_COLORKEY(x) (HW_LCDIF_AS_CTRL(x).B.ENABLE_COLORKEY)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_ENABLE_COLORKEY. */
#define BF_LCDIF_AS_CTRL_ENABLE_COLORKEY(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_ENABLE_COLORKEY) & BM_LCDIF_AS_CTRL_ENABLE_COLORKEY)

/*! @brief Set the ENABLE_COLORKEY field to a new value. */
#define BW_LCDIF_AS_CTRL_ENABLE_COLORKEY(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_ENABLE_COLORKEY) | BF_LCDIF_AS_CTRL_ENABLE_COLORKEY(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field FORMAT[7:4] (RW)
 *
 * Indicates the input buffer format for AS. ARGB8888 = 0x0 32-bit pixels with
 * alpha RGB888 = 0x4 32-bit pixels without alpha (unpacked 24-bit format)
 * ARGB1555 = 0x8 16-bit pixels with alpha ARGB4444 = 0x9 16-bit pixels with alpha
 * RGB555 = 0xC 16-bit pixels without alpha RGB444 = 0xD 16-bit pixels without alpha
 * RGB565 = 0xE 16-bit pixels without alpha
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_FORMAT (4U)       /*!< Bit position for LCDIF_AS_CTRL_FORMAT. */
#define BM_LCDIF_AS_CTRL_FORMAT (0x000000F0U) /*!< Bit mask for LCDIF_AS_CTRL_FORMAT. */
#define BS_LCDIF_AS_CTRL_FORMAT (4U)       /*!< Bit field size in bits for LCDIF_AS_CTRL_FORMAT. */

/*! @brief Read current value of the LCDIF_AS_CTRL_FORMAT field. */
#define BR_LCDIF_AS_CTRL_FORMAT(x) (HW_LCDIF_AS_CTRL(x).B.FORMAT)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_FORMAT. */
#define BF_LCDIF_AS_CTRL_FORMAT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_FORMAT) & BM_LCDIF_AS_CTRL_FORMAT)

/*! @brief Set the FORMAT field to a new value. */
#define BW_LCDIF_AS_CTRL_FORMAT(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_FORMAT) | BF_LCDIF_AS_CTRL_FORMAT(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field ALPHA[15:8] (RW)
 *
 * Alpha modifier used when the ALPHA_MULTIPLY or ALPHA_OVERRIDE values are
 * programmed in REG_AS_CTRL[ALPHA_CTRL]. The output alpha value will either be
 * replaced (ALPHA_OVERRIDE) or scaled (ALPHA_MULTIPLY) when selected.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_ALPHA (8U)        /*!< Bit position for LCDIF_AS_CTRL_ALPHA. */
#define BM_LCDIF_AS_CTRL_ALPHA (0x0000FF00U) /*!< Bit mask for LCDIF_AS_CTRL_ALPHA. */
#define BS_LCDIF_AS_CTRL_ALPHA (8U)        /*!< Bit field size in bits for LCDIF_AS_CTRL_ALPHA. */

/*! @brief Read current value of the LCDIF_AS_CTRL_ALPHA field. */
#define BR_LCDIF_AS_CTRL_ALPHA(x) (HW_LCDIF_AS_CTRL(x).B.ALPHA)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_ALPHA. */
#define BF_LCDIF_AS_CTRL_ALPHA(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_ALPHA) & BM_LCDIF_AS_CTRL_ALPHA)

/*! @brief Set the ALPHA field to a new value. */
#define BW_LCDIF_AS_CTRL_ALPHA(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_ALPHA) | BF_LCDIF_AS_CTRL_ALPHA(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field ROP[19:16] (RW)
 *
 * Indicates a raster operation to perform when enabled. Raster operations are
 * enabled through the ALPHA_CTRL field. MASKAS = 0x0 AS AND PS MASKNOTAS = 0x1
 * nAS AND PS MASKASNOT = 0x2 AS AND nPS MERGEAS = 0x3 AS OR PS MERGENOTAS = 0x4
 * nAS OR PS MERGEASNOT = 0x5 AS OR nPS NOTCOPYAS = 0x6 nAS NOT = 0x7 nPS NOTMASKAS
 * = 0x8 AS NAND PS NOTMERGEAS = 0x9 AS NOR PS XORAS = 0xA AS XOR PS NOTXORAS =
 * 0xB AS XNOR PS
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_ROP (16U)         /*!< Bit position for LCDIF_AS_CTRL_ROP. */
#define BM_LCDIF_AS_CTRL_ROP (0x000F0000U) /*!< Bit mask for LCDIF_AS_CTRL_ROP. */
#define BS_LCDIF_AS_CTRL_ROP (4U)          /*!< Bit field size in bits for LCDIF_AS_CTRL_ROP. */

/*! @brief Read current value of the LCDIF_AS_CTRL_ROP field. */
#define BR_LCDIF_AS_CTRL_ROP(x) (HW_LCDIF_AS_CTRL(x).B.ROP)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_ROP. */
#define BF_LCDIF_AS_CTRL_ROP(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_ROP) & BM_LCDIF_AS_CTRL_ROP)

/*! @brief Set the ROP field to a new value. */
#define BW_LCDIF_AS_CTRL_ROP(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_ROP) | BF_LCDIF_AS_CTRL_ROP(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field ALPHA_INVERT[20] (RW)
 *
 * Setting this bit to logic 0 will not alter the alpha value. A logic 1 will
 * invert the alpha value and apply (1-alpha) for image composition.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_ALPHA_INVERT (20U) /*!< Bit position for LCDIF_AS_CTRL_ALPHA_INVERT. */
#define BM_LCDIF_AS_CTRL_ALPHA_INVERT (0x00100000U) /*!< Bit mask for LCDIF_AS_CTRL_ALPHA_INVERT. */
#define BS_LCDIF_AS_CTRL_ALPHA_INVERT (1U) /*!< Bit field size in bits for LCDIF_AS_CTRL_ALPHA_INVERT. */

/*! @brief Read current value of the LCDIF_AS_CTRL_ALPHA_INVERT field. */
#define BR_LCDIF_AS_CTRL_ALPHA_INVERT(x) (HW_LCDIF_AS_CTRL(x).B.ALPHA_INVERT)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_ALPHA_INVERT. */
#define BF_LCDIF_AS_CTRL_ALPHA_INVERT(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_ALPHA_INVERT) & BM_LCDIF_AS_CTRL_ALPHA_INVERT)

/*! @brief Set the ALPHA_INVERT field to a new value. */
#define BW_LCDIF_AS_CTRL_ALPHA_INVERT(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_ALPHA_INVERT) | BF_LCDIF_AS_CTRL_ALPHA_INVERT(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field INPUT_DATA_SWIZZLE[22:21] (RW)
 *
 * This field specifies how to swap the bytes either in the HW_LCDIF_DATA
 * register or those fetched by the AXI master part of LCDIF. The swizzle function is
 * independent of the WORD_LENGTH bit. See the explanation of the HW_LCDIF_DATA
 * below for names and definitions of data register fields. The supported swizzle
 * configurations are: NO_SWAP = 0x0 No byte swapping.(Little endian)
 * LITTLE_ENDIAN = 0x0 Little Endian byte ordering (same as NO_SWAP). BIG_ENDIAN_SWAP = 0x1
 * Big Endian swap (swap bytes 0, 3 and 1, 2). SWAP_ALL_BYTES = 0x1 Swizzle all
 * bytes, swap bytes 0, 3 and 1, 2 (aka Big Endian). HWD_SWAP = 0x2 Swap
 * half-words. HWD_BYTE_SWAP = 0x3 Swap bytes within each half-word.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE (21U) /*!< Bit position for LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE. */
#define BM_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE (0x00600000U) /*!< Bit mask for LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE. */
#define BS_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE (2U) /*!< Bit field size in bits for LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE. */

/*! @brief Read current value of the LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE field. */
#define BR_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE(x) (HW_LCDIF_AS_CTRL(x).B.INPUT_DATA_SWIZZLE)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE. */
#define BF_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE) & BM_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE)

/*! @brief Set the INPUT_DATA_SWIZZLE field to a new value. */
#define BW_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE) | BF_LCDIF_AS_CTRL_INPUT_DATA_SWIZZLE(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field PS_DISABLE[23] (RW)
 *
 * When this bit is set by software, the LCDIF will disable PS buffer data.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_PS_DISABLE (23U)  /*!< Bit position for LCDIF_AS_CTRL_PS_DISABLE. */
#define BM_LCDIF_AS_CTRL_PS_DISABLE (0x00800000U) /*!< Bit mask for LCDIF_AS_CTRL_PS_DISABLE. */
#define BS_LCDIF_AS_CTRL_PS_DISABLE (1U)   /*!< Bit field size in bits for LCDIF_AS_CTRL_PS_DISABLE. */

/*! @brief Read current value of the LCDIF_AS_CTRL_PS_DISABLE field. */
#define BR_LCDIF_AS_CTRL_PS_DISABLE(x) (HW_LCDIF_AS_CTRL(x).B.PS_DISABLE)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_PS_DISABLE. */
#define BF_LCDIF_AS_CTRL_PS_DISABLE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_PS_DISABLE) & BM_LCDIF_AS_CTRL_PS_DISABLE)

/*! @brief Set the PS_DISABLE field to a new value. */
#define BW_LCDIF_AS_CTRL_PS_DISABLE(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_PS_DISABLE) | BF_LCDIF_AS_CTRL_PS_DISABLE(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field RVDS1[26:24] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_RVDS1 (24U)       /*!< Bit position for LCDIF_AS_CTRL_RVDS1. */
#define BM_LCDIF_AS_CTRL_RVDS1 (0x07000000U) /*!< Bit mask for LCDIF_AS_CTRL_RVDS1. */
#define BS_LCDIF_AS_CTRL_RVDS1 (3U)        /*!< Bit field size in bits for LCDIF_AS_CTRL_RVDS1. */

/*! @brief Read current value of the LCDIF_AS_CTRL_RVDS1 field. */
#define BR_LCDIF_AS_CTRL_RVDS1(x) (HW_LCDIF_AS_CTRL(x).B.RVDS1)
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field CSI_SYNC_ON_IRQ[27] (RW)
 *
 * this bit is set by software to decide which vsync generate mode. LCDIF vsync
 * generate by internal counter when set to 0, LCDIF vsync delayed by each
 * csi_vsync_in when set to 1; INT_SYNC_MODE = 0x0 LCDIF vsync generate by internal
 * counter. EXT_SYNC_MODE = 0x1 LCDIF vsync delayed by each csi_vsync_in.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ (27U) /*!< Bit position for LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ. */
#define BM_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ (0x08000000U) /*!< Bit mask for LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ. */
#define BS_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ (1U) /*!< Bit field size in bits for LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ. */

/*! @brief Read current value of the LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ field. */
#define BR_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ(x) (HW_LCDIF_AS_CTRL(x).B.CSI_SYNC_ON_IRQ)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ. */
#define BF_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ) & BM_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ)

/*! @brief Set the CSI_SYNC_ON_IRQ field to a new value. */
#define BW_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ) | BF_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field CSI_SYNC_ON_IRQ_EN[28] (RW)
 *
 * This bit is set to enable an interrupt when LCDIF lock with CSI vsync input.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN (28U) /*!< Bit position for LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN. */
#define BM_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN (0x10000000U) /*!< Bit mask for LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN. */
#define BS_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN (1U) /*!< Bit field size in bits for LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN. */

/*! @brief Read current value of the LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN field. */
#define BR_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN(x) (HW_LCDIF_AS_CTRL(x).B.CSI_SYNC_ON_IRQ_EN)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN. */
#define BF_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN) & BM_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN)

/*! @brief Set the CSI_SYNC_ON_IRQ_EN field to a new value. */
#define BW_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN) | BF_LCDIF_AS_CTRL_CSI_SYNC_ON_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field CSI_VSYNC_MODE[29] (RW)
 *
 * this bit is set by software to decide which vsync generate mode. LCDIF vsync
 * generate by internal counter when set to 0, LCDIF vsync delayed by each
 * csi_vsync_in when set to 1; INT_SYNC_MODE = 0x0 LCDIF vsync generate by internal
 * counter. EXT_SYNC_MODE = 0x1 LCDIF vsync delayed by each csi_vsync_in.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_CSI_VSYNC_MODE (29U) /*!< Bit position for LCDIF_AS_CTRL_CSI_VSYNC_MODE. */
#define BM_LCDIF_AS_CTRL_CSI_VSYNC_MODE (0x20000000U) /*!< Bit mask for LCDIF_AS_CTRL_CSI_VSYNC_MODE. */
#define BS_LCDIF_AS_CTRL_CSI_VSYNC_MODE (1U) /*!< Bit field size in bits for LCDIF_AS_CTRL_CSI_VSYNC_MODE. */

/*! @brief Read current value of the LCDIF_AS_CTRL_CSI_VSYNC_MODE field. */
#define BR_LCDIF_AS_CTRL_CSI_VSYNC_MODE(x) (HW_LCDIF_AS_CTRL(x).B.CSI_VSYNC_MODE)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_CSI_VSYNC_MODE. */
#define BF_LCDIF_AS_CTRL_CSI_VSYNC_MODE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_CSI_VSYNC_MODE) & BM_LCDIF_AS_CTRL_CSI_VSYNC_MODE)

/*! @brief Set the CSI_VSYNC_MODE field to a new value. */
#define BW_LCDIF_AS_CTRL_CSI_VSYNC_MODE(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_CSI_VSYNC_MODE) | BF_LCDIF_AS_CTRL_CSI_VSYNC_MODE(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field CSI_VSYNC_POL[30] (RW)
 *
 * Default 0 active low during VSYNC_PULSE_WIDTH time and will be high during
 * the rest of the VSYNC period. Set it to 1 to invert the polarity.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_CSI_VSYNC_POL (30U) /*!< Bit position for LCDIF_AS_CTRL_CSI_VSYNC_POL. */
#define BM_LCDIF_AS_CTRL_CSI_VSYNC_POL (0x40000000U) /*!< Bit mask for LCDIF_AS_CTRL_CSI_VSYNC_POL. */
#define BS_LCDIF_AS_CTRL_CSI_VSYNC_POL (1U) /*!< Bit field size in bits for LCDIF_AS_CTRL_CSI_VSYNC_POL. */

/*! @brief Read current value of the LCDIF_AS_CTRL_CSI_VSYNC_POL field. */
#define BR_LCDIF_AS_CTRL_CSI_VSYNC_POL(x) (HW_LCDIF_AS_CTRL(x).B.CSI_VSYNC_POL)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_CSI_VSYNC_POL. */
#define BF_LCDIF_AS_CTRL_CSI_VSYNC_POL(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_CSI_VSYNC_POL) & BM_LCDIF_AS_CTRL_CSI_VSYNC_POL)

/*! @brief Set the CSI_VSYNC_POL field to a new value. */
#define BW_LCDIF_AS_CTRL_CSI_VSYNC_POL(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_CSI_VSYNC_POL) | BF_LCDIF_AS_CTRL_CSI_VSYNC_POL(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CTRL, field CSI_VSYNC_ENABLE[31] (RW)
 *
 * When this bit is set by software, the LCDIF work as sync mode with CSI input.
 */
/*@{*/
#define BP_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE (31U) /*!< Bit position for LCDIF_AS_CTRL_CSI_VSYNC_ENABLE. */
#define BM_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE (0x80000000U) /*!< Bit mask for LCDIF_AS_CTRL_CSI_VSYNC_ENABLE. */
#define BS_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE (1U) /*!< Bit field size in bits for LCDIF_AS_CTRL_CSI_VSYNC_ENABLE. */

/*! @brief Read current value of the LCDIF_AS_CTRL_CSI_VSYNC_ENABLE field. */
#define BR_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE(x) (HW_LCDIF_AS_CTRL(x).B.CSI_VSYNC_ENABLE)

/*! @brief Format value for bitfield LCDIF_AS_CTRL_CSI_VSYNC_ENABLE. */
#define BF_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE) & BM_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE)

/*! @brief Set the CSI_VSYNC_ENABLE field to a new value. */
#define BW_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE(x, v) (HW_LCDIF_AS_CTRL_WR(x, (HW_LCDIF_AS_CTRL_RD(x) & ~BM_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE) | BF_LCDIF_AS_CTRL_CSI_VSYNC_ENABLE(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_AS_BUF - Alpha Surface Buffer Pointer
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_AS_BUF - Alpha Surface Buffer Pointer (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to indicate the base address of the AS buffer.
 */
typedef union _hw_lcdif_as_buf
{
    uint32_t U;
    struct _hw_lcdif_as_buf_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_lcdif_as_buf_t;

/*!
 * @name Constants and macros for entire LCDIF_AS_BUF register
 */
/*@{*/
#define HW_LCDIF_AS_BUF_ADDR(x)  ((uintptr_t)(x) + 0x220U)

#define HW_LCDIF_AS_BUF(x)       (*(__IO hw_lcdif_as_buf_t *) HW_LCDIF_AS_BUF_ADDR(x))
#define HW_LCDIF_AS_BUF_RD(x)    (HW_LCDIF_AS_BUF(x).U)
#define HW_LCDIF_AS_BUF_WR(x, v) (HW_LCDIF_AS_BUF(x).U = (v))
#define HW_LCDIF_AS_BUF_SET(x, v) (HW_LCDIF_AS_BUF_WR(x, HW_LCDIF_AS_BUF_RD(x) |  (v)))
#define HW_LCDIF_AS_BUF_CLR(x, v) (HW_LCDIF_AS_BUF_WR(x, HW_LCDIF_AS_BUF_RD(x) & ~(v)))
#define HW_LCDIF_AS_BUF_TOG(x, v) (HW_LCDIF_AS_BUF_WR(x, HW_LCDIF_AS_BUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_AS_BUF bitfields
 */

/*!
 * @name Register LCDIF_AS_BUF, field ADDR[31:0] (RW)
 *
 * Address pointer for the alpha surface 0 buffer.
 */
/*@{*/
#define BP_LCDIF_AS_BUF_ADDR (0U)          /*!< Bit position for LCDIF_AS_BUF_ADDR. */
#define BM_LCDIF_AS_BUF_ADDR (0xFFFFFFFFU) /*!< Bit mask for LCDIF_AS_BUF_ADDR. */
#define BS_LCDIF_AS_BUF_ADDR (32U)         /*!< Bit field size in bits for LCDIF_AS_BUF_ADDR. */

/*! @brief Read current value of the LCDIF_AS_BUF_ADDR field. */
#define BR_LCDIF_AS_BUF_ADDR(x) (HW_LCDIF_AS_BUF(x).U)

/*! @brief Format value for bitfield LCDIF_AS_BUF_ADDR. */
#define BF_LCDIF_AS_BUF_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_BUF_ADDR) & BM_LCDIF_AS_BUF_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_LCDIF_AS_BUF_ADDR(x, v) (HW_LCDIF_AS_BUF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_AS_NEXT_BUF -
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_AS_NEXT_BUF -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * When the LCDIF is behaving as a master, this address points to the address of
 * the next frame of data that will be sent out via the LCDIF. It is upto the
 * software to make sure that this register is programmed before the end of the
 * current frame, otherwise it might result in old data going out the LCDIF. This
 * address must always be double-word aligned.
 */
typedef union _hw_lcdif_as_next_buf
{
    uint32_t U;
    struct _hw_lcdif_as_next_buf_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_lcdif_as_next_buf_t;

/*!
 * @name Constants and macros for entire LCDIF_AS_NEXT_BUF register
 */
/*@{*/
#define HW_LCDIF_AS_NEXT_BUF_ADDR(x) ((uintptr_t)(x) + 0x230U)

#define HW_LCDIF_AS_NEXT_BUF(x)  (*(__IO hw_lcdif_as_next_buf_t *) HW_LCDIF_AS_NEXT_BUF_ADDR(x))
#define HW_LCDIF_AS_NEXT_BUF_RD(x) (HW_LCDIF_AS_NEXT_BUF(x).U)
#define HW_LCDIF_AS_NEXT_BUF_WR(x, v) (HW_LCDIF_AS_NEXT_BUF(x).U = (v))
#define HW_LCDIF_AS_NEXT_BUF_SET(x, v) (HW_LCDIF_AS_NEXT_BUF_WR(x, HW_LCDIF_AS_NEXT_BUF_RD(x) |  (v)))
#define HW_LCDIF_AS_NEXT_BUF_CLR(x, v) (HW_LCDIF_AS_NEXT_BUF_WR(x, HW_LCDIF_AS_NEXT_BUF_RD(x) & ~(v)))
#define HW_LCDIF_AS_NEXT_BUF_TOG(x, v) (HW_LCDIF_AS_NEXT_BUF_WR(x, HW_LCDIF_AS_NEXT_BUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_AS_NEXT_BUF bitfields
 */

/*!
 * @name Register LCDIF_AS_NEXT_BUF, field ADDR[31:0] (RW)
 *
 * Address of the next frame that will be transmitted by eLCDIF.
 */
/*@{*/
#define BP_LCDIF_AS_NEXT_BUF_ADDR (0U)     /*!< Bit position for LCDIF_AS_NEXT_BUF_ADDR. */
#define BM_LCDIF_AS_NEXT_BUF_ADDR (0xFFFFFFFFU) /*!< Bit mask for LCDIF_AS_NEXT_BUF_ADDR. */
#define BS_LCDIF_AS_NEXT_BUF_ADDR (32U)    /*!< Bit field size in bits for LCDIF_AS_NEXT_BUF_ADDR. */

/*! @brief Read current value of the LCDIF_AS_NEXT_BUF_ADDR field. */
#define BR_LCDIF_AS_NEXT_BUF_ADDR(x) (HW_LCDIF_AS_NEXT_BUF(x).U)

/*! @brief Format value for bitfield LCDIF_AS_NEXT_BUF_ADDR. */
#define BF_LCDIF_AS_NEXT_BUF_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_NEXT_BUF_ADDR) & BM_LCDIF_AS_NEXT_BUF_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_LCDIF_AS_NEXT_BUF_ADDR(x, v) (HW_LCDIF_AS_NEXT_BUF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_AS_CLRKEYLOW - eLCDIF Overlay Color Key Low
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_AS_CLRKEYLOW - eLCDIF Overlay Color Key Low (RW)
 *
 * Reset value: 0x00FFFFFFU
 *
 * If a pixel in the current overlay image with a color that falls in the range
 * from the ASCOLORKEYLOW to ASCOLORKEYHIGH range, it will use the PS pixel value
 * for that location. Colorkey operations are higher priority than alpha or ROP
 * operations.
 */
typedef union _hw_lcdif_as_clrkeylow
{
    uint32_t U;
    struct _hw_lcdif_as_clrkeylow_bitfields
    {
        uint32_t PIXEL : 24;           /*!< [23:0]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_lcdif_as_clrkeylow_t;

/*!
 * @name Constants and macros for entire LCDIF_AS_CLRKEYLOW register
 */
/*@{*/
#define HW_LCDIF_AS_CLRKEYLOW_ADDR(x) ((uintptr_t)(x) + 0x240U)

#define HW_LCDIF_AS_CLRKEYLOW(x) (*(__IO hw_lcdif_as_clrkeylow_t *) HW_LCDIF_AS_CLRKEYLOW_ADDR(x))
#define HW_LCDIF_AS_CLRKEYLOW_RD(x) (HW_LCDIF_AS_CLRKEYLOW(x).U)
#define HW_LCDIF_AS_CLRKEYLOW_WR(x, v) (HW_LCDIF_AS_CLRKEYLOW(x).U = (v))
#define HW_LCDIF_AS_CLRKEYLOW_SET(x, v) (HW_LCDIF_AS_CLRKEYLOW_WR(x, HW_LCDIF_AS_CLRKEYLOW_RD(x) |  (v)))
#define HW_LCDIF_AS_CLRKEYLOW_CLR(x, v) (HW_LCDIF_AS_CLRKEYLOW_WR(x, HW_LCDIF_AS_CLRKEYLOW_RD(x) & ~(v)))
#define HW_LCDIF_AS_CLRKEYLOW_TOG(x, v) (HW_LCDIF_AS_CLRKEYLOW_WR(x, HW_LCDIF_AS_CLRKEYLOW_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_AS_CLRKEYLOW bitfields
 */

/*!
 * @name Register LCDIF_AS_CLRKEYLOW, field PIXEL[23:0] (RW)
 *
 * Low range of RGB color key applied to AS buffer
 */
/*@{*/
#define BP_LCDIF_AS_CLRKEYLOW_PIXEL (0U)   /*!< Bit position for LCDIF_AS_CLRKEYLOW_PIXEL. */
#define BM_LCDIF_AS_CLRKEYLOW_PIXEL (0x00FFFFFFU) /*!< Bit mask for LCDIF_AS_CLRKEYLOW_PIXEL. */
#define BS_LCDIF_AS_CLRKEYLOW_PIXEL (24U)  /*!< Bit field size in bits for LCDIF_AS_CLRKEYLOW_PIXEL. */

/*! @brief Read current value of the LCDIF_AS_CLRKEYLOW_PIXEL field. */
#define BR_LCDIF_AS_CLRKEYLOW_PIXEL(x) (HW_LCDIF_AS_CLRKEYLOW(x).B.PIXEL)

/*! @brief Format value for bitfield LCDIF_AS_CLRKEYLOW_PIXEL. */
#define BF_LCDIF_AS_CLRKEYLOW_PIXEL(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CLRKEYLOW_PIXEL) & BM_LCDIF_AS_CLRKEYLOW_PIXEL)

/*! @brief Set the PIXEL field to a new value. */
#define BW_LCDIF_AS_CLRKEYLOW_PIXEL(x, v) (HW_LCDIF_AS_CLRKEYLOW_WR(x, (HW_LCDIF_AS_CLRKEYLOW_RD(x) & ~BM_LCDIF_AS_CLRKEYLOW_PIXEL) | BF_LCDIF_AS_CLRKEYLOW_PIXEL(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CLRKEYLOW, field RSVD1[31:24] (RW)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_LCDIF_AS_CLRKEYLOW_RSVD1 (24U)  /*!< Bit position for LCDIF_AS_CLRKEYLOW_RSVD1. */
#define BM_LCDIF_AS_CLRKEYLOW_RSVD1 (0xFF000000U) /*!< Bit mask for LCDIF_AS_CLRKEYLOW_RSVD1. */
#define BS_LCDIF_AS_CLRKEYLOW_RSVD1 (8U)   /*!< Bit field size in bits for LCDIF_AS_CLRKEYLOW_RSVD1. */

/*! @brief Read current value of the LCDIF_AS_CLRKEYLOW_RSVD1 field. */
#define BR_LCDIF_AS_CLRKEYLOW_RSVD1(x) (HW_LCDIF_AS_CLRKEYLOW(x).B.RSVD1)

/*! @brief Format value for bitfield LCDIF_AS_CLRKEYLOW_RSVD1. */
#define BF_LCDIF_AS_CLRKEYLOW_RSVD1(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CLRKEYLOW_RSVD1) & BM_LCDIF_AS_CLRKEYLOW_RSVD1)

/*! @brief Set the RSVD1 field to a new value. */
#define BW_LCDIF_AS_CLRKEYLOW_RSVD1(x, v) (HW_LCDIF_AS_CLRKEYLOW_WR(x, (HW_LCDIF_AS_CLRKEYLOW_RD(x) & ~BM_LCDIF_AS_CLRKEYLOW_RSVD1) | BF_LCDIF_AS_CLRKEYLOW_RSVD1(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_AS_CLRKEYHIGH - eLCDIF Overlay Color Key High
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_AS_CLRKEYHIGH - eLCDIF Overlay Color Key High (RW)
 *
 * Reset value: 0x00000000U
 *
 * If a pixel in the current overlay image with a color that falls in the range
 * from the ASCOLORKEYLOW to ASCOLORKEYHIGH range, it will use the PS pixel value
 * for that location. Colorkey operations are higher priority than alpha or ROP
 * operations.
 */
typedef union _hw_lcdif_as_clrkeyhigh
{
    uint32_t U;
    struct _hw_lcdif_as_clrkeyhigh_bitfields
    {
        uint32_t PIXEL : 24;           /*!< [23:0]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_lcdif_as_clrkeyhigh_t;

/*!
 * @name Constants and macros for entire LCDIF_AS_CLRKEYHIGH register
 */
/*@{*/
#define HW_LCDIF_AS_CLRKEYHIGH_ADDR(x) ((uintptr_t)(x) + 0x250U)

#define HW_LCDIF_AS_CLRKEYHIGH(x) (*(__IO hw_lcdif_as_clrkeyhigh_t *) HW_LCDIF_AS_CLRKEYHIGH_ADDR(x))
#define HW_LCDIF_AS_CLRKEYHIGH_RD(x) (HW_LCDIF_AS_CLRKEYHIGH(x).U)
#define HW_LCDIF_AS_CLRKEYHIGH_WR(x, v) (HW_LCDIF_AS_CLRKEYHIGH(x).U = (v))
#define HW_LCDIF_AS_CLRKEYHIGH_SET(x, v) (HW_LCDIF_AS_CLRKEYHIGH_WR(x, HW_LCDIF_AS_CLRKEYHIGH_RD(x) |  (v)))
#define HW_LCDIF_AS_CLRKEYHIGH_CLR(x, v) (HW_LCDIF_AS_CLRKEYHIGH_WR(x, HW_LCDIF_AS_CLRKEYHIGH_RD(x) & ~(v)))
#define HW_LCDIF_AS_CLRKEYHIGH_TOG(x, v) (HW_LCDIF_AS_CLRKEYHIGH_WR(x, HW_LCDIF_AS_CLRKEYHIGH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_AS_CLRKEYHIGH bitfields
 */

/*!
 * @name Register LCDIF_AS_CLRKEYHIGH, field PIXEL[23:0] (RW)
 *
 * High range of RGB color key applied to AS buffer
 */
/*@{*/
#define BP_LCDIF_AS_CLRKEYHIGH_PIXEL (0U)  /*!< Bit position for LCDIF_AS_CLRKEYHIGH_PIXEL. */
#define BM_LCDIF_AS_CLRKEYHIGH_PIXEL (0x00FFFFFFU) /*!< Bit mask for LCDIF_AS_CLRKEYHIGH_PIXEL. */
#define BS_LCDIF_AS_CLRKEYHIGH_PIXEL (24U) /*!< Bit field size in bits for LCDIF_AS_CLRKEYHIGH_PIXEL. */

/*! @brief Read current value of the LCDIF_AS_CLRKEYHIGH_PIXEL field. */
#define BR_LCDIF_AS_CLRKEYHIGH_PIXEL(x) (HW_LCDIF_AS_CLRKEYHIGH(x).B.PIXEL)

/*! @brief Format value for bitfield LCDIF_AS_CLRKEYHIGH_PIXEL. */
#define BF_LCDIF_AS_CLRKEYHIGH_PIXEL(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CLRKEYHIGH_PIXEL) & BM_LCDIF_AS_CLRKEYHIGH_PIXEL)

/*! @brief Set the PIXEL field to a new value. */
#define BW_LCDIF_AS_CLRKEYHIGH_PIXEL(x, v) (HW_LCDIF_AS_CLRKEYHIGH_WR(x, (HW_LCDIF_AS_CLRKEYHIGH_RD(x) & ~BM_LCDIF_AS_CLRKEYHIGH_PIXEL) | BF_LCDIF_AS_CLRKEYHIGH_PIXEL(v)))
/*@}*/

/*!
 * @name Register LCDIF_AS_CLRKEYHIGH, field RSVD1[31:24] (RW)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_LCDIF_AS_CLRKEYHIGH_RSVD1 (24U) /*!< Bit position for LCDIF_AS_CLRKEYHIGH_RSVD1. */
#define BM_LCDIF_AS_CLRKEYHIGH_RSVD1 (0xFF000000U) /*!< Bit mask for LCDIF_AS_CLRKEYHIGH_RSVD1. */
#define BS_LCDIF_AS_CLRKEYHIGH_RSVD1 (8U)  /*!< Bit field size in bits for LCDIF_AS_CLRKEYHIGH_RSVD1. */

/*! @brief Read current value of the LCDIF_AS_CLRKEYHIGH_RSVD1 field. */
#define BR_LCDIF_AS_CLRKEYHIGH_RSVD1(x) (HW_LCDIF_AS_CLRKEYHIGH(x).B.RSVD1)

/*! @brief Format value for bitfield LCDIF_AS_CLRKEYHIGH_RSVD1. */
#define BF_LCDIF_AS_CLRKEYHIGH_RSVD1(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_AS_CLRKEYHIGH_RSVD1) & BM_LCDIF_AS_CLRKEYHIGH_RSVD1)

/*! @brief Set the RSVD1 field to a new value. */
#define BW_LCDIF_AS_CLRKEYHIGH_RSVD1(x, v) (HW_LCDIF_AS_CLRKEYHIGH_WR(x, (HW_LCDIF_AS_CLRKEYHIGH_RD(x) & ~BM_LCDIF_AS_CLRKEYHIGH_RSVD1) | BF_LCDIF_AS_CLRKEYHIGH_RSVD1(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_SYNC_DELAY - LCD working insync mode with CSI for VSYNC delay
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_SYNC_DELAY - LCD working insync mode with CSI for VSYNC delay (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LCDIF DOTCLK mode VSYNC will delay from CSI_VSYNC as ( V_COUNT_DELAY *
 * HSYNC_PERIOD + H_COUNT_DELAY) PIXCLK cycles
 */
typedef union _hw_lcdif_sync_delay
{
    uint32_t U;
    struct _hw_lcdif_sync_delay_bitfields
    {
        uint32_t H_COUNT_DELAY : 16;   /*!< [15:0]  */
        uint32_t V_COUNT_DELAY : 16;   /*!< [31:16]  */
    } B;
} hw_lcdif_sync_delay_t;

/*!
 * @name Constants and macros for entire LCDIF_SYNC_DELAY register
 */
/*@{*/
#define HW_LCDIF_SYNC_DELAY_ADDR(x) ((uintptr_t)(x) + 0x260U)

#define HW_LCDIF_SYNC_DELAY(x)   (*(__IO hw_lcdif_sync_delay_t *) HW_LCDIF_SYNC_DELAY_ADDR(x))
#define HW_LCDIF_SYNC_DELAY_RD(x) (HW_LCDIF_SYNC_DELAY(x).U)
#define HW_LCDIF_SYNC_DELAY_WR(x, v) (HW_LCDIF_SYNC_DELAY(x).U = (v))
#define HW_LCDIF_SYNC_DELAY_SET(x, v) (HW_LCDIF_SYNC_DELAY_WR(x, HW_LCDIF_SYNC_DELAY_RD(x) |  (v)))
#define HW_LCDIF_SYNC_DELAY_CLR(x, v) (HW_LCDIF_SYNC_DELAY_WR(x, HW_LCDIF_SYNC_DELAY_RD(x) & ~(v)))
#define HW_LCDIF_SYNC_DELAY_TOG(x, v) (HW_LCDIF_SYNC_DELAY_WR(x, HW_LCDIF_SYNC_DELAY_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LCDIF_SYNC_DELAY bitfields
 */

/*!
 * @name Register LCDIF_SYNC_DELAY, field H_COUNT_DELAY[15:0] (RW)
 *
 * LCDIF VSYNC delayed counter for CSI_VSYNC.
 */
/*@{*/
#define BP_LCDIF_SYNC_DELAY_H_COUNT_DELAY (0U) /*!< Bit position for LCDIF_SYNC_DELAY_H_COUNT_DELAY. */
#define BM_LCDIF_SYNC_DELAY_H_COUNT_DELAY (0x0000FFFFU) /*!< Bit mask for LCDIF_SYNC_DELAY_H_COUNT_DELAY. */
#define BS_LCDIF_SYNC_DELAY_H_COUNT_DELAY (16U) /*!< Bit field size in bits for LCDIF_SYNC_DELAY_H_COUNT_DELAY. */

/*! @brief Read current value of the LCDIF_SYNC_DELAY_H_COUNT_DELAY field. */
#define BR_LCDIF_SYNC_DELAY_H_COUNT_DELAY(x) (HW_LCDIF_SYNC_DELAY(x).B.H_COUNT_DELAY)

/*! @brief Format value for bitfield LCDIF_SYNC_DELAY_H_COUNT_DELAY. */
#define BF_LCDIF_SYNC_DELAY_H_COUNT_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_SYNC_DELAY_H_COUNT_DELAY) & BM_LCDIF_SYNC_DELAY_H_COUNT_DELAY)

/*! @brief Set the H_COUNT_DELAY field to a new value. */
#define BW_LCDIF_SYNC_DELAY_H_COUNT_DELAY(x, v) (HW_LCDIF_SYNC_DELAY_WR(x, (HW_LCDIF_SYNC_DELAY_RD(x) & ~BM_LCDIF_SYNC_DELAY_H_COUNT_DELAY) | BF_LCDIF_SYNC_DELAY_H_COUNT_DELAY(v)))
/*@}*/

/*!
 * @name Register LCDIF_SYNC_DELAY, field V_COUNT_DELAY[31:16] (RW)
 *
 * LCDIF VSYNC delayed counter for CSI_VSYNC.
 */
/*@{*/
#define BP_LCDIF_SYNC_DELAY_V_COUNT_DELAY (16U) /*!< Bit position for LCDIF_SYNC_DELAY_V_COUNT_DELAY. */
#define BM_LCDIF_SYNC_DELAY_V_COUNT_DELAY (0xFFFF0000U) /*!< Bit mask for LCDIF_SYNC_DELAY_V_COUNT_DELAY. */
#define BS_LCDIF_SYNC_DELAY_V_COUNT_DELAY (16U) /*!< Bit field size in bits for LCDIF_SYNC_DELAY_V_COUNT_DELAY. */

/*! @brief Read current value of the LCDIF_SYNC_DELAY_V_COUNT_DELAY field. */
#define BR_LCDIF_SYNC_DELAY_V_COUNT_DELAY(x) (HW_LCDIF_SYNC_DELAY(x).B.V_COUNT_DELAY)

/*! @brief Format value for bitfield LCDIF_SYNC_DELAY_V_COUNT_DELAY. */
#define BF_LCDIF_SYNC_DELAY_V_COUNT_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_LCDIF_SYNC_DELAY_V_COUNT_DELAY) & BM_LCDIF_SYNC_DELAY_V_COUNT_DELAY)

/*! @brief Set the V_COUNT_DELAY field to a new value. */
#define BW_LCDIF_SYNC_DELAY_V_COUNT_DELAY(x, v) (HW_LCDIF_SYNC_DELAY_WR(x, (HW_LCDIF_SYNC_DELAY_RD(x) & ~BM_LCDIF_SYNC_DELAY_V_COUNT_DELAY) | BF_LCDIF_SYNC_DELAY_V_COUNT_DELAY(v)))
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DEBUG3 - eLCDIF Interface Debug3 Register
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DEBUG3 - eLCDIF Interface Debug3 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The LCD interface debug register is for diagnostic use only.
 */
typedef union _hw_lcdif_debug3
{
    uint32_t U;
    struct _hw_lcdif_debug3_bitfields
    {
        uint32_t MST_WORDS : 4;        /*!< [3:0]  */
        uint32_t MST_OUTSTANDING_REQS : 5; /*!< [8:4]  */
        uint32_t MST_AVALID : 1;       /*!< [9]  */
        uint32_t CUR_REQ_STATE : 2;    /*!< [11:10]  */
        uint32_t RSVD0 : 20;           /*!< [31:12]  */
    } B;
} hw_lcdif_debug3_t;

/*!
 * @name Constants and macros for entire LCDIF_DEBUG3 register
 */
/*@{*/
#define HW_LCDIF_DEBUG3_ADDR(x)  ((uintptr_t)(x) + 0x270U)

#define HW_LCDIF_DEBUG3(x)       (*(__I hw_lcdif_debug3_t *) HW_LCDIF_DEBUG3_ADDR(x))
#define HW_LCDIF_DEBUG3_RD(x)    (HW_LCDIF_DEBUG3(x).U)
/*@}*/

/*
 * Constants & macros for individual LCDIF_DEBUG3 bitfields
 */

/*!
 * @name Register LCDIF_DEBUG3, field MST_WORDS[3:0] (RO)
 *
 * Read only view of the current bursts issued by the AXI bus master.
 */
/*@{*/
#define BP_LCDIF_DEBUG3_MST_WORDS (0U)     /*!< Bit position for LCDIF_DEBUG3_MST_WORDS. */
#define BM_LCDIF_DEBUG3_MST_WORDS (0x0000000FU) /*!< Bit mask for LCDIF_DEBUG3_MST_WORDS. */
#define BS_LCDIF_DEBUG3_MST_WORDS (4U)     /*!< Bit field size in bits for LCDIF_DEBUG3_MST_WORDS. */

/*! @brief Read current value of the LCDIF_DEBUG3_MST_WORDS field. */
#define BR_LCDIF_DEBUG3_MST_WORDS(x) (HW_LCDIF_DEBUG3(x).B.MST_WORDS)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG3, field MST_OUTSTANDING_REQS[8:4] (RO)
 *
 * Read only view of the current outstanding requests issued by the AXI bus
 * master
 */
/*@{*/
#define BP_LCDIF_DEBUG3_MST_OUTSTANDING_REQS (4U) /*!< Bit position for LCDIF_DEBUG3_MST_OUTSTANDING_REQS. */
#define BM_LCDIF_DEBUG3_MST_OUTSTANDING_REQS (0x000001F0U) /*!< Bit mask for LCDIF_DEBUG3_MST_OUTSTANDING_REQS. */
#define BS_LCDIF_DEBUG3_MST_OUTSTANDING_REQS (5U) /*!< Bit field size in bits for LCDIF_DEBUG3_MST_OUTSTANDING_REQS. */

/*! @brief Read current value of the LCDIF_DEBUG3_MST_OUTSTANDING_REQS field. */
#define BR_LCDIF_DEBUG3_MST_OUTSTANDING_REQS(x) (HW_LCDIF_DEBUG3(x).B.MST_OUTSTANDING_REQS)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG3, field MST_AVALID[9] (RO)
 *
 * Read only view of the mst_avalid signal issued by the AXI bus master
 */
/*@{*/
#define BP_LCDIF_DEBUG3_MST_AVALID (9U)    /*!< Bit position for LCDIF_DEBUG3_MST_AVALID. */
#define BM_LCDIF_DEBUG3_MST_AVALID (0x00000200U) /*!< Bit mask for LCDIF_DEBUG3_MST_AVALID. */
#define BS_LCDIF_DEBUG3_MST_AVALID (1U)    /*!< Bit field size in bits for LCDIF_DEBUG3_MST_AVALID. */

/*! @brief Read current value of the LCDIF_DEBUG3_MST_AVALID field. */
#define BR_LCDIF_DEBUG3_MST_AVALID(x) (HW_LCDIF_DEBUG3(x).B.MST_AVALID)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG3, field CUR_REQ_STATE[11:10] (RO)
 *
 * Read only view of the request state machine
 */
/*@{*/
#define BP_LCDIF_DEBUG3_CUR_REQ_STATE (10U) /*!< Bit position for LCDIF_DEBUG3_CUR_REQ_STATE. */
#define BM_LCDIF_DEBUG3_CUR_REQ_STATE (0x00000C00U) /*!< Bit mask for LCDIF_DEBUG3_CUR_REQ_STATE. */
#define BS_LCDIF_DEBUG3_CUR_REQ_STATE (2U) /*!< Bit field size in bits for LCDIF_DEBUG3_CUR_REQ_STATE. */

/*! @brief Read current value of the LCDIF_DEBUG3_CUR_REQ_STATE field. */
#define BR_LCDIF_DEBUG3_CUR_REQ_STATE(x) (HW_LCDIF_DEBUG3(x).B.CUR_REQ_STATE)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG3, field RSVD0[31:12] (RO)
 *
 * Reserved bits, write as 0.
 */
/*@{*/
#define BP_LCDIF_DEBUG3_RSVD0 (12U)        /*!< Bit position for LCDIF_DEBUG3_RSVD0. */
#define BM_LCDIF_DEBUG3_RSVD0 (0xFFFFF000U) /*!< Bit mask for LCDIF_DEBUG3_RSVD0. */
#define BS_LCDIF_DEBUG3_RSVD0 (20U)        /*!< Bit field size in bits for LCDIF_DEBUG3_RSVD0. */

/*! @brief Read current value of the LCDIF_DEBUG3_RSVD0 field. */
#define BR_LCDIF_DEBUG3_RSVD0(x) (HW_LCDIF_DEBUG3(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DEBUG4 - LCD Interface Debug4
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DEBUG4 - LCD Interface Debug4 (RO)
 *
 * Reset value: 0x00000000U
 *
 * The LCD interface debug register is for diagnostic use only.
 */
typedef union _hw_lcdif_debug4
{
    uint32_t U;
    struct _hw_lcdif_debug4_bitfields
    {
        uint32_t V_DATA_COUNT : 16;    /*!< [15:0]  */
        uint32_t H_DATA_COUNT : 16;    /*!< [31:16]  */
    } B;
} hw_lcdif_debug4_t;

/*!
 * @name Constants and macros for entire LCDIF_DEBUG4 register
 */
/*@{*/
#define HW_LCDIF_DEBUG4_ADDR(x)  ((uintptr_t)(x) + 0x280U)

#define HW_LCDIF_DEBUG4(x)       (*(__I hw_lcdif_debug4_t *) HW_LCDIF_DEBUG4_ADDR(x))
#define HW_LCDIF_DEBUG4_RD(x)    (HW_LCDIF_DEBUG4(x).U)
/*@}*/

/*
 * Constants & macros for individual LCDIF_DEBUG4 bitfields
 */

/*!
 * @name Register LCDIF_DEBUG4, field V_DATA_COUNT[15:0] (RO)
 *
 * Read only view of the current AS state of the vertical data counter.
 */
/*@{*/
#define BP_LCDIF_DEBUG4_V_DATA_COUNT (0U)  /*!< Bit position for LCDIF_DEBUG4_V_DATA_COUNT. */
#define BM_LCDIF_DEBUG4_V_DATA_COUNT (0x0000FFFFU) /*!< Bit mask for LCDIF_DEBUG4_V_DATA_COUNT. */
#define BS_LCDIF_DEBUG4_V_DATA_COUNT (16U) /*!< Bit field size in bits for LCDIF_DEBUG4_V_DATA_COUNT. */

/*! @brief Read current value of the LCDIF_DEBUG4_V_DATA_COUNT field. */
#define BR_LCDIF_DEBUG4_V_DATA_COUNT(x) (HW_LCDIF_DEBUG4(x).B.V_DATA_COUNT)
/*@}*/

/*!
 * @name Register LCDIF_DEBUG4, field H_DATA_COUNT[31:16] (RO)
 *
 * Read only view of the current AS state of the horizontal data counter.
 */
/*@{*/
#define BP_LCDIF_DEBUG4_H_DATA_COUNT (16U) /*!< Bit position for LCDIF_DEBUG4_H_DATA_COUNT. */
#define BM_LCDIF_DEBUG4_H_DATA_COUNT (0xFFFF0000U) /*!< Bit mask for LCDIF_DEBUG4_H_DATA_COUNT. */
#define BS_LCDIF_DEBUG4_H_DATA_COUNT (16U) /*!< Bit field size in bits for LCDIF_DEBUG4_H_DATA_COUNT. */

/*! @brief Read current value of the LCDIF_DEBUG4_H_DATA_COUNT field. */
#define BR_LCDIF_DEBUG4_H_DATA_COUNT(x) (HW_LCDIF_DEBUG4(x).B.H_DATA_COUNT)
/*@}*/

/*******************************************************************************
 * HW_LCDIF_DEBUG5 - LCD Interface Debug5
 ******************************************************************************/

/*!
 * @brief HW_LCDIF_DEBUG5 - LCD Interface Debug5 (RO)
 *
 * Reset value: 0x00000000U
 *
 * The LCD interface debug register is for diagnostic use only.
 */
typedef union _hw_lcdif_debug5
{
    uint32_t U;
    struct _hw_lcdif_debug5_bitfields
    {
        uint32_t MST_ADDRESS : 32;     /*!< [31:0]  */
    } B;
} hw_lcdif_debug5_t;

/*!
 * @name Constants and macros for entire LCDIF_DEBUG5 register
 */
/*@{*/
#define HW_LCDIF_DEBUG5_ADDR(x)  ((uintptr_t)(x) + 0x290U)

#define HW_LCDIF_DEBUG5(x)       (*(__I hw_lcdif_debug5_t *) HW_LCDIF_DEBUG5_ADDR(x))
#define HW_LCDIF_DEBUG5_RD(x)    (HW_LCDIF_DEBUG5(x).U)
/*@}*/

/*
 * Constants & macros for individual LCDIF_DEBUG5 bitfields
 */

/*!
 * @name Register LCDIF_DEBUG5, field MST_ADDRESS[31:0] (RO)
 *
 * Read only view of the AS channel address issued by the AXI bus master.
 */
/*@{*/
#define BP_LCDIF_DEBUG5_MST_ADDRESS (0U)   /*!< Bit position for LCDIF_DEBUG5_MST_ADDRESS. */
#define BM_LCDIF_DEBUG5_MST_ADDRESS (0xFFFFFFFFU) /*!< Bit mask for LCDIF_DEBUG5_MST_ADDRESS. */
#define BS_LCDIF_DEBUG5_MST_ADDRESS (32U)  /*!< Bit field size in bits for LCDIF_DEBUG5_MST_ADDRESS. */

/*! @brief Read current value of the LCDIF_DEBUG5_MST_ADDRESS field. */
#define BR_LCDIF_DEBUG5_MST_ADDRESS(x) (HW_LCDIF_DEBUG5(x).U)
/*@}*/

/*******************************************************************************
 * hw_lcdif_t - module struct
 ******************************************************************************/
/*!
 * @brief All LCDIF module registers.
 */
#pragma pack(1)
typedef struct _hw_lcdif
{
    __IO hw_lcdif_rl_t RL;                 /*!< [0x0] eLCDIF General Control Register */
    uint8_t _reserved0[12];
    __IO hw_lcdif_ctrl1_t CTRL1;           /*!< [0x10] eLCDIF General Control1 Register */
    uint8_t _reserved1[12];
    __IO hw_lcdif_ctrl2_t CTRL2;           /*!< [0x20] eLCDIF General Control2 Register */
    uint8_t _reserved2[12];
    __IO hw_lcdif_transfer_count_t TRANSFER_COUNT; /*!< [0x30] eLCDIF Horizontal and Vertical Valid Data Count Register */
    uint8_t _reserved3[12];
    __IO hw_lcdif_cur_buf_t CUR_BUF;       /*!< [0x40] LCD Interface Current Buffer Address Register */
    uint8_t _reserved4[12];
    __IO hw_lcdif_next_buf_t NEXT_BUF;     /*!< [0x50] LCD Interface Next Buffer Address Register */
    uint8_t _reserved5[12];
    __IO hw_lcdif_timing_t TIMING;         /*!< [0x60] LCD Interface Timing Register */
    uint8_t _reserved6[12];
    __IO hw_lcdif_vdctrl0_t VDCTRL0;       /*!< [0x70] eLCDIF VSYNC Mode and Dotclk Mode Control Register0 */
    uint8_t _reserved7[12];
    __IO hw_lcdif_vdctrl1_t VDCTRL1;       /*!< [0x80] eLCDIF VSYNC Mode and Dotclk Mode Control Register1 */
    uint8_t _reserved8[12];
    __IO hw_lcdif_vdctrl2_t VDCTRL2;       /*!< [0x90] LCDIF VSYNC Mode and Dotclk Mode Control Register2 */
    uint8_t _reserved9[12];
    __IO hw_lcdif_vdctrl3_t VDCTRL3;       /*!< [0xA0] eLCDIF VSYNC Mode and Dotclk Mode Control Register3 */
    uint8_t _reserved10[12];
    __IO hw_lcdif_vdctrl4_t VDCTRL4;       /*!< [0xB0] eLCDIF VSYNC Mode and Dotclk Mode Control Register4 */
    uint8_t _reserved11[12];
    __IO hw_lcdif_dvictrl0_t DVICTRL0;     /*!< [0xC0] Digital Video Interface Control0 Register */
    uint8_t _reserved12[12];
    __IO hw_lcdif_dvictrl1_t DVICTRL1;     /*!< [0xD0] Digital Video Interface Control1 Register */
    uint8_t _reserved13[12];
    __IO hw_lcdif_dvictrl2_t DVICTRL2;     /*!< [0xE0] Digital Video Interface Control2 Register */
    uint8_t _reserved14[12];
    __IO hw_lcdif_dvictrl3_t DVICTRL3;     /*!< [0xF0] Digital Video Interface Control3 Register */
    uint8_t _reserved15[12];
    __IO hw_lcdif_dvictrl4_t DVICTRL4;     /*!< [0x100] Digital Video Interface Control4 Register */
    uint8_t _reserved16[12];
    __IO hw_lcdif_csc_coeff0_t CSC_COEFF0; /*!< [0x110] RGB to YCbCr 4:2:2 CSC Coefficient0 Register */
    uint8_t _reserved17[12];
    __IO hw_lcdif_csc_coeff1_t CSC_COEFF1; /*!< [0x120] RGB to YCbCr 4:2:2 CSC Coefficient1 Register */
    uint8_t _reserved18[12];
    __IO hw_lcdif_csc_coeff2_t CSC_COEFF2; /*!< [0x130] RGB to YCbCr 4:2:2 CSC Coefficent2 Register */
    uint8_t _reserved19[12];
    __IO hw_lcdif_csc_coeff3_t CSC_COEFF3; /*!< [0x140] RGB to YCbCr 4:2:2 CSC Coefficient3 Register */
    uint8_t _reserved20[12];
    __IO hw_lcdif_csc_coeff4_t CSC_COEFF4; /*!< [0x150] RGB to YCbCr 4:2:2 CSC Coefficient4 Register */
    uint8_t _reserved21[12];
    __IO hw_lcdif_csc_offset_t CSC_OFFSET; /*!< [0x160] RGB to YCbCr 4:2:2 CSC Offset Register */
    uint8_t _reserved22[12];
    __IO hw_lcdif_csc_limit_t CSC_LIMIT;   /*!< [0x170] RGB to YCbCr 4:2:2 CSC Limit Register */
    uint8_t _reserved23[12];
    __IO hw_lcdif_data_t DATA;             /*!< [0x180] LCD Interface Data Register */
    uint8_t _reserved24[12];
    __IO hw_lcdif_bm_error_stat_t BM_ERROR_STAT; /*!< [0x190] Bus Master Error Status Register */
    uint8_t _reserved25[12];
    __IO hw_lcdif_crc_stat_t CRC_STAT;     /*!< [0x1A0] CRC Status Register */
    uint8_t _reserved26[12];
    __I hw_lcdif_stat_t STAT;              /*!< [0x1B0] LCD Interface Status Register */
    uint8_t _reserved27[12];
    __I hw_lcdif_version_t VERSION;        /*!< [0x1C0] LCD Interface Version Register */
    uint8_t _reserved28[12];
    __I hw_lcdif_debug0_t DEBUG0;          /*!< [0x1D0] LCD Interface Debug0 Register */
    uint8_t _reserved29[12];
    __I hw_lcdif_debug1_t DEBUG1;          /*!< [0x1E0] LCD Interface Debug1 Register */
    uint8_t _reserved30[12];
    __I hw_lcdif_debug2_t DEBUG2;          /*!< [0x1F0] LCD Interface Debug2 Register */
    uint8_t _reserved31[12];
    __IO hw_lcdif_thres_t THRES;           /*!< [0x200] eLCDIF Threshold Register */
    uint8_t _reserved32[12];
    __IO hw_lcdif_as_ctrl_t AS_CTRL;       /*!< [0x210] eLCDIF AS Buffer Control Register */
    uint8_t _reserved33[12];
    __IO hw_lcdif_as_buf_t AS_BUF;         /*!< [0x220] Alpha Surface Buffer Pointer */
    uint8_t _reserved34[12];
    __IO hw_lcdif_as_next_buf_t AS_NEXT_BUF; /*!< [0x230]  */
    uint8_t _reserved35[12];
    __IO hw_lcdif_as_clrkeylow_t AS_CLRKEYLOW; /*!< [0x240] eLCDIF Overlay Color Key Low */
    uint8_t _reserved36[12];
    __IO hw_lcdif_as_clrkeyhigh_t AS_CLRKEYHIGH; /*!< [0x250] eLCDIF Overlay Color Key High */
    uint8_t _reserved37[12];
    __IO hw_lcdif_sync_delay_t SYNC_DELAY; /*!< [0x260] LCD working insync mode with CSI for VSYNC delay */
    uint8_t _reserved38[12];
    __I hw_lcdif_debug3_t DEBUG3;          /*!< [0x270] eLCDIF Interface Debug3 Register */
    uint8_t _reserved39[12];
    __I hw_lcdif_debug4_t DEBUG4;          /*!< [0x280] LCD Interface Debug4 */
    uint8_t _reserved40[12];
    __I hw_lcdif_debug5_t DEBUG5;          /*!< [0x290] LCD Interface Debug5 */
} hw_lcdif_t;
#pragma pack()

/*! @brief Macro to access all LCDIF registers. */
/*! @param x LCDIF module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_LCDIF_REGS(LCDIF1_BASE)</code>. */
#define HW_LCDIF_REGS(x) (*(hw_lcdif_t *)(x))

/*
 * iMX7D LMEM
 *
 * Local Memory Controller
 *
 * Registers defined in this header file:
 * - HW_LMEM_PCCCR - Cache control register
 * - HW_LMEM_PCCLCR - Cache line control register
 * - HW_LMEM_PCCSAR - Cache search address register
 * - HW_LMEM_PCCCVR - Cache read/write value register
 * - HW_LMEM_PSCCR - Cache control register
 * - HW_LMEM_PSCLCR - Cache line control register
 * - HW_LMEM_PSCSAR - Cache search address register
 * - HW_LMEM_PSCCVR - Cache read/write value register
 *
 * - hw_lmem_t - Struct containing all module registers.
 */

#define HW_LMEM_INSTANCE_COUNT (1U) /*!< Number of instances of the LMEM module. */
#define HW_LMEM (0U) /*!< Instance number for LMEM. */
#define LMEM_BASE             (0xE0082000U) /*!< Base address for LMEM. */
/*! Array initializer of LMEM base addresses. */
#define LMEM_BASE_ADDRS       { LMEM_BASE }

/*******************************************************************************
 * HW_LMEM_PCCCR - Cache control register
 ******************************************************************************/

/*!
 * @brief HW_LMEM_PCCCR - Cache control register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_lmem_pcccr
{
    uint32_t U;
    struct _hw_lmem_pcccr_bitfields
    {
        uint32_t ENCACHE : 1;          /*!< [0] Cache enable */
        uint32_t ENWRBUF : 1;          /*!< [1] Enable Write Buffer */
        uint32_t PCCR2 : 1;            /*!< [2] Forces all cacheable spaces to write
                                        * through */
        uint32_t PCCR3 : 1;            /*!< [3] Forces no allocation on cache misses
                                        * (must also have ACCR2 asserted) */
        uint32_t RESERVED0 : 20;       /*!< [23:4]  */
        uint32_t INVW0 : 1;            /*!< [24] Invalidate Way 0 */
        uint32_t PUSHW0 : 1;           /*!< [25] Push Way 0 */
        uint32_t INVW1 : 1;            /*!< [26] Invalidate Way 1 */
        uint32_t PUSHW1 : 1;           /*!< [27] Push Way 1 */
        uint32_t RESERVED1 : 3;        /*!< [30:28]  */
        uint32_t GO : 1;               /*!< [31] Initiate Cache Command */
    } B;
} hw_lmem_pcccr_t;

/*!
 * @name Constants and macros for entire LMEM_PCCCR register
 */
/*@{*/
#define HW_LMEM_PCCCR_ADDR(x)    ((uintptr_t)(x) + 0x0U)

#define HW_LMEM_PCCCR(x)         (*(__IO hw_lmem_pcccr_t *) HW_LMEM_PCCCR_ADDR(x))
#define HW_LMEM_PCCCR_RD(x)      (HW_LMEM_PCCCR(x).U)
#define HW_LMEM_PCCCR_WR(x, v)   (HW_LMEM_PCCCR(x).U = (v))
#define HW_LMEM_PCCCR_SET(x, v)  (HW_LMEM_PCCCR_WR(x, HW_LMEM_PCCCR_RD(x) |  (v)))
#define HW_LMEM_PCCCR_CLR(x, v)  (HW_LMEM_PCCCR_WR(x, HW_LMEM_PCCCR_RD(x) & ~(v)))
#define HW_LMEM_PCCCR_TOG(x, v)  (HW_LMEM_PCCCR_WR(x, HW_LMEM_PCCCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LMEM_PCCCR bitfields
 */

/*!
 * @name Register LMEM_PCCCR, field ENCACHE[0] (RW)
 *
 * Values:
 * - 0 - Cache disabled
 * - 1 - Cache enabled
 */
/*@{*/
#define BP_LMEM_PCCCR_ENCACHE (0U)         /*!< Bit position for LMEM_PCCCR_ENCACHE. */
#define BM_LMEM_PCCCR_ENCACHE (0x00000001U) /*!< Bit mask for LMEM_PCCCR_ENCACHE. */
#define BS_LMEM_PCCCR_ENCACHE (1U)         /*!< Bit field size in bits for LMEM_PCCCR_ENCACHE. */

/*! @brief Read current value of the LMEM_PCCCR_ENCACHE field. */
#define BR_LMEM_PCCCR_ENCACHE(x) (HW_LMEM_PCCCR(x).B.ENCACHE)

/*! @brief Format value for bitfield LMEM_PCCCR_ENCACHE. */
#define BF_LMEM_PCCCR_ENCACHE(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCR_ENCACHE) & BM_LMEM_PCCCR_ENCACHE)

/*! @brief Set the ENCACHE field to a new value. */
#define BW_LMEM_PCCCR_ENCACHE(x, v) (HW_LMEM_PCCCR_WR(x, (HW_LMEM_PCCCR_RD(x) & ~BM_LMEM_PCCCR_ENCACHE) | BF_LMEM_PCCCR_ENCACHE(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCCR, field ENWRBUF[1] (RW)
 *
 * Values:
 * - 0 - Write buffer disabled
 * - 1 - Write buffer enabled
 */
/*@{*/
#define BP_LMEM_PCCCR_ENWRBUF (1U)         /*!< Bit position for LMEM_PCCCR_ENWRBUF. */
#define BM_LMEM_PCCCR_ENWRBUF (0x00000002U) /*!< Bit mask for LMEM_PCCCR_ENWRBUF. */
#define BS_LMEM_PCCCR_ENWRBUF (1U)         /*!< Bit field size in bits for LMEM_PCCCR_ENWRBUF. */

/*! @brief Read current value of the LMEM_PCCCR_ENWRBUF field. */
#define BR_LMEM_PCCCR_ENWRBUF(x) (HW_LMEM_PCCCR(x).B.ENWRBUF)

/*! @brief Format value for bitfield LMEM_PCCCR_ENWRBUF. */
#define BF_LMEM_PCCCR_ENWRBUF(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCR_ENWRBUF) & BM_LMEM_PCCCR_ENWRBUF)

/*! @brief Set the ENWRBUF field to a new value. */
#define BW_LMEM_PCCCR_ENWRBUF(x, v) (HW_LMEM_PCCCR_WR(x, (HW_LMEM_PCCCR_RD(x) & ~BM_LMEM_PCCCR_ENWRBUF) | BF_LMEM_PCCCR_ENWRBUF(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCCR, field PCCR2[2] (RW)
 */
/*@{*/
#define BP_LMEM_PCCCR_PCCR2  (2U)          /*!< Bit position for LMEM_PCCCR_PCCR2. */
#define BM_LMEM_PCCCR_PCCR2  (0x00000004U) /*!< Bit mask for LMEM_PCCCR_PCCR2. */
#define BS_LMEM_PCCCR_PCCR2  (1U)          /*!< Bit field size in bits for LMEM_PCCCR_PCCR2. */

/*! @brief Read current value of the LMEM_PCCCR_PCCR2 field. */
#define BR_LMEM_PCCCR_PCCR2(x) (HW_LMEM_PCCCR(x).B.PCCR2)

/*! @brief Format value for bitfield LMEM_PCCCR_PCCR2. */
#define BF_LMEM_PCCCR_PCCR2(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCR_PCCR2) & BM_LMEM_PCCCR_PCCR2)

/*! @brief Set the PCCR2 field to a new value. */
#define BW_LMEM_PCCCR_PCCR2(x, v) (HW_LMEM_PCCCR_WR(x, (HW_LMEM_PCCCR_RD(x) & ~BM_LMEM_PCCCR_PCCR2) | BF_LMEM_PCCCR_PCCR2(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCCR, field PCCR3[3] (RW)
 */
/*@{*/
#define BP_LMEM_PCCCR_PCCR3  (3U)          /*!< Bit position for LMEM_PCCCR_PCCR3. */
#define BM_LMEM_PCCCR_PCCR3  (0x00000008U) /*!< Bit mask for LMEM_PCCCR_PCCR3. */
#define BS_LMEM_PCCCR_PCCR3  (1U)          /*!< Bit field size in bits for LMEM_PCCCR_PCCR3. */

/*! @brief Read current value of the LMEM_PCCCR_PCCR3 field. */
#define BR_LMEM_PCCCR_PCCR3(x) (HW_LMEM_PCCCR(x).B.PCCR3)

/*! @brief Format value for bitfield LMEM_PCCCR_PCCR3. */
#define BF_LMEM_PCCCR_PCCR3(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCR_PCCR3) & BM_LMEM_PCCCR_PCCR3)

/*! @brief Set the PCCR3 field to a new value. */
#define BW_LMEM_PCCCR_PCCR3(x, v) (HW_LMEM_PCCCR_WR(x, (HW_LMEM_PCCCR_RD(x) & ~BM_LMEM_PCCCR_PCCR3) | BF_LMEM_PCCCR_PCCR3(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCCR, field INVW0[24] (RW)
 *
 * If the PUSHW0 and INVW0 bits are set, then after setting the GO bit, push all
 * modified lines in way 0 and invalidate all lines in way 0 (clear way 0).
 *
 * Values:
 * - 0 - No operation
 * - 1 - When setting the GO bit, invalidate all lines in way 0.
 */
/*@{*/
#define BP_LMEM_PCCCR_INVW0  (24U)         /*!< Bit position for LMEM_PCCCR_INVW0. */
#define BM_LMEM_PCCCR_INVW0  (0x01000000U) /*!< Bit mask for LMEM_PCCCR_INVW0. */
#define BS_LMEM_PCCCR_INVW0  (1U)          /*!< Bit field size in bits for LMEM_PCCCR_INVW0. */

/*! @brief Read current value of the LMEM_PCCCR_INVW0 field. */
#define BR_LMEM_PCCCR_INVW0(x) (HW_LMEM_PCCCR(x).B.INVW0)

/*! @brief Format value for bitfield LMEM_PCCCR_INVW0. */
#define BF_LMEM_PCCCR_INVW0(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCR_INVW0) & BM_LMEM_PCCCR_INVW0)

/*! @brief Set the INVW0 field to a new value. */
#define BW_LMEM_PCCCR_INVW0(x, v) (HW_LMEM_PCCCR_WR(x, (HW_LMEM_PCCCR_RD(x) & ~BM_LMEM_PCCCR_INVW0) | BF_LMEM_PCCCR_INVW0(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCCR, field PUSHW0[25] (RW)
 *
 * Values:
 * - 0 - No operation
 * - 1 - When setting the GO bit, push all modified lines in way 0
 */
/*@{*/
#define BP_LMEM_PCCCR_PUSHW0 (25U)         /*!< Bit position for LMEM_PCCCR_PUSHW0. */
#define BM_LMEM_PCCCR_PUSHW0 (0x02000000U) /*!< Bit mask for LMEM_PCCCR_PUSHW0. */
#define BS_LMEM_PCCCR_PUSHW0 (1U)          /*!< Bit field size in bits for LMEM_PCCCR_PUSHW0. */

/*! @brief Read current value of the LMEM_PCCCR_PUSHW0 field. */
#define BR_LMEM_PCCCR_PUSHW0(x) (HW_LMEM_PCCCR(x).B.PUSHW0)

/*! @brief Format value for bitfield LMEM_PCCCR_PUSHW0. */
#define BF_LMEM_PCCCR_PUSHW0(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCR_PUSHW0) & BM_LMEM_PCCCR_PUSHW0)

/*! @brief Set the PUSHW0 field to a new value. */
#define BW_LMEM_PCCCR_PUSHW0(x, v) (HW_LMEM_PCCCR_WR(x, (HW_LMEM_PCCCR_RD(x) & ~BM_LMEM_PCCCR_PUSHW0) | BF_LMEM_PCCCR_PUSHW0(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCCR, field INVW1[26] (RW)
 *
 * If the PUSHW1 and INVW1 bits are set, then after setting the GO bit, push all
 * modified lines in way 1 and invalidate all lines in way 1 (clear way 1).
 *
 * Values:
 * - 0 - No operation
 * - 1 - When setting the GO bit, invalidate all lines in way 1
 */
/*@{*/
#define BP_LMEM_PCCCR_INVW1  (26U)         /*!< Bit position for LMEM_PCCCR_INVW1. */
#define BM_LMEM_PCCCR_INVW1  (0x04000000U) /*!< Bit mask for LMEM_PCCCR_INVW1. */
#define BS_LMEM_PCCCR_INVW1  (1U)          /*!< Bit field size in bits for LMEM_PCCCR_INVW1. */

/*! @brief Read current value of the LMEM_PCCCR_INVW1 field. */
#define BR_LMEM_PCCCR_INVW1(x) (HW_LMEM_PCCCR(x).B.INVW1)

/*! @brief Format value for bitfield LMEM_PCCCR_INVW1. */
#define BF_LMEM_PCCCR_INVW1(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCR_INVW1) & BM_LMEM_PCCCR_INVW1)

/*! @brief Set the INVW1 field to a new value. */
#define BW_LMEM_PCCCR_INVW1(x, v) (HW_LMEM_PCCCR_WR(x, (HW_LMEM_PCCCR_RD(x) & ~BM_LMEM_PCCCR_INVW1) | BF_LMEM_PCCCR_INVW1(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCCR, field PUSHW1[27] (RW)
 *
 * Values:
 * - 0 - No operation
 * - 1 - When setting the GO bit, push all modified lines in way 1
 */
/*@{*/
#define BP_LMEM_PCCCR_PUSHW1 (27U)         /*!< Bit position for LMEM_PCCCR_PUSHW1. */
#define BM_LMEM_PCCCR_PUSHW1 (0x08000000U) /*!< Bit mask for LMEM_PCCCR_PUSHW1. */
#define BS_LMEM_PCCCR_PUSHW1 (1U)          /*!< Bit field size in bits for LMEM_PCCCR_PUSHW1. */

/*! @brief Read current value of the LMEM_PCCCR_PUSHW1 field. */
#define BR_LMEM_PCCCR_PUSHW1(x) (HW_LMEM_PCCCR(x).B.PUSHW1)

/*! @brief Format value for bitfield LMEM_PCCCR_PUSHW1. */
#define BF_LMEM_PCCCR_PUSHW1(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCR_PUSHW1) & BM_LMEM_PCCCR_PUSHW1)

/*! @brief Set the PUSHW1 field to a new value. */
#define BW_LMEM_PCCCR_PUSHW1(x, v) (HW_LMEM_PCCCR_WR(x, (HW_LMEM_PCCCR_RD(x) & ~BM_LMEM_PCCCR_PUSHW1) | BF_LMEM_PCCCR_PUSHW1(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCCR, field GO[31] (RW)
 *
 * Setting this bit initiates the cache command indicated by bits 27-24. Reading
 * this bit indicates if a command is active This bit stays set until the
 * command completes. Writing zero has no effect.
 *
 * Values:
 * - 0 - Write: no effect. Read: no cache command active.
 * - 1 - Write: initiate command indicated by bits 27-24. Read: cache command
 *     active.
 */
/*@{*/
#define BP_LMEM_PCCCR_GO     (31U)         /*!< Bit position for LMEM_PCCCR_GO. */
#define BM_LMEM_PCCCR_GO     (0x80000000U) /*!< Bit mask for LMEM_PCCCR_GO. */
#define BS_LMEM_PCCCR_GO     (1U)          /*!< Bit field size in bits for LMEM_PCCCR_GO. */

/*! @brief Read current value of the LMEM_PCCCR_GO field. */
#define BR_LMEM_PCCCR_GO(x)  (HW_LMEM_PCCCR(x).B.GO)

/*! @brief Format value for bitfield LMEM_PCCCR_GO. */
#define BF_LMEM_PCCCR_GO(v)  ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCR_GO) & BM_LMEM_PCCCR_GO)

/*! @brief Set the GO field to a new value. */
#define BW_LMEM_PCCCR_GO(x, v) (HW_LMEM_PCCCR_WR(x, (HW_LMEM_PCCCR_RD(x) & ~BM_LMEM_PCCCR_GO) | BF_LMEM_PCCCR_GO(v)))
/*@}*/

/*******************************************************************************
 * HW_LMEM_PCCLCR - Cache line control register
 ******************************************************************************/

/*!
 * @brief HW_LMEM_PCCLCR - Cache line control register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines specific line-sized cache operations to be performed
 * using a specific cache line address or a physical address. If a physical address
 * is specified, both ways of the cache are searched, and the command is only
 * performed on the way which hits.
 */
typedef union _hw_lmem_pcclcr
{
    uint32_t U;
    struct _hw_lmem_pcclcr_bitfields
    {
        uint32_t LGO : 1;              /*!< [0] Initiate Cache Line Command */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t CACHEADDR : 11;       /*!< [12:2] Cache address */
        uint32_t RESERVED1 : 1;        /*!< [13]  */
        uint32_t WSEL : 1;             /*!< [14] Way select */
        uint32_t RESERVED2 : 1;        /*!< [15]  */
        uint32_t TDSEL : 1;            /*!< [16] Tag/Data Select */
        uint32_t RESERVED3 : 3;        /*!< [19:17]  */
        uint32_t LCIVB : 1;            /*!< [20] Line Command Initial Valid Bit */
        uint32_t LCIMB : 1;            /*!< [21] Line Command Initial Modified Bit */
        uint32_t LCWAY : 1;            /*!< [22] Line Command Way */
        uint32_t RESERVED4 : 1;        /*!< [23]  */
        uint32_t LCMD : 2;             /*!< [25:24] Line Command */
        uint32_t LADSEL : 1;           /*!< [26] Line Address Select */
        uint32_t LACC : 1;             /*!< [27] Line access type */
        uint32_t RESERVED5 : 4;        /*!< [31:28]  */
    } B;
} hw_lmem_pcclcr_t;

/*!
 * @name Constants and macros for entire LMEM_PCCLCR register
 */
/*@{*/
#define HW_LMEM_PCCLCR_ADDR(x)   ((uintptr_t)(x) + 0x4U)

#define HW_LMEM_PCCLCR(x)        (*(__IO hw_lmem_pcclcr_t *) HW_LMEM_PCCLCR_ADDR(x))
#define HW_LMEM_PCCLCR_RD(x)     (HW_LMEM_PCCLCR(x).U)
#define HW_LMEM_PCCLCR_WR(x, v)  (HW_LMEM_PCCLCR(x).U = (v))
#define HW_LMEM_PCCLCR_SET(x, v) (HW_LMEM_PCCLCR_WR(x, HW_LMEM_PCCLCR_RD(x) |  (v)))
#define HW_LMEM_PCCLCR_CLR(x, v) (HW_LMEM_PCCLCR_WR(x, HW_LMEM_PCCLCR_RD(x) & ~(v)))
#define HW_LMEM_PCCLCR_TOG(x, v) (HW_LMEM_PCCLCR_WR(x, HW_LMEM_PCCLCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LMEM_PCCLCR bitfields
 */

/*!
 * @name Register LMEM_PCCLCR, field LGO[0] (RW)
 *
 * Setting this bit initiates the cache line command indicated by bits 27-24.
 * Reading this bit indicates if a line command is active This bit stays set until
 * the command completes. Writing zero has no effect. This bit is shared with
 * CSAR[LGO]
 *
 * Values:
 * - 0 - Write: no effect. Read: no line command active.
 * - 1 - Write: initiate line command indicated by bits 27-24. Read: line
 *     command active.
 */
/*@{*/
#define BP_LMEM_PCCLCR_LGO   (0U)          /*!< Bit position for LMEM_PCCLCR_LGO. */
#define BM_LMEM_PCCLCR_LGO   (0x00000001U) /*!< Bit mask for LMEM_PCCLCR_LGO. */
#define BS_LMEM_PCCLCR_LGO   (1U)          /*!< Bit field size in bits for LMEM_PCCLCR_LGO. */

/*! @brief Read current value of the LMEM_PCCLCR_LGO field. */
#define BR_LMEM_PCCLCR_LGO(x) (HW_LMEM_PCCLCR(x).B.LGO)

/*! @brief Format value for bitfield LMEM_PCCLCR_LGO. */
#define BF_LMEM_PCCLCR_LGO(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCLCR_LGO) & BM_LMEM_PCCLCR_LGO)

/*! @brief Set the LGO field to a new value. */
#define BW_LMEM_PCCLCR_LGO(x, v) (HW_LMEM_PCCLCR_WR(x, (HW_LMEM_PCCLCR_RD(x) & ~BM_LMEM_PCCLCR_LGO) | BF_LMEM_PCCLCR_LGO(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCLCR, field CACHEADDR[12:2] (RW)
 *
 * CLCR[11:4] bits are used to access the tag arrays CLCR[11:2] bits are used to
 * access the data arrays
 */
/*@{*/
#define BP_LMEM_PCCLCR_CACHEADDR (2U)      /*!< Bit position for LMEM_PCCLCR_CACHEADDR. */
#define BM_LMEM_PCCLCR_CACHEADDR (0x00001FFCU) /*!< Bit mask for LMEM_PCCLCR_CACHEADDR. */
#define BS_LMEM_PCCLCR_CACHEADDR (11U)     /*!< Bit field size in bits for LMEM_PCCLCR_CACHEADDR. */

/*! @brief Read current value of the LMEM_PCCLCR_CACHEADDR field. */
#define BR_LMEM_PCCLCR_CACHEADDR(x) (HW_LMEM_PCCLCR(x).B.CACHEADDR)

/*! @brief Format value for bitfield LMEM_PCCLCR_CACHEADDR. */
#define BF_LMEM_PCCLCR_CACHEADDR(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCLCR_CACHEADDR) & BM_LMEM_PCCLCR_CACHEADDR)

/*! @brief Set the CACHEADDR field to a new value. */
#define BW_LMEM_PCCLCR_CACHEADDR(x, v) (HW_LMEM_PCCLCR_WR(x, (HW_LMEM_PCCLCR_RD(x) & ~BM_LMEM_PCCLCR_CACHEADDR) | BF_LMEM_PCCLCR_CACHEADDR(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCLCR, field WSEL[14] (RW)
 *
 * Selects the way for line commands.
 *
 * Values:
 * - 0 - Way 0
 * - 1 - Way 1
 */
/*@{*/
#define BP_LMEM_PCCLCR_WSEL  (14U)         /*!< Bit position for LMEM_PCCLCR_WSEL. */
#define BM_LMEM_PCCLCR_WSEL  (0x00004000U) /*!< Bit mask for LMEM_PCCLCR_WSEL. */
#define BS_LMEM_PCCLCR_WSEL  (1U)          /*!< Bit field size in bits for LMEM_PCCLCR_WSEL. */

/*! @brief Read current value of the LMEM_PCCLCR_WSEL field. */
#define BR_LMEM_PCCLCR_WSEL(x) (HW_LMEM_PCCLCR(x).B.WSEL)

/*! @brief Format value for bitfield LMEM_PCCLCR_WSEL. */
#define BF_LMEM_PCCLCR_WSEL(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCLCR_WSEL) & BM_LMEM_PCCLCR_WSEL)

/*! @brief Set the WSEL field to a new value. */
#define BW_LMEM_PCCLCR_WSEL(x, v) (HW_LMEM_PCCLCR_WR(x, (HW_LMEM_PCCLCR_RD(x) & ~BM_LMEM_PCCLCR_WSEL) | BF_LMEM_PCCLCR_WSEL(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCLCR, field TDSEL[16] (RW)
 *
 * Selects tag or data for search and read or write commands.
 *
 * Values:
 * - 0 - Data
 * - 1 - Tag
 */
/*@{*/
#define BP_LMEM_PCCLCR_TDSEL (16U)         /*!< Bit position for LMEM_PCCLCR_TDSEL. */
#define BM_LMEM_PCCLCR_TDSEL (0x00010000U) /*!< Bit mask for LMEM_PCCLCR_TDSEL. */
#define BS_LMEM_PCCLCR_TDSEL (1U)          /*!< Bit field size in bits for LMEM_PCCLCR_TDSEL. */

/*! @brief Read current value of the LMEM_PCCLCR_TDSEL field. */
#define BR_LMEM_PCCLCR_TDSEL(x) (HW_LMEM_PCCLCR(x).B.TDSEL)

/*! @brief Format value for bitfield LMEM_PCCLCR_TDSEL. */
#define BF_LMEM_PCCLCR_TDSEL(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCLCR_TDSEL) & BM_LMEM_PCCLCR_TDSEL)

/*! @brief Set the TDSEL field to a new value. */
#define BW_LMEM_PCCLCR_TDSEL(x, v) (HW_LMEM_PCCLCR_WR(x, (HW_LMEM_PCCLCR_RD(x) & ~BM_LMEM_PCCLCR_TDSEL) | BF_LMEM_PCCLCR_TDSEL(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCLCR, field LCIVB[20] (RO)
 *
 * If command used cache address and way, then this bit shows the initial state
 * of the valid bit If command used physical address and a hit, then this bit
 * shows the initial state of the valid bit. If a miss, this bit reads zero.
 */
/*@{*/
#define BP_LMEM_PCCLCR_LCIVB (20U)         /*!< Bit position for LMEM_PCCLCR_LCIVB. */
#define BM_LMEM_PCCLCR_LCIVB (0x00100000U) /*!< Bit mask for LMEM_PCCLCR_LCIVB. */
#define BS_LMEM_PCCLCR_LCIVB (1U)          /*!< Bit field size in bits for LMEM_PCCLCR_LCIVB. */

/*! @brief Read current value of the LMEM_PCCLCR_LCIVB field. */
#define BR_LMEM_PCCLCR_LCIVB(x) (HW_LMEM_PCCLCR(x).B.LCIVB)
/*@}*/

/*!
 * @name Register LMEM_PCCLCR, field LCIMB[21] (RO)
 *
 * If command used cache address and way, then this bit shows the initial state
 * of the modified bit If command used physical address and a hit, then this bit
 * shows the initial state of the modified bit. If a miss, this bit reads zero.
 */
/*@{*/
#define BP_LMEM_PCCLCR_LCIMB (21U)         /*!< Bit position for LMEM_PCCLCR_LCIMB. */
#define BM_LMEM_PCCLCR_LCIMB (0x00200000U) /*!< Bit mask for LMEM_PCCLCR_LCIMB. */
#define BS_LMEM_PCCLCR_LCIMB (1U)          /*!< Bit field size in bits for LMEM_PCCLCR_LCIMB. */

/*! @brief Read current value of the LMEM_PCCLCR_LCIMB field. */
#define BR_LMEM_PCCLCR_LCIMB(x) (HW_LMEM_PCCLCR(x).B.LCIMB)
/*@}*/

/*!
 * @name Register LMEM_PCCLCR, field LCWAY[22] (RO)
 *
 * Indicates the way used by the line command.
 */
/*@{*/
#define BP_LMEM_PCCLCR_LCWAY (22U)         /*!< Bit position for LMEM_PCCLCR_LCWAY. */
#define BM_LMEM_PCCLCR_LCWAY (0x00400000U) /*!< Bit mask for LMEM_PCCLCR_LCWAY. */
#define BS_LMEM_PCCLCR_LCWAY (1U)          /*!< Bit field size in bits for LMEM_PCCLCR_LCWAY. */

/*! @brief Read current value of the LMEM_PCCLCR_LCWAY field. */
#define BR_LMEM_PCCLCR_LCWAY(x) (HW_LMEM_PCCLCR(x).B.LCWAY)
/*@}*/

/*!
 * @name Register LMEM_PCCLCR, field LCMD[25:24] (RW)
 *
 * Values:
 * - 00 - Search and read or write
 * - 01 - Invalidate
 * - 10 - Push
 * - 11 - Clear
 */
/*@{*/
#define BP_LMEM_PCCLCR_LCMD  (24U)         /*!< Bit position for LMEM_PCCLCR_LCMD. */
#define BM_LMEM_PCCLCR_LCMD  (0x03000000U) /*!< Bit mask for LMEM_PCCLCR_LCMD. */
#define BS_LMEM_PCCLCR_LCMD  (2U)          /*!< Bit field size in bits for LMEM_PCCLCR_LCMD. */

/*! @brief Read current value of the LMEM_PCCLCR_LCMD field. */
#define BR_LMEM_PCCLCR_LCMD(x) (HW_LMEM_PCCLCR(x).B.LCMD)

/*! @brief Format value for bitfield LMEM_PCCLCR_LCMD. */
#define BF_LMEM_PCCLCR_LCMD(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCLCR_LCMD) & BM_LMEM_PCCLCR_LCMD)

/*! @brief Set the LCMD field to a new value. */
#define BW_LMEM_PCCLCR_LCMD(x, v) (HW_LMEM_PCCLCR_WR(x, (HW_LMEM_PCCLCR_RD(x) & ~BM_LMEM_PCCLCR_LCMD) | BF_LMEM_PCCLCR_LCMD(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCLCR, field LADSEL[26] (RW)
 *
 * When using the cache address, the way must also be specified in CLCR[WSEL].
 * When using the physical address, both ways are searched and the command is
 * performed only if a hit.
 *
 * Values:
 * - 0 - Cache address
 * - 1 - Physical address
 */
/*@{*/
#define BP_LMEM_PCCLCR_LADSEL (26U)        /*!< Bit position for LMEM_PCCLCR_LADSEL. */
#define BM_LMEM_PCCLCR_LADSEL (0x04000000U) /*!< Bit mask for LMEM_PCCLCR_LADSEL. */
#define BS_LMEM_PCCLCR_LADSEL (1U)         /*!< Bit field size in bits for LMEM_PCCLCR_LADSEL. */

/*! @brief Read current value of the LMEM_PCCLCR_LADSEL field. */
#define BR_LMEM_PCCLCR_LADSEL(x) (HW_LMEM_PCCLCR(x).B.LADSEL)

/*! @brief Format value for bitfield LMEM_PCCLCR_LADSEL. */
#define BF_LMEM_PCCLCR_LADSEL(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCLCR_LADSEL) & BM_LMEM_PCCLCR_LADSEL)

/*! @brief Set the LADSEL field to a new value. */
#define BW_LMEM_PCCLCR_LADSEL(x, v) (HW_LMEM_PCCLCR_WR(x, (HW_LMEM_PCCLCR_RD(x) & ~BM_LMEM_PCCLCR_LADSEL) | BF_LMEM_PCCLCR_LADSEL(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCLCR, field LACC[27] (RW)
 *
 * Values:
 * - 0 - Read
 * - 1 - Write
 */
/*@{*/
#define BP_LMEM_PCCLCR_LACC  (27U)         /*!< Bit position for LMEM_PCCLCR_LACC. */
#define BM_LMEM_PCCLCR_LACC  (0x08000000U) /*!< Bit mask for LMEM_PCCLCR_LACC. */
#define BS_LMEM_PCCLCR_LACC  (1U)          /*!< Bit field size in bits for LMEM_PCCLCR_LACC. */

/*! @brief Read current value of the LMEM_PCCLCR_LACC field. */
#define BR_LMEM_PCCLCR_LACC(x) (HW_LMEM_PCCLCR(x).B.LACC)

/*! @brief Format value for bitfield LMEM_PCCLCR_LACC. */
#define BF_LMEM_PCCLCR_LACC(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCLCR_LACC) & BM_LMEM_PCCLCR_LACC)

/*! @brief Set the LACC field to a new value. */
#define BW_LMEM_PCCLCR_LACC(x, v) (HW_LMEM_PCCLCR_WR(x, (HW_LMEM_PCCLCR_RD(x) & ~BM_LMEM_PCCLCR_LACC) | BF_LMEM_PCCLCR_LACC(v)))
/*@}*/

/*******************************************************************************
 * HW_LMEM_PCCSAR - Cache search address register
 ******************************************************************************/

/*!
 * @brief HW_LMEM_PCCSAR - Cache search address register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The CSAR register is used to define the explicit cache address or the
 * physical address for line-sized commands specified in the CLCR[LADSEL] bit.
 */
typedef union _hw_lmem_pccsar
{
    uint32_t U;
    struct _hw_lmem_pccsar_bitfields
    {
        uint32_t LGO : 1;              /*!< [0] Initiate Cache Line Command */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t PHYADDR : 30;         /*!< [31:2] Physical Address */
    } B;
} hw_lmem_pccsar_t;

/*!
 * @name Constants and macros for entire LMEM_PCCSAR register
 */
/*@{*/
#define HW_LMEM_PCCSAR_ADDR(x)   ((uintptr_t)(x) + 0x8U)

#define HW_LMEM_PCCSAR(x)        (*(__IO hw_lmem_pccsar_t *) HW_LMEM_PCCSAR_ADDR(x))
#define HW_LMEM_PCCSAR_RD(x)     (HW_LMEM_PCCSAR(x).U)
#define HW_LMEM_PCCSAR_WR(x, v)  (HW_LMEM_PCCSAR(x).U = (v))
#define HW_LMEM_PCCSAR_SET(x, v) (HW_LMEM_PCCSAR_WR(x, HW_LMEM_PCCSAR_RD(x) |  (v)))
#define HW_LMEM_PCCSAR_CLR(x, v) (HW_LMEM_PCCSAR_WR(x, HW_LMEM_PCCSAR_RD(x) & ~(v)))
#define HW_LMEM_PCCSAR_TOG(x, v) (HW_LMEM_PCCSAR_WR(x, HW_LMEM_PCCSAR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LMEM_PCCSAR bitfields
 */

/*!
 * @name Register LMEM_PCCSAR, field LGO[0] (RW)
 *
 * Setting this bit initiates the cache line command indicated by bits 27-24.
 * Reading this bit indicates if a line command is active This bit stays set until
 * the command completes. Writing zero has no effect. This bit is shared with
 * CLCR[LGO]
 *
 * Values:
 * - 0 - Write: no effect. Read: no line command active.
 * - 1 - Write: initiate line command indicated by bits CLCR[27:24]. Read: line
 *     command active.
 */
/*@{*/
#define BP_LMEM_PCCSAR_LGO   (0U)          /*!< Bit position for LMEM_PCCSAR_LGO. */
#define BM_LMEM_PCCSAR_LGO   (0x00000001U) /*!< Bit mask for LMEM_PCCSAR_LGO. */
#define BS_LMEM_PCCSAR_LGO   (1U)          /*!< Bit field size in bits for LMEM_PCCSAR_LGO. */

/*! @brief Read current value of the LMEM_PCCSAR_LGO field. */
#define BR_LMEM_PCCSAR_LGO(x) (HW_LMEM_PCCSAR(x).B.LGO)

/*! @brief Format value for bitfield LMEM_PCCSAR_LGO. */
#define BF_LMEM_PCCSAR_LGO(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCSAR_LGO) & BM_LMEM_PCCSAR_LGO)

/*! @brief Set the LGO field to a new value. */
#define BW_LMEM_PCCSAR_LGO(x, v) (HW_LMEM_PCCSAR_WR(x, (HW_LMEM_PCCSAR_RD(x) & ~BM_LMEM_PCCSAR_LGO) | BF_LMEM_PCCSAR_LGO(v)))
/*@}*/

/*!
 * @name Register LMEM_PCCSAR, field PHYADDR[31:2] (RW)
 *
 * PHYADDR represents bits [31:2] of the system address. CSAR[31:12] bits are
 * used for tag compare CSAR[11:4] bits are used to access the tag arrays
 * CSAR[11:2] bits are used to access the data arrays
 */
/*@{*/
#define BP_LMEM_PCCSAR_PHYADDR (2U)        /*!< Bit position for LMEM_PCCSAR_PHYADDR. */
#define BM_LMEM_PCCSAR_PHYADDR (0xFFFFFFFCU) /*!< Bit mask for LMEM_PCCSAR_PHYADDR. */
#define BS_LMEM_PCCSAR_PHYADDR (30U)       /*!< Bit field size in bits for LMEM_PCCSAR_PHYADDR. */

/*! @brief Read current value of the LMEM_PCCSAR_PHYADDR field. */
#define BR_LMEM_PCCSAR_PHYADDR(x) (HW_LMEM_PCCSAR(x).B.PHYADDR)

/*! @brief Format value for bitfield LMEM_PCCSAR_PHYADDR. */
#define BF_LMEM_PCCSAR_PHYADDR(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCSAR_PHYADDR) & BM_LMEM_PCCSAR_PHYADDR)

/*! @brief Set the PHYADDR field to a new value. */
#define BW_LMEM_PCCSAR_PHYADDR(x, v) (HW_LMEM_PCCSAR_WR(x, (HW_LMEM_PCCSAR_RD(x) & ~BM_LMEM_PCCSAR_PHYADDR) | BF_LMEM_PCCSAR_PHYADDR(v)))
/*@}*/

/*******************************************************************************
 * HW_LMEM_PCCCVR - Cache read/write value register
 ******************************************************************************/

/*!
 * @brief HW_LMEM_PCCCVR - Cache read/write value register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The CCVR register is used to source write data or return read data for the
 * commands specified in the CLCR register.
 */
typedef union _hw_lmem_pcccvr
{
    uint32_t U;
    struct _hw_lmem_pcccvr_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0] Cache read/write Data */
    } B;
} hw_lmem_pcccvr_t;

/*!
 * @name Constants and macros for entire LMEM_PCCCVR register
 */
/*@{*/
#define HW_LMEM_PCCCVR_ADDR(x)   ((uintptr_t)(x) + 0xCU)

#define HW_LMEM_PCCCVR(x)        (*(__IO hw_lmem_pcccvr_t *) HW_LMEM_PCCCVR_ADDR(x))
#define HW_LMEM_PCCCVR_RD(x)     (HW_LMEM_PCCCVR(x).U)
#define HW_LMEM_PCCCVR_WR(x, v)  (HW_LMEM_PCCCVR(x).U = (v))
#define HW_LMEM_PCCCVR_SET(x, v) (HW_LMEM_PCCCVR_WR(x, HW_LMEM_PCCCVR_RD(x) |  (v)))
#define HW_LMEM_PCCCVR_CLR(x, v) (HW_LMEM_PCCCVR_WR(x, HW_LMEM_PCCCVR_RD(x) & ~(v)))
#define HW_LMEM_PCCCVR_TOG(x, v) (HW_LMEM_PCCCVR_WR(x, HW_LMEM_PCCCVR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LMEM_PCCCVR bitfields
 */

/*!
 * @name Register LMEM_PCCCVR, field DATA[31:0] (RW)
 *
 * For tag search, read or write: CCVR[31:12] bits are used for tag array R/W
 * value CCVR[11:4] bits are used for tag set address on reads; unused on writes
 * CCVR[3:2] bits are reserved For data search, read or write: CCVR[31:0] bits are
 * used for data array R/W value
 */
/*@{*/
#define BP_LMEM_PCCCVR_DATA  (0U)          /*!< Bit position for LMEM_PCCCVR_DATA. */
#define BM_LMEM_PCCCVR_DATA  (0xFFFFFFFFU) /*!< Bit mask for LMEM_PCCCVR_DATA. */
#define BS_LMEM_PCCCVR_DATA  (32U)         /*!< Bit field size in bits for LMEM_PCCCVR_DATA. */

/*! @brief Read current value of the LMEM_PCCCVR_DATA field. */
#define BR_LMEM_PCCCVR_DATA(x) (HW_LMEM_PCCCVR(x).U)

/*! @brief Format value for bitfield LMEM_PCCCVR_DATA. */
#define BF_LMEM_PCCCVR_DATA(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PCCCVR_DATA) & BM_LMEM_PCCCVR_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_LMEM_PCCCVR_DATA(x, v) (HW_LMEM_PCCCVR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_LMEM_PSCCR - Cache control register
 ******************************************************************************/

/*!
 * @brief HW_LMEM_PSCCR - Cache control register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_lmem_psccr
{
    uint32_t U;
    struct _hw_lmem_psccr_bitfields
    {
        uint32_t ENCACHE : 1;          /*!< [0] Cache enable */
        uint32_t ENWRBUF : 1;          /*!< [1] Enable Write Buffer */
        uint32_t RESERVED0 : 22;       /*!< [23:2]  */
        uint32_t INVW0 : 1;            /*!< [24] Invalidate Way 0 */
        uint32_t PUSHW0 : 1;           /*!< [25] Push Way 0 */
        uint32_t INVW1 : 1;            /*!< [26] Invalidate Way 1 */
        uint32_t PUSHW1 : 1;           /*!< [27] Push Way 1 */
        uint32_t RESERVED1 : 3;        /*!< [30:28]  */
        uint32_t GO : 1;               /*!< [31] Initiate Cache Command */
    } B;
} hw_lmem_psccr_t;

/*!
 * @name Constants and macros for entire LMEM_PSCCR register
 */
/*@{*/
#define HW_LMEM_PSCCR_ADDR(x)    ((uintptr_t)(x) + 0x800U)

#define HW_LMEM_PSCCR(x)         (*(__IO hw_lmem_psccr_t *) HW_LMEM_PSCCR_ADDR(x))
#define HW_LMEM_PSCCR_RD(x)      (HW_LMEM_PSCCR(x).U)
#define HW_LMEM_PSCCR_WR(x, v)   (HW_LMEM_PSCCR(x).U = (v))
#define HW_LMEM_PSCCR_SET(x, v)  (HW_LMEM_PSCCR_WR(x, HW_LMEM_PSCCR_RD(x) |  (v)))
#define HW_LMEM_PSCCR_CLR(x, v)  (HW_LMEM_PSCCR_WR(x, HW_LMEM_PSCCR_RD(x) & ~(v)))
#define HW_LMEM_PSCCR_TOG(x, v)  (HW_LMEM_PSCCR_WR(x, HW_LMEM_PSCCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LMEM_PSCCR bitfields
 */

/*!
 * @name Register LMEM_PSCCR, field ENCACHE[0] (RW)
 *
 * Values:
 * - 0 - Cache disabled
 * - 1 - Cache enabled
 */
/*@{*/
#define BP_LMEM_PSCCR_ENCACHE (0U)         /*!< Bit position for LMEM_PSCCR_ENCACHE. */
#define BM_LMEM_PSCCR_ENCACHE (0x00000001U) /*!< Bit mask for LMEM_PSCCR_ENCACHE. */
#define BS_LMEM_PSCCR_ENCACHE (1U)         /*!< Bit field size in bits for LMEM_PSCCR_ENCACHE. */

/*! @brief Read current value of the LMEM_PSCCR_ENCACHE field. */
#define BR_LMEM_PSCCR_ENCACHE(x) (HW_LMEM_PSCCR(x).B.ENCACHE)

/*! @brief Format value for bitfield LMEM_PSCCR_ENCACHE. */
#define BF_LMEM_PSCCR_ENCACHE(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCCR_ENCACHE) & BM_LMEM_PSCCR_ENCACHE)

/*! @brief Set the ENCACHE field to a new value. */
#define BW_LMEM_PSCCR_ENCACHE(x, v) (HW_LMEM_PSCCR_WR(x, (HW_LMEM_PSCCR_RD(x) & ~BM_LMEM_PSCCR_ENCACHE) | BF_LMEM_PSCCR_ENCACHE(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCCR, field ENWRBUF[1] (RW)
 *
 * Values:
 * - 0 - Write buffer disabled
 * - 1 - Write buffer enabled
 */
/*@{*/
#define BP_LMEM_PSCCR_ENWRBUF (1U)         /*!< Bit position for LMEM_PSCCR_ENWRBUF. */
#define BM_LMEM_PSCCR_ENWRBUF (0x00000002U) /*!< Bit mask for LMEM_PSCCR_ENWRBUF. */
#define BS_LMEM_PSCCR_ENWRBUF (1U)         /*!< Bit field size in bits for LMEM_PSCCR_ENWRBUF. */

/*! @brief Read current value of the LMEM_PSCCR_ENWRBUF field. */
#define BR_LMEM_PSCCR_ENWRBUF(x) (HW_LMEM_PSCCR(x).B.ENWRBUF)

/*! @brief Format value for bitfield LMEM_PSCCR_ENWRBUF. */
#define BF_LMEM_PSCCR_ENWRBUF(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCCR_ENWRBUF) & BM_LMEM_PSCCR_ENWRBUF)

/*! @brief Set the ENWRBUF field to a new value. */
#define BW_LMEM_PSCCR_ENWRBUF(x, v) (HW_LMEM_PSCCR_WR(x, (HW_LMEM_PSCCR_RD(x) & ~BM_LMEM_PSCCR_ENWRBUF) | BF_LMEM_PSCCR_ENWRBUF(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCCR, field INVW0[24] (RW)
 *
 * If the PUSHW0 and INVW0 bits are set, then after setting the GO bit, push all
 * modified lines in way 0 and invalidate all lines in way 0 (clear way 0).
 *
 * Values:
 * - 0 - No operation
 * - 1 - When setting the GO bit, invalidate all lines in way 0.
 */
/*@{*/
#define BP_LMEM_PSCCR_INVW0  (24U)         /*!< Bit position for LMEM_PSCCR_INVW0. */
#define BM_LMEM_PSCCR_INVW0  (0x01000000U) /*!< Bit mask for LMEM_PSCCR_INVW0. */
#define BS_LMEM_PSCCR_INVW0  (1U)          /*!< Bit field size in bits for LMEM_PSCCR_INVW0. */

/*! @brief Read current value of the LMEM_PSCCR_INVW0 field. */
#define BR_LMEM_PSCCR_INVW0(x) (HW_LMEM_PSCCR(x).B.INVW0)

/*! @brief Format value for bitfield LMEM_PSCCR_INVW0. */
#define BF_LMEM_PSCCR_INVW0(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCCR_INVW0) & BM_LMEM_PSCCR_INVW0)

/*! @brief Set the INVW0 field to a new value. */
#define BW_LMEM_PSCCR_INVW0(x, v) (HW_LMEM_PSCCR_WR(x, (HW_LMEM_PSCCR_RD(x) & ~BM_LMEM_PSCCR_INVW0) | BF_LMEM_PSCCR_INVW0(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCCR, field PUSHW0[25] (RW)
 *
 * Values:
 * - 0 - No operation
 * - 1 - When setting the GO bit, push all modified lines in way 0
 */
/*@{*/
#define BP_LMEM_PSCCR_PUSHW0 (25U)         /*!< Bit position for LMEM_PSCCR_PUSHW0. */
#define BM_LMEM_PSCCR_PUSHW0 (0x02000000U) /*!< Bit mask for LMEM_PSCCR_PUSHW0. */
#define BS_LMEM_PSCCR_PUSHW0 (1U)          /*!< Bit field size in bits for LMEM_PSCCR_PUSHW0. */

/*! @brief Read current value of the LMEM_PSCCR_PUSHW0 field. */
#define BR_LMEM_PSCCR_PUSHW0(x) (HW_LMEM_PSCCR(x).B.PUSHW0)

/*! @brief Format value for bitfield LMEM_PSCCR_PUSHW0. */
#define BF_LMEM_PSCCR_PUSHW0(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCCR_PUSHW0) & BM_LMEM_PSCCR_PUSHW0)

/*! @brief Set the PUSHW0 field to a new value. */
#define BW_LMEM_PSCCR_PUSHW0(x, v) (HW_LMEM_PSCCR_WR(x, (HW_LMEM_PSCCR_RD(x) & ~BM_LMEM_PSCCR_PUSHW0) | BF_LMEM_PSCCR_PUSHW0(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCCR, field INVW1[26] (RW)
 *
 * If the PUSHW1 and INVW1 bits are set, then after setting the GO bit, push all
 * modified lines in way 1 and invalidate all lines in way 1 (clear way 1).
 *
 * Values:
 * - 0 - No operation
 * - 1 - When setting the GO bit, invalidate all lines in way 1
 */
/*@{*/
#define BP_LMEM_PSCCR_INVW1  (26U)         /*!< Bit position for LMEM_PSCCR_INVW1. */
#define BM_LMEM_PSCCR_INVW1  (0x04000000U) /*!< Bit mask for LMEM_PSCCR_INVW1. */
#define BS_LMEM_PSCCR_INVW1  (1U)          /*!< Bit field size in bits for LMEM_PSCCR_INVW1. */

/*! @brief Read current value of the LMEM_PSCCR_INVW1 field. */
#define BR_LMEM_PSCCR_INVW1(x) (HW_LMEM_PSCCR(x).B.INVW1)

/*! @brief Format value for bitfield LMEM_PSCCR_INVW1. */
#define BF_LMEM_PSCCR_INVW1(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCCR_INVW1) & BM_LMEM_PSCCR_INVW1)

/*! @brief Set the INVW1 field to a new value. */
#define BW_LMEM_PSCCR_INVW1(x, v) (HW_LMEM_PSCCR_WR(x, (HW_LMEM_PSCCR_RD(x) & ~BM_LMEM_PSCCR_INVW1) | BF_LMEM_PSCCR_INVW1(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCCR, field PUSHW1[27] (RW)
 *
 * Values:
 * - 0 - No operation
 * - 1 - When setting the GO bit, push all modified lines in way 1
 */
/*@{*/
#define BP_LMEM_PSCCR_PUSHW1 (27U)         /*!< Bit position for LMEM_PSCCR_PUSHW1. */
#define BM_LMEM_PSCCR_PUSHW1 (0x08000000U) /*!< Bit mask for LMEM_PSCCR_PUSHW1. */
#define BS_LMEM_PSCCR_PUSHW1 (1U)          /*!< Bit field size in bits for LMEM_PSCCR_PUSHW1. */

/*! @brief Read current value of the LMEM_PSCCR_PUSHW1 field. */
#define BR_LMEM_PSCCR_PUSHW1(x) (HW_LMEM_PSCCR(x).B.PUSHW1)

/*! @brief Format value for bitfield LMEM_PSCCR_PUSHW1. */
#define BF_LMEM_PSCCR_PUSHW1(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCCR_PUSHW1) & BM_LMEM_PSCCR_PUSHW1)

/*! @brief Set the PUSHW1 field to a new value. */
#define BW_LMEM_PSCCR_PUSHW1(x, v) (HW_LMEM_PSCCR_WR(x, (HW_LMEM_PSCCR_RD(x) & ~BM_LMEM_PSCCR_PUSHW1) | BF_LMEM_PSCCR_PUSHW1(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCCR, field GO[31] (RW)
 *
 * Setting this bit initiates the cache command indicated by bits 27-24. Reading
 * this bit indicates if a command is active This bit stays set until the
 * command completes. Writing zero has no effect.
 *
 * Values:
 * - 0 - Write: no effect. Read: no cache command active.
 * - 1 - Write: initiate command indicated by bits 27-24. Read: cache command
 *     active.
 */
/*@{*/
#define BP_LMEM_PSCCR_GO     (31U)         /*!< Bit position for LMEM_PSCCR_GO. */
#define BM_LMEM_PSCCR_GO     (0x80000000U) /*!< Bit mask for LMEM_PSCCR_GO. */
#define BS_LMEM_PSCCR_GO     (1U)          /*!< Bit field size in bits for LMEM_PSCCR_GO. */

/*! @brief Read current value of the LMEM_PSCCR_GO field. */
#define BR_LMEM_PSCCR_GO(x)  (HW_LMEM_PSCCR(x).B.GO)

/*! @brief Format value for bitfield LMEM_PSCCR_GO. */
#define BF_LMEM_PSCCR_GO(v)  ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCCR_GO) & BM_LMEM_PSCCR_GO)

/*! @brief Set the GO field to a new value. */
#define BW_LMEM_PSCCR_GO(x, v) (HW_LMEM_PSCCR_WR(x, (HW_LMEM_PSCCR_RD(x) & ~BM_LMEM_PSCCR_GO) | BF_LMEM_PSCCR_GO(v)))
/*@}*/

/*******************************************************************************
 * HW_LMEM_PSCLCR - Cache line control register
 ******************************************************************************/

/*!
 * @brief HW_LMEM_PSCLCR - Cache line control register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines specific line-sized cache operations to be performed
 * using a specific cache line address or a physical address. If a physical address
 * is specified, both ways of the cache are searched, and the command is only
 * performed on the way which hits.
 */
typedef union _hw_lmem_psclcr
{
    uint32_t U;
    struct _hw_lmem_psclcr_bitfields
    {
        uint32_t LGO : 1;              /*!< [0] Initiate Cache Line Command */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t CACHEADDR : 11;       /*!< [12:2] Cache address */
        uint32_t RESERVED1 : 1;        /*!< [13]  */
        uint32_t WSEL : 1;             /*!< [14] Way select */
        uint32_t RESERVED2 : 1;        /*!< [15]  */
        uint32_t TDSEL : 1;            /*!< [16] Tag/Data Select */
        uint32_t RESERVED3 : 3;        /*!< [19:17]  */
        uint32_t LCIVB : 1;            /*!< [20] Line Command Initial Valid Bit */
        uint32_t LCIMB : 1;            /*!< [21] Line Command Initial Modified Bit */
        uint32_t LCWAY : 1;            /*!< [22] Line Command Way */
        uint32_t RESERVED4 : 1;        /*!< [23]  */
        uint32_t LCMD : 2;             /*!< [25:24] Line Command */
        uint32_t LADSEL : 1;           /*!< [26] Line Address Select */
        uint32_t LACC : 1;             /*!< [27] Line access type */
        uint32_t RESERVED5 : 4;        /*!< [31:28]  */
    } B;
} hw_lmem_psclcr_t;

/*!
 * @name Constants and macros for entire LMEM_PSCLCR register
 */
/*@{*/
#define HW_LMEM_PSCLCR_ADDR(x)   ((uintptr_t)(x) + 0x804U)

#define HW_LMEM_PSCLCR(x)        (*(__IO hw_lmem_psclcr_t *) HW_LMEM_PSCLCR_ADDR(x))
#define HW_LMEM_PSCLCR_RD(x)     (HW_LMEM_PSCLCR(x).U)
#define HW_LMEM_PSCLCR_WR(x, v)  (HW_LMEM_PSCLCR(x).U = (v))
#define HW_LMEM_PSCLCR_SET(x, v) (HW_LMEM_PSCLCR_WR(x, HW_LMEM_PSCLCR_RD(x) |  (v)))
#define HW_LMEM_PSCLCR_CLR(x, v) (HW_LMEM_PSCLCR_WR(x, HW_LMEM_PSCLCR_RD(x) & ~(v)))
#define HW_LMEM_PSCLCR_TOG(x, v) (HW_LMEM_PSCLCR_WR(x, HW_LMEM_PSCLCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LMEM_PSCLCR bitfields
 */

/*!
 * @name Register LMEM_PSCLCR, field LGO[0] (RW)
 *
 * Setting this bit initiates the cache line command indicated by bits 27-24.
 * Reading this bit indicates if a line command is active This bit stays set until
 * the command completes. Writing zero has no effect. This bit is shared with
 * CSAR[LGO]
 *
 * Values:
 * - 0 - Write: no effect. Read: no line command active.
 * - 1 - Write: initiate line command indicated by bits 27-24. Read: line
 *     command active.
 */
/*@{*/
#define BP_LMEM_PSCLCR_LGO   (0U)          /*!< Bit position for LMEM_PSCLCR_LGO. */
#define BM_LMEM_PSCLCR_LGO   (0x00000001U) /*!< Bit mask for LMEM_PSCLCR_LGO. */
#define BS_LMEM_PSCLCR_LGO   (1U)          /*!< Bit field size in bits for LMEM_PSCLCR_LGO. */

/*! @brief Read current value of the LMEM_PSCLCR_LGO field. */
#define BR_LMEM_PSCLCR_LGO(x) (HW_LMEM_PSCLCR(x).B.LGO)

/*! @brief Format value for bitfield LMEM_PSCLCR_LGO. */
#define BF_LMEM_PSCLCR_LGO(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCLCR_LGO) & BM_LMEM_PSCLCR_LGO)

/*! @brief Set the LGO field to a new value. */
#define BW_LMEM_PSCLCR_LGO(x, v) (HW_LMEM_PSCLCR_WR(x, (HW_LMEM_PSCLCR_RD(x) & ~BM_LMEM_PSCLCR_LGO) | BF_LMEM_PSCLCR_LGO(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCLCR, field CACHEADDR[12:2] (RW)
 *
 * CLCR[11:4] bits are used to access the tag arrays CLCR[11:2] bits are used to
 * access the data arrays
 */
/*@{*/
#define BP_LMEM_PSCLCR_CACHEADDR (2U)      /*!< Bit position for LMEM_PSCLCR_CACHEADDR. */
#define BM_LMEM_PSCLCR_CACHEADDR (0x00001FFCU) /*!< Bit mask for LMEM_PSCLCR_CACHEADDR. */
#define BS_LMEM_PSCLCR_CACHEADDR (11U)     /*!< Bit field size in bits for LMEM_PSCLCR_CACHEADDR. */

/*! @brief Read current value of the LMEM_PSCLCR_CACHEADDR field. */
#define BR_LMEM_PSCLCR_CACHEADDR(x) (HW_LMEM_PSCLCR(x).B.CACHEADDR)

/*! @brief Format value for bitfield LMEM_PSCLCR_CACHEADDR. */
#define BF_LMEM_PSCLCR_CACHEADDR(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCLCR_CACHEADDR) & BM_LMEM_PSCLCR_CACHEADDR)

/*! @brief Set the CACHEADDR field to a new value. */
#define BW_LMEM_PSCLCR_CACHEADDR(x, v) (HW_LMEM_PSCLCR_WR(x, (HW_LMEM_PSCLCR_RD(x) & ~BM_LMEM_PSCLCR_CACHEADDR) | BF_LMEM_PSCLCR_CACHEADDR(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCLCR, field WSEL[14] (RW)
 *
 * Selects the way for line commands.
 *
 * Values:
 * - 0 - Way 0
 * - 1 - Way 1
 */
/*@{*/
#define BP_LMEM_PSCLCR_WSEL  (14U)         /*!< Bit position for LMEM_PSCLCR_WSEL. */
#define BM_LMEM_PSCLCR_WSEL  (0x00004000U) /*!< Bit mask for LMEM_PSCLCR_WSEL. */
#define BS_LMEM_PSCLCR_WSEL  (1U)          /*!< Bit field size in bits for LMEM_PSCLCR_WSEL. */

/*! @brief Read current value of the LMEM_PSCLCR_WSEL field. */
#define BR_LMEM_PSCLCR_WSEL(x) (HW_LMEM_PSCLCR(x).B.WSEL)

/*! @brief Format value for bitfield LMEM_PSCLCR_WSEL. */
#define BF_LMEM_PSCLCR_WSEL(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCLCR_WSEL) & BM_LMEM_PSCLCR_WSEL)

/*! @brief Set the WSEL field to a new value. */
#define BW_LMEM_PSCLCR_WSEL(x, v) (HW_LMEM_PSCLCR_WR(x, (HW_LMEM_PSCLCR_RD(x) & ~BM_LMEM_PSCLCR_WSEL) | BF_LMEM_PSCLCR_WSEL(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCLCR, field TDSEL[16] (RW)
 *
 * Selects tag or data for search and read or write commands.
 *
 * Values:
 * - 0 - Data
 * - 1 - Tag
 */
/*@{*/
#define BP_LMEM_PSCLCR_TDSEL (16U)         /*!< Bit position for LMEM_PSCLCR_TDSEL. */
#define BM_LMEM_PSCLCR_TDSEL (0x00010000U) /*!< Bit mask for LMEM_PSCLCR_TDSEL. */
#define BS_LMEM_PSCLCR_TDSEL (1U)          /*!< Bit field size in bits for LMEM_PSCLCR_TDSEL. */

/*! @brief Read current value of the LMEM_PSCLCR_TDSEL field. */
#define BR_LMEM_PSCLCR_TDSEL(x) (HW_LMEM_PSCLCR(x).B.TDSEL)

/*! @brief Format value for bitfield LMEM_PSCLCR_TDSEL. */
#define BF_LMEM_PSCLCR_TDSEL(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCLCR_TDSEL) & BM_LMEM_PSCLCR_TDSEL)

/*! @brief Set the TDSEL field to a new value. */
#define BW_LMEM_PSCLCR_TDSEL(x, v) (HW_LMEM_PSCLCR_WR(x, (HW_LMEM_PSCLCR_RD(x) & ~BM_LMEM_PSCLCR_TDSEL) | BF_LMEM_PSCLCR_TDSEL(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCLCR, field LCIVB[20] (RO)
 *
 * If command used cache address and way, then this bit shows the initial state
 * of the valid bit If command used physical address and a hit, then this bit
 * shows the initial state of the valid bit. If a miss, this bit reads zero.
 */
/*@{*/
#define BP_LMEM_PSCLCR_LCIVB (20U)         /*!< Bit position for LMEM_PSCLCR_LCIVB. */
#define BM_LMEM_PSCLCR_LCIVB (0x00100000U) /*!< Bit mask for LMEM_PSCLCR_LCIVB. */
#define BS_LMEM_PSCLCR_LCIVB (1U)          /*!< Bit field size in bits for LMEM_PSCLCR_LCIVB. */

/*! @brief Read current value of the LMEM_PSCLCR_LCIVB field. */
#define BR_LMEM_PSCLCR_LCIVB(x) (HW_LMEM_PSCLCR(x).B.LCIVB)
/*@}*/

/*!
 * @name Register LMEM_PSCLCR, field LCIMB[21] (RO)
 *
 * If command used cache address and way, then this bit shows the initial state
 * of the modified bit If command used physical address and a hit, then this bit
 * shows the initial state of the modified bit. If a miss, this bit reads zero.
 */
/*@{*/
#define BP_LMEM_PSCLCR_LCIMB (21U)         /*!< Bit position for LMEM_PSCLCR_LCIMB. */
#define BM_LMEM_PSCLCR_LCIMB (0x00200000U) /*!< Bit mask for LMEM_PSCLCR_LCIMB. */
#define BS_LMEM_PSCLCR_LCIMB (1U)          /*!< Bit field size in bits for LMEM_PSCLCR_LCIMB. */

/*! @brief Read current value of the LMEM_PSCLCR_LCIMB field. */
#define BR_LMEM_PSCLCR_LCIMB(x) (HW_LMEM_PSCLCR(x).B.LCIMB)
/*@}*/

/*!
 * @name Register LMEM_PSCLCR, field LCWAY[22] (RO)
 *
 * Indicates the way used by the line command.
 */
/*@{*/
#define BP_LMEM_PSCLCR_LCWAY (22U)         /*!< Bit position for LMEM_PSCLCR_LCWAY. */
#define BM_LMEM_PSCLCR_LCWAY (0x00400000U) /*!< Bit mask for LMEM_PSCLCR_LCWAY. */
#define BS_LMEM_PSCLCR_LCWAY (1U)          /*!< Bit field size in bits for LMEM_PSCLCR_LCWAY. */

/*! @brief Read current value of the LMEM_PSCLCR_LCWAY field. */
#define BR_LMEM_PSCLCR_LCWAY(x) (HW_LMEM_PSCLCR(x).B.LCWAY)
/*@}*/

/*!
 * @name Register LMEM_PSCLCR, field LCMD[25:24] (RW)
 *
 * Values:
 * - 00 - Search and read or write
 * - 01 - Invalidate
 * - 10 - Push
 * - 11 - Clear
 */
/*@{*/
#define BP_LMEM_PSCLCR_LCMD  (24U)         /*!< Bit position for LMEM_PSCLCR_LCMD. */
#define BM_LMEM_PSCLCR_LCMD  (0x03000000U) /*!< Bit mask for LMEM_PSCLCR_LCMD. */
#define BS_LMEM_PSCLCR_LCMD  (2U)          /*!< Bit field size in bits for LMEM_PSCLCR_LCMD. */

/*! @brief Read current value of the LMEM_PSCLCR_LCMD field. */
#define BR_LMEM_PSCLCR_LCMD(x) (HW_LMEM_PSCLCR(x).B.LCMD)

/*! @brief Format value for bitfield LMEM_PSCLCR_LCMD. */
#define BF_LMEM_PSCLCR_LCMD(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCLCR_LCMD) & BM_LMEM_PSCLCR_LCMD)

/*! @brief Set the LCMD field to a new value. */
#define BW_LMEM_PSCLCR_LCMD(x, v) (HW_LMEM_PSCLCR_WR(x, (HW_LMEM_PSCLCR_RD(x) & ~BM_LMEM_PSCLCR_LCMD) | BF_LMEM_PSCLCR_LCMD(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCLCR, field LADSEL[26] (RW)
 *
 * When using the cache address, the way must also be specified in CLCR[WSEL].
 * When using the physical address, both ways are searched and the command is
 * performed only if a hit.
 *
 * Values:
 * - 0 - Cache address
 * - 1 - Physical address
 */
/*@{*/
#define BP_LMEM_PSCLCR_LADSEL (26U)        /*!< Bit position for LMEM_PSCLCR_LADSEL. */
#define BM_LMEM_PSCLCR_LADSEL (0x04000000U) /*!< Bit mask for LMEM_PSCLCR_LADSEL. */
#define BS_LMEM_PSCLCR_LADSEL (1U)         /*!< Bit field size in bits for LMEM_PSCLCR_LADSEL. */

/*! @brief Read current value of the LMEM_PSCLCR_LADSEL field. */
#define BR_LMEM_PSCLCR_LADSEL(x) (HW_LMEM_PSCLCR(x).B.LADSEL)

/*! @brief Format value for bitfield LMEM_PSCLCR_LADSEL. */
#define BF_LMEM_PSCLCR_LADSEL(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCLCR_LADSEL) & BM_LMEM_PSCLCR_LADSEL)

/*! @brief Set the LADSEL field to a new value. */
#define BW_LMEM_PSCLCR_LADSEL(x, v) (HW_LMEM_PSCLCR_WR(x, (HW_LMEM_PSCLCR_RD(x) & ~BM_LMEM_PSCLCR_LADSEL) | BF_LMEM_PSCLCR_LADSEL(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCLCR, field LACC[27] (RW)
 *
 * Values:
 * - 0 - Read
 * - 1 - Write
 */
/*@{*/
#define BP_LMEM_PSCLCR_LACC  (27U)         /*!< Bit position for LMEM_PSCLCR_LACC. */
#define BM_LMEM_PSCLCR_LACC  (0x08000000U) /*!< Bit mask for LMEM_PSCLCR_LACC. */
#define BS_LMEM_PSCLCR_LACC  (1U)          /*!< Bit field size in bits for LMEM_PSCLCR_LACC. */

/*! @brief Read current value of the LMEM_PSCLCR_LACC field. */
#define BR_LMEM_PSCLCR_LACC(x) (HW_LMEM_PSCLCR(x).B.LACC)

/*! @brief Format value for bitfield LMEM_PSCLCR_LACC. */
#define BF_LMEM_PSCLCR_LACC(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCLCR_LACC) & BM_LMEM_PSCLCR_LACC)

/*! @brief Set the LACC field to a new value. */
#define BW_LMEM_PSCLCR_LACC(x, v) (HW_LMEM_PSCLCR_WR(x, (HW_LMEM_PSCLCR_RD(x) & ~BM_LMEM_PSCLCR_LACC) | BF_LMEM_PSCLCR_LACC(v)))
/*@}*/

/*******************************************************************************
 * HW_LMEM_PSCSAR - Cache search address register
 ******************************************************************************/

/*!
 * @brief HW_LMEM_PSCSAR - Cache search address register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The CSAR register is used to define the explicit cache address or the
 * physical address for line-sized commands specified in the CLCR[LADSEL] bit.
 */
typedef union _hw_lmem_pscsar
{
    uint32_t U;
    struct _hw_lmem_pscsar_bitfields
    {
        uint32_t LGO : 1;              /*!< [0] Initiate Cache Line Command */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t PHYADDR : 30;         /*!< [31:2] Physical Address */
    } B;
} hw_lmem_pscsar_t;

/*!
 * @name Constants and macros for entire LMEM_PSCSAR register
 */
/*@{*/
#define HW_LMEM_PSCSAR_ADDR(x)   ((uintptr_t)(x) + 0x808U)

#define HW_LMEM_PSCSAR(x)        (*(__IO hw_lmem_pscsar_t *) HW_LMEM_PSCSAR_ADDR(x))
#define HW_LMEM_PSCSAR_RD(x)     (HW_LMEM_PSCSAR(x).U)
#define HW_LMEM_PSCSAR_WR(x, v)  (HW_LMEM_PSCSAR(x).U = (v))
#define HW_LMEM_PSCSAR_SET(x, v) (HW_LMEM_PSCSAR_WR(x, HW_LMEM_PSCSAR_RD(x) |  (v)))
#define HW_LMEM_PSCSAR_CLR(x, v) (HW_LMEM_PSCSAR_WR(x, HW_LMEM_PSCSAR_RD(x) & ~(v)))
#define HW_LMEM_PSCSAR_TOG(x, v) (HW_LMEM_PSCSAR_WR(x, HW_LMEM_PSCSAR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LMEM_PSCSAR bitfields
 */

/*!
 * @name Register LMEM_PSCSAR, field LGO[0] (RW)
 *
 * Setting this bit initiates the cache line command indicated by bits 27-24.
 * Reading this bit indicates if a line command is active This bit stays set until
 * the command completes. Writing zero has no effect. This bit is shared with
 * CLCR[LGO]
 *
 * Values:
 * - 0 - Write: no effect. Read: no line command active.
 * - 1 - Write: initiate line command indicated by bits CLCR[27:24]. Read: line
 *     command active.
 */
/*@{*/
#define BP_LMEM_PSCSAR_LGO   (0U)          /*!< Bit position for LMEM_PSCSAR_LGO. */
#define BM_LMEM_PSCSAR_LGO   (0x00000001U) /*!< Bit mask for LMEM_PSCSAR_LGO. */
#define BS_LMEM_PSCSAR_LGO   (1U)          /*!< Bit field size in bits for LMEM_PSCSAR_LGO. */

/*! @brief Read current value of the LMEM_PSCSAR_LGO field. */
#define BR_LMEM_PSCSAR_LGO(x) (HW_LMEM_PSCSAR(x).B.LGO)

/*! @brief Format value for bitfield LMEM_PSCSAR_LGO. */
#define BF_LMEM_PSCSAR_LGO(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCSAR_LGO) & BM_LMEM_PSCSAR_LGO)

/*! @brief Set the LGO field to a new value. */
#define BW_LMEM_PSCSAR_LGO(x, v) (HW_LMEM_PSCSAR_WR(x, (HW_LMEM_PSCSAR_RD(x) & ~BM_LMEM_PSCSAR_LGO) | BF_LMEM_PSCSAR_LGO(v)))
/*@}*/

/*!
 * @name Register LMEM_PSCSAR, field PHYADDR[31:2] (RW)
 *
 * PHYADDR represents bits [31:2] of the system address. CSAR[31:12] bits are
 * used for tag compare CSAR[11:4] bits are used to access the tag arrays
 * CSAR[11:2] bits are used to access the data arrays
 */
/*@{*/
#define BP_LMEM_PSCSAR_PHYADDR (2U)        /*!< Bit position for LMEM_PSCSAR_PHYADDR. */
#define BM_LMEM_PSCSAR_PHYADDR (0xFFFFFFFCU) /*!< Bit mask for LMEM_PSCSAR_PHYADDR. */
#define BS_LMEM_PSCSAR_PHYADDR (30U)       /*!< Bit field size in bits for LMEM_PSCSAR_PHYADDR. */

/*! @brief Read current value of the LMEM_PSCSAR_PHYADDR field. */
#define BR_LMEM_PSCSAR_PHYADDR(x) (HW_LMEM_PSCSAR(x).B.PHYADDR)

/*! @brief Format value for bitfield LMEM_PSCSAR_PHYADDR. */
#define BF_LMEM_PSCSAR_PHYADDR(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCSAR_PHYADDR) & BM_LMEM_PSCSAR_PHYADDR)

/*! @brief Set the PHYADDR field to a new value. */
#define BW_LMEM_PSCSAR_PHYADDR(x, v) (HW_LMEM_PSCSAR_WR(x, (HW_LMEM_PSCSAR_RD(x) & ~BM_LMEM_PSCSAR_PHYADDR) | BF_LMEM_PSCSAR_PHYADDR(v)))
/*@}*/

/*******************************************************************************
 * HW_LMEM_PSCCVR - Cache read/write value register
 ******************************************************************************/

/*!
 * @brief HW_LMEM_PSCCVR - Cache read/write value register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The CCVR register is used to source write data or return read data for the
 * commands specified in the CLCR register.
 */
typedef union _hw_lmem_psccvr
{
    uint32_t U;
    struct _hw_lmem_psccvr_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0] Cache read/write Data */
    } B;
} hw_lmem_psccvr_t;

/*!
 * @name Constants and macros for entire LMEM_PSCCVR register
 */
/*@{*/
#define HW_LMEM_PSCCVR_ADDR(x)   ((uintptr_t)(x) + 0x80CU)

#define HW_LMEM_PSCCVR(x)        (*(__IO hw_lmem_psccvr_t *) HW_LMEM_PSCCVR_ADDR(x))
#define HW_LMEM_PSCCVR_RD(x)     (HW_LMEM_PSCCVR(x).U)
#define HW_LMEM_PSCCVR_WR(x, v)  (HW_LMEM_PSCCVR(x).U = (v))
#define HW_LMEM_PSCCVR_SET(x, v) (HW_LMEM_PSCCVR_WR(x, HW_LMEM_PSCCVR_RD(x) |  (v)))
#define HW_LMEM_PSCCVR_CLR(x, v) (HW_LMEM_PSCCVR_WR(x, HW_LMEM_PSCCVR_RD(x) & ~(v)))
#define HW_LMEM_PSCCVR_TOG(x, v) (HW_LMEM_PSCCVR_WR(x, HW_LMEM_PSCCVR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual LMEM_PSCCVR bitfields
 */

/*!
 * @name Register LMEM_PSCCVR, field DATA[31:0] (RW)
 *
 * For tag search, read or write: CCVR[31:12] bits are used for tag array R/W
 * value CCVR[11:4] bits are used for tag set address on reads; unused on writes
 * CCVR[3:2] bits are reserved For data search, read or write: CCVR[31:0] bits are
 * used for data array R/W value
 */
/*@{*/
#define BP_LMEM_PSCCVR_DATA  (0U)          /*!< Bit position for LMEM_PSCCVR_DATA. */
#define BM_LMEM_PSCCVR_DATA  (0xFFFFFFFFU) /*!< Bit mask for LMEM_PSCCVR_DATA. */
#define BS_LMEM_PSCCVR_DATA  (32U)         /*!< Bit field size in bits for LMEM_PSCCVR_DATA. */

/*! @brief Read current value of the LMEM_PSCCVR_DATA field. */
#define BR_LMEM_PSCCVR_DATA(x) (HW_LMEM_PSCCVR(x).U)

/*! @brief Format value for bitfield LMEM_PSCCVR_DATA. */
#define BF_LMEM_PSCCVR_DATA(v) ((uint32_t)((uint32_t)(v) << BP_LMEM_PSCCVR_DATA) & BM_LMEM_PSCCVR_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_LMEM_PSCCVR_DATA(x, v) (HW_LMEM_PSCCVR_WR(x, v))
/*@}*/

/*******************************************************************************
 * hw_lmem_t - module struct
 ******************************************************************************/
/*!
 * @brief All LMEM module registers.
 */
#pragma pack(1)
typedef struct _hw_lmem
{
    __IO hw_lmem_pcccr_t PCCCR;            /*!< [0x0] Cache control register */
    __IO hw_lmem_pcclcr_t PCCLCR;          /*!< [0x4] Cache line control register */
    __IO hw_lmem_pccsar_t PCCSAR;          /*!< [0x8] Cache search address register */
    __IO hw_lmem_pcccvr_t PCCCVR;          /*!< [0xC] Cache read/write value register */
    uint8_t _reserved0[2032];
    __IO hw_lmem_psccr_t PSCCR;            /*!< [0x800] Cache control register */
    __IO hw_lmem_psclcr_t PSCLCR;          /*!< [0x804] Cache line control register */
    __IO hw_lmem_pscsar_t PSCSAR;          /*!< [0x808] Cache search address register */
    __IO hw_lmem_psccvr_t PSCCVR;          /*!< [0x80C] Cache read/write value register */
} hw_lmem_t;
#pragma pack()

/*! @brief Macro to access all LMEM registers. */
/*! @param x LMEM module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_LMEM_REGS(LMEM_BASE)</code>. */
#define HW_LMEM_REGS(x) (*(hw_lmem_t *)(x))

/*
 * iMX7D MCM
 *
 * Core Platform Miscellaneous Control Module
 *
 * Registers defined in this header file:
 * - HW_MCM_PLASC - Crossbar Switch (AXBS) Slave Configuration
 * - HW_MCM_PLAMC - Crossbar Switch (AXBS) Master Configuration
 * - HW_MCM_PLACR - Crossbar Switch (AXBS) Control Register
 * - HW_MCM_FADR - Fault address register
 * - HW_MCM_FATR - Fault attributes register
 * - HW_MCM_FDR - Fault data register
 *
 * - hw_mcm_t - Struct containing all module registers.
 */

#define HW_MCM_INSTANCE_COUNT (1U) /*!< Number of instances of the MCM module. */
#define HW_MCM (0U) /*!< Instance number for MCM. */
#define MCM_BASE              (0xE0080000U) /*!< Base address for MCM. */
/*! Array initializer of MCM base addresses. */
#define MCM_BASE_ADDRS        { MCM_BASE }

/*******************************************************************************
 * HW_MCM_PLASC - Crossbar Switch (AXBS) Slave Configuration
 ******************************************************************************/

/*!
 * @brief HW_MCM_PLASC - Crossbar Switch (AXBS) Slave Configuration (RO)
 *
 * Reset value: 0x0002U
 *
 * PLASC is a 16-bit read-only register identifying the presence/absence of bus
 * slave connections to the device's crossbar switch.
 */
typedef union _hw_mcm_plasc
{
    uint16_t U;
    struct _hw_mcm_plasc_bitfields
    {
        uint16_t ASC : 8;              /*!< [7:0] Each bit in the ASC field indicates
                                        * whether there is a corresponding connection to the crossbar switch's slave
                                        * input port. */
        uint16_t RESERVED0 : 8;        /*!< [15:8]  */
    } B;
} hw_mcm_plasc_t;

/*!
 * @name Constants and macros for entire MCM_PLASC register
 */
/*@{*/
#define HW_MCM_PLASC_ADDR(x)     ((uintptr_t)(x) + 0x8U)

#define HW_MCM_PLASC(x)          (*(__I hw_mcm_plasc_t *) HW_MCM_PLASC_ADDR(x))
#define HW_MCM_PLASC_RD(x)       (HW_MCM_PLASC(x).U)
/*@}*/

/*
 * Constants & macros for individual MCM_PLASC bitfields
 */

/*!
 * @name Register MCM_PLASC, field ASC[7:0] (RO)
 *
 * Values:
 * - 0 - A bus slave connection to AXBS input port n is absent
 * - 1 - A bus slave connection to AXBS input port n is present
 */
/*@{*/
#define BP_MCM_PLASC_ASC     (0U)          /*!< Bit position for MCM_PLASC_ASC. */
#define BM_MCM_PLASC_ASC     (0x00FFU)     /*!< Bit mask for MCM_PLASC_ASC. */
#define BS_MCM_PLASC_ASC     (8U)          /*!< Bit field size in bits for MCM_PLASC_ASC. */

/*! @brief Read current value of the MCM_PLASC_ASC field. */
#define BR_MCM_PLASC_ASC(x)  (HW_MCM_PLASC(x).B.ASC)
/*@}*/

/*******************************************************************************
 * HW_MCM_PLAMC - Crossbar Switch (AXBS) Master Configuration
 ******************************************************************************/

/*!
 * @brief HW_MCM_PLAMC - Crossbar Switch (AXBS) Master Configuration (RO)
 *
 * Reset value: 0x0003U
 *
 * PLAMC is a 16-bit read-only register identifying the presence/absence of bus
 * master connections to the device's crossbar switch.
 */
typedef union _hw_mcm_plamc
{
    uint16_t U;
    struct _hw_mcm_plamc_bitfields
    {
        uint16_t AMC : 8;              /*!< [7:0] Each bit in the AMC field indicates
                                        * whether there is a corresponding connection to the AXBS master input port. */
        uint16_t RESERVED0 : 8;        /*!< [15:8]  */
    } B;
} hw_mcm_plamc_t;

/*!
 * @name Constants and macros for entire MCM_PLAMC register
 */
/*@{*/
#define HW_MCM_PLAMC_ADDR(x)     ((uintptr_t)(x) + 0xAU)

#define HW_MCM_PLAMC(x)          (*(__I hw_mcm_plamc_t *) HW_MCM_PLAMC_ADDR(x))
#define HW_MCM_PLAMC_RD(x)       (HW_MCM_PLAMC(x).U)
/*@}*/

/*
 * Constants & macros for individual MCM_PLAMC bitfields
 */

/*!
 * @name Register MCM_PLAMC, field AMC[7:0] (RO)
 *
 * Values:
 * - 0 - A bus master connection to AXBS input port n is absent
 * - 1 - A bus master connection to AXBS input port n is present
 */
/*@{*/
#define BP_MCM_PLAMC_AMC     (0U)          /*!< Bit position for MCM_PLAMC_AMC. */
#define BM_MCM_PLAMC_AMC     (0x00FFU)     /*!< Bit mask for MCM_PLAMC_AMC. */
#define BS_MCM_PLAMC_AMC     (8U)          /*!< Bit field size in bits for MCM_PLAMC_AMC. */

/*! @brief Read current value of the MCM_PLAMC_AMC field. */
#define BR_MCM_PLAMC_AMC(x)  (HW_MCM_PLAMC(x).B.AMC)
/*@}*/

/*******************************************************************************
 * HW_MCM_PLACR - Crossbar Switch (AXBS) Control Register
 ******************************************************************************/

/*!
 * @brief HW_MCM_PLACR - Crossbar Switch (AXBS) Control Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The PLACR register selects the arbitration policy for the crossbar masters.
 */
typedef union _hw_mcm_placr
{
    uint32_t U;
    struct _hw_mcm_placr_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_mcm_placr_t;

/*!
 * @name Constants and macros for entire MCM_PLACR register
 */
/*@{*/
#define HW_MCM_PLACR_ADDR(x)     ((uintptr_t)(x) + 0xCU)

#define HW_MCM_PLACR(x)          (*(__I hw_mcm_placr_t *) HW_MCM_PLACR_ADDR(x))
#define HW_MCM_PLACR_RD(x)       (HW_MCM_PLACR(x).U)
/*@}*/

/*
 * Constants & macros for individual MCM_PLACR bitfields
 */

/*******************************************************************************
 * HW_MCM_FADR - Fault address register
 ******************************************************************************/

/*!
 * @brief HW_MCM_FADR - Fault address register (RO)
 *
 * Reset value: 0x00000000U
 *
 * When a properly-enabled cache write buffer error interrupt event is detected,
 * the faulting address is captured in the MCM_FADR register. The MCM logic
 * supports capturing a single cache write buffer bus error event; if a subsequent
 * error is detected before the captured error information has been read from the
 * corresponding registers and the MCM_ISCR[CWBER] indicator cleared, the
 * MCM_FATR[BEOVR] flag is set. However, no additional information is captured. The bits
 * in this register are set by hardware and signaled by the assertion of
 * MCM_ISCR[CWBER]. Attempted writes to this location are terminated with an error.
 */
typedef union _hw_mcm_fadr
{
    uint32_t U;
    struct _hw_mcm_fadr_bitfields
    {
        uint32_t ADDRESS : 32;         /*!< [31:0] Fault address */
    } B;
} hw_mcm_fadr_t;

/*!
 * @name Constants and macros for entire MCM_FADR register
 */
/*@{*/
#define HW_MCM_FADR_ADDR(x)      ((uintptr_t)(x) + 0x20U)

#define HW_MCM_FADR(x)           (*(__I hw_mcm_fadr_t *) HW_MCM_FADR_ADDR(x))
#define HW_MCM_FADR_RD(x)        (HW_MCM_FADR(x).U)
/*@}*/

/*
 * Constants & macros for individual MCM_FADR bitfields
 */

/*!
 * @name Register MCM_FADR, field ADDRESS[31:0] (RO)
 */
/*@{*/
#define BP_MCM_FADR_ADDRESS  (0U)          /*!< Bit position for MCM_FADR_ADDRESS. */
#define BM_MCM_FADR_ADDRESS  (0xFFFFFFFFU) /*!< Bit mask for MCM_FADR_ADDRESS. */
#define BS_MCM_FADR_ADDRESS  (32U)         /*!< Bit field size in bits for MCM_FADR_ADDRESS. */

/*! @brief Read current value of the MCM_FADR_ADDRESS field. */
#define BR_MCM_FADR_ADDRESS(x) (HW_MCM_FADR(x).U)
/*@}*/

/*******************************************************************************
 * HW_MCM_FATR - Fault attributes register
 ******************************************************************************/

/*!
 * @brief HW_MCM_FATR - Fault attributes register (RO)
 *
 * Reset value: 0x00000000U
 *
 * When a properly-enabled cache write buffer error interrupt event is detected,
 * the faulting attributes are captured in the MCM_FATR register. The bits in
 * this register are set by hardware and signaled by the assertion of
 * MCM_ISCR[CWBER]. Attempted writes to this location are terminated with an error.
 */
typedef union _hw_mcm_fatr
{
    uint32_t U;
    struct _hw_mcm_fatr_bitfields
    {
        uint32_t BEDA : 1;             /*!< [0] Bus error access type */
        uint32_t BEMD : 1;             /*!< [1] Bus error privilege level */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t BESZ : 2;             /*!< [5:4] Bus error size */
        uint32_t RESERVED1 : 1;        /*!< [6]  */
        uint32_t BEWT : 1;             /*!< [7] Bus error write */
        uint32_t BEMN : 4;             /*!< [11:8] Bus error master number */
        uint32_t RESERVED2 : 19;       /*!< [30:12]  */
        uint32_t BEOVR : 1;            /*!< [31] Bus error overrun */
    } B;
} hw_mcm_fatr_t;

/*!
 * @name Constants and macros for entire MCM_FATR register
 */
/*@{*/
#define HW_MCM_FATR_ADDR(x)      ((uintptr_t)(x) + 0x24U)

#define HW_MCM_FATR(x)           (*(__I hw_mcm_fatr_t *) HW_MCM_FATR_ADDR(x))
#define HW_MCM_FATR_RD(x)        (HW_MCM_FATR(x).U)
/*@}*/

/*
 * Constants & macros for individual MCM_FATR bitfields
 */

/*!
 * @name Register MCM_FATR, field BEDA[0] (RO)
 *
 * Indicates the type of cache write buffer access when the error was detected.
 * This attribute is always a logical one signaling a data reference.
 *
 * Values:
 * - 0 - Instruction
 * - 1 - Data
 */
/*@{*/
#define BP_MCM_FATR_BEDA     (0U)          /*!< Bit position for MCM_FATR_BEDA. */
#define BM_MCM_FATR_BEDA     (0x00000001U) /*!< Bit mask for MCM_FATR_BEDA. */
#define BS_MCM_FATR_BEDA     (1U)          /*!< Bit field size in bits for MCM_FATR_BEDA. */

/*! @brief Read current value of the MCM_FATR_BEDA field. */
#define BR_MCM_FATR_BEDA(x)  (HW_MCM_FATR(x).B.BEDA)
/*@}*/

/*!
 * @name Register MCM_FATR, field BEMD[1] (RO)
 *
 * Indicates the privilege level of the cache write buffer access when the error
 * was detected.
 *
 * Values:
 * - 0 - User mode
 * - 1 - Supervisor/privileged mode
 */
/*@{*/
#define BP_MCM_FATR_BEMD     (1U)          /*!< Bit position for MCM_FATR_BEMD. */
#define BM_MCM_FATR_BEMD     (0x00000002U) /*!< Bit mask for MCM_FATR_BEMD. */
#define BS_MCM_FATR_BEMD     (1U)          /*!< Bit field size in bits for MCM_FATR_BEMD. */

/*! @brief Read current value of the MCM_FATR_BEMD field. */
#define BR_MCM_FATR_BEMD(x)  (HW_MCM_FATR(x).B.BEMD)
/*@}*/

/*!
 * @name Register MCM_FATR, field BESZ[5:4] (RO)
 *
 * Indicates the size of the cache write buffer access when the error was
 * detected.
 *
 * Values:
 * - 00 - 8-bit access
 * - 01 - 16-bit access
 * - 10 - 32-bit access
 * - 11 - Reserved
 */
/*@{*/
#define BP_MCM_FATR_BESZ     (4U)          /*!< Bit position for MCM_FATR_BESZ. */
#define BM_MCM_FATR_BESZ     (0x00000030U) /*!< Bit mask for MCM_FATR_BESZ. */
#define BS_MCM_FATR_BESZ     (2U)          /*!< Bit field size in bits for MCM_FATR_BESZ. */

/*! @brief Read current value of the MCM_FATR_BESZ field. */
#define BR_MCM_FATR_BESZ(x)  (HW_MCM_FATR(x).B.BESZ)
/*@}*/

/*!
 * @name Register MCM_FATR, field BEWT[7] (RO)
 *
 * Indicates the type of system bus access when the error was detected. Since
 * this logic is monitoring data transfers from the cache write buffer, this bit is
 * always a logical one, signaling a write operation.
 *
 * Values:
 * - 0 - Read access
 * - 1 - Write access
 */
/*@{*/
#define BP_MCM_FATR_BEWT     (7U)          /*!< Bit position for MCM_FATR_BEWT. */
#define BM_MCM_FATR_BEWT     (0x00000080U) /*!< Bit mask for MCM_FATR_BEWT. */
#define BS_MCM_FATR_BEWT     (1U)          /*!< Bit field size in bits for MCM_FATR_BEWT. */

/*! @brief Read current value of the MCM_FATR_BEWT field. */
#define BR_MCM_FATR_BEWT(x)  (HW_MCM_FATR(x).B.BEWT)
/*@}*/

/*!
 * @name Register MCM_FATR, field BEMN[11:8] (RO)
 *
 * Crossbar switch bus master number of the captured cache write buffer bus
 * error. For this device, this value is always 0x1.
 */
/*@{*/
#define BP_MCM_FATR_BEMN     (8U)          /*!< Bit position for MCM_FATR_BEMN. */
#define BM_MCM_FATR_BEMN     (0x00000F00U) /*!< Bit mask for MCM_FATR_BEMN. */
#define BS_MCM_FATR_BEMN     (4U)          /*!< Bit field size in bits for MCM_FATR_BEMN. */

/*! @brief Read current value of the MCM_FATR_BEMN field. */
#define BR_MCM_FATR_BEMN(x)  (HW_MCM_FATR(x).B.BEMN)
/*@}*/

/*!
 * @name Register MCM_FATR, field BEOVR[31] (RO)
 *
 * Indicates if anothercache write buffer bus error is detected before system
 * software has retrieved all the error information from the original event, this
 * overrun flag is set. The window of time is defined from the detection of the
 * original cache write buffer error termination until the MCM_ISCR[CWBER] is
 * written with a 1 to clear it and rearm the capture logic. This bit is set by the
 * hardware and cleared whenever software writes a 1 to the CWBER bit.
 *
 * Values:
 * - 0 - No bus error overrun
 * - 1 - Bus error overrun occurred. The FADR and FDR registers and the other
 *     FATR bits are not updated to reflect this new bus error.
 */
/*@{*/
#define BP_MCM_FATR_BEOVR    (31U)         /*!< Bit position for MCM_FATR_BEOVR. */
#define BM_MCM_FATR_BEOVR    (0x80000000U) /*!< Bit mask for MCM_FATR_BEOVR. */
#define BS_MCM_FATR_BEOVR    (1U)          /*!< Bit field size in bits for MCM_FATR_BEOVR. */

/*! @brief Read current value of the MCM_FATR_BEOVR field. */
#define BR_MCM_FATR_BEOVR(x) (HW_MCM_FATR(x).B.BEOVR)
/*@}*/

/*******************************************************************************
 * HW_MCM_FDR - Fault data register
 ******************************************************************************/

/*!
 * @brief HW_MCM_FDR - Fault data register (RO)
 *
 * Reset value: 0x00000000U
 *
 * When a properly-enabled cache write buffer error interrupt event is detected,
 * the faulting data is captured in the MCM_FDR register. The bits in this
 * register are set by hardware and signaled by the assertion of MCM_ISCR[CWBER]. For
 * byte and halfword writes, only the accessed byte lanes contain valid data; the
 * contents of the other bytes are undefined. Attempted writes to this location
 * are terminated with an error.
 */
typedef union _hw_mcm_fdr
{
    uint32_t U;
    struct _hw_mcm_fdr_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0] Fault data */
    } B;
} hw_mcm_fdr_t;

/*!
 * @name Constants and macros for entire MCM_FDR register
 */
/*@{*/
#define HW_MCM_FDR_ADDR(x)       ((uintptr_t)(x) + 0x28U)

#define HW_MCM_FDR(x)            (*(__I hw_mcm_fdr_t *) HW_MCM_FDR_ADDR(x))
#define HW_MCM_FDR_RD(x)         (HW_MCM_FDR(x).U)
/*@}*/

/*
 * Constants & macros for individual MCM_FDR bitfields
 */

/*!
 * @name Register MCM_FDR, field DATA[31:0] (RO)
 */
/*@{*/
#define BP_MCM_FDR_DATA      (0U)          /*!< Bit position for MCM_FDR_DATA. */
#define BM_MCM_FDR_DATA      (0xFFFFFFFFU) /*!< Bit mask for MCM_FDR_DATA. */
#define BS_MCM_FDR_DATA      (32U)         /*!< Bit field size in bits for MCM_FDR_DATA. */

/*! @brief Read current value of the MCM_FDR_DATA field. */
#define BR_MCM_FDR_DATA(x)   (HW_MCM_FDR(x).U)
/*@}*/

/*******************************************************************************
 * hw_mcm_t - module struct
 ******************************************************************************/
/*!
 * @brief All MCM module registers.
 */
#pragma pack(1)
typedef struct _hw_mcm
{
    uint8_t _reserved0[8];
    __I hw_mcm_plasc_t PLASC;              /*!< [0x8] Crossbar Switch (AXBS) Slave Configuration */
    __I hw_mcm_plamc_t PLAMC;              /*!< [0xA] Crossbar Switch (AXBS) Master Configuration */
    __I hw_mcm_placr_t PLACR;              /*!< [0xC] Crossbar Switch (AXBS) Control Register */
    uint8_t _reserved1[16];
    __I hw_mcm_fadr_t FADR;                /*!< [0x20] Fault address register */
    __I hw_mcm_fatr_t FATR;                /*!< [0x24] Fault attributes register */
    __I hw_mcm_fdr_t FDR;                  /*!< [0x28] Fault data register */
} hw_mcm_t;
#pragma pack()

/*! @brief Macro to access all MCM registers. */
/*! @param x MCM module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_MCM_REGS(MCM_BASE)</code>. */
#define HW_MCM_REGS(x) (*(hw_mcm_t *)(x))

/*
 * iMX7D MIPI_CSI2
 *
 * MIPI CSI2 Host Controller (MIPI_CSI2)
 *
 * Registers defined in this header file:
 * - HW_MIPI_CSI2_CSIS_CMN_CTRL - CSIS Common Control
 * - HW_MIPI_CSI2_CSIS_CLK_CTRL - CSIS Clock gate Control
 * - HW_MIPI_CSI2_CSIS_INT_MSK - CSIS Interrupt Mask
 * - HW_MIPI_CSI2_CSIS_INT_SRC - CSIS Interrupt Source
 * - HW_MIPI_CSI2_DPHY_STATUS - D-PHY Status
 * - HW_MIPI_CSI2_DPHY_CMN_CTRL - D-PHY Common Control
 * - HW_MIPI_CSI2_DPHY_BCTRL_L - D-PHY Master and Slave Control register low
 * - HW_MIPI_CSI2_DPHY_BCTRL_H - D-PHY Master and Slave Control register high
 * - HW_MIPI_CSI2_DPHY_SCTRL_L - D-PHY Slave Control register low
 * - HW_MIPI_CSI2_DPHY_SCTRL_H - D-PHY Slave Control register high
 * - HW_MIPI_CSI2_ISP_CONFIG_CH0 - ISP Configuration register of CH0
 * - HW_MIPI_CSI2_ISP_RESOL_CH0 - ISP Image Resolution register of CH0
 * - HW_MIPI_CSI2_ISP_SYNC_CH0 - ISP SYNC register of CH0
 * - HW_MIPI_CSI2_SDW_CONFIG_CH0 - Shadow Configuration register of CH0
 * - HW_MIPI_CSI2_SDW_RESOL_CH0 - Shadow Resolution register of CH0
 * - HW_MIPI_CSI2_SDW_SYNC_CH0 - Shadow SYNC register of CH0
 * - HW_MIPI_CSI2_DBG_CTRL - Debug Control register
 * - HW_MIPI_CSI2_DBG_INTR_MSK - Debug Interrupt Mask
 * - HW_MIPI_CSI2_DBG_INTR_SRC - Debug Interrupt Mask
 * - HW_MIPI_CSI2_NON_IMG_DATA - Non Image Data
 *
 * - hw_mipi_csi2_t - Struct containing all module registers.
 */

#define HW_MIPI_CSI2_INSTANCE_COUNT (1U) /*!< Number of instances of the MIPI_CSI2 module. */
#define HW_MIPI_CSI2 (0U) /*!< Instance number for MIPI_CSI2. */
#define MIPI_CSI2_BASE        (0x30750000U) /*!< Base address for MIPI_CSI2. */
/*! Array initializer of MIPI_CSI2 base addresses. */
#define MIPI_CSI2_BASE_ADDRS  { MIPI_CSI2_BASE }

/*******************************************************************************
 * HW_MIPI_CSI2_CSIS_CMN_CTRL - CSIS Common Control
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_CSIS_CMN_CTRL - CSIS Common Control (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mipi_csi2_csis_cmn_ctrl
{
    uint32_t U;
    struct _hw_mipi_csi2_csis_cmn_ctrl_bitfields
    {
        uint32_t CSI_EN : 1;           /*!< [0]  */
        uint32_t SW_REST : 1;          /*!< [1] Software Reset */
        uint32_t UPDATE_SHADOW_CTRL : 1; /*!< [2] Update Shadow Control */
        uint32_t RSVD3 : 5;            /*!< [7:3] Reserved */
        uint32_t LANE_NUMBER : 2;      /*!< [9:8] Number of data lane */
        uint32_t INTERLEAVE_MODE : 2;  /*!< [11:10]  */
        uint32_t RSVD2 : 4;            /*!< [15:12] Reserved */
        uint32_t UPDATE_SHADOW : 4;    /*!< [19:16] Strobe of updating shadow
                                        * registers */
        uint32_t RSVD1 : 12;           /*!< [31:20] Reserved */
    } B;
} hw_mipi_csi2_csis_cmn_ctrl_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_CSIS_CMN_CTRL register
 */
/*@{*/
#define HW_MIPI_CSI2_CSIS_CMN_CTRL_ADDR(x) ((uintptr_t)(x) + 0x4U)

#define HW_MIPI_CSI2_CSIS_CMN_CTRL(x) (*(__IO hw_mipi_csi2_csis_cmn_ctrl_t *) HW_MIPI_CSI2_CSIS_CMN_CTRL_ADDR(x))
#define HW_MIPI_CSI2_CSIS_CMN_CTRL_RD(x) (HW_MIPI_CSI2_CSIS_CMN_CTRL(x).U)
#define HW_MIPI_CSI2_CSIS_CMN_CTRL_WR(x, v) (HW_MIPI_CSI2_CSIS_CMN_CTRL(x).U = (v))
#define HW_MIPI_CSI2_CSIS_CMN_CTRL_SET(x, v) (HW_MIPI_CSI2_CSIS_CMN_CTRL_WR(x, HW_MIPI_CSI2_CSIS_CMN_CTRL_RD(x) |  (v)))
#define HW_MIPI_CSI2_CSIS_CMN_CTRL_CLR(x, v) (HW_MIPI_CSI2_CSIS_CMN_CTRL_WR(x, HW_MIPI_CSI2_CSIS_CMN_CTRL_RD(x) & ~(v)))
#define HW_MIPI_CSI2_CSIS_CMN_CTRL_TOG(x, v) (HW_MIPI_CSI2_CSIS_CMN_CTRL_WR(x, HW_MIPI_CSI2_CSIS_CMN_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_CSIS_CMN_CTRL bitfields
 */

/*!
 * @name Register MIPI_CSI2_CSIS_CMN_CTRL, field CSI_EN[0] (RW)
 *
 * MIPI CSI2 system enable
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_CMN_CTRL_CSI_EN (0U) /*!< Bit position for MIPI_CSI2_CSIS_CMN_CTRL_CSI_EN. */
#define BM_MIPI_CSI2_CSIS_CMN_CTRL_CSI_EN (0x00000001U) /*!< Bit mask for MIPI_CSI2_CSIS_CMN_CTRL_CSI_EN. */
#define BS_MIPI_CSI2_CSIS_CMN_CTRL_CSI_EN (1U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_CMN_CTRL_CSI_EN. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_CMN_CTRL_CSI_EN field. */
#define BR_MIPI_CSI2_CSIS_CMN_CTRL_CSI_EN(x) (HW_MIPI_CSI2_CSIS_CMN_CTRL(x).B.CSI_EN)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_CMN_CTRL_CSI_EN. */
#define BF_MIPI_CSI2_CSIS_CMN_CTRL_CSI_EN(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_CMN_CTRL_CSI_EN) & BM_MIPI_CSI2_CSIS_CMN_CTRL_CSI_EN)

/*! @brief Set the CSI_EN field to a new value. */
#define BW_MIPI_CSI2_CSIS_CMN_CTRL_CSI_EN(x, v) (HW_MIPI_CSI2_CSIS_CMN_CTRL_WR(x, (HW_MIPI_CSI2_CSIS_CMN_CTRL_RD(x) & ~BM_MIPI_CSI2_CSIS_CMN_CTRL_CSI_EN) | BF_MIPI_CSI2_CSIS_CMN_CTRL_CSI_EN(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_CMN_CTRL, field SW_REST[1] (WO)
 *
 * All writable registers in CSI2 go back to initial state. After this bit is
 * active for three cycles, this bit will be deasserted automatically.Almost MIPI
 * CSI2 block uses "ByteClk" from D-phy. This "ByteClk" is not continuous clock.
 * User has to assert software reset when Camera module is turned off.
 *
 * Values:
 * - 0 - Ready
 * - 1 - Reset
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_CMN_CTRL_SW_REST (1U) /*!< Bit position for MIPI_CSI2_CSIS_CMN_CTRL_SW_REST. */
#define BM_MIPI_CSI2_CSIS_CMN_CTRL_SW_REST (0x00000002U) /*!< Bit mask for MIPI_CSI2_CSIS_CMN_CTRL_SW_REST. */
#define BS_MIPI_CSI2_CSIS_CMN_CTRL_SW_REST (1U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_CMN_CTRL_SW_REST. */

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_CMN_CTRL_SW_REST. */
#define BF_MIPI_CSI2_CSIS_CMN_CTRL_SW_REST(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_CMN_CTRL_SW_REST) & BM_MIPI_CSI2_CSIS_CMN_CTRL_SW_REST)
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_CMN_CTRL, field UPDATE_SHADOW_CTRL[2] (RW)
 *
 * Enable this reg is recommended when interleave_mode is 2 or 3.
 *
 * Values:
 * - 0 - Disable (default)
 * - 1 - Enable
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_CTRL (2U) /*!< Bit position for MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_CTRL. */
#define BM_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_CTRL (0x00000004U) /*!< Bit mask for MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_CTRL. */
#define BS_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_CTRL (1U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_CTRL. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_CTRL field. */
#define BR_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_CTRL(x) (HW_MIPI_CSI2_CSIS_CMN_CTRL(x).B.UPDATE_SHADOW_CTRL)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_CTRL. */
#define BF_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_CTRL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_CTRL) & BM_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_CTRL)

/*! @brief Set the UPDATE_SHADOW_CTRL field to a new value. */
#define BW_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_CTRL(x, v) (HW_MIPI_CSI2_CSIS_CMN_CTRL_WR(x, (HW_MIPI_CSI2_CSIS_CMN_CTRL_RD(x) & ~BM_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_CTRL) | BF_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW_CTRL(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_CMN_CTRL, field RSVD3[7:3] (RO)
 *
 * Read as zero, do not modify.
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_CMN_CTRL_RSVD3 (3U) /*!< Bit position for MIPI_CSI2_CSIS_CMN_CTRL_RSVD3. */
#define BM_MIPI_CSI2_CSIS_CMN_CTRL_RSVD3 (0x000000F8U) /*!< Bit mask for MIPI_CSI2_CSIS_CMN_CTRL_RSVD3. */
#define BS_MIPI_CSI2_CSIS_CMN_CTRL_RSVD3 (5U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_CMN_CTRL_RSVD3. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_CMN_CTRL_RSVD3 field. */
#define BR_MIPI_CSI2_CSIS_CMN_CTRL_RSVD3(x) (HW_MIPI_CSI2_CSIS_CMN_CTRL(x).B.RSVD3)
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_CMN_CTRL, field LANE_NUMBER[9:8] (RW)
 *
 * Values:
 * - 00 - 1 data lane
 * - 01 - 2 data lane
 * - 10 - Reserved
 * - 11 - Reserved
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER (8U) /*!< Bit position for MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER. */
#define BM_MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER (0x00000300U) /*!< Bit mask for MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER. */
#define BS_MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER (2U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER field. */
#define BR_MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER(x) (HW_MIPI_CSI2_CSIS_CMN_CTRL(x).B.LANE_NUMBER)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER. */
#define BF_MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER) & BM_MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER)

/*! @brief Set the LANE_NUMBER field to a new value. */
#define BW_MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER(x, v) (HW_MIPI_CSI2_CSIS_CMN_CTRL_WR(x, (HW_MIPI_CSI2_CSIS_CMN_CTRL_RD(x) & ~BM_MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER) | BF_MIPI_CSI2_CSIS_CMN_CTRL_LANE_NUMBER(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_CMN_CTRL, field INTERLEAVE_MODE[11:10] (RW)
 *
 * Select Interleave mode, VC (Virtual channel) and DT (Data type)
 *
 * Values:
 * - 11 - VC and DT
 * - 10 - VC only
 * - 01 - DT only
 * - 00 - CH0 only, no data interleave
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE (10U) /*!< Bit position for MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE. */
#define BM_MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE (0x00000C00U) /*!< Bit mask for MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE. */
#define BS_MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE (2U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE field. */
#define BR_MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE(x) (HW_MIPI_CSI2_CSIS_CMN_CTRL(x).B.INTERLEAVE_MODE)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE. */
#define BF_MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE) & BM_MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE)

/*! @brief Set the INTERLEAVE_MODE field to a new value. */
#define BW_MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE(x, v) (HW_MIPI_CSI2_CSIS_CMN_CTRL_WR(x, (HW_MIPI_CSI2_CSIS_CMN_CTRL_RD(x) & ~BM_MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE) | BF_MIPI_CSI2_CSIS_CMN_CTRL_INTERLEAVE_MODE(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_CMN_CTRL, field RSVD2[15:12] (RO)
 *
 * Read as zero, do not modify.
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_CMN_CTRL_RSVD2 (12U) /*!< Bit position for MIPI_CSI2_CSIS_CMN_CTRL_RSVD2. */
#define BM_MIPI_CSI2_CSIS_CMN_CTRL_RSVD2 (0x0000F000U) /*!< Bit mask for MIPI_CSI2_CSIS_CMN_CTRL_RSVD2. */
#define BS_MIPI_CSI2_CSIS_CMN_CTRL_RSVD2 (4U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_CMN_CTRL_RSVD2. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_CMN_CTRL_RSVD2 field. */
#define BR_MIPI_CSI2_CSIS_CMN_CTRL_RSVD2(x) (HW_MIPI_CSI2_CSIS_CMN_CTRL(x).B.RSVD2)
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_CMN_CTRL, field UPDATE_SHADOW[19:16] (RW)
 *
 * After configuration, user has to set this bit for updating shadow registers.
 * This bit is cleared automatically after updating shadow registers. Bit 19, 18,
 * 17 is reserved. Bit 16 set for CH0.
 *
 * Values:
 * - 0 - Default
 * - 1 - Update the shadow registers
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW (16U) /*!< Bit position for MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW. */
#define BM_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW (0x000F0000U) /*!< Bit mask for MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW. */
#define BS_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW (4U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW field. */
#define BR_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW(x) (HW_MIPI_CSI2_CSIS_CMN_CTRL(x).B.UPDATE_SHADOW)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW. */
#define BF_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW) & BM_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW)

/*! @brief Set the UPDATE_SHADOW field to a new value. */
#define BW_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW(x, v) (HW_MIPI_CSI2_CSIS_CMN_CTRL_WR(x, (HW_MIPI_CSI2_CSIS_CMN_CTRL_RD(x) & ~BM_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW) | BF_MIPI_CSI2_CSIS_CMN_CTRL_UPDATE_SHADOW(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_CMN_CTRL, field RSVD1[31:20] (RO)
 *
 * Read as zero, do not modify.
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_CMN_CTRL_RSVD1 (20U) /*!< Bit position for MIPI_CSI2_CSIS_CMN_CTRL_RSVD1. */
#define BM_MIPI_CSI2_CSIS_CMN_CTRL_RSVD1 (0xFFF00000U) /*!< Bit mask for MIPI_CSI2_CSIS_CMN_CTRL_RSVD1. */
#define BS_MIPI_CSI2_CSIS_CMN_CTRL_RSVD1 (12U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_CMN_CTRL_RSVD1. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_CMN_CTRL_RSVD1 field. */
#define BR_MIPI_CSI2_CSIS_CMN_CTRL_RSVD1(x) (HW_MIPI_CSI2_CSIS_CMN_CTRL(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_MIPI_CSI2_CSIS_CLK_CTRL - CSIS Clock gate Control
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_CSIS_CLK_CTRL - CSIS Clock gate Control (RW)
 *
 * Reset value: 0x000000F0U
 */
typedef union _hw_mipi_csi2_csis_clk_ctrl
{
    uint32_t U;
    struct _hw_mipi_csi2_csis_clk_ctrl_bitfields
    {
        uint32_t WCLK_SRC : 4;         /*!< [3:0] Pixel Clock Source */
        uint32_t CLKGATE_EN : 4;       /*!< [7:4]  */
        uint32_t RSVD4 : 8;            /*!< [15:8] Reserved */
        uint32_t CLKGATE_TRAIL : 16;   /*!< [31:16]  */
    } B;
} hw_mipi_csi2_csis_clk_ctrl_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_CSIS_CLK_CTRL register
 */
/*@{*/
#define HW_MIPI_CSI2_CSIS_CLK_CTRL_ADDR(x) ((uintptr_t)(x) + 0x8U)

#define HW_MIPI_CSI2_CSIS_CLK_CTRL(x) (*(__IO hw_mipi_csi2_csis_clk_ctrl_t *) HW_MIPI_CSI2_CSIS_CLK_CTRL_ADDR(x))
#define HW_MIPI_CSI2_CSIS_CLK_CTRL_RD(x) (HW_MIPI_CSI2_CSIS_CLK_CTRL(x).U)
#define HW_MIPI_CSI2_CSIS_CLK_CTRL_WR(x, v) (HW_MIPI_CSI2_CSIS_CLK_CTRL(x).U = (v))
#define HW_MIPI_CSI2_CSIS_CLK_CTRL_SET(x, v) (HW_MIPI_CSI2_CSIS_CLK_CTRL_WR(x, HW_MIPI_CSI2_CSIS_CLK_CTRL_RD(x) |  (v)))
#define HW_MIPI_CSI2_CSIS_CLK_CTRL_CLR(x, v) (HW_MIPI_CSI2_CSIS_CLK_CTRL_WR(x, HW_MIPI_CSI2_CSIS_CLK_CTRL_RD(x) & ~(v)))
#define HW_MIPI_CSI2_CSIS_CLK_CTRL_TOG(x, v) (HW_MIPI_CSI2_CSIS_CLK_CTRL_WR(x, HW_MIPI_CSI2_CSIS_CLK_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_CSIS_CLK_CTRL bitfields
 */

/*!
 * @name Register MIPI_CSI2_CSIS_CLK_CTRL, field WCLK_SRC[3:0] (RW)
 *
 * This bit determines source of Pixel clock, which is clock of transferring
 * image data to ISP or CAM I/F. Bit3, 2, 1 is reserved, bit0 set for CH0.
 *
 * Values:
 * - 0 - PCLK
 * - 1 - EXTCLK (WRAP_CLK)
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC (0U) /*!< Bit position for MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC. */
#define BM_MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC (0x0000000FU) /*!< Bit mask for MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC. */
#define BS_MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC (4U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC field. */
#define BR_MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC(x) (HW_MIPI_CSI2_CSIS_CLK_CTRL(x).B.WCLK_SRC)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC. */
#define BF_MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC) & BM_MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC)

/*! @brief Set the WCLK_SRC field to a new value. */
#define BW_MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC(x, v) (HW_MIPI_CSI2_CSIS_CLK_CTRL_WR(x, (HW_MIPI_CSI2_CSIS_CLK_CTRL_RD(x) & ~BM_MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC) | BF_MIPI_CSI2_CSIS_CLK_CTRL_WCLK_SRC(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_CLK_CTRL, field CLKGATE_EN[7:4] (RW)
 *
 * Bit 7, 6, 5 is reserved, bit 4 set for CH0.
 *
 * Values:
 * - 0 - Pixel clock is always alive.
 * - 1 - Pixel clock is alive during the interval of frame.
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN (4U) /*!< Bit position for MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN. */
#define BM_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN (0x000000F0U) /*!< Bit mask for MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN. */
#define BS_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN (4U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN field. */
#define BR_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN(x) (HW_MIPI_CSI2_CSIS_CLK_CTRL(x).B.CLKGATE_EN)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN. */
#define BF_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN) & BM_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN)

/*! @brief Set the CLKGATE_EN field to a new value. */
#define BW_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN(x, v) (HW_MIPI_CSI2_CSIS_CLK_CTRL_WR(x, (HW_MIPI_CSI2_CSIS_CLK_CTRL_RD(x) & ~BM_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN) | BF_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_EN(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_CLK_CTRL, field RSVD4[15:8] (RO)
 *
 * Read as zero, do not modify.
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_CLK_CTRL_RSVD4 (8U) /*!< Bit position for MIPI_CSI2_CSIS_CLK_CTRL_RSVD4. */
#define BM_MIPI_CSI2_CSIS_CLK_CTRL_RSVD4 (0x0000FF00U) /*!< Bit mask for MIPI_CSI2_CSIS_CLK_CTRL_RSVD4. */
#define BS_MIPI_CSI2_CSIS_CLK_CTRL_RSVD4 (8U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_CLK_CTRL_RSVD4. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_CLK_CTRL_RSVD4 field. */
#define BR_MIPI_CSI2_CSIS_CLK_CTRL_RSVD4(x) (HW_MIPI_CSI2_CSIS_CLK_CTRL(x).B.RSVD4)
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_CLK_CTRL, field CLKGATE_TRAIL[31:16] (RW)
 *
 * 0 ~ 15 (1~16 Trailing clocks) [31:28], [27:24], [23:20] Reserved; [19:16]
 * CH0. Trailing clocks are used for poping the F/F of ISP or CAM.
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL (16U) /*!< Bit position for MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL. */
#define BM_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL (0xFFFF0000U) /*!< Bit mask for MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL. */
#define BS_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL (16U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL field. */
#define BR_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL(x) (HW_MIPI_CSI2_CSIS_CLK_CTRL(x).B.CLKGATE_TRAIL)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL. */
#define BF_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL) & BM_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL)

/*! @brief Set the CLKGATE_TRAIL field to a new value. */
#define BW_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL(x, v) (HW_MIPI_CSI2_CSIS_CLK_CTRL_WR(x, (HW_MIPI_CSI2_CSIS_CLK_CTRL_RD(x) & ~BM_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL) | BF_MIPI_CSI2_CSIS_CLK_CTRL_CLKGATE_TRAIL(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_CSI2_CSIS_INT_MSK - CSIS Interrupt Mask
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_CSIS_INT_MSK - CSIS Interrupt Mask (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mipi_csi2_csis_int_msk
{
    uint32_t U;
    struct _hw_mipi_csi2_csis_int_msk_bitfields
    {
        uint32_t MSK_ERR_id : 1;       /*!< [0] Unknown ID Error */
        uint32_t MSK_ERR_CRC : 1;      /*!< [1] CRC Error */
        uint32_t MSK_ERR_ECC : 1;      /*!< [2] ECC Error */
        uint32_t MSK_ERR_WRONG_CFG : 1; /*!< [3]  */
        uint32_t MSK_ERR_OVER : 4;     /*!< [7:4]  */
        uint32_t MSK_ERR_LOST_FE : 4;  /*!< [11:8]  */
        uint32_t MSK_ERR_LOST_FS : 4;  /*!< [15:12]  */
        uint32_t MSK_ERR_SOT_HS : 4;   /*!< [19:16]  */
        uint32_t MSK_FRAMEEND : 4;     /*!< [23:20]  */
        uint32_t MSK_FRAMESTART : 4;   /*!< [27:24]  */
        uint32_t MSK_ODDAFTER : 1;     /*!< [28]  */
        uint32_t MSK_ODDBEFORE : 1;    /*!< [29]  */
        uint32_t MSK_EVENAFTER : 1;    /*!< [30]  */
        uint32_t MSK_EVENBEFORE : 1;   /*!< [31]  */
    } B;
} hw_mipi_csi2_csis_int_msk_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_CSIS_INT_MSK register
 */
/*@{*/
#define HW_MIPI_CSI2_CSIS_INT_MSK_ADDR(x) ((uintptr_t)(x) + 0x10U)

#define HW_MIPI_CSI2_CSIS_INT_MSK(x) (*(__IO hw_mipi_csi2_csis_int_msk_t *) HW_MIPI_CSI2_CSIS_INT_MSK_ADDR(x))
#define HW_MIPI_CSI2_CSIS_INT_MSK_RD(x) (HW_MIPI_CSI2_CSIS_INT_MSK(x).U)
#define HW_MIPI_CSI2_CSIS_INT_MSK_WR(x, v) (HW_MIPI_CSI2_CSIS_INT_MSK(x).U = (v))
#define HW_MIPI_CSI2_CSIS_INT_MSK_SET(x, v) (HW_MIPI_CSI2_CSIS_INT_MSK_WR(x, HW_MIPI_CSI2_CSIS_INT_MSK_RD(x) |  (v)))
#define HW_MIPI_CSI2_CSIS_INT_MSK_CLR(x, v) (HW_MIPI_CSI2_CSIS_INT_MSK_WR(x, HW_MIPI_CSI2_CSIS_INT_MSK_RD(x) & ~(v)))
#define HW_MIPI_CSI2_CSIS_INT_MSK_TOG(x, v) (HW_MIPI_CSI2_CSIS_INT_MSK_WR(x, HW_MIPI_CSI2_CSIS_INT_MSK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_CSIS_INT_MSK bitfields
 */

/*!
 * @name Register MIPI_CSI2_CSIS_INT_MSK, field MSK_ERR_id[0] (RW)
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_id (0U) /*!< Bit position for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_id. */
#define BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_id (0x00000001U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_id. */
#define BS_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_id (1U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_id. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_id field. */
#define BR_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_id(x) (HW_MIPI_CSI2_CSIS_INT_MSK(x).B.MSK_ERR_id)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_id. */
#define BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_id(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_id) & BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_id)

/*! @brief Set the MSK_ERR_id field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_id(x, v) (HW_MIPI_CSI2_CSIS_INT_MSK_WR(x, (HW_MIPI_CSI2_CSIS_INT_MSK_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_id) | BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_id(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_MSK, field MSK_ERR_CRC[1] (RW)
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_CRC (1U) /*!< Bit position for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_CRC. */
#define BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_CRC (0x00000002U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_CRC. */
#define BS_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_CRC (1U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_CRC. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_CRC field. */
#define BR_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_CRC(x) (HW_MIPI_CSI2_CSIS_INT_MSK(x).B.MSK_ERR_CRC)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_CRC. */
#define BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_CRC(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_CRC) & BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_CRC)

/*! @brief Set the MSK_ERR_CRC field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_CRC(x, v) (HW_MIPI_CSI2_CSIS_INT_MSK_WR(x, (HW_MIPI_CSI2_CSIS_INT_MSK_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_CRC) | BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_CRC(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_MSK, field MSK_ERR_ECC[2] (RW)
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_ECC (2U) /*!< Bit position for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_ECC. */
#define BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_ECC (0x00000004U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_ECC. */
#define BS_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_ECC (1U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_ECC. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_ECC field. */
#define BR_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_ECC(x) (HW_MIPI_CSI2_CSIS_INT_MSK(x).B.MSK_ERR_ECC)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_ECC. */
#define BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_ECC(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_ECC) & BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_ECC)

/*! @brief Set the MSK_ERR_ECC field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_ECC(x, v) (HW_MIPI_CSI2_CSIS_INT_MSK_WR(x, (HW_MIPI_CSI2_CSIS_INT_MSK_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_ECC) | BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_ECC(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_MSK, field MSK_ERR_WRONG_CFG[3] (RW)
 *
 * Wrong configuration
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_WRONG_CFG (3U) /*!< Bit position for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_WRONG_CFG. */
#define BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_WRONG_CFG (0x00000008U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_WRONG_CFG. */
#define BS_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_WRONG_CFG (1U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_WRONG_CFG. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_WRONG_CFG field. */
#define BR_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_WRONG_CFG(x) (HW_MIPI_CSI2_CSIS_INT_MSK(x).B.MSK_ERR_WRONG_CFG)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_WRONG_CFG. */
#define BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_WRONG_CFG(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_WRONG_CFG) & BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_WRONG_CFG)

/*! @brief Set the MSK_ERR_WRONG_CFG field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_WRONG_CFG(x, v) (HW_MIPI_CSI2_CSIS_INT_MSK_WR(x, (HW_MIPI_CSI2_CSIS_INT_MSK_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_WRONG_CFG) | BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_WRONG_CFG(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_MSK, field MSK_ERR_OVER[7:4] (RW)
 *
 * Image FIFO overflow interrupt, [CH3,CH2,CH1,CH0]
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER (4U) /*!< Bit position for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER. */
#define BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER (0x000000F0U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER. */
#define BS_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER (4U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER field. */
#define BR_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER(x) (HW_MIPI_CSI2_CSIS_INT_MSK(x).B.MSK_ERR_OVER)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER. */
#define BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER) & BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER)

/*! @brief Set the MSK_ERR_OVER field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER(x, v) (HW_MIPI_CSI2_CSIS_INT_MSK_WR(x, (HW_MIPI_CSI2_CSIS_INT_MSK_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER) | BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_OVER(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_MSK, field MSK_ERR_LOST_FE[11:8] (RW)
 *
 * Lost of Frame End packet, [CH3,CH2,CH1,CH0]
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE (8U) /*!< Bit position for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE. */
#define BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE (0x00000F00U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE. */
#define BS_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE (4U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE field. */
#define BR_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE(x) (HW_MIPI_CSI2_CSIS_INT_MSK(x).B.MSK_ERR_LOST_FE)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE. */
#define BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE) & BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE)

/*! @brief Set the MSK_ERR_LOST_FE field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE(x, v) (HW_MIPI_CSI2_CSIS_INT_MSK_WR(x, (HW_MIPI_CSI2_CSIS_INT_MSK_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE) | BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FE(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_MSK, field MSK_ERR_LOST_FS[15:12] (RW)
 *
 * Lost of Frame Start packet, [CH3,CH2,CH1,CH0]
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS (12U) /*!< Bit position for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS. */
#define BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS (0x0000F000U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS. */
#define BS_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS (4U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS field. */
#define BR_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS(x) (HW_MIPI_CSI2_CSIS_INT_MSK(x).B.MSK_ERR_LOST_FS)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS. */
#define BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS) & BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS)

/*! @brief Set the MSK_ERR_LOST_FS field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS(x, v) (HW_MIPI_CSI2_CSIS_INT_MSK_WR(x, (HW_MIPI_CSI2_CSIS_INT_MSK_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS) | BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_LOST_FS(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_MSK, field MSK_ERR_SOT_HS[19:16] (RW)
 *
 * Start of transmission error [reserved, reserved, Lane1, Lane0]
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS (16U) /*!< Bit position for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS. */
#define BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS (0x000F0000U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS. */
#define BS_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS (4U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS field. */
#define BR_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS(x) (HW_MIPI_CSI2_CSIS_INT_MSK(x).B.MSK_ERR_SOT_HS)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS. */
#define BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS) & BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS)

/*! @brief Set the MSK_ERR_SOT_HS field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS(x, v) (HW_MIPI_CSI2_CSIS_INT_MSK_WR(x, (HW_MIPI_CSI2_CSIS_INT_MSK_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS) | BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ERR_SOT_HS(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_MSK, field MSK_FRAMEEND[23:20] (RW)
 *
 * FE packet is received, [CH3,CH2,CH1,CH0]
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND (20U) /*!< Bit position for MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND. */
#define BM_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND (0x00F00000U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND. */
#define BS_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND (4U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND field. */
#define BR_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND(x) (HW_MIPI_CSI2_CSIS_INT_MSK(x).B.MSK_FRAMEEND)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND. */
#define BF_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND) & BM_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND)

/*! @brief Set the MSK_FRAMEEND field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND(x, v) (HW_MIPI_CSI2_CSIS_INT_MSK_WR(x, (HW_MIPI_CSI2_CSIS_INT_MSK_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND) | BF_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMEEND(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_MSK, field MSK_FRAMESTART[27:24] (RW)
 *
 * FS packet is received, [CH3,CH2,CH1,CH0]
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART (24U) /*!< Bit position for MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART. */
#define BM_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART (0x0F000000U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART. */
#define BS_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART (4U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART field. */
#define BR_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART(x) (HW_MIPI_CSI2_CSIS_INT_MSK(x).B.MSK_FRAMESTART)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART. */
#define BF_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART) & BM_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART)

/*! @brief Set the MSK_FRAMESTART field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART(x, v) (HW_MIPI_CSI2_CSIS_INT_MSK_WR(x, (HW_MIPI_CSI2_CSIS_INT_MSK_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART) | BF_MIPI_CSI2_CSIS_INT_MSK_MSK_FRAMESTART(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_MSK, field MSK_ODDAFTER[28] (RW)
 *
 * Non Image data are received at Odd frame and After Image.
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDAFTER (28U) /*!< Bit position for MIPI_CSI2_CSIS_INT_MSK_MSK_ODDAFTER. */
#define BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDAFTER (0x10000000U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_MSK_MSK_ODDAFTER. */
#define BS_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDAFTER (1U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_MSK_MSK_ODDAFTER. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_MSK_MSK_ODDAFTER field. */
#define BR_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDAFTER(x) (HW_MIPI_CSI2_CSIS_INT_MSK(x).B.MSK_ODDAFTER)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_MSK_MSK_ODDAFTER. */
#define BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDAFTER(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDAFTER) & BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDAFTER)

/*! @brief Set the MSK_ODDAFTER field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDAFTER(x, v) (HW_MIPI_CSI2_CSIS_INT_MSK_WR(x, (HW_MIPI_CSI2_CSIS_INT_MSK_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDAFTER) | BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDAFTER(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_MSK, field MSK_ODDBEFORE[29] (RW)
 *
 * Non Image data are received at Odd frame and Before Image.
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDBEFORE (29U) /*!< Bit position for MIPI_CSI2_CSIS_INT_MSK_MSK_ODDBEFORE. */
#define BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDBEFORE (0x20000000U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_MSK_MSK_ODDBEFORE. */
#define BS_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDBEFORE (1U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_MSK_MSK_ODDBEFORE. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_MSK_MSK_ODDBEFORE field. */
#define BR_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDBEFORE(x) (HW_MIPI_CSI2_CSIS_INT_MSK(x).B.MSK_ODDBEFORE)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_MSK_MSK_ODDBEFORE. */
#define BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDBEFORE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDBEFORE) & BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDBEFORE)

/*! @brief Set the MSK_ODDBEFORE field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDBEFORE(x, v) (HW_MIPI_CSI2_CSIS_INT_MSK_WR(x, (HW_MIPI_CSI2_CSIS_INT_MSK_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDBEFORE) | BF_MIPI_CSI2_CSIS_INT_MSK_MSK_ODDBEFORE(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_MSK, field MSK_EVENAFTER[30] (RW)
 *
 * Non Image data are received at Even frame and After Image.
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENAFTER (30U) /*!< Bit position for MIPI_CSI2_CSIS_INT_MSK_MSK_EVENAFTER. */
#define BM_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENAFTER (0x40000000U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_MSK_MSK_EVENAFTER. */
#define BS_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENAFTER (1U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_MSK_MSK_EVENAFTER. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_MSK_MSK_EVENAFTER field. */
#define BR_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENAFTER(x) (HW_MIPI_CSI2_CSIS_INT_MSK(x).B.MSK_EVENAFTER)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_MSK_MSK_EVENAFTER. */
#define BF_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENAFTER(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENAFTER) & BM_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENAFTER)

/*! @brief Set the MSK_EVENAFTER field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENAFTER(x, v) (HW_MIPI_CSI2_CSIS_INT_MSK_WR(x, (HW_MIPI_CSI2_CSIS_INT_MSK_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENAFTER) | BF_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENAFTER(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_MSK, field MSK_EVENBEFORE[31] (RW)
 *
 * Non Image data are received at Even frame and Before Image.
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENBEFORE (31U) /*!< Bit position for MIPI_CSI2_CSIS_INT_MSK_MSK_EVENBEFORE. */
#define BM_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENBEFORE (0x80000000U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_MSK_MSK_EVENBEFORE. */
#define BS_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENBEFORE (1U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_MSK_MSK_EVENBEFORE. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_MSK_MSK_EVENBEFORE field. */
#define BR_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENBEFORE(x) (HW_MIPI_CSI2_CSIS_INT_MSK(x).B.MSK_EVENBEFORE)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_MSK_MSK_EVENBEFORE. */
#define BF_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENBEFORE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENBEFORE) & BM_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENBEFORE)

/*! @brief Set the MSK_EVENBEFORE field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENBEFORE(x, v) (HW_MIPI_CSI2_CSIS_INT_MSK_WR(x, (HW_MIPI_CSI2_CSIS_INT_MSK_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENBEFORE) | BF_MIPI_CSI2_CSIS_INT_MSK_MSK_EVENBEFORE(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_CSI2_CSIS_INT_SRC - CSIS Interrupt Source
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_CSIS_INT_SRC - CSIS Interrupt Source (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mipi_csi2_csis_int_src
{
    uint32_t U;
    struct _hw_mipi_csi2_csis_int_src_bitfields
    {
        uint32_t ERR_ID : 1;           /*!< [0] Unknown ID Error */
        uint32_t ERR_CRC : 1;          /*!< [1] CRC Error */
        uint32_t ERR_ECC : 1;          /*!< [2] ECC Error */
        uint32_t ERR_WRONG_CFG : 1;    /*!< [3] Wrong Configuration */
        uint32_t ERR_OVER : 4;         /*!< [7:4]  */
        uint32_t ERR_LOST_FE : 4;      /*!< [11:8]  */
        uint32_t ERR_LOST_FS : 4;      /*!< [15:12]  */
        uint32_t ERR_SOT_HS : 4;       /*!< [19:16]  */
        uint32_t FRAMEEND : 4;         /*!< [23:20]  */
        uint32_t FRAMESTART : 4;       /*!< [27:24]  */
        uint32_t ODDAFTER : 1;         /*!< [28]  */
        uint32_t ODDBEFORE : 1;        /*!< [29]  */
        uint32_t EVENAFTER : 1;        /*!< [30]  */
        uint32_t EVENBEFORE : 1;       /*!< [31]  */
    } B;
} hw_mipi_csi2_csis_int_src_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_CSIS_INT_SRC register
 */
/*@{*/
#define HW_MIPI_CSI2_CSIS_INT_SRC_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_MIPI_CSI2_CSIS_INT_SRC(x) (*(__IO hw_mipi_csi2_csis_int_src_t *) HW_MIPI_CSI2_CSIS_INT_SRC_ADDR(x))
#define HW_MIPI_CSI2_CSIS_INT_SRC_RD(x) (HW_MIPI_CSI2_CSIS_INT_SRC(x).U)
#define HW_MIPI_CSI2_CSIS_INT_SRC_WR(x, v) (HW_MIPI_CSI2_CSIS_INT_SRC(x).U = (v))
#define HW_MIPI_CSI2_CSIS_INT_SRC_SET(x, v) (HW_MIPI_CSI2_CSIS_INT_SRC_WR(x, HW_MIPI_CSI2_CSIS_INT_SRC_RD(x) |  (v)))
#define HW_MIPI_CSI2_CSIS_INT_SRC_CLR(x, v) (HW_MIPI_CSI2_CSIS_INT_SRC_WR(x, HW_MIPI_CSI2_CSIS_INT_SRC_RD(x) & ~(v)))
#define HW_MIPI_CSI2_CSIS_INT_SRC_TOG(x, v) (HW_MIPI_CSI2_CSIS_INT_SRC_WR(x, HW_MIPI_CSI2_CSIS_INT_SRC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_CSIS_INT_SRC bitfields
 */

/*!
 * @name Register MIPI_CSI2_CSIS_INT_SRC, field ERR_ID[0] (RW)
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_SRC_ERR_ID (0U) /*!< Bit position for MIPI_CSI2_CSIS_INT_SRC_ERR_ID. */
#define BM_MIPI_CSI2_CSIS_INT_SRC_ERR_ID (0x00000001U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_SRC_ERR_ID. */
#define BS_MIPI_CSI2_CSIS_INT_SRC_ERR_ID (1U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_SRC_ERR_ID. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_SRC_ERR_ID field. */
#define BR_MIPI_CSI2_CSIS_INT_SRC_ERR_ID(x) (HW_MIPI_CSI2_CSIS_INT_SRC(x).B.ERR_ID)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_SRC_ERR_ID. */
#define BF_MIPI_CSI2_CSIS_INT_SRC_ERR_ID(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_SRC_ERR_ID) & BM_MIPI_CSI2_CSIS_INT_SRC_ERR_ID)

/*! @brief Set the ERR_ID field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_SRC_ERR_ID(x, v) (HW_MIPI_CSI2_CSIS_INT_SRC_WR(x, (HW_MIPI_CSI2_CSIS_INT_SRC_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_SRC_ERR_ID) | BF_MIPI_CSI2_CSIS_INT_SRC_ERR_ID(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_SRC, field ERR_CRC[1] (RW)
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_SRC_ERR_CRC (1U) /*!< Bit position for MIPI_CSI2_CSIS_INT_SRC_ERR_CRC. */
#define BM_MIPI_CSI2_CSIS_INT_SRC_ERR_CRC (0x00000002U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_SRC_ERR_CRC. */
#define BS_MIPI_CSI2_CSIS_INT_SRC_ERR_CRC (1U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_SRC_ERR_CRC. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_SRC_ERR_CRC field. */
#define BR_MIPI_CSI2_CSIS_INT_SRC_ERR_CRC(x) (HW_MIPI_CSI2_CSIS_INT_SRC(x).B.ERR_CRC)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_SRC_ERR_CRC. */
#define BF_MIPI_CSI2_CSIS_INT_SRC_ERR_CRC(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_SRC_ERR_CRC) & BM_MIPI_CSI2_CSIS_INT_SRC_ERR_CRC)

/*! @brief Set the ERR_CRC field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_SRC_ERR_CRC(x, v) (HW_MIPI_CSI2_CSIS_INT_SRC_WR(x, (HW_MIPI_CSI2_CSIS_INT_SRC_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_SRC_ERR_CRC) | BF_MIPI_CSI2_CSIS_INT_SRC_ERR_CRC(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_SRC, field ERR_ECC[2] (RW)
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_SRC_ERR_ECC (2U) /*!< Bit position for MIPI_CSI2_CSIS_INT_SRC_ERR_ECC. */
#define BM_MIPI_CSI2_CSIS_INT_SRC_ERR_ECC (0x00000004U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_SRC_ERR_ECC. */
#define BS_MIPI_CSI2_CSIS_INT_SRC_ERR_ECC (1U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_SRC_ERR_ECC. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_SRC_ERR_ECC field. */
#define BR_MIPI_CSI2_CSIS_INT_SRC_ERR_ECC(x) (HW_MIPI_CSI2_CSIS_INT_SRC(x).B.ERR_ECC)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_SRC_ERR_ECC. */
#define BF_MIPI_CSI2_CSIS_INT_SRC_ERR_ECC(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_SRC_ERR_ECC) & BM_MIPI_CSI2_CSIS_INT_SRC_ERR_ECC)

/*! @brief Set the ERR_ECC field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_SRC_ERR_ECC(x, v) (HW_MIPI_CSI2_CSIS_INT_SRC_WR(x, (HW_MIPI_CSI2_CSIS_INT_SRC_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_SRC_ERR_ECC) | BF_MIPI_CSI2_CSIS_INT_SRC_ERR_ECC(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_SRC, field ERR_WRONG_CFG[3] (RW)
 *
 * The received packet is not decoded at any channels of ISP (due to wrong data
 * type or virtual channel ID)
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_SRC_ERR_WRONG_CFG (3U) /*!< Bit position for MIPI_CSI2_CSIS_INT_SRC_ERR_WRONG_CFG. */
#define BM_MIPI_CSI2_CSIS_INT_SRC_ERR_WRONG_CFG (0x00000008U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_SRC_ERR_WRONG_CFG. */
#define BS_MIPI_CSI2_CSIS_INT_SRC_ERR_WRONG_CFG (1U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_SRC_ERR_WRONG_CFG. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_SRC_ERR_WRONG_CFG field. */
#define BR_MIPI_CSI2_CSIS_INT_SRC_ERR_WRONG_CFG(x) (HW_MIPI_CSI2_CSIS_INT_SRC(x).B.ERR_WRONG_CFG)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_SRC_ERR_WRONG_CFG. */
#define BF_MIPI_CSI2_CSIS_INT_SRC_ERR_WRONG_CFG(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_SRC_ERR_WRONG_CFG) & BM_MIPI_CSI2_CSIS_INT_SRC_ERR_WRONG_CFG)

/*! @brief Set the ERR_WRONG_CFG field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_SRC_ERR_WRONG_CFG(x, v) (HW_MIPI_CSI2_CSIS_INT_SRC_WR(x, (HW_MIPI_CSI2_CSIS_INT_SRC_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_SRC_ERR_WRONG_CFG) | BF_MIPI_CSI2_CSIS_INT_SRC_ERR_WRONG_CFG(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_SRC, field ERR_OVER[7:4] (RW)
 *
 * Overflow is caused in image FIFO, [CH3,CH2,CH1,CH0] Outer bandwidth has to be
 * faster than imputer bandwidth. But image FIFO can be overflow because of
 * user's fault. There are two ways for preventing overflow. Tune output pixel clock
 * faster than current Tune input byte clock slowr than current First case:
 * WCLK_SRC in CSIS_CTRL register can be set 1, and then assign faster clock Second
 * case: user can set register in camera module through I2C channel. When this
 * interrupt is generated, Turn camera off Assert software reset, if you didn't
 * assert software reset, MIPI CSIS could not receive any more data. Tune the clock
 * frequency and re-configure all related registers MIPI CSIS module is ready for
 * operating.
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_SRC_ERR_OVER (4U) /*!< Bit position for MIPI_CSI2_CSIS_INT_SRC_ERR_OVER. */
#define BM_MIPI_CSI2_CSIS_INT_SRC_ERR_OVER (0x000000F0U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_SRC_ERR_OVER. */
#define BS_MIPI_CSI2_CSIS_INT_SRC_ERR_OVER (4U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_SRC_ERR_OVER. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_SRC_ERR_OVER field. */
#define BR_MIPI_CSI2_CSIS_INT_SRC_ERR_OVER(x) (HW_MIPI_CSI2_CSIS_INT_SRC(x).B.ERR_OVER)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_SRC_ERR_OVER. */
#define BF_MIPI_CSI2_CSIS_INT_SRC_ERR_OVER(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_SRC_ERR_OVER) & BM_MIPI_CSI2_CSIS_INT_SRC_ERR_OVER)

/*! @brief Set the ERR_OVER field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_SRC_ERR_OVER(x, v) (HW_MIPI_CSI2_CSIS_INT_SRC_WR(x, (HW_MIPI_CSI2_CSIS_INT_SRC_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_SRC_ERR_OVER) | BF_MIPI_CSI2_CSIS_INT_SRC_ERR_OVER(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_SRC, field ERR_LOST_FE[11:8] (RW)
 *
 * Indication of lost of Frame End packet, [CH3,CH2,CH1,CH0]
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE (8U) /*!< Bit position for MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE. */
#define BM_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE (0x00000F00U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE. */
#define BS_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE (4U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE field. */
#define BR_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE(x) (HW_MIPI_CSI2_CSIS_INT_SRC(x).B.ERR_LOST_FE)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE. */
#define BF_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE) & BM_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE)

/*! @brief Set the ERR_LOST_FE field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE(x, v) (HW_MIPI_CSI2_CSIS_INT_SRC_WR(x, (HW_MIPI_CSI2_CSIS_INT_SRC_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE) | BF_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FE(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_SRC, field ERR_LOST_FS[15:12] (RW)
 *
 * Indication of lost of Frame Start packet, [CH3,CH2,CH1,CH0]
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS (12U) /*!< Bit position for MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS. */
#define BM_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS (0x0000F000U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS. */
#define BS_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS (4U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS field. */
#define BR_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS(x) (HW_MIPI_CSI2_CSIS_INT_SRC(x).B.ERR_LOST_FS)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS. */
#define BF_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS) & BM_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS)

/*! @brief Set the ERR_LOST_FS field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS(x, v) (HW_MIPI_CSI2_CSIS_INT_SRC_WR(x, (HW_MIPI_CSI2_CSIS_INT_SRC_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS) | BF_MIPI_CSI2_CSIS_INT_SRC_ERR_LOST_FS(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_SRC, field ERR_SOT_HS[19:16] (RW)
 *
 * Start of transmission error, [reserved, reserved, Lane1 , Lane0]
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS (16U) /*!< Bit position for MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS. */
#define BM_MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS (0x000F0000U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS. */
#define BS_MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS (4U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS field. */
#define BR_MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS(x) (HW_MIPI_CSI2_CSIS_INT_SRC(x).B.ERR_SOT_HS)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS. */
#define BF_MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS) & BM_MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS)

/*! @brief Set the ERR_SOT_HS field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS(x, v) (HW_MIPI_CSI2_CSIS_INT_SRC_WR(x, (HW_MIPI_CSI2_CSIS_INT_SRC_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS) | BF_MIPI_CSI2_CSIS_INT_SRC_ERR_SOT_HS(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_SRC, field FRAMEEND[23:20] (RW)
 *
 * FE packet is received, [CH3,CH2,CH1,CH0]
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_SRC_FRAMEEND (20U) /*!< Bit position for MIPI_CSI2_CSIS_INT_SRC_FRAMEEND. */
#define BM_MIPI_CSI2_CSIS_INT_SRC_FRAMEEND (0x00F00000U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_SRC_FRAMEEND. */
#define BS_MIPI_CSI2_CSIS_INT_SRC_FRAMEEND (4U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_SRC_FRAMEEND. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_SRC_FRAMEEND field. */
#define BR_MIPI_CSI2_CSIS_INT_SRC_FRAMEEND(x) (HW_MIPI_CSI2_CSIS_INT_SRC(x).B.FRAMEEND)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_SRC_FRAMEEND. */
#define BF_MIPI_CSI2_CSIS_INT_SRC_FRAMEEND(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_SRC_FRAMEEND) & BM_MIPI_CSI2_CSIS_INT_SRC_FRAMEEND)

/*! @brief Set the FRAMEEND field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_SRC_FRAMEEND(x, v) (HW_MIPI_CSI2_CSIS_INT_SRC_WR(x, (HW_MIPI_CSI2_CSIS_INT_SRC_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_SRC_FRAMEEND) | BF_MIPI_CSI2_CSIS_INT_SRC_FRAMEEND(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_SRC, field FRAMESTART[27:24] (RW)
 *
 * FS packet is received, [CH3,CH2,CH1,CH0]
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_SRC_FRAMESTART (24U) /*!< Bit position for MIPI_CSI2_CSIS_INT_SRC_FRAMESTART. */
#define BM_MIPI_CSI2_CSIS_INT_SRC_FRAMESTART (0x0F000000U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_SRC_FRAMESTART. */
#define BS_MIPI_CSI2_CSIS_INT_SRC_FRAMESTART (4U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_SRC_FRAMESTART. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_SRC_FRAMESTART field. */
#define BR_MIPI_CSI2_CSIS_INT_SRC_FRAMESTART(x) (HW_MIPI_CSI2_CSIS_INT_SRC(x).B.FRAMESTART)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_SRC_FRAMESTART. */
#define BF_MIPI_CSI2_CSIS_INT_SRC_FRAMESTART(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_SRC_FRAMESTART) & BM_MIPI_CSI2_CSIS_INT_SRC_FRAMESTART)

/*! @brief Set the FRAMESTART field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_SRC_FRAMESTART(x, v) (HW_MIPI_CSI2_CSIS_INT_SRC_WR(x, (HW_MIPI_CSI2_CSIS_INT_SRC_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_SRC_FRAMESTART) | BF_MIPI_CSI2_CSIS_INT_SRC_FRAMESTART(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_SRC, field ODDAFTER[28] (RW)
 *
 * Non Image data are received at Odd frame and After Image.
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_SRC_ODDAFTER (28U) /*!< Bit position for MIPI_CSI2_CSIS_INT_SRC_ODDAFTER. */
#define BM_MIPI_CSI2_CSIS_INT_SRC_ODDAFTER (0x10000000U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_SRC_ODDAFTER. */
#define BS_MIPI_CSI2_CSIS_INT_SRC_ODDAFTER (1U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_SRC_ODDAFTER. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_SRC_ODDAFTER field. */
#define BR_MIPI_CSI2_CSIS_INT_SRC_ODDAFTER(x) (HW_MIPI_CSI2_CSIS_INT_SRC(x).B.ODDAFTER)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_SRC_ODDAFTER. */
#define BF_MIPI_CSI2_CSIS_INT_SRC_ODDAFTER(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_SRC_ODDAFTER) & BM_MIPI_CSI2_CSIS_INT_SRC_ODDAFTER)

/*! @brief Set the ODDAFTER field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_SRC_ODDAFTER(x, v) (HW_MIPI_CSI2_CSIS_INT_SRC_WR(x, (HW_MIPI_CSI2_CSIS_INT_SRC_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_SRC_ODDAFTER) | BF_MIPI_CSI2_CSIS_INT_SRC_ODDAFTER(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_SRC, field ODDBEFORE[29] (RW)
 *
 * Non Image data are received at Odd frame and Before Image.
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_SRC_ODDBEFORE (29U) /*!< Bit position for MIPI_CSI2_CSIS_INT_SRC_ODDBEFORE. */
#define BM_MIPI_CSI2_CSIS_INT_SRC_ODDBEFORE (0x20000000U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_SRC_ODDBEFORE. */
#define BS_MIPI_CSI2_CSIS_INT_SRC_ODDBEFORE (1U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_SRC_ODDBEFORE. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_SRC_ODDBEFORE field. */
#define BR_MIPI_CSI2_CSIS_INT_SRC_ODDBEFORE(x) (HW_MIPI_CSI2_CSIS_INT_SRC(x).B.ODDBEFORE)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_SRC_ODDBEFORE. */
#define BF_MIPI_CSI2_CSIS_INT_SRC_ODDBEFORE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_SRC_ODDBEFORE) & BM_MIPI_CSI2_CSIS_INT_SRC_ODDBEFORE)

/*! @brief Set the ODDBEFORE field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_SRC_ODDBEFORE(x, v) (HW_MIPI_CSI2_CSIS_INT_SRC_WR(x, (HW_MIPI_CSI2_CSIS_INT_SRC_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_SRC_ODDBEFORE) | BF_MIPI_CSI2_CSIS_INT_SRC_ODDBEFORE(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_SRC, field EVENAFTER[30] (RW)
 *
 * Non Image data are received at Even frame and After Image.
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_SRC_EVENAFTER (30U) /*!< Bit position for MIPI_CSI2_CSIS_INT_SRC_EVENAFTER. */
#define BM_MIPI_CSI2_CSIS_INT_SRC_EVENAFTER (0x40000000U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_SRC_EVENAFTER. */
#define BS_MIPI_CSI2_CSIS_INT_SRC_EVENAFTER (1U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_SRC_EVENAFTER. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_SRC_EVENAFTER field. */
#define BR_MIPI_CSI2_CSIS_INT_SRC_EVENAFTER(x) (HW_MIPI_CSI2_CSIS_INT_SRC(x).B.EVENAFTER)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_SRC_EVENAFTER. */
#define BF_MIPI_CSI2_CSIS_INT_SRC_EVENAFTER(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_SRC_EVENAFTER) & BM_MIPI_CSI2_CSIS_INT_SRC_EVENAFTER)

/*! @brief Set the EVENAFTER field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_SRC_EVENAFTER(x, v) (HW_MIPI_CSI2_CSIS_INT_SRC_WR(x, (HW_MIPI_CSI2_CSIS_INT_SRC_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_SRC_EVENAFTER) | BF_MIPI_CSI2_CSIS_INT_SRC_EVENAFTER(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_CSIS_INT_SRC, field EVENBEFORE[31] (RW)
 *
 * Non Image data are received at Even frame and Before Image.
 */
/*@{*/
#define BP_MIPI_CSI2_CSIS_INT_SRC_EVENBEFORE (31U) /*!< Bit position for MIPI_CSI2_CSIS_INT_SRC_EVENBEFORE. */
#define BM_MIPI_CSI2_CSIS_INT_SRC_EVENBEFORE (0x80000000U) /*!< Bit mask for MIPI_CSI2_CSIS_INT_SRC_EVENBEFORE. */
#define BS_MIPI_CSI2_CSIS_INT_SRC_EVENBEFORE (1U) /*!< Bit field size in bits for MIPI_CSI2_CSIS_INT_SRC_EVENBEFORE. */

/*! @brief Read current value of the MIPI_CSI2_CSIS_INT_SRC_EVENBEFORE field. */
#define BR_MIPI_CSI2_CSIS_INT_SRC_EVENBEFORE(x) (HW_MIPI_CSI2_CSIS_INT_SRC(x).B.EVENBEFORE)

/*! @brief Format value for bitfield MIPI_CSI2_CSIS_INT_SRC_EVENBEFORE. */
#define BF_MIPI_CSI2_CSIS_INT_SRC_EVENBEFORE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_CSIS_INT_SRC_EVENBEFORE) & BM_MIPI_CSI2_CSIS_INT_SRC_EVENBEFORE)

/*! @brief Set the EVENBEFORE field to a new value. */
#define BW_MIPI_CSI2_CSIS_INT_SRC_EVENBEFORE(x, v) (HW_MIPI_CSI2_CSIS_INT_SRC_WR(x, (HW_MIPI_CSI2_CSIS_INT_SRC_RD(x) & ~BM_MIPI_CSI2_CSIS_INT_SRC_EVENBEFORE) | BF_MIPI_CSI2_CSIS_INT_SRC_EVENBEFORE(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_CSI2_DPHY_STATUS - D-PHY Status
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_DPHY_STATUS - D-PHY Status (RO)
 *
 * Reset value: 0x000000F1U
 */
typedef union _hw_mipi_csi2_dphy_status
{
    uint32_t U;
    struct _hw_mipi_csi2_dphy_status_bitfields
    {
        uint32_t STOPSTATECLK : 1;     /*!< [0]  */
        uint32_t ULPSCLK : 1;          /*!< [1]  */
        uint32_t RSVD6 : 2;            /*!< [3:2] Reserved */
        uint32_t STOPSTATEDAT : 4;     /*!< [7:4]  */
        uint32_t ULPSDAT : 4;          /*!< [11:8]  */
        uint32_t RSVD5 : 20;           /*!< [31:12] Reserved */
    } B;
} hw_mipi_csi2_dphy_status_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_DPHY_STATUS register
 */
/*@{*/
#define HW_MIPI_CSI2_DPHY_STATUS_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_MIPI_CSI2_DPHY_STATUS(x) (*(__I hw_mipi_csi2_dphy_status_t *) HW_MIPI_CSI2_DPHY_STATUS_ADDR(x))
#define HW_MIPI_CSI2_DPHY_STATUS_RD(x) (HW_MIPI_CSI2_DPHY_STATUS(x).U)
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_DPHY_STATUS bitfields
 */

/*!
 * @name Register MIPI_CSI2_DPHY_STATUS, field STOPSTATECLK[0] (RO)
 *
 * Clock lane is in Stop state.
 *
 * Values:
 * - 0 - Not Stop state
 * - 1 - Stop state
 */
/*@{*/
#define BP_MIPI_CSI2_DPHY_STATUS_STOPSTATECLK (0U) /*!< Bit position for MIPI_CSI2_DPHY_STATUS_STOPSTATECLK. */
#define BM_MIPI_CSI2_DPHY_STATUS_STOPSTATECLK (0x00000001U) /*!< Bit mask for MIPI_CSI2_DPHY_STATUS_STOPSTATECLK. */
#define BS_MIPI_CSI2_DPHY_STATUS_STOPSTATECLK (1U) /*!< Bit field size in bits for MIPI_CSI2_DPHY_STATUS_STOPSTATECLK. */

/*! @brief Read current value of the MIPI_CSI2_DPHY_STATUS_STOPSTATECLK field. */
#define BR_MIPI_CSI2_DPHY_STATUS_STOPSTATECLK(x) (HW_MIPI_CSI2_DPHY_STATUS(x).B.STOPSTATECLK)
/*@}*/

/*!
 * @name Register MIPI_CSI2_DPHY_STATUS, field ULPSCLK[1] (RO)
 *
 * Clock lane is in ULPS.
 *
 * Values:
 * - 0 - Not ULPS
 * - 1 - ULPS
 */
/*@{*/
#define BP_MIPI_CSI2_DPHY_STATUS_ULPSCLK (1U) /*!< Bit position for MIPI_CSI2_DPHY_STATUS_ULPSCLK. */
#define BM_MIPI_CSI2_DPHY_STATUS_ULPSCLK (0x00000002U) /*!< Bit mask for MIPI_CSI2_DPHY_STATUS_ULPSCLK. */
#define BS_MIPI_CSI2_DPHY_STATUS_ULPSCLK (1U) /*!< Bit field size in bits for MIPI_CSI2_DPHY_STATUS_ULPSCLK. */

/*! @brief Read current value of the MIPI_CSI2_DPHY_STATUS_ULPSCLK field. */
#define BR_MIPI_CSI2_DPHY_STATUS_ULPSCLK(x) (HW_MIPI_CSI2_DPHY_STATUS(x).B.ULPSCLK)
/*@}*/

/*!
 * @name Register MIPI_CSI2_DPHY_STATUS, field RSVD6[3:2] (RO)
 *
 * Read as zero, do not modify.
 */
/*@{*/
#define BP_MIPI_CSI2_DPHY_STATUS_RSVD6 (2U) /*!< Bit position for MIPI_CSI2_DPHY_STATUS_RSVD6. */
#define BM_MIPI_CSI2_DPHY_STATUS_RSVD6 (0x0000000CU) /*!< Bit mask for MIPI_CSI2_DPHY_STATUS_RSVD6. */
#define BS_MIPI_CSI2_DPHY_STATUS_RSVD6 (2U) /*!< Bit field size in bits for MIPI_CSI2_DPHY_STATUS_RSVD6. */

/*! @brief Read current value of the MIPI_CSI2_DPHY_STATUS_RSVD6 field. */
#define BR_MIPI_CSI2_DPHY_STATUS_RSVD6(x) (HW_MIPI_CSI2_DPHY_STATUS(x).B.RSVD6)
/*@}*/

/*!
 * @name Register MIPI_CSI2_DPHY_STATUS, field STOPSTATEDAT[7:4] (RO)
 *
 * Data lane [3:0] is in Stop State. [7]: Reserved [6]: Reserved [5]: Data lane
 * 1 [4]: Data lane 0
 *
 * Values:
 * - 0 - Not Stop state
 * - 1 - Stop state
 */
/*@{*/
#define BP_MIPI_CSI2_DPHY_STATUS_STOPSTATEDAT (4U) /*!< Bit position for MIPI_CSI2_DPHY_STATUS_STOPSTATEDAT. */
#define BM_MIPI_CSI2_DPHY_STATUS_STOPSTATEDAT (0x000000F0U) /*!< Bit mask for MIPI_CSI2_DPHY_STATUS_STOPSTATEDAT. */
#define BS_MIPI_CSI2_DPHY_STATUS_STOPSTATEDAT (4U) /*!< Bit field size in bits for MIPI_CSI2_DPHY_STATUS_STOPSTATEDAT. */

/*! @brief Read current value of the MIPI_CSI2_DPHY_STATUS_STOPSTATEDAT field. */
#define BR_MIPI_CSI2_DPHY_STATUS_STOPSTATEDAT(x) (HW_MIPI_CSI2_DPHY_STATUS(x).B.STOPSTATEDAT)
/*@}*/

/*!
 * @name Register MIPI_CSI2_DPHY_STATUS, field ULPSDAT[11:8] (RO)
 *
 * Data lane [3:0] is in ULPS. [11]: Reserved [10]: Reserved [9]: Data lane 1
 * [8]: Dsata lane 0
 *
 * Values:
 * - 0 - Not ULPS
 * - 1 - ULPS
 */
/*@{*/
#define BP_MIPI_CSI2_DPHY_STATUS_ULPSDAT (8U) /*!< Bit position for MIPI_CSI2_DPHY_STATUS_ULPSDAT. */
#define BM_MIPI_CSI2_DPHY_STATUS_ULPSDAT (0x00000F00U) /*!< Bit mask for MIPI_CSI2_DPHY_STATUS_ULPSDAT. */
#define BS_MIPI_CSI2_DPHY_STATUS_ULPSDAT (4U) /*!< Bit field size in bits for MIPI_CSI2_DPHY_STATUS_ULPSDAT. */

/*! @brief Read current value of the MIPI_CSI2_DPHY_STATUS_ULPSDAT field. */
#define BR_MIPI_CSI2_DPHY_STATUS_ULPSDAT(x) (HW_MIPI_CSI2_DPHY_STATUS(x).B.ULPSDAT)
/*@}*/

/*!
 * @name Register MIPI_CSI2_DPHY_STATUS, field RSVD5[31:12] (RO)
 *
 * Read as zero, do not modify.
 */
/*@{*/
#define BP_MIPI_CSI2_DPHY_STATUS_RSVD5 (12U) /*!< Bit position for MIPI_CSI2_DPHY_STATUS_RSVD5. */
#define BM_MIPI_CSI2_DPHY_STATUS_RSVD5 (0xFFFFF000U) /*!< Bit mask for MIPI_CSI2_DPHY_STATUS_RSVD5. */
#define BS_MIPI_CSI2_DPHY_STATUS_RSVD5 (20U) /*!< Bit field size in bits for MIPI_CSI2_DPHY_STATUS_RSVD5. */

/*! @brief Read current value of the MIPI_CSI2_DPHY_STATUS_RSVD5 field. */
#define BR_MIPI_CSI2_DPHY_STATUS_RSVD5(x) (HW_MIPI_CSI2_DPHY_STATUS(x).B.RSVD5)
/*@}*/

/*******************************************************************************
 * HW_MIPI_CSI2_DPHY_CMN_CTRL - D-PHY Common Control
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_DPHY_CMN_CTRL - D-PHY Common Control (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mipi_csi2_dphy_cmn_ctrl
{
    uint32_t U;
    struct _hw_mipi_csi2_dphy_cmn_ctrl_bitfields
    {
        uint32_t ENABLE_CLK : 1;       /*!< [0] D-PHY clock lane enable */
        uint32_t ENABLE_DAT : 4;       /*!< [4:1] D-PHY enable */
        uint32_t S_DPDN_SWAP_DAT : 1;  /*!< [5]  */
        uint32_t S_DPDN_SWAP_CLK : 1;  /*!< [6]  */
        uint32_t RSVD7 : 15;           /*!< [21:7] Reserved */
        uint32_t S_CLKSETTLECTL : 2;   /*!< [23:22]  */
        uint32_t HSSETTLE : 8;         /*!< [31:24]  */
    } B;
} hw_mipi_csi2_dphy_cmn_ctrl_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_DPHY_CMN_CTRL register
 */
/*@{*/
#define HW_MIPI_CSI2_DPHY_CMN_CTRL_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_MIPI_CSI2_DPHY_CMN_CTRL(x) (*(__IO hw_mipi_csi2_dphy_cmn_ctrl_t *) HW_MIPI_CSI2_DPHY_CMN_CTRL_ADDR(x))
#define HW_MIPI_CSI2_DPHY_CMN_CTRL_RD(x) (HW_MIPI_CSI2_DPHY_CMN_CTRL(x).U)
#define HW_MIPI_CSI2_DPHY_CMN_CTRL_WR(x, v) (HW_MIPI_CSI2_DPHY_CMN_CTRL(x).U = (v))
#define HW_MIPI_CSI2_DPHY_CMN_CTRL_SET(x, v) (HW_MIPI_CSI2_DPHY_CMN_CTRL_WR(x, HW_MIPI_CSI2_DPHY_CMN_CTRL_RD(x) |  (v)))
#define HW_MIPI_CSI2_DPHY_CMN_CTRL_CLR(x, v) (HW_MIPI_CSI2_DPHY_CMN_CTRL_WR(x, HW_MIPI_CSI2_DPHY_CMN_CTRL_RD(x) & ~(v)))
#define HW_MIPI_CSI2_DPHY_CMN_CTRL_TOG(x, v) (HW_MIPI_CSI2_DPHY_CMN_CTRL_WR(x, HW_MIPI_CSI2_DPHY_CMN_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_DPHY_CMN_CTRL bitfields
 */

/*!
 * @name Register MIPI_CSI2_DPHY_CMN_CTRL, field ENABLE_CLK[0] (RW)
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_CLK (0U) /*!< Bit position for MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_CLK. */
#define BM_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_CLK (0x00000001U) /*!< Bit mask for MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_CLK. */
#define BS_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_CLK (1U) /*!< Bit field size in bits for MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_CLK. */

/*! @brief Read current value of the MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_CLK field. */
#define BR_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_CLK(x) (HW_MIPI_CSI2_DPHY_CMN_CTRL(x).B.ENABLE_CLK)

/*! @brief Format value for bitfield MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_CLK. */
#define BF_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_CLK(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_CLK) & BM_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_CLK)

/*! @brief Set the ENABLE_CLK field to a new value. */
#define BW_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_CLK(x, v) (HW_MIPI_CSI2_DPHY_CMN_CTRL_WR(x, (HW_MIPI_CSI2_DPHY_CMN_CTRL_RD(x) & ~BM_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_CLK) | BF_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_CLK(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DPHY_CMN_CTRL, field ENABLE_DAT[4:1] (RW)
 *
 * [3]: Reserved [2]: Reserved [1]: Data lane 1 [0]: Data lane 0
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT (1U) /*!< Bit position for MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT. */
#define BM_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT (0x0000001EU) /*!< Bit mask for MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT. */
#define BS_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT (4U) /*!< Bit field size in bits for MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT. */

/*! @brief Read current value of the MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT field. */
#define BR_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT(x) (HW_MIPI_CSI2_DPHY_CMN_CTRL(x).B.ENABLE_DAT)

/*! @brief Format value for bitfield MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT. */
#define BF_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT) & BM_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT)

/*! @brief Set the ENABLE_DAT field to a new value. */
#define BW_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT(x, v) (HW_MIPI_CSI2_DPHY_CMN_CTRL_WR(x, (HW_MIPI_CSI2_DPHY_CMN_CTRL_RD(x) & ~BM_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT) | BF_MIPI_CSI2_DPHY_CMN_CTRL_ENABLE_DAT(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DPHY_CMN_CTRL, field S_DPDN_SWAP_DAT[5] (RW)
 *
 * Swapping Dp and Dn channel of data lanes.
 *
 * Values:
 * - 0 - Default
 * - 1 - Swapped
 */
/*@{*/
#define BP_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_DAT (5U) /*!< Bit position for MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_DAT. */
#define BM_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_DAT (0x00000020U) /*!< Bit mask for MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_DAT. */
#define BS_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_DAT (1U) /*!< Bit field size in bits for MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_DAT. */

/*! @brief Read current value of the MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_DAT field. */
#define BR_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_DAT(x) (HW_MIPI_CSI2_DPHY_CMN_CTRL(x).B.S_DPDN_SWAP_DAT)

/*! @brief Format value for bitfield MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_DAT. */
#define BF_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_DAT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_DAT) & BM_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_DAT)

/*! @brief Set the S_DPDN_SWAP_DAT field to a new value. */
#define BW_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_DAT(x, v) (HW_MIPI_CSI2_DPHY_CMN_CTRL_WR(x, (HW_MIPI_CSI2_DPHY_CMN_CTRL_RD(x) & ~BM_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_DAT) | BF_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_DAT(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DPHY_CMN_CTRL, field S_DPDN_SWAP_CLK[6] (RW)
 *
 * Swapping Dp and Dn channel of clock lane.
 *
 * Values:
 * - 0 - Default
 * - 1 - Swapped
 */
/*@{*/
#define BP_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_CLK (6U) /*!< Bit position for MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_CLK. */
#define BM_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_CLK (0x00000040U) /*!< Bit mask for MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_CLK. */
#define BS_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_CLK (1U) /*!< Bit field size in bits for MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_CLK. */

/*! @brief Read current value of the MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_CLK field. */
#define BR_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_CLK(x) (HW_MIPI_CSI2_DPHY_CMN_CTRL(x).B.S_DPDN_SWAP_CLK)

/*! @brief Format value for bitfield MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_CLK. */
#define BF_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_CLK(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_CLK) & BM_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_CLK)

/*! @brief Set the S_DPDN_SWAP_CLK field to a new value. */
#define BW_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_CLK(x, v) (HW_MIPI_CSI2_DPHY_CMN_CTRL_WR(x, (HW_MIPI_CSI2_DPHY_CMN_CTRL_RD(x) & ~BM_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_CLK) | BF_MIPI_CSI2_DPHY_CMN_CTRL_S_DPDN_SWAP_CLK(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DPHY_CMN_CTRL, field RSVD7[21:7] (RO)
 *
 * Read as zero, do not modify.
 */
/*@{*/
#define BP_MIPI_CSI2_DPHY_CMN_CTRL_RSVD7 (7U) /*!< Bit position for MIPI_CSI2_DPHY_CMN_CTRL_RSVD7. */
#define BM_MIPI_CSI2_DPHY_CMN_CTRL_RSVD7 (0x003FFF80U) /*!< Bit mask for MIPI_CSI2_DPHY_CMN_CTRL_RSVD7. */
#define BS_MIPI_CSI2_DPHY_CMN_CTRL_RSVD7 (15U) /*!< Bit field size in bits for MIPI_CSI2_DPHY_CMN_CTRL_RSVD7. */

/*! @brief Read current value of the MIPI_CSI2_DPHY_CMN_CTRL_RSVD7 field. */
#define BR_MIPI_CSI2_DPHY_CMN_CTRL_RSVD7(x) (HW_MIPI_CSI2_DPHY_CMN_CTRL(x).B.RSVD7)
/*@}*/

/*!
 * @name Register MIPI_CSI2_DPHY_CMN_CTRL, field S_CLKSETTLECTL[23:22] (RW)
 *
 * D-PHY control register is for standard spec v0.9 of MIPI CSI2.
 */
/*@{*/
#define BP_MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL (22U) /*!< Bit position for MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL. */
#define BM_MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL (0x00C00000U) /*!< Bit mask for MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL. */
#define BS_MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL (2U) /*!< Bit field size in bits for MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL. */

/*! @brief Read current value of the MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL field. */
#define BR_MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL(x) (HW_MIPI_CSI2_DPHY_CMN_CTRL(x).B.S_CLKSETTLECTL)

/*! @brief Format value for bitfield MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL. */
#define BF_MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL) & BM_MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL)

/*! @brief Set the S_CLKSETTLECTL field to a new value. */
#define BW_MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL(x, v) (HW_MIPI_CSI2_DPHY_CMN_CTRL_WR(x, (HW_MIPI_CSI2_DPHY_CMN_CTRL_RD(x) & ~BM_MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL) | BF_MIPI_CSI2_DPHY_CMN_CTRL_S_CLKSETTLECTL(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DPHY_CMN_CTRL, field HSSETTLE[31:24] (RW)
 *
 * HS-RX settle time control register
 */
/*@{*/
#define BP_MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE (24U) /*!< Bit position for MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE. */
#define BM_MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE (0xFF000000U) /*!< Bit mask for MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE. */
#define BS_MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE (8U) /*!< Bit field size in bits for MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE. */

/*! @brief Read current value of the MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE field. */
#define BR_MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE(x) (HW_MIPI_CSI2_DPHY_CMN_CTRL(x).B.HSSETTLE)

/*! @brief Format value for bitfield MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE. */
#define BF_MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE) & BM_MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE)

/*! @brief Set the HSSETTLE field to a new value. */
#define BW_MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE(x, v) (HW_MIPI_CSI2_DPHY_CMN_CTRL_WR(x, (HW_MIPI_CSI2_DPHY_CMN_CTRL_RD(x) & ~BM_MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE) | BF_MIPI_CSI2_DPHY_CMN_CTRL_HSSETTLE(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_CSI2_DPHY_BCTRL_L - D-PHY Master and Slave Control register low
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_DPHY_BCTRL_L - D-PHY Master and Slave Control register low (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mipi_csi2_dphy_bctrl_l
{
    uint32_t U;
    struct _hw_mipi_csi2_dphy_bctrl_l_bitfields
    {
        uint32_t B_DPHYCTRL : 32;      /*!< [31:0]  */
    } B;
} hw_mipi_csi2_dphy_bctrl_l_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_DPHY_BCTRL_L register
 */
/*@{*/
#define HW_MIPI_CSI2_DPHY_BCTRL_L_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_MIPI_CSI2_DPHY_BCTRL_L(x) (*(__IO hw_mipi_csi2_dphy_bctrl_l_t *) HW_MIPI_CSI2_DPHY_BCTRL_L_ADDR(x))
#define HW_MIPI_CSI2_DPHY_BCTRL_L_RD(x) (HW_MIPI_CSI2_DPHY_BCTRL_L(x).U)
#define HW_MIPI_CSI2_DPHY_BCTRL_L_WR(x, v) (HW_MIPI_CSI2_DPHY_BCTRL_L(x).U = (v))
#define HW_MIPI_CSI2_DPHY_BCTRL_L_SET(x, v) (HW_MIPI_CSI2_DPHY_BCTRL_L_WR(x, HW_MIPI_CSI2_DPHY_BCTRL_L_RD(x) |  (v)))
#define HW_MIPI_CSI2_DPHY_BCTRL_L_CLR(x, v) (HW_MIPI_CSI2_DPHY_BCTRL_L_WR(x, HW_MIPI_CSI2_DPHY_BCTRL_L_RD(x) & ~(v)))
#define HW_MIPI_CSI2_DPHY_BCTRL_L_TOG(x, v) (HW_MIPI_CSI2_DPHY_BCTRL_L_WR(x, HW_MIPI_CSI2_DPHY_BCTRL_L_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_DPHY_BCTRL_L bitfields
 */

/*!
 * @name Register MIPI_CSI2_DPHY_BCTRL_L, field B_DPHYCTRL[31:0] (RW)
 *
 * D-PHY Master and Slave control register Low part
 */
/*@{*/
#define BP_MIPI_CSI2_DPHY_BCTRL_L_B_DPHYCTRL (0U) /*!< Bit position for MIPI_CSI2_DPHY_BCTRL_L_B_DPHYCTRL. */
#define BM_MIPI_CSI2_DPHY_BCTRL_L_B_DPHYCTRL (0xFFFFFFFFU) /*!< Bit mask for MIPI_CSI2_DPHY_BCTRL_L_B_DPHYCTRL. */
#define BS_MIPI_CSI2_DPHY_BCTRL_L_B_DPHYCTRL (32U) /*!< Bit field size in bits for MIPI_CSI2_DPHY_BCTRL_L_B_DPHYCTRL. */

/*! @brief Read current value of the MIPI_CSI2_DPHY_BCTRL_L_B_DPHYCTRL field. */
#define BR_MIPI_CSI2_DPHY_BCTRL_L_B_DPHYCTRL(x) (HW_MIPI_CSI2_DPHY_BCTRL_L(x).U)

/*! @brief Format value for bitfield MIPI_CSI2_DPHY_BCTRL_L_B_DPHYCTRL. */
#define BF_MIPI_CSI2_DPHY_BCTRL_L_B_DPHYCTRL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DPHY_BCTRL_L_B_DPHYCTRL) & BM_MIPI_CSI2_DPHY_BCTRL_L_B_DPHYCTRL)

/*! @brief Set the B_DPHYCTRL field to a new value. */
#define BW_MIPI_CSI2_DPHY_BCTRL_L_B_DPHYCTRL(x, v) (HW_MIPI_CSI2_DPHY_BCTRL_L_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MIPI_CSI2_DPHY_BCTRL_H - D-PHY Master and Slave Control register high
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_DPHY_BCTRL_H - D-PHY Master and Slave Control register high (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mipi_csi2_dphy_bctrl_h
{
    uint32_t U;
    struct _hw_mipi_csi2_dphy_bctrl_h_bitfields
    {
        uint32_t B_DPHYCTRL : 32;      /*!< [31:0]  */
    } B;
} hw_mipi_csi2_dphy_bctrl_h_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_DPHY_BCTRL_H register
 */
/*@{*/
#define HW_MIPI_CSI2_DPHY_BCTRL_H_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_MIPI_CSI2_DPHY_BCTRL_H(x) (*(__IO hw_mipi_csi2_dphy_bctrl_h_t *) HW_MIPI_CSI2_DPHY_BCTRL_H_ADDR(x))
#define HW_MIPI_CSI2_DPHY_BCTRL_H_RD(x) (HW_MIPI_CSI2_DPHY_BCTRL_H(x).U)
#define HW_MIPI_CSI2_DPHY_BCTRL_H_WR(x, v) (HW_MIPI_CSI2_DPHY_BCTRL_H(x).U = (v))
#define HW_MIPI_CSI2_DPHY_BCTRL_H_SET(x, v) (HW_MIPI_CSI2_DPHY_BCTRL_H_WR(x, HW_MIPI_CSI2_DPHY_BCTRL_H_RD(x) |  (v)))
#define HW_MIPI_CSI2_DPHY_BCTRL_H_CLR(x, v) (HW_MIPI_CSI2_DPHY_BCTRL_H_WR(x, HW_MIPI_CSI2_DPHY_BCTRL_H_RD(x) & ~(v)))
#define HW_MIPI_CSI2_DPHY_BCTRL_H_TOG(x, v) (HW_MIPI_CSI2_DPHY_BCTRL_H_WR(x, HW_MIPI_CSI2_DPHY_BCTRL_H_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_DPHY_BCTRL_H bitfields
 */

/*!
 * @name Register MIPI_CSI2_DPHY_BCTRL_H, field B_DPHYCTRL[31:0] (RW)
 *
 * D-PHY Master and Slave control register High part
 */
/*@{*/
#define BP_MIPI_CSI2_DPHY_BCTRL_H_B_DPHYCTRL (0U) /*!< Bit position for MIPI_CSI2_DPHY_BCTRL_H_B_DPHYCTRL. */
#define BM_MIPI_CSI2_DPHY_BCTRL_H_B_DPHYCTRL (0xFFFFFFFFU) /*!< Bit mask for MIPI_CSI2_DPHY_BCTRL_H_B_DPHYCTRL. */
#define BS_MIPI_CSI2_DPHY_BCTRL_H_B_DPHYCTRL (32U) /*!< Bit field size in bits for MIPI_CSI2_DPHY_BCTRL_H_B_DPHYCTRL. */

/*! @brief Read current value of the MIPI_CSI2_DPHY_BCTRL_H_B_DPHYCTRL field. */
#define BR_MIPI_CSI2_DPHY_BCTRL_H_B_DPHYCTRL(x) (HW_MIPI_CSI2_DPHY_BCTRL_H(x).U)

/*! @brief Format value for bitfield MIPI_CSI2_DPHY_BCTRL_H_B_DPHYCTRL. */
#define BF_MIPI_CSI2_DPHY_BCTRL_H_B_DPHYCTRL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DPHY_BCTRL_H_B_DPHYCTRL) & BM_MIPI_CSI2_DPHY_BCTRL_H_B_DPHYCTRL)

/*! @brief Set the B_DPHYCTRL field to a new value. */
#define BW_MIPI_CSI2_DPHY_BCTRL_H_B_DPHYCTRL(x, v) (HW_MIPI_CSI2_DPHY_BCTRL_H_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MIPI_CSI2_DPHY_SCTRL_L - D-PHY Slave Control register low
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_DPHY_SCTRL_L - D-PHY Slave Control register low (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mipi_csi2_dphy_sctrl_l
{
    uint32_t U;
    struct _hw_mipi_csi2_dphy_sctrl_l_bitfields
    {
        uint32_t S_DPHYCTRL : 32;      /*!< [31:0]  */
    } B;
} hw_mipi_csi2_dphy_sctrl_l_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_DPHY_SCTRL_L register
 */
/*@{*/
#define HW_MIPI_CSI2_DPHY_SCTRL_L_ADDR(x) ((uintptr_t)(x) + 0x38U)

#define HW_MIPI_CSI2_DPHY_SCTRL_L(x) (*(__IO hw_mipi_csi2_dphy_sctrl_l_t *) HW_MIPI_CSI2_DPHY_SCTRL_L_ADDR(x))
#define HW_MIPI_CSI2_DPHY_SCTRL_L_RD(x) (HW_MIPI_CSI2_DPHY_SCTRL_L(x).U)
#define HW_MIPI_CSI2_DPHY_SCTRL_L_WR(x, v) (HW_MIPI_CSI2_DPHY_SCTRL_L(x).U = (v))
#define HW_MIPI_CSI2_DPHY_SCTRL_L_SET(x, v) (HW_MIPI_CSI2_DPHY_SCTRL_L_WR(x, HW_MIPI_CSI2_DPHY_SCTRL_L_RD(x) |  (v)))
#define HW_MIPI_CSI2_DPHY_SCTRL_L_CLR(x, v) (HW_MIPI_CSI2_DPHY_SCTRL_L_WR(x, HW_MIPI_CSI2_DPHY_SCTRL_L_RD(x) & ~(v)))
#define HW_MIPI_CSI2_DPHY_SCTRL_L_TOG(x, v) (HW_MIPI_CSI2_DPHY_SCTRL_L_WR(x, HW_MIPI_CSI2_DPHY_SCTRL_L_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_DPHY_SCTRL_L bitfields
 */

/*!
 * @name Register MIPI_CSI2_DPHY_SCTRL_L, field S_DPHYCTRL[31:0] (RW)
 *
 * D-PHY Slave control register Low part
 */
/*@{*/
#define BP_MIPI_CSI2_DPHY_SCTRL_L_S_DPHYCTRL (0U) /*!< Bit position for MIPI_CSI2_DPHY_SCTRL_L_S_DPHYCTRL. */
#define BM_MIPI_CSI2_DPHY_SCTRL_L_S_DPHYCTRL (0xFFFFFFFFU) /*!< Bit mask for MIPI_CSI2_DPHY_SCTRL_L_S_DPHYCTRL. */
#define BS_MIPI_CSI2_DPHY_SCTRL_L_S_DPHYCTRL (32U) /*!< Bit field size in bits for MIPI_CSI2_DPHY_SCTRL_L_S_DPHYCTRL. */

/*! @brief Read current value of the MIPI_CSI2_DPHY_SCTRL_L_S_DPHYCTRL field. */
#define BR_MIPI_CSI2_DPHY_SCTRL_L_S_DPHYCTRL(x) (HW_MIPI_CSI2_DPHY_SCTRL_L(x).U)

/*! @brief Format value for bitfield MIPI_CSI2_DPHY_SCTRL_L_S_DPHYCTRL. */
#define BF_MIPI_CSI2_DPHY_SCTRL_L_S_DPHYCTRL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DPHY_SCTRL_L_S_DPHYCTRL) & BM_MIPI_CSI2_DPHY_SCTRL_L_S_DPHYCTRL)

/*! @brief Set the S_DPHYCTRL field to a new value. */
#define BW_MIPI_CSI2_DPHY_SCTRL_L_S_DPHYCTRL(x, v) (HW_MIPI_CSI2_DPHY_SCTRL_L_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MIPI_CSI2_DPHY_SCTRL_H - D-PHY Slave Control register high
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_DPHY_SCTRL_H - D-PHY Slave Control register high (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mipi_csi2_dphy_sctrl_h
{
    uint32_t U;
    struct _hw_mipi_csi2_dphy_sctrl_h_bitfields
    {
        uint32_t S_DPHYCTRL : 32;      /*!< [31:0]  */
    } B;
} hw_mipi_csi2_dphy_sctrl_h_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_DPHY_SCTRL_H register
 */
/*@{*/
#define HW_MIPI_CSI2_DPHY_SCTRL_H_ADDR(x) ((uintptr_t)(x) + 0x3CU)

#define HW_MIPI_CSI2_DPHY_SCTRL_H(x) (*(__IO hw_mipi_csi2_dphy_sctrl_h_t *) HW_MIPI_CSI2_DPHY_SCTRL_H_ADDR(x))
#define HW_MIPI_CSI2_DPHY_SCTRL_H_RD(x) (HW_MIPI_CSI2_DPHY_SCTRL_H(x).U)
#define HW_MIPI_CSI2_DPHY_SCTRL_H_WR(x, v) (HW_MIPI_CSI2_DPHY_SCTRL_H(x).U = (v))
#define HW_MIPI_CSI2_DPHY_SCTRL_H_SET(x, v) (HW_MIPI_CSI2_DPHY_SCTRL_H_WR(x, HW_MIPI_CSI2_DPHY_SCTRL_H_RD(x) |  (v)))
#define HW_MIPI_CSI2_DPHY_SCTRL_H_CLR(x, v) (HW_MIPI_CSI2_DPHY_SCTRL_H_WR(x, HW_MIPI_CSI2_DPHY_SCTRL_H_RD(x) & ~(v)))
#define HW_MIPI_CSI2_DPHY_SCTRL_H_TOG(x, v) (HW_MIPI_CSI2_DPHY_SCTRL_H_WR(x, HW_MIPI_CSI2_DPHY_SCTRL_H_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_DPHY_SCTRL_H bitfields
 */

/*!
 * @name Register MIPI_CSI2_DPHY_SCTRL_H, field S_DPHYCTRL[31:0] (RW)
 *
 * D-PHY Slave control register High part
 */
/*@{*/
#define BP_MIPI_CSI2_DPHY_SCTRL_H_S_DPHYCTRL (0U) /*!< Bit position for MIPI_CSI2_DPHY_SCTRL_H_S_DPHYCTRL. */
#define BM_MIPI_CSI2_DPHY_SCTRL_H_S_DPHYCTRL (0xFFFFFFFFU) /*!< Bit mask for MIPI_CSI2_DPHY_SCTRL_H_S_DPHYCTRL. */
#define BS_MIPI_CSI2_DPHY_SCTRL_H_S_DPHYCTRL (32U) /*!< Bit field size in bits for MIPI_CSI2_DPHY_SCTRL_H_S_DPHYCTRL. */

/*! @brief Read current value of the MIPI_CSI2_DPHY_SCTRL_H_S_DPHYCTRL field. */
#define BR_MIPI_CSI2_DPHY_SCTRL_H_S_DPHYCTRL(x) (HW_MIPI_CSI2_DPHY_SCTRL_H(x).U)

/*! @brief Format value for bitfield MIPI_CSI2_DPHY_SCTRL_H_S_DPHYCTRL. */
#define BF_MIPI_CSI2_DPHY_SCTRL_H_S_DPHYCTRL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DPHY_SCTRL_H_S_DPHYCTRL) & BM_MIPI_CSI2_DPHY_SCTRL_H_S_DPHYCTRL)

/*! @brief Set the S_DPHYCTRL field to a new value. */
#define BW_MIPI_CSI2_DPHY_SCTRL_H_S_DPHYCTRL(x, v) (HW_MIPI_CSI2_DPHY_SCTRL_H_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MIPI_CSI2_ISP_CONFIG_CH0 - ISP Configuration register of CH0
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_ISP_CONFIG_CH0 - ISP Configuration register of CH0 (RW)
 *
 * Reset value: 0x080008FCU
 */
typedef union _hw_mipi_csi2_isp_config_ch0
{
    uint32_t U;
    struct _hw_mipi_csi2_isp_config_ch0_bitfields
    {
        uint32_t VIRTUAL_CHANNEL : 2;  /*!< [1:0]  */
        uint32_t DATAFORMAT : 6;       /*!< [7:2] Image Data Format */
        uint32_t DECOMP_EN : 1;        /*!< [8] Decompress Enable Do not enable this
                                        * when data format is not RAW6 / 7 / 8 / 10. */
        uint32_t DECOMP_PREDICT : 1;   /*!< [9]  */
        uint32_t RGB_SWAP : 1;         /*!< [10] Swapping RGB sequence */
        uint32_t PARALLEL : 1;         /*!< [11]  */
        uint32_t DOUBLE_CMPNT : 1;     /*!< [12]  */
        uint32_t RSVD8 : 11;           /*!< [23:13] Reserved */
        uint32_t MEM_FULL_GAP : 8;     /*!< [31:24]  */
    } B;
} hw_mipi_csi2_isp_config_ch0_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_ISP_CONFIG_CH0 register
 */
/*@{*/
#define HW_MIPI_CSI2_ISP_CONFIG_CH0_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_MIPI_CSI2_ISP_CONFIG_CH0(x) (*(__IO hw_mipi_csi2_isp_config_ch0_t *) HW_MIPI_CSI2_ISP_CONFIG_CH0_ADDR(x))
#define HW_MIPI_CSI2_ISP_CONFIG_CH0_RD(x) (HW_MIPI_CSI2_ISP_CONFIG_CH0(x).U)
#define HW_MIPI_CSI2_ISP_CONFIG_CH0_WR(x, v) (HW_MIPI_CSI2_ISP_CONFIG_CH0(x).U = (v))
#define HW_MIPI_CSI2_ISP_CONFIG_CH0_SET(x, v) (HW_MIPI_CSI2_ISP_CONFIG_CH0_WR(x, HW_MIPI_CSI2_ISP_CONFIG_CH0_RD(x) |  (v)))
#define HW_MIPI_CSI2_ISP_CONFIG_CH0_CLR(x, v) (HW_MIPI_CSI2_ISP_CONFIG_CH0_WR(x, HW_MIPI_CSI2_ISP_CONFIG_CH0_RD(x) & ~(v)))
#define HW_MIPI_CSI2_ISP_CONFIG_CH0_TOG(x, v) (HW_MIPI_CSI2_ISP_CONFIG_CH0_WR(x, HW_MIPI_CSI2_ISP_CONFIG_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_ISP_CONFIG_CH0 bitfields
 */

/*!
 * @name Register MIPI_CSI2_ISP_CONFIG_CH0, field VIRTUAL_CHANNEL[1:0] (RW)
 *
 * Set Virtual channel for data interleave
 *
 * Values:
 * - 00 - VC = 0
 * - 01 - VC = 1
 * - 10 - VC = 2
 * - 11 - VC = 3
 */
/*@{*/
#define BP_MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL (0U) /*!< Bit position for MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL. */
#define BM_MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL (0x00000003U) /*!< Bit mask for MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL. */
#define BS_MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL (2U) /*!< Bit field size in bits for MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL. */

/*! @brief Read current value of the MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL field. */
#define BR_MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL(x) (HW_MIPI_CSI2_ISP_CONFIG_CH0(x).B.VIRTUAL_CHANNEL)

/*! @brief Format value for bitfield MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL. */
#define BF_MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL) & BM_MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL)

/*! @brief Set the VIRTUAL_CHANNEL field to a new value. */
#define BW_MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL(x, v) (HW_MIPI_CSI2_ISP_CONFIG_CH0_WR(x, (HW_MIPI_CSI2_ISP_CONFIG_CH0_RD(x) & ~BM_MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL) | BF_MIPI_CSI2_ISP_CONFIG_CH0_VIRTUAL_CHANNEL(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_ISP_CONFIG_CH0, field DATAFORMAT[7:2] (RW)
 *
 * Generic Short Packet: 0x08 ~ 0x0F Embedded 8-bit non Image: 0x12 Not
 * described types are ignored. Only VC0 can use the Generic type packets.
 *
 * Values:
 * - 11000 - YUV420 (8-bit)
 * - 11001 - YUV420 (10-bit)
 * - 11010 - YUV420 (8-bit legacy)
 * - 11100 - YUV420 (8-bit CSPS)
 * - 11101 - YUV420 (10-bit CSPS)
 * - 11110 - YUV422 (8-bit)
 * - 11111 - YUV422 (10-bit)
 * - 100010 - RGB565
 * - 100011 - RGB666
 * - 100100 - RGB888
 * - 101000 - RAW6
 * - 101001 - RAW7
 * - 101010 - RAW8
 * - 101011 - RAW10
 * - 101100 - RAW12
 * - 101101 - RAW14
 * - 110000 - User defined 1
 * - 110001 - User defined 2
 * - 110010 - User defined 3
 * - 110011 - User defined 4
 * - 110100 - User defined 5
 * - 110101 - User defined 6
 * - 110110 - User defined 7
 * - 110111 - User defined 8
 */
/*@{*/
#define BP_MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT (2U) /*!< Bit position for MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT. */
#define BM_MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT (0x000000FCU) /*!< Bit mask for MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT. */
#define BS_MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT (6U) /*!< Bit field size in bits for MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT. */

/*! @brief Read current value of the MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT field. */
#define BR_MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT(x) (HW_MIPI_CSI2_ISP_CONFIG_CH0(x).B.DATAFORMAT)

/*! @brief Format value for bitfield MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT. */
#define BF_MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT) & BM_MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT)

/*! @brief Set the DATAFORMAT field to a new value. */
#define BW_MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT(x, v) (HW_MIPI_CSI2_ISP_CONFIG_CH0_WR(x, (HW_MIPI_CSI2_ISP_CONFIG_CH0_RD(x) & ~BM_MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT) | BF_MIPI_CSI2_ISP_CONFIG_CH0_DATAFORMAT(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_ISP_CONFIG_CH0, field DECOMP_EN[8] (RW)
 *
 * Values:
 * - 0 - Disable (default)
 * - 1 - Enable
 */
/*@{*/
#define BP_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_EN (8U) /*!< Bit position for MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_EN. */
#define BM_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_EN (0x00000100U) /*!< Bit mask for MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_EN. */
#define BS_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_EN (1U) /*!< Bit field size in bits for MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_EN. */

/*! @brief Read current value of the MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_EN field. */
#define BR_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_EN(x) (HW_MIPI_CSI2_ISP_CONFIG_CH0(x).B.DECOMP_EN)

/*! @brief Format value for bitfield MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_EN. */
#define BF_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_EN(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_EN) & BM_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_EN)

/*! @brief Set the DECOMP_EN field to a new value. */
#define BW_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_EN(x, v) (HW_MIPI_CSI2_ISP_CONFIG_CH0_WR(x, (HW_MIPI_CSI2_ISP_CONFIG_CH0_RD(x) & ~BM_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_EN) | BF_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_EN(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_ISP_CONFIG_CH0, field DECOMP_PREDICT[9] (RW)
 *
 * Decompress prediction mode of CH0 Cannot use advanced prediction for RAW8 type
 *
 * Values:
 * - 0 - Simple prediction
 * - 1 - Advanced prediction
 */
/*@{*/
#define BP_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_PREDICT (9U) /*!< Bit position for MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_PREDICT. */
#define BM_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_PREDICT (0x00000200U) /*!< Bit mask for MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_PREDICT. */
#define BS_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_PREDICT (1U) /*!< Bit field size in bits for MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_PREDICT. */

/*! @brief Read current value of the MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_PREDICT field. */
#define BR_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_PREDICT(x) (HW_MIPI_CSI2_ISP_CONFIG_CH0(x).B.DECOMP_PREDICT)

/*! @brief Format value for bitfield MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_PREDICT. */
#define BF_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_PREDICT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_PREDICT) & BM_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_PREDICT)

/*! @brief Set the DECOMP_PREDICT field to a new value. */
#define BW_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_PREDICT(x, v) (HW_MIPI_CSI2_ISP_CONFIG_CH0_WR(x, (HW_MIPI_CSI2_ISP_CONFIG_CH0_RD(x) & ~BM_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_PREDICT) | BF_MIPI_CSI2_ISP_CONFIG_CH0_DECOMP_PREDICT(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_ISP_CONFIG_CH0, field RGB_SWAP[10] (RW)
 *
 * Values:
 * - 0 - MSB is R and LSB is B.
 * - 1 - MSB is B and LSB is R (swapped).
 */
/*@{*/
#define BP_MIPI_CSI2_ISP_CONFIG_CH0_RGB_SWAP (10U) /*!< Bit position for MIPI_CSI2_ISP_CONFIG_CH0_RGB_SWAP. */
#define BM_MIPI_CSI2_ISP_CONFIG_CH0_RGB_SWAP (0x00000400U) /*!< Bit mask for MIPI_CSI2_ISP_CONFIG_CH0_RGB_SWAP. */
#define BS_MIPI_CSI2_ISP_CONFIG_CH0_RGB_SWAP (1U) /*!< Bit field size in bits for MIPI_CSI2_ISP_CONFIG_CH0_RGB_SWAP. */

/*! @brief Read current value of the MIPI_CSI2_ISP_CONFIG_CH0_RGB_SWAP field. */
#define BR_MIPI_CSI2_ISP_CONFIG_CH0_RGB_SWAP(x) (HW_MIPI_CSI2_ISP_CONFIG_CH0(x).B.RGB_SWAP)

/*! @brief Format value for bitfield MIPI_CSI2_ISP_CONFIG_CH0_RGB_SWAP. */
#define BF_MIPI_CSI2_ISP_CONFIG_CH0_RGB_SWAP(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_ISP_CONFIG_CH0_RGB_SWAP) & BM_MIPI_CSI2_ISP_CONFIG_CH0_RGB_SWAP)

/*! @brief Set the RGB_SWAP field to a new value. */
#define BW_MIPI_CSI2_ISP_CONFIG_CH0_RGB_SWAP(x, v) (HW_MIPI_CSI2_ISP_CONFIG_CH0_WR(x, (HW_MIPI_CSI2_ISP_CONFIG_CH0_RD(x) & ~BM_MIPI_CSI2_ISP_CONFIG_CH0_RGB_SWAP) | BF_MIPI_CSI2_ISP_CONFIG_CH0_RGB_SWAP(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_ISP_CONFIG_CH0, field PARALLEL[11] (RW)
 *
 * Output bus width of CH0 is 32 bits. When this bit is set, the outer bus width
 * of CSIS V3.3 is 32.
 *
 * Values:
 * - 0 - Normal output
 * - 1 - 32-bit data alignment
 */
/*@{*/
#define BP_MIPI_CSI2_ISP_CONFIG_CH0_PARALLEL (11U) /*!< Bit position for MIPI_CSI2_ISP_CONFIG_CH0_PARALLEL. */
#define BM_MIPI_CSI2_ISP_CONFIG_CH0_PARALLEL (0x00000800U) /*!< Bit mask for MIPI_CSI2_ISP_CONFIG_CH0_PARALLEL. */
#define BS_MIPI_CSI2_ISP_CONFIG_CH0_PARALLEL (1U) /*!< Bit field size in bits for MIPI_CSI2_ISP_CONFIG_CH0_PARALLEL. */

/*! @brief Read current value of the MIPI_CSI2_ISP_CONFIG_CH0_PARALLEL field. */
#define BR_MIPI_CSI2_ISP_CONFIG_CH0_PARALLEL(x) (HW_MIPI_CSI2_ISP_CONFIG_CH0(x).B.PARALLEL)

/*! @brief Format value for bitfield MIPI_CSI2_ISP_CONFIG_CH0_PARALLEL. */
#define BF_MIPI_CSI2_ISP_CONFIG_CH0_PARALLEL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_ISP_CONFIG_CH0_PARALLEL) & BM_MIPI_CSI2_ISP_CONFIG_CH0_PARALLEL)

/*! @brief Set the PARALLEL field to a new value. */
#define BW_MIPI_CSI2_ISP_CONFIG_CH0_PARALLEL(x, v) (HW_MIPI_CSI2_ISP_CONFIG_CH0_WR(x, (HW_MIPI_CSI2_ISP_CONFIG_CH0_RD(x) & ~BM_MIPI_CSI2_ISP_CONFIG_CH0_PARALLEL) | BF_MIPI_CSI2_ISP_CONFIG_CH0_PARALLEL(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_ISP_CONFIG_CH0, field DOUBLE_CMPNT[12] (RW)
 *
 * Double component per clock cycle in YUV422 formats
 *
 * Values:
 * - 0 - Single component per clock cycle (half pixel per clock cycle)
 * - 1 - Double component per clock cycle (a pixel per clock cycle)
 */
/*@{*/
#define BP_MIPI_CSI2_ISP_CONFIG_CH0_DOUBLE_CMPNT (12U) /*!< Bit position for MIPI_CSI2_ISP_CONFIG_CH0_DOUBLE_CMPNT. */
#define BM_MIPI_CSI2_ISP_CONFIG_CH0_DOUBLE_CMPNT (0x00001000U) /*!< Bit mask for MIPI_CSI2_ISP_CONFIG_CH0_DOUBLE_CMPNT. */
#define BS_MIPI_CSI2_ISP_CONFIG_CH0_DOUBLE_CMPNT (1U) /*!< Bit field size in bits for MIPI_CSI2_ISP_CONFIG_CH0_DOUBLE_CMPNT. */

/*! @brief Read current value of the MIPI_CSI2_ISP_CONFIG_CH0_DOUBLE_CMPNT field. */
#define BR_MIPI_CSI2_ISP_CONFIG_CH0_DOUBLE_CMPNT(x) (HW_MIPI_CSI2_ISP_CONFIG_CH0(x).B.DOUBLE_CMPNT)

/*! @brief Format value for bitfield MIPI_CSI2_ISP_CONFIG_CH0_DOUBLE_CMPNT. */
#define BF_MIPI_CSI2_ISP_CONFIG_CH0_DOUBLE_CMPNT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_ISP_CONFIG_CH0_DOUBLE_CMPNT) & BM_MIPI_CSI2_ISP_CONFIG_CH0_DOUBLE_CMPNT)

/*! @brief Set the DOUBLE_CMPNT field to a new value. */
#define BW_MIPI_CSI2_ISP_CONFIG_CH0_DOUBLE_CMPNT(x, v) (HW_MIPI_CSI2_ISP_CONFIG_CH0_WR(x, (HW_MIPI_CSI2_ISP_CONFIG_CH0_RD(x) & ~BM_MIPI_CSI2_ISP_CONFIG_CH0_DOUBLE_CMPNT) | BF_MIPI_CSI2_ISP_CONFIG_CH0_DOUBLE_CMPNT(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_ISP_CONFIG_CH0, field RSVD8[23:13] (RO)
 *
 * Read as zero, do not modify.
 */
/*@{*/
#define BP_MIPI_CSI2_ISP_CONFIG_CH0_RSVD8 (13U) /*!< Bit position for MIPI_CSI2_ISP_CONFIG_CH0_RSVD8. */
#define BM_MIPI_CSI2_ISP_CONFIG_CH0_RSVD8 (0x00FFE000U) /*!< Bit mask for MIPI_CSI2_ISP_CONFIG_CH0_RSVD8. */
#define BS_MIPI_CSI2_ISP_CONFIG_CH0_RSVD8 (11U) /*!< Bit field size in bits for MIPI_CSI2_ISP_CONFIG_CH0_RSVD8. */

/*! @brief Read current value of the MIPI_CSI2_ISP_CONFIG_CH0_RSVD8 field. */
#define BR_MIPI_CSI2_ISP_CONFIG_CH0_RSVD8(x) (HW_MIPI_CSI2_ISP_CONFIG_CH0(x).B.RSVD8)
/*@}*/

/*!
 * @name Register MIPI_CSI2_ISP_CONFIG_CH0, field MEM_FULL_GAP[31:24] (RW)
 *
 * When the room of Image memory is lower than this, STOPREQ_EN is 0, then the
 * image data cannot be blocked (Do not set this register lower than 4).
 */
/*@{*/
#define BP_MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP (24U) /*!< Bit position for MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP. */
#define BM_MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP (0xFF000000U) /*!< Bit mask for MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP. */
#define BS_MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP (8U) /*!< Bit field size in bits for MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP. */

/*! @brief Read current value of the MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP field. */
#define BR_MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP(x) (HW_MIPI_CSI2_ISP_CONFIG_CH0(x).B.MEM_FULL_GAP)

/*! @brief Format value for bitfield MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP. */
#define BF_MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP) & BM_MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP)

/*! @brief Set the MEM_FULL_GAP field to a new value. */
#define BW_MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP(x, v) (HW_MIPI_CSI2_ISP_CONFIG_CH0_WR(x, (HW_MIPI_CSI2_ISP_CONFIG_CH0_RD(x) & ~BM_MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP) | BF_MIPI_CSI2_ISP_CONFIG_CH0_MEM_FULL_GAP(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_CSI2_ISP_RESOL_CH0 - ISP Image Resolution register of CH0
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_ISP_RESOL_CH0 - ISP Image Resolution register of CH0 (RW)
 *
 * Reset value: 0x80008000U
 *
 * When Data format is User defined packet type, this register is ignored.
 */
typedef union _hw_mipi_csi2_isp_resol_ch0
{
    uint32_t U;
    struct _hw_mipi_csi2_isp_resol_ch0_bitfields
    {
        uint32_t HRESOL : 16;          /*!< [15:0] Horizontal Image resolution */
        uint32_t VRESOL : 16;          /*!< [31:16] Vertical Image resolution */
    } B;
} hw_mipi_csi2_isp_resol_ch0_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_ISP_RESOL_CH0 register
 */
/*@{*/
#define HW_MIPI_CSI2_ISP_RESOL_CH0_ADDR(x) ((uintptr_t)(x) + 0x44U)

#define HW_MIPI_CSI2_ISP_RESOL_CH0(x) (*(__IO hw_mipi_csi2_isp_resol_ch0_t *) HW_MIPI_CSI2_ISP_RESOL_CH0_ADDR(x))
#define HW_MIPI_CSI2_ISP_RESOL_CH0_RD(x) (HW_MIPI_CSI2_ISP_RESOL_CH0(x).U)
#define HW_MIPI_CSI2_ISP_RESOL_CH0_WR(x, v) (HW_MIPI_CSI2_ISP_RESOL_CH0(x).U = (v))
#define HW_MIPI_CSI2_ISP_RESOL_CH0_SET(x, v) (HW_MIPI_CSI2_ISP_RESOL_CH0_WR(x, HW_MIPI_CSI2_ISP_RESOL_CH0_RD(x) |  (v)))
#define HW_MIPI_CSI2_ISP_RESOL_CH0_CLR(x, v) (HW_MIPI_CSI2_ISP_RESOL_CH0_WR(x, HW_MIPI_CSI2_ISP_RESOL_CH0_RD(x) & ~(v)))
#define HW_MIPI_CSI2_ISP_RESOL_CH0_TOG(x, v) (HW_MIPI_CSI2_ISP_RESOL_CH0_WR(x, HW_MIPI_CSI2_ISP_RESOL_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_ISP_RESOL_CH0 bitfields
 */

/*!
 * @name Register MIPI_CSI2_ISP_RESOL_CH0, field HRESOL[15:0] (RW)
 *
 * Input boundary of each image format
 */
/*@{*/
#define BP_MIPI_CSI2_ISP_RESOL_CH0_HRESOL (0U) /*!< Bit position for MIPI_CSI2_ISP_RESOL_CH0_HRESOL. */
#define BM_MIPI_CSI2_ISP_RESOL_CH0_HRESOL (0x0000FFFFU) /*!< Bit mask for MIPI_CSI2_ISP_RESOL_CH0_HRESOL. */
#define BS_MIPI_CSI2_ISP_RESOL_CH0_HRESOL (16U) /*!< Bit field size in bits for MIPI_CSI2_ISP_RESOL_CH0_HRESOL. */

/*! @brief Read current value of the MIPI_CSI2_ISP_RESOL_CH0_HRESOL field. */
#define BR_MIPI_CSI2_ISP_RESOL_CH0_HRESOL(x) (HW_MIPI_CSI2_ISP_RESOL_CH0(x).B.HRESOL)

/*! @brief Format value for bitfield MIPI_CSI2_ISP_RESOL_CH0_HRESOL. */
#define BF_MIPI_CSI2_ISP_RESOL_CH0_HRESOL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_ISP_RESOL_CH0_HRESOL) & BM_MIPI_CSI2_ISP_RESOL_CH0_HRESOL)

/*! @brief Set the HRESOL field to a new value. */
#define BW_MIPI_CSI2_ISP_RESOL_CH0_HRESOL(x, v) (HW_MIPI_CSI2_ISP_RESOL_CH0_WR(x, (HW_MIPI_CSI2_ISP_RESOL_CH0_RD(x) & ~BM_MIPI_CSI2_ISP_RESOL_CH0_HRESOL) | BF_MIPI_CSI2_ISP_RESOL_CH0_HRESOL(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_ISP_RESOL_CH0, field VRESOL[31:16] (RW)
 *
 * Input boundary: 0x0001 ~ 0xFFFF
 */
/*@{*/
#define BP_MIPI_CSI2_ISP_RESOL_CH0_VRESOL (16U) /*!< Bit position for MIPI_CSI2_ISP_RESOL_CH0_VRESOL. */
#define BM_MIPI_CSI2_ISP_RESOL_CH0_VRESOL (0xFFFF0000U) /*!< Bit mask for MIPI_CSI2_ISP_RESOL_CH0_VRESOL. */
#define BS_MIPI_CSI2_ISP_RESOL_CH0_VRESOL (16U) /*!< Bit field size in bits for MIPI_CSI2_ISP_RESOL_CH0_VRESOL. */

/*! @brief Read current value of the MIPI_CSI2_ISP_RESOL_CH0_VRESOL field. */
#define BR_MIPI_CSI2_ISP_RESOL_CH0_VRESOL(x) (HW_MIPI_CSI2_ISP_RESOL_CH0(x).B.VRESOL)

/*! @brief Format value for bitfield MIPI_CSI2_ISP_RESOL_CH0_VRESOL. */
#define BF_MIPI_CSI2_ISP_RESOL_CH0_VRESOL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_ISP_RESOL_CH0_VRESOL) & BM_MIPI_CSI2_ISP_RESOL_CH0_VRESOL)

/*! @brief Set the VRESOL field to a new value. */
#define BW_MIPI_CSI2_ISP_RESOL_CH0_VRESOL(x, v) (HW_MIPI_CSI2_ISP_RESOL_CH0_WR(x, (HW_MIPI_CSI2_ISP_RESOL_CH0_RD(x) & ~BM_MIPI_CSI2_ISP_RESOL_CH0_VRESOL) | BF_MIPI_CSI2_ISP_RESOL_CH0_VRESOL(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_CSI2_ISP_SYNC_CH0 - ISP SYNC register of CH0
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_ISP_SYNC_CH0 - ISP SYNC register of CH0 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mipi_csi2_isp_sync_ch0
{
    uint32_t U;
    struct _hw_mipi_csi2_isp_sync_ch0_bitfields
    {
        uint32_t VSYNC_EINTV : 12;     /*!< [11:0]  */
        uint32_t VSYNC_SINTV : 6;      /*!< [17:12]  */
        uint32_t HSYNC_LINTV : 6;      /*!< [23:18]  */
        uint32_t RSVD9 : 8;            /*!< [31:24] Reserved */
    } B;
} hw_mipi_csi2_isp_sync_ch0_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_ISP_SYNC_CH0 register
 */
/*@{*/
#define HW_MIPI_CSI2_ISP_SYNC_CH0_ADDR(x) ((uintptr_t)(x) + 0x48U)

#define HW_MIPI_CSI2_ISP_SYNC_CH0(x) (*(__IO hw_mipi_csi2_isp_sync_ch0_t *) HW_MIPI_CSI2_ISP_SYNC_CH0_ADDR(x))
#define HW_MIPI_CSI2_ISP_SYNC_CH0_RD(x) (HW_MIPI_CSI2_ISP_SYNC_CH0(x).U)
#define HW_MIPI_CSI2_ISP_SYNC_CH0_WR(x, v) (HW_MIPI_CSI2_ISP_SYNC_CH0(x).U = (v))
#define HW_MIPI_CSI2_ISP_SYNC_CH0_SET(x, v) (HW_MIPI_CSI2_ISP_SYNC_CH0_WR(x, HW_MIPI_CSI2_ISP_SYNC_CH0_RD(x) |  (v)))
#define HW_MIPI_CSI2_ISP_SYNC_CH0_CLR(x, v) (HW_MIPI_CSI2_ISP_SYNC_CH0_WR(x, HW_MIPI_CSI2_ISP_SYNC_CH0_RD(x) & ~(v)))
#define HW_MIPI_CSI2_ISP_SYNC_CH0_TOG(x, v) (HW_MIPI_CSI2_ISP_SYNC_CH0_WR(x, HW_MIPI_CSI2_ISP_SYNC_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_ISP_SYNC_CH0 bitfields
 */

/*!
 * @name Register MIPI_CSI2_ISP_SYNC_CH0, field VSYNC_EINTV[11:0] (RW)
 *
 * Interval between last Hsync falling and Vsync falling 12'h000 ~ 12'hFFF cycle
 * of Pixel clock
 */
/*@{*/
#define BP_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV (0U) /*!< Bit position for MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV. */
#define BM_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV (0x00000FFFU) /*!< Bit mask for MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV. */
#define BS_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV (12U) /*!< Bit field size in bits for MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV. */

/*! @brief Read current value of the MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV field. */
#define BR_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV(x) (HW_MIPI_CSI2_ISP_SYNC_CH0(x).B.VSYNC_EINTV)

/*! @brief Format value for bitfield MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV. */
#define BF_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV) & BM_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV)

/*! @brief Set the VSYNC_EINTV field to a new value. */
#define BW_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV(x, v) (HW_MIPI_CSI2_ISP_SYNC_CH0_WR(x, (HW_MIPI_CSI2_ISP_SYNC_CH0_RD(x) & ~BM_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV) | BF_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_EINTV(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_ISP_SYNC_CH0, field VSYNC_SINTV[17:12] (RW)
 *
 * Interval between Vsync rising and first Hsync rising 6'h00 ~ 6'h3F cycle of
 * Pixel clock
 */
/*@{*/
#define BP_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV (12U) /*!< Bit position for MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV. */
#define BM_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV (0x0003F000U) /*!< Bit mask for MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV. */
#define BS_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV (6U) /*!< Bit field size in bits for MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV. */

/*! @brief Read current value of the MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV field. */
#define BR_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV(x) (HW_MIPI_CSI2_ISP_SYNC_CH0(x).B.VSYNC_SINTV)

/*! @brief Format value for bitfield MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV. */
#define BF_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV) & BM_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV)

/*! @brief Set the VSYNC_SINTV field to a new value. */
#define BW_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV(x, v) (HW_MIPI_CSI2_ISP_SYNC_CH0_WR(x, (HW_MIPI_CSI2_ISP_SYNC_CH0_RD(x) & ~BM_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV) | BF_MIPI_CSI2_ISP_SYNC_CH0_VSYNC_SINTV(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_ISP_SYNC_CH0, field HSYNC_LINTV[23:18] (RW)
 *
 * Interval between Hsync falling and Hsync rising (Line interval) 6'h00 ~ 6'h3F
 * cycle of Pixel clock
 */
/*@{*/
#define BP_MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV (18U) /*!< Bit position for MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV. */
#define BM_MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV (0x00FC0000U) /*!< Bit mask for MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV. */
#define BS_MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV (6U) /*!< Bit field size in bits for MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV. */

/*! @brief Read current value of the MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV field. */
#define BR_MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV(x) (HW_MIPI_CSI2_ISP_SYNC_CH0(x).B.HSYNC_LINTV)

/*! @brief Format value for bitfield MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV. */
#define BF_MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV) & BM_MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV)

/*! @brief Set the HSYNC_LINTV field to a new value. */
#define BW_MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV(x, v) (HW_MIPI_CSI2_ISP_SYNC_CH0_WR(x, (HW_MIPI_CSI2_ISP_SYNC_CH0_RD(x) & ~BM_MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV) | BF_MIPI_CSI2_ISP_SYNC_CH0_HSYNC_LINTV(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_ISP_SYNC_CH0, field RSVD9[31:24] (RO)
 *
 * Read as zero, do not modify.
 */
/*@{*/
#define BP_MIPI_CSI2_ISP_SYNC_CH0_RSVD9 (24U) /*!< Bit position for MIPI_CSI2_ISP_SYNC_CH0_RSVD9. */
#define BM_MIPI_CSI2_ISP_SYNC_CH0_RSVD9 (0xFF000000U) /*!< Bit mask for MIPI_CSI2_ISP_SYNC_CH0_RSVD9. */
#define BS_MIPI_CSI2_ISP_SYNC_CH0_RSVD9 (8U) /*!< Bit field size in bits for MIPI_CSI2_ISP_SYNC_CH0_RSVD9. */

/*! @brief Read current value of the MIPI_CSI2_ISP_SYNC_CH0_RSVD9 field. */
#define BR_MIPI_CSI2_ISP_SYNC_CH0_RSVD9(x) (HW_MIPI_CSI2_ISP_SYNC_CH0(x).B.RSVD9)
/*@}*/

/*******************************************************************************
 * HW_MIPI_CSI2_SDW_CONFIG_CH0 - Shadow Configuration register of CH0
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_SDW_CONFIG_CH0 - Shadow Configuration register of CH0 (RO)
 *
 * Reset value: 0x080008FCU
 */
typedef union _hw_mipi_csi2_sdw_config_ch0
{
    uint32_t U;
    struct _hw_mipi_csi2_sdw_config_ch0_bitfields
    {
        uint32_t VIRTUAL_CHANNEL : 2;  /*!< [1:0] Current Virtual channel */
        uint32_t DataFormat : 6;       /*!< [7:2] Current Image Data Format */
        uint32_t DECOMP_EN_SDW : 1;    /*!< [8] Current Decompress enable */
        uint32_t DECOMP_PREDICT_SDW : 1; /*!< [9] Current Decompress
                                        * prediction mode */
        uint32_t RGB_SWAP_SDW : 1;     /*!< [10] Current RGB_SWAP */
        uint32_t PARALLEL_SDW : 1;     /*!< [11] Current Parallel */
        uint32_t DOUBLE_CMPNT_SDW : 1; /*!< [12] Current Double component */
        uint32_t RSVD10 : 11;          /*!< [23:13] Reserved */
        uint32_t NAMEMEM_FULL_GAP_SDW : 8; /*!< [31:24]  */
    } B;
} hw_mipi_csi2_sdw_config_ch0_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_SDW_CONFIG_CH0 register
 */
/*@{*/
#define HW_MIPI_CSI2_SDW_CONFIG_CH0_ADDR(x) ((uintptr_t)(x) + 0x80U)

#define HW_MIPI_CSI2_SDW_CONFIG_CH0(x) (*(__I hw_mipi_csi2_sdw_config_ch0_t *) HW_MIPI_CSI2_SDW_CONFIG_CH0_ADDR(x))
#define HW_MIPI_CSI2_SDW_CONFIG_CH0_RD(x) (HW_MIPI_CSI2_SDW_CONFIG_CH0(x).U)
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_SDW_CONFIG_CH0 bitfields
 */

/*!
 * @name Register MIPI_CSI2_SDW_CONFIG_CH0, field VIRTUAL_CHANNEL[1:0] (RO)
 */
/*@{*/
#define BP_MIPI_CSI2_SDW_CONFIG_CH0_VIRTUAL_CHANNEL (0U) /*!< Bit position for MIPI_CSI2_SDW_CONFIG_CH0_VIRTUAL_CHANNEL. */
#define BM_MIPI_CSI2_SDW_CONFIG_CH0_VIRTUAL_CHANNEL (0x00000003U) /*!< Bit mask for MIPI_CSI2_SDW_CONFIG_CH0_VIRTUAL_CHANNEL. */
#define BS_MIPI_CSI2_SDW_CONFIG_CH0_VIRTUAL_CHANNEL (2U) /*!< Bit field size in bits for MIPI_CSI2_SDW_CONFIG_CH0_VIRTUAL_CHANNEL. */

/*! @brief Read current value of the MIPI_CSI2_SDW_CONFIG_CH0_VIRTUAL_CHANNEL field. */
#define BR_MIPI_CSI2_SDW_CONFIG_CH0_VIRTUAL_CHANNEL(x) (HW_MIPI_CSI2_SDW_CONFIG_CH0(x).B.VIRTUAL_CHANNEL)
/*@}*/

/*!
 * @name Register MIPI_CSI2_SDW_CONFIG_CH0, field DataFormat[7:2] (RO)
 */
/*@{*/
#define BP_MIPI_CSI2_SDW_CONFIG_CH0_DataFormat (2U) /*!< Bit position for MIPI_CSI2_SDW_CONFIG_CH0_DataFormat. */
#define BM_MIPI_CSI2_SDW_CONFIG_CH0_DataFormat (0x000000FCU) /*!< Bit mask for MIPI_CSI2_SDW_CONFIG_CH0_DataFormat. */
#define BS_MIPI_CSI2_SDW_CONFIG_CH0_DataFormat (6U) /*!< Bit field size in bits for MIPI_CSI2_SDW_CONFIG_CH0_DataFormat. */

/*! @brief Read current value of the MIPI_CSI2_SDW_CONFIG_CH0_DataFormat field. */
#define BR_MIPI_CSI2_SDW_CONFIG_CH0_DataFormat(x) (HW_MIPI_CSI2_SDW_CONFIG_CH0(x).B.DataFormat)
/*@}*/

/*!
 * @name Register MIPI_CSI2_SDW_CONFIG_CH0, field DECOMP_EN_SDW[8] (RO)
 */
/*@{*/
#define BP_MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_EN_SDW (8U) /*!< Bit position for MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_EN_SDW. */
#define BM_MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_EN_SDW (0x00000100U) /*!< Bit mask for MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_EN_SDW. */
#define BS_MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_EN_SDW (1U) /*!< Bit field size in bits for MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_EN_SDW. */

/*! @brief Read current value of the MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_EN_SDW field. */
#define BR_MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_EN_SDW(x) (HW_MIPI_CSI2_SDW_CONFIG_CH0(x).B.DECOMP_EN_SDW)
/*@}*/

/*!
 * @name Register MIPI_CSI2_SDW_CONFIG_CH0, field DECOMP_PREDICT_SDW[9] (RO)
 */
/*@{*/
#define BP_MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_PREDICT_SDW (9U) /*!< Bit position for MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_PREDICT_SDW. */
#define BM_MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_PREDICT_SDW (0x00000200U) /*!< Bit mask for MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_PREDICT_SDW. */
#define BS_MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_PREDICT_SDW (1U) /*!< Bit field size in bits for MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_PREDICT_SDW. */

/*! @brief Read current value of the MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_PREDICT_SDW field. */
#define BR_MIPI_CSI2_SDW_CONFIG_CH0_DECOMP_PREDICT_SDW(x) (HW_MIPI_CSI2_SDW_CONFIG_CH0(x).B.DECOMP_PREDICT_SDW)
/*@}*/

/*!
 * @name Register MIPI_CSI2_SDW_CONFIG_CH0, field RGB_SWAP_SDW[10] (RO)
 */
/*@{*/
#define BP_MIPI_CSI2_SDW_CONFIG_CH0_RGB_SWAP_SDW (10U) /*!< Bit position for MIPI_CSI2_SDW_CONFIG_CH0_RGB_SWAP_SDW. */
#define BM_MIPI_CSI2_SDW_CONFIG_CH0_RGB_SWAP_SDW (0x00000400U) /*!< Bit mask for MIPI_CSI2_SDW_CONFIG_CH0_RGB_SWAP_SDW. */
#define BS_MIPI_CSI2_SDW_CONFIG_CH0_RGB_SWAP_SDW (1U) /*!< Bit field size in bits for MIPI_CSI2_SDW_CONFIG_CH0_RGB_SWAP_SDW. */

/*! @brief Read current value of the MIPI_CSI2_SDW_CONFIG_CH0_RGB_SWAP_SDW field. */
#define BR_MIPI_CSI2_SDW_CONFIG_CH0_RGB_SWAP_SDW(x) (HW_MIPI_CSI2_SDW_CONFIG_CH0(x).B.RGB_SWAP_SDW)
/*@}*/

/*!
 * @name Register MIPI_CSI2_SDW_CONFIG_CH0, field PARALLEL_SDW[11] (RO)
 */
/*@{*/
#define BP_MIPI_CSI2_SDW_CONFIG_CH0_PARALLEL_SDW (11U) /*!< Bit position for MIPI_CSI2_SDW_CONFIG_CH0_PARALLEL_SDW. */
#define BM_MIPI_CSI2_SDW_CONFIG_CH0_PARALLEL_SDW (0x00000800U) /*!< Bit mask for MIPI_CSI2_SDW_CONFIG_CH0_PARALLEL_SDW. */
#define BS_MIPI_CSI2_SDW_CONFIG_CH0_PARALLEL_SDW (1U) /*!< Bit field size in bits for MIPI_CSI2_SDW_CONFIG_CH0_PARALLEL_SDW. */

/*! @brief Read current value of the MIPI_CSI2_SDW_CONFIG_CH0_PARALLEL_SDW field. */
#define BR_MIPI_CSI2_SDW_CONFIG_CH0_PARALLEL_SDW(x) (HW_MIPI_CSI2_SDW_CONFIG_CH0(x).B.PARALLEL_SDW)
/*@}*/

/*!
 * @name Register MIPI_CSI2_SDW_CONFIG_CH0, field DOUBLE_CMPNT_SDW[12] (RO)
 */
/*@{*/
#define BP_MIPI_CSI2_SDW_CONFIG_CH0_DOUBLE_CMPNT_SDW (12U) /*!< Bit position for MIPI_CSI2_SDW_CONFIG_CH0_DOUBLE_CMPNT_SDW. */
#define BM_MIPI_CSI2_SDW_CONFIG_CH0_DOUBLE_CMPNT_SDW (0x00001000U) /*!< Bit mask for MIPI_CSI2_SDW_CONFIG_CH0_DOUBLE_CMPNT_SDW. */
#define BS_MIPI_CSI2_SDW_CONFIG_CH0_DOUBLE_CMPNT_SDW (1U) /*!< Bit field size in bits for MIPI_CSI2_SDW_CONFIG_CH0_DOUBLE_CMPNT_SDW. */

/*! @brief Read current value of the MIPI_CSI2_SDW_CONFIG_CH0_DOUBLE_CMPNT_SDW field. */
#define BR_MIPI_CSI2_SDW_CONFIG_CH0_DOUBLE_CMPNT_SDW(x) (HW_MIPI_CSI2_SDW_CONFIG_CH0(x).B.DOUBLE_CMPNT_SDW)
/*@}*/

/*!
 * @name Register MIPI_CSI2_SDW_CONFIG_CH0, field RSVD10[23:13] (RO)
 *
 * Read as zero, do not modify.
 */
/*@{*/
#define BP_MIPI_CSI2_SDW_CONFIG_CH0_RSVD10 (13U) /*!< Bit position for MIPI_CSI2_SDW_CONFIG_CH0_RSVD10. */
#define BM_MIPI_CSI2_SDW_CONFIG_CH0_RSVD10 (0x00FFE000U) /*!< Bit mask for MIPI_CSI2_SDW_CONFIG_CH0_RSVD10. */
#define BS_MIPI_CSI2_SDW_CONFIG_CH0_RSVD10 (11U) /*!< Bit field size in bits for MIPI_CSI2_SDW_CONFIG_CH0_RSVD10. */

/*! @brief Read current value of the MIPI_CSI2_SDW_CONFIG_CH0_RSVD10 field. */
#define BR_MIPI_CSI2_SDW_CONFIG_CH0_RSVD10(x) (HW_MIPI_CSI2_SDW_CONFIG_CH0(x).B.RSVD10)
/*@}*/

/*!
 * @name Register MIPI_CSI2_SDW_CONFIG_CH0, field NAMEMEM_FULL_GAP_SDW[31:24] (RO)
 *
 * Current MEM_FULL_GAP
 */
/*@{*/
#define BP_MIPI_CSI2_SDW_CONFIG_CH0_NAMEMEM_FULL_GAP_SDW (24U) /*!< Bit position for MIPI_CSI2_SDW_CONFIG_CH0_NAMEMEM_FULL_GAP_SDW. */
#define BM_MIPI_CSI2_SDW_CONFIG_CH0_NAMEMEM_FULL_GAP_SDW (0xFF000000U) /*!< Bit mask for MIPI_CSI2_SDW_CONFIG_CH0_NAMEMEM_FULL_GAP_SDW. */
#define BS_MIPI_CSI2_SDW_CONFIG_CH0_NAMEMEM_FULL_GAP_SDW (8U) /*!< Bit field size in bits for MIPI_CSI2_SDW_CONFIG_CH0_NAMEMEM_FULL_GAP_SDW. */

/*! @brief Read current value of the MIPI_CSI2_SDW_CONFIG_CH0_NAMEMEM_FULL_GAP_SDW field. */
#define BR_MIPI_CSI2_SDW_CONFIG_CH0_NAMEMEM_FULL_GAP_SDW(x) (HW_MIPI_CSI2_SDW_CONFIG_CH0(x).B.NAMEMEM_FULL_GAP_SDW)
/*@}*/

/*******************************************************************************
 * HW_MIPI_CSI2_SDW_RESOL_CH0 - Shadow Resolution register of CH0
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_SDW_RESOL_CH0 - Shadow Resolution register of CH0 (RO)
 *
 * Reset value: 0x08000800U
 */
typedef union _hw_mipi_csi2_sdw_resol_ch0
{
    uint32_t U;
    struct _hw_mipi_csi2_sdw_resol_ch0_bitfields
    {
        uint32_t HRESOL_SDW : 16;      /*!< [15:0] Current Horizontal Image
                                        * resolution */
        uint32_t VRESOL_SDW : 16;      /*!< [31:16] Current Vertical Image
                                        * resolution */
    } B;
} hw_mipi_csi2_sdw_resol_ch0_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_SDW_RESOL_CH0 register
 */
/*@{*/
#define HW_MIPI_CSI2_SDW_RESOL_CH0_ADDR(x) ((uintptr_t)(x) + 0x84U)

#define HW_MIPI_CSI2_SDW_RESOL_CH0(x) (*(__I hw_mipi_csi2_sdw_resol_ch0_t *) HW_MIPI_CSI2_SDW_RESOL_CH0_ADDR(x))
#define HW_MIPI_CSI2_SDW_RESOL_CH0_RD(x) (HW_MIPI_CSI2_SDW_RESOL_CH0(x).U)
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_SDW_RESOL_CH0 bitfields
 */

/*!
 * @name Register MIPI_CSI2_SDW_RESOL_CH0, field HRESOL_SDW[15:0] (RO)
 */
/*@{*/
#define BP_MIPI_CSI2_SDW_RESOL_CH0_HRESOL_SDW (0U) /*!< Bit position for MIPI_CSI2_SDW_RESOL_CH0_HRESOL_SDW. */
#define BM_MIPI_CSI2_SDW_RESOL_CH0_HRESOL_SDW (0x0000FFFFU) /*!< Bit mask for MIPI_CSI2_SDW_RESOL_CH0_HRESOL_SDW. */
#define BS_MIPI_CSI2_SDW_RESOL_CH0_HRESOL_SDW (16U) /*!< Bit field size in bits for MIPI_CSI2_SDW_RESOL_CH0_HRESOL_SDW. */

/*! @brief Read current value of the MIPI_CSI2_SDW_RESOL_CH0_HRESOL_SDW field. */
#define BR_MIPI_CSI2_SDW_RESOL_CH0_HRESOL_SDW(x) (HW_MIPI_CSI2_SDW_RESOL_CH0(x).B.HRESOL_SDW)
/*@}*/

/*!
 * @name Register MIPI_CSI2_SDW_RESOL_CH0, field VRESOL_SDW[31:16] (RO)
 */
/*@{*/
#define BP_MIPI_CSI2_SDW_RESOL_CH0_VRESOL_SDW (16U) /*!< Bit position for MIPI_CSI2_SDW_RESOL_CH0_VRESOL_SDW. */
#define BM_MIPI_CSI2_SDW_RESOL_CH0_VRESOL_SDW (0xFFFF0000U) /*!< Bit mask for MIPI_CSI2_SDW_RESOL_CH0_VRESOL_SDW. */
#define BS_MIPI_CSI2_SDW_RESOL_CH0_VRESOL_SDW (16U) /*!< Bit field size in bits for MIPI_CSI2_SDW_RESOL_CH0_VRESOL_SDW. */

/*! @brief Read current value of the MIPI_CSI2_SDW_RESOL_CH0_VRESOL_SDW field. */
#define BR_MIPI_CSI2_SDW_RESOL_CH0_VRESOL_SDW(x) (HW_MIPI_CSI2_SDW_RESOL_CH0(x).B.VRESOL_SDW)
/*@}*/

/*******************************************************************************
 * HW_MIPI_CSI2_SDW_SYNC_CH0 - Shadow SYNC register of CH0
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_SDW_SYNC_CH0 - Shadow SYNC register of CH0 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mipi_csi2_sdw_sync_ch0
{
    uint32_t U;
    struct _hw_mipi_csi2_sdw_sync_ch0_bitfields
    {
        uint32_t VSYNC_EINTV_SDW : 12; /*!< [11:0]  */
        uint32_t VSYNC_SINTV_SDW : 6;  /*!< [17:12]  */
        uint32_t HSYNC_LINTV_SDW : 6;  /*!< [23:18]  */
        uint32_t RSVD11 : 8;           /*!< [31:24] Reserved */
    } B;
} hw_mipi_csi2_sdw_sync_ch0_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_SDW_SYNC_CH0 register
 */
/*@{*/
#define HW_MIPI_CSI2_SDW_SYNC_CH0_ADDR(x) ((uintptr_t)(x) + 0x88U)

#define HW_MIPI_CSI2_SDW_SYNC_CH0(x) (*(__I hw_mipi_csi2_sdw_sync_ch0_t *) HW_MIPI_CSI2_SDW_SYNC_CH0_ADDR(x))
#define HW_MIPI_CSI2_SDW_SYNC_CH0_RD(x) (HW_MIPI_CSI2_SDW_SYNC_CH0(x).U)
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_SDW_SYNC_CH0 bitfields
 */

/*!
 * @name Register MIPI_CSI2_SDW_SYNC_CH0, field VSYNC_EINTV_SDW[11:0] (RO)
 *
 * Current interval between last Hsync falling and Vsync falling
 */
/*@{*/
#define BP_MIPI_CSI2_SDW_SYNC_CH0_VSYNC_EINTV_SDW (0U) /*!< Bit position for MIPI_CSI2_SDW_SYNC_CH0_VSYNC_EINTV_SDW. */
#define BM_MIPI_CSI2_SDW_SYNC_CH0_VSYNC_EINTV_SDW (0x00000FFFU) /*!< Bit mask for MIPI_CSI2_SDW_SYNC_CH0_VSYNC_EINTV_SDW. */
#define BS_MIPI_CSI2_SDW_SYNC_CH0_VSYNC_EINTV_SDW (12U) /*!< Bit field size in bits for MIPI_CSI2_SDW_SYNC_CH0_VSYNC_EINTV_SDW. */

/*! @brief Read current value of the MIPI_CSI2_SDW_SYNC_CH0_VSYNC_EINTV_SDW field. */
#define BR_MIPI_CSI2_SDW_SYNC_CH0_VSYNC_EINTV_SDW(x) (HW_MIPI_CSI2_SDW_SYNC_CH0(x).B.VSYNC_EINTV_SDW)
/*@}*/

/*!
 * @name Register MIPI_CSI2_SDW_SYNC_CH0, field VSYNC_SINTV_SDW[17:12] (RO)
 *
 * Current interval between Vsync rising and first Hsync rising
 */
/*@{*/
#define BP_MIPI_CSI2_SDW_SYNC_CH0_VSYNC_SINTV_SDW (12U) /*!< Bit position for MIPI_CSI2_SDW_SYNC_CH0_VSYNC_SINTV_SDW. */
#define BM_MIPI_CSI2_SDW_SYNC_CH0_VSYNC_SINTV_SDW (0x0003F000U) /*!< Bit mask for MIPI_CSI2_SDW_SYNC_CH0_VSYNC_SINTV_SDW. */
#define BS_MIPI_CSI2_SDW_SYNC_CH0_VSYNC_SINTV_SDW (6U) /*!< Bit field size in bits for MIPI_CSI2_SDW_SYNC_CH0_VSYNC_SINTV_SDW. */

/*! @brief Read current value of the MIPI_CSI2_SDW_SYNC_CH0_VSYNC_SINTV_SDW field. */
#define BR_MIPI_CSI2_SDW_SYNC_CH0_VSYNC_SINTV_SDW(x) (HW_MIPI_CSI2_SDW_SYNC_CH0(x).B.VSYNC_SINTV_SDW)
/*@}*/

/*!
 * @name Register MIPI_CSI2_SDW_SYNC_CH0, field HSYNC_LINTV_SDW[23:18] (RO)
 *
 * Current interval between Hsync falling and Hsync rising (Line interval)
 */
/*@{*/
#define BP_MIPI_CSI2_SDW_SYNC_CH0_HSYNC_LINTV_SDW (18U) /*!< Bit position for MIPI_CSI2_SDW_SYNC_CH0_HSYNC_LINTV_SDW. */
#define BM_MIPI_CSI2_SDW_SYNC_CH0_HSYNC_LINTV_SDW (0x00FC0000U) /*!< Bit mask for MIPI_CSI2_SDW_SYNC_CH0_HSYNC_LINTV_SDW. */
#define BS_MIPI_CSI2_SDW_SYNC_CH0_HSYNC_LINTV_SDW (6U) /*!< Bit field size in bits for MIPI_CSI2_SDW_SYNC_CH0_HSYNC_LINTV_SDW. */

/*! @brief Read current value of the MIPI_CSI2_SDW_SYNC_CH0_HSYNC_LINTV_SDW field. */
#define BR_MIPI_CSI2_SDW_SYNC_CH0_HSYNC_LINTV_SDW(x) (HW_MIPI_CSI2_SDW_SYNC_CH0(x).B.HSYNC_LINTV_SDW)
/*@}*/

/*!
 * @name Register MIPI_CSI2_SDW_SYNC_CH0, field RSVD11[31:24] (RO)
 *
 * Read as zero, do not modify.
 */
/*@{*/
#define BP_MIPI_CSI2_SDW_SYNC_CH0_RSVD11 (24U) /*!< Bit position for MIPI_CSI2_SDW_SYNC_CH0_RSVD11. */
#define BM_MIPI_CSI2_SDW_SYNC_CH0_RSVD11 (0xFF000000U) /*!< Bit mask for MIPI_CSI2_SDW_SYNC_CH0_RSVD11. */
#define BS_MIPI_CSI2_SDW_SYNC_CH0_RSVD11 (8U) /*!< Bit field size in bits for MIPI_CSI2_SDW_SYNC_CH0_RSVD11. */

/*! @brief Read current value of the MIPI_CSI2_SDW_SYNC_CH0_RSVD11 field. */
#define BR_MIPI_CSI2_SDW_SYNC_CH0_RSVD11(x) (HW_MIPI_CSI2_SDW_SYNC_CH0(x).B.RSVD11)
/*@}*/

/*******************************************************************************
 * HW_MIPI_CSI2_DBG_CTRL - Debug Control register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_DBG_CTRL - Debug Control register (RW)
 *
 * Reset value: 0x00000F00U
 *
 * In the case of FS or FE lost during continous frame transfers, CSIS transfer
 * the data of second frame as it belongs to the first frame when
 * DBG_BLK_EXC_FRAME is low. DBG_CH_OUTPUT forces the result of demux for the incoming packet.
 */
typedef union _hw_mipi_csi2_dbg_ctrl
{
    uint32_t U;
    struct _hw_mipi_csi2_dbg_ctrl_bitfields
    {
        uint32_t DBG_CH_OUTPUT : 4;    /*!< [3:0]  */
        uint32_t DBG_BLK_EXC_FRAME : 4; /*!< [7:4]  */
        uint32_t DBG_DONT_STOP_LAST_LINE : 4; /*!< [11:8]  */
        uint32_t DBG_FORCE_UPDATE : 4; /*!< [15:12]  */
        uint32_t RSVD12 : 16;          /*!< [31:16] Reserved */
    } B;
} hw_mipi_csi2_dbg_ctrl_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_DBG_CTRL register
 */
/*@{*/
#define HW_MIPI_CSI2_DBG_CTRL_ADDR(x) ((uintptr_t)(x) + 0xC0U)

#define HW_MIPI_CSI2_DBG_CTRL(x) (*(__IO hw_mipi_csi2_dbg_ctrl_t *) HW_MIPI_CSI2_DBG_CTRL_ADDR(x))
#define HW_MIPI_CSI2_DBG_CTRL_RD(x) (HW_MIPI_CSI2_DBG_CTRL(x).U)
#define HW_MIPI_CSI2_DBG_CTRL_WR(x, v) (HW_MIPI_CSI2_DBG_CTRL(x).U = (v))
#define HW_MIPI_CSI2_DBG_CTRL_SET(x, v) (HW_MIPI_CSI2_DBG_CTRL_WR(x, HW_MIPI_CSI2_DBG_CTRL_RD(x) |  (v)))
#define HW_MIPI_CSI2_DBG_CTRL_CLR(x, v) (HW_MIPI_CSI2_DBG_CTRL_WR(x, HW_MIPI_CSI2_DBG_CTRL_RD(x) & ~(v)))
#define HW_MIPI_CSI2_DBG_CTRL_TOG(x, v) (HW_MIPI_CSI2_DBG_CTRL_WR(x, HW_MIPI_CSI2_DBG_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_DBG_CTRL bitfields
 */

/*!
 * @name Register MIPI_CSI2_DBG_CTRL, field DBG_CH_OUTPUT[3:0] (RW)
 *
 * [3] CH3 [2] CH2 [1] CH1 [0] CH0
 *
 * Values:
 * - 1 - Force the channel output to 1
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT (0U) /*!< Bit position for MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT. */
#define BM_MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT (0x0000000FU) /*!< Bit mask for MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT. */
#define BS_MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT (4U) /*!< Bit field size in bits for MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT. */

/*! @brief Read current value of the MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT field. */
#define BR_MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT(x) (HW_MIPI_CSI2_DBG_CTRL(x).B.DBG_CH_OUTPUT)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT. */
#define BF_MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT) & BM_MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT)

/*! @brief Set the DBG_CH_OUTPUT field to a new value. */
#define BW_MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT(x, v) (HW_MIPI_CSI2_DBG_CTRL_WR(x, (HW_MIPI_CSI2_DBG_CTRL_RD(x) & ~BM_MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT) | BF_MIPI_CSI2_DBG_CTRL_DBG_CH_OUTPUT(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_CTRL, field DBG_BLK_EXC_FRAME[7:4] (RW)
 *
 * [7] CH3 [6] CH2 [5] CH1 [4] CH0
 *
 * Values:
 * - 0 - Do not block the exceeded frame
 * - 1 - Block the exceeded frame
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME (4U) /*!< Bit position for MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME. */
#define BM_MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME (0x000000F0U) /*!< Bit mask for MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME. */
#define BS_MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME (4U) /*!< Bit field size in bits for MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME. */

/*! @brief Read current value of the MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME field. */
#define BR_MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME(x) (HW_MIPI_CSI2_DBG_CTRL(x).B.DBG_BLK_EXC_FRAME)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME. */
#define BF_MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME) & BM_MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME)

/*! @brief Set the DBG_BLK_EXC_FRAME field to a new value. */
#define BW_MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME(x, v) (HW_MIPI_CSI2_DBG_CTRL_WR(x, (HW_MIPI_CSI2_DBG_CTRL_RD(x) & ~BM_MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME) | BF_MIPI_CSI2_DBG_CTRL_DBG_BLK_EXC_FRAME(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_CTRL, field DBG_DONT_STOP_LAST_LINE[11:8] (RW)
 *
 * [11] CH3 [10] CH2 [9] CH1 [8] CH0
 *
 * Values:
 * - 0 - Can receive STOP_REQ from ISP any time
 * - 1 - Ignore STOP_REQ from ISP at the LAST_LINE
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE (8U) /*!< Bit position for MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE. */
#define BM_MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE (0x00000F00U) /*!< Bit mask for MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE. */
#define BS_MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE (4U) /*!< Bit field size in bits for MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE. */

/*! @brief Read current value of the MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE field. */
#define BR_MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE(x) (HW_MIPI_CSI2_DBG_CTRL(x).B.DBG_DONT_STOP_LAST_LINE)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE. */
#define BF_MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE) & BM_MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE)

/*! @brief Set the DBG_DONT_STOP_LAST_LINE field to a new value. */
#define BW_MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE(x, v) (HW_MIPI_CSI2_DBG_CTRL_WR(x, (HW_MIPI_CSI2_DBG_CTRL_RD(x) & ~BM_MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE) | BF_MIPI_CSI2_DBG_CTRL_DBG_DONT_STOP_LAST_LINE(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_CTRL, field DBG_FORCE_UPDATE[15:12] (RW)
 *
 * [15] CH3 [14] CH2 [13] CH1 [12] CH0
 *
 * Values:
 * - 0 - Update shadow reg normally
 * - 1 - Force to update shadow reg without waiting end of frame
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE (12U) /*!< Bit position for MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE. */
#define BM_MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE (0x0000F000U) /*!< Bit mask for MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE. */
#define BS_MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE (4U) /*!< Bit field size in bits for MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE. */

/*! @brief Read current value of the MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE field. */
#define BR_MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE(x) (HW_MIPI_CSI2_DBG_CTRL(x).B.DBG_FORCE_UPDATE)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE. */
#define BF_MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE) & BM_MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE)

/*! @brief Set the DBG_FORCE_UPDATE field to a new value. */
#define BW_MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE(x, v) (HW_MIPI_CSI2_DBG_CTRL_WR(x, (HW_MIPI_CSI2_DBG_CTRL_RD(x) & ~BM_MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE) | BF_MIPI_CSI2_DBG_CTRL_DBG_FORCE_UPDATE(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_CTRL, field RSVD12[31:16] (RO)
 *
 * Read as zero, do not modify.
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_CTRL_RSVD12 (16U) /*!< Bit position for MIPI_CSI2_DBG_CTRL_RSVD12. */
#define BM_MIPI_CSI2_DBG_CTRL_RSVD12 (0xFFFF0000U) /*!< Bit mask for MIPI_CSI2_DBG_CTRL_RSVD12. */
#define BS_MIPI_CSI2_DBG_CTRL_RSVD12 (16U) /*!< Bit field size in bits for MIPI_CSI2_DBG_CTRL_RSVD12. */

/*! @brief Read current value of the MIPI_CSI2_DBG_CTRL_RSVD12 field. */
#define BR_MIPI_CSI2_DBG_CTRL_RSVD12(x) (HW_MIPI_CSI2_DBG_CTRL(x).B.RSVD12)
/*@}*/

/*******************************************************************************
 * HW_MIPI_CSI2_DBG_INTR_MSK - Debug Interrupt Mask
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_DBG_INTR_MSK - Debug Interrupt Mask (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mipi_csi2_dbg_intr_msk
{
    uint32_t U;
    struct _hw_mipi_csi2_dbg_intr_msk_bitfields
    {
        uint32_t CAM_VSYNC_RISE : 4;   /*!< [3:0]  */
        uint32_t CAM_VSYNC_FALL : 4;   /*!< [7:4]  */
        uint32_t EARLY_FS : 4;         /*!< [11:8] Early FS */
        uint32_t EARLY_FE : 4;         /*!< [15:12] Early FE */
        uint32_t TRUNCATED_FRAME : 4;  /*!< [19:16] Truncated Frame */
        uint32_t ERR_FRAME_SIZE : 4;   /*!< [23:20] Error Frame Size */
        uint32_t DT_IGNORE : 1;        /*!< [24] DT_IGNORE */
        uint32_t DT_NOT_SUPPORT : 1;   /*!< [25] DT_NOT_SUPPORT */
        uint32_t RSVD13 : 6;           /*!< [31:26] Reserved */
    } B;
} hw_mipi_csi2_dbg_intr_msk_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_DBG_INTR_MSK register
 */
/*@{*/
#define HW_MIPI_CSI2_DBG_INTR_MSK_ADDR(x) ((uintptr_t)(x) + 0xC4U)

#define HW_MIPI_CSI2_DBG_INTR_MSK(x) (*(__IO hw_mipi_csi2_dbg_intr_msk_t *) HW_MIPI_CSI2_DBG_INTR_MSK_ADDR(x))
#define HW_MIPI_CSI2_DBG_INTR_MSK_RD(x) (HW_MIPI_CSI2_DBG_INTR_MSK(x).U)
#define HW_MIPI_CSI2_DBG_INTR_MSK_WR(x, v) (HW_MIPI_CSI2_DBG_INTR_MSK(x).U = (v))
#define HW_MIPI_CSI2_DBG_INTR_MSK_SET(x, v) (HW_MIPI_CSI2_DBG_INTR_MSK_WR(x, HW_MIPI_CSI2_DBG_INTR_MSK_RD(x) |  (v)))
#define HW_MIPI_CSI2_DBG_INTR_MSK_CLR(x, v) (HW_MIPI_CSI2_DBG_INTR_MSK_WR(x, HW_MIPI_CSI2_DBG_INTR_MSK_RD(x) & ~(v)))
#define HW_MIPI_CSI2_DBG_INTR_MSK_TOG(x, v) (HW_MIPI_CSI2_DBG_INTR_MSK_WR(x, HW_MIPI_CSI2_DBG_INTR_MSK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_DBG_INTR_MSK bitfields
 */

/*!
 * @name Register MIPI_CSI2_DBG_INTR_MSK, field CAM_VSYNC_RISE[3:0] (RW)
 *
 * [3] CH3 [2] CH2 [1] CH1 [0] CH0
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE (0U) /*!< Bit position for MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE. */
#define BM_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE (0x0000000FU) /*!< Bit mask for MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE. */
#define BS_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE (4U) /*!< Bit field size in bits for MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE. */

/*! @brief Read current value of the MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE field. */
#define BR_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE(x) (HW_MIPI_CSI2_DBG_INTR_MSK(x).B.CAM_VSYNC_RISE)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE. */
#define BF_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE) & BM_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE)

/*! @brief Set the CAM_VSYNC_RISE field to a new value. */
#define BW_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE(x, v) (HW_MIPI_CSI2_DBG_INTR_MSK_WR(x, (HW_MIPI_CSI2_DBG_INTR_MSK_RD(x) & ~BM_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE) | BF_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_RISE(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_INTR_MSK, field CAM_VSYNC_FALL[7:4] (RW)
 *
 * [7] CH3 [6] CH2 [5] CH1 [4] CH0
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL (4U) /*!< Bit position for MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL. */
#define BM_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL (0x000000F0U) /*!< Bit mask for MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL. */
#define BS_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL (4U) /*!< Bit field size in bits for MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL. */

/*! @brief Read current value of the MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL field. */
#define BR_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL(x) (HW_MIPI_CSI2_DBG_INTR_MSK(x).B.CAM_VSYNC_FALL)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL. */
#define BF_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL) & BM_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL)

/*! @brief Set the CAM_VSYNC_FALL field to a new value. */
#define BW_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL(x, v) (HW_MIPI_CSI2_DBG_INTR_MSK_WR(x, (HW_MIPI_CSI2_DBG_INTR_MSK_RD(x) & ~BM_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL) | BF_MIPI_CSI2_DBG_INTR_MSK_CAM_VSYNC_FALL(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_INTR_MSK, field EARLY_FS[11:8] (RW)
 *
 * [11] CH3 [10] CH2 [9] CH1 [8] CH0
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_INTR_MSK_EARLY_FS (8U) /*!< Bit position for MIPI_CSI2_DBG_INTR_MSK_EARLY_FS. */
#define BM_MIPI_CSI2_DBG_INTR_MSK_EARLY_FS (0x00000F00U) /*!< Bit mask for MIPI_CSI2_DBG_INTR_MSK_EARLY_FS. */
#define BS_MIPI_CSI2_DBG_INTR_MSK_EARLY_FS (4U) /*!< Bit field size in bits for MIPI_CSI2_DBG_INTR_MSK_EARLY_FS. */

/*! @brief Read current value of the MIPI_CSI2_DBG_INTR_MSK_EARLY_FS field. */
#define BR_MIPI_CSI2_DBG_INTR_MSK_EARLY_FS(x) (HW_MIPI_CSI2_DBG_INTR_MSK(x).B.EARLY_FS)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_INTR_MSK_EARLY_FS. */
#define BF_MIPI_CSI2_DBG_INTR_MSK_EARLY_FS(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_INTR_MSK_EARLY_FS) & BM_MIPI_CSI2_DBG_INTR_MSK_EARLY_FS)

/*! @brief Set the EARLY_FS field to a new value. */
#define BW_MIPI_CSI2_DBG_INTR_MSK_EARLY_FS(x, v) (HW_MIPI_CSI2_DBG_INTR_MSK_WR(x, (HW_MIPI_CSI2_DBG_INTR_MSK_RD(x) & ~BM_MIPI_CSI2_DBG_INTR_MSK_EARLY_FS) | BF_MIPI_CSI2_DBG_INTR_MSK_EARLY_FS(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_INTR_MSK, field EARLY_FE[15:12] (RW)
 *
 * [15] CH3 [14] CH2 [13] CH1 [12] CH0
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_INTR_MSK_EARLY_FE (12U) /*!< Bit position for MIPI_CSI2_DBG_INTR_MSK_EARLY_FE. */
#define BM_MIPI_CSI2_DBG_INTR_MSK_EARLY_FE (0x0000F000U) /*!< Bit mask for MIPI_CSI2_DBG_INTR_MSK_EARLY_FE. */
#define BS_MIPI_CSI2_DBG_INTR_MSK_EARLY_FE (4U) /*!< Bit field size in bits for MIPI_CSI2_DBG_INTR_MSK_EARLY_FE. */

/*! @brief Read current value of the MIPI_CSI2_DBG_INTR_MSK_EARLY_FE field. */
#define BR_MIPI_CSI2_DBG_INTR_MSK_EARLY_FE(x) (HW_MIPI_CSI2_DBG_INTR_MSK(x).B.EARLY_FE)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_INTR_MSK_EARLY_FE. */
#define BF_MIPI_CSI2_DBG_INTR_MSK_EARLY_FE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_INTR_MSK_EARLY_FE) & BM_MIPI_CSI2_DBG_INTR_MSK_EARLY_FE)

/*! @brief Set the EARLY_FE field to a new value. */
#define BW_MIPI_CSI2_DBG_INTR_MSK_EARLY_FE(x, v) (HW_MIPI_CSI2_DBG_INTR_MSK_WR(x, (HW_MIPI_CSI2_DBG_INTR_MSK_RD(x) & ~BM_MIPI_CSI2_DBG_INTR_MSK_EARLY_FE) | BF_MIPI_CSI2_DBG_INTR_MSK_EARLY_FE(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_INTR_MSK, field TRUNCATED_FRAME[19:16] (RW)
 *
 * [19] CH3 [18] CH2 [17] CH1 [16] CH0
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME (16U) /*!< Bit position for MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME. */
#define BM_MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME (0x000F0000U) /*!< Bit mask for MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME. */
#define BS_MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME (4U) /*!< Bit field size in bits for MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME. */

/*! @brief Read current value of the MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME field. */
#define BR_MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME(x) (HW_MIPI_CSI2_DBG_INTR_MSK(x).B.TRUNCATED_FRAME)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME. */
#define BF_MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME) & BM_MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME)

/*! @brief Set the TRUNCATED_FRAME field to a new value. */
#define BW_MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME(x, v) (HW_MIPI_CSI2_DBG_INTR_MSK_WR(x, (HW_MIPI_CSI2_DBG_INTR_MSK_RD(x) & ~BM_MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME) | BF_MIPI_CSI2_DBG_INTR_MSK_TRUNCATED_FRAME(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_INTR_MSK, field ERR_FRAME_SIZE[23:20] (RW)
 *
 * [23] CH3 [22] CH2 [21] CH1 [20] CH0
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE (20U) /*!< Bit position for MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE. */
#define BM_MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE (0x00F00000U) /*!< Bit mask for MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE. */
#define BS_MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE (4U) /*!< Bit field size in bits for MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE. */

/*! @brief Read current value of the MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE field. */
#define BR_MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE(x) (HW_MIPI_CSI2_DBG_INTR_MSK(x).B.ERR_FRAME_SIZE)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE. */
#define BF_MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE) & BM_MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE)

/*! @brief Set the ERR_FRAME_SIZE field to a new value. */
#define BW_MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE(x, v) (HW_MIPI_CSI2_DBG_INTR_MSK_WR(x, (HW_MIPI_CSI2_DBG_INTR_MSK_RD(x) & ~BM_MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE) | BF_MIPI_CSI2_DBG_INTR_MSK_ERR_FRAME_SIZE(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_INTR_MSK, field DT_IGNORE[24] (RW)
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_INTR_MSK_DT_IGNORE (24U) /*!< Bit position for MIPI_CSI2_DBG_INTR_MSK_DT_IGNORE. */
#define BM_MIPI_CSI2_DBG_INTR_MSK_DT_IGNORE (0x01000000U) /*!< Bit mask for MIPI_CSI2_DBG_INTR_MSK_DT_IGNORE. */
#define BS_MIPI_CSI2_DBG_INTR_MSK_DT_IGNORE (1U) /*!< Bit field size in bits for MIPI_CSI2_DBG_INTR_MSK_DT_IGNORE. */

/*! @brief Read current value of the MIPI_CSI2_DBG_INTR_MSK_DT_IGNORE field. */
#define BR_MIPI_CSI2_DBG_INTR_MSK_DT_IGNORE(x) (HW_MIPI_CSI2_DBG_INTR_MSK(x).B.DT_IGNORE)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_INTR_MSK_DT_IGNORE. */
#define BF_MIPI_CSI2_DBG_INTR_MSK_DT_IGNORE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_INTR_MSK_DT_IGNORE) & BM_MIPI_CSI2_DBG_INTR_MSK_DT_IGNORE)

/*! @brief Set the DT_IGNORE field to a new value. */
#define BW_MIPI_CSI2_DBG_INTR_MSK_DT_IGNORE(x, v) (HW_MIPI_CSI2_DBG_INTR_MSK_WR(x, (HW_MIPI_CSI2_DBG_INTR_MSK_RD(x) & ~BM_MIPI_CSI2_DBG_INTR_MSK_DT_IGNORE) | BF_MIPI_CSI2_DBG_INTR_MSK_DT_IGNORE(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_INTR_MSK, field DT_NOT_SUPPORT[25] (RW)
 *
 * Values:
 * - 0 - Disable (masked)
 * - 1 - Enable (unmasked)
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_INTR_MSK_DT_NOT_SUPPORT (25U) /*!< Bit position for MIPI_CSI2_DBG_INTR_MSK_DT_NOT_SUPPORT. */
#define BM_MIPI_CSI2_DBG_INTR_MSK_DT_NOT_SUPPORT (0x02000000U) /*!< Bit mask for MIPI_CSI2_DBG_INTR_MSK_DT_NOT_SUPPORT. */
#define BS_MIPI_CSI2_DBG_INTR_MSK_DT_NOT_SUPPORT (1U) /*!< Bit field size in bits for MIPI_CSI2_DBG_INTR_MSK_DT_NOT_SUPPORT. */

/*! @brief Read current value of the MIPI_CSI2_DBG_INTR_MSK_DT_NOT_SUPPORT field. */
#define BR_MIPI_CSI2_DBG_INTR_MSK_DT_NOT_SUPPORT(x) (HW_MIPI_CSI2_DBG_INTR_MSK(x).B.DT_NOT_SUPPORT)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_INTR_MSK_DT_NOT_SUPPORT. */
#define BF_MIPI_CSI2_DBG_INTR_MSK_DT_NOT_SUPPORT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_INTR_MSK_DT_NOT_SUPPORT) & BM_MIPI_CSI2_DBG_INTR_MSK_DT_NOT_SUPPORT)

/*! @brief Set the DT_NOT_SUPPORT field to a new value. */
#define BW_MIPI_CSI2_DBG_INTR_MSK_DT_NOT_SUPPORT(x, v) (HW_MIPI_CSI2_DBG_INTR_MSK_WR(x, (HW_MIPI_CSI2_DBG_INTR_MSK_RD(x) & ~BM_MIPI_CSI2_DBG_INTR_MSK_DT_NOT_SUPPORT) | BF_MIPI_CSI2_DBG_INTR_MSK_DT_NOT_SUPPORT(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_INTR_MSK, field RSVD13[31:26] (RO)
 *
 * Read as zero, do not modify.
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_INTR_MSK_RSVD13 (26U) /*!< Bit position for MIPI_CSI2_DBG_INTR_MSK_RSVD13. */
#define BM_MIPI_CSI2_DBG_INTR_MSK_RSVD13 (0xFC000000U) /*!< Bit mask for MIPI_CSI2_DBG_INTR_MSK_RSVD13. */
#define BS_MIPI_CSI2_DBG_INTR_MSK_RSVD13 (6U) /*!< Bit field size in bits for MIPI_CSI2_DBG_INTR_MSK_RSVD13. */

/*! @brief Read current value of the MIPI_CSI2_DBG_INTR_MSK_RSVD13 field. */
#define BR_MIPI_CSI2_DBG_INTR_MSK_RSVD13(x) (HW_MIPI_CSI2_DBG_INTR_MSK(x).B.RSVD13)
/*@}*/

/*******************************************************************************
 * HW_MIPI_CSI2_DBG_INTR_SRC - Debug Interrupt Mask
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_DBG_INTR_SRC - Debug Interrupt Mask (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mipi_csi2_dbg_intr_src
{
    uint32_t U;
    struct _hw_mipi_csi2_dbg_intr_src_bitfields
    {
        uint32_t CAM_VSYNC_RISE : 4;   /*!< [3:0]  */
        uint32_t CAM_VSYNC_FALL : 4;   /*!< [7:4]  */
        uint32_t EARLY_FS : 4;         /*!< [11:8]  */
        uint32_t EARLY_FE : 4;         /*!< [15:12]  */
        uint32_t TRUNCATED_FRAME : 4;  /*!< [19:16]  */
        uint32_t ERR_FRAME_SIZE : 4;   /*!< [23:20]  */
        uint32_t DT_IGNORE : 1;        /*!< [24]  */
        uint32_t DT_NOT_SUPPURT : 1;   /*!< [25]  */
        uint32_t RSVD14 : 6;           /*!< [31:26] Reserved */
    } B;
} hw_mipi_csi2_dbg_intr_src_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_DBG_INTR_SRC register
 */
/*@{*/
#define HW_MIPI_CSI2_DBG_INTR_SRC_ADDR(x) ((uintptr_t)(x) + 0xC8U)

#define HW_MIPI_CSI2_DBG_INTR_SRC(x) (*(__IO hw_mipi_csi2_dbg_intr_src_t *) HW_MIPI_CSI2_DBG_INTR_SRC_ADDR(x))
#define HW_MIPI_CSI2_DBG_INTR_SRC_RD(x) (HW_MIPI_CSI2_DBG_INTR_SRC(x).U)
#define HW_MIPI_CSI2_DBG_INTR_SRC_WR(x, v) (HW_MIPI_CSI2_DBG_INTR_SRC(x).U = (v))
#define HW_MIPI_CSI2_DBG_INTR_SRC_SET(x, v) (HW_MIPI_CSI2_DBG_INTR_SRC_WR(x, HW_MIPI_CSI2_DBG_INTR_SRC_RD(x) |  (v)))
#define HW_MIPI_CSI2_DBG_INTR_SRC_CLR(x, v) (HW_MIPI_CSI2_DBG_INTR_SRC_WR(x, HW_MIPI_CSI2_DBG_INTR_SRC_RD(x) & ~(v)))
#define HW_MIPI_CSI2_DBG_INTR_SRC_TOG(x, v) (HW_MIPI_CSI2_DBG_INTR_SRC_WR(x, HW_MIPI_CSI2_DBG_INTR_SRC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_DBG_INTR_SRC bitfields
 */

/*!
 * @name Register MIPI_CSI2_DBG_INTR_SRC, field CAM_VSYNC_RISE[3:0] (RW)
 *
 * The rising of vsync in the CAM I/F [3] CH3 [2] CH2 [1] CH1 [0] CH0
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE (0U) /*!< Bit position for MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE. */
#define BM_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE (0x0000000FU) /*!< Bit mask for MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE. */
#define BS_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE (4U) /*!< Bit field size in bits for MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE. */

/*! @brief Read current value of the MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE field. */
#define BR_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE(x) (HW_MIPI_CSI2_DBG_INTR_SRC(x).B.CAM_VSYNC_RISE)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE. */
#define BF_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE) & BM_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE)

/*! @brief Set the CAM_VSYNC_RISE field to a new value. */
#define BW_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE(x, v) (HW_MIPI_CSI2_DBG_INTR_SRC_WR(x, (HW_MIPI_CSI2_DBG_INTR_SRC_RD(x) & ~BM_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE) | BF_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_RISE(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_INTR_SRC, field CAM_VSYNC_FALL[7:4] (RW)
 *
 * The falling of vsync in the CAM I/F [7] CH3 [6] CH2 [5] CH1 [4] CH0
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL (4U) /*!< Bit position for MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL. */
#define BM_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL (0x000000F0U) /*!< Bit mask for MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL. */
#define BS_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL (4U) /*!< Bit field size in bits for MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL. */

/*! @brief Read current value of the MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL field. */
#define BR_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL(x) (HW_MIPI_CSI2_DBG_INTR_SRC(x).B.CAM_VSYNC_FALL)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL. */
#define BF_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL) & BM_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL)

/*! @brief Set the CAM_VSYNC_FALL field to a new value. */
#define BW_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL(x, v) (HW_MIPI_CSI2_DBG_INTR_SRC_WR(x, (HW_MIPI_CSI2_DBG_INTR_SRC_RD(x) & ~BM_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL) | BF_MIPI_CSI2_DBG_INTR_SRC_CAM_VSYNC_FALL(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_INTR_SRC, field EARLY_FS[11:8] (RW)
 *
 * Frame Start packet is received during transfer of image. [11] CH3 [10] CH2
 * [9] CH1 [8] CH0
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_INTR_SRC_EARLY_FS (8U) /*!< Bit position for MIPI_CSI2_DBG_INTR_SRC_EARLY_FS. */
#define BM_MIPI_CSI2_DBG_INTR_SRC_EARLY_FS (0x00000F00U) /*!< Bit mask for MIPI_CSI2_DBG_INTR_SRC_EARLY_FS. */
#define BS_MIPI_CSI2_DBG_INTR_SRC_EARLY_FS (4U) /*!< Bit field size in bits for MIPI_CSI2_DBG_INTR_SRC_EARLY_FS. */

/*! @brief Read current value of the MIPI_CSI2_DBG_INTR_SRC_EARLY_FS field. */
#define BR_MIPI_CSI2_DBG_INTR_SRC_EARLY_FS(x) (HW_MIPI_CSI2_DBG_INTR_SRC(x).B.EARLY_FS)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_INTR_SRC_EARLY_FS. */
#define BF_MIPI_CSI2_DBG_INTR_SRC_EARLY_FS(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_INTR_SRC_EARLY_FS) & BM_MIPI_CSI2_DBG_INTR_SRC_EARLY_FS)

/*! @brief Set the EARLY_FS field to a new value. */
#define BW_MIPI_CSI2_DBG_INTR_SRC_EARLY_FS(x, v) (HW_MIPI_CSI2_DBG_INTR_SRC_WR(x, (HW_MIPI_CSI2_DBG_INTR_SRC_RD(x) & ~BM_MIPI_CSI2_DBG_INTR_SRC_EARLY_FS) | BF_MIPI_CSI2_DBG_INTR_SRC_EARLY_FS(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_INTR_SRC, field EARLY_FE[15:12] (RW)
 *
 * Frame End packet is received during transfer of image. [15] CH3 [14] CH2 [13]
 * CH1 [12] CH0
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_INTR_SRC_EARLY_FE (12U) /*!< Bit position for MIPI_CSI2_DBG_INTR_SRC_EARLY_FE. */
#define BM_MIPI_CSI2_DBG_INTR_SRC_EARLY_FE (0x0000F000U) /*!< Bit mask for MIPI_CSI2_DBG_INTR_SRC_EARLY_FE. */
#define BS_MIPI_CSI2_DBG_INTR_SRC_EARLY_FE (4U) /*!< Bit field size in bits for MIPI_CSI2_DBG_INTR_SRC_EARLY_FE. */

/*! @brief Read current value of the MIPI_CSI2_DBG_INTR_SRC_EARLY_FE field. */
#define BR_MIPI_CSI2_DBG_INTR_SRC_EARLY_FE(x) (HW_MIPI_CSI2_DBG_INTR_SRC(x).B.EARLY_FE)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_INTR_SRC_EARLY_FE. */
#define BF_MIPI_CSI2_DBG_INTR_SRC_EARLY_FE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_INTR_SRC_EARLY_FE) & BM_MIPI_CSI2_DBG_INTR_SRC_EARLY_FE)

/*! @brief Set the EARLY_FE field to a new value. */
#define BW_MIPI_CSI2_DBG_INTR_SRC_EARLY_FE(x, v) (HW_MIPI_CSI2_DBG_INTR_SRC_WR(x, (HW_MIPI_CSI2_DBG_INTR_SRC_RD(x) & ~BM_MIPI_CSI2_DBG_INTR_SRC_EARLY_FE) | BF_MIPI_CSI2_DBG_INTR_SRC_EARLY_FE(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_INTR_SRC, field TRUNCATED_FRAME[19:16] (RW)
 *
 * Truncated frame is received. [19] CH3 [18] CH2 [17] CH1 [16] CH0
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME (16U) /*!< Bit position for MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME. */
#define BM_MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME (0x000F0000U) /*!< Bit mask for MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME. */
#define BS_MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME (4U) /*!< Bit field size in bits for MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME. */

/*! @brief Read current value of the MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME field. */
#define BR_MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME(x) (HW_MIPI_CSI2_DBG_INTR_SRC(x).B.TRUNCATED_FRAME)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME. */
#define BF_MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME) & BM_MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME)

/*! @brief Set the TRUNCATED_FRAME field to a new value. */
#define BW_MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME(x, v) (HW_MIPI_CSI2_DBG_INTR_SRC_WR(x, (HW_MIPI_CSI2_DBG_INTR_SRC_RD(x) & ~BM_MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME) | BF_MIPI_CSI2_DBG_INTR_SRC_TRUNCATED_FRAME(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_INTR_SRC, field ERR_FRAME_SIZE[23:20] (RW)
 *
 * The received frame is not matched with the configured. [23] CH3 [22] CH2 [21]
 * CH1 [20] CH0
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE (20U) /*!< Bit position for MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE. */
#define BM_MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE (0x00F00000U) /*!< Bit mask for MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE. */
#define BS_MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE (4U) /*!< Bit field size in bits for MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE. */

/*! @brief Read current value of the MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE field. */
#define BR_MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE(x) (HW_MIPI_CSI2_DBG_INTR_SRC(x).B.ERR_FRAME_SIZE)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE. */
#define BF_MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE) & BM_MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE)

/*! @brief Set the ERR_FRAME_SIZE field to a new value. */
#define BW_MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE(x, v) (HW_MIPI_CSI2_DBG_INTR_SRC_WR(x, (HW_MIPI_CSI2_DBG_INTR_SRC_RD(x) & ~BM_MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE) | BF_MIPI_CSI2_DBG_INTR_SRC_ERR_FRAME_SIZE(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_INTR_SRC, field DT_IGNORE[24] (RW)
 *
 * The data type of the received packet is ignored (NULL or BLANKING)
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_INTR_SRC_DT_IGNORE (24U) /*!< Bit position for MIPI_CSI2_DBG_INTR_SRC_DT_IGNORE. */
#define BM_MIPI_CSI2_DBG_INTR_SRC_DT_IGNORE (0x01000000U) /*!< Bit mask for MIPI_CSI2_DBG_INTR_SRC_DT_IGNORE. */
#define BS_MIPI_CSI2_DBG_INTR_SRC_DT_IGNORE (1U) /*!< Bit field size in bits for MIPI_CSI2_DBG_INTR_SRC_DT_IGNORE. */

/*! @brief Read current value of the MIPI_CSI2_DBG_INTR_SRC_DT_IGNORE field. */
#define BR_MIPI_CSI2_DBG_INTR_SRC_DT_IGNORE(x) (HW_MIPI_CSI2_DBG_INTR_SRC(x).B.DT_IGNORE)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_INTR_SRC_DT_IGNORE. */
#define BF_MIPI_CSI2_DBG_INTR_SRC_DT_IGNORE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_INTR_SRC_DT_IGNORE) & BM_MIPI_CSI2_DBG_INTR_SRC_DT_IGNORE)

/*! @brief Set the DT_IGNORE field to a new value. */
#define BW_MIPI_CSI2_DBG_INTR_SRC_DT_IGNORE(x, v) (HW_MIPI_CSI2_DBG_INTR_SRC_WR(x, (HW_MIPI_CSI2_DBG_INTR_SRC_RD(x) & ~BM_MIPI_CSI2_DBG_INTR_SRC_DT_IGNORE) | BF_MIPI_CSI2_DBG_INTR_SRC_DT_IGNORE(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_INTR_SRC, field DT_NOT_SUPPURT[25] (RW)
 *
 * The data type of the received packet is not supported (RGB444 or RGB555)
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_INTR_SRC_DT_NOT_SUPPURT (25U) /*!< Bit position for MIPI_CSI2_DBG_INTR_SRC_DT_NOT_SUPPURT. */
#define BM_MIPI_CSI2_DBG_INTR_SRC_DT_NOT_SUPPURT (0x02000000U) /*!< Bit mask for MIPI_CSI2_DBG_INTR_SRC_DT_NOT_SUPPURT. */
#define BS_MIPI_CSI2_DBG_INTR_SRC_DT_NOT_SUPPURT (1U) /*!< Bit field size in bits for MIPI_CSI2_DBG_INTR_SRC_DT_NOT_SUPPURT. */

/*! @brief Read current value of the MIPI_CSI2_DBG_INTR_SRC_DT_NOT_SUPPURT field. */
#define BR_MIPI_CSI2_DBG_INTR_SRC_DT_NOT_SUPPURT(x) (HW_MIPI_CSI2_DBG_INTR_SRC(x).B.DT_NOT_SUPPURT)

/*! @brief Format value for bitfield MIPI_CSI2_DBG_INTR_SRC_DT_NOT_SUPPURT. */
#define BF_MIPI_CSI2_DBG_INTR_SRC_DT_NOT_SUPPURT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_CSI2_DBG_INTR_SRC_DT_NOT_SUPPURT) & BM_MIPI_CSI2_DBG_INTR_SRC_DT_NOT_SUPPURT)

/*! @brief Set the DT_NOT_SUPPURT field to a new value. */
#define BW_MIPI_CSI2_DBG_INTR_SRC_DT_NOT_SUPPURT(x, v) (HW_MIPI_CSI2_DBG_INTR_SRC_WR(x, (HW_MIPI_CSI2_DBG_INTR_SRC_RD(x) & ~BM_MIPI_CSI2_DBG_INTR_SRC_DT_NOT_SUPPURT) | BF_MIPI_CSI2_DBG_INTR_SRC_DT_NOT_SUPPURT(v)))
/*@}*/

/*!
 * @name Register MIPI_CSI2_DBG_INTR_SRC, field RSVD14[31:26] (RO)
 *
 * Read as zero, do not modify.
 */
/*@{*/
#define BP_MIPI_CSI2_DBG_INTR_SRC_RSVD14 (26U) /*!< Bit position for MIPI_CSI2_DBG_INTR_SRC_RSVD14. */
#define BM_MIPI_CSI2_DBG_INTR_SRC_RSVD14 (0xFC000000U) /*!< Bit mask for MIPI_CSI2_DBG_INTR_SRC_RSVD14. */
#define BS_MIPI_CSI2_DBG_INTR_SRC_RSVD14 (6U) /*!< Bit field size in bits for MIPI_CSI2_DBG_INTR_SRC_RSVD14. */

/*! @brief Read current value of the MIPI_CSI2_DBG_INTR_SRC_RSVD14 field. */
#define BR_MIPI_CSI2_DBG_INTR_SRC_RSVD14(x) (HW_MIPI_CSI2_DBG_INTR_SRC(x).B.RSVD14)
/*@}*/

/*******************************************************************************
 * HW_MIPI_CSI2_NON_IMG_DATA - Non Image Data
 ******************************************************************************/

/*!
 * @brief HW_MIPI_CSI2_NON_IMG_DATA - Non Image Data (RO)
 *
 * Reset value: 0x00000000U
 *
 * For the double buffering, Non-image data region is divided as following
 * address. 0x2000 - 0x2FFC: Odd frame / 0x3000 - 0x3FFC: Even frame (8 KB memory)
 * 0x2000 - 0x27FC: Odd frame / 0x2800 - 0x2FFC: Even frame (4 KB memory) 0x2000 -
 * 0x23FC: Odd frame / 0x2400 - 0x27FC: Even frame (2 KB memory)
 */
typedef union _hw_mipi_csi2_non_img_data
{
    uint32_t U;
    struct _hw_mipi_csi2_non_img_data_bitfields
    {
        uint32_t NONIMGDATA : 32;      /*!< [31:0] Non Image data memory */
    } B;
} hw_mipi_csi2_non_img_data_t;

/*!
 * @name Constants and macros for entire MIPI_CSI2_NON_IMG_DATA register
 */
/*@{*/
#define HW_MIPI_CSI2_NON_IMG_DATA_ADDR(x) ((uintptr_t)(x) + 0x2000U)

#define HW_MIPI_CSI2_NON_IMG_DATA(x) (*(__I hw_mipi_csi2_non_img_data_t *) HW_MIPI_CSI2_NON_IMG_DATA_ADDR(x))
#define HW_MIPI_CSI2_NON_IMG_DATA_RD(x) (HW_MIPI_CSI2_NON_IMG_DATA(x).U)
/*@}*/

/*
 * Constants & macros for individual MIPI_CSI2_NON_IMG_DATA bitfields
 */

/*!
 * @name Register MIPI_CSI2_NON_IMG_DATA, field NONIMGDATA[31:0] (RO)
 */
/*@{*/
#define BP_MIPI_CSI2_NON_IMG_DATA_NONIMGDATA (0U) /*!< Bit position for MIPI_CSI2_NON_IMG_DATA_NONIMGDATA. */
#define BM_MIPI_CSI2_NON_IMG_DATA_NONIMGDATA (0xFFFFFFFFU) /*!< Bit mask for MIPI_CSI2_NON_IMG_DATA_NONIMGDATA. */
#define BS_MIPI_CSI2_NON_IMG_DATA_NONIMGDATA (32U) /*!< Bit field size in bits for MIPI_CSI2_NON_IMG_DATA_NONIMGDATA. */

/*! @brief Read current value of the MIPI_CSI2_NON_IMG_DATA_NONIMGDATA field. */
#define BR_MIPI_CSI2_NON_IMG_DATA_NONIMGDATA(x) (HW_MIPI_CSI2_NON_IMG_DATA(x).U)
/*@}*/

/*******************************************************************************
 * hw_mipi_csi2_t - module struct
 ******************************************************************************/
/*!
 * @brief All MIPI_CSI2 module registers.
 */
#pragma pack(1)
typedef struct _hw_mipi_csi2
{
    uint8_t _reserved0[4];
    __IO hw_mipi_csi2_csis_cmn_ctrl_t CSIS_CMN_CTRL; /*!< [0x4] CSIS Common Control */
    __IO hw_mipi_csi2_csis_clk_ctrl_t CSIS_CLK_CTRL; /*!< [0x8] CSIS Clock gate Control */
    uint8_t _reserved1[4];
    __IO hw_mipi_csi2_csis_int_msk_t CSIS_INT_MSK; /*!< [0x10] CSIS Interrupt Mask */
    __IO hw_mipi_csi2_csis_int_src_t CSIS_INT_SRC; /*!< [0x14] CSIS Interrupt Source */
    uint8_t _reserved2[8];
    __I hw_mipi_csi2_dphy_status_t DPHY_STATUS; /*!< [0x20] D-PHY Status */
    __IO hw_mipi_csi2_dphy_cmn_ctrl_t DPHY_CMN_CTRL; /*!< [0x24] D-PHY Common Control */
    uint8_t _reserved3[8];
    __IO hw_mipi_csi2_dphy_bctrl_l_t DPHY_BCTRL_L; /*!< [0x30] D-PHY Master and Slave Control register low */
    __IO hw_mipi_csi2_dphy_bctrl_h_t DPHY_BCTRL_H; /*!< [0x34] D-PHY Master and Slave Control register high */
    __IO hw_mipi_csi2_dphy_sctrl_l_t DPHY_SCTRL_L; /*!< [0x38] D-PHY Slave Control register low */
    __IO hw_mipi_csi2_dphy_sctrl_h_t DPHY_SCTRL_H; /*!< [0x3C] D-PHY Slave Control register high */
    __IO hw_mipi_csi2_isp_config_ch0_t ISP_CONFIG_CH0; /*!< [0x40] ISP Configuration register of CH0 */
    __IO hw_mipi_csi2_isp_resol_ch0_t ISP_RESOL_CH0; /*!< [0x44] ISP Image Resolution register of CH0 */
    __IO hw_mipi_csi2_isp_sync_ch0_t ISP_SYNC_CH0; /*!< [0x48] ISP SYNC register of CH0 */
    uint8_t _reserved4[52];
    __I hw_mipi_csi2_sdw_config_ch0_t SDW_CONFIG_CH0; /*!< [0x80] Shadow Configuration register of CH0 */
    __I hw_mipi_csi2_sdw_resol_ch0_t SDW_RESOL_CH0; /*!< [0x84] Shadow Resolution register of CH0 */
    __I hw_mipi_csi2_sdw_sync_ch0_t SDW_SYNC_CH0; /*!< [0x88] Shadow SYNC register of CH0 */
    uint8_t _reserved5[52];
    __IO hw_mipi_csi2_dbg_ctrl_t DBG_CTRL; /*!< [0xC0] Debug Control register */
    __IO hw_mipi_csi2_dbg_intr_msk_t DBG_INTR_MSK; /*!< [0xC4] Debug Interrupt Mask */
    __IO hw_mipi_csi2_dbg_intr_src_t DBG_INTR_SRC; /*!< [0xC8] Debug Interrupt Mask */
    uint8_t _reserved6[7988];
    __I hw_mipi_csi2_non_img_data_t NON_IMG_DATA; /*!< [0x2000] Non Image Data */
} hw_mipi_csi2_t;
#pragma pack()

/*! @brief Macro to access all MIPI_CSI2 registers. */
/*! @param x MIPI_CSI2 module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_MIPI_CSI2_REGS(MIPI_CSI2_BASE)</code>. */
#define HW_MIPI_CSI2_REGS(x) (*(hw_mipi_csi2_t *)(x))

/*
 * iMX7D MIPI_DSI
 *
 * MIPI DSI Host Controller (MIPI_DSI)
 *
 * Registers defined in this header file:
 * - HW_MIPI_DSI_VERSION - Version Register
 * - HW_MIPI_DSI_STATUS -
 * - HW_MIPI_DSI_RGB_STATUS - RGB Status Register
 * - HW_MIPI_DSI_SWRST -
 * - HW_MIPI_DSI_CLKCTRL - Clock Control Register
 * - HW_MIPI_DSI_TIMEOUT -
 * - HW_MIPI_DSI_CONFIG -
 * - HW_MIPI_DSI_ESCMODE - Escape Mode Register
 * - HW_MIPI_DSI_MDRESOL - Main Display Image Resolution Register
 * - HW_MIPI_DSI_MVPORCH - Main Display VPORCH Register
 * - HW_MIPI_DSI_MHPORCH -
 * - HW_MIPI_DSI_MSYNC -
 * - HW_MIPI_DSI_SDRESOL - Sub Display Image Resolution Register
 * - HW_MIPI_DSI_INTSRC - Interrupt Source Register
 * - HW_MIPI_DSI_INTMSK - Interrupt Mask Register
 * - HW_MIPI_DSI_PKTHDR - Packet Header FIFO Register
 * - HW_MIPI_DSI_PAYLOAD - Payload FIFO Register
 * - HW_MIPI_DSI_RXFIFO - Payload FIFO Register
 * - HW_MIPI_DSI_FIFOTHLD - FIFO Threshold Level Register
 * - HW_MIPI_DSI_FIFOCTRL - FIFO Status and Control Register
 * - HW_MIPI_DSI_MEMACCHR - FIFO Memory AC Characteristic Register
 * - HW_MIPI_DSI_MULTI_PKT -
 * - HW_MIPI_DSI_PLLCTRL_1G - 1 Gbps D-PHY PLL Control Register
 * - HW_MIPI_DSI_PLLCTRL - PLL Control register
 * - HW_MIPI_DSI_PLLCTRL1 - PLL Control Register 1
 * - HW_MIPI_DSI_PLLCTRL2 - PLL control register 2
 * - HW_MIPI_DSI_PLLTMR - PLL Timer Register
 * - HW_MIPI_DSI_PHYCTRL_B1 - D-PHY Master and Slave Analog Block Control Register 1
 * - HW_MIPI_DSI_PHYCTRL_B2 - D-PHY Master and Slave Analog Block Control Register 2
 * - HW_MIPI_DSI_PHYCTRL_M1 - D-PHY Master Analog Block Control Register 1
 * - HW_MIPI_DSI_PHYCTRL_M2 - D-PHY Master Analog Block Control Register 1
 * - HW_MIPI_DSI_PHYTIMING - D-PHY Timing register
 * - HW_MIPI_DSI_PHYTIMING1 -
 * - HW_MIPI_DSI_PHYTIMING2 - D-PHY Timing Register 2
 *
 * - hw_mipi_dsi_t - Struct containing all module registers.
 */

#define HW_MIPI_DSI_INSTANCE_COUNT (1U) /*!< Number of instances of the MIPI_DSI module. */
#define HW_MIPI_DSI (0U) /*!< Instance number for MIPI_DSI. */
#define MIPI_DSI_BASE         (0x30760000U) /*!< Base address for MIPI_DSI. */
/*! Array initializer of MIPI_DSI base addresses. */
#define MIPI_DSI_BASE_ADDRS   { MIPI_DSI_BASE }

/*******************************************************************************
 * HW_MIPI_DSI_VERSION - Version Register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_VERSION - Version Register (RO)
 *
 * Reset value: 0x01060100U
 */
typedef union _hw_mipi_dsi_version
{
    uint32_t U;
    struct _hw_mipi_dsi_version_bitfields
    {
        uint32_t VERSION : 32;         /*!< [31:0]  */
    } B;
} hw_mipi_dsi_version_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_VERSION register
 */
/*@{*/
#define HW_MIPI_DSI_VERSION_ADDR(x) ((uintptr_t)(x) + 0x0U)

#define HW_MIPI_DSI_VERSION(x)   (*(__I hw_mipi_dsi_version_t *) HW_MIPI_DSI_VERSION_ADDR(x))
#define HW_MIPI_DSI_VERSION_RD(x) (HW_MIPI_DSI_VERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_VERSION bitfields
 */

/*!
 * @name Register MIPI_DSI_VERSION, field VERSION[31:0] (RO)
 *
 * Specifies the DSIM version information
 */
/*@{*/
#define BP_MIPI_DSI_VERSION_VERSION (0U)   /*!< Bit position for MIPI_DSI_VERSION_VERSION. */
#define BM_MIPI_DSI_VERSION_VERSION (0xFFFFFFFFU) /*!< Bit mask for MIPI_DSI_VERSION_VERSION. */
#define BS_MIPI_DSI_VERSION_VERSION (32U)  /*!< Bit field size in bits for MIPI_DSI_VERSION_VERSION. */

/*! @brief Read current value of the MIPI_DSI_VERSION_VERSION field. */
#define BR_MIPI_DSI_VERSION_VERSION(x) (HW_MIPI_DSI_VERSION(x).U)
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_STATUS -
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_STATUS -  (RO)
 *
 * Reset value: 0x0010010FU
 *
 * This register reads and checks internal and interface status. It also checks
 * FSM status, Line buffer status, current image line number, and so on.
 */
typedef union _hw_mipi_dsi_status
{
    uint32_t U;
    struct _hw_mipi_dsi_status_bitfields
    {
        uint32_t STOPSTATEDAT : 4;     /*!< [3:0]  */
        uint32_t ULPSDAT : 4;          /*!< [7:4]  */
        uint32_t STOPSTATECLK : 1;     /*!< [8]  */
        uint32_t ULPSCLK : 1;          /*!< [9]  */
        uint32_t TXREADYHSCLK : 1;     /*!< [10]  */
        uint32_t RESERVED0 : 5;        /*!< [15:11]  */
        uint32_t DIRECTION : 1;        /*!< [16]  */
        uint32_t RESERVED1 : 3;        /*!< [19:17]  */
        uint32_t SWRSTRLS : 1;         /*!< [20]  */
        uint32_t RESERVED2 : 10;       /*!< [30:21]  */
        uint32_t PLLSTABLE : 1;        /*!< [31]  */
    } B;
} hw_mipi_dsi_status_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_STATUS register
 */
/*@{*/
#define HW_MIPI_DSI_STATUS_ADDR(x) ((uintptr_t)(x) + 0x4U)

#define HW_MIPI_DSI_STATUS(x)    (*(__I hw_mipi_dsi_status_t *) HW_MIPI_DSI_STATUS_ADDR(x))
#define HW_MIPI_DSI_STATUS_RD(x) (HW_MIPI_DSI_STATUS(x).U)
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_STATUS bitfields
 */

/*!
 * @name Register MIPI_DSI_STATUS, field STOPSTATEDAT[3:0] (RO)
 *
 * Specifies the stop state indicator at data lane StopstateDat[0]: Data lane 0
 * StopstateDat[1]: Data lane 1 StopstateDat[2]: Reserved StopstateDat[3]:
 * Reserved
 */
/*@{*/
#define BP_MIPI_DSI_STATUS_STOPSTATEDAT (0U) /*!< Bit position for MIPI_DSI_STATUS_STOPSTATEDAT. */
#define BM_MIPI_DSI_STATUS_STOPSTATEDAT (0x0000000FU) /*!< Bit mask for MIPI_DSI_STATUS_STOPSTATEDAT. */
#define BS_MIPI_DSI_STATUS_STOPSTATEDAT (4U) /*!< Bit field size in bits for MIPI_DSI_STATUS_STOPSTATEDAT. */

/*! @brief Read current value of the MIPI_DSI_STATUS_STOPSTATEDAT field. */
#define BR_MIPI_DSI_STATUS_STOPSTATEDAT(x) (HW_MIPI_DSI_STATUS(x).B.STOPSTATEDAT)
/*@}*/

/*!
 * @name Register MIPI_DSI_STATUS, field ULPSDAT[7:4] (RO)
 *
 * Specifies the ULPS indicator at data lanes UlpsDat[0]: Data lane 0
 * UlpsDat[1]: Data lane 1 UlpsDat[2]: Reserved UlpsDat[3]: Reserved
 *
 * Values:
 * - 0 - No ULPS in each data lane
 * - 1 - ULPS in each data lane
 */
/*@{*/
#define BP_MIPI_DSI_STATUS_ULPSDAT (4U)    /*!< Bit position for MIPI_DSI_STATUS_ULPSDAT. */
#define BM_MIPI_DSI_STATUS_ULPSDAT (0x000000F0U) /*!< Bit mask for MIPI_DSI_STATUS_ULPSDAT. */
#define BS_MIPI_DSI_STATUS_ULPSDAT (4U)    /*!< Bit field size in bits for MIPI_DSI_STATUS_ULPSDAT. */

/*! @brief Read current value of the MIPI_DSI_STATUS_ULPSDAT field. */
#define BR_MIPI_DSI_STATUS_ULPSDAT(x) (HW_MIPI_DSI_STATUS(x).B.ULPSDAT)
/*@}*/

/*!
 * @name Register MIPI_DSI_STATUS, field STOPSTATECLK[8] (RO)
 *
 * Specifies the stop state indicator at clock lane
 *
 * Values:
 * - 0 - No stop state in clock lane
 * - 1 - Stop state in clock lane
 */
/*@{*/
#define BP_MIPI_DSI_STATUS_STOPSTATECLK (8U) /*!< Bit position for MIPI_DSI_STATUS_STOPSTATECLK. */
#define BM_MIPI_DSI_STATUS_STOPSTATECLK (0x00000100U) /*!< Bit mask for MIPI_DSI_STATUS_STOPSTATECLK. */
#define BS_MIPI_DSI_STATUS_STOPSTATECLK (1U) /*!< Bit field size in bits for MIPI_DSI_STATUS_STOPSTATECLK. */

/*! @brief Read current value of the MIPI_DSI_STATUS_STOPSTATECLK field. */
#define BR_MIPI_DSI_STATUS_STOPSTATECLK(x) (HW_MIPI_DSI_STATUS(x).B.STOPSTATECLK)
/*@}*/

/*!
 * @name Register MIPI_DSI_STATUS, field ULPSCLK[9] (RO)
 *
 * Specifies the ULPS indicator at clock lane
 *
 * Values:
 * - 0 - No ULPS in clock lane
 * - 1 - ULPS in clock lane
 */
/*@{*/
#define BP_MIPI_DSI_STATUS_ULPSCLK (9U)    /*!< Bit position for MIPI_DSI_STATUS_ULPSCLK. */
#define BM_MIPI_DSI_STATUS_ULPSCLK (0x00000200U) /*!< Bit mask for MIPI_DSI_STATUS_ULPSCLK. */
#define BS_MIPI_DSI_STATUS_ULPSCLK (1U)    /*!< Bit field size in bits for MIPI_DSI_STATUS_ULPSCLK. */

/*! @brief Read current value of the MIPI_DSI_STATUS_ULPSCLK field. */
#define BR_MIPI_DSI_STATUS_ULPSCLK(x) (HW_MIPI_DSI_STATUS(x).B.ULPSCLK)
/*@}*/

/*!
 * @name Register MIPI_DSI_STATUS, field TXREADYHSCLK[10] (RO)
 *
 * Specifies the HS clock ready at clock lane
 *
 * Values:
 * - 0 - Not ready for transmitting HS data at clock lane
 * - 1 - Ready for transmitting HS data at clock lane
 */
/*@{*/
#define BP_MIPI_DSI_STATUS_TXREADYHSCLK (10U) /*!< Bit position for MIPI_DSI_STATUS_TXREADYHSCLK. */
#define BM_MIPI_DSI_STATUS_TXREADYHSCLK (0x00000400U) /*!< Bit mask for MIPI_DSI_STATUS_TXREADYHSCLK. */
#define BS_MIPI_DSI_STATUS_TXREADYHSCLK (1U) /*!< Bit field size in bits for MIPI_DSI_STATUS_TXREADYHSCLK. */

/*! @brief Read current value of the MIPI_DSI_STATUS_TXREADYHSCLK field. */
#define BR_MIPI_DSI_STATUS_TXREADYHSCLK(x) (HW_MIPI_DSI_STATUS(x).B.TXREADYHSCLK)
/*@}*/

/*!
 * @name Register MIPI_DSI_STATUS, field DIRECTION[16] (RO)
 *
 * Specifies the data direction indicator
 *
 * Values:
 * - 0 - Forward direction
 * - 1 - Backward direction
 */
/*@{*/
#define BP_MIPI_DSI_STATUS_DIRECTION (16U) /*!< Bit position for MIPI_DSI_STATUS_DIRECTION. */
#define BM_MIPI_DSI_STATUS_DIRECTION (0x00010000U) /*!< Bit mask for MIPI_DSI_STATUS_DIRECTION. */
#define BS_MIPI_DSI_STATUS_DIRECTION (1U)  /*!< Bit field size in bits for MIPI_DSI_STATUS_DIRECTION. */

/*! @brief Read current value of the MIPI_DSI_STATUS_DIRECTION field. */
#define BR_MIPI_DSI_STATUS_DIRECTION(x) (HW_MIPI_DSI_STATUS(x).B.DIRECTION)
/*@}*/

/*!
 * @name Register MIPI_DSI_STATUS, field SWRSTRLS[20] (RO)
 *
 * Specifies the software reset status
 *
 * Values:
 * - 0 - Reset state
 * - 1 - Release state
 */
/*@{*/
#define BP_MIPI_DSI_STATUS_SWRSTRLS (20U)  /*!< Bit position for MIPI_DSI_STATUS_SWRSTRLS. */
#define BM_MIPI_DSI_STATUS_SWRSTRLS (0x00100000U) /*!< Bit mask for MIPI_DSI_STATUS_SWRSTRLS. */
#define BS_MIPI_DSI_STATUS_SWRSTRLS (1U)   /*!< Bit field size in bits for MIPI_DSI_STATUS_SWRSTRLS. */

/*! @brief Read current value of the MIPI_DSI_STATUS_SWRSTRLS field. */
#define BR_MIPI_DSI_STATUS_SWRSTRLS(x) (HW_MIPI_DSI_STATUS(x).B.SWRSTRLS)
/*@}*/

/*!
 * @name Register MIPI_DSI_STATUS, field PLLSTABLE[31] (RO)
 *
 * D-PHY PLL generates stable byteclk.
 */
/*@{*/
#define BP_MIPI_DSI_STATUS_PLLSTABLE (31U) /*!< Bit position for MIPI_DSI_STATUS_PLLSTABLE. */
#define BM_MIPI_DSI_STATUS_PLLSTABLE (0x80000000U) /*!< Bit mask for MIPI_DSI_STATUS_PLLSTABLE. */
#define BS_MIPI_DSI_STATUS_PLLSTABLE (1U)  /*!< Bit field size in bits for MIPI_DSI_STATUS_PLLSTABLE. */

/*! @brief Read current value of the MIPI_DSI_STATUS_PLLSTABLE field. */
#define BR_MIPI_DSI_STATUS_PLLSTABLE(x) (HW_MIPI_DSI_STATUS(x).B.PLLSTABLE)
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_RGB_STATUS - RGB Status Register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_RGB_STATUS - RGB Status Register (RO)
 *
 * Reset value: 0x00000001U
 */
typedef union _hw_mipi_dsi_rgb_status
{
    uint32_t U;
    struct _hw_mipi_dsi_rgb_status_bitfields
    {
        uint32_t RGBSTATE : 13;        /*!< [12:0]  */
        uint32_t RESERVED0 : 18;       /*!< [30:13]  */
        uint32_t CMDMODE_INSEL : 1;    /*!< [31]  */
    } B;
} hw_mipi_dsi_rgb_status_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_RGB_STATUS register
 */
/*@{*/
#define HW_MIPI_DSI_RGB_STATUS_ADDR(x) ((uintptr_t)(x) + 0x8U)

#define HW_MIPI_DSI_RGB_STATUS(x) (*(__I hw_mipi_dsi_rgb_status_t *) HW_MIPI_DSI_RGB_STATUS_ADDR(x))
#define HW_MIPI_DSI_RGB_STATUS_RD(x) (HW_MIPI_DSI_RGB_STATUS(x).U)
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_RGB_STATUS bitfields
 */

/*!
 * @name Register MIPI_DSI_RGB_STATUS, field RGBSTATE[12:0] (RO)
 *
 * Specifies the RGB packetize FSM status
 *
 * Values:
 * - 1 - IDLE
 * - 10 - STOP
 * - 100 - VSYS
 * - 1000 - VSE
 * - 10000 - HSS
 * - 100000 - HSA
 * - 1000000 - HSE
 * - 10000000 - HBP
 * - 100000000 - RGB
 * - 1000000000 - NULL
 * - 10000000000 - HFP
 * - 100000000000 - EOT
 * - 1000000000000 - NHOLD
 */
/*@{*/
#define BP_MIPI_DSI_RGB_STATUS_RGBSTATE (0U) /*!< Bit position for MIPI_DSI_RGB_STATUS_RGBSTATE. */
#define BM_MIPI_DSI_RGB_STATUS_RGBSTATE (0x00001FFFU) /*!< Bit mask for MIPI_DSI_RGB_STATUS_RGBSTATE. */
#define BS_MIPI_DSI_RGB_STATUS_RGBSTATE (13U) /*!< Bit field size in bits for MIPI_DSI_RGB_STATUS_RGBSTATE. */

/*! @brief Read current value of the MIPI_DSI_RGB_STATUS_RGBSTATE field. */
#define BR_MIPI_DSI_RGB_STATUS_RGBSTATE(x) (HW_MIPI_DSI_RGB_STATUS(x).B.RGBSTATE)
/*@}*/

/*!
 * @name Register MIPI_DSI_RGB_STATUS, field CMDMODE_INSEL[31] (RO)
 *
 * Specifies the command mode input selection
 *
 * Values:
 * - 0 - Using RGB video interface
 * - 1 - Using S-i80 interface
 */
/*@{*/
#define BP_MIPI_DSI_RGB_STATUS_CMDMODE_INSEL (31U) /*!< Bit position for MIPI_DSI_RGB_STATUS_CMDMODE_INSEL. */
#define BM_MIPI_DSI_RGB_STATUS_CMDMODE_INSEL (0x80000000U) /*!< Bit mask for MIPI_DSI_RGB_STATUS_CMDMODE_INSEL. */
#define BS_MIPI_DSI_RGB_STATUS_CMDMODE_INSEL (1U) /*!< Bit field size in bits for MIPI_DSI_RGB_STATUS_CMDMODE_INSEL. */

/*! @brief Read current value of the MIPI_DSI_RGB_STATUS_CMDMODE_INSEL field. */
#define BR_MIPI_DSI_RGB_STATUS_CMDMODE_INSEL(x) (HW_MIPI_DSI_RGB_STATUS(x).B.CMDMODE_INSEL)
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_SWRST -
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_SWRST -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mipi_dsi_swrst
{
    uint32_t U;
    struct _hw_mipi_dsi_swrst_bitfields
    {
        uint32_t SWRST : 1;            /*!< [0]  */
        uint32_t RESERVED0 : 15;       /*!< [15:1]  */
        uint32_t FUNCRST : 1;          /*!< [16]  */
        uint32_t RESERVED1 : 15;       /*!< [31:17]  */
    } B;
} hw_mipi_dsi_swrst_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_SWRST register
 */
/*@{*/
#define HW_MIPI_DSI_SWRST_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_MIPI_DSI_SWRST(x)     (*(__IO hw_mipi_dsi_swrst_t *) HW_MIPI_DSI_SWRST_ADDR(x))
#define HW_MIPI_DSI_SWRST_RD(x)  (HW_MIPI_DSI_SWRST(x).U)
#define HW_MIPI_DSI_SWRST_WR(x, v) (HW_MIPI_DSI_SWRST(x).U = (v))
#define HW_MIPI_DSI_SWRST_SET(x, v) (HW_MIPI_DSI_SWRST_WR(x, HW_MIPI_DSI_SWRST_RD(x) |  (v)))
#define HW_MIPI_DSI_SWRST_CLR(x, v) (HW_MIPI_DSI_SWRST_WR(x, HW_MIPI_DSI_SWRST_RD(x) & ~(v)))
#define HW_MIPI_DSI_SWRST_TOG(x, v) (HW_MIPI_DSI_SWRST_WR(x, HW_MIPI_DSI_SWRST_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_SWRST bitfields
 */

/*!
 * @name Register MIPI_DSI_SWRST, field SWRST[0] (RW)
 *
 * Specifies the software reset (High active). "Software reset" resets all FF in
 * MIPI DSIM (except some SFRs: STATUS, SWRST, CLKCTRL, PLLCTRL, PLLTMR,
 * PHYTUNE, and VERINFORM).
 *
 * Values:
 * - 0 - Standy
 * - 1 - Reset
 */
/*@{*/
#define BP_MIPI_DSI_SWRST_SWRST (0U)       /*!< Bit position for MIPI_DSI_SWRST_SWRST. */
#define BM_MIPI_DSI_SWRST_SWRST (0x00000001U) /*!< Bit mask for MIPI_DSI_SWRST_SWRST. */
#define BS_MIPI_DSI_SWRST_SWRST (1U)       /*!< Bit field size in bits for MIPI_DSI_SWRST_SWRST. */

/*! @brief Read current value of the MIPI_DSI_SWRST_SWRST field. */
#define BR_MIPI_DSI_SWRST_SWRST(x) (HW_MIPI_DSI_SWRST(x).B.SWRST)

/*! @brief Format value for bitfield MIPI_DSI_SWRST_SWRST. */
#define BF_MIPI_DSI_SWRST_SWRST(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_SWRST_SWRST) & BM_MIPI_DSI_SWRST_SWRST)

/*! @brief Set the SWRST field to a new value. */
#define BW_MIPI_DSI_SWRST_SWRST(x, v) (HW_MIPI_DSI_SWRST_WR(x, (HW_MIPI_DSI_SWRST_RD(x) & ~BM_MIPI_DSI_SWRST_SWRST) | BF_MIPI_DSI_SWRST_SWRST(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_SWRST, field FUNCRST[16] (RW)
 *
 * Specifies the software reset (High active). "Function reset" resets all FF in
 * MIPI DSIM (except SFRs: STATUS, RGB_STATUS, SWRST, CLKCTRL, TIMEOUT, CONFIG,
 * ESCMODEForceStopstate, CmdLpdt, TxLpdt, MDRESOL, MVPORCH, MHPORCH, MSYNC,
 * INTMSK, SDRESOL, S3D_CTL, P3D_CTL, MIC_CTL, P3D_ON_MIC_OFF_HSA,
 * P3D_OFF_MIC_ON_HSA, P3D_ON_MIC_ON_HSA, P3D_ON_MIC_OFF_HFP, P3D_OFF_MIC_ON_HFP,
 * P3D_ON_MIC_ON_HFP, MULTI_PKT, FIFOTHLD, FIFOCTRLnInitRx, nInitSfr, nInitI80, nInitSub, nInitMD,
 * MEMACCHR, PLLCTRL, PLLTMR, PHYACCHR, and VERINFORM).
 *
 * Values:
 * - 0 - Standy
 * - 1 - Reset
 */
/*@{*/
#define BP_MIPI_DSI_SWRST_FUNCRST (16U)    /*!< Bit position for MIPI_DSI_SWRST_FUNCRST. */
#define BM_MIPI_DSI_SWRST_FUNCRST (0x00010000U) /*!< Bit mask for MIPI_DSI_SWRST_FUNCRST. */
#define BS_MIPI_DSI_SWRST_FUNCRST (1U)     /*!< Bit field size in bits for MIPI_DSI_SWRST_FUNCRST. */

/*! @brief Read current value of the MIPI_DSI_SWRST_FUNCRST field. */
#define BR_MIPI_DSI_SWRST_FUNCRST(x) (HW_MIPI_DSI_SWRST(x).B.FUNCRST)

/*! @brief Format value for bitfield MIPI_DSI_SWRST_FUNCRST. */
#define BF_MIPI_DSI_SWRST_FUNCRST(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_SWRST_FUNCRST) & BM_MIPI_DSI_SWRST_FUNCRST)

/*! @brief Set the FUNCRST field to a new value. */
#define BW_MIPI_DSI_SWRST_FUNCRST(x, v) (HW_MIPI_DSI_SWRST_WR(x, (HW_MIPI_DSI_SWRST_RD(x) & ~BM_MIPI_DSI_SWRST_FUNCRST) | BF_MIPI_DSI_SWRST_FUNCRST(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_CLKCTRL - Clock Control Register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_CLKCTRL - Clock Control Register (RW)
 *
 * Reset value: 0x0000FFFFU
 */
typedef union _hw_mipi_dsi_clkctrl
{
    uint32_t U;
    struct _hw_mipi_dsi_clkctrl_bitfields
    {
        uint32_t ESCPRESCALER : 16;    /*!< [15:0]  */
        uint32_t RESERVED0 : 3;        /*!< [18:16]  */
        uint32_t LANEESCCLKEN : 5;     /*!< [23:19]  */
        uint32_t ByteClkEn : 1;        /*!< [24]  */
        uint32_t BYTECLKSRC : 2;       /*!< [26:25]  */
        uint32_t PLLBYPASS : 1;        /*!< [27]  */
        uint32_t ESCCLKEN : 1;         /*!< [28]  */
        uint32_t DPHY_SEL : 1;         /*!< [29] D-PHY Select */
        uint32_t RESERVED1 : 1;        /*!< [30]  */
        uint32_t TXREQUESTHSCLK : 1;   /*!< [31]  */
    } B;
} hw_mipi_dsi_clkctrl_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_CLKCTRL register
 */
/*@{*/
#define HW_MIPI_DSI_CLKCTRL_ADDR(x) ((uintptr_t)(x) + 0x10U)

#define HW_MIPI_DSI_CLKCTRL(x)   (*(__IO hw_mipi_dsi_clkctrl_t *) HW_MIPI_DSI_CLKCTRL_ADDR(x))
#define HW_MIPI_DSI_CLKCTRL_RD(x) (HW_MIPI_DSI_CLKCTRL(x).U)
#define HW_MIPI_DSI_CLKCTRL_WR(x, v) (HW_MIPI_DSI_CLKCTRL(x).U = (v))
#define HW_MIPI_DSI_CLKCTRL_SET(x, v) (HW_MIPI_DSI_CLKCTRL_WR(x, HW_MIPI_DSI_CLKCTRL_RD(x) |  (v)))
#define HW_MIPI_DSI_CLKCTRL_CLR(x, v) (HW_MIPI_DSI_CLKCTRL_WR(x, HW_MIPI_DSI_CLKCTRL_RD(x) & ~(v)))
#define HW_MIPI_DSI_CLKCTRL_TOG(x, v) (HW_MIPI_DSI_CLKCTRL_WR(x, HW_MIPI_DSI_CLKCTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_CLKCTRL bitfields
 */

/*!
 * @name Register MIPI_DSI_CLKCTRL, field ESCPRESCALER[15:0] (RW)
 *
 * Specifies the escape clock prescaler value. The escape clock frequency range
 * varies up to 20 MHz. The requirement for BTA is that the Host Escclk frequency
 * should range between 66.7 ~ 150% of the peripheral escape clock frequency.
 * EscClk = ByteClk / (EscPrescaler)
 */
/*@{*/
#define BP_MIPI_DSI_CLKCTRL_ESCPRESCALER (0U) /*!< Bit position for MIPI_DSI_CLKCTRL_ESCPRESCALER. */
#define BM_MIPI_DSI_CLKCTRL_ESCPRESCALER (0x0000FFFFU) /*!< Bit mask for MIPI_DSI_CLKCTRL_ESCPRESCALER. */
#define BS_MIPI_DSI_CLKCTRL_ESCPRESCALER (16U) /*!< Bit field size in bits for MIPI_DSI_CLKCTRL_ESCPRESCALER. */

/*! @brief Read current value of the MIPI_DSI_CLKCTRL_ESCPRESCALER field. */
#define BR_MIPI_DSI_CLKCTRL_ESCPRESCALER(x) (HW_MIPI_DSI_CLKCTRL(x).B.ESCPRESCALER)

/*! @brief Format value for bitfield MIPI_DSI_CLKCTRL_ESCPRESCALER. */
#define BF_MIPI_DSI_CLKCTRL_ESCPRESCALER(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CLKCTRL_ESCPRESCALER) & BM_MIPI_DSI_CLKCTRL_ESCPRESCALER)

/*! @brief Set the ESCPRESCALER field to a new value. */
#define BW_MIPI_DSI_CLKCTRL_ESCPRESCALER(x, v) (HW_MIPI_DSI_CLKCTRL_WR(x, (HW_MIPI_DSI_CLKCTRL_RD(x) & ~BM_MIPI_DSI_CLKCTRL_ESCPRESCALER) | BF_MIPI_DSI_CLKCTRL_ESCPRESCALER(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CLKCTRL, field LANEESCCLKEN[23:19] (RW)
 *
 * Enables escape clock for D-phy lane LaneEscClkEn[0] = Clock lane
 * LaneEscClkEn[1] = Data lane 0 LaneEscClkEn[2] = Data lane 1 LaneEscClkEn[3] = Reserved
 * LaneEscClkEn[4] = Reserved
 *
 * Values:
 * - 0 - Disables
 * - 1 - Enables
 */
/*@{*/
#define BP_MIPI_DSI_CLKCTRL_LANEESCCLKEN (19U) /*!< Bit position for MIPI_DSI_CLKCTRL_LANEESCCLKEN. */
#define BM_MIPI_DSI_CLKCTRL_LANEESCCLKEN (0x00F80000U) /*!< Bit mask for MIPI_DSI_CLKCTRL_LANEESCCLKEN. */
#define BS_MIPI_DSI_CLKCTRL_LANEESCCLKEN (5U) /*!< Bit field size in bits for MIPI_DSI_CLKCTRL_LANEESCCLKEN. */

/*! @brief Read current value of the MIPI_DSI_CLKCTRL_LANEESCCLKEN field. */
#define BR_MIPI_DSI_CLKCTRL_LANEESCCLKEN(x) (HW_MIPI_DSI_CLKCTRL(x).B.LANEESCCLKEN)

/*! @brief Format value for bitfield MIPI_DSI_CLKCTRL_LANEESCCLKEN. */
#define BF_MIPI_DSI_CLKCTRL_LANEESCCLKEN(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CLKCTRL_LANEESCCLKEN) & BM_MIPI_DSI_CLKCTRL_LANEESCCLKEN)

/*! @brief Set the LANEESCCLKEN field to a new value. */
#define BW_MIPI_DSI_CLKCTRL_LANEESCCLKEN(x, v) (HW_MIPI_DSI_CLKCTRL_WR(x, (HW_MIPI_DSI_CLKCTRL_RD(x) & ~BM_MIPI_DSI_CLKCTRL_LANEESCCLKEN) | BF_MIPI_DSI_CLKCTRL_LANEESCCLKEN(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CLKCTRL, field ByteClkEn[24] (RW)
 *
 * Enables byte clock
 *
 * Values:
 * - 0 - Disables
 * - 1 - Enables
 */
/*@{*/
#define BP_MIPI_DSI_CLKCTRL_ByteClkEn (24U) /*!< Bit position for MIPI_DSI_CLKCTRL_ByteClkEn. */
#define BM_MIPI_DSI_CLKCTRL_ByteClkEn (0x01000000U) /*!< Bit mask for MIPI_DSI_CLKCTRL_ByteClkEn. */
#define BS_MIPI_DSI_CLKCTRL_ByteClkEn (1U) /*!< Bit field size in bits for MIPI_DSI_CLKCTRL_ByteClkEn. */

/*! @brief Read current value of the MIPI_DSI_CLKCTRL_ByteClkEn field. */
#define BR_MIPI_DSI_CLKCTRL_ByteClkEn(x) (HW_MIPI_DSI_CLKCTRL(x).B.ByteClkEn)

/*! @brief Format value for bitfield MIPI_DSI_CLKCTRL_ByteClkEn. */
#define BF_MIPI_DSI_CLKCTRL_ByteClkEn(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CLKCTRL_ByteClkEn) & BM_MIPI_DSI_CLKCTRL_ByteClkEn)

/*! @brief Set the ByteClkEn field to a new value. */
#define BW_MIPI_DSI_CLKCTRL_ByteClkEn(x, v) (HW_MIPI_DSI_CLKCTRL_WR(x, (HW_MIPI_DSI_CLKCTRL_RD(x) & ~BM_MIPI_DSI_CLKCTRL_ByteClkEn) | BF_MIPI_DSI_CLKCTRL_ByteClkEn(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CLKCTRL, field BYTECLKSRC[26:25] (RW)
 *
 * Selects byte clock source. (It must be 2'b00.) 00 = D-PHY PLL (default).
 * PLL_out clock is used to generate ByteClk by dividing 8.
 */
/*@{*/
#define BP_MIPI_DSI_CLKCTRL_BYTECLKSRC (25U) /*!< Bit position for MIPI_DSI_CLKCTRL_BYTECLKSRC. */
#define BM_MIPI_DSI_CLKCTRL_BYTECLKSRC (0x06000000U) /*!< Bit mask for MIPI_DSI_CLKCTRL_BYTECLKSRC. */
#define BS_MIPI_DSI_CLKCTRL_BYTECLKSRC (2U) /*!< Bit field size in bits for MIPI_DSI_CLKCTRL_BYTECLKSRC. */

/*! @brief Read current value of the MIPI_DSI_CLKCTRL_BYTECLKSRC field. */
#define BR_MIPI_DSI_CLKCTRL_BYTECLKSRC(x) (HW_MIPI_DSI_CLKCTRL(x).B.BYTECLKSRC)

/*! @brief Format value for bitfield MIPI_DSI_CLKCTRL_BYTECLKSRC. */
#define BF_MIPI_DSI_CLKCTRL_BYTECLKSRC(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CLKCTRL_BYTECLKSRC) & BM_MIPI_DSI_CLKCTRL_BYTECLKSRC)

/*! @brief Set the BYTECLKSRC field to a new value. */
#define BW_MIPI_DSI_CLKCTRL_BYTECLKSRC(x, v) (HW_MIPI_DSI_CLKCTRL_WR(x, (HW_MIPI_DSI_CLKCTRL_RD(x) & ~BM_MIPI_DSI_CLKCTRL_BYTECLKSRC) | BF_MIPI_DSI_CLKCTRL_BYTECLKSRC(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CLKCTRL, field PLLBYPASS[27] (RW)
 *
 * Sets the PLLBypass signal connected to D-PHY module input for selecting clock
 * source bit. This bit must be set to 0.
 *
 * Values:
 * - 0 - PLL output
 * - 1 - External Serial clock
 */
/*@{*/
#define BP_MIPI_DSI_CLKCTRL_PLLBYPASS (27U) /*!< Bit position for MIPI_DSI_CLKCTRL_PLLBYPASS. */
#define BM_MIPI_DSI_CLKCTRL_PLLBYPASS (0x08000000U) /*!< Bit mask for MIPI_DSI_CLKCTRL_PLLBYPASS. */
#define BS_MIPI_DSI_CLKCTRL_PLLBYPASS (1U) /*!< Bit field size in bits for MIPI_DSI_CLKCTRL_PLLBYPASS. */

/*! @brief Read current value of the MIPI_DSI_CLKCTRL_PLLBYPASS field. */
#define BR_MIPI_DSI_CLKCTRL_PLLBYPASS(x) (HW_MIPI_DSI_CLKCTRL(x).B.PLLBYPASS)

/*! @brief Format value for bitfield MIPI_DSI_CLKCTRL_PLLBYPASS. */
#define BF_MIPI_DSI_CLKCTRL_PLLBYPASS(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CLKCTRL_PLLBYPASS) & BM_MIPI_DSI_CLKCTRL_PLLBYPASS)

/*! @brief Set the PLLBYPASS field to a new value. */
#define BW_MIPI_DSI_CLKCTRL_PLLBYPASS(x, v) (HW_MIPI_DSI_CLKCTRL_WR(x, (HW_MIPI_DSI_CLKCTRL_RD(x) & ~BM_MIPI_DSI_CLKCTRL_PLLBYPASS) | BF_MIPI_DSI_CLKCTRL_PLLBYPASS(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CLKCTRL, field ESCCLKEN[28] (RW)
 *
 * Enables the escape clock generating prescaler
 *
 * Values:
 * - 0 - Disables
 * - 1 - Enables
 */
/*@{*/
#define BP_MIPI_DSI_CLKCTRL_ESCCLKEN (28U) /*!< Bit position for MIPI_DSI_CLKCTRL_ESCCLKEN. */
#define BM_MIPI_DSI_CLKCTRL_ESCCLKEN (0x10000000U) /*!< Bit mask for MIPI_DSI_CLKCTRL_ESCCLKEN. */
#define BS_MIPI_DSI_CLKCTRL_ESCCLKEN (1U)  /*!< Bit field size in bits for MIPI_DSI_CLKCTRL_ESCCLKEN. */

/*! @brief Read current value of the MIPI_DSI_CLKCTRL_ESCCLKEN field. */
#define BR_MIPI_DSI_CLKCTRL_ESCCLKEN(x) (HW_MIPI_DSI_CLKCTRL(x).B.ESCCLKEN)

/*! @brief Format value for bitfield MIPI_DSI_CLKCTRL_ESCCLKEN. */
#define BF_MIPI_DSI_CLKCTRL_ESCCLKEN(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CLKCTRL_ESCCLKEN) & BM_MIPI_DSI_CLKCTRL_ESCCLKEN)

/*! @brief Set the ESCCLKEN field to a new value. */
#define BW_MIPI_DSI_CLKCTRL_ESCCLKEN(x, v) (HW_MIPI_DSI_CLKCTRL_WR(x, (HW_MIPI_DSI_CLKCTRL_RD(x) & ~BM_MIPI_DSI_CLKCTRL_ESCCLKEN) | BF_MIPI_DSI_CLKCTRL_ESCCLKEN(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CLKCTRL, field DPHY_SEL[29] (RW)
 *
 * Values:
 * - 0 - 1.5 Gbps D-PHY (default)
 * - 1 - 1 Gbps D-PHY
 */
/*@{*/
#define BP_MIPI_DSI_CLKCTRL_DPHY_SEL (29U) /*!< Bit position for MIPI_DSI_CLKCTRL_DPHY_SEL. */
#define BM_MIPI_DSI_CLKCTRL_DPHY_SEL (0x20000000U) /*!< Bit mask for MIPI_DSI_CLKCTRL_DPHY_SEL. */
#define BS_MIPI_DSI_CLKCTRL_DPHY_SEL (1U)  /*!< Bit field size in bits for MIPI_DSI_CLKCTRL_DPHY_SEL. */

/*! @brief Read current value of the MIPI_DSI_CLKCTRL_DPHY_SEL field. */
#define BR_MIPI_DSI_CLKCTRL_DPHY_SEL(x) (HW_MIPI_DSI_CLKCTRL(x).B.DPHY_SEL)

/*! @brief Format value for bitfield MIPI_DSI_CLKCTRL_DPHY_SEL. */
#define BF_MIPI_DSI_CLKCTRL_DPHY_SEL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CLKCTRL_DPHY_SEL) & BM_MIPI_DSI_CLKCTRL_DPHY_SEL)

/*! @brief Set the DPHY_SEL field to a new value. */
#define BW_MIPI_DSI_CLKCTRL_DPHY_SEL(x, v) (HW_MIPI_DSI_CLKCTRL_WR(x, (HW_MIPI_DSI_CLKCTRL_RD(x) & ~BM_MIPI_DSI_CLKCTRL_DPHY_SEL) | BF_MIPI_DSI_CLKCTRL_DPHY_SEL(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CLKCTRL, field TXREQUESTHSCLK[31] (RW)
 *
 * Specifies the HS clock request for HS transfer at clock lane (Turn on HS
 * clock)
 */
/*@{*/
#define BP_MIPI_DSI_CLKCTRL_TXREQUESTHSCLK (31U) /*!< Bit position for MIPI_DSI_CLKCTRL_TXREQUESTHSCLK. */
#define BM_MIPI_DSI_CLKCTRL_TXREQUESTHSCLK (0x80000000U) /*!< Bit mask for MIPI_DSI_CLKCTRL_TXREQUESTHSCLK. */
#define BS_MIPI_DSI_CLKCTRL_TXREQUESTHSCLK (1U) /*!< Bit field size in bits for MIPI_DSI_CLKCTRL_TXREQUESTHSCLK. */

/*! @brief Read current value of the MIPI_DSI_CLKCTRL_TXREQUESTHSCLK field. */
#define BR_MIPI_DSI_CLKCTRL_TXREQUESTHSCLK(x) (HW_MIPI_DSI_CLKCTRL(x).B.TXREQUESTHSCLK)

/*! @brief Format value for bitfield MIPI_DSI_CLKCTRL_TXREQUESTHSCLK. */
#define BF_MIPI_DSI_CLKCTRL_TXREQUESTHSCLK(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CLKCTRL_TXREQUESTHSCLK) & BM_MIPI_DSI_CLKCTRL_TXREQUESTHSCLK)

/*! @brief Set the TXREQUESTHSCLK field to a new value. */
#define BW_MIPI_DSI_CLKCTRL_TXREQUESTHSCLK(x, v) (HW_MIPI_DSI_CLKCTRL_WR(x, (HW_MIPI_DSI_CLKCTRL_RD(x) & ~BM_MIPI_DSI_CLKCTRL_TXREQUESTHSCLK) | BF_MIPI_DSI_CLKCTRL_TXREQUESTHSCLK(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_TIMEOUT -
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_TIMEOUT -  (RW)
 *
 * Reset value: 0x00FFFFFFU
 */
typedef union _hw_mipi_dsi_timeout
{
    uint32_t U;
    struct _hw_mipi_dsi_timeout_bitfields
    {
        uint32_t LPDRTOUT : 16;        /*!< [15:0]  */
        uint32_t BTAOUT : 8;           /*!< [23:16]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_mipi_dsi_timeout_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_TIMEOUT register
 */
/*@{*/
#define HW_MIPI_DSI_TIMEOUT_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_MIPI_DSI_TIMEOUT(x)   (*(__IO hw_mipi_dsi_timeout_t *) HW_MIPI_DSI_TIMEOUT_ADDR(x))
#define HW_MIPI_DSI_TIMEOUT_RD(x) (HW_MIPI_DSI_TIMEOUT(x).U)
#define HW_MIPI_DSI_TIMEOUT_WR(x, v) (HW_MIPI_DSI_TIMEOUT(x).U = (v))
#define HW_MIPI_DSI_TIMEOUT_SET(x, v) (HW_MIPI_DSI_TIMEOUT_WR(x, HW_MIPI_DSI_TIMEOUT_RD(x) |  (v)))
#define HW_MIPI_DSI_TIMEOUT_CLR(x, v) (HW_MIPI_DSI_TIMEOUT_WR(x, HW_MIPI_DSI_TIMEOUT_RD(x) & ~(v)))
#define HW_MIPI_DSI_TIMEOUT_TOG(x, v) (HW_MIPI_DSI_TIMEOUT_WR(x, HW_MIPI_DSI_TIMEOUT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_TIMEOUT bitfields
 */

/*!
 * @name Register MIPI_DSI_TIMEOUT, field LPDRTOUT[15:0] (RW)
 *
 * Specifies the timer for LP Rx mode timeout. This register specifies time out
 * on how long RxValid deasserts, after RxLpdt asserts with respect to Tx escape
 * clock. RxValid specifies Rx data valid indicator. RxLpdt specifies an
 * indicator that D-phy is under RxLpdt mode. RxValid and RxLpdt specifies signal from
 * D-phy.
 */
/*@{*/
#define BP_MIPI_DSI_TIMEOUT_LPDRTOUT (0U)  /*!< Bit position for MIPI_DSI_TIMEOUT_LPDRTOUT. */
#define BM_MIPI_DSI_TIMEOUT_LPDRTOUT (0x0000FFFFU) /*!< Bit mask for MIPI_DSI_TIMEOUT_LPDRTOUT. */
#define BS_MIPI_DSI_TIMEOUT_LPDRTOUT (16U) /*!< Bit field size in bits for MIPI_DSI_TIMEOUT_LPDRTOUT. */

/*! @brief Read current value of the MIPI_DSI_TIMEOUT_LPDRTOUT field. */
#define BR_MIPI_DSI_TIMEOUT_LPDRTOUT(x) (HW_MIPI_DSI_TIMEOUT(x).B.LPDRTOUT)

/*! @brief Format value for bitfield MIPI_DSI_TIMEOUT_LPDRTOUT. */
#define BF_MIPI_DSI_TIMEOUT_LPDRTOUT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_TIMEOUT_LPDRTOUT) & BM_MIPI_DSI_TIMEOUT_LPDRTOUT)

/*! @brief Set the LPDRTOUT field to a new value. */
#define BW_MIPI_DSI_TIMEOUT_LPDRTOUT(x, v) (HW_MIPI_DSI_TIMEOUT_WR(x, (HW_MIPI_DSI_TIMEOUT_RD(x) & ~BM_MIPI_DSI_TIMEOUT_LPDRTOUT) | BF_MIPI_DSI_TIMEOUT_LPDRTOUT(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_TIMEOUT, field BTAOUT[23:16] (RW)
 *
 * Specifies the timer for BTA. This register specifies time out from BTA
 * request to change the direction with respect to Tx escape clock.
 */
/*@{*/
#define BP_MIPI_DSI_TIMEOUT_BTAOUT (16U)   /*!< Bit position for MIPI_DSI_TIMEOUT_BTAOUT. */
#define BM_MIPI_DSI_TIMEOUT_BTAOUT (0x00FF0000U) /*!< Bit mask for MIPI_DSI_TIMEOUT_BTAOUT. */
#define BS_MIPI_DSI_TIMEOUT_BTAOUT (8U)    /*!< Bit field size in bits for MIPI_DSI_TIMEOUT_BTAOUT. */

/*! @brief Read current value of the MIPI_DSI_TIMEOUT_BTAOUT field. */
#define BR_MIPI_DSI_TIMEOUT_BTAOUT(x) (HW_MIPI_DSI_TIMEOUT(x).B.BTAOUT)

/*! @brief Format value for bitfield MIPI_DSI_TIMEOUT_BTAOUT. */
#define BF_MIPI_DSI_TIMEOUT_BTAOUT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_TIMEOUT_BTAOUT) & BM_MIPI_DSI_TIMEOUT_BTAOUT)

/*! @brief Set the BTAOUT field to a new value. */
#define BW_MIPI_DSI_TIMEOUT_BTAOUT(x, v) (HW_MIPI_DSI_TIMEOUT_WR(x, (HW_MIPI_DSI_TIMEOUT_RD(x) & ~BM_MIPI_DSI_TIMEOUT_BTAOUT) | BF_MIPI_DSI_TIMEOUT_BTAOUT(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_CONFIG -
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_CONFIG -  (RW)
 *
 * Reset value: 0x00200000U
 *
 * This register configures MIPI DSI master such as data lane number, input
 * interface, porch area, frame rate, BTA, LPDT, ULPS, and so on.
 */
typedef union _hw_mipi_dsi_config
{
    uint32_t U;
    struct _hw_mipi_dsi_config_bitfields
    {
        uint32_t LANEEN : 5;           /*!< [4:0]  */
        uint32_t NUMOFDATLANE : 2;     /*!< [6:5]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t SUBPIXFORMAT : 3;     /*!< [10:8]  */
        uint32_t RESERVED1 : 1;        /*!< [11]  */
        uint32_t MAINPIXFORMAT : 3;    /*!< [14:12]  */
        uint32_t RESERVED2 : 1;        /*!< [15]  */
        uint32_t SUBVC : 2;            /*!< [17:16]  */
        uint32_t MAINVC : 2;           /*!< [19:18]  */
        uint32_t HSADISABLEMODE : 1;   /*!< [20]  */
        uint32_t HBPDISABLEMODE : 1;   /*!< [21]  */
        uint32_t HFPDISABLEMODE : 1;   /*!< [22]  */
        uint32_t HSEDISABLEMODE : 1;   /*!< [23]  */
        uint32_t AUTOMODE : 1;         /*!< [24]  */
        uint32_t VIDEOMODE : 1;        /*!< [25]  */
        uint32_t BURSTMODE : 1;        /*!< [26]  */
        uint32_t SYNCINFORM : 1;       /*!< [27]  */
        uint32_t EOT_R03 : 1;          /*!< [28]  */
        uint32_t MFLUSH_VS : 1;        /*!< [29]  */
        uint32_t CLKLANE_STOP_START : 1; /*!< [30]  */
        uint32_t NON_CONTINUOUS_CLOCK_LANE : 1; /*!< [31]  */
    } B;
} hw_mipi_dsi_config_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_CONFIG register
 */
/*@{*/
#define HW_MIPI_DSI_CONFIG_ADDR(x) ((uintptr_t)(x) + 0x18U)

#define HW_MIPI_DSI_CONFIG(x)    (*(__IO hw_mipi_dsi_config_t *) HW_MIPI_DSI_CONFIG_ADDR(x))
#define HW_MIPI_DSI_CONFIG_RD(x) (HW_MIPI_DSI_CONFIG(x).U)
#define HW_MIPI_DSI_CONFIG_WR(x, v) (HW_MIPI_DSI_CONFIG(x).U = (v))
#define HW_MIPI_DSI_CONFIG_SET(x, v) (HW_MIPI_DSI_CONFIG_WR(x, HW_MIPI_DSI_CONFIG_RD(x) |  (v)))
#define HW_MIPI_DSI_CONFIG_CLR(x, v) (HW_MIPI_DSI_CONFIG_WR(x, HW_MIPI_DSI_CONFIG_RD(x) & ~(v)))
#define HW_MIPI_DSI_CONFIG_TOG(x, v) (HW_MIPI_DSI_CONFIG_WR(x, HW_MIPI_DSI_CONFIG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_CONFIG bitfields
 */

/*!
 * @name Register MIPI_DSI_CONFIG, field LANEEN[4:0] (RW)
 *
 * Enables the lane. If Lane_EN is disabled, the lane ignores input and drives
 * initial value through output port. LaneEn[0] = Clock lane enabler LaneEn[1] =
 * Data lane 0 enabler LaneEn[2] = Data lane 1 enabler LaneEn[3] = Reserved
 * LaneEn[4] = Reserved
 */
/*@{*/
#define BP_MIPI_DSI_CONFIG_LANEEN (0U)     /*!< Bit position for MIPI_DSI_CONFIG_LANEEN. */
#define BM_MIPI_DSI_CONFIG_LANEEN (0x0000001FU) /*!< Bit mask for MIPI_DSI_CONFIG_LANEEN. */
#define BS_MIPI_DSI_CONFIG_LANEEN (5U)     /*!< Bit field size in bits for MIPI_DSI_CONFIG_LANEEN. */

/*! @brief Read current value of the MIPI_DSI_CONFIG_LANEEN field. */
#define BR_MIPI_DSI_CONFIG_LANEEN(x) (HW_MIPI_DSI_CONFIG(x).B.LANEEN)

/*! @brief Format value for bitfield MIPI_DSI_CONFIG_LANEEN. */
#define BF_MIPI_DSI_CONFIG_LANEEN(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CONFIG_LANEEN) & BM_MIPI_DSI_CONFIG_LANEEN)

/*! @brief Set the LANEEN field to a new value. */
#define BW_MIPI_DSI_CONFIG_LANEEN(x, v) (HW_MIPI_DSI_CONFIG_WR(x, (HW_MIPI_DSI_CONFIG_RD(x) & ~BM_MIPI_DSI_CONFIG_LANEEN) | BF_MIPI_DSI_CONFIG_LANEEN(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CONFIG, field NUMOFDATLANE[6:5] (RW)
 *
 * Sets the data lane number
 *
 * Values:
 * - 00 - Data lane 0 ( 1 data lane)
 * - 01 - Data lane 0 ~ 1 (2 data lanes)
 * - 10 - Reserved.
 * - 11 - Reserved.
 */
/*@{*/
#define BP_MIPI_DSI_CONFIG_NUMOFDATLANE (5U) /*!< Bit position for MIPI_DSI_CONFIG_NUMOFDATLANE. */
#define BM_MIPI_DSI_CONFIG_NUMOFDATLANE (0x00000060U) /*!< Bit mask for MIPI_DSI_CONFIG_NUMOFDATLANE. */
#define BS_MIPI_DSI_CONFIG_NUMOFDATLANE (2U) /*!< Bit field size in bits for MIPI_DSI_CONFIG_NUMOFDATLANE. */

/*! @brief Read current value of the MIPI_DSI_CONFIG_NUMOFDATLANE field. */
#define BR_MIPI_DSI_CONFIG_NUMOFDATLANE(x) (HW_MIPI_DSI_CONFIG(x).B.NUMOFDATLANE)

/*! @brief Format value for bitfield MIPI_DSI_CONFIG_NUMOFDATLANE. */
#define BF_MIPI_DSI_CONFIG_NUMOFDATLANE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CONFIG_NUMOFDATLANE) & BM_MIPI_DSI_CONFIG_NUMOFDATLANE)

/*! @brief Set the NUMOFDATLANE field to a new value. */
#define BW_MIPI_DSI_CONFIG_NUMOFDATLANE(x, v) (HW_MIPI_DSI_CONFIG_WR(x, (HW_MIPI_DSI_CONFIG_RD(x) & ~BM_MIPI_DSI_CONFIG_NUMOFDATLANE) | BF_MIPI_DSI_CONFIG_NUMOFDATLANE(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CONFIG, field SUBPIXFORMAT[10:8] (RW)
 *
 * Specifies pixel stream format for main display
 *
 * Values:
 * - 000 - 3 bpp (for Command mode only)
 * - 001 - 8 bpp (for Command mode only)
 * - 010 - 12 bpp (for Command mode only)
 * - 011 - 16 bpp (for Command mode only)
 * - 100 - 16-bit RGB (565) (for Video mode only)
 * - 101 - 18-bit RGB (666: packed pixel stream) (for Video mode only)
 * - 110 - 18-bit RGB (666: loosely packed pixel stream) for Common
 * - 111 - 24-bit RGB (888) for common
 */
/*@{*/
#define BP_MIPI_DSI_CONFIG_SUBPIXFORMAT (8U) /*!< Bit position for MIPI_DSI_CONFIG_SUBPIXFORMAT. */
#define BM_MIPI_DSI_CONFIG_SUBPIXFORMAT (0x00000700U) /*!< Bit mask for MIPI_DSI_CONFIG_SUBPIXFORMAT. */
#define BS_MIPI_DSI_CONFIG_SUBPIXFORMAT (3U) /*!< Bit field size in bits for MIPI_DSI_CONFIG_SUBPIXFORMAT. */

/*! @brief Read current value of the MIPI_DSI_CONFIG_SUBPIXFORMAT field. */
#define BR_MIPI_DSI_CONFIG_SUBPIXFORMAT(x) (HW_MIPI_DSI_CONFIG(x).B.SUBPIXFORMAT)

/*! @brief Format value for bitfield MIPI_DSI_CONFIG_SUBPIXFORMAT. */
#define BF_MIPI_DSI_CONFIG_SUBPIXFORMAT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CONFIG_SUBPIXFORMAT) & BM_MIPI_DSI_CONFIG_SUBPIXFORMAT)

/*! @brief Set the SUBPIXFORMAT field to a new value. */
#define BW_MIPI_DSI_CONFIG_SUBPIXFORMAT(x, v) (HW_MIPI_DSI_CONFIG_WR(x, (HW_MIPI_DSI_CONFIG_RD(x) & ~BM_MIPI_DSI_CONFIG_SUBPIXFORMAT) | BF_MIPI_DSI_CONFIG_SUBPIXFORMAT(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CONFIG, field MAINPIXFORMAT[14:12] (RW)
 *
 * Specifies pixel stream format for main display
 *
 * Values:
 * - 000 - 3 bpp (for Command mode only)
 * - 001 - 8 bpp (for Command mode only)
 * - 010 - 12 bpp (for Command mode only)
 * - 011 - 16 bpp (for Command mode only)
 * - 100 - 16-bit RGB (565) (for Video mode only)
 * - 101 - 18-bit RGB (666: packed pixel stream) (for Video mode only)
 * - 110 - 18-bit RGB (666: loosely packed pixel stream) for Common
 * - 111 - 24-bit RGB (888) for common
 */
/*@{*/
#define BP_MIPI_DSI_CONFIG_MAINPIXFORMAT (12U) /*!< Bit position for MIPI_DSI_CONFIG_MAINPIXFORMAT. */
#define BM_MIPI_DSI_CONFIG_MAINPIXFORMAT (0x00007000U) /*!< Bit mask for MIPI_DSI_CONFIG_MAINPIXFORMAT. */
#define BS_MIPI_DSI_CONFIG_MAINPIXFORMAT (3U) /*!< Bit field size in bits for MIPI_DSI_CONFIG_MAINPIXFORMAT. */

/*! @brief Read current value of the MIPI_DSI_CONFIG_MAINPIXFORMAT field. */
#define BR_MIPI_DSI_CONFIG_MAINPIXFORMAT(x) (HW_MIPI_DSI_CONFIG(x).B.MAINPIXFORMAT)

/*! @brief Format value for bitfield MIPI_DSI_CONFIG_MAINPIXFORMAT. */
#define BF_MIPI_DSI_CONFIG_MAINPIXFORMAT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CONFIG_MAINPIXFORMAT) & BM_MIPI_DSI_CONFIG_MAINPIXFORMAT)

/*! @brief Set the MAINPIXFORMAT field to a new value. */
#define BW_MIPI_DSI_CONFIG_MAINPIXFORMAT(x, v) (HW_MIPI_DSI_CONFIG_WR(x, (HW_MIPI_DSI_CONFIG_RD(x) & ~BM_MIPI_DSI_CONFIG_MAINPIXFORMAT) | BF_MIPI_DSI_CONFIG_MAINPIXFORMAT(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CONFIG, field SUBVC[17:16] (RW)
 *
 * Specifies virtual channel number for sub display
 */
/*@{*/
#define BP_MIPI_DSI_CONFIG_SUBVC (16U)     /*!< Bit position for MIPI_DSI_CONFIG_SUBVC. */
#define BM_MIPI_DSI_CONFIG_SUBVC (0x00030000U) /*!< Bit mask for MIPI_DSI_CONFIG_SUBVC. */
#define BS_MIPI_DSI_CONFIG_SUBVC (2U)      /*!< Bit field size in bits for MIPI_DSI_CONFIG_SUBVC. */

/*! @brief Read current value of the MIPI_DSI_CONFIG_SUBVC field. */
#define BR_MIPI_DSI_CONFIG_SUBVC(x) (HW_MIPI_DSI_CONFIG(x).B.SUBVC)

/*! @brief Format value for bitfield MIPI_DSI_CONFIG_SUBVC. */
#define BF_MIPI_DSI_CONFIG_SUBVC(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CONFIG_SUBVC) & BM_MIPI_DSI_CONFIG_SUBVC)

/*! @brief Set the SUBVC field to a new value. */
#define BW_MIPI_DSI_CONFIG_SUBVC(x, v) (HW_MIPI_DSI_CONFIG_WR(x, (HW_MIPI_DSI_CONFIG_RD(x) & ~BM_MIPI_DSI_CONFIG_SUBVC) | BF_MIPI_DSI_CONFIG_SUBVC(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CONFIG, field MAINVC[19:18] (RW)
 *
 * Specifies virtual channel number for main display
 */
/*@{*/
#define BP_MIPI_DSI_CONFIG_MAINVC (18U)    /*!< Bit position for MIPI_DSI_CONFIG_MAINVC. */
#define BM_MIPI_DSI_CONFIG_MAINVC (0x000C0000U) /*!< Bit mask for MIPI_DSI_CONFIG_MAINVC. */
#define BS_MIPI_DSI_CONFIG_MAINVC (2U)     /*!< Bit field size in bits for MIPI_DSI_CONFIG_MAINVC. */

/*! @brief Read current value of the MIPI_DSI_CONFIG_MAINVC field. */
#define BR_MIPI_DSI_CONFIG_MAINVC(x) (HW_MIPI_DSI_CONFIG(x).B.MAINVC)

/*! @brief Format value for bitfield MIPI_DSI_CONFIG_MAINVC. */
#define BF_MIPI_DSI_CONFIG_MAINVC(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CONFIG_MAINVC) & BM_MIPI_DSI_CONFIG_MAINVC)

/*! @brief Set the MAINVC field to a new value. */
#define BW_MIPI_DSI_CONFIG_MAINVC(x, v) (HW_MIPI_DSI_CONFIG_WR(x, (HW_MIPI_DSI_CONFIG_RD(x) & ~BM_MIPI_DSI_CONFIG_MAINVC) | BF_MIPI_DSI_CONFIG_MAINVC(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CONFIG, field HSADISABLEMODE[20] (RW)
 *
 * Specifies HSA disable mode. If this bit set, DSI master ignores HSA area in
 * Video mode. In command mode, this bit is ignored.
 *
 * Values:
 * - 0 - Enables
 * - 1 - Disables
 */
/*@{*/
#define BP_MIPI_DSI_CONFIG_HSADISABLEMODE (20U) /*!< Bit position for MIPI_DSI_CONFIG_HSADISABLEMODE. */
#define BM_MIPI_DSI_CONFIG_HSADISABLEMODE (0x00100000U) /*!< Bit mask for MIPI_DSI_CONFIG_HSADISABLEMODE. */
#define BS_MIPI_DSI_CONFIG_HSADISABLEMODE (1U) /*!< Bit field size in bits for MIPI_DSI_CONFIG_HSADISABLEMODE. */

/*! @brief Read current value of the MIPI_DSI_CONFIG_HSADISABLEMODE field. */
#define BR_MIPI_DSI_CONFIG_HSADISABLEMODE(x) (HW_MIPI_DSI_CONFIG(x).B.HSADISABLEMODE)

/*! @brief Format value for bitfield MIPI_DSI_CONFIG_HSADISABLEMODE. */
#define BF_MIPI_DSI_CONFIG_HSADISABLEMODE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CONFIG_HSADISABLEMODE) & BM_MIPI_DSI_CONFIG_HSADISABLEMODE)

/*! @brief Set the HSADISABLEMODE field to a new value. */
#define BW_MIPI_DSI_CONFIG_HSADISABLEMODE(x, v) (HW_MIPI_DSI_CONFIG_WR(x, (HW_MIPI_DSI_CONFIG_RD(x) & ~BM_MIPI_DSI_CONFIG_HSADISABLEMODE) | BF_MIPI_DSI_CONFIG_HSADISABLEMODE(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CONFIG, field HBPDISABLEMODE[21] (RW)
 *
 * Specifies HBP disable mode. If this bit set, DSI master ignores HBP area in
 * Video mode. In command mode, this bit is ignored.
 *
 * Values:
 * - 0 - Enables
 * - 1 - Disables
 */
/*@{*/
#define BP_MIPI_DSI_CONFIG_HBPDISABLEMODE (21U) /*!< Bit position for MIPI_DSI_CONFIG_HBPDISABLEMODE. */
#define BM_MIPI_DSI_CONFIG_HBPDISABLEMODE (0x00200000U) /*!< Bit mask for MIPI_DSI_CONFIG_HBPDISABLEMODE. */
#define BS_MIPI_DSI_CONFIG_HBPDISABLEMODE (1U) /*!< Bit field size in bits for MIPI_DSI_CONFIG_HBPDISABLEMODE. */

/*! @brief Read current value of the MIPI_DSI_CONFIG_HBPDISABLEMODE field. */
#define BR_MIPI_DSI_CONFIG_HBPDISABLEMODE(x) (HW_MIPI_DSI_CONFIG(x).B.HBPDISABLEMODE)

/*! @brief Format value for bitfield MIPI_DSI_CONFIG_HBPDISABLEMODE. */
#define BF_MIPI_DSI_CONFIG_HBPDISABLEMODE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CONFIG_HBPDISABLEMODE) & BM_MIPI_DSI_CONFIG_HBPDISABLEMODE)

/*! @brief Set the HBPDISABLEMODE field to a new value. */
#define BW_MIPI_DSI_CONFIG_HBPDISABLEMODE(x, v) (HW_MIPI_DSI_CONFIG_WR(x, (HW_MIPI_DSI_CONFIG_RD(x) & ~BM_MIPI_DSI_CONFIG_HBPDISABLEMODE) | BF_MIPI_DSI_CONFIG_HBPDISABLEMODE(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CONFIG, field HFPDISABLEMODE[22] (RW)
 *
 * Specifies HFP disable mode. If this bit set, DSI master ignores HFP area in
 * Video mode. In command mode, this bit is ignored.
 *
 * Values:
 * - 0 - Enables
 * - 1 - Disables
 */
/*@{*/
#define BP_MIPI_DSI_CONFIG_HFPDISABLEMODE (22U) /*!< Bit position for MIPI_DSI_CONFIG_HFPDISABLEMODE. */
#define BM_MIPI_DSI_CONFIG_HFPDISABLEMODE (0x00400000U) /*!< Bit mask for MIPI_DSI_CONFIG_HFPDISABLEMODE. */
#define BS_MIPI_DSI_CONFIG_HFPDISABLEMODE (1U) /*!< Bit field size in bits for MIPI_DSI_CONFIG_HFPDISABLEMODE. */

/*! @brief Read current value of the MIPI_DSI_CONFIG_HFPDISABLEMODE field. */
#define BR_MIPI_DSI_CONFIG_HFPDISABLEMODE(x) (HW_MIPI_DSI_CONFIG(x).B.HFPDISABLEMODE)

/*! @brief Format value for bitfield MIPI_DSI_CONFIG_HFPDISABLEMODE. */
#define BF_MIPI_DSI_CONFIG_HFPDISABLEMODE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CONFIG_HFPDISABLEMODE) & BM_MIPI_DSI_CONFIG_HFPDISABLEMODE)

/*! @brief Set the HFPDISABLEMODE field to a new value. */
#define BW_MIPI_DSI_CONFIG_HFPDISABLEMODE(x, v) (HW_MIPI_DSI_CONFIG_WR(x, (HW_MIPI_DSI_CONFIG_RD(x) & ~BM_MIPI_DSI_CONFIG_HFPDISABLEMODE) | BF_MIPI_DSI_CONFIG_HFPDISABLEMODE(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CONFIG, field HSEDISABLEMODE[23] (RW)
 *
 * In Vsync pulse and Vporch area, MIPI DSI master transfers only Hsync start
 * packet to MIPI DSI slave at MIPI DSI spec 1.1r02. This bit transfers Hsync end
 * packet in Vsync pulse and Vporch area (optional). In command mode, this bit is
 * ignored.
 *
 * Values:
 * - 0 - Disables transfer
 * - 1 - Enables transfer
 */
/*@{*/
#define BP_MIPI_DSI_CONFIG_HSEDISABLEMODE (23U) /*!< Bit position for MIPI_DSI_CONFIG_HSEDISABLEMODE. */
#define BM_MIPI_DSI_CONFIG_HSEDISABLEMODE (0x00800000U) /*!< Bit mask for MIPI_DSI_CONFIG_HSEDISABLEMODE. */
#define BS_MIPI_DSI_CONFIG_HSEDISABLEMODE (1U) /*!< Bit field size in bits for MIPI_DSI_CONFIG_HSEDISABLEMODE. */

/*! @brief Read current value of the MIPI_DSI_CONFIG_HSEDISABLEMODE field. */
#define BR_MIPI_DSI_CONFIG_HSEDISABLEMODE(x) (HW_MIPI_DSI_CONFIG(x).B.HSEDISABLEMODE)

/*! @brief Format value for bitfield MIPI_DSI_CONFIG_HSEDISABLEMODE. */
#define BF_MIPI_DSI_CONFIG_HSEDISABLEMODE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CONFIG_HSEDISABLEMODE) & BM_MIPI_DSI_CONFIG_HSEDISABLEMODE)

/*! @brief Set the HSEDISABLEMODE field to a new value. */
#define BW_MIPI_DSI_CONFIG_HSEDISABLEMODE(x, v) (HW_MIPI_DSI_CONFIG_WR(x, (HW_MIPI_DSI_CONFIG_RD(x) & ~BM_MIPI_DSI_CONFIG_HSEDISABLEMODE) | BF_MIPI_DSI_CONFIG_HSEDISABLEMODE(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CONFIG, field AUTOMODE[24] (RW)
 *
 * Specifies auto vertical count mode In Video mode, the vertical line
 * transition uses line counter configured by VSA, VBP, and Vertical resolution. If this
 * bit is set to '1', the line counter does not use VSA and VBP registers. In
 * command mode, this bit is ignored.
 *
 * Values:
 * - 0 - Configuration mode
 * - 1 - Auto mode
 */
/*@{*/
#define BP_MIPI_DSI_CONFIG_AUTOMODE (24U)  /*!< Bit position for MIPI_DSI_CONFIG_AUTOMODE. */
#define BM_MIPI_DSI_CONFIG_AUTOMODE (0x01000000U) /*!< Bit mask for MIPI_DSI_CONFIG_AUTOMODE. */
#define BS_MIPI_DSI_CONFIG_AUTOMODE (1U)   /*!< Bit field size in bits for MIPI_DSI_CONFIG_AUTOMODE. */

/*! @brief Read current value of the MIPI_DSI_CONFIG_AUTOMODE field. */
#define BR_MIPI_DSI_CONFIG_AUTOMODE(x) (HW_MIPI_DSI_CONFIG(x).B.AUTOMODE)

/*! @brief Format value for bitfield MIPI_DSI_CONFIG_AUTOMODE. */
#define BF_MIPI_DSI_CONFIG_AUTOMODE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CONFIG_AUTOMODE) & BM_MIPI_DSI_CONFIG_AUTOMODE)

/*! @brief Set the AUTOMODE field to a new value. */
#define BW_MIPI_DSI_CONFIG_AUTOMODE(x, v) (HW_MIPI_DSI_CONFIG_WR(x, (HW_MIPI_DSI_CONFIG_RD(x) & ~BM_MIPI_DSI_CONFIG_AUTOMODE) | BF_MIPI_DSI_CONFIG_AUTOMODE(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CONFIG, field VIDEOMODE[25] (RW)
 *
 * Specifies display configuration
 */
/*@{*/
#define BP_MIPI_DSI_CONFIG_VIDEOMODE (25U) /*!< Bit position for MIPI_DSI_CONFIG_VIDEOMODE. */
#define BM_MIPI_DSI_CONFIG_VIDEOMODE (0x02000000U) /*!< Bit mask for MIPI_DSI_CONFIG_VIDEOMODE. */
#define BS_MIPI_DSI_CONFIG_VIDEOMODE (1U)  /*!< Bit field size in bits for MIPI_DSI_CONFIG_VIDEOMODE. */

/*! @brief Read current value of the MIPI_DSI_CONFIG_VIDEOMODE field. */
#define BR_MIPI_DSI_CONFIG_VIDEOMODE(x) (HW_MIPI_DSI_CONFIG(x).B.VIDEOMODE)

/*! @brief Format value for bitfield MIPI_DSI_CONFIG_VIDEOMODE. */
#define BF_MIPI_DSI_CONFIG_VIDEOMODE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CONFIG_VIDEOMODE) & BM_MIPI_DSI_CONFIG_VIDEOMODE)

/*! @brief Set the VIDEOMODE field to a new value. */
#define BW_MIPI_DSI_CONFIG_VIDEOMODE(x, v) (HW_MIPI_DSI_CONFIG_WR(x, (HW_MIPI_DSI_CONFIG_RD(x) & ~BM_MIPI_DSI_CONFIG_VIDEOMODE) | BF_MIPI_DSI_CONFIG_VIDEOMODE(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CONFIG, field BURSTMODE[26] (RW)
 *
 * Selects Burst mode in Video mode In Non-burst mode, RGB data area is filled
 * with RGB data and Null packets, according to input bandwidth of RGB interface.
 * In Burst mode, RGB data area is filled with RGB data only. In command mode,
 * this bit is ignored.
 *
 * Values:
 * - 0 - Non-burst mode
 * - 1 - Burst mode
 */
/*@{*/
#define BP_MIPI_DSI_CONFIG_BURSTMODE (26U) /*!< Bit position for MIPI_DSI_CONFIG_BURSTMODE. */
#define BM_MIPI_DSI_CONFIG_BURSTMODE (0x04000000U) /*!< Bit mask for MIPI_DSI_CONFIG_BURSTMODE. */
#define BS_MIPI_DSI_CONFIG_BURSTMODE (1U)  /*!< Bit field size in bits for MIPI_DSI_CONFIG_BURSTMODE. */

/*! @brief Read current value of the MIPI_DSI_CONFIG_BURSTMODE field. */
#define BR_MIPI_DSI_CONFIG_BURSTMODE(x) (HW_MIPI_DSI_CONFIG(x).B.BURSTMODE)

/*! @brief Format value for bitfield MIPI_DSI_CONFIG_BURSTMODE. */
#define BF_MIPI_DSI_CONFIG_BURSTMODE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CONFIG_BURSTMODE) & BM_MIPI_DSI_CONFIG_BURSTMODE)

/*! @brief Set the BURSTMODE field to a new value. */
#define BW_MIPI_DSI_CONFIG_BURSTMODE(x, v) (HW_MIPI_DSI_CONFIG_WR(x, (HW_MIPI_DSI_CONFIG_RD(x) & ~BM_MIPI_DSI_CONFIG_BURSTMODE) | BF_MIPI_DSI_CONFIG_BURSTMODE(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CONFIG, field SYNCINFORM[27] (RW)
 *
 * Selects Sync Pulse or Event mode in Video mode In command mode, this bit is
 * ignored.
 *
 * Values:
 * - 0 - Event mode (non burst, burst)
 * - 1 - Pulse mode (non burst only)
 */
/*@{*/
#define BP_MIPI_DSI_CONFIG_SYNCINFORM (27U) /*!< Bit position for MIPI_DSI_CONFIG_SYNCINFORM. */
#define BM_MIPI_DSI_CONFIG_SYNCINFORM (0x08000000U) /*!< Bit mask for MIPI_DSI_CONFIG_SYNCINFORM. */
#define BS_MIPI_DSI_CONFIG_SYNCINFORM (1U) /*!< Bit field size in bits for MIPI_DSI_CONFIG_SYNCINFORM. */

/*! @brief Read current value of the MIPI_DSI_CONFIG_SYNCINFORM field. */
#define BR_MIPI_DSI_CONFIG_SYNCINFORM(x) (HW_MIPI_DSI_CONFIG(x).B.SYNCINFORM)

/*! @brief Format value for bitfield MIPI_DSI_CONFIG_SYNCINFORM. */
#define BF_MIPI_DSI_CONFIG_SYNCINFORM(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CONFIG_SYNCINFORM) & BM_MIPI_DSI_CONFIG_SYNCINFORM)

/*! @brief Set the SYNCINFORM field to a new value. */
#define BW_MIPI_DSI_CONFIG_SYNCINFORM(x, v) (HW_MIPI_DSI_CONFIG_WR(x, (HW_MIPI_DSI_CONFIG_RD(x) & ~BM_MIPI_DSI_CONFIG_SYNCINFORM) | BF_MIPI_DSI_CONFIG_SYNCINFORM(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CONFIG, field EOT_R03[28] (RW)
 *
 * Disables EoT packet in HS mode.
 *
 * Values:
 * - 0 - Enables EoT packet generation for V1.01r11
 * - 1 - Disables EoT packet generation for V1.01r03
 */
/*@{*/
#define BP_MIPI_DSI_CONFIG_EOT_R03 (28U)   /*!< Bit position for MIPI_DSI_CONFIG_EOT_R03. */
#define BM_MIPI_DSI_CONFIG_EOT_R03 (0x10000000U) /*!< Bit mask for MIPI_DSI_CONFIG_EOT_R03. */
#define BS_MIPI_DSI_CONFIG_EOT_R03 (1U)    /*!< Bit field size in bits for MIPI_DSI_CONFIG_EOT_R03. */

/*! @brief Read current value of the MIPI_DSI_CONFIG_EOT_R03 field. */
#define BR_MIPI_DSI_CONFIG_EOT_R03(x) (HW_MIPI_DSI_CONFIG(x).B.EOT_R03)

/*! @brief Format value for bitfield MIPI_DSI_CONFIG_EOT_R03. */
#define BF_MIPI_DSI_CONFIG_EOT_R03(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CONFIG_EOT_R03) & BM_MIPI_DSI_CONFIG_EOT_R03)

/*! @brief Set the EOT_R03 field to a new value. */
#define BW_MIPI_DSI_CONFIG_EOT_R03(x, v) (HW_MIPI_DSI_CONFIG_WR(x, (HW_MIPI_DSI_CONFIG_RD(x) & ~BM_MIPI_DSI_CONFIG_EOT_R03) | BF_MIPI_DSI_CONFIG_EOT_R03(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CONFIG, field MFLUSH_VS[29] (RW)
 *
 * Auto flush of MD FIFO using Vsync pulse. It needs that Main display FIFO
 * should be flushed for deleting garbage data.
 *
 * Values:
 * - 0 - Disable (default)
 * - 1 - Enable
 */
/*@{*/
#define BP_MIPI_DSI_CONFIG_MFLUSH_VS (29U) /*!< Bit position for MIPI_DSI_CONFIG_MFLUSH_VS. */
#define BM_MIPI_DSI_CONFIG_MFLUSH_VS (0x20000000U) /*!< Bit mask for MIPI_DSI_CONFIG_MFLUSH_VS. */
#define BS_MIPI_DSI_CONFIG_MFLUSH_VS (1U)  /*!< Bit field size in bits for MIPI_DSI_CONFIG_MFLUSH_VS. */

/*! @brief Read current value of the MIPI_DSI_CONFIG_MFLUSH_VS field. */
#define BR_MIPI_DSI_CONFIG_MFLUSH_VS(x) (HW_MIPI_DSI_CONFIG(x).B.MFLUSH_VS)

/*! @brief Format value for bitfield MIPI_DSI_CONFIG_MFLUSH_VS. */
#define BF_MIPI_DSI_CONFIG_MFLUSH_VS(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CONFIG_MFLUSH_VS) & BM_MIPI_DSI_CONFIG_MFLUSH_VS)

/*! @brief Set the MFLUSH_VS field to a new value. */
#define BW_MIPI_DSI_CONFIG_MFLUSH_VS(x, v) (HW_MIPI_DSI_CONFIG_WR(x, (HW_MIPI_DSI_CONFIG_RD(x) & ~BM_MIPI_DSI_CONFIG_MFLUSH_VS) | BF_MIPI_DSI_CONFIG_MFLUSH_VS(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CONFIG, field CLKLANE_STOP_START[30] (RW)
 *
 * PHY clock lane On / Off for ESD. It is operated when first HBP to second HFP
 * in every VSYNC. This feature not guarantees on Command mode.
 *
 * Values:
 * - 0 - Disable (default)
 * - 1 - Enable
 */
/*@{*/
#define BP_MIPI_DSI_CONFIG_CLKLANE_STOP_START (30U) /*!< Bit position for MIPI_DSI_CONFIG_CLKLANE_STOP_START. */
#define BM_MIPI_DSI_CONFIG_CLKLANE_STOP_START (0x40000000U) /*!< Bit mask for MIPI_DSI_CONFIG_CLKLANE_STOP_START. */
#define BS_MIPI_DSI_CONFIG_CLKLANE_STOP_START (1U) /*!< Bit field size in bits for MIPI_DSI_CONFIG_CLKLANE_STOP_START. */

/*! @brief Read current value of the MIPI_DSI_CONFIG_CLKLANE_STOP_START field. */
#define BR_MIPI_DSI_CONFIG_CLKLANE_STOP_START(x) (HW_MIPI_DSI_CONFIG(x).B.CLKLANE_STOP_START)

/*! @brief Format value for bitfield MIPI_DSI_CONFIG_CLKLANE_STOP_START. */
#define BF_MIPI_DSI_CONFIG_CLKLANE_STOP_START(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CONFIG_CLKLANE_STOP_START) & BM_MIPI_DSI_CONFIG_CLKLANE_STOP_START)

/*! @brief Set the CLKLANE_STOP_START field to a new value. */
#define BW_MIPI_DSI_CONFIG_CLKLANE_STOP_START(x, v) (HW_MIPI_DSI_CONFIG_WR(x, (HW_MIPI_DSI_CONFIG_RD(x) & ~BM_MIPI_DSI_CONFIG_CLKLANE_STOP_START) | BF_MIPI_DSI_CONFIG_CLKLANE_STOP_START(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_CONFIG, field NON_CONTINUOUS_CLOCK_LANE[31] (RW)
 *
 * Non-continuous clock mode. This feature is D-PHY clock lane control DP / DN.
 * The follwoing figure shows timing diagram of clock lane. Multi Packet register
 * shows configuration of count values. Non-continuous Clock Lane Timing Diagram
 *
 * Values:
 * - 0 - Disable (default)
 * - 1 - Enable
 */
/*@{*/
#define BP_MIPI_DSI_CONFIG_NON_CONTINUOUS_CLOCK_LANE (31U) /*!< Bit position for MIPI_DSI_CONFIG_NON_CONTINUOUS_CLOCK_LANE. */
#define BM_MIPI_DSI_CONFIG_NON_CONTINUOUS_CLOCK_LANE (0x80000000U) /*!< Bit mask for MIPI_DSI_CONFIG_NON_CONTINUOUS_CLOCK_LANE. */
#define BS_MIPI_DSI_CONFIG_NON_CONTINUOUS_CLOCK_LANE (1U) /*!< Bit field size in bits for MIPI_DSI_CONFIG_NON_CONTINUOUS_CLOCK_LANE. */

/*! @brief Read current value of the MIPI_DSI_CONFIG_NON_CONTINUOUS_CLOCK_LANE field. */
#define BR_MIPI_DSI_CONFIG_NON_CONTINUOUS_CLOCK_LANE(x) (HW_MIPI_DSI_CONFIG(x).B.NON_CONTINUOUS_CLOCK_LANE)

/*! @brief Format value for bitfield MIPI_DSI_CONFIG_NON_CONTINUOUS_CLOCK_LANE. */
#define BF_MIPI_DSI_CONFIG_NON_CONTINUOUS_CLOCK_LANE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_CONFIG_NON_CONTINUOUS_CLOCK_LANE) & BM_MIPI_DSI_CONFIG_NON_CONTINUOUS_CLOCK_LANE)

/*! @brief Set the NON_CONTINUOUS_CLOCK_LANE field to a new value. */
#define BW_MIPI_DSI_CONFIG_NON_CONTINUOUS_CLOCK_LANE(x, v) (HW_MIPI_DSI_CONFIG_WR(x, (HW_MIPI_DSI_CONFIG_RD(x) & ~BM_MIPI_DSI_CONFIG_NON_CONTINUOUS_CLOCK_LANE) | BF_MIPI_DSI_CONFIG_NON_CONTINUOUS_CLOCK_LANE(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_ESCMODE - Escape Mode Register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_ESCMODE - Escape Mode Register (RW)
 *
 * Reset value: 0x03000400U
 *
 * This register configures MIPI DSI master.
 */
typedef union _hw_mipi_dsi_escmode
{
    uint32_t U;
    struct _hw_mipi_dsi_escmode_bitfields
    {
        uint32_t TXULPSCLKEXIT : 1;    /*!< [0]  */
        uint32_t TXULPSCLK : 1;        /*!< [1]  */
        uint32_t TXULPSEXIT : 1;       /*!< [2]  */
        uint32_t TXULPSDAT : 1;        /*!< [3]  */
        uint32_t TXTRIGGERRST : 1;     /*!< [4]  */
        uint32_t RESERVED0 : 1;        /*!< [5]  */
        uint32_t TXLPDT : 1;           /*!< [6]  */
        uint32_t CMDLPDT : 1;          /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t FORCEBTA : 1;         /*!< [16]  */
        uint32_t RESERVED2 : 3;        /*!< [19:17]  */
        uint32_t FORCESTOPSTATE : 1;   /*!< [20]  */
        uint32_t STOPSTATE_CNT : 11;   /*!< [31:21]  */
    } B;
} hw_mipi_dsi_escmode_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_ESCMODE register
 */
/*@{*/
#define HW_MIPI_DSI_ESCMODE_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_MIPI_DSI_ESCMODE(x)   (*(__IO hw_mipi_dsi_escmode_t *) HW_MIPI_DSI_ESCMODE_ADDR(x))
#define HW_MIPI_DSI_ESCMODE_RD(x) (HW_MIPI_DSI_ESCMODE(x).U)
#define HW_MIPI_DSI_ESCMODE_WR(x, v) (HW_MIPI_DSI_ESCMODE(x).U = (v))
#define HW_MIPI_DSI_ESCMODE_SET(x, v) (HW_MIPI_DSI_ESCMODE_WR(x, HW_MIPI_DSI_ESCMODE_RD(x) |  (v)))
#define HW_MIPI_DSI_ESCMODE_CLR(x, v) (HW_MIPI_DSI_ESCMODE_WR(x, HW_MIPI_DSI_ESCMODE_RD(x) & ~(v)))
#define HW_MIPI_DSI_ESCMODE_TOG(x, v) (HW_MIPI_DSI_ESCMODE_WR(x, HW_MIPI_DSI_ESCMODE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_ESCMODE bitfields
 */

/*!
 * @name Register MIPI_DSI_ESCMODE, field TXULPSCLKEXIT[0] (RW)
 *
 * Specifies ULPS exit request for clock lane. Manually clears after ULPS exit.
 */
/*@{*/
#define BP_MIPI_DSI_ESCMODE_TXULPSCLKEXIT (0U) /*!< Bit position for MIPI_DSI_ESCMODE_TXULPSCLKEXIT. */
#define BM_MIPI_DSI_ESCMODE_TXULPSCLKEXIT (0x00000001U) /*!< Bit mask for MIPI_DSI_ESCMODE_TXULPSCLKEXIT. */
#define BS_MIPI_DSI_ESCMODE_TXULPSCLKEXIT (1U) /*!< Bit field size in bits for MIPI_DSI_ESCMODE_TXULPSCLKEXIT. */

/*! @brief Read current value of the MIPI_DSI_ESCMODE_TXULPSCLKEXIT field. */
#define BR_MIPI_DSI_ESCMODE_TXULPSCLKEXIT(x) (HW_MIPI_DSI_ESCMODE(x).B.TXULPSCLKEXIT)

/*! @brief Format value for bitfield MIPI_DSI_ESCMODE_TXULPSCLKEXIT. */
#define BF_MIPI_DSI_ESCMODE_TXULPSCLKEXIT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_ESCMODE_TXULPSCLKEXIT) & BM_MIPI_DSI_ESCMODE_TXULPSCLKEXIT)

/*! @brief Set the TXULPSCLKEXIT field to a new value. */
#define BW_MIPI_DSI_ESCMODE_TXULPSCLKEXIT(x, v) (HW_MIPI_DSI_ESCMODE_WR(x, (HW_MIPI_DSI_ESCMODE_RD(x) & ~BM_MIPI_DSI_ESCMODE_TXULPSCLKEXIT) | BF_MIPI_DSI_ESCMODE_TXULPSCLKEXIT(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_ESCMODE, field TXULPSCLK[1] (RW)
 *
 * Specifies ULPS request for clock lane. Manually clears after ULPS exit.
 */
/*@{*/
#define BP_MIPI_DSI_ESCMODE_TXULPSCLK (1U) /*!< Bit position for MIPI_DSI_ESCMODE_TXULPSCLK. */
#define BM_MIPI_DSI_ESCMODE_TXULPSCLK (0x00000002U) /*!< Bit mask for MIPI_DSI_ESCMODE_TXULPSCLK. */
#define BS_MIPI_DSI_ESCMODE_TXULPSCLK (1U) /*!< Bit field size in bits for MIPI_DSI_ESCMODE_TXULPSCLK. */

/*! @brief Read current value of the MIPI_DSI_ESCMODE_TXULPSCLK field. */
#define BR_MIPI_DSI_ESCMODE_TXULPSCLK(x) (HW_MIPI_DSI_ESCMODE(x).B.TXULPSCLK)

/*! @brief Format value for bitfield MIPI_DSI_ESCMODE_TXULPSCLK. */
#define BF_MIPI_DSI_ESCMODE_TXULPSCLK(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_ESCMODE_TXULPSCLK) & BM_MIPI_DSI_ESCMODE_TXULPSCLK)

/*! @brief Set the TXULPSCLK field to a new value. */
#define BW_MIPI_DSI_ESCMODE_TXULPSCLK(x, v) (HW_MIPI_DSI_ESCMODE_WR(x, (HW_MIPI_DSI_ESCMODE_RD(x) & ~BM_MIPI_DSI_ESCMODE_TXULPSCLK) | BF_MIPI_DSI_ESCMODE_TXULPSCLK(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_ESCMODE, field TXULPSEXIT[2] (RW)
 *
 * Specifies ULPS exit request for data lane. Manually clears after ULPS exit.
 */
/*@{*/
#define BP_MIPI_DSI_ESCMODE_TXULPSEXIT (2U) /*!< Bit position for MIPI_DSI_ESCMODE_TXULPSEXIT. */
#define BM_MIPI_DSI_ESCMODE_TXULPSEXIT (0x00000004U) /*!< Bit mask for MIPI_DSI_ESCMODE_TXULPSEXIT. */
#define BS_MIPI_DSI_ESCMODE_TXULPSEXIT (1U) /*!< Bit field size in bits for MIPI_DSI_ESCMODE_TXULPSEXIT. */

/*! @brief Read current value of the MIPI_DSI_ESCMODE_TXULPSEXIT field. */
#define BR_MIPI_DSI_ESCMODE_TXULPSEXIT(x) (HW_MIPI_DSI_ESCMODE(x).B.TXULPSEXIT)

/*! @brief Format value for bitfield MIPI_DSI_ESCMODE_TXULPSEXIT. */
#define BF_MIPI_DSI_ESCMODE_TXULPSEXIT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_ESCMODE_TXULPSEXIT) & BM_MIPI_DSI_ESCMODE_TXULPSEXIT)

/*! @brief Set the TXULPSEXIT field to a new value. */
#define BW_MIPI_DSI_ESCMODE_TXULPSEXIT(x, v) (HW_MIPI_DSI_ESCMODE_WR(x, (HW_MIPI_DSI_ESCMODE_RD(x) & ~BM_MIPI_DSI_ESCMODE_TXULPSEXIT) | BF_MIPI_DSI_ESCMODE_TXULPSEXIT(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_ESCMODE, field TXULPSDAT[3] (RW)
 *
 * Specifies ULPS request for data lane. Manually clears after ULPS exit.
 */
/*@{*/
#define BP_MIPI_DSI_ESCMODE_TXULPSDAT (3U) /*!< Bit position for MIPI_DSI_ESCMODE_TXULPSDAT. */
#define BM_MIPI_DSI_ESCMODE_TXULPSDAT (0x00000008U) /*!< Bit mask for MIPI_DSI_ESCMODE_TXULPSDAT. */
#define BS_MIPI_DSI_ESCMODE_TXULPSDAT (1U) /*!< Bit field size in bits for MIPI_DSI_ESCMODE_TXULPSDAT. */

/*! @brief Read current value of the MIPI_DSI_ESCMODE_TXULPSDAT field. */
#define BR_MIPI_DSI_ESCMODE_TXULPSDAT(x) (HW_MIPI_DSI_ESCMODE(x).B.TXULPSDAT)

/*! @brief Format value for bitfield MIPI_DSI_ESCMODE_TXULPSDAT. */
#define BF_MIPI_DSI_ESCMODE_TXULPSDAT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_ESCMODE_TXULPSDAT) & BM_MIPI_DSI_ESCMODE_TXULPSDAT)

/*! @brief Set the TXULPSDAT field to a new value. */
#define BW_MIPI_DSI_ESCMODE_TXULPSDAT(x, v) (HW_MIPI_DSI_ESCMODE_WR(x, (HW_MIPI_DSI_ESCMODE_RD(x) & ~BM_MIPI_DSI_ESCMODE_TXULPSDAT) | BF_MIPI_DSI_ESCMODE_TXULPSDAT(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_ESCMODE, field TXTRIGGERRST[4] (RW)
 *
 * Specifies remote reset trigger function. After trigger operation, these bits
 * will be cleared automatically.
 */
/*@{*/
#define BP_MIPI_DSI_ESCMODE_TXTRIGGERRST (4U) /*!< Bit position for MIPI_DSI_ESCMODE_TXTRIGGERRST. */
#define BM_MIPI_DSI_ESCMODE_TXTRIGGERRST (0x00000010U) /*!< Bit mask for MIPI_DSI_ESCMODE_TXTRIGGERRST. */
#define BS_MIPI_DSI_ESCMODE_TXTRIGGERRST (1U) /*!< Bit field size in bits for MIPI_DSI_ESCMODE_TXTRIGGERRST. */

/*! @brief Read current value of the MIPI_DSI_ESCMODE_TXTRIGGERRST field. */
#define BR_MIPI_DSI_ESCMODE_TXTRIGGERRST(x) (HW_MIPI_DSI_ESCMODE(x).B.TXTRIGGERRST)

/*! @brief Format value for bitfield MIPI_DSI_ESCMODE_TXTRIGGERRST. */
#define BF_MIPI_DSI_ESCMODE_TXTRIGGERRST(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_ESCMODE_TXTRIGGERRST) & BM_MIPI_DSI_ESCMODE_TXTRIGGERRST)

/*! @brief Set the TXTRIGGERRST field to a new value. */
#define BW_MIPI_DSI_ESCMODE_TXTRIGGERRST(x, v) (HW_MIPI_DSI_ESCMODE_WR(x, (HW_MIPI_DSI_ESCMODE_RD(x) & ~BM_MIPI_DSI_ESCMODE_TXTRIGGERRST) | BF_MIPI_DSI_ESCMODE_TXTRIGGERRST(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_ESCMODE, field TXLPDT[6] (RW)
 *
 * Specifies data transmission in LP mode (all data transfer in LPDT)
 *
 * Values:
 * - 0 - HS Mode
 * - 1 - LP Mode
 */
/*@{*/
#define BP_MIPI_DSI_ESCMODE_TXLPDT (6U)    /*!< Bit position for MIPI_DSI_ESCMODE_TXLPDT. */
#define BM_MIPI_DSI_ESCMODE_TXLPDT (0x00000040U) /*!< Bit mask for MIPI_DSI_ESCMODE_TXLPDT. */
#define BS_MIPI_DSI_ESCMODE_TXLPDT (1U)    /*!< Bit field size in bits for MIPI_DSI_ESCMODE_TXLPDT. */

/*! @brief Read current value of the MIPI_DSI_ESCMODE_TXLPDT field. */
#define BR_MIPI_DSI_ESCMODE_TXLPDT(x) (HW_MIPI_DSI_ESCMODE(x).B.TXLPDT)

/*! @brief Format value for bitfield MIPI_DSI_ESCMODE_TXLPDT. */
#define BF_MIPI_DSI_ESCMODE_TXLPDT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_ESCMODE_TXLPDT) & BM_MIPI_DSI_ESCMODE_TXLPDT)

/*! @brief Set the TXLPDT field to a new value. */
#define BW_MIPI_DSI_ESCMODE_TXLPDT(x, v) (HW_MIPI_DSI_ESCMODE_WR(x, (HW_MIPI_DSI_ESCMODE_RD(x) & ~BM_MIPI_DSI_ESCMODE_TXLPDT) | BF_MIPI_DSI_ESCMODE_TXLPDT(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_ESCMODE, field CMDLPDT[7] (RW)
 *
 * Specifies LPDT transfers command in SFR FIFO
 *
 * Values:
 * - 0 - HS Mode
 * - 1 - LP Mode
 */
/*@{*/
#define BP_MIPI_DSI_ESCMODE_CMDLPDT (7U)   /*!< Bit position for MIPI_DSI_ESCMODE_CMDLPDT. */
#define BM_MIPI_DSI_ESCMODE_CMDLPDT (0x00000080U) /*!< Bit mask for MIPI_DSI_ESCMODE_CMDLPDT. */
#define BS_MIPI_DSI_ESCMODE_CMDLPDT (1U)   /*!< Bit field size in bits for MIPI_DSI_ESCMODE_CMDLPDT. */

/*! @brief Read current value of the MIPI_DSI_ESCMODE_CMDLPDT field. */
#define BR_MIPI_DSI_ESCMODE_CMDLPDT(x) (HW_MIPI_DSI_ESCMODE(x).B.CMDLPDT)

/*! @brief Format value for bitfield MIPI_DSI_ESCMODE_CMDLPDT. */
#define BF_MIPI_DSI_ESCMODE_CMDLPDT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_ESCMODE_CMDLPDT) & BM_MIPI_DSI_ESCMODE_CMDLPDT)

/*! @brief Set the CMDLPDT field to a new value. */
#define BW_MIPI_DSI_ESCMODE_CMDLPDT(x, v) (HW_MIPI_DSI_ESCMODE_WR(x, (HW_MIPI_DSI_ESCMODE_RD(x) & ~BM_MIPI_DSI_ESCMODE_CMDLPDT) | BF_MIPI_DSI_ESCMODE_CMDLPDT(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_ESCMODE, field FORCEBTA[16] (RW)
 *
 * Forces Bus Turn Around 1 = Sends the protocol layer request to D-PHY. MIPI
 * DSI peripheral becomes master after BTA sequence. This bit clears automatically
 * after receiving BTA acknowledge from MIPI DSI peripheral.
 */
/*@{*/
#define BP_MIPI_DSI_ESCMODE_FORCEBTA (16U) /*!< Bit position for MIPI_DSI_ESCMODE_FORCEBTA. */
#define BM_MIPI_DSI_ESCMODE_FORCEBTA (0x00010000U) /*!< Bit mask for MIPI_DSI_ESCMODE_FORCEBTA. */
#define BS_MIPI_DSI_ESCMODE_FORCEBTA (1U)  /*!< Bit field size in bits for MIPI_DSI_ESCMODE_FORCEBTA. */

/*! @brief Read current value of the MIPI_DSI_ESCMODE_FORCEBTA field. */
#define BR_MIPI_DSI_ESCMODE_FORCEBTA(x) (HW_MIPI_DSI_ESCMODE(x).B.FORCEBTA)

/*! @brief Format value for bitfield MIPI_DSI_ESCMODE_FORCEBTA. */
#define BF_MIPI_DSI_ESCMODE_FORCEBTA(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_ESCMODE_FORCEBTA) & BM_MIPI_DSI_ESCMODE_FORCEBTA)

/*! @brief Set the FORCEBTA field to a new value. */
#define BW_MIPI_DSI_ESCMODE_FORCEBTA(x, v) (HW_MIPI_DSI_ESCMODE_WR(x, (HW_MIPI_DSI_ESCMODE_RD(x) & ~BM_MIPI_DSI_ESCMODE_FORCEBTA) | BF_MIPI_DSI_ESCMODE_FORCEBTA(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_ESCMODE, field FORCESTOPSTATE[20] (RW)
 *
 * Forces Stopstate for D-PHY
 */
/*@{*/
#define BP_MIPI_DSI_ESCMODE_FORCESTOPSTATE (20U) /*!< Bit position for MIPI_DSI_ESCMODE_FORCESTOPSTATE. */
#define BM_MIPI_DSI_ESCMODE_FORCESTOPSTATE (0x00100000U) /*!< Bit mask for MIPI_DSI_ESCMODE_FORCESTOPSTATE. */
#define BS_MIPI_DSI_ESCMODE_FORCESTOPSTATE (1U) /*!< Bit field size in bits for MIPI_DSI_ESCMODE_FORCESTOPSTATE. */

/*! @brief Read current value of the MIPI_DSI_ESCMODE_FORCESTOPSTATE field. */
#define BR_MIPI_DSI_ESCMODE_FORCESTOPSTATE(x) (HW_MIPI_DSI_ESCMODE(x).B.FORCESTOPSTATE)

/*! @brief Format value for bitfield MIPI_DSI_ESCMODE_FORCESTOPSTATE. */
#define BF_MIPI_DSI_ESCMODE_FORCESTOPSTATE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_ESCMODE_FORCESTOPSTATE) & BM_MIPI_DSI_ESCMODE_FORCESTOPSTATE)

/*! @brief Set the FORCESTOPSTATE field to a new value. */
#define BW_MIPI_DSI_ESCMODE_FORCESTOPSTATE(x, v) (HW_MIPI_DSI_ESCMODE_WR(x, (HW_MIPI_DSI_ESCMODE_RD(x) & ~BM_MIPI_DSI_ESCMODE_FORCESTOPSTATE) | BF_MIPI_DSI_ESCMODE_FORCESTOPSTATE(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_ESCMODE, field STOPSTATE_CNT[31:21] (RW)
 *
 * After transmitting read packet or write "set_tear_on" command, BTA requests
 * to D-phy automatically. This counter value specifies the interval value between
 * transmitting read packet (or write "set_tear_on" command) and BTA request.
 * 11'h000 = 2 EscClk 11'h001 = 2 EscClk + 1 EscClk ~ 11'h3FF = 2 EscClk + 1023
 * EscClk
 */
/*@{*/
#define BP_MIPI_DSI_ESCMODE_STOPSTATE_CNT (21U) /*!< Bit position for MIPI_DSI_ESCMODE_STOPSTATE_CNT. */
#define BM_MIPI_DSI_ESCMODE_STOPSTATE_CNT (0xFFE00000U) /*!< Bit mask for MIPI_DSI_ESCMODE_STOPSTATE_CNT. */
#define BS_MIPI_DSI_ESCMODE_STOPSTATE_CNT (11U) /*!< Bit field size in bits for MIPI_DSI_ESCMODE_STOPSTATE_CNT. */

/*! @brief Read current value of the MIPI_DSI_ESCMODE_STOPSTATE_CNT field. */
#define BR_MIPI_DSI_ESCMODE_STOPSTATE_CNT(x) (HW_MIPI_DSI_ESCMODE(x).B.STOPSTATE_CNT)

/*! @brief Format value for bitfield MIPI_DSI_ESCMODE_STOPSTATE_CNT. */
#define BF_MIPI_DSI_ESCMODE_STOPSTATE_CNT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_ESCMODE_STOPSTATE_CNT) & BM_MIPI_DSI_ESCMODE_STOPSTATE_CNT)

/*! @brief Set the STOPSTATE_CNT field to a new value. */
#define BW_MIPI_DSI_ESCMODE_STOPSTATE_CNT(x, v) (HW_MIPI_DSI_ESCMODE_WR(x, (HW_MIPI_DSI_ESCMODE_RD(x) & ~BM_MIPI_DSI_ESCMODE_STOPSTATE_CNT) | BF_MIPI_DSI_ESCMODE_STOPSTATE_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_MDRESOL - Main Display Image Resolution Register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_MDRESOL - Main Display Image Resolution Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mipi_dsi_mdresol
{
    uint32_t U;
    struct _hw_mipi_dsi_mdresol_bitfields
    {
        uint32_t MAINHRESOL : 12;      /*!< [11:0]  */
        uint32_t RESERVED0 : 4;        /*!< [15:12]  */
        uint32_t MainVResol : 12;      /*!< [27:16]  */
        uint32_t RESERVED1 : 3;        /*!< [30:28]  */
        uint32_t MAINSTANDBY : 1;      /*!< [31]  */
    } B;
} hw_mipi_dsi_mdresol_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_MDRESOL register
 */
/*@{*/
#define HW_MIPI_DSI_MDRESOL_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_MIPI_DSI_MDRESOL(x)   (*(__IO hw_mipi_dsi_mdresol_t *) HW_MIPI_DSI_MDRESOL_ADDR(x))
#define HW_MIPI_DSI_MDRESOL_RD(x) (HW_MIPI_DSI_MDRESOL(x).U)
#define HW_MIPI_DSI_MDRESOL_WR(x, v) (HW_MIPI_DSI_MDRESOL(x).U = (v))
#define HW_MIPI_DSI_MDRESOL_SET(x, v) (HW_MIPI_DSI_MDRESOL_WR(x, HW_MIPI_DSI_MDRESOL_RD(x) |  (v)))
#define HW_MIPI_DSI_MDRESOL_CLR(x, v) (HW_MIPI_DSI_MDRESOL_WR(x, HW_MIPI_DSI_MDRESOL_RD(x) & ~(v)))
#define HW_MIPI_DSI_MDRESOL_TOG(x, v) (HW_MIPI_DSI_MDRESOL_WR(x, HW_MIPI_DSI_MDRESOL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_MDRESOL bitfields
 */

/*!
 * @name Register MIPI_DSI_MDRESOL, field MAINHRESOL[11:0] (RW)
 *
 * Specifies Horizontal resolution (1 ~ 2047)
 */
/*@{*/
#define BP_MIPI_DSI_MDRESOL_MAINHRESOL (0U) /*!< Bit position for MIPI_DSI_MDRESOL_MAINHRESOL. */
#define BM_MIPI_DSI_MDRESOL_MAINHRESOL (0x00000FFFU) /*!< Bit mask for MIPI_DSI_MDRESOL_MAINHRESOL. */
#define BS_MIPI_DSI_MDRESOL_MAINHRESOL (12U) /*!< Bit field size in bits for MIPI_DSI_MDRESOL_MAINHRESOL. */

/*! @brief Read current value of the MIPI_DSI_MDRESOL_MAINHRESOL field. */
#define BR_MIPI_DSI_MDRESOL_MAINHRESOL(x) (HW_MIPI_DSI_MDRESOL(x).B.MAINHRESOL)

/*! @brief Format value for bitfield MIPI_DSI_MDRESOL_MAINHRESOL. */
#define BF_MIPI_DSI_MDRESOL_MAINHRESOL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MDRESOL_MAINHRESOL) & BM_MIPI_DSI_MDRESOL_MAINHRESOL)

/*! @brief Set the MAINHRESOL field to a new value. */
#define BW_MIPI_DSI_MDRESOL_MAINHRESOL(x, v) (HW_MIPI_DSI_MDRESOL_WR(x, (HW_MIPI_DSI_MDRESOL_RD(x) & ~BM_MIPI_DSI_MDRESOL_MAINHRESOL) | BF_MIPI_DSI_MDRESOL_MAINHRESOL(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_MDRESOL, field MainVResol[27:16] (RW)
 *
 * Specifies Vertical resolution (1 ~ 2047)
 */
/*@{*/
#define BP_MIPI_DSI_MDRESOL_MainVResol (16U) /*!< Bit position for MIPI_DSI_MDRESOL_MainVResol. */
#define BM_MIPI_DSI_MDRESOL_MainVResol (0x0FFF0000U) /*!< Bit mask for MIPI_DSI_MDRESOL_MainVResol. */
#define BS_MIPI_DSI_MDRESOL_MainVResol (12U) /*!< Bit field size in bits for MIPI_DSI_MDRESOL_MainVResol. */

/*! @brief Read current value of the MIPI_DSI_MDRESOL_MainVResol field. */
#define BR_MIPI_DSI_MDRESOL_MainVResol(x) (HW_MIPI_DSI_MDRESOL(x).B.MainVResol)

/*! @brief Format value for bitfield MIPI_DSI_MDRESOL_MainVResol. */
#define BF_MIPI_DSI_MDRESOL_MainVResol(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MDRESOL_MainVResol) & BM_MIPI_DSI_MDRESOL_MainVResol)

/*! @brief Set the MainVResol field to a new value. */
#define BW_MIPI_DSI_MDRESOL_MainVResol(x, v) (HW_MIPI_DSI_MDRESOL_WR(x, (HW_MIPI_DSI_MDRESOL_RD(x) & ~BM_MIPI_DSI_MDRESOL_MainVResol) | BF_MIPI_DSI_MDRESOL_MainVResol(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_MDRESOL, field MAINSTANDBY[31] (RW)
 *
 * Specifies standby for receiving DISPCON output in Command mode after setting
 * all configuration. Standby should be set after configuration (resolution,
 * reqtype, pixelform, and so on) is set for command mode. In Video mode, if this bit
 * value is 0, data is not transferred.
 *
 * Values:
 * - 0 - Not ready
 * - 1 - Standby
 */
/*@{*/
#define BP_MIPI_DSI_MDRESOL_MAINSTANDBY (31U) /*!< Bit position for MIPI_DSI_MDRESOL_MAINSTANDBY. */
#define BM_MIPI_DSI_MDRESOL_MAINSTANDBY (0x80000000U) /*!< Bit mask for MIPI_DSI_MDRESOL_MAINSTANDBY. */
#define BS_MIPI_DSI_MDRESOL_MAINSTANDBY (1U) /*!< Bit field size in bits for MIPI_DSI_MDRESOL_MAINSTANDBY. */

/*! @brief Read current value of the MIPI_DSI_MDRESOL_MAINSTANDBY field. */
#define BR_MIPI_DSI_MDRESOL_MAINSTANDBY(x) (HW_MIPI_DSI_MDRESOL(x).B.MAINSTANDBY)

/*! @brief Format value for bitfield MIPI_DSI_MDRESOL_MAINSTANDBY. */
#define BF_MIPI_DSI_MDRESOL_MAINSTANDBY(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MDRESOL_MAINSTANDBY) & BM_MIPI_DSI_MDRESOL_MAINSTANDBY)

/*! @brief Set the MAINSTANDBY field to a new value. */
#define BW_MIPI_DSI_MDRESOL_MAINSTANDBY(x, v) (HW_MIPI_DSI_MDRESOL_WR(x, (HW_MIPI_DSI_MDRESOL_RD(x) & ~BM_MIPI_DSI_MDRESOL_MAINSTANDBY) | BF_MIPI_DSI_MDRESOL_MAINSTANDBY(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_MVPORCH - Main Display VPORCH Register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_MVPORCH - Main Display VPORCH Register (RW)
 *
 * Reset value: 0xF0000000U
 *
 * Transfers command packets after Stable VFP area. Display controller VFP lines
 * should be set based on sum of these values: Stable VFP, command allowing area
 * and command masked area. See the section for transferring general data in
 * Video mode.
 */
typedef union _hw_mipi_dsi_mvporch
{
    uint32_t U;
    struct _hw_mipi_dsi_mvporch_bitfields
    {
        uint32_t MAINVBP : 11;         /*!< [10:0]  */
        uint32_t RESERVED0 : 5;        /*!< [15:11]  */
        uint32_t STABLEVFP : 11;       /*!< [26:16]  */
        uint32_t RESERVED1 : 1;        /*!< [27]  */
        uint32_t CMDALLOW : 4;         /*!< [31:28]  */
    } B;
} hw_mipi_dsi_mvporch_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_MVPORCH register
 */
/*@{*/
#define HW_MIPI_DSI_MVPORCH_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_MIPI_DSI_MVPORCH(x)   (*(__IO hw_mipi_dsi_mvporch_t *) HW_MIPI_DSI_MVPORCH_ADDR(x))
#define HW_MIPI_DSI_MVPORCH_RD(x) (HW_MIPI_DSI_MVPORCH(x).U)
#define HW_MIPI_DSI_MVPORCH_WR(x, v) (HW_MIPI_DSI_MVPORCH(x).U = (v))
#define HW_MIPI_DSI_MVPORCH_SET(x, v) (HW_MIPI_DSI_MVPORCH_WR(x, HW_MIPI_DSI_MVPORCH_RD(x) |  (v)))
#define HW_MIPI_DSI_MVPORCH_CLR(x, v) (HW_MIPI_DSI_MVPORCH_WR(x, HW_MIPI_DSI_MVPORCH_RD(x) & ~(v)))
#define HW_MIPI_DSI_MVPORCH_TOG(x, v) (HW_MIPI_DSI_MVPORCH_WR(x, HW_MIPI_DSI_MVPORCH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_MVPORCH bitfields
 */

/*!
 * @name Register MIPI_DSI_MVPORCH, field MAINVBP[10:0] (RW)
 *
 * Specifies vertical back porch width for Video mode (line count). In Command
 * mode, these bits are ignored.
 */
/*@{*/
#define BP_MIPI_DSI_MVPORCH_MAINVBP (0U)   /*!< Bit position for MIPI_DSI_MVPORCH_MAINVBP. */
#define BM_MIPI_DSI_MVPORCH_MAINVBP (0x000007FFU) /*!< Bit mask for MIPI_DSI_MVPORCH_MAINVBP. */
#define BS_MIPI_DSI_MVPORCH_MAINVBP (11U)  /*!< Bit field size in bits for MIPI_DSI_MVPORCH_MAINVBP. */

/*! @brief Read current value of the MIPI_DSI_MVPORCH_MAINVBP field. */
#define BR_MIPI_DSI_MVPORCH_MAINVBP(x) (HW_MIPI_DSI_MVPORCH(x).B.MAINVBP)

/*! @brief Format value for bitfield MIPI_DSI_MVPORCH_MAINVBP. */
#define BF_MIPI_DSI_MVPORCH_MAINVBP(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MVPORCH_MAINVBP) & BM_MIPI_DSI_MVPORCH_MAINVBP)

/*! @brief Set the MAINVBP field to a new value. */
#define BW_MIPI_DSI_MVPORCH_MAINVBP(x, v) (HW_MIPI_DSI_MVPORCH_WR(x, (HW_MIPI_DSI_MVPORCH_RD(x) & ~BM_MIPI_DSI_MVPORCH_MAINVBP) | BF_MIPI_DSI_MVPORCH_MAINVBP(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_MVPORCH, field STABLEVFP[26:16] (RW)
 *
 * Specifies the number of horizontal lines, where command packet transmission
 * is not allowed after end of active region. For more information, see .. In
 * Command mode, these bits are ignored.
 */
/*@{*/
#define BP_MIPI_DSI_MVPORCH_STABLEVFP (16U) /*!< Bit position for MIPI_DSI_MVPORCH_STABLEVFP. */
#define BM_MIPI_DSI_MVPORCH_STABLEVFP (0x07FF0000U) /*!< Bit mask for MIPI_DSI_MVPORCH_STABLEVFP. */
#define BS_MIPI_DSI_MVPORCH_STABLEVFP (11U) /*!< Bit field size in bits for MIPI_DSI_MVPORCH_STABLEVFP. */

/*! @brief Read current value of the MIPI_DSI_MVPORCH_STABLEVFP field. */
#define BR_MIPI_DSI_MVPORCH_STABLEVFP(x) (HW_MIPI_DSI_MVPORCH(x).B.STABLEVFP)

/*! @brief Format value for bitfield MIPI_DSI_MVPORCH_STABLEVFP. */
#define BF_MIPI_DSI_MVPORCH_STABLEVFP(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MVPORCH_STABLEVFP) & BM_MIPI_DSI_MVPORCH_STABLEVFP)

/*! @brief Set the STABLEVFP field to a new value. */
#define BW_MIPI_DSI_MVPORCH_STABLEVFP(x, v) (HW_MIPI_DSI_MVPORCH_WR(x, (HW_MIPI_DSI_MVPORCH_RD(x) & ~BM_MIPI_DSI_MVPORCH_STABLEVFP) | BF_MIPI_DSI_MVPORCH_STABLEVFP(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_MVPORCH, field CMDALLOW[31:28] (RW)
 *
 * Specifies the number of horizontal lines, where command packet transmission
 * is allowed after Stable VFP period. For more information, see .
 */
/*@{*/
#define BP_MIPI_DSI_MVPORCH_CMDALLOW (28U) /*!< Bit position for MIPI_DSI_MVPORCH_CMDALLOW. */
#define BM_MIPI_DSI_MVPORCH_CMDALLOW (0xF0000000U) /*!< Bit mask for MIPI_DSI_MVPORCH_CMDALLOW. */
#define BS_MIPI_DSI_MVPORCH_CMDALLOW (4U)  /*!< Bit field size in bits for MIPI_DSI_MVPORCH_CMDALLOW. */

/*! @brief Read current value of the MIPI_DSI_MVPORCH_CMDALLOW field. */
#define BR_MIPI_DSI_MVPORCH_CMDALLOW(x) (HW_MIPI_DSI_MVPORCH(x).B.CMDALLOW)

/*! @brief Format value for bitfield MIPI_DSI_MVPORCH_CMDALLOW. */
#define BF_MIPI_DSI_MVPORCH_CMDALLOW(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MVPORCH_CMDALLOW) & BM_MIPI_DSI_MVPORCH_CMDALLOW)

/*! @brief Set the CMDALLOW field to a new value. */
#define BW_MIPI_DSI_MVPORCH_CMDALLOW(x, v) (HW_MIPI_DSI_MVPORCH_WR(x, (HW_MIPI_DSI_MVPORCH_RD(x) & ~BM_MIPI_DSI_MVPORCH_CMDALLOW) | BF_MIPI_DSI_MVPORCH_CMDALLOW(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_MHPORCH -
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_MHPORCH -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mipi_dsi_mhporch
{
    uint32_t U;
    struct _hw_mipi_dsi_mhporch_bitfields
    {
        uint32_t MAINHBP : 16;         /*!< [15:0]  */
        uint32_t MAINHFP : 16;         /*!< [31:16]  */
    } B;
} hw_mipi_dsi_mhporch_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_MHPORCH register
 */
/*@{*/
#define HW_MIPI_DSI_MHPORCH_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_MIPI_DSI_MHPORCH(x)   (*(__IO hw_mipi_dsi_mhporch_t *) HW_MIPI_DSI_MHPORCH_ADDR(x))
#define HW_MIPI_DSI_MHPORCH_RD(x) (HW_MIPI_DSI_MHPORCH(x).U)
#define HW_MIPI_DSI_MHPORCH_WR(x, v) (HW_MIPI_DSI_MHPORCH(x).U = (v))
#define HW_MIPI_DSI_MHPORCH_SET(x, v) (HW_MIPI_DSI_MHPORCH_WR(x, HW_MIPI_DSI_MHPORCH_RD(x) |  (v)))
#define HW_MIPI_DSI_MHPORCH_CLR(x, v) (HW_MIPI_DSI_MHPORCH_WR(x, HW_MIPI_DSI_MHPORCH_RD(x) & ~(v)))
#define HW_MIPI_DSI_MHPORCH_TOG(x, v) (HW_MIPI_DSI_MHPORCH_WR(x, HW_MIPI_DSI_MHPORCH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_MHPORCH bitfields
 */

/*!
 * @name Register MIPI_DSI_MHPORCH, field MAINHBP[15:0] (RW)
 *
 * Specifies the horizontal back porch width for Video mode. HBP is specified
 * using blank packet. These bits specify the word counts for blank packet in HBP.
 * In Command mode, these bits are ignored.
 */
/*@{*/
#define BP_MIPI_DSI_MHPORCH_MAINHBP (0U)   /*!< Bit position for MIPI_DSI_MHPORCH_MAINHBP. */
#define BM_MIPI_DSI_MHPORCH_MAINHBP (0x0000FFFFU) /*!< Bit mask for MIPI_DSI_MHPORCH_MAINHBP. */
#define BS_MIPI_DSI_MHPORCH_MAINHBP (16U)  /*!< Bit field size in bits for MIPI_DSI_MHPORCH_MAINHBP. */

/*! @brief Read current value of the MIPI_DSI_MHPORCH_MAINHBP field. */
#define BR_MIPI_DSI_MHPORCH_MAINHBP(x) (HW_MIPI_DSI_MHPORCH(x).B.MAINHBP)

/*! @brief Format value for bitfield MIPI_DSI_MHPORCH_MAINHBP. */
#define BF_MIPI_DSI_MHPORCH_MAINHBP(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MHPORCH_MAINHBP) & BM_MIPI_DSI_MHPORCH_MAINHBP)

/*! @brief Set the MAINHBP field to a new value. */
#define BW_MIPI_DSI_MHPORCH_MAINHBP(x, v) (HW_MIPI_DSI_MHPORCH_WR(x, (HW_MIPI_DSI_MHPORCH_RD(x) & ~BM_MIPI_DSI_MHPORCH_MAINHBP) | BF_MIPI_DSI_MHPORCH_MAINHBP(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_MHPORCH, field MAINHFP[31:16] (RW)
 *
 * Specifies the horizontal front porch width for Video mode. HFP is specified
 * using blank packet. These bits specify the word counts for blank packet in HFP.
 * In Command mode, these bits are ignored.
 */
/*@{*/
#define BP_MIPI_DSI_MHPORCH_MAINHFP (16U)  /*!< Bit position for MIPI_DSI_MHPORCH_MAINHFP. */
#define BM_MIPI_DSI_MHPORCH_MAINHFP (0xFFFF0000U) /*!< Bit mask for MIPI_DSI_MHPORCH_MAINHFP. */
#define BS_MIPI_DSI_MHPORCH_MAINHFP (16U)  /*!< Bit field size in bits for MIPI_DSI_MHPORCH_MAINHFP. */

/*! @brief Read current value of the MIPI_DSI_MHPORCH_MAINHFP field. */
#define BR_MIPI_DSI_MHPORCH_MAINHFP(x) (HW_MIPI_DSI_MHPORCH(x).B.MAINHFP)

/*! @brief Format value for bitfield MIPI_DSI_MHPORCH_MAINHFP. */
#define BF_MIPI_DSI_MHPORCH_MAINHFP(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MHPORCH_MAINHFP) & BM_MIPI_DSI_MHPORCH_MAINHFP)

/*! @brief Set the MAINHFP field to a new value. */
#define BW_MIPI_DSI_MHPORCH_MAINHFP(x, v) (HW_MIPI_DSI_MHPORCH_WR(x, (HW_MIPI_DSI_MHPORCH_RD(x) & ~BM_MIPI_DSI_MHPORCH_MAINHFP) | BF_MIPI_DSI_MHPORCH_MAINHFP(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_MSYNC -
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_MSYNC -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_mipi_dsi_msync
{
    uint32_t U;
    struct _hw_mipi_dsi_msync_bitfields
    {
        uint32_t MAINHSA : 16;         /*!< [15:0]  */
        uint32_t RESERVED0 : 6;        /*!< [21:16]  */
        uint32_t MAINVSA : 10;         /*!< [31:22]  */
    } B;
} hw_mipi_dsi_msync_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_MSYNC register
 */
/*@{*/
#define HW_MIPI_DSI_MSYNC_ADDR(x) ((uintptr_t)(x) + 0x2CU)

#define HW_MIPI_DSI_MSYNC(x)     (*(__IO hw_mipi_dsi_msync_t *) HW_MIPI_DSI_MSYNC_ADDR(x))
#define HW_MIPI_DSI_MSYNC_RD(x)  (HW_MIPI_DSI_MSYNC(x).U)
#define HW_MIPI_DSI_MSYNC_WR(x, v) (HW_MIPI_DSI_MSYNC(x).U = (v))
#define HW_MIPI_DSI_MSYNC_SET(x, v) (HW_MIPI_DSI_MSYNC_WR(x, HW_MIPI_DSI_MSYNC_RD(x) |  (v)))
#define HW_MIPI_DSI_MSYNC_CLR(x, v) (HW_MIPI_DSI_MSYNC_WR(x, HW_MIPI_DSI_MSYNC_RD(x) & ~(v)))
#define HW_MIPI_DSI_MSYNC_TOG(x, v) (HW_MIPI_DSI_MSYNC_WR(x, HW_MIPI_DSI_MSYNC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_MSYNC bitfields
 */

/*!
 * @name Register MIPI_DSI_MSYNC, field MAINHSA[15:0] (RW)
 *
 * Specifies the horizontal sync pulse width for Video mode. HSA is specified
 * using blank packet. These bits specify word counts for blank packet in HSA. In
 * command mode, these bits are ignored.
 */
/*@{*/
#define BP_MIPI_DSI_MSYNC_MAINHSA (0U)     /*!< Bit position for MIPI_DSI_MSYNC_MAINHSA. */
#define BM_MIPI_DSI_MSYNC_MAINHSA (0x0000FFFFU) /*!< Bit mask for MIPI_DSI_MSYNC_MAINHSA. */
#define BS_MIPI_DSI_MSYNC_MAINHSA (16U)    /*!< Bit field size in bits for MIPI_DSI_MSYNC_MAINHSA. */

/*! @brief Read current value of the MIPI_DSI_MSYNC_MAINHSA field. */
#define BR_MIPI_DSI_MSYNC_MAINHSA(x) (HW_MIPI_DSI_MSYNC(x).B.MAINHSA)

/*! @brief Format value for bitfield MIPI_DSI_MSYNC_MAINHSA. */
#define BF_MIPI_DSI_MSYNC_MAINHSA(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MSYNC_MAINHSA) & BM_MIPI_DSI_MSYNC_MAINHSA)

/*! @brief Set the MAINHSA field to a new value. */
#define BW_MIPI_DSI_MSYNC_MAINHSA(x, v) (HW_MIPI_DSI_MSYNC_WR(x, (HW_MIPI_DSI_MSYNC_RD(x) & ~BM_MIPI_DSI_MSYNC_MAINHSA) | BF_MIPI_DSI_MSYNC_MAINHSA(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_MSYNC, field MAINVSA[31:22] (RW)
 *
 * Specifies the vertical sync pulse width for Video mode (Line count). In
 * command mode, these bits are ignored.
 */
/*@{*/
#define BP_MIPI_DSI_MSYNC_MAINVSA (22U)    /*!< Bit position for MIPI_DSI_MSYNC_MAINVSA. */
#define BM_MIPI_DSI_MSYNC_MAINVSA (0xFFC00000U) /*!< Bit mask for MIPI_DSI_MSYNC_MAINVSA. */
#define BS_MIPI_DSI_MSYNC_MAINVSA (10U)    /*!< Bit field size in bits for MIPI_DSI_MSYNC_MAINVSA. */

/*! @brief Read current value of the MIPI_DSI_MSYNC_MAINVSA field. */
#define BR_MIPI_DSI_MSYNC_MAINVSA(x) (HW_MIPI_DSI_MSYNC(x).B.MAINVSA)

/*! @brief Format value for bitfield MIPI_DSI_MSYNC_MAINVSA. */
#define BF_MIPI_DSI_MSYNC_MAINVSA(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MSYNC_MAINVSA) & BM_MIPI_DSI_MSYNC_MAINVSA)

/*! @brief Set the MAINVSA field to a new value. */
#define BW_MIPI_DSI_MSYNC_MAINVSA(x, v) (HW_MIPI_DSI_MSYNC_WR(x, (HW_MIPI_DSI_MSYNC_RD(x) & ~BM_MIPI_DSI_MSYNC_MAINVSA) | BF_MIPI_DSI_MSYNC_MAINVSA(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_SDRESOL - Sub Display Image Resolution Register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_SDRESOL - Sub Display Image Resolution Register (RW)
 *
 * Reset value: 0x03000400U
 */
typedef union _hw_mipi_dsi_sdresol
{
    uint32_t U;
    struct _hw_mipi_dsi_sdresol_bitfields
    {
        uint32_t SUBHRESOL : 11;       /*!< [10:0]  */
        uint32_t RESERVED0 : 5;        /*!< [15:11]  */
        uint32_t SUBVRESOL : 11;       /*!< [26:16]  */
        uint32_t RESERVED1 : 4;        /*!< [30:27]  */
        uint32_t SUBSTANDBY : 1;       /*!< [31]  */
    } B;
} hw_mipi_dsi_sdresol_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_SDRESOL register
 */
/*@{*/
#define HW_MIPI_DSI_SDRESOL_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_MIPI_DSI_SDRESOL(x)   (*(__IO hw_mipi_dsi_sdresol_t *) HW_MIPI_DSI_SDRESOL_ADDR(x))
#define HW_MIPI_DSI_SDRESOL_RD(x) (HW_MIPI_DSI_SDRESOL(x).U)
#define HW_MIPI_DSI_SDRESOL_WR(x, v) (HW_MIPI_DSI_SDRESOL(x).U = (v))
#define HW_MIPI_DSI_SDRESOL_SET(x, v) (HW_MIPI_DSI_SDRESOL_WR(x, HW_MIPI_DSI_SDRESOL_RD(x) |  (v)))
#define HW_MIPI_DSI_SDRESOL_CLR(x, v) (HW_MIPI_DSI_SDRESOL_WR(x, HW_MIPI_DSI_SDRESOL_RD(x) & ~(v)))
#define HW_MIPI_DSI_SDRESOL_TOG(x, v) (HW_MIPI_DSI_SDRESOL_WR(x, HW_MIPI_DSI_SDRESOL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_SDRESOL bitfields
 */

/*!
 * @name Register MIPI_DSI_SDRESOL, field SUBHRESOL[10:0] (RW)
 *
 * Specifies the Horizontal resolution (1 ~ 1024)
 */
/*@{*/
#define BP_MIPI_DSI_SDRESOL_SUBHRESOL (0U) /*!< Bit position for MIPI_DSI_SDRESOL_SUBHRESOL. */
#define BM_MIPI_DSI_SDRESOL_SUBHRESOL (0x000007FFU) /*!< Bit mask for MIPI_DSI_SDRESOL_SUBHRESOL. */
#define BS_MIPI_DSI_SDRESOL_SUBHRESOL (11U) /*!< Bit field size in bits for MIPI_DSI_SDRESOL_SUBHRESOL. */

/*! @brief Read current value of the MIPI_DSI_SDRESOL_SUBHRESOL field. */
#define BR_MIPI_DSI_SDRESOL_SUBHRESOL(x) (HW_MIPI_DSI_SDRESOL(x).B.SUBHRESOL)

/*! @brief Format value for bitfield MIPI_DSI_SDRESOL_SUBHRESOL. */
#define BF_MIPI_DSI_SDRESOL_SUBHRESOL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_SDRESOL_SUBHRESOL) & BM_MIPI_DSI_SDRESOL_SUBHRESOL)

/*! @brief Set the SUBHRESOL field to a new value. */
#define BW_MIPI_DSI_SDRESOL_SUBHRESOL(x, v) (HW_MIPI_DSI_SDRESOL_WR(x, (HW_MIPI_DSI_SDRESOL_RD(x) & ~BM_MIPI_DSI_SDRESOL_SUBHRESOL) | BF_MIPI_DSI_SDRESOL_SUBHRESOL(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_SDRESOL, field SUBVRESOL[26:16] (RW)
 *
 * Specifies the Vertical resolution (1 ~ 1024)
 */
/*@{*/
#define BP_MIPI_DSI_SDRESOL_SUBVRESOL (16U) /*!< Bit position for MIPI_DSI_SDRESOL_SUBVRESOL. */
#define BM_MIPI_DSI_SDRESOL_SUBVRESOL (0x07FF0000U) /*!< Bit mask for MIPI_DSI_SDRESOL_SUBVRESOL. */
#define BS_MIPI_DSI_SDRESOL_SUBVRESOL (11U) /*!< Bit field size in bits for MIPI_DSI_SDRESOL_SUBVRESOL. */

/*! @brief Read current value of the MIPI_DSI_SDRESOL_SUBVRESOL field. */
#define BR_MIPI_DSI_SDRESOL_SUBVRESOL(x) (HW_MIPI_DSI_SDRESOL(x).B.SUBVRESOL)

/*! @brief Format value for bitfield MIPI_DSI_SDRESOL_SUBVRESOL. */
#define BF_MIPI_DSI_SDRESOL_SUBVRESOL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_SDRESOL_SUBVRESOL) & BM_MIPI_DSI_SDRESOL_SUBVRESOL)

/*! @brief Set the SUBVRESOL field to a new value. */
#define BW_MIPI_DSI_SDRESOL_SUBVRESOL(x, v) (HW_MIPI_DSI_SDRESOL_WR(x, (HW_MIPI_DSI_SDRESOL_RD(x) & ~BM_MIPI_DSI_SDRESOL_SUBVRESOL) | BF_MIPI_DSI_SDRESOL_SUBVRESOL(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_SDRESOL, field SUBSTANDBY[31] (RW)
 *
 * Specifies standby for receiving DISPCON output in Command mode after setting
 * all configuration. Standby should be set after configuration (resolution,
 * reqtype, pixelform, and so on) is set for command mode. In Video mode, this bit is
 * ignored.
 *
 * Values:
 * - 0 - Not ready
 * - 1 - Standby
 */
/*@{*/
#define BP_MIPI_DSI_SDRESOL_SUBSTANDBY (31U) /*!< Bit position for MIPI_DSI_SDRESOL_SUBSTANDBY. */
#define BM_MIPI_DSI_SDRESOL_SUBSTANDBY (0x80000000U) /*!< Bit mask for MIPI_DSI_SDRESOL_SUBSTANDBY. */
#define BS_MIPI_DSI_SDRESOL_SUBSTANDBY (1U) /*!< Bit field size in bits for MIPI_DSI_SDRESOL_SUBSTANDBY. */

/*! @brief Read current value of the MIPI_DSI_SDRESOL_SUBSTANDBY field. */
#define BR_MIPI_DSI_SDRESOL_SUBSTANDBY(x) (HW_MIPI_DSI_SDRESOL(x).B.SUBSTANDBY)

/*! @brief Format value for bitfield MIPI_DSI_SDRESOL_SUBSTANDBY. */
#define BF_MIPI_DSI_SDRESOL_SUBSTANDBY(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_SDRESOL_SUBSTANDBY) & BM_MIPI_DSI_SDRESOL_SUBSTANDBY)

/*! @brief Set the SUBSTANDBY field to a new value. */
#define BW_MIPI_DSI_SDRESOL_SUBSTANDBY(x, v) (HW_MIPI_DSI_SDRESOL_WR(x, (HW_MIPI_DSI_SDRESOL_RD(x) & ~BM_MIPI_DSI_SDRESOL_SUBSTANDBY) | BF_MIPI_DSI_SDRESOL_SUBSTANDBY(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_INTSRC - Interrupt Source Register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_INTSRC - Interrupt Source Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register identifies interrupt sources. Internal block error, data
 * transmit interrupt, inter-layer (D_PHY) error, etc. The bits are set even if they
 * are masked off by DSIM_INTMSK_REG. Write '1' to clear the Interrupt.
 */
typedef union _hw_mipi_dsi_intsrc
{
    uint32_t U;
    struct _hw_mipi_dsi_intsrc_bitfields
    {
        uint32_t ERRCONTENTLP1 : 1;    /*!< [0]  */
        uint32_t ERRCONTENTLP0 : 1;    /*!< [1]  */
        uint32_t ERRCONTROL0 : 1;      /*!< [2]  */
        uint32_t ERRCONTROL1 : 1;      /*!< [3]  */
        uint32_t RESERVED0 : 2;        /*!< [5:4]  */
        uint32_t ERRSYNC0 : 1;         /*!< [6]  */
        uint32_t ERRSYNC1 : 1;         /*!< [7]  */
        uint32_t RESERVED1 : 2;        /*!< [9:8]  */
        uint32_t ERRESC0 : 1;          /*!< [10]  */
        uint32_t ERRESC1 : 1;          /*!< [11]  */
        uint32_t RESERVED2 : 2;        /*!< [13:12]  */
        uint32_t ERRRXCRC : 1;         /*!< [14]  */
        uint32_t ERRRXECC : 1;         /*!< [15]  */
        uint32_t RXACK : 1;            /*!< [16]  */
        uint32_t RXTE : 1;             /*!< [17]  */
        uint32_t RXDATDONE : 1;        /*!< [18]  */
        uint32_t RESERVED3 : 1;        /*!< [19]  */
        uint32_t TATOUT : 1;           /*!< [20]  */
        uint32_t LPDRTOUT : 1;         /*!< [21]  */
        uint32_t RESERVED4 : 2;        /*!< [23:22]  */
        uint32_t FRAMEDONE : 1;        /*!< [24]  */
        uint32_t BUSTURNOVER : 1;      /*!< [25]  */
        uint32_t RESERVED5 : 1;        /*!< [26]  */
        uint32_t SYNCOVERRIDE : 1;     /*!< [27]  */
        uint32_t SFRPHFIFOEMPTY : 1;   /*!< [28]  */
        uint32_t SFRPLFIFOEMPTY : 1;   /*!< [29]  */
        uint32_t SWRSTRELEASE : 1;     /*!< [30]  */
        uint32_t PLLSTABLE : 1;        /*!< [31]  */
    } B;
} hw_mipi_dsi_intsrc_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_INTSRC register
 */
/*@{*/
#define HW_MIPI_DSI_INTSRC_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_MIPI_DSI_INTSRC(x)    (*(__IO hw_mipi_dsi_intsrc_t *) HW_MIPI_DSI_INTSRC_ADDR(x))
#define HW_MIPI_DSI_INTSRC_RD(x) (HW_MIPI_DSI_INTSRC(x).U)
#define HW_MIPI_DSI_INTSRC_WR(x, v) (HW_MIPI_DSI_INTSRC(x).U = (v))
#define HW_MIPI_DSI_INTSRC_SET(x, v) (HW_MIPI_DSI_INTSRC_WR(x, HW_MIPI_DSI_INTSRC_RD(x) |  (v)))
#define HW_MIPI_DSI_INTSRC_CLR(x, v) (HW_MIPI_DSI_INTSRC_WR(x, HW_MIPI_DSI_INTSRC_RD(x) & ~(v)))
#define HW_MIPI_DSI_INTSRC_TOG(x, v) (HW_MIPI_DSI_INTSRC_WR(x, HW_MIPI_DSI_INTSRC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_INTSRC bitfields
 */

/*!
 * @name Register MIPI_DSI_INTSRC, field ERRCONTENTLP1[0] (RW)
 *
 * Specifies the LP1 Contention Error (only lane0, because BTA occurs at lane0
 * only). For more information, refer to standard D-PHY specification.
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_ERRCONTENTLP1 (0U) /*!< Bit position for MIPI_DSI_INTSRC_ERRCONTENTLP1. */
#define BM_MIPI_DSI_INTSRC_ERRCONTENTLP1 (0x00000001U) /*!< Bit mask for MIPI_DSI_INTSRC_ERRCONTENTLP1. */
#define BS_MIPI_DSI_INTSRC_ERRCONTENTLP1 (1U) /*!< Bit field size in bits for MIPI_DSI_INTSRC_ERRCONTENTLP1. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_ERRCONTENTLP1 field. */
#define BR_MIPI_DSI_INTSRC_ERRCONTENTLP1(x) (HW_MIPI_DSI_INTSRC(x).B.ERRCONTENTLP1)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_ERRCONTENTLP1. */
#define BF_MIPI_DSI_INTSRC_ERRCONTENTLP1(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_ERRCONTENTLP1) & BM_MIPI_DSI_INTSRC_ERRCONTENTLP1)

/*! @brief Set the ERRCONTENTLP1 field to a new value. */
#define BW_MIPI_DSI_INTSRC_ERRCONTENTLP1(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_ERRCONTENTLP1) | BF_MIPI_DSI_INTSRC_ERRCONTENTLP1(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field ERRCONTENTLP0[1] (RW)
 *
 * Specifies the LP0 Contention Error (only lane0, because BTA occurs at lane0
 * only). For more information, refer to standard D-PHY specification.
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_ERRCONTENTLP0 (1U) /*!< Bit position for MIPI_DSI_INTSRC_ERRCONTENTLP0. */
#define BM_MIPI_DSI_INTSRC_ERRCONTENTLP0 (0x00000002U) /*!< Bit mask for MIPI_DSI_INTSRC_ERRCONTENTLP0. */
#define BS_MIPI_DSI_INTSRC_ERRCONTENTLP0 (1U) /*!< Bit field size in bits for MIPI_DSI_INTSRC_ERRCONTENTLP0. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_ERRCONTENTLP0 field. */
#define BR_MIPI_DSI_INTSRC_ERRCONTENTLP0(x) (HW_MIPI_DSI_INTSRC(x).B.ERRCONTENTLP0)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_ERRCONTENTLP0. */
#define BF_MIPI_DSI_INTSRC_ERRCONTENTLP0(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_ERRCONTENTLP0) & BM_MIPI_DSI_INTSRC_ERRCONTENTLP0)

/*! @brief Set the ERRCONTENTLP0 field to a new value. */
#define BW_MIPI_DSI_INTSRC_ERRCONTENTLP0(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_ERRCONTENTLP0) | BF_MIPI_DSI_INTSRC_ERRCONTENTLP0(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field ERRCONTROL0[2] (RW)
 *
 * Controls Error lane0. For more information, refer to standard D-PHY
 * specification.
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_ERRCONTROL0 (2U) /*!< Bit position for MIPI_DSI_INTSRC_ERRCONTROL0. */
#define BM_MIPI_DSI_INTSRC_ERRCONTROL0 (0x00000004U) /*!< Bit mask for MIPI_DSI_INTSRC_ERRCONTROL0. */
#define BS_MIPI_DSI_INTSRC_ERRCONTROL0 (1U) /*!< Bit field size in bits for MIPI_DSI_INTSRC_ERRCONTROL0. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_ERRCONTROL0 field. */
#define BR_MIPI_DSI_INTSRC_ERRCONTROL0(x) (HW_MIPI_DSI_INTSRC(x).B.ERRCONTROL0)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_ERRCONTROL0. */
#define BF_MIPI_DSI_INTSRC_ERRCONTROL0(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_ERRCONTROL0) & BM_MIPI_DSI_INTSRC_ERRCONTROL0)

/*! @brief Set the ERRCONTROL0 field to a new value. */
#define BW_MIPI_DSI_INTSRC_ERRCONTROL0(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_ERRCONTROL0) | BF_MIPI_DSI_INTSRC_ERRCONTROL0(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field ERRCONTROL1[3] (RW)
 *
 * Controls Error lane1. For more information, refer to standard D-PHY
 * specification.
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_ERRCONTROL1 (3U) /*!< Bit position for MIPI_DSI_INTSRC_ERRCONTROL1. */
#define BM_MIPI_DSI_INTSRC_ERRCONTROL1 (0x00000008U) /*!< Bit mask for MIPI_DSI_INTSRC_ERRCONTROL1. */
#define BS_MIPI_DSI_INTSRC_ERRCONTROL1 (1U) /*!< Bit field size in bits for MIPI_DSI_INTSRC_ERRCONTROL1. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_ERRCONTROL1 field. */
#define BR_MIPI_DSI_INTSRC_ERRCONTROL1(x) (HW_MIPI_DSI_INTSRC(x).B.ERRCONTROL1)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_ERRCONTROL1. */
#define BF_MIPI_DSI_INTSRC_ERRCONTROL1(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_ERRCONTROL1) & BM_MIPI_DSI_INTSRC_ERRCONTROL1)

/*! @brief Set the ERRCONTROL1 field to a new value. */
#define BW_MIPI_DSI_INTSRC_ERRCONTROL1(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_ERRCONTROL1) | BF_MIPI_DSI_INTSRC_ERRCONTROL1(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field ERRSYNC0[6] (RW)
 *
 * Specifies the LPDT Sync Error lane0. For more information, refer to standard
 * D-PHY specification.
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_ERRSYNC0 (6U)   /*!< Bit position for MIPI_DSI_INTSRC_ERRSYNC0. */
#define BM_MIPI_DSI_INTSRC_ERRSYNC0 (0x00000040U) /*!< Bit mask for MIPI_DSI_INTSRC_ERRSYNC0. */
#define BS_MIPI_DSI_INTSRC_ERRSYNC0 (1U)   /*!< Bit field size in bits for MIPI_DSI_INTSRC_ERRSYNC0. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_ERRSYNC0 field. */
#define BR_MIPI_DSI_INTSRC_ERRSYNC0(x) (HW_MIPI_DSI_INTSRC(x).B.ERRSYNC0)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_ERRSYNC0. */
#define BF_MIPI_DSI_INTSRC_ERRSYNC0(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_ERRSYNC0) & BM_MIPI_DSI_INTSRC_ERRSYNC0)

/*! @brief Set the ERRSYNC0 field to a new value. */
#define BW_MIPI_DSI_INTSRC_ERRSYNC0(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_ERRSYNC0) | BF_MIPI_DSI_INTSRC_ERRSYNC0(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field ERRSYNC1[7] (RW)
 *
 * Specifies the LPDT Sync Error lane1. For more information, refer to standard
 * D-PHY specification.
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_ERRSYNC1 (7U)   /*!< Bit position for MIPI_DSI_INTSRC_ERRSYNC1. */
#define BM_MIPI_DSI_INTSRC_ERRSYNC1 (0x00000080U) /*!< Bit mask for MIPI_DSI_INTSRC_ERRSYNC1. */
#define BS_MIPI_DSI_INTSRC_ERRSYNC1 (1U)   /*!< Bit field size in bits for MIPI_DSI_INTSRC_ERRSYNC1. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_ERRSYNC1 field. */
#define BR_MIPI_DSI_INTSRC_ERRSYNC1(x) (HW_MIPI_DSI_INTSRC(x).B.ERRSYNC1)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_ERRSYNC1. */
#define BF_MIPI_DSI_INTSRC_ERRSYNC1(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_ERRSYNC1) & BM_MIPI_DSI_INTSRC_ERRSYNC1)

/*! @brief Set the ERRSYNC1 field to a new value. */
#define BW_MIPI_DSI_INTSRC_ERRSYNC1(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_ERRSYNC1) | BF_MIPI_DSI_INTSRC_ERRSYNC1(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field ERRESC0[10] (RW)
 *
 * Specifies the escape mode entry error lane 0. For more information, refer to
 * standard D-PHY specification.
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_ERRESC0 (10U)   /*!< Bit position for MIPI_DSI_INTSRC_ERRESC0. */
#define BM_MIPI_DSI_INTSRC_ERRESC0 (0x00000400U) /*!< Bit mask for MIPI_DSI_INTSRC_ERRESC0. */
#define BS_MIPI_DSI_INTSRC_ERRESC0 (1U)    /*!< Bit field size in bits for MIPI_DSI_INTSRC_ERRESC0. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_ERRESC0 field. */
#define BR_MIPI_DSI_INTSRC_ERRESC0(x) (HW_MIPI_DSI_INTSRC(x).B.ERRESC0)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_ERRESC0. */
#define BF_MIPI_DSI_INTSRC_ERRESC0(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_ERRESC0) & BM_MIPI_DSI_INTSRC_ERRESC0)

/*! @brief Set the ERRESC0 field to a new value. */
#define BW_MIPI_DSI_INTSRC_ERRESC0(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_ERRESC0) | BF_MIPI_DSI_INTSRC_ERRESC0(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field ERRESC1[11] (RW)
 *
 * Specifies the escape mode entry error lane 1. For more information, refer to
 * standard D-PHY specification.
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_ERRESC1 (11U)   /*!< Bit position for MIPI_DSI_INTSRC_ERRESC1. */
#define BM_MIPI_DSI_INTSRC_ERRESC1 (0x00000800U) /*!< Bit mask for MIPI_DSI_INTSRC_ERRESC1. */
#define BS_MIPI_DSI_INTSRC_ERRESC1 (1U)    /*!< Bit field size in bits for MIPI_DSI_INTSRC_ERRESC1. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_ERRESC1 field. */
#define BR_MIPI_DSI_INTSRC_ERRESC1(x) (HW_MIPI_DSI_INTSRC(x).B.ERRESC1)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_ERRESC1. */
#define BF_MIPI_DSI_INTSRC_ERRESC1(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_ERRESC1) & BM_MIPI_DSI_INTSRC_ERRESC1)

/*! @brief Set the ERRESC1 field to a new value. */
#define BW_MIPI_DSI_INTSRC_ERRESC1(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_ERRESC1) | BF_MIPI_DSI_INTSRC_ERRESC1(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field ERRRXCRC[14] (RW)
 *
 * Specifies the CRC error in LPDR
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_ERRRXCRC (14U)  /*!< Bit position for MIPI_DSI_INTSRC_ERRRXCRC. */
#define BM_MIPI_DSI_INTSRC_ERRRXCRC (0x00004000U) /*!< Bit mask for MIPI_DSI_INTSRC_ERRRXCRC. */
#define BS_MIPI_DSI_INTSRC_ERRRXCRC (1U)   /*!< Bit field size in bits for MIPI_DSI_INTSRC_ERRRXCRC. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_ERRRXCRC field. */
#define BR_MIPI_DSI_INTSRC_ERRRXCRC(x) (HW_MIPI_DSI_INTSRC(x).B.ERRRXCRC)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_ERRRXCRC. */
#define BF_MIPI_DSI_INTSRC_ERRRXCRC(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_ERRRXCRC) & BM_MIPI_DSI_INTSRC_ERRRXCRC)

/*! @brief Set the ERRRXCRC field to a new value. */
#define BW_MIPI_DSI_INTSRC_ERRRXCRC(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_ERRRXCRC) | BF_MIPI_DSI_INTSRC_ERRRXCRC(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field ERRRXECC[15] (RW)
 *
 * Specifies the ECC multi bit error in LPDR
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_ERRRXECC (15U)  /*!< Bit position for MIPI_DSI_INTSRC_ERRRXECC. */
#define BM_MIPI_DSI_INTSRC_ERRRXECC (0x00008000U) /*!< Bit mask for MIPI_DSI_INTSRC_ERRRXECC. */
#define BS_MIPI_DSI_INTSRC_ERRRXECC (1U)   /*!< Bit field size in bits for MIPI_DSI_INTSRC_ERRRXECC. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_ERRRXECC field. */
#define BR_MIPI_DSI_INTSRC_ERRRXECC(x) (HW_MIPI_DSI_INTSRC(x).B.ERRRXECC)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_ERRRXECC. */
#define BF_MIPI_DSI_INTSRC_ERRRXECC(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_ERRRXECC) & BM_MIPI_DSI_INTSRC_ERRRXECC)

/*! @brief Set the ERRRXECC field to a new value. */
#define BW_MIPI_DSI_INTSRC_ERRRXECC(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_ERRRXECC) | BF_MIPI_DSI_INTSRC_ERRRXECC(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field RXACK[16] (RW)
 *
 * Receives ACK Rx trigger
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_RXACK (16U)     /*!< Bit position for MIPI_DSI_INTSRC_RXACK. */
#define BM_MIPI_DSI_INTSRC_RXACK (0x00010000U) /*!< Bit mask for MIPI_DSI_INTSRC_RXACK. */
#define BS_MIPI_DSI_INTSRC_RXACK (1U)      /*!< Bit field size in bits for MIPI_DSI_INTSRC_RXACK. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_RXACK field. */
#define BR_MIPI_DSI_INTSRC_RXACK(x) (HW_MIPI_DSI_INTSRC(x).B.RXACK)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_RXACK. */
#define BF_MIPI_DSI_INTSRC_RXACK(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_RXACK) & BM_MIPI_DSI_INTSRC_RXACK)

/*! @brief Set the RXACK field to a new value. */
#define BW_MIPI_DSI_INTSRC_RXACK(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_RXACK) | BF_MIPI_DSI_INTSRC_RXACK(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field RXTE[17] (RW)
 *
 * Receives TE Rx trigger
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_RXTE (17U)      /*!< Bit position for MIPI_DSI_INTSRC_RXTE. */
#define BM_MIPI_DSI_INTSRC_RXTE (0x00020000U) /*!< Bit mask for MIPI_DSI_INTSRC_RXTE. */
#define BS_MIPI_DSI_INTSRC_RXTE (1U)       /*!< Bit field size in bits for MIPI_DSI_INTSRC_RXTE. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_RXTE field. */
#define BR_MIPI_DSI_INTSRC_RXTE(x) (HW_MIPI_DSI_INTSRC(x).B.RXTE)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_RXTE. */
#define BF_MIPI_DSI_INTSRC_RXTE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_RXTE) & BM_MIPI_DSI_INTSRC_RXTE)

/*! @brief Set the RXTE field to a new value. */
#define BW_MIPI_DSI_INTSRC_RXTE(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_RXTE) | BF_MIPI_DSI_INTSRC_RXTE(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field RXDATDONE[18] (RW)
 *
 * Completes receiving data
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_RXDATDONE (18U) /*!< Bit position for MIPI_DSI_INTSRC_RXDATDONE. */
#define BM_MIPI_DSI_INTSRC_RXDATDONE (0x00040000U) /*!< Bit mask for MIPI_DSI_INTSRC_RXDATDONE. */
#define BS_MIPI_DSI_INTSRC_RXDATDONE (1U)  /*!< Bit field size in bits for MIPI_DSI_INTSRC_RXDATDONE. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_RXDATDONE field. */
#define BR_MIPI_DSI_INTSRC_RXDATDONE(x) (HW_MIPI_DSI_INTSRC(x).B.RXDATDONE)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_RXDATDONE. */
#define BF_MIPI_DSI_INTSRC_RXDATDONE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_RXDATDONE) & BM_MIPI_DSI_INTSRC_RXDATDONE)

/*! @brief Set the RXDATDONE field to a new value. */
#define BW_MIPI_DSI_INTSRC_RXDATDONE(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_RXDATDONE) | BF_MIPI_DSI_INTSRC_RXDATDONE(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field TATOUT[20] (RW)
 *
 * Turns around Acknowledge Timeout. See time out register (0x10).
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_TATOUT (20U)    /*!< Bit position for MIPI_DSI_INTSRC_TATOUT. */
#define BM_MIPI_DSI_INTSRC_TATOUT (0x00100000U) /*!< Bit mask for MIPI_DSI_INTSRC_TATOUT. */
#define BS_MIPI_DSI_INTSRC_TATOUT (1U)     /*!< Bit field size in bits for MIPI_DSI_INTSRC_TATOUT. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_TATOUT field. */
#define BR_MIPI_DSI_INTSRC_TATOUT(x) (HW_MIPI_DSI_INTSRC(x).B.TATOUT)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_TATOUT. */
#define BF_MIPI_DSI_INTSRC_TATOUT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_TATOUT) & BM_MIPI_DSI_INTSRC_TATOUT)

/*! @brief Set the TATOUT field to a new value. */
#define BW_MIPI_DSI_INTSRC_TATOUT(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_TATOUT) | BF_MIPI_DSI_INTSRC_TATOUT(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field LPDRTOUT[21] (RW)
 *
 * Specifies the LP Rx timeout. See time out register (0x10).
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_LPDRTOUT (21U)  /*!< Bit position for MIPI_DSI_INTSRC_LPDRTOUT. */
#define BM_MIPI_DSI_INTSRC_LPDRTOUT (0x00200000U) /*!< Bit mask for MIPI_DSI_INTSRC_LPDRTOUT. */
#define BS_MIPI_DSI_INTSRC_LPDRTOUT (1U)   /*!< Bit field size in bits for MIPI_DSI_INTSRC_LPDRTOUT. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_LPDRTOUT field. */
#define BR_MIPI_DSI_INTSRC_LPDRTOUT(x) (HW_MIPI_DSI_INTSRC(x).B.LPDRTOUT)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_LPDRTOUT. */
#define BF_MIPI_DSI_INTSRC_LPDRTOUT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_LPDRTOUT) & BM_MIPI_DSI_INTSRC_LPDRTOUT)

/*! @brief Set the LPDRTOUT field to a new value. */
#define BW_MIPI_DSI_INTSRC_LPDRTOUT(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_LPDRTOUT) | BF_MIPI_DSI_INTSRC_LPDRTOUT(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field FRAMEDONE[24] (RW)
 *
 * Indicates when MIPI DSIM transfers the whole image frame.If Hsync is not
 * received during two line times, internal timer is timed out and this bit is
 * flagged.
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_FRAMEDONE (24U) /*!< Bit position for MIPI_DSI_INTSRC_FRAMEDONE. */
#define BM_MIPI_DSI_INTSRC_FRAMEDONE (0x01000000U) /*!< Bit mask for MIPI_DSI_INTSRC_FRAMEDONE. */
#define BS_MIPI_DSI_INTSRC_FRAMEDONE (1U)  /*!< Bit field size in bits for MIPI_DSI_INTSRC_FRAMEDONE. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_FRAMEDONE field. */
#define BR_MIPI_DSI_INTSRC_FRAMEDONE(x) (HW_MIPI_DSI_INTSRC(x).B.FRAMEDONE)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_FRAMEDONE. */
#define BF_MIPI_DSI_INTSRC_FRAMEDONE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_FRAMEDONE) & BM_MIPI_DSI_INTSRC_FRAMEDONE)

/*! @brief Set the FRAMEDONE field to a new value. */
#define BW_MIPI_DSI_INTSRC_FRAMEDONE(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_FRAMEDONE) | BF_MIPI_DSI_INTSRC_FRAMEDONE(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field BUSTURNOVER[25] (RW)
 *
 * Indicates when bus grant turns over from DSI slave to DSI master.
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_BUSTURNOVER (25U) /*!< Bit position for MIPI_DSI_INTSRC_BUSTURNOVER. */
#define BM_MIPI_DSI_INTSRC_BUSTURNOVER (0x02000000U) /*!< Bit mask for MIPI_DSI_INTSRC_BUSTURNOVER. */
#define BS_MIPI_DSI_INTSRC_BUSTURNOVER (1U) /*!< Bit field size in bits for MIPI_DSI_INTSRC_BUSTURNOVER. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_BUSTURNOVER field. */
#define BR_MIPI_DSI_INTSRC_BUSTURNOVER(x) (HW_MIPI_DSI_INTSRC(x).B.BUSTURNOVER)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_BUSTURNOVER. */
#define BF_MIPI_DSI_INTSRC_BUSTURNOVER(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_BUSTURNOVER) & BM_MIPI_DSI_INTSRC_BUSTURNOVER)

/*! @brief Set the BUSTURNOVER field to a new value. */
#define BW_MIPI_DSI_INTSRC_BUSTURNOVER(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_BUSTURNOVER) | BF_MIPI_DSI_INTSRC_BUSTURNOVER(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field SYNCOVERRIDE[27] (RW)
 *
 * Indicates that other DSI command transfer have overridden sync timing.
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_SYNCOVERRIDE (27U) /*!< Bit position for MIPI_DSI_INTSRC_SYNCOVERRIDE. */
#define BM_MIPI_DSI_INTSRC_SYNCOVERRIDE (0x08000000U) /*!< Bit mask for MIPI_DSI_INTSRC_SYNCOVERRIDE. */
#define BS_MIPI_DSI_INTSRC_SYNCOVERRIDE (1U) /*!< Bit field size in bits for MIPI_DSI_INTSRC_SYNCOVERRIDE. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_SYNCOVERRIDE field. */
#define BR_MIPI_DSI_INTSRC_SYNCOVERRIDE(x) (HW_MIPI_DSI_INTSRC(x).B.SYNCOVERRIDE)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_SYNCOVERRIDE. */
#define BF_MIPI_DSI_INTSRC_SYNCOVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_SYNCOVERRIDE) & BM_MIPI_DSI_INTSRC_SYNCOVERRIDE)

/*! @brief Set the SYNCOVERRIDE field to a new value. */
#define BW_MIPI_DSI_INTSRC_SYNCOVERRIDE(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_SYNCOVERRIDE) | BF_MIPI_DSI_INTSRC_SYNCOVERRIDE(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field SFRPHFIFOEMPTY[28] (RW)
 *
 * Specifies the SFR Packet Header FIFO emtpy
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_SFRPHFIFOEMPTY (28U) /*!< Bit position for MIPI_DSI_INTSRC_SFRPHFIFOEMPTY. */
#define BM_MIPI_DSI_INTSRC_SFRPHFIFOEMPTY (0x10000000U) /*!< Bit mask for MIPI_DSI_INTSRC_SFRPHFIFOEMPTY. */
#define BS_MIPI_DSI_INTSRC_SFRPHFIFOEMPTY (1U) /*!< Bit field size in bits for MIPI_DSI_INTSRC_SFRPHFIFOEMPTY. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_SFRPHFIFOEMPTY field. */
#define BR_MIPI_DSI_INTSRC_SFRPHFIFOEMPTY(x) (HW_MIPI_DSI_INTSRC(x).B.SFRPHFIFOEMPTY)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_SFRPHFIFOEMPTY. */
#define BF_MIPI_DSI_INTSRC_SFRPHFIFOEMPTY(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_SFRPHFIFOEMPTY) & BM_MIPI_DSI_INTSRC_SFRPHFIFOEMPTY)

/*! @brief Set the SFRPHFIFOEMPTY field to a new value. */
#define BW_MIPI_DSI_INTSRC_SFRPHFIFOEMPTY(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_SFRPHFIFOEMPTY) | BF_MIPI_DSI_INTSRC_SFRPHFIFOEMPTY(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field SFRPLFIFOEMPTY[29] (RW)
 *
 * Specifies the SFR payload FIFO empty.
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_SFRPLFIFOEMPTY (29U) /*!< Bit position for MIPI_DSI_INTSRC_SFRPLFIFOEMPTY. */
#define BM_MIPI_DSI_INTSRC_SFRPLFIFOEMPTY (0x20000000U) /*!< Bit mask for MIPI_DSI_INTSRC_SFRPLFIFOEMPTY. */
#define BS_MIPI_DSI_INTSRC_SFRPLFIFOEMPTY (1U) /*!< Bit field size in bits for MIPI_DSI_INTSRC_SFRPLFIFOEMPTY. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_SFRPLFIFOEMPTY field. */
#define BR_MIPI_DSI_INTSRC_SFRPLFIFOEMPTY(x) (HW_MIPI_DSI_INTSRC(x).B.SFRPLFIFOEMPTY)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_SFRPLFIFOEMPTY. */
#define BF_MIPI_DSI_INTSRC_SFRPLFIFOEMPTY(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_SFRPLFIFOEMPTY) & BM_MIPI_DSI_INTSRC_SFRPLFIFOEMPTY)

/*! @brief Set the SFRPLFIFOEMPTY field to a new value. */
#define BW_MIPI_DSI_INTSRC_SFRPLFIFOEMPTY(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_SFRPLFIFOEMPTY) | BF_MIPI_DSI_INTSRC_SFRPLFIFOEMPTY(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field SWRSTRELEASE[30] (RW)
 *
 * Releases the software reset.
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_SWRSTRELEASE (30U) /*!< Bit position for MIPI_DSI_INTSRC_SWRSTRELEASE. */
#define BM_MIPI_DSI_INTSRC_SWRSTRELEASE (0x40000000U) /*!< Bit mask for MIPI_DSI_INTSRC_SWRSTRELEASE. */
#define BS_MIPI_DSI_INTSRC_SWRSTRELEASE (1U) /*!< Bit field size in bits for MIPI_DSI_INTSRC_SWRSTRELEASE. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_SWRSTRELEASE field. */
#define BR_MIPI_DSI_INTSRC_SWRSTRELEASE(x) (HW_MIPI_DSI_INTSRC(x).B.SWRSTRELEASE)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_SWRSTRELEASE. */
#define BF_MIPI_DSI_INTSRC_SWRSTRELEASE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_SWRSTRELEASE) & BM_MIPI_DSI_INTSRC_SWRSTRELEASE)

/*! @brief Set the SWRSTRELEASE field to a new value. */
#define BW_MIPI_DSI_INTSRC_SWRSTRELEASE(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_SWRSTRELEASE) | BF_MIPI_DSI_INTSRC_SWRSTRELEASE(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTSRC, field PLLSTABLE[31] (RW)
 *
 * Indicates that D-phy PLL is stable.
 */
/*@{*/
#define BP_MIPI_DSI_INTSRC_PLLSTABLE (31U) /*!< Bit position for MIPI_DSI_INTSRC_PLLSTABLE. */
#define BM_MIPI_DSI_INTSRC_PLLSTABLE (0x80000000U) /*!< Bit mask for MIPI_DSI_INTSRC_PLLSTABLE. */
#define BS_MIPI_DSI_INTSRC_PLLSTABLE (1U)  /*!< Bit field size in bits for MIPI_DSI_INTSRC_PLLSTABLE. */

/*! @brief Read current value of the MIPI_DSI_INTSRC_PLLSTABLE field. */
#define BR_MIPI_DSI_INTSRC_PLLSTABLE(x) (HW_MIPI_DSI_INTSRC(x).B.PLLSTABLE)

/*! @brief Format value for bitfield MIPI_DSI_INTSRC_PLLSTABLE. */
#define BF_MIPI_DSI_INTSRC_PLLSTABLE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTSRC_PLLSTABLE) & BM_MIPI_DSI_INTSRC_PLLSTABLE)

/*! @brief Set the PLLSTABLE field to a new value. */
#define BW_MIPI_DSI_INTSRC_PLLSTABLE(x, v) (HW_MIPI_DSI_INTSRC_WR(x, (HW_MIPI_DSI_INTSRC_RD(x) & ~BM_MIPI_DSI_INTSRC_PLLSTABLE) | BF_MIPI_DSI_INTSRC_PLLSTABLE(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_INTMSK - Interrupt Mask Register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_INTMSK - Interrupt Mask Register (RW)
 *
 * Reset value: 0xBB3F7FFFU
 *
 * This register masks interrupt sources.
 */
typedef union _hw_mipi_dsi_intmsk
{
    uint32_t U;
    struct _hw_mipi_dsi_intmsk_bitfields
    {
        uint32_t MSKCONTENTLP1 : 1;    /*!< [0]  */
        uint32_t MSKCONTENTLP0 : 1;    /*!< [1]  */
        uint32_t MSKCONTROL0 : 1;      /*!< [2]  */
        uint32_t MSKCONTROL1 : 1;      /*!< [3]  */
        uint32_t RESERVED0 : 2;        /*!< [5:4]  */
        uint32_t MSKSYNC0 : 1;         /*!< [6]  */
        uint32_t MSKSYNC1 : 1;         /*!< [7]  */
        uint32_t RESERVED1 : 2;        /*!< [9:8]  */
        uint32_t MSKESC0 : 1;          /*!< [10]  */
        uint32_t MSKESC1 : 1;          /*!< [11]  */
        uint32_t RESERVED2 : 2;        /*!< [13:12]  */
        uint32_t MSKRXCRC : 1;         /*!< [14]  */
        uint32_t MSKRXECC : 1;         /*!< [15]  */
        uint32_t MSKRXACK : 1;         /*!< [16]  */
        uint32_t MSKRXTE : 1;          /*!< [17]  */
        uint32_t MSKRXDATDONE : 1;     /*!< [18]  */
        uint32_t RESERVED3 : 1;        /*!< [19]  */
        uint32_t MSKTATOUT : 1;        /*!< [20]  */
        uint32_t MSKLPDRTOUT : 1;      /*!< [21]  */
        uint32_t RESERVED4 : 2;        /*!< [23:22]  */
        uint32_t MSKFRAMEDONE : 1;     /*!< [24]  */
        uint32_t MSKBUSTURNOVER : 1;   /*!< [25]  */
        uint32_t RESERVED5 : 1;        /*!< [26]  */
        uint32_t MSKSYNCOVERRIDE : 1;  /*!< [27]  */
        uint32_t MSKSFRPHFIFOEMPTY : 1; /*!< [28]  */
        uint32_t MSKSFRPLFIFOEMPTY : 1; /*!< [29]  */
        uint32_t MSKSWRSTRELEASE : 1;  /*!< [30]  */
        uint32_t MSKPLLSTABLE : 1;     /*!< [31]  */
    } B;
} hw_mipi_dsi_intmsk_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_INTMSK register
 */
/*@{*/
#define HW_MIPI_DSI_INTMSK_ADDR(x) ((uintptr_t)(x) + 0x38U)

#define HW_MIPI_DSI_INTMSK(x)    (*(__IO hw_mipi_dsi_intmsk_t *) HW_MIPI_DSI_INTMSK_ADDR(x))
#define HW_MIPI_DSI_INTMSK_RD(x) (HW_MIPI_DSI_INTMSK(x).U)
#define HW_MIPI_DSI_INTMSK_WR(x, v) (HW_MIPI_DSI_INTMSK(x).U = (v))
#define HW_MIPI_DSI_INTMSK_SET(x, v) (HW_MIPI_DSI_INTMSK_WR(x, HW_MIPI_DSI_INTMSK_RD(x) |  (v)))
#define HW_MIPI_DSI_INTMSK_CLR(x, v) (HW_MIPI_DSI_INTMSK_WR(x, HW_MIPI_DSI_INTMSK_RD(x) & ~(v)))
#define HW_MIPI_DSI_INTMSK_TOG(x, v) (HW_MIPI_DSI_INTMSK_WR(x, HW_MIPI_DSI_INTMSK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_INTMSK bitfields
 */

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKCONTENTLP1[0] (RW)
 *
 * Specifies LP1 contention error. For more information, refer to standard D-PHY
 * specification.
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKCONTENTLP1 (0U) /*!< Bit position for MIPI_DSI_INTMSK_MSKCONTENTLP1. */
#define BM_MIPI_DSI_INTMSK_MSKCONTENTLP1 (0x00000001U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKCONTENTLP1. */
#define BS_MIPI_DSI_INTMSK_MSKCONTENTLP1 (1U) /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKCONTENTLP1. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKCONTENTLP1 field. */
#define BR_MIPI_DSI_INTMSK_MSKCONTENTLP1(x) (HW_MIPI_DSI_INTMSK(x).B.MSKCONTENTLP1)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKCONTENTLP1. */
#define BF_MIPI_DSI_INTMSK_MSKCONTENTLP1(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKCONTENTLP1) & BM_MIPI_DSI_INTMSK_MSKCONTENTLP1)

/*! @brief Set the MSKCONTENTLP1 field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKCONTENTLP1(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKCONTENTLP1) | BF_MIPI_DSI_INTMSK_MSKCONTENTLP1(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKCONTENTLP0[1] (RW)
 *
 * Specifies LP0 contention error. For more information, refer to standard D-PHY
 * specification.
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKCONTENTLP0 (1U) /*!< Bit position for MIPI_DSI_INTMSK_MSKCONTENTLP0. */
#define BM_MIPI_DSI_INTMSK_MSKCONTENTLP0 (0x00000002U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKCONTENTLP0. */
#define BS_MIPI_DSI_INTMSK_MSKCONTENTLP0 (1U) /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKCONTENTLP0. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKCONTENTLP0 field. */
#define BR_MIPI_DSI_INTMSK_MSKCONTENTLP0(x) (HW_MIPI_DSI_INTMSK(x).B.MSKCONTENTLP0)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKCONTENTLP0. */
#define BF_MIPI_DSI_INTMSK_MSKCONTENTLP0(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKCONTENTLP0) & BM_MIPI_DSI_INTMSK_MSKCONTENTLP0)

/*! @brief Set the MSKCONTENTLP0 field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKCONTENTLP0(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKCONTENTLP0) | BF_MIPI_DSI_INTMSK_MSKCONTENTLP0(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKCONTROL0[2] (RW)
 *
 * Controls error in lane0. For more information, refer to standard D-PHY
 * specification.
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKCONTROL0 (2U) /*!< Bit position for MIPI_DSI_INTMSK_MSKCONTROL0. */
#define BM_MIPI_DSI_INTMSK_MSKCONTROL0 (0x00000004U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKCONTROL0. */
#define BS_MIPI_DSI_INTMSK_MSKCONTROL0 (1U) /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKCONTROL0. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKCONTROL0 field. */
#define BR_MIPI_DSI_INTMSK_MSKCONTROL0(x) (HW_MIPI_DSI_INTMSK(x).B.MSKCONTROL0)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKCONTROL0. */
#define BF_MIPI_DSI_INTMSK_MSKCONTROL0(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKCONTROL0) & BM_MIPI_DSI_INTMSK_MSKCONTROL0)

/*! @brief Set the MSKCONTROL0 field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKCONTROL0(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKCONTROL0) | BF_MIPI_DSI_INTMSK_MSKCONTROL0(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKCONTROL1[3] (RW)
 *
 * Controls error in lane1. For more information, refer to standard D-PHY
 * specification.
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKCONTROL1 (3U) /*!< Bit position for MIPI_DSI_INTMSK_MSKCONTROL1. */
#define BM_MIPI_DSI_INTMSK_MSKCONTROL1 (0x00000008U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKCONTROL1. */
#define BS_MIPI_DSI_INTMSK_MSKCONTROL1 (1U) /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKCONTROL1. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKCONTROL1 field. */
#define BR_MIPI_DSI_INTMSK_MSKCONTROL1(x) (HW_MIPI_DSI_INTMSK(x).B.MSKCONTROL1)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKCONTROL1. */
#define BF_MIPI_DSI_INTMSK_MSKCONTROL1(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKCONTROL1) & BM_MIPI_DSI_INTMSK_MSKCONTROL1)

/*! @brief Set the MSKCONTROL1 field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKCONTROL1(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKCONTROL1) | BF_MIPI_DSI_INTMSK_MSKCONTROL1(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKSYNC0[6] (RW)
 *
 * Specifies LPDT sync error in lane0. For more information, refer to standard
 * D-PHY specification.
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKSYNC0 (6U)   /*!< Bit position for MIPI_DSI_INTMSK_MSKSYNC0. */
#define BM_MIPI_DSI_INTMSK_MSKSYNC0 (0x00000040U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKSYNC0. */
#define BS_MIPI_DSI_INTMSK_MSKSYNC0 (1U)   /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKSYNC0. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKSYNC0 field. */
#define BR_MIPI_DSI_INTMSK_MSKSYNC0(x) (HW_MIPI_DSI_INTMSK(x).B.MSKSYNC0)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKSYNC0. */
#define BF_MIPI_DSI_INTMSK_MSKSYNC0(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKSYNC0) & BM_MIPI_DSI_INTMSK_MSKSYNC0)

/*! @brief Set the MSKSYNC0 field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKSYNC0(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKSYNC0) | BF_MIPI_DSI_INTMSK_MSKSYNC0(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKSYNC1[7] (RW)
 *
 * Specifies LPDT sync error in lane1. For more information, refer to standard
 * D-PHY specification.
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKSYNC1 (7U)   /*!< Bit position for MIPI_DSI_INTMSK_MSKSYNC1. */
#define BM_MIPI_DSI_INTMSK_MSKSYNC1 (0x00000080U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKSYNC1. */
#define BS_MIPI_DSI_INTMSK_MSKSYNC1 (1U)   /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKSYNC1. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKSYNC1 field. */
#define BR_MIPI_DSI_INTMSK_MSKSYNC1(x) (HW_MIPI_DSI_INTMSK(x).B.MSKSYNC1)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKSYNC1. */
#define BF_MIPI_DSI_INTMSK_MSKSYNC1(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKSYNC1) & BM_MIPI_DSI_INTMSK_MSKSYNC1)

/*! @brief Set the MSKSYNC1 field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKSYNC1(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKSYNC1) | BF_MIPI_DSI_INTMSK_MSKSYNC1(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKESC0[10] (RW)
 *
 * Specifies escape mode entry error in lane0. For more information, refer to
 * standard D-PHY specification.
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKESC0 (10U)   /*!< Bit position for MIPI_DSI_INTMSK_MSKESC0. */
#define BM_MIPI_DSI_INTMSK_MSKESC0 (0x00000400U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKESC0. */
#define BS_MIPI_DSI_INTMSK_MSKESC0 (1U)    /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKESC0. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKESC0 field. */
#define BR_MIPI_DSI_INTMSK_MSKESC0(x) (HW_MIPI_DSI_INTMSK(x).B.MSKESC0)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKESC0. */
#define BF_MIPI_DSI_INTMSK_MSKESC0(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKESC0) & BM_MIPI_DSI_INTMSK_MSKESC0)

/*! @brief Set the MSKESC0 field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKESC0(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKESC0) | BF_MIPI_DSI_INTMSK_MSKESC0(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKESC1[11] (RW)
 *
 * Specifies escape mode entry error in lane1. For more information, refer to
 * standard D-PHY specification.
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKESC1 (11U)   /*!< Bit position for MIPI_DSI_INTMSK_MSKESC1. */
#define BM_MIPI_DSI_INTMSK_MSKESC1 (0x00000800U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKESC1. */
#define BS_MIPI_DSI_INTMSK_MSKESC1 (1U)    /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKESC1. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKESC1 field. */
#define BR_MIPI_DSI_INTMSK_MSKESC1(x) (HW_MIPI_DSI_INTMSK(x).B.MSKESC1)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKESC1. */
#define BF_MIPI_DSI_INTMSK_MSKESC1(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKESC1) & BM_MIPI_DSI_INTMSK_MSKESC1)

/*! @brief Set the MSKESC1 field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKESC1(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKESC1) | BF_MIPI_DSI_INTMSK_MSKESC1(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKRXCRC[14] (RW)
 *
 * Specifies CRC error in LPDR
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKRXCRC (14U)  /*!< Bit position for MIPI_DSI_INTMSK_MSKRXCRC. */
#define BM_MIPI_DSI_INTMSK_MSKRXCRC (0x00004000U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKRXCRC. */
#define BS_MIPI_DSI_INTMSK_MSKRXCRC (1U)   /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKRXCRC. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKRXCRC field. */
#define BR_MIPI_DSI_INTMSK_MSKRXCRC(x) (HW_MIPI_DSI_INTMSK(x).B.MSKRXCRC)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKRXCRC. */
#define BF_MIPI_DSI_INTMSK_MSKRXCRC(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKRXCRC) & BM_MIPI_DSI_INTMSK_MSKRXCRC)

/*! @brief Set the MSKRXCRC field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKRXCRC(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKRXCRC) | BF_MIPI_DSI_INTMSK_MSKRXCRC(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKRXECC[15] (RW)
 *
 * Specifies ECC multibit error in LPDR
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKRXECC (15U)  /*!< Bit position for MIPI_DSI_INTMSK_MSKRXECC. */
#define BM_MIPI_DSI_INTMSK_MSKRXECC (0x00008000U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKRXECC. */
#define BS_MIPI_DSI_INTMSK_MSKRXECC (1U)   /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKRXECC. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKRXECC field. */
#define BR_MIPI_DSI_INTMSK_MSKRXECC(x) (HW_MIPI_DSI_INTMSK(x).B.MSKRXECC)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKRXECC. */
#define BF_MIPI_DSI_INTMSK_MSKRXECC(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKRXECC) & BM_MIPI_DSI_INTMSK_MSKRXECC)

/*! @brief Set the MSKRXECC field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKRXECC(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKRXECC) | BF_MIPI_DSI_INTMSK_MSKRXECC(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKRXACK[16] (RW)
 *
 * Specifies receipt of ACK Rx trigger
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKRXACK (16U)  /*!< Bit position for MIPI_DSI_INTMSK_MSKRXACK. */
#define BM_MIPI_DSI_INTMSK_MSKRXACK (0x00010000U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKRXACK. */
#define BS_MIPI_DSI_INTMSK_MSKRXACK (1U)   /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKRXACK. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKRXACK field. */
#define BR_MIPI_DSI_INTMSK_MSKRXACK(x) (HW_MIPI_DSI_INTMSK(x).B.MSKRXACK)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKRXACK. */
#define BF_MIPI_DSI_INTMSK_MSKRXACK(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKRXACK) & BM_MIPI_DSI_INTMSK_MSKRXACK)

/*! @brief Set the MSKRXACK field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKRXACK(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKRXACK) | BF_MIPI_DSI_INTMSK_MSKRXACK(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKRXTE[17] (RW)
 *
 * Specifies receipt of TE Rx trigger
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKRXTE (17U)   /*!< Bit position for MIPI_DSI_INTMSK_MSKRXTE. */
#define BM_MIPI_DSI_INTMSK_MSKRXTE (0x00020000U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKRXTE. */
#define BS_MIPI_DSI_INTMSK_MSKRXTE (1U)    /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKRXTE. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKRXTE field. */
#define BR_MIPI_DSI_INTMSK_MSKRXTE(x) (HW_MIPI_DSI_INTMSK(x).B.MSKRXTE)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKRXTE. */
#define BF_MIPI_DSI_INTMSK_MSKRXTE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKRXTE) & BM_MIPI_DSI_INTMSK_MSKRXTE)

/*! @brief Set the MSKRXTE field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKRXTE(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKRXTE) | BF_MIPI_DSI_INTMSK_MSKRXTE(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKRXDATDONE[18] (RW)
 *
 * Specifies completion of data receiving
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKRXDATDONE (18U) /*!< Bit position for MIPI_DSI_INTMSK_MSKRXDATDONE. */
#define BM_MIPI_DSI_INTMSK_MSKRXDATDONE (0x00040000U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKRXDATDONE. */
#define BS_MIPI_DSI_INTMSK_MSKRXDATDONE (1U) /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKRXDATDONE. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKRXDATDONE field. */
#define BR_MIPI_DSI_INTMSK_MSKRXDATDONE(x) (HW_MIPI_DSI_INTMSK(x).B.MSKRXDATDONE)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKRXDATDONE. */
#define BF_MIPI_DSI_INTMSK_MSKRXDATDONE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKRXDATDONE) & BM_MIPI_DSI_INTMSK_MSKRXDATDONE)

/*! @brief Set the MSKRXDATDONE field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKRXDATDONE(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKRXDATDONE) | BF_MIPI_DSI_INTMSK_MSKRXDATDONE(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKTATOUT[20] (RW)
 *
 * Specifies turnaround acknowledge timeout. See time out register (0x10)
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKTATOUT (20U) /*!< Bit position for MIPI_DSI_INTMSK_MSKTATOUT. */
#define BM_MIPI_DSI_INTMSK_MSKTATOUT (0x00100000U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKTATOUT. */
#define BS_MIPI_DSI_INTMSK_MSKTATOUT (1U)  /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKTATOUT. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKTATOUT field. */
#define BR_MIPI_DSI_INTMSK_MSKTATOUT(x) (HW_MIPI_DSI_INTMSK(x).B.MSKTATOUT)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKTATOUT. */
#define BF_MIPI_DSI_INTMSK_MSKTATOUT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKTATOUT) & BM_MIPI_DSI_INTMSK_MSKTATOUT)

/*! @brief Set the MSKTATOUT field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKTATOUT(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKTATOUT) | BF_MIPI_DSI_INTMSK_MSKTATOUT(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKLPDRTOUT[21] (RW)
 *
 * Specifies LP Rx timeout. See time out register (0x10).
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKLPDRTOUT (21U) /*!< Bit position for MIPI_DSI_INTMSK_MSKLPDRTOUT. */
#define BM_MIPI_DSI_INTMSK_MSKLPDRTOUT (0x00200000U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKLPDRTOUT. */
#define BS_MIPI_DSI_INTMSK_MSKLPDRTOUT (1U) /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKLPDRTOUT. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKLPDRTOUT field. */
#define BR_MIPI_DSI_INTMSK_MSKLPDRTOUT(x) (HW_MIPI_DSI_INTMSK(x).B.MSKLPDRTOUT)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKLPDRTOUT. */
#define BF_MIPI_DSI_INTMSK_MSKLPDRTOUT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKLPDRTOUT) & BM_MIPI_DSI_INTMSK_MSKLPDRTOUT)

/*! @brief Set the MSKLPDRTOUT field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKLPDRTOUT(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKLPDRTOUT) | BF_MIPI_DSI_INTMSK_MSKLPDRTOUT(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKFRAMEDONE[24] (RW)
 *
 * Indicates when MIPI DSIM transfers whole image frame.
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKFRAMEDONE (24U) /*!< Bit position for MIPI_DSI_INTMSK_MSKFRAMEDONE. */
#define BM_MIPI_DSI_INTMSK_MSKFRAMEDONE (0x01000000U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKFRAMEDONE. */
#define BS_MIPI_DSI_INTMSK_MSKFRAMEDONE (1U) /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKFRAMEDONE. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKFRAMEDONE field. */
#define BR_MIPI_DSI_INTMSK_MSKFRAMEDONE(x) (HW_MIPI_DSI_INTMSK(x).B.MSKFRAMEDONE)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKFRAMEDONE. */
#define BF_MIPI_DSI_INTMSK_MSKFRAMEDONE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKFRAMEDONE) & BM_MIPI_DSI_INTMSK_MSKFRAMEDONE)

/*! @brief Set the MSKFRAMEDONE field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKFRAMEDONE(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKFRAMEDONE) | BF_MIPI_DSI_INTMSK_MSKFRAMEDONE(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKBUSTURNOVER[25] (RW)
 *
 * Indicates when bus grant turns over from DSI slave to DSI master.
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKBUSTURNOVER (25U) /*!< Bit position for MIPI_DSI_INTMSK_MSKBUSTURNOVER. */
#define BM_MIPI_DSI_INTMSK_MSKBUSTURNOVER (0x02000000U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKBUSTURNOVER. */
#define BS_MIPI_DSI_INTMSK_MSKBUSTURNOVER (1U) /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKBUSTURNOVER. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKBUSTURNOVER field. */
#define BR_MIPI_DSI_INTMSK_MSKBUSTURNOVER(x) (HW_MIPI_DSI_INTMSK(x).B.MSKBUSTURNOVER)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKBUSTURNOVER. */
#define BF_MIPI_DSI_INTMSK_MSKBUSTURNOVER(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKBUSTURNOVER) & BM_MIPI_DSI_INTMSK_MSKBUSTURNOVER)

/*! @brief Set the MSKBUSTURNOVER field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKBUSTURNOVER(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKBUSTURNOVER) | BF_MIPI_DSI_INTMSK_MSKBUSTURNOVER(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKSYNCOVERRIDE[27] (RW)
 *
 * Indicates that other DSI command transfer have overridden sync timing.
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKSYNCOVERRIDE (27U) /*!< Bit position for MIPI_DSI_INTMSK_MSKSYNCOVERRIDE. */
#define BM_MIPI_DSI_INTMSK_MSKSYNCOVERRIDE (0x08000000U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKSYNCOVERRIDE. */
#define BS_MIPI_DSI_INTMSK_MSKSYNCOVERRIDE (1U) /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKSYNCOVERRIDE. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKSYNCOVERRIDE field. */
#define BR_MIPI_DSI_INTMSK_MSKSYNCOVERRIDE(x) (HW_MIPI_DSI_INTMSK(x).B.MSKSYNCOVERRIDE)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKSYNCOVERRIDE. */
#define BF_MIPI_DSI_INTMSK_MSKSYNCOVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKSYNCOVERRIDE) & BM_MIPI_DSI_INTMSK_MSKSYNCOVERRIDE)

/*! @brief Set the MSKSYNCOVERRIDE field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKSYNCOVERRIDE(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKSYNCOVERRIDE) | BF_MIPI_DSI_INTMSK_MSKSYNCOVERRIDE(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKSFRPHFIFOEMPTY[28] (RW)
 *
 * Interrupt Mask for SFR packet header FIFO empty
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKSFRPHFIFOEMPTY (28U) /*!< Bit position for MIPI_DSI_INTMSK_MSKSFRPHFIFOEMPTY. */
#define BM_MIPI_DSI_INTMSK_MSKSFRPHFIFOEMPTY (0x10000000U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKSFRPHFIFOEMPTY. */
#define BS_MIPI_DSI_INTMSK_MSKSFRPHFIFOEMPTY (1U) /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKSFRPHFIFOEMPTY. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKSFRPHFIFOEMPTY field. */
#define BR_MIPI_DSI_INTMSK_MSKSFRPHFIFOEMPTY(x) (HW_MIPI_DSI_INTMSK(x).B.MSKSFRPHFIFOEMPTY)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKSFRPHFIFOEMPTY. */
#define BF_MIPI_DSI_INTMSK_MSKSFRPHFIFOEMPTY(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKSFRPHFIFOEMPTY) & BM_MIPI_DSI_INTMSK_MSKSFRPHFIFOEMPTY)

/*! @brief Set the MSKSFRPHFIFOEMPTY field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKSFRPHFIFOEMPTY(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKSFRPHFIFOEMPTY) | BF_MIPI_DSI_INTMSK_MSKSFRPHFIFOEMPTY(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKSFRPLFIFOEMPTY[29] (RW)
 *
 * Empties SFR payload FIFO.
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKSFRPLFIFOEMPTY (29U) /*!< Bit position for MIPI_DSI_INTMSK_MSKSFRPLFIFOEMPTY. */
#define BM_MIPI_DSI_INTMSK_MSKSFRPLFIFOEMPTY (0x20000000U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKSFRPLFIFOEMPTY. */
#define BS_MIPI_DSI_INTMSK_MSKSFRPLFIFOEMPTY (1U) /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKSFRPLFIFOEMPTY. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKSFRPLFIFOEMPTY field. */
#define BR_MIPI_DSI_INTMSK_MSKSFRPLFIFOEMPTY(x) (HW_MIPI_DSI_INTMSK(x).B.MSKSFRPLFIFOEMPTY)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKSFRPLFIFOEMPTY. */
#define BF_MIPI_DSI_INTMSK_MSKSFRPLFIFOEMPTY(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKSFRPLFIFOEMPTY) & BM_MIPI_DSI_INTMSK_MSKSFRPLFIFOEMPTY)

/*! @brief Set the MSKSFRPLFIFOEMPTY field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKSFRPLFIFOEMPTY(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKSFRPLFIFOEMPTY) | BF_MIPI_DSI_INTMSK_MSKSFRPLFIFOEMPTY(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKSWRSTRELEASE[30] (RW)
 *
 * Releases software reset.
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKSWRSTRELEASE (30U) /*!< Bit position for MIPI_DSI_INTMSK_MSKSWRSTRELEASE. */
#define BM_MIPI_DSI_INTMSK_MSKSWRSTRELEASE (0x40000000U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKSWRSTRELEASE. */
#define BS_MIPI_DSI_INTMSK_MSKSWRSTRELEASE (1U) /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKSWRSTRELEASE. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKSWRSTRELEASE field. */
#define BR_MIPI_DSI_INTMSK_MSKSWRSTRELEASE(x) (HW_MIPI_DSI_INTMSK(x).B.MSKSWRSTRELEASE)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKSWRSTRELEASE. */
#define BF_MIPI_DSI_INTMSK_MSKSWRSTRELEASE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKSWRSTRELEASE) & BM_MIPI_DSI_INTMSK_MSKSWRSTRELEASE)

/*! @brief Set the MSKSWRSTRELEASE field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKSWRSTRELEASE(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKSWRSTRELEASE) | BF_MIPI_DSI_INTMSK_MSKSWRSTRELEASE(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_INTMSK, field MSKPLLSTABLE[31] (RW)
 *
 * Indicates that D-PHY PLL is stable.
 */
/*@{*/
#define BP_MIPI_DSI_INTMSK_MSKPLLSTABLE (31U) /*!< Bit position for MIPI_DSI_INTMSK_MSKPLLSTABLE. */
#define BM_MIPI_DSI_INTMSK_MSKPLLSTABLE (0x80000000U) /*!< Bit mask for MIPI_DSI_INTMSK_MSKPLLSTABLE. */
#define BS_MIPI_DSI_INTMSK_MSKPLLSTABLE (1U) /*!< Bit field size in bits for MIPI_DSI_INTMSK_MSKPLLSTABLE. */

/*! @brief Read current value of the MIPI_DSI_INTMSK_MSKPLLSTABLE field. */
#define BR_MIPI_DSI_INTMSK_MSKPLLSTABLE(x) (HW_MIPI_DSI_INTMSK(x).B.MSKPLLSTABLE)

/*! @brief Format value for bitfield MIPI_DSI_INTMSK_MSKPLLSTABLE. */
#define BF_MIPI_DSI_INTMSK_MSKPLLSTABLE(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_INTMSK_MSKPLLSTABLE) & BM_MIPI_DSI_INTMSK_MSKPLLSTABLE)

/*! @brief Set the MSKPLLSTABLE field to a new value. */
#define BW_MIPI_DSI_INTMSK_MSKPLLSTABLE(x, v) (HW_MIPI_DSI_INTMSK_WR(x, (HW_MIPI_DSI_INTMSK_RD(x) & ~BM_MIPI_DSI_INTMSK_MSKPLLSTABLE) | BF_MIPI_DSI_INTMSK_MSKPLLSTABLE(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_PKTHDR - Packet Header FIFO Register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_PKTHDR - Packet Header FIFO Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is the FIFO for packet header to send DSI packets.
 */
typedef union _hw_mipi_dsi_pkthdr
{
    uint32_t U;
    struct _hw_mipi_dsi_pkthdr_bitfields
    {
        uint32_t PACKETHEADER : 24;    /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_mipi_dsi_pkthdr_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_PKTHDR register
 */
/*@{*/
#define HW_MIPI_DSI_PKTHDR_ADDR(x) ((uintptr_t)(x) + 0x3CU)

#define HW_MIPI_DSI_PKTHDR(x)    (*(__IO hw_mipi_dsi_pkthdr_t *) HW_MIPI_DSI_PKTHDR_ADDR(x))
#define HW_MIPI_DSI_PKTHDR_RD(x) (HW_MIPI_DSI_PKTHDR(x).U)
#define HW_MIPI_DSI_PKTHDR_WR(x, v) (HW_MIPI_DSI_PKTHDR(x).U = (v))
#define HW_MIPI_DSI_PKTHDR_SET(x, v) (HW_MIPI_DSI_PKTHDR_WR(x, HW_MIPI_DSI_PKTHDR_RD(x) |  (v)))
#define HW_MIPI_DSI_PKTHDR_CLR(x, v) (HW_MIPI_DSI_PKTHDR_WR(x, HW_MIPI_DSI_PKTHDR_RD(x) & ~(v)))
#define HW_MIPI_DSI_PKTHDR_TOG(x, v) (HW_MIPI_DSI_PKTHDR_WR(x, HW_MIPI_DSI_PKTHDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_PKTHDR bitfields
 */

/*!
 * @name Register MIPI_DSI_PKTHDR, field PACKETHEADER[23:0] (RW)
 *
 * Writes the packet header of Tx packet. [7:0] = DI [15:8] = Dat0 (Word Count
 * lower byte for long packet) [23:16] = Dat1 (Word Count upper byte for long
 * packet)
 */
/*@{*/
#define BP_MIPI_DSI_PKTHDR_PACKETHEADER (0U) /*!< Bit position for MIPI_DSI_PKTHDR_PACKETHEADER. */
#define BM_MIPI_DSI_PKTHDR_PACKETHEADER (0x00FFFFFFU) /*!< Bit mask for MIPI_DSI_PKTHDR_PACKETHEADER. */
#define BS_MIPI_DSI_PKTHDR_PACKETHEADER (24U) /*!< Bit field size in bits for MIPI_DSI_PKTHDR_PACKETHEADER. */

/*! @brief Read current value of the MIPI_DSI_PKTHDR_PACKETHEADER field. */
#define BR_MIPI_DSI_PKTHDR_PACKETHEADER(x) (HW_MIPI_DSI_PKTHDR(x).B.PACKETHEADER)

/*! @brief Format value for bitfield MIPI_DSI_PKTHDR_PACKETHEADER. */
#define BF_MIPI_DSI_PKTHDR_PACKETHEADER(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PKTHDR_PACKETHEADER) & BM_MIPI_DSI_PKTHDR_PACKETHEADER)

/*! @brief Set the PACKETHEADER field to a new value. */
#define BW_MIPI_DSI_PKTHDR_PACKETHEADER(x, v) (HW_MIPI_DSI_PKTHDR_WR(x, (HW_MIPI_DSI_PKTHDR_RD(x) & ~BM_MIPI_DSI_PKTHDR_PACKETHEADER) | BF_MIPI_DSI_PKTHDR_PACKETHEADER(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_PAYLOAD - Payload FIFO Register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_PAYLOAD - Payload FIFO Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is the FIFO for packet header to send DSI packets.
 */
typedef union _hw_mipi_dsi_payload
{
    uint32_t U;
    struct _hw_mipi_dsi_payload_bitfields
    {
        uint32_t PAYLOAD : 32;         /*!< [31:0]  */
    } B;
} hw_mipi_dsi_payload_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_PAYLOAD register
 */
/*@{*/
#define HW_MIPI_DSI_PAYLOAD_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_MIPI_DSI_PAYLOAD(x)   (*(__IO hw_mipi_dsi_payload_t *) HW_MIPI_DSI_PAYLOAD_ADDR(x))
#define HW_MIPI_DSI_PAYLOAD_RD(x) (HW_MIPI_DSI_PAYLOAD(x).U)
#define HW_MIPI_DSI_PAYLOAD_WR(x, v) (HW_MIPI_DSI_PAYLOAD(x).U = (v))
#define HW_MIPI_DSI_PAYLOAD_SET(x, v) (HW_MIPI_DSI_PAYLOAD_WR(x, HW_MIPI_DSI_PAYLOAD_RD(x) |  (v)))
#define HW_MIPI_DSI_PAYLOAD_CLR(x, v) (HW_MIPI_DSI_PAYLOAD_WR(x, HW_MIPI_DSI_PAYLOAD_RD(x) & ~(v)))
#define HW_MIPI_DSI_PAYLOAD_TOG(x, v) (HW_MIPI_DSI_PAYLOAD_WR(x, HW_MIPI_DSI_PAYLOAD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_PAYLOAD bitfields
 */

/*!
 * @name Register MIPI_DSI_PAYLOAD, field PAYLOAD[31:0] (RW)
 *
 * Writes the Payload of Tx packet
 */
/*@{*/
#define BP_MIPI_DSI_PAYLOAD_PAYLOAD (0U)   /*!< Bit position for MIPI_DSI_PAYLOAD_PAYLOAD. */
#define BM_MIPI_DSI_PAYLOAD_PAYLOAD (0xFFFFFFFFU) /*!< Bit mask for MIPI_DSI_PAYLOAD_PAYLOAD. */
#define BS_MIPI_DSI_PAYLOAD_PAYLOAD (32U)  /*!< Bit field size in bits for MIPI_DSI_PAYLOAD_PAYLOAD. */

/*! @brief Read current value of the MIPI_DSI_PAYLOAD_PAYLOAD field. */
#define BR_MIPI_DSI_PAYLOAD_PAYLOAD(x) (HW_MIPI_DSI_PAYLOAD(x).U)

/*! @brief Format value for bitfield MIPI_DSI_PAYLOAD_PAYLOAD. */
#define BF_MIPI_DSI_PAYLOAD_PAYLOAD(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PAYLOAD_PAYLOAD) & BM_MIPI_DSI_PAYLOAD_PAYLOAD)

/*! @brief Set the PAYLOAD field to a new value. */
#define BW_MIPI_DSI_PAYLOAD_PAYLOAD(x, v) (HW_MIPI_DSI_PAYLOAD_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_RXFIFO - Payload FIFO Register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_RXFIFO - Payload FIFO Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register is the gate of FIFO read.
 */
typedef union _hw_mipi_dsi_rxfifo
{
    uint32_t U;
    struct _hw_mipi_dsi_rxfifo_bitfields
    {
        uint32_t RXFIFO : 32;          /*!< [31:0]  */
    } B;
} hw_mipi_dsi_rxfifo_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_RXFIFO register
 */
/*@{*/
#define HW_MIPI_DSI_RXFIFO_ADDR(x) ((uintptr_t)(x) + 0x44U)

#define HW_MIPI_DSI_RXFIFO(x)    (*(__I hw_mipi_dsi_rxfifo_t *) HW_MIPI_DSI_RXFIFO_ADDR(x))
#define HW_MIPI_DSI_RXFIFO_RD(x) (HW_MIPI_DSI_RXFIFO(x).U)
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_RXFIFO bitfields
 */

/*!
 * @name Register MIPI_DSI_RXFIFO, field RXFIFO[31:0] (RO)
 *
 * In the Rx mode, you can read Rx data through this register. The CRC in packet
 * is not stored in RxFIFO.
 */
/*@{*/
#define BP_MIPI_DSI_RXFIFO_RXFIFO (0U)     /*!< Bit position for MIPI_DSI_RXFIFO_RXFIFO. */
#define BM_MIPI_DSI_RXFIFO_RXFIFO (0xFFFFFFFFU) /*!< Bit mask for MIPI_DSI_RXFIFO_RXFIFO. */
#define BS_MIPI_DSI_RXFIFO_RXFIFO (32U)    /*!< Bit field size in bits for MIPI_DSI_RXFIFO_RXFIFO. */

/*! @brief Read current value of the MIPI_DSI_RXFIFO_RXFIFO field. */
#define BR_MIPI_DSI_RXFIFO_RXFIFO(x) (HW_MIPI_DSI_RXFIFO(x).U)
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_FIFOTHLD - FIFO Threshold Level Register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_FIFOTHLD - FIFO Threshold Level Register (RW)
 *
 * Reset value: 0x000001FFU
 */
typedef union _hw_mipi_dsi_fifothld
{
    uint32_t U;
    struct _hw_mipi_dsi_fifothld_bitfields
    {
        uint32_t WFULLLEVELSFR : 9;    /*!< [8:0]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_mipi_dsi_fifothld_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_FIFOTHLD register
 */
/*@{*/
#define HW_MIPI_DSI_FIFOTHLD_ADDR(x) ((uintptr_t)(x) + 0x48U)

#define HW_MIPI_DSI_FIFOTHLD(x)  (*(__IO hw_mipi_dsi_fifothld_t *) HW_MIPI_DSI_FIFOTHLD_ADDR(x))
#define HW_MIPI_DSI_FIFOTHLD_RD(x) (HW_MIPI_DSI_FIFOTHLD(x).U)
#define HW_MIPI_DSI_FIFOTHLD_WR(x, v) (HW_MIPI_DSI_FIFOTHLD(x).U = (v))
#define HW_MIPI_DSI_FIFOTHLD_SET(x, v) (HW_MIPI_DSI_FIFOTHLD_WR(x, HW_MIPI_DSI_FIFOTHLD_RD(x) |  (v)))
#define HW_MIPI_DSI_FIFOTHLD_CLR(x, v) (HW_MIPI_DSI_FIFOTHLD_WR(x, HW_MIPI_DSI_FIFOTHLD_RD(x) & ~(v)))
#define HW_MIPI_DSI_FIFOTHLD_TOG(x, v) (HW_MIPI_DSI_FIFOTHLD_WR(x, HW_MIPI_DSI_FIFOTHLD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_FIFOTHLD bitfields
 */

/*!
 * @name Register MIPI_DSI_FIFOTHLD, field WFULLLEVELSFR[8:0] (RW)
 *
 * Almost full level of SFR payload FIFO
 */
/*@{*/
#define BP_MIPI_DSI_FIFOTHLD_WFULLLEVELSFR (0U) /*!< Bit position for MIPI_DSI_FIFOTHLD_WFULLLEVELSFR. */
#define BM_MIPI_DSI_FIFOTHLD_WFULLLEVELSFR (0x000001FFU) /*!< Bit mask for MIPI_DSI_FIFOTHLD_WFULLLEVELSFR. */
#define BS_MIPI_DSI_FIFOTHLD_WFULLLEVELSFR (9U) /*!< Bit field size in bits for MIPI_DSI_FIFOTHLD_WFULLLEVELSFR. */

/*! @brief Read current value of the MIPI_DSI_FIFOTHLD_WFULLLEVELSFR field. */
#define BR_MIPI_DSI_FIFOTHLD_WFULLLEVELSFR(x) (HW_MIPI_DSI_FIFOTHLD(x).B.WFULLLEVELSFR)

/*! @brief Format value for bitfield MIPI_DSI_FIFOTHLD_WFULLLEVELSFR. */
#define BF_MIPI_DSI_FIFOTHLD_WFULLLEVELSFR(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_FIFOTHLD_WFULLLEVELSFR) & BM_MIPI_DSI_FIFOTHLD_WFULLLEVELSFR)

/*! @brief Set the WFULLLEVELSFR field to a new value. */
#define BW_MIPI_DSI_FIFOTHLD_WFULLLEVELSFR(x, v) (HW_MIPI_DSI_FIFOTHLD_WR(x, (HW_MIPI_DSI_FIFOTHLD_RD(x) & ~BM_MIPI_DSI_FIFOTHLD_WFULLLEVELSFR) | BF_MIPI_DSI_FIFOTHLD_WFULLLEVELSFR(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_FIFOCTRL - FIFO Status and Control Register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_FIFOCTRL - FIFO Status and Control Register (RW)
 *
 * Reset value: 0x0155551FU
 */
typedef union _hw_mipi_dsi_fifoctrl
{
    uint32_t U;
    struct _hw_mipi_dsi_fifoctrl_bitfields
    {
        uint32_t NINITMAIN : 1;        /*!< [0]  */
        uint32_t NINITSUB : 1;         /*!< [1]  */
        uint32_t NLNITL80 : 1;         /*!< [2]  */
        uint32_t NINITSFR : 1;         /*!< [3]  */
        uint32_t NINITRX : 1;          /*!< [4]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t EMPTYLMAIN : 1;       /*!< [8]  */
        uint32_t FULLLMAIN : 1;        /*!< [9]  */
        uint32_t EMPTYHMAIN : 1;       /*!< [10]  */
        uint32_t FULLHMAIN : 1;        /*!< [11]  */
        uint32_t EMPTYLSUB : 1;        /*!< [12]  */
        uint32_t FULLLSUB : 1;         /*!< [13]  */
        uint32_t EMPTYHSUB : 1;        /*!< [14]  */
        uint32_t FULLHSUB : 1;         /*!< [15]  */
        uint32_t EMPTYLI80 : 1;        /*!< [16]  */
        uint32_t FULLLI80 : 1;         /*!< [17]  */
        uint32_t EMPTYHI80 : 1;        /*!< [18]  */
        uint32_t FULLHI80 : 1;         /*!< [19]  */
        uint32_t EMPTYLSFR : 1;        /*!< [20]  */
        uint32_t FULLLSFR : 1;         /*!< [21]  */
        uint32_t EMPTYHSFR : 1;        /*!< [22]  */
        uint32_t FullHSfr : 1;         /*!< [23]  */
        uint32_t EMPTYRX : 1;          /*!< [24]  */
        uint32_t FULLRX : 1;           /*!< [25]  */
        uint32_t RESERVED1 : 6;        /*!< [31:26]  */
    } B;
} hw_mipi_dsi_fifoctrl_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_FIFOCTRL register
 */
/*@{*/
#define HW_MIPI_DSI_FIFOCTRL_ADDR(x) ((uintptr_t)(x) + 0x4CU)

#define HW_MIPI_DSI_FIFOCTRL(x)  (*(__IO hw_mipi_dsi_fifoctrl_t *) HW_MIPI_DSI_FIFOCTRL_ADDR(x))
#define HW_MIPI_DSI_FIFOCTRL_RD(x) (HW_MIPI_DSI_FIFOCTRL(x).U)
#define HW_MIPI_DSI_FIFOCTRL_WR(x, v) (HW_MIPI_DSI_FIFOCTRL(x).U = (v))
#define HW_MIPI_DSI_FIFOCTRL_SET(x, v) (HW_MIPI_DSI_FIFOCTRL_WR(x, HW_MIPI_DSI_FIFOCTRL_RD(x) |  (v)))
#define HW_MIPI_DSI_FIFOCTRL_CLR(x, v) (HW_MIPI_DSI_FIFOCTRL_WR(x, HW_MIPI_DSI_FIFOCTRL_RD(x) & ~(v)))
#define HW_MIPI_DSI_FIFOCTRL_TOG(x, v) (HW_MIPI_DSI_FIFOCTRL_WR(x, HW_MIPI_DSI_FIFOCTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_FIFOCTRL bitfields
 */

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field NINITMAIN[0] (RW)
 *
 * MD FIFO write point initialize
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_NINITMAIN (0U) /*!< Bit position for MIPI_DSI_FIFOCTRL_NINITMAIN. */
#define BM_MIPI_DSI_FIFOCTRL_NINITMAIN (0x00000001U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_NINITMAIN. */
#define BS_MIPI_DSI_FIFOCTRL_NINITMAIN (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_NINITMAIN. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_NINITMAIN field. */
#define BR_MIPI_DSI_FIFOCTRL_NINITMAIN(x) (HW_MIPI_DSI_FIFOCTRL(x).B.NINITMAIN)

/*! @brief Format value for bitfield MIPI_DSI_FIFOCTRL_NINITMAIN. */
#define BF_MIPI_DSI_FIFOCTRL_NINITMAIN(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_FIFOCTRL_NINITMAIN) & BM_MIPI_DSI_FIFOCTRL_NINITMAIN)

/*! @brief Set the NINITMAIN field to a new value. */
#define BW_MIPI_DSI_FIFOCTRL_NINITMAIN(x, v) (HW_MIPI_DSI_FIFOCTRL_WR(x, (HW_MIPI_DSI_FIFOCTRL_RD(x) & ~BM_MIPI_DSI_FIFOCTRL_NINITMAIN) | BF_MIPI_DSI_FIFOCTRL_NINITMAIN(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field NINITSUB[1] (RW)
 *
 * SD FIFO write point initialize
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_NINITSUB (1U) /*!< Bit position for MIPI_DSI_FIFOCTRL_NINITSUB. */
#define BM_MIPI_DSI_FIFOCTRL_NINITSUB (0x00000002U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_NINITSUB. */
#define BS_MIPI_DSI_FIFOCTRL_NINITSUB (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_NINITSUB. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_NINITSUB field. */
#define BR_MIPI_DSI_FIFOCTRL_NINITSUB(x) (HW_MIPI_DSI_FIFOCTRL(x).B.NINITSUB)

/*! @brief Format value for bitfield MIPI_DSI_FIFOCTRL_NINITSUB. */
#define BF_MIPI_DSI_FIFOCTRL_NINITSUB(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_FIFOCTRL_NINITSUB) & BM_MIPI_DSI_FIFOCTRL_NINITSUB)

/*! @brief Set the NINITSUB field to a new value. */
#define BW_MIPI_DSI_FIFOCTRL_NINITSUB(x, v) (HW_MIPI_DSI_FIFOCTRL_WR(x, (HW_MIPI_DSI_FIFOCTRL_RD(x) & ~BM_MIPI_DSI_FIFOCTRL_NINITSUB) | BF_MIPI_DSI_FIFOCTRL_NINITSUB(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field NLNITL80[2] (RW)
 *
 * S-i80 FIFO write point initialize
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_NLNITL80 (2U) /*!< Bit position for MIPI_DSI_FIFOCTRL_NLNITL80. */
#define BM_MIPI_DSI_FIFOCTRL_NLNITL80 (0x00000004U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_NLNITL80. */
#define BS_MIPI_DSI_FIFOCTRL_NLNITL80 (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_NLNITL80. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_NLNITL80 field. */
#define BR_MIPI_DSI_FIFOCTRL_NLNITL80(x) (HW_MIPI_DSI_FIFOCTRL(x).B.NLNITL80)

/*! @brief Format value for bitfield MIPI_DSI_FIFOCTRL_NLNITL80. */
#define BF_MIPI_DSI_FIFOCTRL_NLNITL80(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_FIFOCTRL_NLNITL80) & BM_MIPI_DSI_FIFOCTRL_NLNITL80)

/*! @brief Set the NLNITL80 field to a new value. */
#define BW_MIPI_DSI_FIFOCTRL_NLNITL80(x, v) (HW_MIPI_DSI_FIFOCTRL_WR(x, (HW_MIPI_DSI_FIFOCTRL_RD(x) & ~BM_MIPI_DSI_FIFOCTRL_NLNITL80) | BF_MIPI_DSI_FIFOCTRL_NLNITL80(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field NINITSFR[3] (RW)
 *
 * SFR FIFO write point initialize
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_NINITSFR (3U) /*!< Bit position for MIPI_DSI_FIFOCTRL_NINITSFR. */
#define BM_MIPI_DSI_FIFOCTRL_NINITSFR (0x00000008U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_NINITSFR. */
#define BS_MIPI_DSI_FIFOCTRL_NINITSFR (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_NINITSFR. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_NINITSFR field. */
#define BR_MIPI_DSI_FIFOCTRL_NINITSFR(x) (HW_MIPI_DSI_FIFOCTRL(x).B.NINITSFR)

/*! @brief Format value for bitfield MIPI_DSI_FIFOCTRL_NINITSFR. */
#define BF_MIPI_DSI_FIFOCTRL_NINITSFR(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_FIFOCTRL_NINITSFR) & BM_MIPI_DSI_FIFOCTRL_NINITSFR)

/*! @brief Set the NINITSFR field to a new value. */
#define BW_MIPI_DSI_FIFOCTRL_NINITSFR(x, v) (HW_MIPI_DSI_FIFOCTRL_WR(x, (HW_MIPI_DSI_FIFOCTRL_RD(x) & ~BM_MIPI_DSI_FIFOCTRL_NINITSFR) | BF_MIPI_DSI_FIFOCTRL_NINITSFR(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field NINITRX[4] (RW)
 *
 * MD FIFO read point initialize
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_NINITRX (4U)  /*!< Bit position for MIPI_DSI_FIFOCTRL_NINITRX. */
#define BM_MIPI_DSI_FIFOCTRL_NINITRX (0x00000010U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_NINITRX. */
#define BS_MIPI_DSI_FIFOCTRL_NINITRX (1U)  /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_NINITRX. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_NINITRX field. */
#define BR_MIPI_DSI_FIFOCTRL_NINITRX(x) (HW_MIPI_DSI_FIFOCTRL(x).B.NINITRX)

/*! @brief Format value for bitfield MIPI_DSI_FIFOCTRL_NINITRX. */
#define BF_MIPI_DSI_FIFOCTRL_NINITRX(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_FIFOCTRL_NINITRX) & BM_MIPI_DSI_FIFOCTRL_NINITRX)

/*! @brief Set the NINITRX field to a new value. */
#define BW_MIPI_DSI_FIFOCTRL_NINITRX(x, v) (HW_MIPI_DSI_FIFOCTRL_WR(x, (HW_MIPI_DSI_FIFOCTRL_RD(x) & ~BM_MIPI_DSI_FIFOCTRL_NINITRX) | BF_MIPI_DSI_FIFOCTRL_NINITRX(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field EMPTYLMAIN[8] (RO)
 *
 * Main display payload FIFO empty
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_EMPTYLMAIN (8U) /*!< Bit position for MIPI_DSI_FIFOCTRL_EMPTYLMAIN. */
#define BM_MIPI_DSI_FIFOCTRL_EMPTYLMAIN (0x00000100U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_EMPTYLMAIN. */
#define BS_MIPI_DSI_FIFOCTRL_EMPTYLMAIN (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_EMPTYLMAIN. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_EMPTYLMAIN field. */
#define BR_MIPI_DSI_FIFOCTRL_EMPTYLMAIN(x) (HW_MIPI_DSI_FIFOCTRL(x).B.EMPTYLMAIN)
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field FULLLMAIN[9] (RO)
 *
 * Main display payload FIFO full
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_FULLLMAIN (9U) /*!< Bit position for MIPI_DSI_FIFOCTRL_FULLLMAIN. */
#define BM_MIPI_DSI_FIFOCTRL_FULLLMAIN (0x00000200U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_FULLLMAIN. */
#define BS_MIPI_DSI_FIFOCTRL_FULLLMAIN (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_FULLLMAIN. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_FULLLMAIN field. */
#define BR_MIPI_DSI_FIFOCTRL_FULLLMAIN(x) (HW_MIPI_DSI_FIFOCTRL(x).B.FULLLMAIN)
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field EMPTYHMAIN[10] (RO)
 *
 * Main display packet header FIFO empty
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_EMPTYHMAIN (10U) /*!< Bit position for MIPI_DSI_FIFOCTRL_EMPTYHMAIN. */
#define BM_MIPI_DSI_FIFOCTRL_EMPTYHMAIN (0x00000400U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_EMPTYHMAIN. */
#define BS_MIPI_DSI_FIFOCTRL_EMPTYHMAIN (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_EMPTYHMAIN. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_EMPTYHMAIN field. */
#define BR_MIPI_DSI_FIFOCTRL_EMPTYHMAIN(x) (HW_MIPI_DSI_FIFOCTRL(x).B.EMPTYHMAIN)
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field FULLHMAIN[11] (RO)
 *
 * Main display packet header FIFO full
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_FULLHMAIN (11U) /*!< Bit position for MIPI_DSI_FIFOCTRL_FULLHMAIN. */
#define BM_MIPI_DSI_FIFOCTRL_FULLHMAIN (0x00000800U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_FULLHMAIN. */
#define BS_MIPI_DSI_FIFOCTRL_FULLHMAIN (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_FULLHMAIN. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_FULLHMAIN field. */
#define BR_MIPI_DSI_FIFOCTRL_FULLHMAIN(x) (HW_MIPI_DSI_FIFOCTRL(x).B.FULLHMAIN)
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field EMPTYLSUB[12] (RO)
 *
 * Sub display payload FIFO empty
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_EMPTYLSUB (12U) /*!< Bit position for MIPI_DSI_FIFOCTRL_EMPTYLSUB. */
#define BM_MIPI_DSI_FIFOCTRL_EMPTYLSUB (0x00001000U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_EMPTYLSUB. */
#define BS_MIPI_DSI_FIFOCTRL_EMPTYLSUB (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_EMPTYLSUB. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_EMPTYLSUB field. */
#define BR_MIPI_DSI_FIFOCTRL_EMPTYLSUB(x) (HW_MIPI_DSI_FIFOCTRL(x).B.EMPTYLSUB)
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field FULLLSUB[13] (RO)
 *
 * Sub display payload FIFO full
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_FULLLSUB (13U) /*!< Bit position for MIPI_DSI_FIFOCTRL_FULLLSUB. */
#define BM_MIPI_DSI_FIFOCTRL_FULLLSUB (0x00002000U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_FULLLSUB. */
#define BS_MIPI_DSI_FIFOCTRL_FULLLSUB (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_FULLLSUB. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_FULLLSUB field. */
#define BR_MIPI_DSI_FIFOCTRL_FULLLSUB(x) (HW_MIPI_DSI_FIFOCTRL(x).B.FULLLSUB)
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field EMPTYHSUB[14] (RO)
 *
 * Sub display packet header FIFO empty
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_EMPTYHSUB (14U) /*!< Bit position for MIPI_DSI_FIFOCTRL_EMPTYHSUB. */
#define BM_MIPI_DSI_FIFOCTRL_EMPTYHSUB (0x00004000U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_EMPTYHSUB. */
#define BS_MIPI_DSI_FIFOCTRL_EMPTYHSUB (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_EMPTYHSUB. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_EMPTYHSUB field. */
#define BR_MIPI_DSI_FIFOCTRL_EMPTYHSUB(x) (HW_MIPI_DSI_FIFOCTRL(x).B.EMPTYHSUB)
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field FULLHSUB[15] (RO)
 *
 * Sub display packet header FIFO full
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_FULLHSUB (15U) /*!< Bit position for MIPI_DSI_FIFOCTRL_FULLHSUB. */
#define BM_MIPI_DSI_FIFOCTRL_FULLHSUB (0x00008000U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_FULLHSUB. */
#define BS_MIPI_DSI_FIFOCTRL_FULLHSUB (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_FULLHSUB. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_FULLHSUB field. */
#define BR_MIPI_DSI_FIFOCTRL_FULLHSUB(x) (HW_MIPI_DSI_FIFOCTRL(x).B.FULLHSUB)
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field EMPTYLI80[16] (RO)
 *
 * S-i80 payload FIFO empty
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_EMPTYLI80 (16U) /*!< Bit position for MIPI_DSI_FIFOCTRL_EMPTYLI80. */
#define BM_MIPI_DSI_FIFOCTRL_EMPTYLI80 (0x00010000U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_EMPTYLI80. */
#define BS_MIPI_DSI_FIFOCTRL_EMPTYLI80 (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_EMPTYLI80. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_EMPTYLI80 field. */
#define BR_MIPI_DSI_FIFOCTRL_EMPTYLI80(x) (HW_MIPI_DSI_FIFOCTRL(x).B.EMPTYLI80)
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field FULLLI80[17] (RO)
 *
 * S-i80 payload FIFO full
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_FULLLI80 (17U) /*!< Bit position for MIPI_DSI_FIFOCTRL_FULLLI80. */
#define BM_MIPI_DSI_FIFOCTRL_FULLLI80 (0x00020000U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_FULLLI80. */
#define BS_MIPI_DSI_FIFOCTRL_FULLLI80 (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_FULLLI80. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_FULLLI80 field. */
#define BR_MIPI_DSI_FIFOCTRL_FULLLI80(x) (HW_MIPI_DSI_FIFOCTRL(x).B.FULLLI80)
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field EMPTYHI80[18] (RO)
 *
 * S-i80 packet header FIFO empty
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_EMPTYHI80 (18U) /*!< Bit position for MIPI_DSI_FIFOCTRL_EMPTYHI80. */
#define BM_MIPI_DSI_FIFOCTRL_EMPTYHI80 (0x00040000U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_EMPTYHI80. */
#define BS_MIPI_DSI_FIFOCTRL_EMPTYHI80 (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_EMPTYHI80. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_EMPTYHI80 field. */
#define BR_MIPI_DSI_FIFOCTRL_EMPTYHI80(x) (HW_MIPI_DSI_FIFOCTRL(x).B.EMPTYHI80)
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field FULLHI80[19] (RO)
 *
 * S-i80 packet header FIFO full
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_FULLHI80 (19U) /*!< Bit position for MIPI_DSI_FIFOCTRL_FULLHI80. */
#define BM_MIPI_DSI_FIFOCTRL_FULLHI80 (0x00080000U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_FULLHI80. */
#define BS_MIPI_DSI_FIFOCTRL_FULLHI80 (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_FULLHI80. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_FULLHI80 field. */
#define BR_MIPI_DSI_FIFOCTRL_FULLHI80(x) (HW_MIPI_DSI_FIFOCTRL(x).B.FULLHI80)
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field EMPTYLSFR[20] (RO)
 *
 * SFR payload FIFO empty
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_EMPTYLSFR (20U) /*!< Bit position for MIPI_DSI_FIFOCTRL_EMPTYLSFR. */
#define BM_MIPI_DSI_FIFOCTRL_EMPTYLSFR (0x00100000U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_EMPTYLSFR. */
#define BS_MIPI_DSI_FIFOCTRL_EMPTYLSFR (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_EMPTYLSFR. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_EMPTYLSFR field. */
#define BR_MIPI_DSI_FIFOCTRL_EMPTYLSFR(x) (HW_MIPI_DSI_FIFOCTRL(x).B.EMPTYLSFR)
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field FULLLSFR[21] (RO)
 *
 * SFR payload FIFO full
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_FULLLSFR (21U) /*!< Bit position for MIPI_DSI_FIFOCTRL_FULLLSFR. */
#define BM_MIPI_DSI_FIFOCTRL_FULLLSFR (0x00200000U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_FULLLSFR. */
#define BS_MIPI_DSI_FIFOCTRL_FULLLSFR (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_FULLLSFR. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_FULLLSFR field. */
#define BR_MIPI_DSI_FIFOCTRL_FULLLSFR(x) (HW_MIPI_DSI_FIFOCTRL(x).B.FULLLSFR)
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field EMPTYHSFR[22] (RO)
 *
 * SFR packet header FIFO empty
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_EMPTYHSFR (22U) /*!< Bit position for MIPI_DSI_FIFOCTRL_EMPTYHSFR. */
#define BM_MIPI_DSI_FIFOCTRL_EMPTYHSFR (0x00400000U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_EMPTYHSFR. */
#define BS_MIPI_DSI_FIFOCTRL_EMPTYHSFR (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_EMPTYHSFR. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_EMPTYHSFR field. */
#define BR_MIPI_DSI_FIFOCTRL_EMPTYHSFR(x) (HW_MIPI_DSI_FIFOCTRL(x).B.EMPTYHSFR)
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field FullHSfr[23] (RO)
 *
 * SFR packet header FIFO full
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_FullHSfr (23U) /*!< Bit position for MIPI_DSI_FIFOCTRL_FullHSfr. */
#define BM_MIPI_DSI_FIFOCTRL_FullHSfr (0x00800000U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_FullHSfr. */
#define BS_MIPI_DSI_FIFOCTRL_FullHSfr (1U) /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_FullHSfr. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_FullHSfr field. */
#define BR_MIPI_DSI_FIFOCTRL_FullHSfr(x) (HW_MIPI_DSI_FIFOCTRL(x).B.FullHSfr)
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field EMPTYRX[24] (RO)
 *
 * Rx FIFO empty
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_EMPTYRX (24U) /*!< Bit position for MIPI_DSI_FIFOCTRL_EMPTYRX. */
#define BM_MIPI_DSI_FIFOCTRL_EMPTYRX (0x01000000U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_EMPTYRX. */
#define BS_MIPI_DSI_FIFOCTRL_EMPTYRX (1U)  /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_EMPTYRX. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_EMPTYRX field. */
#define BR_MIPI_DSI_FIFOCTRL_EMPTYRX(x) (HW_MIPI_DSI_FIFOCTRL(x).B.EMPTYRX)
/*@}*/

/*!
 * @name Register MIPI_DSI_FIFOCTRL, field FULLRX[25] (RO)
 *
 * Rx FIFO full
 */
/*@{*/
#define BP_MIPI_DSI_FIFOCTRL_FULLRX (25U)  /*!< Bit position for MIPI_DSI_FIFOCTRL_FULLRX. */
#define BM_MIPI_DSI_FIFOCTRL_FULLRX (0x02000000U) /*!< Bit mask for MIPI_DSI_FIFOCTRL_FULLRX. */
#define BS_MIPI_DSI_FIFOCTRL_FULLRX (1U)   /*!< Bit field size in bits for MIPI_DSI_FIFOCTRL_FULLRX. */

/*! @brief Read current value of the MIPI_DSI_FIFOCTRL_FULLRX field. */
#define BR_MIPI_DSI_FIFOCTRL_FULLRX(x) (HW_MIPI_DSI_FIFOCTRL(x).B.FULLRX)
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_MEMACCHR - FIFO Memory AC Characteristic Register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_MEMACCHR - FIFO Memory AC Characteristic Register (RW)
 *
 * Reset value: 0x00004040U
 *
 * In current design, these memory port controls were disabled. User can ignore
 * the function of this register.
 */
typedef union _hw_mipi_dsi_memacchr
{
    uint32_t U;
    struct _hw_mipi_dsi_memacchr_bitfields
    {
        uint32_t EMAA_MD : 3;          /*!< [2:0]  */
        uint32_t EMAB_MD : 3;          /*!< [5:3]  */
        uint32_t RETN_MD : 1;          /*!< [6]  */
        uint32_t PGEN_MD : 1;          /*!< [7]  */
        uint32_t EMAA_SD : 3;          /*!< [10:8]  */
        uint32_t EMAB_SD : 3;          /*!< [13:11]  */
        uint32_t RETN_SD : 1;          /*!< [14]  */
        uint32_t PGEN_SD : 1;          /*!< [15]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_mipi_dsi_memacchr_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_MEMACCHR register
 */
/*@{*/
#define HW_MIPI_DSI_MEMACCHR_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_MIPI_DSI_MEMACCHR(x)  (*(__IO hw_mipi_dsi_memacchr_t *) HW_MIPI_DSI_MEMACCHR_ADDR(x))
#define HW_MIPI_DSI_MEMACCHR_RD(x) (HW_MIPI_DSI_MEMACCHR(x).U)
#define HW_MIPI_DSI_MEMACCHR_WR(x, v) (HW_MIPI_DSI_MEMACCHR(x).U = (v))
#define HW_MIPI_DSI_MEMACCHR_SET(x, v) (HW_MIPI_DSI_MEMACCHR_WR(x, HW_MIPI_DSI_MEMACCHR_RD(x) |  (v)))
#define HW_MIPI_DSI_MEMACCHR_CLR(x, v) (HW_MIPI_DSI_MEMACCHR_WR(x, HW_MIPI_DSI_MEMACCHR_RD(x) & ~(v)))
#define HW_MIPI_DSI_MEMACCHR_TOG(x, v) (HW_MIPI_DSI_MEMACCHR_WR(x, HW_MIPI_DSI_MEMACCHR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_MEMACCHR bitfields
 */

/*!
 * @name Register MIPI_DSI_MEMACCHR, field EMAA_MD[2:0] (RW)
 *
 * Main display FIFO memory A port margin adjustment
 */
/*@{*/
#define BP_MIPI_DSI_MEMACCHR_EMAA_MD (0U)  /*!< Bit position for MIPI_DSI_MEMACCHR_EMAA_MD. */
#define BM_MIPI_DSI_MEMACCHR_EMAA_MD (0x00000007U) /*!< Bit mask for MIPI_DSI_MEMACCHR_EMAA_MD. */
#define BS_MIPI_DSI_MEMACCHR_EMAA_MD (3U)  /*!< Bit field size in bits for MIPI_DSI_MEMACCHR_EMAA_MD. */

/*! @brief Read current value of the MIPI_DSI_MEMACCHR_EMAA_MD field. */
#define BR_MIPI_DSI_MEMACCHR_EMAA_MD(x) (HW_MIPI_DSI_MEMACCHR(x).B.EMAA_MD)

/*! @brief Format value for bitfield MIPI_DSI_MEMACCHR_EMAA_MD. */
#define BF_MIPI_DSI_MEMACCHR_EMAA_MD(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MEMACCHR_EMAA_MD) & BM_MIPI_DSI_MEMACCHR_EMAA_MD)

/*! @brief Set the EMAA_MD field to a new value. */
#define BW_MIPI_DSI_MEMACCHR_EMAA_MD(x, v) (HW_MIPI_DSI_MEMACCHR_WR(x, (HW_MIPI_DSI_MEMACCHR_RD(x) & ~BM_MIPI_DSI_MEMACCHR_EMAA_MD) | BF_MIPI_DSI_MEMACCHR_EMAA_MD(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_MEMACCHR, field EMAB_MD[5:3] (RW)
 *
 * Main display FIFO memory B port margin adjustment
 */
/*@{*/
#define BP_MIPI_DSI_MEMACCHR_EMAB_MD (3U)  /*!< Bit position for MIPI_DSI_MEMACCHR_EMAB_MD. */
#define BM_MIPI_DSI_MEMACCHR_EMAB_MD (0x00000038U) /*!< Bit mask for MIPI_DSI_MEMACCHR_EMAB_MD. */
#define BS_MIPI_DSI_MEMACCHR_EMAB_MD (3U)  /*!< Bit field size in bits for MIPI_DSI_MEMACCHR_EMAB_MD. */

/*! @brief Read current value of the MIPI_DSI_MEMACCHR_EMAB_MD field. */
#define BR_MIPI_DSI_MEMACCHR_EMAB_MD(x) (HW_MIPI_DSI_MEMACCHR(x).B.EMAB_MD)

/*! @brief Format value for bitfield MIPI_DSI_MEMACCHR_EMAB_MD. */
#define BF_MIPI_DSI_MEMACCHR_EMAB_MD(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MEMACCHR_EMAB_MD) & BM_MIPI_DSI_MEMACCHR_EMAB_MD)

/*! @brief Set the EMAB_MD field to a new value. */
#define BW_MIPI_DSI_MEMACCHR_EMAB_MD(x, v) (HW_MIPI_DSI_MEMACCHR_WR(x, (HW_MIPI_DSI_MEMACCHR_RD(x) & ~BM_MIPI_DSI_MEMACCHR_EMAB_MD) | BF_MIPI_DSI_MEMACCHR_EMAB_MD(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_MEMACCHR, field RETN_MD[6] (RW)
 *
 * Main display FIFO memory Retention
 */
/*@{*/
#define BP_MIPI_DSI_MEMACCHR_RETN_MD (6U)  /*!< Bit position for MIPI_DSI_MEMACCHR_RETN_MD. */
#define BM_MIPI_DSI_MEMACCHR_RETN_MD (0x00000040U) /*!< Bit mask for MIPI_DSI_MEMACCHR_RETN_MD. */
#define BS_MIPI_DSI_MEMACCHR_RETN_MD (1U)  /*!< Bit field size in bits for MIPI_DSI_MEMACCHR_RETN_MD. */

/*! @brief Read current value of the MIPI_DSI_MEMACCHR_RETN_MD field. */
#define BR_MIPI_DSI_MEMACCHR_RETN_MD(x) (HW_MIPI_DSI_MEMACCHR(x).B.RETN_MD)

/*! @brief Format value for bitfield MIPI_DSI_MEMACCHR_RETN_MD. */
#define BF_MIPI_DSI_MEMACCHR_RETN_MD(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MEMACCHR_RETN_MD) & BM_MIPI_DSI_MEMACCHR_RETN_MD)

/*! @brief Set the RETN_MD field to a new value. */
#define BW_MIPI_DSI_MEMACCHR_RETN_MD(x, v) (HW_MIPI_DSI_MEMACCHR_WR(x, (HW_MIPI_DSI_MEMACCHR_RD(x) & ~BM_MIPI_DSI_MEMACCHR_RETN_MD) | BF_MIPI_DSI_MEMACCHR_RETN_MD(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_MEMACCHR, field PGEN_MD[7] (RW)
 *
 * Main display FIFO memory power gating
 */
/*@{*/
#define BP_MIPI_DSI_MEMACCHR_PGEN_MD (7U)  /*!< Bit position for MIPI_DSI_MEMACCHR_PGEN_MD. */
#define BM_MIPI_DSI_MEMACCHR_PGEN_MD (0x00000080U) /*!< Bit mask for MIPI_DSI_MEMACCHR_PGEN_MD. */
#define BS_MIPI_DSI_MEMACCHR_PGEN_MD (1U)  /*!< Bit field size in bits for MIPI_DSI_MEMACCHR_PGEN_MD. */

/*! @brief Read current value of the MIPI_DSI_MEMACCHR_PGEN_MD field. */
#define BR_MIPI_DSI_MEMACCHR_PGEN_MD(x) (HW_MIPI_DSI_MEMACCHR(x).B.PGEN_MD)

/*! @brief Format value for bitfield MIPI_DSI_MEMACCHR_PGEN_MD. */
#define BF_MIPI_DSI_MEMACCHR_PGEN_MD(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MEMACCHR_PGEN_MD) & BM_MIPI_DSI_MEMACCHR_PGEN_MD)

/*! @brief Set the PGEN_MD field to a new value. */
#define BW_MIPI_DSI_MEMACCHR_PGEN_MD(x, v) (HW_MIPI_DSI_MEMACCHR_WR(x, (HW_MIPI_DSI_MEMACCHR_RD(x) & ~BM_MIPI_DSI_MEMACCHR_PGEN_MD) | BF_MIPI_DSI_MEMACCHR_PGEN_MD(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_MEMACCHR, field EMAA_SD[10:8] (RW)
 *
 * Sub display FIFO memory A port margin adjustment
 */
/*@{*/
#define BP_MIPI_DSI_MEMACCHR_EMAA_SD (8U)  /*!< Bit position for MIPI_DSI_MEMACCHR_EMAA_SD. */
#define BM_MIPI_DSI_MEMACCHR_EMAA_SD (0x00000700U) /*!< Bit mask for MIPI_DSI_MEMACCHR_EMAA_SD. */
#define BS_MIPI_DSI_MEMACCHR_EMAA_SD (3U)  /*!< Bit field size in bits for MIPI_DSI_MEMACCHR_EMAA_SD. */

/*! @brief Read current value of the MIPI_DSI_MEMACCHR_EMAA_SD field. */
#define BR_MIPI_DSI_MEMACCHR_EMAA_SD(x) (HW_MIPI_DSI_MEMACCHR(x).B.EMAA_SD)

/*! @brief Format value for bitfield MIPI_DSI_MEMACCHR_EMAA_SD. */
#define BF_MIPI_DSI_MEMACCHR_EMAA_SD(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MEMACCHR_EMAA_SD) & BM_MIPI_DSI_MEMACCHR_EMAA_SD)

/*! @brief Set the EMAA_SD field to a new value. */
#define BW_MIPI_DSI_MEMACCHR_EMAA_SD(x, v) (HW_MIPI_DSI_MEMACCHR_WR(x, (HW_MIPI_DSI_MEMACCHR_RD(x) & ~BM_MIPI_DSI_MEMACCHR_EMAA_SD) | BF_MIPI_DSI_MEMACCHR_EMAA_SD(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_MEMACCHR, field EMAB_SD[13:11] (RW)
 *
 * Sub display FIFO memory B port margin adjustment
 */
/*@{*/
#define BP_MIPI_DSI_MEMACCHR_EMAB_SD (11U) /*!< Bit position for MIPI_DSI_MEMACCHR_EMAB_SD. */
#define BM_MIPI_DSI_MEMACCHR_EMAB_SD (0x00003800U) /*!< Bit mask for MIPI_DSI_MEMACCHR_EMAB_SD. */
#define BS_MIPI_DSI_MEMACCHR_EMAB_SD (3U)  /*!< Bit field size in bits for MIPI_DSI_MEMACCHR_EMAB_SD. */

/*! @brief Read current value of the MIPI_DSI_MEMACCHR_EMAB_SD field. */
#define BR_MIPI_DSI_MEMACCHR_EMAB_SD(x) (HW_MIPI_DSI_MEMACCHR(x).B.EMAB_SD)

/*! @brief Format value for bitfield MIPI_DSI_MEMACCHR_EMAB_SD. */
#define BF_MIPI_DSI_MEMACCHR_EMAB_SD(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MEMACCHR_EMAB_SD) & BM_MIPI_DSI_MEMACCHR_EMAB_SD)

/*! @brief Set the EMAB_SD field to a new value. */
#define BW_MIPI_DSI_MEMACCHR_EMAB_SD(x, v) (HW_MIPI_DSI_MEMACCHR_WR(x, (HW_MIPI_DSI_MEMACCHR_RD(x) & ~BM_MIPI_DSI_MEMACCHR_EMAB_SD) | BF_MIPI_DSI_MEMACCHR_EMAB_SD(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_MEMACCHR, field RETN_SD[14] (RW)
 *
 * Sub display FIFO memory Retention
 */
/*@{*/
#define BP_MIPI_DSI_MEMACCHR_RETN_SD (14U) /*!< Bit position for MIPI_DSI_MEMACCHR_RETN_SD. */
#define BM_MIPI_DSI_MEMACCHR_RETN_SD (0x00004000U) /*!< Bit mask for MIPI_DSI_MEMACCHR_RETN_SD. */
#define BS_MIPI_DSI_MEMACCHR_RETN_SD (1U)  /*!< Bit field size in bits for MIPI_DSI_MEMACCHR_RETN_SD. */

/*! @brief Read current value of the MIPI_DSI_MEMACCHR_RETN_SD field. */
#define BR_MIPI_DSI_MEMACCHR_RETN_SD(x) (HW_MIPI_DSI_MEMACCHR(x).B.RETN_SD)

/*! @brief Format value for bitfield MIPI_DSI_MEMACCHR_RETN_SD. */
#define BF_MIPI_DSI_MEMACCHR_RETN_SD(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MEMACCHR_RETN_SD) & BM_MIPI_DSI_MEMACCHR_RETN_SD)

/*! @brief Set the RETN_SD field to a new value. */
#define BW_MIPI_DSI_MEMACCHR_RETN_SD(x, v) (HW_MIPI_DSI_MEMACCHR_WR(x, (HW_MIPI_DSI_MEMACCHR_RD(x) & ~BM_MIPI_DSI_MEMACCHR_RETN_SD) | BF_MIPI_DSI_MEMACCHR_RETN_SD(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_MEMACCHR, field PGEN_SD[15] (RW)
 *
 * Sub display FIFO memory power gating
 */
/*@{*/
#define BP_MIPI_DSI_MEMACCHR_PGEN_SD (15U) /*!< Bit position for MIPI_DSI_MEMACCHR_PGEN_SD. */
#define BM_MIPI_DSI_MEMACCHR_PGEN_SD (0x00008000U) /*!< Bit mask for MIPI_DSI_MEMACCHR_PGEN_SD. */
#define BS_MIPI_DSI_MEMACCHR_PGEN_SD (1U)  /*!< Bit field size in bits for MIPI_DSI_MEMACCHR_PGEN_SD. */

/*! @brief Read current value of the MIPI_DSI_MEMACCHR_PGEN_SD field. */
#define BR_MIPI_DSI_MEMACCHR_PGEN_SD(x) (HW_MIPI_DSI_MEMACCHR(x).B.PGEN_SD)

/*! @brief Format value for bitfield MIPI_DSI_MEMACCHR_PGEN_SD. */
#define BF_MIPI_DSI_MEMACCHR_PGEN_SD(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MEMACCHR_PGEN_SD) & BM_MIPI_DSI_MEMACCHR_PGEN_SD)

/*! @brief Set the PGEN_SD field to a new value. */
#define BW_MIPI_DSI_MEMACCHR_PGEN_SD(x, v) (HW_MIPI_DSI_MEMACCHR_WR(x, (HW_MIPI_DSI_MEMACCHR_RD(x) & ~BM_MIPI_DSI_MEMACCHR_PGEN_SD) | BF_MIPI_DSI_MEMACCHR_PGEN_SD(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_MULTI_PKT -
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_MULTI_PKT -  (RW)
 *
 * Reset value: 0x00010002U
 */
typedef union _hw_mipi_dsi_multi_pkt
{
    uint32_t U;
    struct _hw_mipi_dsi_multi_pkt_bitfields
    {
        uint32_t MULTI_PKT_CNT_REF : 16; /*!< [15:0]  */
        uint32_t PKT_SEND_CNT_REF : 12; /*!< [27:16]  */
        uint32_t PKT_GO_RDY : 1;       /*!< [28]  */
        uint32_t PKT_GO_EN : 1;        /*!< [29]  */
        uint32_t MULTI_PKT_EN : 1;     /*!< [30]  */
        uint32_t RESERVED0 : 1;        /*!< [31]  */
    } B;
} hw_mipi_dsi_multi_pkt_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_MULTI_PKT register
 */
/*@{*/
#define HW_MIPI_DSI_MULTI_PKT_ADDR(x) ((uintptr_t)(x) + 0x78U)

#define HW_MIPI_DSI_MULTI_PKT(x) (*(__IO hw_mipi_dsi_multi_pkt_t *) HW_MIPI_DSI_MULTI_PKT_ADDR(x))
#define HW_MIPI_DSI_MULTI_PKT_RD(x) (HW_MIPI_DSI_MULTI_PKT(x).U)
#define HW_MIPI_DSI_MULTI_PKT_WR(x, v) (HW_MIPI_DSI_MULTI_PKT(x).U = (v))
#define HW_MIPI_DSI_MULTI_PKT_SET(x, v) (HW_MIPI_DSI_MULTI_PKT_WR(x, HW_MIPI_DSI_MULTI_PKT_RD(x) |  (v)))
#define HW_MIPI_DSI_MULTI_PKT_CLR(x, v) (HW_MIPI_DSI_MULTI_PKT_WR(x, HW_MIPI_DSI_MULTI_PKT_RD(x) & ~(v)))
#define HW_MIPI_DSI_MULTI_PKT_TOG(x, v) (HW_MIPI_DSI_MULTI_PKT_WR(x, HW_MIPI_DSI_MULTI_PKT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_MULTI_PKT bitfields
 */

/*!
 * @name Register MIPI_DSI_MULTI_PKT, field MULTI_PKT_CNT_REF[15:0] (RW)
 *
 * Specifies the number of packets on single transmission. Do not use '0' and
 * '1'. 0 and 1 are same as '2'
 */
/*@{*/
#define BP_MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF (0U) /*!< Bit position for MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF. */
#define BM_MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF (0x0000FFFFU) /*!< Bit mask for MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF. */
#define BS_MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF (16U) /*!< Bit field size in bits for MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF. */

/*! @brief Read current value of the MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF field. */
#define BR_MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF(x) (HW_MIPI_DSI_MULTI_PKT(x).B.MULTI_PKT_CNT_REF)

/*! @brief Format value for bitfield MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF. */
#define BF_MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF) & BM_MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF)

/*! @brief Set the MULTI_PKT_CNT_REF field to a new value. */
#define BW_MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF(x, v) (HW_MIPI_DSI_MULTI_PKT_WR(x, (HW_MIPI_DSI_MULTI_PKT_RD(x) & ~BM_MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF) | BF_MIPI_DSI_MULTI_PKT_MULTI_PKT_CNT_REF(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_MULTI_PKT, field PKT_SEND_CNT_REF[27:16] (RW)
 *
 * Specifies the command packet(s) send point indicator. That value is 1H time +
 * D-PHY LP-HS-LP latency by ByteCLK. Do not use '0'.
 */
/*@{*/
#define BP_MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF (16U) /*!< Bit position for MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF. */
#define BM_MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF (0x0FFF0000U) /*!< Bit mask for MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF. */
#define BS_MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF (12U) /*!< Bit field size in bits for MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF. */

/*! @brief Read current value of the MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF field. */
#define BR_MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF(x) (HW_MIPI_DSI_MULTI_PKT(x).B.PKT_SEND_CNT_REF)

/*! @brief Format value for bitfield MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF. */
#define BF_MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF) & BM_MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF)

/*! @brief Set the PKT_SEND_CNT_REF field to a new value. */
#define BW_MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF(x, v) (HW_MIPI_DSI_MULTI_PKT_WR(x, (HW_MIPI_DSI_MULTI_PKT_RD(x) & ~BM_MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF) | BF_MIPI_DSI_MULTI_PKT_PKT_SEND_CNT_REF(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_MULTI_PKT, field PKT_GO_RDY[28] (RW)
 *
 * Specifies the send command packet(s) on this frame VFP. If packet transferred
 * or PKT_Go_EN is disabled, this bit goes to 1'b0.
 */
/*@{*/
#define BP_MIPI_DSI_MULTI_PKT_PKT_GO_RDY (28U) /*!< Bit position for MIPI_DSI_MULTI_PKT_PKT_GO_RDY. */
#define BM_MIPI_DSI_MULTI_PKT_PKT_GO_RDY (0x10000000U) /*!< Bit mask for MIPI_DSI_MULTI_PKT_PKT_GO_RDY. */
#define BS_MIPI_DSI_MULTI_PKT_PKT_GO_RDY (1U) /*!< Bit field size in bits for MIPI_DSI_MULTI_PKT_PKT_GO_RDY. */

/*! @brief Read current value of the MIPI_DSI_MULTI_PKT_PKT_GO_RDY field. */
#define BR_MIPI_DSI_MULTI_PKT_PKT_GO_RDY(x) (HW_MIPI_DSI_MULTI_PKT(x).B.PKT_GO_RDY)

/*! @brief Format value for bitfield MIPI_DSI_MULTI_PKT_PKT_GO_RDY. */
#define BF_MIPI_DSI_MULTI_PKT_PKT_GO_RDY(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MULTI_PKT_PKT_GO_RDY) & BM_MIPI_DSI_MULTI_PKT_PKT_GO_RDY)

/*! @brief Set the PKT_GO_RDY field to a new value. */
#define BW_MIPI_DSI_MULTI_PKT_PKT_GO_RDY(x, v) (HW_MIPI_DSI_MULTI_PKT_WR(x, (HW_MIPI_DSI_MULTI_PKT_RD(x) & ~BM_MIPI_DSI_MULTI_PKT_PKT_GO_RDY) | BF_MIPI_DSI_MULTI_PKT_PKT_GO_RDY(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_MULTI_PKT, field PKT_GO_EN[29] (RW)
 *
 * Specifies the send command packet(s) per frame enable . Packet go can
 * transfer by only HS mode.
 *
 * Values:
 * - 0 - Send command packet(s) during every VFP
 * - 1 - Send command packet(s) during 1frame VFP
 */
/*@{*/
#define BP_MIPI_DSI_MULTI_PKT_PKT_GO_EN (29U) /*!< Bit position for MIPI_DSI_MULTI_PKT_PKT_GO_EN. */
#define BM_MIPI_DSI_MULTI_PKT_PKT_GO_EN (0x20000000U) /*!< Bit mask for MIPI_DSI_MULTI_PKT_PKT_GO_EN. */
#define BS_MIPI_DSI_MULTI_PKT_PKT_GO_EN (1U) /*!< Bit field size in bits for MIPI_DSI_MULTI_PKT_PKT_GO_EN. */

/*! @brief Read current value of the MIPI_DSI_MULTI_PKT_PKT_GO_EN field. */
#define BR_MIPI_DSI_MULTI_PKT_PKT_GO_EN(x) (HW_MIPI_DSI_MULTI_PKT(x).B.PKT_GO_EN)

/*! @brief Format value for bitfield MIPI_DSI_MULTI_PKT_PKT_GO_EN. */
#define BF_MIPI_DSI_MULTI_PKT_PKT_GO_EN(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MULTI_PKT_PKT_GO_EN) & BM_MIPI_DSI_MULTI_PKT_PKT_GO_EN)

/*! @brief Set the PKT_GO_EN field to a new value. */
#define BW_MIPI_DSI_MULTI_PKT_PKT_GO_EN(x, v) (HW_MIPI_DSI_MULTI_PKT_WR(x, (HW_MIPI_DSI_MULTI_PKT_RD(x) & ~BM_MIPI_DSI_MULTI_PKT_PKT_GO_EN) | BF_MIPI_DSI_MULTI_PKT_PKT_GO_EN(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_MULTI_PKT, field MULTI_PKT_EN[30] (RW)
 *
 * Specifies the send multi command packets on single transmission. Multi
 * command packet can transfer by only HS mode.
 *
 * Values:
 * - 0 - Send single command packet
 * - 1 - Send multi command packets
 */
/*@{*/
#define BP_MIPI_DSI_MULTI_PKT_MULTI_PKT_EN (30U) /*!< Bit position for MIPI_DSI_MULTI_PKT_MULTI_PKT_EN. */
#define BM_MIPI_DSI_MULTI_PKT_MULTI_PKT_EN (0x40000000U) /*!< Bit mask for MIPI_DSI_MULTI_PKT_MULTI_PKT_EN. */
#define BS_MIPI_DSI_MULTI_PKT_MULTI_PKT_EN (1U) /*!< Bit field size in bits for MIPI_DSI_MULTI_PKT_MULTI_PKT_EN. */

/*! @brief Read current value of the MIPI_DSI_MULTI_PKT_MULTI_PKT_EN field. */
#define BR_MIPI_DSI_MULTI_PKT_MULTI_PKT_EN(x) (HW_MIPI_DSI_MULTI_PKT(x).B.MULTI_PKT_EN)

/*! @brief Format value for bitfield MIPI_DSI_MULTI_PKT_MULTI_PKT_EN. */
#define BF_MIPI_DSI_MULTI_PKT_MULTI_PKT_EN(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_MULTI_PKT_MULTI_PKT_EN) & BM_MIPI_DSI_MULTI_PKT_MULTI_PKT_EN)

/*! @brief Set the MULTI_PKT_EN field to a new value. */
#define BW_MIPI_DSI_MULTI_PKT_MULTI_PKT_EN(x, v) (HW_MIPI_DSI_MULTI_PKT_WR(x, (HW_MIPI_DSI_MULTI_PKT_RD(x) & ~BM_MIPI_DSI_MULTI_PKT_MULTI_PKT_EN) | BF_MIPI_DSI_MULTI_PKT_MULTI_PKT_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_PLLCTRL_1G - 1 Gbps D-PHY PLL Control Register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_PLLCTRL_1G - 1 Gbps D-PHY PLL Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register configures 1Gbps D-PHY PLL control, D-PHY, clock range
 * indication, and so on.
 */
typedef union _hw_mipi_dsi_pllctrl_1g
{
    uint32_t U;
    struct _hw_mipi_dsi_pllctrl_1g_bitfields
    {
        uint32_t PRPRCTLCLK : 3;       /*!< [2:0]  */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t PREPRCTL : 3;         /*!< [6:4]  */
        uint32_t RESERVED1 : 1;        /*!< [7]  */
        uint32_t FREQ_BAND : 4;        /*!< [11:8]  */
        uint32_t HSZEROCTL : 4;        /*!< [15:12]  */
        uint32_t RESERVED2 : 16;       /*!< [31:16]  */
    } B;
} hw_mipi_dsi_pllctrl_1g_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_PLLCTRL_1G register
 */
/*@{*/
#define HW_MIPI_DSI_PLLCTRL_1G_ADDR(x) ((uintptr_t)(x) + 0x90U)

#define HW_MIPI_DSI_PLLCTRL_1G(x) (*(__IO hw_mipi_dsi_pllctrl_1g_t *) HW_MIPI_DSI_PLLCTRL_1G_ADDR(x))
#define HW_MIPI_DSI_PLLCTRL_1G_RD(x) (HW_MIPI_DSI_PLLCTRL_1G(x).U)
#define HW_MIPI_DSI_PLLCTRL_1G_WR(x, v) (HW_MIPI_DSI_PLLCTRL_1G(x).U = (v))
#define HW_MIPI_DSI_PLLCTRL_1G_SET(x, v) (HW_MIPI_DSI_PLLCTRL_1G_WR(x, HW_MIPI_DSI_PLLCTRL_1G_RD(x) |  (v)))
#define HW_MIPI_DSI_PLLCTRL_1G_CLR(x, v) (HW_MIPI_DSI_PLLCTRL_1G_WR(x, HW_MIPI_DSI_PLLCTRL_1G_RD(x) & ~(v)))
#define HW_MIPI_DSI_PLLCTRL_1G_TOG(x, v) (HW_MIPI_DSI_PLLCTRL_1G_WR(x, HW_MIPI_DSI_PLLCTRL_1G_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_PLLCTRL_1G bitfields
 */

/*!
 * @name Register MIPI_DSI_PLLCTRL_1G, field PRPRCTLCLK[2:0] (RW)
 *
 * 1 Gbps D-PHY PLL Ths-prepare driving time control
 */
/*@{*/
#define BP_MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK (0U) /*!< Bit position for MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK. */
#define BM_MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK (0x00000007U) /*!< Bit mask for MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK. */
#define BS_MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK (3U) /*!< Bit field size in bits for MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK. */

/*! @brief Read current value of the MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK field. */
#define BR_MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK(x) (HW_MIPI_DSI_PLLCTRL_1G(x).B.PRPRCTLCLK)

/*! @brief Format value for bitfield MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK. */
#define BF_MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK) & BM_MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK)

/*! @brief Set the PRPRCTLCLK field to a new value. */
#define BW_MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK(x, v) (HW_MIPI_DSI_PLLCTRL_1G_WR(x, (HW_MIPI_DSI_PLLCTRL_1G_RD(x) & ~BM_MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK) | BF_MIPI_DSI_PLLCTRL_1G_PRPRCTLCLK(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_PLLCTRL_1G, field PREPRCTL[6:4] (RW)
 *
 * 1 Gbps D-PHY PLL Tclk-prepare and Ths-prepare driving control.
 */
/*@{*/
#define BP_MIPI_DSI_PLLCTRL_1G_PREPRCTL (4U) /*!< Bit position for MIPI_DSI_PLLCTRL_1G_PREPRCTL. */
#define BM_MIPI_DSI_PLLCTRL_1G_PREPRCTL (0x00000070U) /*!< Bit mask for MIPI_DSI_PLLCTRL_1G_PREPRCTL. */
#define BS_MIPI_DSI_PLLCTRL_1G_PREPRCTL (3U) /*!< Bit field size in bits for MIPI_DSI_PLLCTRL_1G_PREPRCTL. */

/*! @brief Read current value of the MIPI_DSI_PLLCTRL_1G_PREPRCTL field. */
#define BR_MIPI_DSI_PLLCTRL_1G_PREPRCTL(x) (HW_MIPI_DSI_PLLCTRL_1G(x).B.PREPRCTL)

/*! @brief Format value for bitfield MIPI_DSI_PLLCTRL_1G_PREPRCTL. */
#define BF_MIPI_DSI_PLLCTRL_1G_PREPRCTL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PLLCTRL_1G_PREPRCTL) & BM_MIPI_DSI_PLLCTRL_1G_PREPRCTL)

/*! @brief Set the PREPRCTL field to a new value. */
#define BW_MIPI_DSI_PLLCTRL_1G_PREPRCTL(x, v) (HW_MIPI_DSI_PLLCTRL_1G_WR(x, (HW_MIPI_DSI_PLLCTRL_1G_RD(x) & ~BM_MIPI_DSI_PLLCTRL_1G_PREPRCTL) | BF_MIPI_DSI_PLLCTRL_1G_PREPRCTL(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_PLLCTRL_1G, field FREQ_BAND[11:8] (RW)
 *
 * 1 Gbps D-PHY Timing control for D-PHY global operation timing.
 */
/*@{*/
#define BP_MIPI_DSI_PLLCTRL_1G_FREQ_BAND (8U) /*!< Bit position for MIPI_DSI_PLLCTRL_1G_FREQ_BAND. */
#define BM_MIPI_DSI_PLLCTRL_1G_FREQ_BAND (0x00000F00U) /*!< Bit mask for MIPI_DSI_PLLCTRL_1G_FREQ_BAND. */
#define BS_MIPI_DSI_PLLCTRL_1G_FREQ_BAND (4U) /*!< Bit field size in bits for MIPI_DSI_PLLCTRL_1G_FREQ_BAND. */

/*! @brief Read current value of the MIPI_DSI_PLLCTRL_1G_FREQ_BAND field. */
#define BR_MIPI_DSI_PLLCTRL_1G_FREQ_BAND(x) (HW_MIPI_DSI_PLLCTRL_1G(x).B.FREQ_BAND)

/*! @brief Format value for bitfield MIPI_DSI_PLLCTRL_1G_FREQ_BAND. */
#define BF_MIPI_DSI_PLLCTRL_1G_FREQ_BAND(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PLLCTRL_1G_FREQ_BAND) & BM_MIPI_DSI_PLLCTRL_1G_FREQ_BAND)

/*! @brief Set the FREQ_BAND field to a new value. */
#define BW_MIPI_DSI_PLLCTRL_1G_FREQ_BAND(x, v) (HW_MIPI_DSI_PLLCTRL_1G_WR(x, (HW_MIPI_DSI_PLLCTRL_1G_RD(x) & ~BM_MIPI_DSI_PLLCTRL_1G_FREQ_BAND) | BF_MIPI_DSI_PLLCTRL_1G_FREQ_BAND(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_PLLCTRL_1G, field HSZEROCTL[15:12] (RW)
 *
 * 1 Gbps D-PHY HS-Zero driving timing control.
 */
/*@{*/
#define BP_MIPI_DSI_PLLCTRL_1G_HSZEROCTL (12U) /*!< Bit position for MIPI_DSI_PLLCTRL_1G_HSZEROCTL. */
#define BM_MIPI_DSI_PLLCTRL_1G_HSZEROCTL (0x0000F000U) /*!< Bit mask for MIPI_DSI_PLLCTRL_1G_HSZEROCTL. */
#define BS_MIPI_DSI_PLLCTRL_1G_HSZEROCTL (4U) /*!< Bit field size in bits for MIPI_DSI_PLLCTRL_1G_HSZEROCTL. */

/*! @brief Read current value of the MIPI_DSI_PLLCTRL_1G_HSZEROCTL field. */
#define BR_MIPI_DSI_PLLCTRL_1G_HSZEROCTL(x) (HW_MIPI_DSI_PLLCTRL_1G(x).B.HSZEROCTL)

/*! @brief Format value for bitfield MIPI_DSI_PLLCTRL_1G_HSZEROCTL. */
#define BF_MIPI_DSI_PLLCTRL_1G_HSZEROCTL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PLLCTRL_1G_HSZEROCTL) & BM_MIPI_DSI_PLLCTRL_1G_HSZEROCTL)

/*! @brief Set the HSZEROCTL field to a new value. */
#define BW_MIPI_DSI_PLLCTRL_1G_HSZEROCTL(x, v) (HW_MIPI_DSI_PLLCTRL_1G_WR(x, (HW_MIPI_DSI_PLLCTRL_1G_RD(x) & ~BM_MIPI_DSI_PLLCTRL_1G_HSZEROCTL) | BF_MIPI_DSI_PLLCTRL_1G_HSZEROCTL(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_PLLCTRL - PLL Control register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_PLLCTRL - PLL Control register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register configures PLL control, D-PHY, clock range indication, and so
 * on.
 */
typedef union _hw_mipi_dsi_pllctrl
{
    uint32_t U;
    struct _hw_mipi_dsi_pllctrl_bitfields
    {
        uint32_t RESERVED0 : 1;        /*!< [0]  */
        uint32_t PMS : 19;             /*!< [19:1]  */
        uint32_t RESERVED1 : 3;        /*!< [22:20]  */
        uint32_t PLLEN : 1;            /*!< [23]  */
        uint32_t DPDNSWAP_DAT : 1;     /*!< [24]  */
        uint32_t DPDNSWAP_CLK : 1;     /*!< [25]  */
        uint32_t RESERVED2 : 6;        /*!< [31:26]  */
    } B;
} hw_mipi_dsi_pllctrl_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_PLLCTRL register
 */
/*@{*/
#define HW_MIPI_DSI_PLLCTRL_ADDR(x) ((uintptr_t)(x) + 0x94U)

#define HW_MIPI_DSI_PLLCTRL(x)   (*(__IO hw_mipi_dsi_pllctrl_t *) HW_MIPI_DSI_PLLCTRL_ADDR(x))
#define HW_MIPI_DSI_PLLCTRL_RD(x) (HW_MIPI_DSI_PLLCTRL(x).U)
#define HW_MIPI_DSI_PLLCTRL_WR(x, v) (HW_MIPI_DSI_PLLCTRL(x).U = (v))
#define HW_MIPI_DSI_PLLCTRL_SET(x, v) (HW_MIPI_DSI_PLLCTRL_WR(x, HW_MIPI_DSI_PLLCTRL_RD(x) |  (v)))
#define HW_MIPI_DSI_PLLCTRL_CLR(x, v) (HW_MIPI_DSI_PLLCTRL_WR(x, HW_MIPI_DSI_PLLCTRL_RD(x) & ~(v)))
#define HW_MIPI_DSI_PLLCTRL_TOG(x, v) (HW_MIPI_DSI_PLLCTRL_WR(x, HW_MIPI_DSI_PLLCTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_PLLCTRL bitfields
 */

/*!
 * @name Register MIPI_DSI_PLLCTRL, field PMS[19:1] (RW)
 *
 * Specifies the PLL PMS value
 */
/*@{*/
#define BP_MIPI_DSI_PLLCTRL_PMS (1U)       /*!< Bit position for MIPI_DSI_PLLCTRL_PMS. */
#define BM_MIPI_DSI_PLLCTRL_PMS (0x000FFFFEU) /*!< Bit mask for MIPI_DSI_PLLCTRL_PMS. */
#define BS_MIPI_DSI_PLLCTRL_PMS (19U)      /*!< Bit field size in bits for MIPI_DSI_PLLCTRL_PMS. */

/*! @brief Read current value of the MIPI_DSI_PLLCTRL_PMS field. */
#define BR_MIPI_DSI_PLLCTRL_PMS(x) (HW_MIPI_DSI_PLLCTRL(x).B.PMS)

/*! @brief Format value for bitfield MIPI_DSI_PLLCTRL_PMS. */
#define BF_MIPI_DSI_PLLCTRL_PMS(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PLLCTRL_PMS) & BM_MIPI_DSI_PLLCTRL_PMS)

/*! @brief Set the PMS field to a new value. */
#define BW_MIPI_DSI_PLLCTRL_PMS(x, v) (HW_MIPI_DSI_PLLCTRL_WR(x, (HW_MIPI_DSI_PLLCTRL_RD(x) & ~BM_MIPI_DSI_PLLCTRL_PMS) | BF_MIPI_DSI_PLLCTRL_PMS(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_PLLCTRL, field PLLEN[23] (RW)
 *
 * Enables PLL
 */
/*@{*/
#define BP_MIPI_DSI_PLLCTRL_PLLEN (23U)    /*!< Bit position for MIPI_DSI_PLLCTRL_PLLEN. */
#define BM_MIPI_DSI_PLLCTRL_PLLEN (0x00800000U) /*!< Bit mask for MIPI_DSI_PLLCTRL_PLLEN. */
#define BS_MIPI_DSI_PLLCTRL_PLLEN (1U)     /*!< Bit field size in bits for MIPI_DSI_PLLCTRL_PLLEN. */

/*! @brief Read current value of the MIPI_DSI_PLLCTRL_PLLEN field. */
#define BR_MIPI_DSI_PLLCTRL_PLLEN(x) (HW_MIPI_DSI_PLLCTRL(x).B.PLLEN)

/*! @brief Format value for bitfield MIPI_DSI_PLLCTRL_PLLEN. */
#define BF_MIPI_DSI_PLLCTRL_PLLEN(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PLLCTRL_PLLEN) & BM_MIPI_DSI_PLLCTRL_PLLEN)

/*! @brief Set the PLLEN field to a new value. */
#define BW_MIPI_DSI_PLLCTRL_PLLEN(x, v) (HW_MIPI_DSI_PLLCTRL_WR(x, (HW_MIPI_DSI_PLLCTRL_RD(x) & ~BM_MIPI_DSI_PLLCTRL_PLLEN) | BF_MIPI_DSI_PLLCTRL_PLLEN(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_PLLCTRL, field DPDNSWAP_DAT[24] (RW)
 *
 * Swaps Dp / Dn channel of Data lanes. If this bit is set, Dp and Dn channel
 * swap each other.
 */
/*@{*/
#define BP_MIPI_DSI_PLLCTRL_DPDNSWAP_DAT (24U) /*!< Bit position for MIPI_DSI_PLLCTRL_DPDNSWAP_DAT. */
#define BM_MIPI_DSI_PLLCTRL_DPDNSWAP_DAT (0x01000000U) /*!< Bit mask for MIPI_DSI_PLLCTRL_DPDNSWAP_DAT. */
#define BS_MIPI_DSI_PLLCTRL_DPDNSWAP_DAT (1U) /*!< Bit field size in bits for MIPI_DSI_PLLCTRL_DPDNSWAP_DAT. */

/*! @brief Read current value of the MIPI_DSI_PLLCTRL_DPDNSWAP_DAT field. */
#define BR_MIPI_DSI_PLLCTRL_DPDNSWAP_DAT(x) (HW_MIPI_DSI_PLLCTRL(x).B.DPDNSWAP_DAT)

/*! @brief Format value for bitfield MIPI_DSI_PLLCTRL_DPDNSWAP_DAT. */
#define BF_MIPI_DSI_PLLCTRL_DPDNSWAP_DAT(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PLLCTRL_DPDNSWAP_DAT) & BM_MIPI_DSI_PLLCTRL_DPDNSWAP_DAT)

/*! @brief Set the DPDNSWAP_DAT field to a new value. */
#define BW_MIPI_DSI_PLLCTRL_DPDNSWAP_DAT(x, v) (HW_MIPI_DSI_PLLCTRL_WR(x, (HW_MIPI_DSI_PLLCTRL_RD(x) & ~BM_MIPI_DSI_PLLCTRL_DPDNSWAP_DAT) | BF_MIPI_DSI_PLLCTRL_DPDNSWAP_DAT(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_PLLCTRL, field DPDNSWAP_CLK[25] (RW)
 *
 * Swaps Dp / Dn channel of clock lane. If this bit is set, Dp and Dn channel
 * swap each other.
 */
/*@{*/
#define BP_MIPI_DSI_PLLCTRL_DPDNSWAP_CLK (25U) /*!< Bit position for MIPI_DSI_PLLCTRL_DPDNSWAP_CLK. */
#define BM_MIPI_DSI_PLLCTRL_DPDNSWAP_CLK (0x02000000U) /*!< Bit mask for MIPI_DSI_PLLCTRL_DPDNSWAP_CLK. */
#define BS_MIPI_DSI_PLLCTRL_DPDNSWAP_CLK (1U) /*!< Bit field size in bits for MIPI_DSI_PLLCTRL_DPDNSWAP_CLK. */

/*! @brief Read current value of the MIPI_DSI_PLLCTRL_DPDNSWAP_CLK field. */
#define BR_MIPI_DSI_PLLCTRL_DPDNSWAP_CLK(x) (HW_MIPI_DSI_PLLCTRL(x).B.DPDNSWAP_CLK)

/*! @brief Format value for bitfield MIPI_DSI_PLLCTRL_DPDNSWAP_CLK. */
#define BF_MIPI_DSI_PLLCTRL_DPDNSWAP_CLK(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PLLCTRL_DPDNSWAP_CLK) & BM_MIPI_DSI_PLLCTRL_DPDNSWAP_CLK)

/*! @brief Set the DPDNSWAP_CLK field to a new value. */
#define BW_MIPI_DSI_PLLCTRL_DPDNSWAP_CLK(x, v) (HW_MIPI_DSI_PLLCTRL_WR(x, (HW_MIPI_DSI_PLLCTRL_RD(x) & ~BM_MIPI_DSI_PLLCTRL_DPDNSWAP_CLK) | BF_MIPI_DSI_PLLCTRL_DPDNSWAP_CLK(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_PLLCTRL1 - PLL Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_PLLCTRL1 - PLL Control Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register configures D-PHY PLL control (M_PLLCTL[31:0]).
 */
typedef union _hw_mipi_dsi_pllctrl1
{
    uint32_t U;
    struct _hw_mipi_dsi_pllctrl1_bitfields
    {
        uint32_t M_PLLCTL0 : 32;       /*!< [31:0]  */
    } B;
} hw_mipi_dsi_pllctrl1_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_PLLCTRL1 register
 */
/*@{*/
#define HW_MIPI_DSI_PLLCTRL1_ADDR(x) ((uintptr_t)(x) + 0x98U)

#define HW_MIPI_DSI_PLLCTRL1(x)  (*(__IO hw_mipi_dsi_pllctrl1_t *) HW_MIPI_DSI_PLLCTRL1_ADDR(x))
#define HW_MIPI_DSI_PLLCTRL1_RD(x) (HW_MIPI_DSI_PLLCTRL1(x).U)
#define HW_MIPI_DSI_PLLCTRL1_WR(x, v) (HW_MIPI_DSI_PLLCTRL1(x).U = (v))
#define HW_MIPI_DSI_PLLCTRL1_SET(x, v) (HW_MIPI_DSI_PLLCTRL1_WR(x, HW_MIPI_DSI_PLLCTRL1_RD(x) |  (v)))
#define HW_MIPI_DSI_PLLCTRL1_CLR(x, v) (HW_MIPI_DSI_PLLCTRL1_WR(x, HW_MIPI_DSI_PLLCTRL1_RD(x) & ~(v)))
#define HW_MIPI_DSI_PLLCTRL1_TOG(x, v) (HW_MIPI_DSI_PLLCTRL1_WR(x, HW_MIPI_DSI_PLLCTRL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_PLLCTRL1 bitfields
 */

/*!
 * @name Register MIPI_DSI_PLLCTRL1, field M_PLLCTL0[31:0] (RW)
 *
 * M_PLLCTL[31:0] to D-PHY
 */
/*@{*/
#define BP_MIPI_DSI_PLLCTRL1_M_PLLCTL0 (0U) /*!< Bit position for MIPI_DSI_PLLCTRL1_M_PLLCTL0. */
#define BM_MIPI_DSI_PLLCTRL1_M_PLLCTL0 (0xFFFFFFFFU) /*!< Bit mask for MIPI_DSI_PLLCTRL1_M_PLLCTL0. */
#define BS_MIPI_DSI_PLLCTRL1_M_PLLCTL0 (32U) /*!< Bit field size in bits for MIPI_DSI_PLLCTRL1_M_PLLCTL0. */

/*! @brief Read current value of the MIPI_DSI_PLLCTRL1_M_PLLCTL0 field. */
#define BR_MIPI_DSI_PLLCTRL1_M_PLLCTL0(x) (HW_MIPI_DSI_PLLCTRL1(x).U)

/*! @brief Format value for bitfield MIPI_DSI_PLLCTRL1_M_PLLCTL0. */
#define BF_MIPI_DSI_PLLCTRL1_M_PLLCTL0(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PLLCTRL1_M_PLLCTL0) & BM_MIPI_DSI_PLLCTRL1_M_PLLCTL0)

/*! @brief Set the M_PLLCTL0 field to a new value. */
#define BW_MIPI_DSI_PLLCTRL1_M_PLLCTL0(x, v) (HW_MIPI_DSI_PLLCTRL1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_PLLCTRL2 - PLL control register 2
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_PLLCTRL2 - PLL control register 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register configures D-PHY PLL control (M_PLLCTL[39:32]).
 */
typedef union _hw_mipi_dsi_pllctrl2
{
    uint32_t U;
    struct _hw_mipi_dsi_pllctrl2_bitfields
    {
        uint32_t M_PLLCTL1 : 8;        /*!< [7:0]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_mipi_dsi_pllctrl2_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_PLLCTRL2 register
 */
/*@{*/
#define HW_MIPI_DSI_PLLCTRL2_ADDR(x) ((uintptr_t)(x) + 0x9CU)

#define HW_MIPI_DSI_PLLCTRL2(x)  (*(__IO hw_mipi_dsi_pllctrl2_t *) HW_MIPI_DSI_PLLCTRL2_ADDR(x))
#define HW_MIPI_DSI_PLLCTRL2_RD(x) (HW_MIPI_DSI_PLLCTRL2(x).U)
#define HW_MIPI_DSI_PLLCTRL2_WR(x, v) (HW_MIPI_DSI_PLLCTRL2(x).U = (v))
#define HW_MIPI_DSI_PLLCTRL2_SET(x, v) (HW_MIPI_DSI_PLLCTRL2_WR(x, HW_MIPI_DSI_PLLCTRL2_RD(x) |  (v)))
#define HW_MIPI_DSI_PLLCTRL2_CLR(x, v) (HW_MIPI_DSI_PLLCTRL2_WR(x, HW_MIPI_DSI_PLLCTRL2_RD(x) & ~(v)))
#define HW_MIPI_DSI_PLLCTRL2_TOG(x, v) (HW_MIPI_DSI_PLLCTRL2_WR(x, HW_MIPI_DSI_PLLCTRL2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_PLLCTRL2 bitfields
 */

/*!
 * @name Register MIPI_DSI_PLLCTRL2, field M_PLLCTL1[7:0] (RW)
 *
 * M_PLLCTL[39:32] to D-PHY
 */
/*@{*/
#define BP_MIPI_DSI_PLLCTRL2_M_PLLCTL1 (0U) /*!< Bit position for MIPI_DSI_PLLCTRL2_M_PLLCTL1. */
#define BM_MIPI_DSI_PLLCTRL2_M_PLLCTL1 (0x000000FFU) /*!< Bit mask for MIPI_DSI_PLLCTRL2_M_PLLCTL1. */
#define BS_MIPI_DSI_PLLCTRL2_M_PLLCTL1 (8U) /*!< Bit field size in bits for MIPI_DSI_PLLCTRL2_M_PLLCTL1. */

/*! @brief Read current value of the MIPI_DSI_PLLCTRL2_M_PLLCTL1 field. */
#define BR_MIPI_DSI_PLLCTRL2_M_PLLCTL1(x) (HW_MIPI_DSI_PLLCTRL2(x).B.M_PLLCTL1)

/*! @brief Format value for bitfield MIPI_DSI_PLLCTRL2_M_PLLCTL1. */
#define BF_MIPI_DSI_PLLCTRL2_M_PLLCTL1(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PLLCTRL2_M_PLLCTL1) & BM_MIPI_DSI_PLLCTRL2_M_PLLCTL1)

/*! @brief Set the M_PLLCTL1 field to a new value. */
#define BW_MIPI_DSI_PLLCTRL2_M_PLLCTL1(x, v) (HW_MIPI_DSI_PLLCTRL2_WR(x, (HW_MIPI_DSI_PLLCTRL2_RD(x) & ~BM_MIPI_DSI_PLLCTRL2_M_PLLCTL1) | BF_MIPI_DSI_PLLCTRL2_M_PLLCTL1(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_PLLTMR - PLL Timer Register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_PLLTMR - PLL Timer Register (RW)
 *
 * Reset value: 0xFFFFFFFFU
 */
typedef union _hw_mipi_dsi_plltmr
{
    uint32_t U;
    struct _hw_mipi_dsi_plltmr_bitfields
    {
        uint32_t PLLTIMER : 32;        /*!< [31:0]  */
    } B;
} hw_mipi_dsi_plltmr_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_PLLTMR register
 */
/*@{*/
#define HW_MIPI_DSI_PLLTMR_ADDR(x) ((uintptr_t)(x) + 0xA0U)

#define HW_MIPI_DSI_PLLTMR(x)    (*(__IO hw_mipi_dsi_plltmr_t *) HW_MIPI_DSI_PLLTMR_ADDR(x))
#define HW_MIPI_DSI_PLLTMR_RD(x) (HW_MIPI_DSI_PLLTMR(x).U)
#define HW_MIPI_DSI_PLLTMR_WR(x, v) (HW_MIPI_DSI_PLLTMR(x).U = (v))
#define HW_MIPI_DSI_PLLTMR_SET(x, v) (HW_MIPI_DSI_PLLTMR_WR(x, HW_MIPI_DSI_PLLTMR_RD(x) |  (v)))
#define HW_MIPI_DSI_PLLTMR_CLR(x, v) (HW_MIPI_DSI_PLLTMR_WR(x, HW_MIPI_DSI_PLLTMR_RD(x) & ~(v)))
#define HW_MIPI_DSI_PLLTMR_TOG(x, v) (HW_MIPI_DSI_PLLTMR_WR(x, HW_MIPI_DSI_PLLTMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_PLLTMR bitfields
 */

/*!
 * @name Register MIPI_DSI_PLLTMR, field PLLTIMER[31:0] (RW)
 *
 * Specifies the PLL Timer for stability of the generated clock (System clock
 * cycle base). If the timer value goes to 0x00000000, the clock stable bit of
 * status and interrupt register is set.
 */
/*@{*/
#define BP_MIPI_DSI_PLLTMR_PLLTIMER (0U)   /*!< Bit position for MIPI_DSI_PLLTMR_PLLTIMER. */
#define BM_MIPI_DSI_PLLTMR_PLLTIMER (0xFFFFFFFFU) /*!< Bit mask for MIPI_DSI_PLLTMR_PLLTIMER. */
#define BS_MIPI_DSI_PLLTMR_PLLTIMER (32U)  /*!< Bit field size in bits for MIPI_DSI_PLLTMR_PLLTIMER. */

/*! @brief Read current value of the MIPI_DSI_PLLTMR_PLLTIMER field. */
#define BR_MIPI_DSI_PLLTMR_PLLTIMER(x) (HW_MIPI_DSI_PLLTMR(x).U)

/*! @brief Format value for bitfield MIPI_DSI_PLLTMR_PLLTIMER. */
#define BF_MIPI_DSI_PLLTMR_PLLTIMER(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PLLTMR_PLLTIMER) & BM_MIPI_DSI_PLLTMR_PLLTIMER)

/*! @brief Set the PLLTIMER field to a new value. */
#define BW_MIPI_DSI_PLLTMR_PLLTIMER(x, v) (HW_MIPI_DSI_PLLTMR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_PHYCTRL_B1 - D-PHY Master and Slave Analog Block Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_PHYCTRL_B1 - D-PHY Master and Slave Analog Block Control Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * D-PHY Master and Slave Analog block characteristics control registers
 * (B_DPHYCTL).
 */
typedef union _hw_mipi_dsi_phyctrl_b1
{
    uint32_t U;
    struct _hw_mipi_dsi_phyctrl_b1_bitfields
    {
        uint32_t B_DPHYCTL0 : 32;      /*!< [31:0]  */
    } B;
} hw_mipi_dsi_phyctrl_b1_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_PHYCTRL_B1 register
 */
/*@{*/
#define HW_MIPI_DSI_PHYCTRL_B1_ADDR(x) ((uintptr_t)(x) + 0xA4U)

#define HW_MIPI_DSI_PHYCTRL_B1(x) (*(__IO hw_mipi_dsi_phyctrl_b1_t *) HW_MIPI_DSI_PHYCTRL_B1_ADDR(x))
#define HW_MIPI_DSI_PHYCTRL_B1_RD(x) (HW_MIPI_DSI_PHYCTRL_B1(x).U)
#define HW_MIPI_DSI_PHYCTRL_B1_WR(x, v) (HW_MIPI_DSI_PHYCTRL_B1(x).U = (v))
#define HW_MIPI_DSI_PHYCTRL_B1_SET(x, v) (HW_MIPI_DSI_PHYCTRL_B1_WR(x, HW_MIPI_DSI_PHYCTRL_B1_RD(x) |  (v)))
#define HW_MIPI_DSI_PHYCTRL_B1_CLR(x, v) (HW_MIPI_DSI_PHYCTRL_B1_WR(x, HW_MIPI_DSI_PHYCTRL_B1_RD(x) & ~(v)))
#define HW_MIPI_DSI_PHYCTRL_B1_TOG(x, v) (HW_MIPI_DSI_PHYCTRL_B1_WR(x, HW_MIPI_DSI_PHYCTRL_B1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_PHYCTRL_B1 bitfields
 */

/*!
 * @name Register MIPI_DSI_PHYCTRL_B1, field B_DPHYCTL0[31:0] (RW)
 *
 * B_DPHYCTL[31:0] to D-PHY
 */
/*@{*/
#define BP_MIPI_DSI_PHYCTRL_B1_B_DPHYCTL0 (0U) /*!< Bit position for MIPI_DSI_PHYCTRL_B1_B_DPHYCTL0. */
#define BM_MIPI_DSI_PHYCTRL_B1_B_DPHYCTL0 (0xFFFFFFFFU) /*!< Bit mask for MIPI_DSI_PHYCTRL_B1_B_DPHYCTL0. */
#define BS_MIPI_DSI_PHYCTRL_B1_B_DPHYCTL0 (32U) /*!< Bit field size in bits for MIPI_DSI_PHYCTRL_B1_B_DPHYCTL0. */

/*! @brief Read current value of the MIPI_DSI_PHYCTRL_B1_B_DPHYCTL0 field. */
#define BR_MIPI_DSI_PHYCTRL_B1_B_DPHYCTL0(x) (HW_MIPI_DSI_PHYCTRL_B1(x).U)

/*! @brief Format value for bitfield MIPI_DSI_PHYCTRL_B1_B_DPHYCTL0. */
#define BF_MIPI_DSI_PHYCTRL_B1_B_DPHYCTL0(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PHYCTRL_B1_B_DPHYCTL0) & BM_MIPI_DSI_PHYCTRL_B1_B_DPHYCTL0)

/*! @brief Set the B_DPHYCTL0 field to a new value. */
#define BW_MIPI_DSI_PHYCTRL_B1_B_DPHYCTL0(x, v) (HW_MIPI_DSI_PHYCTRL_B1_WR(x, v))
/*@}*/
/*******************************************************************************
 * HW_MIPI_DSI_PHYCTRL_B2 - D-PHY Master and Slave Analog Block Control Register 2
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_PHYCTRL_B2 - D-PHY Master and Slave Analog Block Control Register 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * D-PHY Master and Slave Analog block characteristics control registers
 * (B_DPHYCTL).
 */
typedef union _hw_mipi_dsi_phyctrl_b2
{
    uint32_t U;
    struct _hw_mipi_dsi_phyctrl_b2_bitfields
    {
        uint32_t B_DPHYCTL1 : 32;      /*!< [31:0]  */
    } B;
} hw_mipi_dsi_phyctrl_b2_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_PHYCTRL_B2 register
 */
/*@{*/
#define HW_MIPI_DSI_PHYCTRL_B2_ADDR(x) ((uintptr_t)(x) + 0xA8U)

#define HW_MIPI_DSI_PHYCTRL_B2(x) (*(__IO hw_mipi_dsi_phyctrl_b2_t *) HW_MIPI_DSI_PHYCTRL_B2_ADDR(x))
#define HW_MIPI_DSI_PHYCTRL_B2_RD(x) (HW_MIPI_DSI_PHYCTRL_B2(x).U)
#define HW_MIPI_DSI_PHYCTRL_B2_WR(x, v) (HW_MIPI_DSI_PHYCTRL_B2(x).U = (v))
#define HW_MIPI_DSI_PHYCTRL_B2_SET(x, v) (HW_MIPI_DSI_PHYCTRL_B2_WR(x, HW_MIPI_DSI_PHYCTRL_B2_RD(x) |  (v)))
#define HW_MIPI_DSI_PHYCTRL_B2_CLR(x, v) (HW_MIPI_DSI_PHYCTRL_B2_WR(x, HW_MIPI_DSI_PHYCTRL_B2_RD(x) & ~(v)))
#define HW_MIPI_DSI_PHYCTRL_B2_TOG(x, v) (HW_MIPI_DSI_PHYCTRL_B2_WR(x, HW_MIPI_DSI_PHYCTRL_B2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_PHYCTRL_B2 bitfields
 */

/*!
 * @name Register MIPI_DSI_PHYCTRL_B2, field B_DPHYCTL1[31:0] (RW)
 *
 * B_DPHYCTL[63:32] to D-PHY
 */
/*@{*/
#define BP_MIPI_DSI_PHYCTRL_B2_B_DPHYCTL1 (0U) /*!< Bit position for MIPI_DSI_PHYCTRL_B2_B_DPHYCTL1. */
#define BM_MIPI_DSI_PHYCTRL_B2_B_DPHYCTL1 (0xFFFFFFFFU) /*!< Bit mask for MIPI_DSI_PHYCTRL_B2_B_DPHYCTL1. */
#define BS_MIPI_DSI_PHYCTRL_B2_B_DPHYCTL1 (32U) /*!< Bit field size in bits for MIPI_DSI_PHYCTRL_B2_B_DPHYCTL1. */

/*! @brief Read current value of the MIPI_DSI_PHYCTRL_B2_B_DPHYCTL1 field. */
#define BR_MIPI_DSI_PHYCTRL_B2_B_DPHYCTL1(x) (HW_MIPI_DSI_PHYCTRL_B2(x).U)

/*! @brief Format value for bitfield MIPI_DSI_PHYCTRL_B2_B_DPHYCTL1. */
#define BF_MIPI_DSI_PHYCTRL_B2_B_DPHYCTL1(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PHYCTRL_B2_B_DPHYCTL1) & BM_MIPI_DSI_PHYCTRL_B2_B_DPHYCTL1)

/*! @brief Set the B_DPHYCTL1 field to a new value. */
#define BW_MIPI_DSI_PHYCTRL_B2_B_DPHYCTL1(x, v) (HW_MIPI_DSI_PHYCTRL_B2_WR(x, v))
/*@}*/
/*******************************************************************************
 * HW_MIPI_DSI_PHYCTRL_M1 - D-PHY Master Analog Block Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_PHYCTRL_M1 - D-PHY Master Analog Block Control Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * D-PHY Master Analog block characteristics control registers (M_DPHYCTL).
 */
typedef union _hw_mipi_dsi_phyctrl_m1
{
    uint32_t U;
    struct _hw_mipi_dsi_phyctrl_m1_bitfields
    {
        uint32_t M_DPHYCTL0 : 32;      /*!< [31:0]  */
    } B;
} hw_mipi_dsi_phyctrl_m1_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_PHYCTRL_M1 register
 */
/*@{*/
#define HW_MIPI_DSI_PHYCTRL_M1_ADDR(x) ((uintptr_t)(x) + 0xACU)

#define HW_MIPI_DSI_PHYCTRL_M1(x) (*(__IO hw_mipi_dsi_phyctrl_m1_t *) HW_MIPI_DSI_PHYCTRL_M1_ADDR(x))
#define HW_MIPI_DSI_PHYCTRL_M1_RD(x) (HW_MIPI_DSI_PHYCTRL_M1(x).U)
#define HW_MIPI_DSI_PHYCTRL_M1_WR(x, v) (HW_MIPI_DSI_PHYCTRL_M1(x).U = (v))
#define HW_MIPI_DSI_PHYCTRL_M1_SET(x, v) (HW_MIPI_DSI_PHYCTRL_M1_WR(x, HW_MIPI_DSI_PHYCTRL_M1_RD(x) |  (v)))
#define HW_MIPI_DSI_PHYCTRL_M1_CLR(x, v) (HW_MIPI_DSI_PHYCTRL_M1_WR(x, HW_MIPI_DSI_PHYCTRL_M1_RD(x) & ~(v)))
#define HW_MIPI_DSI_PHYCTRL_M1_TOG(x, v) (HW_MIPI_DSI_PHYCTRL_M1_WR(x, HW_MIPI_DSI_PHYCTRL_M1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_PHYCTRL_M1 bitfields
 */

/*!
 * @name Register MIPI_DSI_PHYCTRL_M1, field M_DPHYCTL0[31:0] (RW)
 *
 * M_DPHYCTL[31:0] to D-PHY
 */
/*@{*/
#define BP_MIPI_DSI_PHYCTRL_M1_M_DPHYCTL0 (0U) /*!< Bit position for MIPI_DSI_PHYCTRL_M1_M_DPHYCTL0. */
#define BM_MIPI_DSI_PHYCTRL_M1_M_DPHYCTL0 (0xFFFFFFFFU) /*!< Bit mask for MIPI_DSI_PHYCTRL_M1_M_DPHYCTL0. */
#define BS_MIPI_DSI_PHYCTRL_M1_M_DPHYCTL0 (32U) /*!< Bit field size in bits for MIPI_DSI_PHYCTRL_M1_M_DPHYCTL0. */

/*! @brief Read current value of the MIPI_DSI_PHYCTRL_M1_M_DPHYCTL0 field. */
#define BR_MIPI_DSI_PHYCTRL_M1_M_DPHYCTL0(x) (HW_MIPI_DSI_PHYCTRL_M1(x).U)

/*! @brief Format value for bitfield MIPI_DSI_PHYCTRL_M1_M_DPHYCTL0. */
#define BF_MIPI_DSI_PHYCTRL_M1_M_DPHYCTL0(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PHYCTRL_M1_M_DPHYCTL0) & BM_MIPI_DSI_PHYCTRL_M1_M_DPHYCTL0)

/*! @brief Set the M_DPHYCTL0 field to a new value. */
#define BW_MIPI_DSI_PHYCTRL_M1_M_DPHYCTL0(x, v) (HW_MIPI_DSI_PHYCTRL_M1_WR(x, v))
/*@}*/
/*******************************************************************************
 * HW_MIPI_DSI_PHYCTRL_M2 - D-PHY Master Analog Block Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_PHYCTRL_M2 - D-PHY Master Analog Block Control Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * D-PHY Master Analog block characteristics control registers (M_DPHYCTL).
 */
typedef union _hw_mipi_dsi_phyctrl_m2
{
    uint32_t U;
    struct _hw_mipi_dsi_phyctrl_m2_bitfields
    {
        uint32_t M_DPHYCTL1 : 32;      /*!< [31:0]  */
    } B;
} hw_mipi_dsi_phyctrl_m2_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_PHYCTRL_M2 register
 */
/*@{*/
#define HW_MIPI_DSI_PHYCTRL_M2_ADDR(x) ((uintptr_t)(x) + 0xB0U)

#define HW_MIPI_DSI_PHYCTRL_M2(x) (*(__IO hw_mipi_dsi_phyctrl_m2_t *) HW_MIPI_DSI_PHYCTRL_M2_ADDR(x))
#define HW_MIPI_DSI_PHYCTRL_M2_RD(x) (HW_MIPI_DSI_PHYCTRL_M2(x).U)
#define HW_MIPI_DSI_PHYCTRL_M2_WR(x, v) (HW_MIPI_DSI_PHYCTRL_M2(x).U = (v))
#define HW_MIPI_DSI_PHYCTRL_M2_SET(x, v) (HW_MIPI_DSI_PHYCTRL_M2_WR(x, HW_MIPI_DSI_PHYCTRL_M2_RD(x) |  (v)))
#define HW_MIPI_DSI_PHYCTRL_M2_CLR(x, v) (HW_MIPI_DSI_PHYCTRL_M2_WR(x, HW_MIPI_DSI_PHYCTRL_M2_RD(x) & ~(v)))
#define HW_MIPI_DSI_PHYCTRL_M2_TOG(x, v) (HW_MIPI_DSI_PHYCTRL_M2_WR(x, HW_MIPI_DSI_PHYCTRL_M2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_PHYCTRL_M2 bitfields
 */

/*!
 * @name Register MIPI_DSI_PHYCTRL_M2, field M_DPHYCTL1[31:0] (RW)
 *
 * M_DPHYCTL[63:32] to D-PHY
 */
/*@{*/
#define BP_MIPI_DSI_PHYCTRL_M2_M_DPHYCTL1 (0U) /*!< Bit position for MIPI_DSI_PHYCTRL_M2_M_DPHYCTL1. */
#define BM_MIPI_DSI_PHYCTRL_M2_M_DPHYCTL1 (0xFFFFFFFFU) /*!< Bit mask for MIPI_DSI_PHYCTRL_M2_M_DPHYCTL1. */
#define BS_MIPI_DSI_PHYCTRL_M2_M_DPHYCTL1 (32U) /*!< Bit field size in bits for MIPI_DSI_PHYCTRL_M2_M_DPHYCTL1. */

/*! @brief Read current value of the MIPI_DSI_PHYCTRL_M2_M_DPHYCTL1 field. */
#define BR_MIPI_DSI_PHYCTRL_M2_M_DPHYCTL1(x) (HW_MIPI_DSI_PHYCTRL_M2(x).U)

/*! @brief Format value for bitfield MIPI_DSI_PHYCTRL_M2_M_DPHYCTL1. */
#define BF_MIPI_DSI_PHYCTRL_M2_M_DPHYCTL1(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PHYCTRL_M2_M_DPHYCTL1) & BM_MIPI_DSI_PHYCTRL_M2_M_DPHYCTL1)

/*! @brief Set the M_DPHYCTL1 field to a new value. */
#define BW_MIPI_DSI_PHYCTRL_M2_M_DPHYCTL1(x, v) (HW_MIPI_DSI_PHYCTRL_M2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_PHYTIMING - D-PHY Timing register
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_PHYTIMING - D-PHY Timing register (RW)
 *
 * Reset value: 0x00000000U
 *
 * D-PHY Master global operating timing registers
 */
typedef union _hw_mipi_dsi_phytiming
{
    uint32_t U;
    struct _hw_mipi_dsi_phytiming_bitfields
    {
        uint32_t M_THSEXITCTL : 8;     /*!< [7:0]  */
        uint32_t M_TLPXCTL : 8;        /*!< [15:8]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_mipi_dsi_phytiming_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_PHYTIMING register
 */
/*@{*/
#define HW_MIPI_DSI_PHYTIMING_ADDR(x) ((uintptr_t)(x) + 0xB4U)

#define HW_MIPI_DSI_PHYTIMING(x) (*(__IO hw_mipi_dsi_phytiming_t *) HW_MIPI_DSI_PHYTIMING_ADDR(x))
#define HW_MIPI_DSI_PHYTIMING_RD(x) (HW_MIPI_DSI_PHYTIMING(x).U)
#define HW_MIPI_DSI_PHYTIMING_WR(x, v) (HW_MIPI_DSI_PHYTIMING(x).U = (v))
#define HW_MIPI_DSI_PHYTIMING_SET(x, v) (HW_MIPI_DSI_PHYTIMING_WR(x, HW_MIPI_DSI_PHYTIMING_RD(x) |  (v)))
#define HW_MIPI_DSI_PHYTIMING_CLR(x, v) (HW_MIPI_DSI_PHYTIMING_WR(x, HW_MIPI_DSI_PHYTIMING_RD(x) & ~(v)))
#define HW_MIPI_DSI_PHYTIMING_TOG(x, v) (HW_MIPI_DSI_PHYTIMING_WR(x, HW_MIPI_DSI_PHYTIMING_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_PHYTIMING bitfields
 */

/*!
 * @name Register MIPI_DSI_PHYTIMING, field M_THSEXITCTL[7:0] (RW)
 *
 * M_THSEXITCTL[7:0] to D-PHY
 */
/*@{*/
#define BP_MIPI_DSI_PHYTIMING_M_THSEXITCTL (0U) /*!< Bit position for MIPI_DSI_PHYTIMING_M_THSEXITCTL. */
#define BM_MIPI_DSI_PHYTIMING_M_THSEXITCTL (0x000000FFU) /*!< Bit mask for MIPI_DSI_PHYTIMING_M_THSEXITCTL. */
#define BS_MIPI_DSI_PHYTIMING_M_THSEXITCTL (8U) /*!< Bit field size in bits for MIPI_DSI_PHYTIMING_M_THSEXITCTL. */

/*! @brief Read current value of the MIPI_DSI_PHYTIMING_M_THSEXITCTL field. */
#define BR_MIPI_DSI_PHYTIMING_M_THSEXITCTL(x) (HW_MIPI_DSI_PHYTIMING(x).B.M_THSEXITCTL)

/*! @brief Format value for bitfield MIPI_DSI_PHYTIMING_M_THSEXITCTL. */
#define BF_MIPI_DSI_PHYTIMING_M_THSEXITCTL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PHYTIMING_M_THSEXITCTL) & BM_MIPI_DSI_PHYTIMING_M_THSEXITCTL)

/*! @brief Set the M_THSEXITCTL field to a new value. */
#define BW_MIPI_DSI_PHYTIMING_M_THSEXITCTL(x, v) (HW_MIPI_DSI_PHYTIMING_WR(x, (HW_MIPI_DSI_PHYTIMING_RD(x) & ~BM_MIPI_DSI_PHYTIMING_M_THSEXITCTL) | BF_MIPI_DSI_PHYTIMING_M_THSEXITCTL(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_PHYTIMING, field M_TLPXCTL[15:8] (RW)
 *
 * M_TLPXCTL[7:0] to D-PHY
 */
/*@{*/
#define BP_MIPI_DSI_PHYTIMING_M_TLPXCTL (8U) /*!< Bit position for MIPI_DSI_PHYTIMING_M_TLPXCTL. */
#define BM_MIPI_DSI_PHYTIMING_M_TLPXCTL (0x0000FF00U) /*!< Bit mask for MIPI_DSI_PHYTIMING_M_TLPXCTL. */
#define BS_MIPI_DSI_PHYTIMING_M_TLPXCTL (8U) /*!< Bit field size in bits for MIPI_DSI_PHYTIMING_M_TLPXCTL. */

/*! @brief Read current value of the MIPI_DSI_PHYTIMING_M_TLPXCTL field. */
#define BR_MIPI_DSI_PHYTIMING_M_TLPXCTL(x) (HW_MIPI_DSI_PHYTIMING(x).B.M_TLPXCTL)

/*! @brief Format value for bitfield MIPI_DSI_PHYTIMING_M_TLPXCTL. */
#define BF_MIPI_DSI_PHYTIMING_M_TLPXCTL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PHYTIMING_M_TLPXCTL) & BM_MIPI_DSI_PHYTIMING_M_TLPXCTL)

/*! @brief Set the M_TLPXCTL field to a new value. */
#define BW_MIPI_DSI_PHYTIMING_M_TLPXCTL(x, v) (HW_MIPI_DSI_PHYTIMING_WR(x, (HW_MIPI_DSI_PHYTIMING_RD(x) & ~BM_MIPI_DSI_PHYTIMING_M_TLPXCTL) | BF_MIPI_DSI_PHYTIMING_M_TLPXCTL(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_PHYTIMING1 -
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_PHYTIMING1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * D-PHY Master global operating timing registers.
 */
typedef union _hw_mipi_dsi_phytiming1
{
    uint32_t U;
    struct _hw_mipi_dsi_phytiming1_bitfields
    {
        uint32_t M_TCLKTRAILCTL : 8;   /*!< [7:0]  */
        uint32_t M_TCLKPOSTCTL : 8;    /*!< [15:8]  */
        uint32_t M_TCLKZEROCTL : 8;    /*!< [23:16]  */
        uint32_t M_TCLKPRPRCTL : 8;    /*!< [31:24]  */
    } B;
} hw_mipi_dsi_phytiming1_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_PHYTIMING1 register
 */
/*@{*/
#define HW_MIPI_DSI_PHYTIMING1_ADDR(x) ((uintptr_t)(x) + 0xB8U)

#define HW_MIPI_DSI_PHYTIMING1(x) (*(__IO hw_mipi_dsi_phytiming1_t *) HW_MIPI_DSI_PHYTIMING1_ADDR(x))
#define HW_MIPI_DSI_PHYTIMING1_RD(x) (HW_MIPI_DSI_PHYTIMING1(x).U)
#define HW_MIPI_DSI_PHYTIMING1_WR(x, v) (HW_MIPI_DSI_PHYTIMING1(x).U = (v))
#define HW_MIPI_DSI_PHYTIMING1_SET(x, v) (HW_MIPI_DSI_PHYTIMING1_WR(x, HW_MIPI_DSI_PHYTIMING1_RD(x) |  (v)))
#define HW_MIPI_DSI_PHYTIMING1_CLR(x, v) (HW_MIPI_DSI_PHYTIMING1_WR(x, HW_MIPI_DSI_PHYTIMING1_RD(x) & ~(v)))
#define HW_MIPI_DSI_PHYTIMING1_TOG(x, v) (HW_MIPI_DSI_PHYTIMING1_WR(x, HW_MIPI_DSI_PHYTIMING1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_PHYTIMING1 bitfields
 */

/*!
 * @name Register MIPI_DSI_PHYTIMING1, field M_TCLKTRAILCTL[7:0] (RW)
 *
 * M_TCLKTRAILCTL[7:0] to D-PHY
 */
/*@{*/
#define BP_MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL (0U) /*!< Bit position for MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL. */
#define BM_MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL (0x000000FFU) /*!< Bit mask for MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL. */
#define BS_MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL (8U) /*!< Bit field size in bits for MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL. */

/*! @brief Read current value of the MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL field. */
#define BR_MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL(x) (HW_MIPI_DSI_PHYTIMING1(x).B.M_TCLKTRAILCTL)

/*! @brief Format value for bitfield MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL. */
#define BF_MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL) & BM_MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL)

/*! @brief Set the M_TCLKTRAILCTL field to a new value. */
#define BW_MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL(x, v) (HW_MIPI_DSI_PHYTIMING1_WR(x, (HW_MIPI_DSI_PHYTIMING1_RD(x) & ~BM_MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL) | BF_MIPI_DSI_PHYTIMING1_M_TCLKTRAILCTL(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_PHYTIMING1, field M_TCLKPOSTCTL[15:8] (RW)
 *
 * M_TCLKPOSTCTL[7:0] to D-PHY
 */
/*@{*/
#define BP_MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL (8U) /*!< Bit position for MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL. */
#define BM_MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL (0x0000FF00U) /*!< Bit mask for MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL. */
#define BS_MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL (8U) /*!< Bit field size in bits for MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL. */

/*! @brief Read current value of the MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL field. */
#define BR_MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL(x) (HW_MIPI_DSI_PHYTIMING1(x).B.M_TCLKPOSTCTL)

/*! @brief Format value for bitfield MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL. */
#define BF_MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL) & BM_MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL)

/*! @brief Set the M_TCLKPOSTCTL field to a new value. */
#define BW_MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL(x, v) (HW_MIPI_DSI_PHYTIMING1_WR(x, (HW_MIPI_DSI_PHYTIMING1_RD(x) & ~BM_MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL) | BF_MIPI_DSI_PHYTIMING1_M_TCLKPOSTCTL(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_PHYTIMING1, field M_TCLKZEROCTL[23:16] (RW)
 *
 * M_TCLKZEROCTL[7:0] to D-PHY
 */
/*@{*/
#define BP_MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL (16U) /*!< Bit position for MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL. */
#define BM_MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL (0x00FF0000U) /*!< Bit mask for MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL. */
#define BS_MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL (8U) /*!< Bit field size in bits for MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL. */

/*! @brief Read current value of the MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL field. */
#define BR_MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL(x) (HW_MIPI_DSI_PHYTIMING1(x).B.M_TCLKZEROCTL)

/*! @brief Format value for bitfield MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL. */
#define BF_MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL) & BM_MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL)

/*! @brief Set the M_TCLKZEROCTL field to a new value. */
#define BW_MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL(x, v) (HW_MIPI_DSI_PHYTIMING1_WR(x, (HW_MIPI_DSI_PHYTIMING1_RD(x) & ~BM_MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL) | BF_MIPI_DSI_PHYTIMING1_M_TCLKZEROCTL(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_PHYTIMING1, field M_TCLKPRPRCTL[31:24] (RW)
 *
 * M_TCLKPRPRCTL[7:0] to D-PHY
 */
/*@{*/
#define BP_MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL (24U) /*!< Bit position for MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL. */
#define BM_MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL (0xFF000000U) /*!< Bit mask for MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL. */
#define BS_MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL (8U) /*!< Bit field size in bits for MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL. */

/*! @brief Read current value of the MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL field. */
#define BR_MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL(x) (HW_MIPI_DSI_PHYTIMING1(x).B.M_TCLKPRPRCTL)

/*! @brief Format value for bitfield MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL. */
#define BF_MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL) & BM_MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL)

/*! @brief Set the M_TCLKPRPRCTL field to a new value. */
#define BW_MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL(x, v) (HW_MIPI_DSI_PHYTIMING1_WR(x, (HW_MIPI_DSI_PHYTIMING1_RD(x) & ~BM_MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL) | BF_MIPI_DSI_PHYTIMING1_M_TCLKPRPRCTL(v)))
/*@}*/

/*******************************************************************************
 * HW_MIPI_DSI_PHYTIMING2 - D-PHY Timing Register 2
 ******************************************************************************/

/*!
 * @brief HW_MIPI_DSI_PHYTIMING2 - D-PHY Timing Register 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * D-PHY Master global operating timing registers
 */
typedef union _hw_mipi_dsi_phytiming2
{
    uint32_t U;
    struct _hw_mipi_dsi_phytiming2_bitfields
    {
        uint32_t M_THSTRAILCTL : 8;    /*!< [7:0]  */
        uint32_t M_THSZEROCTL : 8;     /*!< [15:8]  */
        uint32_t M_THSPRPRCTL : 8;     /*!< [23:16]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_mipi_dsi_phytiming2_t;

/*!
 * @name Constants and macros for entire MIPI_DSI_PHYTIMING2 register
 */
/*@{*/
#define HW_MIPI_DSI_PHYTIMING2_ADDR(x) ((uintptr_t)(x) + 0xBCU)

#define HW_MIPI_DSI_PHYTIMING2(x) (*(__IO hw_mipi_dsi_phytiming2_t *) HW_MIPI_DSI_PHYTIMING2_ADDR(x))
#define HW_MIPI_DSI_PHYTIMING2_RD(x) (HW_MIPI_DSI_PHYTIMING2(x).U)
#define HW_MIPI_DSI_PHYTIMING2_WR(x, v) (HW_MIPI_DSI_PHYTIMING2(x).U = (v))
#define HW_MIPI_DSI_PHYTIMING2_SET(x, v) (HW_MIPI_DSI_PHYTIMING2_WR(x, HW_MIPI_DSI_PHYTIMING2_RD(x) |  (v)))
#define HW_MIPI_DSI_PHYTIMING2_CLR(x, v) (HW_MIPI_DSI_PHYTIMING2_WR(x, HW_MIPI_DSI_PHYTIMING2_RD(x) & ~(v)))
#define HW_MIPI_DSI_PHYTIMING2_TOG(x, v) (HW_MIPI_DSI_PHYTIMING2_WR(x, HW_MIPI_DSI_PHYTIMING2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MIPI_DSI_PHYTIMING2 bitfields
 */

/*!
 * @name Register MIPI_DSI_PHYTIMING2, field M_THSTRAILCTL[7:0] (RW)
 *
 * M_THSTRAILCTL[7:0] to D-PHY
 */
/*@{*/
#define BP_MIPI_DSI_PHYTIMING2_M_THSTRAILCTL (0U) /*!< Bit position for MIPI_DSI_PHYTIMING2_M_THSTRAILCTL. */
#define BM_MIPI_DSI_PHYTIMING2_M_THSTRAILCTL (0x000000FFU) /*!< Bit mask for MIPI_DSI_PHYTIMING2_M_THSTRAILCTL. */
#define BS_MIPI_DSI_PHYTIMING2_M_THSTRAILCTL (8U) /*!< Bit field size in bits for MIPI_DSI_PHYTIMING2_M_THSTRAILCTL. */

/*! @brief Read current value of the MIPI_DSI_PHYTIMING2_M_THSTRAILCTL field. */
#define BR_MIPI_DSI_PHYTIMING2_M_THSTRAILCTL(x) (HW_MIPI_DSI_PHYTIMING2(x).B.M_THSTRAILCTL)

/*! @brief Format value for bitfield MIPI_DSI_PHYTIMING2_M_THSTRAILCTL. */
#define BF_MIPI_DSI_PHYTIMING2_M_THSTRAILCTL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PHYTIMING2_M_THSTRAILCTL) & BM_MIPI_DSI_PHYTIMING2_M_THSTRAILCTL)

/*! @brief Set the M_THSTRAILCTL field to a new value. */
#define BW_MIPI_DSI_PHYTIMING2_M_THSTRAILCTL(x, v) (HW_MIPI_DSI_PHYTIMING2_WR(x, (HW_MIPI_DSI_PHYTIMING2_RD(x) & ~BM_MIPI_DSI_PHYTIMING2_M_THSTRAILCTL) | BF_MIPI_DSI_PHYTIMING2_M_THSTRAILCTL(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_PHYTIMING2, field M_THSZEROCTL[15:8] (RW)
 *
 * M_THSZEROCTL[7:0] to D-PHY
 */
/*@{*/
#define BP_MIPI_DSI_PHYTIMING2_M_THSZEROCTL (8U) /*!< Bit position for MIPI_DSI_PHYTIMING2_M_THSZEROCTL. */
#define BM_MIPI_DSI_PHYTIMING2_M_THSZEROCTL (0x0000FF00U) /*!< Bit mask for MIPI_DSI_PHYTIMING2_M_THSZEROCTL. */
#define BS_MIPI_DSI_PHYTIMING2_M_THSZEROCTL (8U) /*!< Bit field size in bits for MIPI_DSI_PHYTIMING2_M_THSZEROCTL. */

/*! @brief Read current value of the MIPI_DSI_PHYTIMING2_M_THSZEROCTL field. */
#define BR_MIPI_DSI_PHYTIMING2_M_THSZEROCTL(x) (HW_MIPI_DSI_PHYTIMING2(x).B.M_THSZEROCTL)

/*! @brief Format value for bitfield MIPI_DSI_PHYTIMING2_M_THSZEROCTL. */
#define BF_MIPI_DSI_PHYTIMING2_M_THSZEROCTL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PHYTIMING2_M_THSZEROCTL) & BM_MIPI_DSI_PHYTIMING2_M_THSZEROCTL)

/*! @brief Set the M_THSZEROCTL field to a new value. */
#define BW_MIPI_DSI_PHYTIMING2_M_THSZEROCTL(x, v) (HW_MIPI_DSI_PHYTIMING2_WR(x, (HW_MIPI_DSI_PHYTIMING2_RD(x) & ~BM_MIPI_DSI_PHYTIMING2_M_THSZEROCTL) | BF_MIPI_DSI_PHYTIMING2_M_THSZEROCTL(v)))
/*@}*/

/*!
 * @name Register MIPI_DSI_PHYTIMING2, field M_THSPRPRCTL[23:16] (RW)
 *
 * M_THSPRPRCTL[7:0] to D-PHY
 */
/*@{*/
#define BP_MIPI_DSI_PHYTIMING2_M_THSPRPRCTL (16U) /*!< Bit position for MIPI_DSI_PHYTIMING2_M_THSPRPRCTL. */
#define BM_MIPI_DSI_PHYTIMING2_M_THSPRPRCTL (0x00FF0000U) /*!< Bit mask for MIPI_DSI_PHYTIMING2_M_THSPRPRCTL. */
#define BS_MIPI_DSI_PHYTIMING2_M_THSPRPRCTL (8U) /*!< Bit field size in bits for MIPI_DSI_PHYTIMING2_M_THSPRPRCTL. */

/*! @brief Read current value of the MIPI_DSI_PHYTIMING2_M_THSPRPRCTL field. */
#define BR_MIPI_DSI_PHYTIMING2_M_THSPRPRCTL(x) (HW_MIPI_DSI_PHYTIMING2(x).B.M_THSPRPRCTL)

/*! @brief Format value for bitfield MIPI_DSI_PHYTIMING2_M_THSPRPRCTL. */
#define BF_MIPI_DSI_PHYTIMING2_M_THSPRPRCTL(v) ((uint32_t)((uint32_t)(v) << BP_MIPI_DSI_PHYTIMING2_M_THSPRPRCTL) & BM_MIPI_DSI_PHYTIMING2_M_THSPRPRCTL)

/*! @brief Set the M_THSPRPRCTL field to a new value. */
#define BW_MIPI_DSI_PHYTIMING2_M_THSPRPRCTL(x, v) (HW_MIPI_DSI_PHYTIMING2_WR(x, (HW_MIPI_DSI_PHYTIMING2_RD(x) & ~BM_MIPI_DSI_PHYTIMING2_M_THSPRPRCTL) | BF_MIPI_DSI_PHYTIMING2_M_THSPRPRCTL(v)))
/*@}*/

/*
** Start of section using anonymous unions
*/

#if defined(__ARMCC_VERSION)
  #pragma push
  #pragma anon_unions
#elif defined(__GNUC__)
  /* anonymous unions are enabled by default */
#elif defined(__IAR_SYSTEMS_ICC__)
  #pragma language=extended
#else
  #error Not supported compiler type
#endif

/*******************************************************************************
 * hw_mipi_dsi_t - module struct
 ******************************************************************************/
/*!
 * @brief All MIPI_DSI module registers.
 */
#pragma pack(1)
typedef struct _hw_mipi_dsi
{
    __I hw_mipi_dsi_version_t VERSION;     /*!< [0x0] Version Register */
    __I hw_mipi_dsi_status_t STATUS;       /*!< [0x4]  */
    __I hw_mipi_dsi_rgb_status_t RGB_STATUS; /*!< [0x8] RGB Status Register */
    __IO hw_mipi_dsi_swrst_t SWRST;        /*!< [0xC]  */
    __IO hw_mipi_dsi_clkctrl_t CLKCTRL;    /*!< [0x10] Clock Control Register */
    __IO hw_mipi_dsi_timeout_t TIMEOUT;    /*!< [0x14]  */
    __IO hw_mipi_dsi_config_t CONFIG;      /*!< [0x18]  */
    __IO hw_mipi_dsi_escmode_t ESCMODE;    /*!< [0x1C] Escape Mode Register */
    __IO hw_mipi_dsi_mdresol_t MDRESOL;    /*!< [0x20] Main Display Image Resolution Register */
    __IO hw_mipi_dsi_mvporch_t MVPORCH;    /*!< [0x24] Main Display VPORCH Register */
    __IO hw_mipi_dsi_mhporch_t MHPORCH;    /*!< [0x28]  */
    __IO hw_mipi_dsi_msync_t MSYNC;        /*!< [0x2C]  */
    __IO hw_mipi_dsi_sdresol_t SDRESOL;    /*!< [0x30] Sub Display Image Resolution Register */
    __IO hw_mipi_dsi_intsrc_t INTSRC;      /*!< [0x34] Interrupt Source Register */
    __IO hw_mipi_dsi_intmsk_t INTMSK;      /*!< [0x38] Interrupt Mask Register */
    __IO hw_mipi_dsi_pkthdr_t PKTHDR;      /*!< [0x3C] Packet Header FIFO Register */
    __IO hw_mipi_dsi_payload_t PAYLOAD;    /*!< [0x40] Payload FIFO Register */
    __I hw_mipi_dsi_rxfifo_t RXFIFO;       /*!< [0x44] Payload FIFO Register */
    __IO hw_mipi_dsi_fifothld_t FIFOTHLD;  /*!< [0x48] FIFO Threshold Level Register */
    __IO hw_mipi_dsi_fifoctrl_t FIFOCTRL;  /*!< [0x4C] FIFO Status and Control Register */
    __IO hw_mipi_dsi_memacchr_t MEMACCHR;  /*!< [0x50] FIFO Memory AC Characteristic Register */
    uint8_t _reserved0[36];
    __IO hw_mipi_dsi_multi_pkt_t MULTI_PKT; /*!< [0x78]  */
    uint8_t _reserved1[20];
    __IO hw_mipi_dsi_pllctrl_1g_t PLLCTRL_1G; /*!< [0x90] 1 Gbps D-PHY PLL Control Register */
    __IO hw_mipi_dsi_pllctrl_t PLLCTRL;    /*!< [0x94] PLL Control register */
    __IO hw_mipi_dsi_pllctrl1_t PLLCTRL1;  /*!< [0x98] PLL Control Register 1 */
    __IO hw_mipi_dsi_pllctrl2_t PLLCTRL2;  /*!< [0x9C] PLL control register 2 */
    __IO hw_mipi_dsi_plltmr_t PLLTMR;      /*!< [0xA0] PLL Timer Register */
    union {
        struct {
            __IO hw_mipi_dsi_phyctrl_b1_t PHYCTRL_B1; /*!< [0xA4] D-PHY Master and Slave Analog Block Control Register 1 */
            __IO hw_mipi_dsi_phyctrl_b2_t PHYCTRL_B2; /*!< [0xA8] D-PHY Master and Slave Analog Block Control Register 2 */
        } PHYCTRL_B;
        struct {
            uint8_t _reserved0[8];
            __IO hw_mipi_dsi_phyctrl_m1_t PHYCTRL_M1; /*!< [0xAC] D-PHY Master Analog Block Control Register 1 */
            __IO hw_mipi_dsi_phyctrl_m2_t PHYCTRL_M2; /*!< [0xB0] D-PHY Master Analog Block Control Register 1 */
        } PHYCTRL_M;
    };
    __IO hw_mipi_dsi_phytiming_t PHYTIMING; /*!< [0xB4] D-PHY Timing register */
    __IO hw_mipi_dsi_phytiming1_t PHYTIMING1; /*!< [0xB8]  */
    __IO hw_mipi_dsi_phytiming2_t PHYTIMING2; /*!< [0xBC] D-PHY Timing Register 2 */
} hw_mipi_dsi_t;
#pragma pack()

/*! @brief Macro to access all MIPI_DSI registers. */
/*! @param x MIPI_DSI module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_MIPI_DSI_REGS(MIPI_DSI_BASE)</code>. */
#define HW_MIPI_DSI_REGS(x) (*(hw_mipi_dsi_t *)(x))

/*
** End of section using anonymous unions
*/

#if defined(__ARMCC_VERSION)
  #pragma pop
#elif defined(__GNUC__)
  /* leave anonymous unions enabled */
#elif defined(__IAR_SYSTEMS_ICC__)
  #pragma language=default
#else
  #error Not supported compiler type
#endif

/*
 * iMX7D MU
 *
 * MU
 *
 * Registers defined in this header file:
 * - HW_MU_ATR0 - Processor A Transmit Register 0
 * - HW_MU_ATR1 - Processor A Transmit Register 1
 * - HW_MU_ATR2 - Processor A Transmit Register 2
 * - HW_MU_ATR3 - Processor A Transmit Register 3
 * - HW_MU_ARR0 - Processor A Receive Register 0
 * - HW_MU_ARR1 - Processor A Receive Register 1
 * - HW_MU_ARR2 - Processor A Receive Register 2
 * - HW_MU_ARR3 - Processor A Receive Register 3
 * - HW_MU_ASR - Processor A Status Register
 * - HW_MU_ACR - Processor A Control Register
 *
 * - hw_mu_t - Struct containing all module registers.
 */

#define HW_MU_INSTANCE_COUNT (1U) /*!< Number of instances of the MU module. */
#define HW_MUA (0U) /*!< Instance number for MUA. */
#define MUA_BASE              (0x30AA0000U) /*!< Base address for MUA. */
/*! Array initializer of MU base addresses. */
#define MU_BASE_ADDRS         { MUA_BASE }

/*******************************************************************************
 * HW_MU_ATR0 - Processor A Transmit Register 0
 ******************************************************************************/

/*!
 * @brief HW_MU_ATR0 - Processor A Transmit Register 0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Use Processor A Transmit Register 0 (ATR0, 32-bit, write-only) to transmit a
 * message or data to the Processor B. You can only write to the ATR0 register
 * when the TE0 bit in ASR register is set to "1". Reading the ATR0 register
 * returns all zeros.
 */
typedef union _hw_mu_atr0
{
    uint32_t U;
    struct _hw_mu_atr0_bitfields
    {
        uint32_t ATR0 : 32;            /*!< [31:0]  */
    } B;
} hw_mu_atr0_t;

/*!
 * @name Constants and macros for entire MU_ATR0 register
 */
/*@{*/
#define HW_MU_ATR0_ADDR(x)       ((uintptr_t)(x) + 0x0U)

#define HW_MU_ATR0(x)            (*(__IO hw_mu_atr0_t *) HW_MU_ATR0_ADDR(x))
#define HW_MU_ATR0_RD(x)         (HW_MU_ATR0(x).U)
#define HW_MU_ATR0_WR(x, v)      (HW_MU_ATR0(x).U = (v))
#define HW_MU_ATR0_SET(x, v)     (HW_MU_ATR0_WR(x, HW_MU_ATR0_RD(x) |  (v)))
#define HW_MU_ATR0_CLR(x, v)     (HW_MU_ATR0_WR(x, HW_MU_ATR0_RD(x) & ~(v)))
#define HW_MU_ATR0_TOG(x, v)     (HW_MU_ATR0_WR(x, HW_MU_ATR0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MU_ATR0 bitfields
 */

/*!
 * @name Register MU_ATR0, field ATR0[31:0] (RW)
 *
 * Processor A Transmit Register 0. (Write-only) Data written to the ATR0
 * register is reflected on the Processor B-side in the Processor B Receive Register 0
 * (BRR0). The ATR0 and BRR0 registers are not double-buffered-a write to the
 * ATR0 register overrides the data readable at the BRR0 register. A write to the
 * transmit register clears a "transmitter empty" bit (TE0) in the Processor A
 * Status Register (ASR) on the transmitter side, and sets a "receiver full" bit
 * (RF0) in the Processor B Status Register (BSR) on the receiver side (optionally
 * triggering an interrupt 0 on the Processor B-side). Any write to the ATR0
 * register will update all status information.
 */
/*@{*/
#define BP_MU_ATR0_ATR0      (0U)          /*!< Bit position for MU_ATR0_ATR0. */
#define BM_MU_ATR0_ATR0      (0xFFFFFFFFU) /*!< Bit mask for MU_ATR0_ATR0. */
#define BS_MU_ATR0_ATR0      (32U)         /*!< Bit field size in bits for MU_ATR0_ATR0. */

/*! @brief Read current value of the MU_ATR0_ATR0 field. */
#define BR_MU_ATR0_ATR0(x)   (HW_MU_ATR0(x).U)

/*! @brief Format value for bitfield MU_ATR0_ATR0. */
#define BF_MU_ATR0_ATR0(v)   ((uint32_t)((uint32_t)(v) << BP_MU_ATR0_ATR0) & BM_MU_ATR0_ATR0)

/*! @brief Set the ATR0 field to a new value. */
#define BW_MU_ATR0_ATR0(x, v) (HW_MU_ATR0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MU_ATR1 - Processor A Transmit Register 1
 ******************************************************************************/

/*!
 * @brief HW_MU_ATR1 - Processor A Transmit Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Use Processor A Transmit Register 1 (ATR1, 32-bit, write-only) to transmit a
 * message or data to the Processor B. You can only write to the ATR1 register
 * when the TE1 bit in ASR register is set to "1". Reading the ATR1 register
 * returns all zeros.
 */
typedef union _hw_mu_atr1
{
    uint32_t U;
    struct _hw_mu_atr1_bitfields
    {
        uint32_t ATR1 : 32;            /*!< [31:0]  */
    } B;
} hw_mu_atr1_t;

/*!
 * @name Constants and macros for entire MU_ATR1 register
 */
/*@{*/
#define HW_MU_ATR1_ADDR(x)       ((uintptr_t)(x) + 0x4U)

#define HW_MU_ATR1(x)            (*(__IO hw_mu_atr1_t *) HW_MU_ATR1_ADDR(x))
#define HW_MU_ATR1_RD(x)         (HW_MU_ATR1(x).U)
#define HW_MU_ATR1_WR(x, v)      (HW_MU_ATR1(x).U = (v))
#define HW_MU_ATR1_SET(x, v)     (HW_MU_ATR1_WR(x, HW_MU_ATR1_RD(x) |  (v)))
#define HW_MU_ATR1_CLR(x, v)     (HW_MU_ATR1_WR(x, HW_MU_ATR1_RD(x) & ~(v)))
#define HW_MU_ATR1_TOG(x, v)     (HW_MU_ATR1_WR(x, HW_MU_ATR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MU_ATR1 bitfields
 */

/*!
 * @name Register MU_ATR1, field ATR1[31:0] (RW)
 *
 * Processor A Transmit Register 1. (Write-only) Data written to the ATR1
 * register is reflected on the Processor B-side in the Processor B Receive Register 1
 * (BRR1). The ATR1 and BRR1 registers are not double-buffered-a write to the
 * ATR1 register overrides the data readable at the BRR1 register. A write to the
 * transmit register clears a "transmitter empty" bit (TE1) in the Processor A
 * Status Register (ASR) on the transmitter side, and sets a "receiver full" bit
 * (RF1) in the Processor B Status Register (BSR) on the receiver side (optionally
 * triggering an interrupt 1 on the Processor B-side). Any write to the ATR1
 * register will update all status information.
 */
/*@{*/
#define BP_MU_ATR1_ATR1      (0U)          /*!< Bit position for MU_ATR1_ATR1. */
#define BM_MU_ATR1_ATR1      (0xFFFFFFFFU) /*!< Bit mask for MU_ATR1_ATR1. */
#define BS_MU_ATR1_ATR1      (32U)         /*!< Bit field size in bits for MU_ATR1_ATR1. */

/*! @brief Read current value of the MU_ATR1_ATR1 field. */
#define BR_MU_ATR1_ATR1(x)   (HW_MU_ATR1(x).U)

/*! @brief Format value for bitfield MU_ATR1_ATR1. */
#define BF_MU_ATR1_ATR1(v)   ((uint32_t)((uint32_t)(v) << BP_MU_ATR1_ATR1) & BM_MU_ATR1_ATR1)

/*! @brief Set the ATR1 field to a new value. */
#define BW_MU_ATR1_ATR1(x, v) (HW_MU_ATR1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MU_ATR2 - Processor A Transmit Register 2
 ******************************************************************************/

/*!
 * @brief HW_MU_ATR2 - Processor A Transmit Register 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Use Processor A Transmit Register 2 (ATR2, 32-bit, write-only) to transmit a
 * message or data to the Processor B. You can only write to the ATR2 register
 * when the TE2 bit in ASR register is set to "1". Reading the ATR2 register
 * returns all zeros.
 */
typedef union _hw_mu_atr2
{
    uint32_t U;
    struct _hw_mu_atr2_bitfields
    {
        uint32_t ATR2 : 32;            /*!< [31:0]  */
    } B;
} hw_mu_atr2_t;

/*!
 * @name Constants and macros for entire MU_ATR2 register
 */
/*@{*/
#define HW_MU_ATR2_ADDR(x)       ((uintptr_t)(x) + 0x8U)

#define HW_MU_ATR2(x)            (*(__IO hw_mu_atr2_t *) HW_MU_ATR2_ADDR(x))
#define HW_MU_ATR2_RD(x)         (HW_MU_ATR2(x).U)
#define HW_MU_ATR2_WR(x, v)      (HW_MU_ATR2(x).U = (v))
#define HW_MU_ATR2_SET(x, v)     (HW_MU_ATR2_WR(x, HW_MU_ATR2_RD(x) |  (v)))
#define HW_MU_ATR2_CLR(x, v)     (HW_MU_ATR2_WR(x, HW_MU_ATR2_RD(x) & ~(v)))
#define HW_MU_ATR2_TOG(x, v)     (HW_MU_ATR2_WR(x, HW_MU_ATR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MU_ATR2 bitfields
 */

/*!
 * @name Register MU_ATR2, field ATR2[31:0] (RW)
 *
 * Processor A Transmit Register 2. (Write-only) Data written to the ATR2
 * register is reflected on the Processor B-side in the Processor B Receive Register 2
 * (BRR2). The ATR2 and BRR2 registers are not double-buffered-a write to the
 * ATR2 register overrides the data readable at the BRR2 register. A write to the
 * transmit register clears a "transmitter empty" bit (TE2) in the Processor A
 * Status Register (ASR) on the transmitter side, and sets a "receiver full" bit
 * (RF2) in the Processor B Status Register (BSR) on the receiver side (optionally
 * triggering an interrupt 2 on the Processor B-side). Any write to the ATR2
 * register will update all status information.
 */
/*@{*/
#define BP_MU_ATR2_ATR2      (0U)          /*!< Bit position for MU_ATR2_ATR2. */
#define BM_MU_ATR2_ATR2      (0xFFFFFFFFU) /*!< Bit mask for MU_ATR2_ATR2. */
#define BS_MU_ATR2_ATR2      (32U)         /*!< Bit field size in bits for MU_ATR2_ATR2. */

/*! @brief Read current value of the MU_ATR2_ATR2 field. */
#define BR_MU_ATR2_ATR2(x)   (HW_MU_ATR2(x).U)

/*! @brief Format value for bitfield MU_ATR2_ATR2. */
#define BF_MU_ATR2_ATR2(v)   ((uint32_t)((uint32_t)(v) << BP_MU_ATR2_ATR2) & BM_MU_ATR2_ATR2)

/*! @brief Set the ATR2 field to a new value. */
#define BW_MU_ATR2_ATR2(x, v) (HW_MU_ATR2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MU_ATR3 - Processor A Transmit Register 3
 ******************************************************************************/

/*!
 * @brief HW_MU_ATR3 - Processor A Transmit Register 3 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Use Processor A Transmit Register 3 (ATR3, 32-bit, write-only) to transmit a
 * message or data to the Processor B. You can only write to the ATR3 register
 * when the TE3 bit in ASR register is set to "1". Reading the ATR3 register
 * returns all zeros.
 */
typedef union _hw_mu_atr3
{
    uint32_t U;
    struct _hw_mu_atr3_bitfields
    {
        uint32_t ATR3 : 32;            /*!< [31:0]  */
    } B;
} hw_mu_atr3_t;

/*!
 * @name Constants and macros for entire MU_ATR3 register
 */
/*@{*/
#define HW_MU_ATR3_ADDR(x)       ((uintptr_t)(x) + 0xCU)

#define HW_MU_ATR3(x)            (*(__IO hw_mu_atr3_t *) HW_MU_ATR3_ADDR(x))
#define HW_MU_ATR3_RD(x)         (HW_MU_ATR3(x).U)
#define HW_MU_ATR3_WR(x, v)      (HW_MU_ATR3(x).U = (v))
#define HW_MU_ATR3_SET(x, v)     (HW_MU_ATR3_WR(x, HW_MU_ATR3_RD(x) |  (v)))
#define HW_MU_ATR3_CLR(x, v)     (HW_MU_ATR3_WR(x, HW_MU_ATR3_RD(x) & ~(v)))
#define HW_MU_ATR3_TOG(x, v)     (HW_MU_ATR3_WR(x, HW_MU_ATR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MU_ATR3 bitfields
 */

/*!
 * @name Register MU_ATR3, field ATR3[31:0] (RW)
 *
 * Processor A Transmit Register 3. (Write-only) Data written to the ATR3
 * register is reflected on the Processor B-side in the Processor B Receive Register 3
 * (BRR3). The ATR3 and BRR3 registers are not double-buffered-a write to the
 * ATR3 register overrides the data readable at the BRR3 register. A write to the
 * transmit register clears a "transmitter empty" bit (TE3) in the Processor A
 * Status Register (ASR) on the transmitter side, and sets a "receiver full" bit
 * (RF3) in the Processor B Status Register (BSR) on the receiver side (optionally
 * triggering an interrupt 3 on the Processor B-side). Any write to the ATR3
 * register will update all status information.
 */
/*@{*/
#define BP_MU_ATR3_ATR3      (0U)          /*!< Bit position for MU_ATR3_ATR3. */
#define BM_MU_ATR3_ATR3      (0xFFFFFFFFU) /*!< Bit mask for MU_ATR3_ATR3. */
#define BS_MU_ATR3_ATR3      (32U)         /*!< Bit field size in bits for MU_ATR3_ATR3. */

/*! @brief Read current value of the MU_ATR3_ATR3 field. */
#define BR_MU_ATR3_ATR3(x)   (HW_MU_ATR3(x).U)

/*! @brief Format value for bitfield MU_ATR3_ATR3. */
#define BF_MU_ATR3_ATR3(v)   ((uint32_t)((uint32_t)(v) << BP_MU_ATR3_ATR3) & BM_MU_ATR3_ATR3)

/*! @brief Set the ATR3 field to a new value. */
#define BW_MU_ATR3_ATR3(x, v) (HW_MU_ATR3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_MU_ARR0 - Processor A Receive Register 0
 ******************************************************************************/

/*!
 * @brief HW_MU_ARR0 - Processor A Receive Register 0 (RO)
 *
 * Reset value: 0x00000000U
 *
 * Use Processor A Receive Register 0 (ARR0, 32-bit, read-only) to receive a
 * message or data from the Processor B. Data written to the BTR0 register is
 * immediately reflected in the ARR0 register. You can only read the ARR0 register when
 * the RF0 bit in the ASR register is set to "1". Writing to the ARR0 register
 * generates an error response to the Processor A.
 */
typedef union _hw_mu_arr0
{
    uint32_t U;
    struct _hw_mu_arr0_bitfields
    {
        uint32_t ARR0 : 32;            /*!< [31:0]  */
    } B;
} hw_mu_arr0_t;

/*!
 * @name Constants and macros for entire MU_ARR0 register
 */
/*@{*/
#define HW_MU_ARR0_ADDR(x)       ((uintptr_t)(x) + 0x10U)

#define HW_MU_ARR0(x)            (*(__I hw_mu_arr0_t *) HW_MU_ARR0_ADDR(x))
#define HW_MU_ARR0_RD(x)         (HW_MU_ARR0(x).U)
/*@}*/

/*
 * Constants & macros for individual MU_ARR0 bitfields
 */

/*!
 * @name Register MU_ARR0, field ARR0[31:0] (RO)
 *
 * Processor A Receive Register 0. (Read-only) Reflects the data written to
 * Processor B Transmit Register 0 (BTR0). Reading the ARR0 register clears the
 * "receiver full" bit (RF0) in the Processor A Status Register (ASR) on the receiver
 * side, and sets the "transmitter empty" bit (TE0) in the Processor B Status
 * Register on the transmitter side (optionally triggering a transmit interrupt 0 on
 * the Processor B-side). Any read of the ARR0 register will update all status
 * information.
 */
/*@{*/
#define BP_MU_ARR0_ARR0      (0U)          /*!< Bit position for MU_ARR0_ARR0. */
#define BM_MU_ARR0_ARR0      (0xFFFFFFFFU) /*!< Bit mask for MU_ARR0_ARR0. */
#define BS_MU_ARR0_ARR0      (32U)         /*!< Bit field size in bits for MU_ARR0_ARR0. */

/*! @brief Read current value of the MU_ARR0_ARR0 field. */
#define BR_MU_ARR0_ARR0(x)   (HW_MU_ARR0(x).U)
/*@}*/

/*******************************************************************************
 * HW_MU_ARR1 - Processor A Receive Register 1
 ******************************************************************************/

/*!
 * @brief HW_MU_ARR1 - Processor A Receive Register 1 (RO)
 *
 * Reset value: 0x00000000U
 *
 * Use Processor A Receive Register 1 (ARR1, 32-bit, read-only) to receive a
 * message or data from the Processor B. Data written to the BTR1 register is
 * immediately reflected in the ARR1 register. You can only read the ARR1 register when
 * the RF1 bit in the ASR register is set to "1". Writing to the ARR1 register
 * generates an error response to the Processor A.
 */
typedef union _hw_mu_arr1
{
    uint32_t U;
    struct _hw_mu_arr1_bitfields
    {
        uint32_t ARR1 : 32;            /*!< [31:0]  */
    } B;
} hw_mu_arr1_t;

/*!
 * @name Constants and macros for entire MU_ARR1 register
 */
/*@{*/
#define HW_MU_ARR1_ADDR(x)       ((uintptr_t)(x) + 0x14U)

#define HW_MU_ARR1(x)            (*(__I hw_mu_arr1_t *) HW_MU_ARR1_ADDR(x))
#define HW_MU_ARR1_RD(x)         (HW_MU_ARR1(x).U)
/*@}*/

/*
 * Constants & macros for individual MU_ARR1 bitfields
 */

/*!
 * @name Register MU_ARR1, field ARR1[31:0] (RO)
 *
 * Processor A Receive Register 1. (Read-only) Reflects the data written to
 * Processor B Transmit Register 1 (BTR1). Reading the ARR1 register clears the
 * "receiver full" bit (RF1) in the Processor A Status Register (ASR) on the receiver
 * side, and sets the "transmitter empty" bit (TE1) in the Processor B Status
 * Register on the transmitter side (optionally triggering a transmit interrupt 1 on
 * the Processor B-side). Any read of the ARR1 register will update all status
 * information.
 */
/*@{*/
#define BP_MU_ARR1_ARR1      (0U)          /*!< Bit position for MU_ARR1_ARR1. */
#define BM_MU_ARR1_ARR1      (0xFFFFFFFFU) /*!< Bit mask for MU_ARR1_ARR1. */
#define BS_MU_ARR1_ARR1      (32U)         /*!< Bit field size in bits for MU_ARR1_ARR1. */

/*! @brief Read current value of the MU_ARR1_ARR1 field. */
#define BR_MU_ARR1_ARR1(x)   (HW_MU_ARR1(x).U)
/*@}*/

/*******************************************************************************
 * HW_MU_ARR2 - Processor A Receive Register 2
 ******************************************************************************/

/*!
 * @brief HW_MU_ARR2 - Processor A Receive Register 2 (RO)
 *
 * Reset value: 0x00000000U
 *
 * Use Processor A Receive Register 2 (ARR2, 32-bit, read-only) to receive a
 * message or data from the Processor B. Data written to the BTR2 register is
 * immediately reflected in the ARR2 register. You can only read the ARR2 register when
 * the RF2 bit in the ASR register is set to "1". Writing to the ARR2 register
 * generates an error response to the Processor A.
 */
typedef union _hw_mu_arr2
{
    uint32_t U;
    struct _hw_mu_arr2_bitfields
    {
        uint32_t ARR2 : 32;            /*!< [31:0]  */
    } B;
} hw_mu_arr2_t;

/*!
 * @name Constants and macros for entire MU_ARR2 register
 */
/*@{*/
#define HW_MU_ARR2_ADDR(x)       ((uintptr_t)(x) + 0x18U)

#define HW_MU_ARR2(x)            (*(__I hw_mu_arr2_t *) HW_MU_ARR2_ADDR(x))
#define HW_MU_ARR2_RD(x)         (HW_MU_ARR2(x).U)
/*@}*/

/*
 * Constants & macros for individual MU_ARR2 bitfields
 */

/*!
 * @name Register MU_ARR2, field ARR2[31:0] (RO)
 *
 * Processor A Receive Register 2. (Read-only) Reflects the data written to
 * Processor B Transmit Register 1 (BTR2). Reading the ARR2 register clears the
 * "receiver full" bit (RF2) in the Processor A Status Register (ASR) on the receiver
 * side, and sets the "transmitter empty" bit (TE2) in the Processor B Status
 * Register on the transmitter side (optionally triggering a transmit interrupt 2 on
 * the Processor B-side). Any read of the ARR2 register will update all status
 * information.
 */
/*@{*/
#define BP_MU_ARR2_ARR2      (0U)          /*!< Bit position for MU_ARR2_ARR2. */
#define BM_MU_ARR2_ARR2      (0xFFFFFFFFU) /*!< Bit mask for MU_ARR2_ARR2. */
#define BS_MU_ARR2_ARR2      (32U)         /*!< Bit field size in bits for MU_ARR2_ARR2. */

/*! @brief Read current value of the MU_ARR2_ARR2 field. */
#define BR_MU_ARR2_ARR2(x)   (HW_MU_ARR2(x).U)
/*@}*/

/*******************************************************************************
 * HW_MU_ARR3 - Processor A Receive Register 3
 ******************************************************************************/

/*!
 * @brief HW_MU_ARR3 - Processor A Receive Register 3 (RO)
 *
 * Reset value: 0x00000000U
 *
 * Use Processor A Receive Register 3 (ARR3, 32-bit, read-only) to receive a
 * message or data from the Processor B. Data written to the BTR3 register is
 * immediately reflected in the ARR3 register. You can only read the ARR3 register when
 * the RF3 bit in the ASR register is set to "1". Writing to the ARR3 register
 * generates an error response to the Processor A.
 */
typedef union _hw_mu_arr3
{
    uint32_t U;
    struct _hw_mu_arr3_bitfields
    {
        uint32_t ARR3 : 32;            /*!< [31:0]  */
    } B;
} hw_mu_arr3_t;

/*!
 * @name Constants and macros for entire MU_ARR3 register
 */
/*@{*/
#define HW_MU_ARR3_ADDR(x)       ((uintptr_t)(x) + 0x1CU)

#define HW_MU_ARR3(x)            (*(__I hw_mu_arr3_t *) HW_MU_ARR3_ADDR(x))
#define HW_MU_ARR3_RD(x)         (HW_MU_ARR3(x).U)
/*@}*/

/*
 * Constants & macros for individual MU_ARR3 bitfields
 */

/*!
 * @name Register MU_ARR3, field ARR3[31:0] (RO)
 *
 * Processor A Receive Register 3. (Read-only) Reflects the data written to
 * Processor B Transmit Register 3 (BTR3). Reading the ARR3 register clears the
 * "receiver full" bit (RF3) in the Processor A Status Register (ASR) on the receiver
 * side, and sets the "transmitter empty" bit (TE3) in the Processor B Status
 * Register on the transmitter side (optionally triggering a transmit interrupt 3 on
 * the Processor B-side). Any read of the ARR3 register will update all status
 * information.
 */
/*@{*/
#define BP_MU_ARR3_ARR3      (0U)          /*!< Bit position for MU_ARR3_ARR3. */
#define BM_MU_ARR3_ARR3      (0xFFFFFFFFU) /*!< Bit mask for MU_ARR3_ARR3. */
#define BS_MU_ARR3_ARR3      (32U)         /*!< Bit field size in bits for MU_ARR3_ARR3. */

/*! @brief Read current value of the MU_ARR3_ARR3 field. */
#define BR_MU_ARR3_ARR3(x)   (HW_MU_ARR3(x).U)
/*@}*/

/*******************************************************************************
 * HW_MU_ASR - Processor A Status Register
 ******************************************************************************/

/*!
 * @brief HW_MU_ASR - Processor A Status Register (RW)
 *
 * Reset value: 0x00F00080U
 *
 * Use the Processor A Status Register (ASR, 32-bit, read-write) to show
 * interrupt status from the Processor B, general purpose flags, and to set dual
 * function control-status bits. Some dual-purpose bits are set by the MU logic, and
 * cleared by the Processor A-side programmer Other dual-purpose bits are set by the
 * Processor A-side programmer, and cleared by the MU logic.
 */
typedef union _hw_mu_asr
{
    uint32_t U;
    struct _hw_mu_asr_bitfields
    {
        uint32_t Fn : 3;               /*!< [2:0]  */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t EP : 1;               /*!< [4]  */
        uint32_t RESERVED1 : 2;        /*!< [6:5]  */
        uint32_t BRS : 1;              /*!< [7]  */
        uint32_t FUP : 1;              /*!< [8]  */
        uint32_t BRDIP : 1;            /*!< [9]  */
        uint32_t RESERVED2 : 10;       /*!< [19:10]  */
        uint32_t TEn : 4;              /*!< [23:20]  */
        uint32_t RFn : 4;              /*!< [27:24]  */
        uint32_t GIPn : 4;             /*!< [31:28]  */
    } B;
} hw_mu_asr_t;

/*!
 * @name Constants and macros for entire MU_ASR register
 */
/*@{*/
#define HW_MU_ASR_ADDR(x)        ((uintptr_t)(x) + 0x20U)

#define HW_MU_ASR(x)             (*(__IO hw_mu_asr_t *) HW_MU_ASR_ADDR(x))
#define HW_MU_ASR_RD(x)          (HW_MU_ASR(x).U)
#define HW_MU_ASR_WR(x, v)       (HW_MU_ASR(x).U = (v))
#define HW_MU_ASR_SET(x, v)      (HW_MU_ASR_WR(x, HW_MU_ASR_RD(x) |  (v)))
#define HW_MU_ASR_CLR(x, v)      (HW_MU_ASR_WR(x, HW_MU_ASR_RD(x) & ~(v)))
#define HW_MU_ASR_TOG(x, v)      (HW_MU_ASR_WR(x, HW_MU_ASR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MU_ASR bitfields
 */

/*!
 * @name Register MU_ASR, field Fn[2:0] (RW)
 *
 * For n = {0, 1, 2} Processor A-Side Flag n. (Read-only) Fn bit is the
 * Processor A-side flag that reflects the values written to the BAFn bit in the
 * Processor B control register. Every time that the BAFn bit is written, the BAFn bit
 * write event updates the Fn bit after the event update latency, which is measured
 * in terms of the number of clocks of the Processor B and the Processor A.
 *
 * Values:
 * - 0 - BAFn bit in BCR register is written 0 (default).
 * - 1 - BAFn bit in BCR register is written 1.
 */
/*@{*/
#define BP_MU_ASR_Fn         (0U)          /*!< Bit position for MU_ASR_Fn. */
#define BM_MU_ASR_Fn         (0x00000007U) /*!< Bit mask for MU_ASR_Fn. */
#define BS_MU_ASR_Fn         (3U)          /*!< Bit field size in bits for MU_ASR_Fn. */

/*! @brief Read current value of the MU_ASR_Fn field. */
#define BR_MU_ASR_Fn(x)      (HW_MU_ASR(x).B.Fn)

/*! @brief Format value for bitfield MU_ASR_Fn. */
#define BF_MU_ASR_Fn(v)      ((uint32_t)((uint32_t)(v) << BP_MU_ASR_Fn) & BM_MU_ASR_Fn)

/*! @brief Set the Fn field to a new value. */
#define BW_MU_ASR_Fn(x, v)   (HW_MU_ASR_WR(x, (HW_MU_ASR_RD(x) & ~BM_MU_ASR_Fn) | BF_MU_ASR_Fn(v)))
/*@}*/

/*!
 * @name Register MU_ASR, field EP[4] (RW)
 *
 * Processor A-Side Event Pending. (Read-only) EP bit is set to "1" when the
 * Processor A-side mechanism sends an event update request to the Processor B-side.
 * EP bit is cleared when the event update acknowledge is received. An "event"
 * is any hardware message that is reflected in the BSR register on the Processor
 * B-side (for example, "transmit register 0 written"). During normal operations,
 * you do not have to deal with the state of the EP bit because the event update
 * mechanism works automatically. To ensure events have been posted to Processor
 * B before entering STOP mode, you should verify that the EP bit is cleared. If
 * EP bit is set to "1", you should wait and continue to poll it (EP bit) before
 * entering STOP mode. Reading the ASR register (to check the EP bit) should be
 * the last access to the MU that should be performed before entering STOPor WAIT
 * modes; otherwise, the EP bit may be set by subsequent additional actions. The
 * EP bit is cleared when the MU resets.
 *
 * Values:
 * - 0 - The Processor A-side event is not pending (default).
 * - 1 - The Processor A-side event is pending.
 */
/*@{*/
#define BP_MU_ASR_EP         (4U)          /*!< Bit position for MU_ASR_EP. */
#define BM_MU_ASR_EP         (0x00000010U) /*!< Bit mask for MU_ASR_EP. */
#define BS_MU_ASR_EP         (1U)          /*!< Bit field size in bits for MU_ASR_EP. */

/*! @brief Read current value of the MU_ASR_EP field. */
#define BR_MU_ASR_EP(x)      (HW_MU_ASR(x).B.EP)

/*! @brief Format value for bitfield MU_ASR_EP. */
#define BF_MU_ASR_EP(v)      ((uint32_t)((uint32_t)(v) << BP_MU_ASR_EP) & BM_MU_ASR_EP)

/*! @brief Set the EP field to a new value. */
#define BW_MU_ASR_EP(x, v)   (HW_MU_ASR_WR(x, (HW_MU_ASR_RD(x) & ~BM_MU_ASR_EP) | BF_MU_ASR_EP(v)))
/*@}*/

/*!
 * @name Register MU_ASR, field BRS[7] (RW)
 *
 * Processor B-side Reset State. (Read-only) BRS bit indicates if the Processor
 * B-side of the MU is in a reset state or not. If the BRS bit is set to "1",
 * then the Processor B-side of the MU is still in the reset state. If the BRS bit
 * is cleared, then the Processor B-side of the MU are out of reset. The BRS bit
 * is set to "1" during: a Processor B system reset, or an MU reset (caused by
 * setting the MUR bit at the ACR register). The BRS bit is cleared when the reset
 * sequence on the Processor B-side of the MU ends. After issuing any of the reset
 * events mentioned previously, you should verify that the BRS bit is cleared
 * before starting any accesses. When Processor A side of MU comes out of reset BRS
 * bit has value "1"(default).Then Processor A sees the status of Processor
 * B-side and if Processor B-side has come out of reset then BRS bit goes low.This
 * takes 5-6 clock cycles.And if you read BRS bit now you will see it as low
 * although its reset value was "1" .
 *
 * Values:
 * - 0 - The Processor B-side of the MU is not in reset.
 * - 1 - The Processor B-side of the MU is in reset.
 */
/*@{*/
#define BP_MU_ASR_BRS        (7U)          /*!< Bit position for MU_ASR_BRS. */
#define BM_MU_ASR_BRS        (0x00000080U) /*!< Bit mask for MU_ASR_BRS. */
#define BS_MU_ASR_BRS        (1U)          /*!< Bit field size in bits for MU_ASR_BRS. */

/*! @brief Read current value of the MU_ASR_BRS field. */
#define BR_MU_ASR_BRS(x)     (HW_MU_ASR(x).B.BRS)

/*! @brief Format value for bitfield MU_ASR_BRS. */
#define BF_MU_ASR_BRS(v)     ((uint32_t)((uint32_t)(v) << BP_MU_ASR_BRS) & BM_MU_ASR_BRS)

/*! @brief Set the BRS field to a new value. */
#define BW_MU_ASR_BRS(x, v)  (HW_MU_ASR_WR(x, (HW_MU_ASR_RD(x) & ~BM_MU_ASR_BRS) | BF_MU_ASR_BRS(v)))
/*@}*/

/*!
 * @name Register MU_ASR, field FUP[8] (RW)
 *
 * Processor A Flags Update Pending. (Read-only) FUP bit is set to "1" when the
 * Processor A-side sends a Flags Update request to the Processor B-side. A Flags
 * Update request is generated when the ABF[2:0] bits of the ACR register
 * change. No flag update changes are allowed while the FUP bit is set to "1". Any
 * write to the ABF[2:0] bits, while the FUP bit is set to "1", will not generate a
 * Flags Update event, and the ABF[2:0] bits will stay unchanged. FUP bit is
 * cleared when this Flags Update request is internally acknowledged (that the flag is
 * updated) from the MU Processor B-side, and during MU reset.
 *
 * Values:
 * - 0 - No flags updated, initiated by the Processor A, in progress (default)
 * - 1 - Processor A initiated flags update, processing
 */
/*@{*/
#define BP_MU_ASR_FUP        (8U)          /*!< Bit position for MU_ASR_FUP. */
#define BM_MU_ASR_FUP        (0x00000100U) /*!< Bit mask for MU_ASR_FUP. */
#define BS_MU_ASR_FUP        (1U)          /*!< Bit field size in bits for MU_ASR_FUP. */

/*! @brief Read current value of the MU_ASR_FUP field. */
#define BR_MU_ASR_FUP(x)     (HW_MU_ASR(x).B.FUP)

/*! @brief Format value for bitfield MU_ASR_FUP. */
#define BF_MU_ASR_FUP(v)     ((uint32_t)((uint32_t)(v) << BP_MU_ASR_FUP) & BM_MU_ASR_FUP)

/*! @brief Set the FUP field to a new value. */
#define BW_MU_ASR_FUP(x, v)  (HW_MU_ASR_WR(x, (HW_MU_ASR_RD(x) & ~BM_MU_ASR_FUP) | BF_MU_ASR_FUP(v)))
/*@}*/

/*!
 * @name Register MU_ASR, field BRDIP[9] (RW)
 *
 * Processor B Reset De-asserted Interrupt Pending. (Read-Write) BRDIP bit
 * signals the Processor A-side that the Processor B-side has come out of reset. BRDIP
 * bit is set to "1" after the MU Processor B-side comes out of reset, after
 * synchronization. The interrupt generated by a Processor B-side reset de-assertion
 * is ORed with the Processor A general purpose interrupt 3. The Processor A
 * general purpose interrupt 3 is issued when the Processor B-side comes out of
 * reset (if the interrupt is enabled). To clear the BRDIP bit, write "1", which also
 * clears general purpose interrupt 3. When Processor A-side of MU comes out of
 * reset BRDIP bit has value "0"(default).Then Processor A sees the status of
 * Processor B-side and if Processor B-side has come out of reset then BRDIP bit
 * goes high.This takes 5-6 clock cycles.And if you read BRDIP bit now you will see
 * it as high although its reset value was "0".
 *
 * Values:
 * - 0 - The Processor A general purpose interrupt 3, because of a Processor
 *     B-side reset de-assertion, is cleared (default).
 * - 1 - The Processor B-side is out of reset.
 */
/*@{*/
#define BP_MU_ASR_BRDIP      (9U)          /*!< Bit position for MU_ASR_BRDIP. */
#define BM_MU_ASR_BRDIP      (0x00000200U) /*!< Bit mask for MU_ASR_BRDIP. */
#define BS_MU_ASR_BRDIP      (1U)          /*!< Bit field size in bits for MU_ASR_BRDIP. */

/*! @brief Read current value of the MU_ASR_BRDIP field. */
#define BR_MU_ASR_BRDIP(x)   (HW_MU_ASR(x).B.BRDIP)

/*! @brief Format value for bitfield MU_ASR_BRDIP. */
#define BF_MU_ASR_BRDIP(v)   ((uint32_t)((uint32_t)(v) << BP_MU_ASR_BRDIP) & BM_MU_ASR_BRDIP)

/*! @brief Set the BRDIP field to a new value. */
#define BW_MU_ASR_BRDIP(x, v) (HW_MU_ASR_WR(x, (HW_MU_ASR_RD(x) & ~BM_MU_ASR_BRDIP) | BF_MU_ASR_BRDIP(v)))
/*@}*/

/*!
 * @name Register MU_ASR, field TEn[23:20] (RW)
 *
 * For n = {0, 1, 2, 3} Processor A Transmit Register n Empty. (Read-only) The
 * TEn bit is set to "1" after the BRRn register is read on the Processor B-side.
 * After the TEn bit is set to "1", the TEn bit signals the Processor A-side that
 * the ATRn register is ready to be written on the Processor A-side, and a
 * Transmit n interrupt is issued on the Processor A-side (if the TEn bit in the ACR
 * register is set to "1"). TEn bit is cleared after the ATRn register is written
 * on the Processor A-side. TEn bit is set to "1" when the MU is reset.
 *
 * Values:
 * - 0 - ATRn register is not empty.
 * - 1 - ATRn register is empty (default).
 */
/*@{*/
#define BP_MU_ASR_TEn        (20U)         /*!< Bit position for MU_ASR_TEn. */
#define BM_MU_ASR_TEn        (0x00F00000U) /*!< Bit mask for MU_ASR_TEn. */
#define BS_MU_ASR_TEn        (4U)          /*!< Bit field size in bits for MU_ASR_TEn. */

/*! @brief Read current value of the MU_ASR_TEn field. */
#define BR_MU_ASR_TEn(x)     (HW_MU_ASR(x).B.TEn)

/*! @brief Format value for bitfield MU_ASR_TEn. */
#define BF_MU_ASR_TEn(v)     ((uint32_t)((uint32_t)(v) << BP_MU_ASR_TEn) & BM_MU_ASR_TEn)

/*! @brief Set the TEn field to a new value. */
#define BW_MU_ASR_TEn(x, v)  (HW_MU_ASR_WR(x, (HW_MU_ASR_RD(x) & ~BM_MU_ASR_TEn) | BF_MU_ASR_TEn(v)))
/*@}*/

/*!
 * @name Register MU_ASR, field RFn[27:24] (RW)
 *
 * For n = {0, 1, 2, 3} Processor A Receive Register n Full. (Read-only) The RFn
 * bit is set to "1" when the BTRn register is written on the Processor B-side.
 * After the RFn bit is set to "1", the RFn bit signals the Processor A-side that
 * new data is ready to be read by the Processor A in the ARRn register, and a
 * Receive n interrupt is issued on the Processor A-side (if the RIEn bit in the
 * ACR register has been set to "1"). RFn bit is cleared when the ARRn register is
 * read, and when the MU is reset.
 *
 * Values:
 * - 0 - ARRn register is not full (default).
 * - 1 - ARRn register has received data from BTRn register and is ready to be
 *     read by the Processor A.
 */
/*@{*/
#define BP_MU_ASR_RFn        (24U)         /*!< Bit position for MU_ASR_RFn. */
#define BM_MU_ASR_RFn        (0x0F000000U) /*!< Bit mask for MU_ASR_RFn. */
#define BS_MU_ASR_RFn        (4U)          /*!< Bit field size in bits for MU_ASR_RFn. */

/*! @brief Read current value of the MU_ASR_RFn field. */
#define BR_MU_ASR_RFn(x)     (HW_MU_ASR(x).B.RFn)

/*! @brief Format value for bitfield MU_ASR_RFn. */
#define BF_MU_ASR_RFn(v)     ((uint32_t)((uint32_t)(v) << BP_MU_ASR_RFn) & BM_MU_ASR_RFn)

/*! @brief Set the RFn field to a new value. */
#define BW_MU_ASR_RFn(x, v)  (HW_MU_ASR_WR(x, (HW_MU_ASR_RD(x) & ~BM_MU_ASR_RFn) | BF_MU_ASR_RFn(v)))
/*@}*/

/*!
 * @name Register MU_ASR, field GIPn[31:28] (RW)
 *
 * For n = {0, 1, 2, 3} Processor A General Interrupt Request n Pending.
 * (Read-Write) GIPn bit signals the Processor A that the GIRn bit in the BCR register
 * on the Processor B-side was set from "0" to "1". If the GIEn bit in the ACR
 * register is set to "1", a General Interrupt n request is issued. The GIPn bit is
 * cleared by writing it back as "1". Writing "0", or writing "1" when the GIPn
 * bit is cleared is ignored. Use this feature in the interrupt routine, where the
 * GIPn bit is cleared in order to de-assert the interrupt request source at the
 * interrupt controller. The proper bit clearing sequence is: clear an Processor
 * A register, set the desired bit in it (Processor A register), and write it to
 * the ASR register, thus clearing the GIPn bit. GIPn bit is cleared when the MU
 * is reset.
 *
 * Values:
 * - 0 - Processor A general purpose interrupt n is not pending. (default)
 * - 1 - Processor A general purpose interrupt n is pending.
 */
/*@{*/
#define BP_MU_ASR_GIPn       (28U)         /*!< Bit position for MU_ASR_GIPn. */
#define BM_MU_ASR_GIPn       (0xF0000000U) /*!< Bit mask for MU_ASR_GIPn. */
#define BS_MU_ASR_GIPn       (4U)          /*!< Bit field size in bits for MU_ASR_GIPn. */

/*! @brief Read current value of the MU_ASR_GIPn field. */
#define BR_MU_ASR_GIPn(x)    (HW_MU_ASR(x).B.GIPn)

/*! @brief Format value for bitfield MU_ASR_GIPn. */
#define BF_MU_ASR_GIPn(v)    ((uint32_t)((uint32_t)(v) << BP_MU_ASR_GIPn) & BM_MU_ASR_GIPn)

/*! @brief Set the GIPn field to a new value. */
#define BW_MU_ASR_GIPn(x, v) (HW_MU_ASR_WR(x, (HW_MU_ASR_RD(x) & ~BM_MU_ASR_GIPn) | BF_MU_ASR_GIPn(v)))
/*@}*/

/*******************************************************************************
 * HW_MU_ACR - Processor A Control Register
 ******************************************************************************/

/*!
 * @brief HW_MU_ACR - Processor A Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Use the Processor A Control Register (ACR, 32-bit, read-write) to enable the
 * MU interrupts on the Processor A-side, and trigger events and interrupts on
 * the Processor B-side (general purpose interrupt, flag update).
 */
typedef union _hw_mu_acr
{
    uint32_t U;
    struct _hw_mu_acr_bitfields
    {
        uint32_t ABFn : 3;             /*!< [2:0]  */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t BHR : 1;              /*!< [4]  */
        uint32_t MUR : 1;              /*!< [5]  */
        uint32_t BRDIE : 1;            /*!< [6]  */
        uint32_t RESERVED1 : 9;        /*!< [15:7]  */
        uint32_t GIRn : 4;             /*!< [19:16]  */
        uint32_t TIEn : 4;             /*!< [23:20]  */
        uint32_t RIEn : 4;             /*!< [27:24]  */
        uint32_t GIEn : 4;             /*!< [31:28]  */
    } B;
} hw_mu_acr_t;

/*!
 * @name Constants and macros for entire MU_ACR register
 */
/*@{*/
#define HW_MU_ACR_ADDR(x)        ((uintptr_t)(x) + 0x24U)

#define HW_MU_ACR(x)             (*(__IO hw_mu_acr_t *) HW_MU_ACR_ADDR(x))
#define HW_MU_ACR_RD(x)          (HW_MU_ACR(x).U)
#define HW_MU_ACR_WR(x, v)       (HW_MU_ACR(x).U = (v))
#define HW_MU_ACR_SET(x, v)      (HW_MU_ACR_WR(x, HW_MU_ACR_RD(x) |  (v)))
#define HW_MU_ACR_CLR(x, v)      (HW_MU_ACR_WR(x, HW_MU_ACR_RD(x) & ~(v)))
#define HW_MU_ACR_TOG(x, v)      (HW_MU_ACR_WR(x, HW_MU_ACR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual MU_ACR bitfields
 */

/*!
 * @name Register MU_ACR, field ABFn[2:0] (RW)
 *
 * For n = {0, 1, 2} Processor A to Processor B Flag n. (Read-Write) ABFn bit is
 * a read-write flag that is reflected in Fn bit in the BSR register on the
 * Processor B-side. ABFn bit is cleared when the MU resets.
 *
 * Values:
 * - 0 - N/A. Self clearing bit (default).
 * - 1 - Asserts the Processor A MU reset.
 */
/*@{*/
#define BP_MU_ACR_ABFn       (0U)          /*!< Bit position for MU_ACR_ABFn. */
#define BM_MU_ACR_ABFn       (0x00000007U) /*!< Bit mask for MU_ACR_ABFn. */
#define BS_MU_ACR_ABFn       (3U)          /*!< Bit field size in bits for MU_ACR_ABFn. */

/*! @brief Read current value of the MU_ACR_ABFn field. */
#define BR_MU_ACR_ABFn(x)    (HW_MU_ACR(x).B.ABFn)

/*! @brief Format value for bitfield MU_ACR_ABFn. */
#define BF_MU_ACR_ABFn(v)    ((uint32_t)((uint32_t)(v) << BP_MU_ACR_ABFn) & BM_MU_ACR_ABFn)

/*! @brief Set the ABFn field to a new value. */
#define BW_MU_ACR_ABFn(x, v) (HW_MU_ACR_WR(x, (HW_MU_ACR_RD(x) & ~BM_MU_ACR_ABFn) | BF_MU_ACR_ABFn(v)))
/*@}*/

/*!
 * @name Register MU_ACR, field BHR[4] (RW)
 *
 * Processor B Hardware Reset. (Read-Write) BHR bit asserts and de-asserts the
 * hardware reset of the Processor B. Set BHR bit to "1" to start a hardware reset
 * of the Processor B. Clear the BHR bit to de-assert the Processor B hardware
 * reset input. Assert the BHR bit for a minimum of 3 clock cycles of network
 * clock (sampling clock in SRC) clock. The BRS bit in MU_ASR register (b[7])
 * indicates the state of the Processor B. As soon as the Processor B goes into Reset
 * (BRS bit is set to "1"), the BHR bit can be de-asserted. Strobe-setting the BHR
 * bit will not cause an internal MU reset but will be routed outside MU to
 * Processor B domain reset logic After clearing the BHR bit, monitor the value of the
 * BRS bit at the ASR to know when the Processor B reset sequence has ended. The
 * BHR reset issued by the Processor A to the Processor B is maskable by the
 * Processor B (according to the settings of the BHRM bit in the BCR register). If
 * the BHRM bit (in the BCR register) is set to "1", then the BHR reset is masked;
 * if the BHRM bit (in the BCR register) is cleared (default), then the BHR
 * reset is enabled. The BHR bit does not return to the reset value during the
 * software (MUR) reset.
 *
 * Values:
 * - 0 - De-assert Hardware reset to the Processor B. (default)
 * - 1 - Assert Hardware reset to the Processor B.
 */
/*@{*/
#define BP_MU_ACR_BHR        (4U)          /*!< Bit position for MU_ACR_BHR. */
#define BM_MU_ACR_BHR        (0x00000010U) /*!< Bit mask for MU_ACR_BHR. */
#define BS_MU_ACR_BHR        (1U)          /*!< Bit field size in bits for MU_ACR_BHR. */

/*! @brief Read current value of the MU_ACR_BHR field. */
#define BR_MU_ACR_BHR(x)     (HW_MU_ACR(x).B.BHR)

/*! @brief Format value for bitfield MU_ACR_BHR. */
#define BF_MU_ACR_BHR(v)     ((uint32_t)((uint32_t)(v) << BP_MU_ACR_BHR) & BM_MU_ACR_BHR)

/*! @brief Set the BHR field to a new value. */
#define BW_MU_ACR_BHR(x, v)  (HW_MU_ACR_WR(x, (HW_MU_ACR_RD(x) & ~BM_MU_ACR_BHR) | BF_MU_ACR_BHR(v)))
/*@}*/

/*!
 * @name Register MU_ACR, field MUR[5] (RW)
 *
 * Processor A MU Reset. Setting MUR bit to "1" resets both the Processor B and
 * the Processor A sides of the MU module, forcing all control and status
 * registers to return to their default values (except the BHR bit in the ACR register
 * and BHRM bit in BCR register), and all internal states to be cleared. Before
 * setting the MUR bit to "1", it is advisable to interrupt the Processor B,
 * because setting the MUR bit may affect the ongoing Processor B program. After
 * setting the MUR bit, you should monitor the value of the BRS bit in the ASR register
 * to know when the reset sequence on the Processor B-side has ended. MUR bit
 * can only be written as "1". MUR bit is always read as "0". MUR bit is cleared
 * during the MU reset sequence.
 *
 * Values:
 * - 0 - N/A. Self clearing bit (default).
 * - 1 - Asserts the Processor A MU reset.
 */
/*@{*/
#define BP_MU_ACR_MUR        (5U)          /*!< Bit position for MU_ACR_MUR. */
#define BM_MU_ACR_MUR        (0x00000020U) /*!< Bit mask for MU_ACR_MUR. */
#define BS_MU_ACR_MUR        (1U)          /*!< Bit field size in bits for MU_ACR_MUR. */

/*! @brief Read current value of the MU_ACR_MUR field. */
#define BR_MU_ACR_MUR(x)     (HW_MU_ACR(x).B.MUR)

/*! @brief Format value for bitfield MU_ACR_MUR. */
#define BF_MU_ACR_MUR(v)     ((uint32_t)((uint32_t)(v) << BP_MU_ACR_MUR) & BM_MU_ACR_MUR)

/*! @brief Set the MUR field to a new value. */
#define BW_MU_ACR_MUR(x, v)  (HW_MU_ACR_WR(x, (HW_MU_ACR_RD(x) & ~BM_MU_ACR_MUR) | BF_MU_ACR_MUR(v)))
/*@}*/

/*!
 * @name Register MU_ACR, field BRDIE[6] (RW)
 *
 * Processor B Reset De-assertion Interrupt Enable. (Read-Write) BRDIE bit
 * enables Processor A General Interrupt 3. If BRDIE bit is set to "1", then General
 * Interrupt 3 request is issued to the Processor A when the BRDIP bit in the ASR
 * register is set to "1". If BRDIE is cleared, then the value of the BRDIP bit
 * is ignored and no General Interrupt 3 request will be issued. The BRDIE bit is
 * cleared when the MU resets.
 *
 * Values:
 * - 0 - Disables the Processor A General Purpose Interrupt 3 request due to the
 *     Processor B reset de-assertion to the Processor A. Processor B reset
 *     deassertion causes Processor B and MU-Processor B side to come out of reset
 *     thus setting BRDIP bit to "1".
 * - 1 - Enables Processor A General Purpose Interrupt 3 request due to the
 *     Processor B reset de-assertion to the Processor A.
 */
/*@{*/
#define BP_MU_ACR_BRDIE      (6U)          /*!< Bit position for MU_ACR_BRDIE. */
#define BM_MU_ACR_BRDIE      (0x00000040U) /*!< Bit mask for MU_ACR_BRDIE. */
#define BS_MU_ACR_BRDIE      (1U)          /*!< Bit field size in bits for MU_ACR_BRDIE. */

/*! @brief Read current value of the MU_ACR_BRDIE field. */
#define BR_MU_ACR_BRDIE(x)   (HW_MU_ACR(x).B.BRDIE)

/*! @brief Format value for bitfield MU_ACR_BRDIE. */
#define BF_MU_ACR_BRDIE(v)   ((uint32_t)((uint32_t)(v) << BP_MU_ACR_BRDIE) & BM_MU_ACR_BRDIE)

/*! @brief Set the BRDIE field to a new value. */
#define BW_MU_ACR_BRDIE(x, v) (HW_MU_ACR_WR(x, (HW_MU_ACR_RD(x) & ~BM_MU_ACR_BRDIE) | BF_MU_ACR_BRDIE(v)))
/*@}*/

/*!
 * @name Register MU_ACR, field GIRn[19:16] (RW)
 *
 * For n = {0, 1, 2, 3} Processor A General Purpose Interrupt Request n.
 * (Read-Write) Writing "1" to the GIRn bit sets the GIPn bit in the BSR register on the
 * Processor B-side. If the GIEn bit in the BCR register is set to "1" on the
 * Processor B-side, a General Purpose Interrupt n request is triggered. The GIRn
 * bit is cleared if the GIPn bit (in the BSR register on the Processor B-side) is
 * cleared by writing it (GIPn bit) as "1", thereby signalling the Processor A
 * that the interrupt was accepted (cleared by the software). The GIPn bit cannot
 * be written as "0" on the Processor A-side. To ensure proper operations, you
 * must verify that the GIRn bit is cleared (meaning that there is no pending
 * interrupt) before setting it (GIRn bit). GIRn bit is cleared when the MU resets.
 *
 * Values:
 * - 0 - Processor A General Interrupt n is not requested to the Processor B
 *     (default).
 * - 1 - Processor A General Interrupt n is requested to the Processor B.
 */
/*@{*/
#define BP_MU_ACR_GIRn       (16U)         /*!< Bit position for MU_ACR_GIRn. */
#define BM_MU_ACR_GIRn       (0x000F0000U) /*!< Bit mask for MU_ACR_GIRn. */
#define BS_MU_ACR_GIRn       (4U)          /*!< Bit field size in bits for MU_ACR_GIRn. */

/*! @brief Read current value of the MU_ACR_GIRn field. */
#define BR_MU_ACR_GIRn(x)    (HW_MU_ACR(x).B.GIRn)

/*! @brief Format value for bitfield MU_ACR_GIRn. */
#define BF_MU_ACR_GIRn(v)    ((uint32_t)((uint32_t)(v) << BP_MU_ACR_GIRn) & BM_MU_ACR_GIRn)

/*! @brief Set the GIRn field to a new value. */
#define BW_MU_ACR_GIRn(x, v) (HW_MU_ACR_WR(x, (HW_MU_ACR_RD(x) & ~BM_MU_ACR_GIRn) | BF_MU_ACR_GIRn(v)))
/*@}*/

/*!
 * @name Register MU_ACR, field TIEn[23:20] (RW)
 *
 * For n = {0, 1, 2, 3} Processor A Transmit Interrupt Enable n. (Read-Write)
 * TIEn bit enables Processor A Transmit Interrupt n. If TIEn bit is set to "1"
 * (enabled), then an Processor A Transmit Interrupt n request is issued when the
 * TEn bit in the ASR register is set to "1". If TIEn bit is cleared (disabled),
 * then the value of the TEn bit is ignored and no Processor A Transmit Interrupt n
 * request will be issued. TIEn bit is cleared when the MU resets.
 *
 * Values:
 * - 0 - Disables Processor A Transmit Interrupt n. (default)
 * - 1 - Enables Processor A Transmit Interrupt n.
 */
/*@{*/
#define BP_MU_ACR_TIEn       (20U)         /*!< Bit position for MU_ACR_TIEn. */
#define BM_MU_ACR_TIEn       (0x00F00000U) /*!< Bit mask for MU_ACR_TIEn. */
#define BS_MU_ACR_TIEn       (4U)          /*!< Bit field size in bits for MU_ACR_TIEn. */

/*! @brief Read current value of the MU_ACR_TIEn field. */
#define BR_MU_ACR_TIEn(x)    (HW_MU_ACR(x).B.TIEn)

/*! @brief Format value for bitfield MU_ACR_TIEn. */
#define BF_MU_ACR_TIEn(v)    ((uint32_t)((uint32_t)(v) << BP_MU_ACR_TIEn) & BM_MU_ACR_TIEn)

/*! @brief Set the TIEn field to a new value. */
#define BW_MU_ACR_TIEn(x, v) (HW_MU_ACR_WR(x, (HW_MU_ACR_RD(x) & ~BM_MU_ACR_TIEn) | BF_MU_ACR_TIEn(v)))
/*@}*/

/*!
 * @name Register MU_ACR, field RIEn[27:24] (RW)
 *
 * For n = {0, 1, 2, 3} Processor A Receive Interrupt Enable n. (Read-Write)
 * RIEn bit enables Processor A Receive Interrupt n. If RIEn bit is set to "1"
 * (enabled), then an Processor A Receive Interrupt n request is issued when the RFn
 * bit in the ASR register is set to "1". If RIEn bit is cleared (disabled), then
 * the value of the RFn bit is ignored and no Processor A Receive Interrupt n
 * request will be issued. RIEn bit is cleared when the MU resets.
 *
 * Values:
 * - 0 - Disables Processor A Receive Interrupt n. (default)
 * - 1 - Enables Processor A Receive Interrupt n.
 */
/*@{*/
#define BP_MU_ACR_RIEn       (24U)         /*!< Bit position for MU_ACR_RIEn. */
#define BM_MU_ACR_RIEn       (0x0F000000U) /*!< Bit mask for MU_ACR_RIEn. */
#define BS_MU_ACR_RIEn       (4U)          /*!< Bit field size in bits for MU_ACR_RIEn. */

/*! @brief Read current value of the MU_ACR_RIEn field. */
#define BR_MU_ACR_RIEn(x)    (HW_MU_ACR(x).B.RIEn)

/*! @brief Format value for bitfield MU_ACR_RIEn. */
#define BF_MU_ACR_RIEn(v)    ((uint32_t)((uint32_t)(v) << BP_MU_ACR_RIEn) & BM_MU_ACR_RIEn)

/*! @brief Set the RIEn field to a new value. */
#define BW_MU_ACR_RIEn(x, v) (HW_MU_ACR_WR(x, (HW_MU_ACR_RD(x) & ~BM_MU_ACR_RIEn) | BF_MU_ACR_RIEn(v)))
/*@}*/

/*!
 * @name Register MU_ACR, field GIEn[31:28] (RW)
 *
 * For n = {0, 1, 2, 3} Processor A General Purpose Interrupt Enable n.
 * (Read-Write) GIEn bit enables Processor A General Interrupt n. If GIEn bit is set to
 * "1" (enabled), then a General Interrupt n request is issued when the GIPn bit
 * in the ASR register is set to "1". If GIEn is cleared (disabled), then the
 * value of the GIPn bit is ignored and no General Interrupt n request will be
 * issued. GIEn bit is cleared when the MU resets.
 *
 * Values:
 * - 0 - Disables Processor A General Interrupt n. (default)
 * - 1 - Enables Processor A General Interrupt n.
 */
/*@{*/
#define BP_MU_ACR_GIEn       (28U)         /*!< Bit position for MU_ACR_GIEn. */
#define BM_MU_ACR_GIEn       (0xF0000000U) /*!< Bit mask for MU_ACR_GIEn. */
#define BS_MU_ACR_GIEn       (4U)          /*!< Bit field size in bits for MU_ACR_GIEn. */

/*! @brief Read current value of the MU_ACR_GIEn field. */
#define BR_MU_ACR_GIEn(x)    (HW_MU_ACR(x).B.GIEn)

/*! @brief Format value for bitfield MU_ACR_GIEn. */
#define BF_MU_ACR_GIEn(v)    ((uint32_t)((uint32_t)(v) << BP_MU_ACR_GIEn) & BM_MU_ACR_GIEn)

/*! @brief Set the GIEn field to a new value. */
#define BW_MU_ACR_GIEn(x, v) (HW_MU_ACR_WR(x, (HW_MU_ACR_RD(x) & ~BM_MU_ACR_GIEn) | BF_MU_ACR_GIEn(v)))
/*@}*/

/*******************************************************************************
 * hw_mu_t - module struct
 ******************************************************************************/
/*!
 * @brief All MU module registers.
 */
#pragma pack(1)
typedef struct _hw_mu
{
    __IO hw_mu_atr0_t ATR0;                /*!< [0x0] Processor A Transmit Register 0 */
    __IO hw_mu_atr1_t ATR1;                /*!< [0x4] Processor A Transmit Register 1 */
    __IO hw_mu_atr2_t ATR2;                /*!< [0x8] Processor A Transmit Register 2 */
    __IO hw_mu_atr3_t ATR3;                /*!< [0xC] Processor A Transmit Register 3 */
    __I hw_mu_arr0_t ARR0;                 /*!< [0x10] Processor A Receive Register 0 */
    __I hw_mu_arr1_t ARR1;                 /*!< [0x14] Processor A Receive Register 1 */
    __I hw_mu_arr2_t ARR2;                 /*!< [0x18] Processor A Receive Register 2 */
    __I hw_mu_arr3_t ARR3;                 /*!< [0x1C] Processor A Receive Register 3 */
    __IO hw_mu_asr_t ASR;                  /*!< [0x20] Processor A Status Register */
    __IO hw_mu_acr_t ACR;                  /*!< [0x24] Processor A Control Register */
} hw_mu_t;
#pragma pack()

/*! @brief Macro to access all MU registers. */
/*! @param x MU module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_MU_REGS(MUA_BASE)</code>. */
#define HW_MU_REGS(x)  (*(hw_mu_t *)(x))

/*
 * iMX7D OCOTP
 *
 * OCOTP Register Reference Index
 *
 * Registers defined in this header file:
 * - HW_OCOTP_CTRL - OTP Controller Control Register
 * - HW_OCOTP_TIMING - OTP Controller Timing Register
 * - HW_OCOTP_DATA0 - OTP Controller Write Data Register
 * - HW_OCOTP_DATA1 - OTP Controller Write Data Register
 * - HW_OCOTP_DATA2 - OTP Controller Write Data Register
 * - HW_OCOTP_DATA3 - OTP Controller Write Data Register
 * - HW_OCOTP_READ_CTRL - OTP Controller Write Data Register
 * - HW_OCOTP_READ_FUSE_DATA0 - OTP Controller Read Data Register
 * - HW_OCOTP_READ_FUSE_DATA1 - OTP Controller Read Data Register
 * - HW_OCOTP_READ_FUSE_DATA2 - OTP Controller Read Data Register
 * - HW_OCOTP_READ_FUSE_DATA3 - OTP Controller Read Data Register
 * - HW_OCOTP_SW_STICKY - Sticky bit Register
 * - HW_OCOTP_SCS - Software Controllable Signals Register
 * - HW_OCOTP_CRC_ADDR - OTP Controller CRC test address
 * - HW_OCOTP_CRC_VALUE - OTP Controller CRC Value Register
 * - HW_OCOTP_VERSION - OTP Controller Version Register
 * - HW_OCOTP_LOCK - Value of OTP Bank0 Word0 (Lock controls)
 * - HW_OCOTP_TESTER0 - Value of OTP Bank0 Word1 (Tester Information)
 * - HW_OCOTP_TESTER1 - Value of OTP Bank0 Word2 (Tester Information)
 * - HW_OCOTP_TESTER2 - Value of OTP Bank0 Word3 (Tester Information)
 * - HW_OCOTP_TESTER3 - Value of OTP Bank1 Word0 (Tester Information)
 * - HW_OCOTP_TESTER4 - Value of OTP Bank1 Word1 (Tester Information)
 * - HW_OCOTP_TESTER5 - Value of OTP Bank1 Word2 (Tester Information)
 * - HW_OCOTP_BOOT_CFG0 - Value of OTP Bank1 Word3 (Boot Configuration Information)
 * - HW_OCOTP_BOOT_CFG1 - Value of OTP Bank2 Word0 (Boot Configuration Information)
 * - HW_OCOTP_BOOT_CFG2 - Value of OTP Bank2 Word1 (Boot Configuration Information)
 * - HW_OCOTP_BOOT_CFG3 - Value of OTP Bank2 Word2 (Boot Configuration Information)
 * - HW_OCOTP_BOOT_CFG4 - Value of OTP Bank2 Word3 (BOOT Configuration Information)
 * - HW_OCOTP_MEM_TRIM0 - Value of OTP Bank3 Word0 (Memory Related Information)
 * - HW_OCOTP_MEM_TRIM1 - Value of OTP Bank3 Word1 (Memory Related Information)
 * - HW_OCOTP_ANA0 - Value of OTP Bank3 Word2 (Analog Information)
 * - HW_OCOTP_ANA1 - Value of OTP Bank3 Word3 (Analog Info.)
 * - HW_OCOTP_OTPMK0 - Shadow Register for OTP Bank4 Word0 (OTPMK Key)
 * - HW_OCOTP_OTPMK1 - Shadow Register for OTP Bank4 Word1 (OTPMK Key)
 * - HW_OCOTP_OTPMK2 - Shadow Register for OTP Bank4 Word2 (OTPMK Key)
 * - HW_OCOTP_OTPMK3 - Shadow Register for OTP Bank4 Word3 (OTPMK Key)
 * - HW_OCOTP_OTPMK4 - Shadow Register for OTP Bank5 Word0 (OTPMK Key)
 * - HW_OCOTP_OTPMK5 - Shadow Register for OTP Bank5 Word1 (OTPMK Key)
 * - HW_OCOTP_OTPMK6 - Shadow Register for OTP Bank5 Word2 (OTPMK Key)
 * - HW_OCOTP_OTPMK7 - Shadow Register for OTP Bank5 Word3 (OTPMK Key)
 * - HW_OCOTP_SRK0 - Shadow Register for OTP Bank6 Word0 (SRK Hash)
 * - HW_OCOTP_SRK1 - Shadow Register for OTP Bank6 Word1 (SRK Hash)
 * - HW_OCOTP_SRK2 - Shadow Register for OTP Bank6 Word2 (SRK Hash)
 * - HW_OCOTP_SRK3 - Shadow Register for OTP Bank6 Word3 (SRK Hash)
 * - HW_OCOTP_SRK4 - Shadow Register for OTP Bank7 Word0 (SRK Hash)
 * - HW_OCOTP_SRK5 - Shadow Register for OTP Bank7 Word1 (SRK Hash)
 * - HW_OCOTP_SRK6 - Shadow Register for OTP Bank7 Word2 (SRK Hash)
 * - HW_OCOTP_SRK7 - Shadow Register for OTP Bank7 Word3 (SRK Hash)
 * - HW_OCOTP_SJC_RESP0 - Value of OTP Bank8 Word0 (Secure JTAG Response Field)
 * - HW_OCOTP_SJC_RESP1 - Value of OTP Bank8 Word1 (Secure JTAG Response Field)
 * - HW_OCOTP_USB_ID - Value of OTP Bank8 Word2 (USB ID info)
 * - HW_OCOTP_FIELD_RETURN - Value of OTP Bank8 Word3 (Field Return)
 * - HW_OCOTP_MAC_ADDR0 - Value of OTP Bank9 Word0 (MAC Address)
 * - HW_OCOTP_MAC_ADDR1 - Value of OTP Bank9 Word1 (MAC Address)
 * - HW_OCOTP_MAC_ADDR2 - Value of OTP Bank9 Word2 (MAC Address)
 * - HW_OCOTP_SRK_REVOKE - Value of OTP Bank9 Word3 (SRK Revoke)
 * - HW_OCOTP_MAU_KEY0 - Shadow Register for OTP Bank10 Word0 (MAU Key)
 * - HW_OCOTP_MAU_KEY1 - Shadow Register for OTP Bank10 Word1 (MAU Key)
 * - HW_OCOTP_MAU_KEY2 - Shadow Register for OTP Bank10 Word2 (MAU Key)
 * - HW_OCOTP_MAU_KEY3 - Shadow Register for OTP Bank10 Word3 (MAU Key)
 * - HW_OCOTP_MAU_KEY4 - Shadow Register for OTP Bank11 Word0 (MAU Key)
 * - HW_OCOTP_MAU_KEY5 - Shadow Register for OTP Bank11 Word1 (MAU Key)
 * - HW_OCOTP_MAU_KEY6 - Shadow Register for OTP Bank11 Word2 (MAU Key)
 * - HW_OCOTP_MAU_KEY7 - Shadow Register for OTP Bank11 Word3 (MAU Key)
 * - HW_OCOTP_GP10 - Value of OTP Bank14 Word0
 * - HW_OCOTP_GP11 - Value of OTP Bank14 Word1
 * - HW_OCOTP_GP20 - Value of OTP Bank14 Word2
 * - HW_OCOTP_GP21 - Value of OTP Bank14 Word3
 * - HW_OCOTP_CRC_GP10 - Value of OTP Bank15 Word0 (CRC Key)
 * - HW_OCOTP_CRC_GP11 - Value of OTP Bank15 Word1 (CRC Key)
 * - HW_OCOTP_CRC_GP20 - Value of OTP Bank15 Word2 (CRC Key)
 * - HW_OCOTP_CRC_GP21 - Value of OTP Bank15 Word3 (CRC Key)
 *
 * - hw_ocotp_t - Struct containing all module registers.
 */

#define HW_OCOTP_INSTANCE_COUNT (1U) /*!< Number of instances of the OCOTP module. */
#define HW_OCOTP (0U) /*!< Instance number for OCOTP. */
#define OCOTP_BASE            (0x30350000U) /*!< Base address for OCOTP. */
/*! Array initializer of OCOTP base addresses. */
#define OCOTP_BASE_ADDRS      { OCOTP_BASE }

/*******************************************************************************
 * HW_OCOTP_CTRL - OTP Controller Control Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_CTRL - OTP Controller Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The OCOTP Control and Status Register specifies the copy state, as well as
 * the control required for random access of the OTP memory OCOTP_CTRL: 0x000
 * OCOTP_CTRL_SET: 0x004 OCOTP_CTRL_CLR: 0x008 OCOTP_CTRL_TOG: 0x00C The OCOTP Control
 * and Status Register provides the necessary software interface for performing
 * read and write operations to the On-Chip OTP (One-Time Programmable ROM). The
 * control fields such as WR_UNLOCK, ADDR, and BUSY / ERROR may be used in
 * conjunction with the HW_OCOTP_DATAn (n = 0, 1, 2, 3) register to perform write
 * operations. Read operations to the On-Chip OTP are involving ADDR, BUSY / ERROR bit
 * field and HW_OCOTP_READ_CTRL register. Read value is saved in
 * HW_OCOTP_READ_FUSE_DATAn (n = 0, 1, 2, 3) register. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_ctrl
{
    uint32_t U;
    struct _hw_ocotp_ctrl_bitfields
    {
        uint32_t ADDR : 4;             /*!< [3:0]  */
        uint32_t RSVD0 : 4;            /*!< [7:4] This field is reserved. */
        uint32_t BUSY : 1;             /*!< [8]  */
        uint32_t ERROR : 1;            /*!< [9]  */
        uint32_t RELOAD_SHADOWS : 1;   /*!< [10]  */
        uint32_t CRC_TEST : 1;         /*!< [11]  */
        uint32_t CRC_FAIL : 1;         /*!< [12]  */
        uint32_t RSVD1 : 3;            /*!< [15:13] This field is reserved. */
        uint32_t WR_UNLOCK : 16;       /*!< [31:16]  */
    } B;
} hw_ocotp_ctrl_t;

/*!
 * @name Constants and macros for entire OCOTP_CTRL register
 */
/*@{*/
#define HW_OCOTP_CTRL_ADDR(x)    ((uintptr_t)(x) + 0x0U)
#define HW_OCOTP_CTRL_SET_ADDR(x) (HW_OCOTP_CTRL_ADDR(x) + 0x4U)
#define HW_OCOTP_CTRL_CLR_ADDR(x) (HW_OCOTP_CTRL_ADDR(x) + 0x8U)
#define HW_OCOTP_CTRL_TOG_ADDR(x) (HW_OCOTP_CTRL_ADDR(x) + 0xCU)

#define HW_OCOTP_CTRL(x)         (*(__IO hw_ocotp_ctrl_t *) HW_OCOTP_CTRL_ADDR(x))
#define HW_OCOTP_CTRL_RD(x)      (HW_OCOTP_CTRL(x).U)
#define HW_OCOTP_CTRL_WR(x, v)   (HW_OCOTP_CTRL(x).U = (v))
#define HW_OCOTP_CTRL_SET(x, v)  ((*(uint32_t *) HW_OCOTP_CTRL_SET_ADDR(x)) = (v))
#define HW_OCOTP_CTRL_CLR(x, v)  ((*(uint32_t *) HW_OCOTP_CTRL_CLR_ADDR(x)) = (v))
#define HW_OCOTP_CTRL_TOG(x, v)  ((*(uint32_t *) HW_OCOTP_CTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual OCOTP_CTRL bitfields
 */

/*!
 * @name Register OCOTP_CTRL, field ADDR[3:0] (RW)
 *
 * OTP write and read access address register. Specifies one of 16 128 bits OTP
 * locations (bank 0x0 ~ 0xF). If a valid access is accepted by the controller,
 * the controller makes an internal copy of this value. This internal copy will
 * not update until the access is complete.
 */
/*@{*/
#define BP_OCOTP_CTRL_ADDR   (0U)          /*!< Bit position for OCOTP_CTRL_ADDR. */
#define BM_OCOTP_CTRL_ADDR   (0x0000000FU) /*!< Bit mask for OCOTP_CTRL_ADDR. */
#define BS_OCOTP_CTRL_ADDR   (4U)          /*!< Bit field size in bits for OCOTP_CTRL_ADDR. */

/*! @brief Read current value of the OCOTP_CTRL_ADDR field. */
#define BR_OCOTP_CTRL_ADDR(x) (HW_OCOTP_CTRL(x).B.ADDR)

/*! @brief Format value for bitfield OCOTP_CTRL_ADDR. */
#define BF_OCOTP_CTRL_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CTRL_ADDR) & BM_OCOTP_CTRL_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_OCOTP_CTRL_ADDR(x, v) (HW_OCOTP_CTRL_WR(x, (HW_OCOTP_CTRL_RD(x) & ~BM_OCOTP_CTRL_ADDR) | BF_OCOTP_CTRL_ADDR(v)))
/*@}*/

/*!
 * @name Register OCOTP_CTRL, field RSVD0[7:4] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_OCOTP_CTRL_RSVD0  (4U)          /*!< Bit position for OCOTP_CTRL_RSVD0. */
#define BM_OCOTP_CTRL_RSVD0  (0x000000F0U) /*!< Bit mask for OCOTP_CTRL_RSVD0. */
#define BS_OCOTP_CTRL_RSVD0  (4U)          /*!< Bit field size in bits for OCOTP_CTRL_RSVD0. */

/*! @brief Read current value of the OCOTP_CTRL_RSVD0 field. */
#define BR_OCOTP_CTRL_RSVD0(x) (HW_OCOTP_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register OCOTP_CTRL, field BUSY[8] (RO)
 *
 * OTP controller status bit. When active, no new write access or read access to
 * OTP(including RELOAD_SHADOWS) can be performed. Cleared by controller when
 * access complete. After reset (or after setting RELOAD_SHADOWS), this bit is set
 * by the controller until the HW/SW and LOCK registers are successfully copied,
 * after which time it is automatically cleared by the controller.
 */
/*@{*/
#define BP_OCOTP_CTRL_BUSY   (8U)          /*!< Bit position for OCOTP_CTRL_BUSY. */
#define BM_OCOTP_CTRL_BUSY   (0x00000100U) /*!< Bit mask for OCOTP_CTRL_BUSY. */
#define BS_OCOTP_CTRL_BUSY   (1U)          /*!< Bit field size in bits for OCOTP_CTRL_BUSY. */

/*! @brief Read current value of the OCOTP_CTRL_BUSY field. */
#define BR_OCOTP_CTRL_BUSY(x) (HW_OCOTP_CTRL(x).B.BUSY)
/*@}*/

/*!
 * @name Register OCOTP_CTRL, field ERROR[9] (RW)
 *
 * Set by the controller when an access to a locked region (OTP or shadow
 * register) is requested. Must be cleared before any further access performed. This
 * bit can only be set by the controller. This bit is also set if the Pin interface
 * is active and software requests an access to the OTP. For instance, the ERROR
 * bit cannot be cleared until the Pin interface access has completed. Reset
 * this bit by writing a 1 to the SCT clear address space and not by a general write.
 */
/*@{*/
#define BP_OCOTP_CTRL_ERROR  (9U)          /*!< Bit position for OCOTP_CTRL_ERROR. */
#define BM_OCOTP_CTRL_ERROR  (0x00000200U) /*!< Bit mask for OCOTP_CTRL_ERROR. */
#define BS_OCOTP_CTRL_ERROR  (1U)          /*!< Bit field size in bits for OCOTP_CTRL_ERROR. */

/*! @brief Read current value of the OCOTP_CTRL_ERROR field. */
#define BR_OCOTP_CTRL_ERROR(x) (HW_OCOTP_CTRL(x).B.ERROR)

/*! @brief Format value for bitfield OCOTP_CTRL_ERROR. */
#define BF_OCOTP_CTRL_ERROR(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CTRL_ERROR) & BM_OCOTP_CTRL_ERROR)

/*! @brief Set the ERROR field to a new value. */
#define BW_OCOTP_CTRL_ERROR(x, v) (HW_OCOTP_CTRL_WR(x, (HW_OCOTP_CTRL_RD(x) & ~BM_OCOTP_CTRL_ERROR) | BF_OCOTP_CTRL_ERROR(v)))
/*@}*/

/*!
 * @name Register OCOTP_CTRL, field RELOAD_SHADOWS[10] (RW)
 *
 * Set to force re-loading all the shadow registers (HW / SW capability and
 * LOCK). This operation automatically set BUSY. Once the shadow registers have been
 * re-loaded, BUSY and RELOAD_SHADOWS are automatically cleared by the controller.
 */
/*@{*/
#define BP_OCOTP_CTRL_RELOAD_SHADOWS (10U) /*!< Bit position for OCOTP_CTRL_RELOAD_SHADOWS. */
#define BM_OCOTP_CTRL_RELOAD_SHADOWS (0x00000400U) /*!< Bit mask for OCOTP_CTRL_RELOAD_SHADOWS. */
#define BS_OCOTP_CTRL_RELOAD_SHADOWS (1U)  /*!< Bit field size in bits for OCOTP_CTRL_RELOAD_SHADOWS. */

/*! @brief Read current value of the OCOTP_CTRL_RELOAD_SHADOWS field. */
#define BR_OCOTP_CTRL_RELOAD_SHADOWS(x) (HW_OCOTP_CTRL(x).B.RELOAD_SHADOWS)

/*! @brief Format value for bitfield OCOTP_CTRL_RELOAD_SHADOWS. */
#define BF_OCOTP_CTRL_RELOAD_SHADOWS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CTRL_RELOAD_SHADOWS) & BM_OCOTP_CTRL_RELOAD_SHADOWS)

/*! @brief Set the RELOAD_SHADOWS field to a new value. */
#define BW_OCOTP_CTRL_RELOAD_SHADOWS(x, v) (HW_OCOTP_CTRL_WR(x, (HW_OCOTP_CTRL_RD(x) & ~BM_OCOTP_CTRL_RELOAD_SHADOWS) | BF_OCOTP_CTRL_RELOAD_SHADOWS(v)))
/*@}*/

/*!
 * @name Register OCOTP_CTRL, field CRC_TEST[11] (RW)
 *
 * Set to calculate CRC32 according to start address and end address in CRC_ADDR
 * register. Then compare with CRC fuse word according CRC address in CRC_ADDR
 * register to generate CRC_FAIL flag. This operation automatically set Busy. Once
 * CRC test is finished, BUSY and CRC_TEST are automatically cleared by the
 * controller.
 */
/*@{*/
#define BP_OCOTP_CTRL_CRC_TEST (11U)       /*!< Bit position for OCOTP_CTRL_CRC_TEST. */
#define BM_OCOTP_CTRL_CRC_TEST (0x00000800U) /*!< Bit mask for OCOTP_CTRL_CRC_TEST. */
#define BS_OCOTP_CTRL_CRC_TEST (1U)        /*!< Bit field size in bits for OCOTP_CTRL_CRC_TEST. */

/*! @brief Read current value of the OCOTP_CTRL_CRC_TEST field. */
#define BR_OCOTP_CTRL_CRC_TEST(x) (HW_OCOTP_CTRL(x).B.CRC_TEST)

/*! @brief Format value for bitfield OCOTP_CTRL_CRC_TEST. */
#define BF_OCOTP_CTRL_CRC_TEST(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CTRL_CRC_TEST) & BM_OCOTP_CTRL_CRC_TEST)

/*! @brief Set the CRC_TEST field to a new value. */
#define BW_OCOTP_CTRL_CRC_TEST(x, v) (HW_OCOTP_CTRL_WR(x, (HW_OCOTP_CTRL_RD(x) & ~BM_OCOTP_CTRL_CRC_TEST) | BF_OCOTP_CTRL_CRC_TEST(v)))
/*@}*/

/*!
 * @name Register OCOTP_CTRL, field CRC_FAIL[12] (RW)
 *
 * Set by controller when calculated CRC value is not equal to appointed CRC
 * fuse word.
 */
/*@{*/
#define BP_OCOTP_CTRL_CRC_FAIL (12U)       /*!< Bit position for OCOTP_CTRL_CRC_FAIL. */
#define BM_OCOTP_CTRL_CRC_FAIL (0x00001000U) /*!< Bit mask for OCOTP_CTRL_CRC_FAIL. */
#define BS_OCOTP_CTRL_CRC_FAIL (1U)        /*!< Bit field size in bits for OCOTP_CTRL_CRC_FAIL. */

/*! @brief Read current value of the OCOTP_CTRL_CRC_FAIL field. */
#define BR_OCOTP_CTRL_CRC_FAIL(x) (HW_OCOTP_CTRL(x).B.CRC_FAIL)

/*! @brief Format value for bitfield OCOTP_CTRL_CRC_FAIL. */
#define BF_OCOTP_CTRL_CRC_FAIL(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CTRL_CRC_FAIL) & BM_OCOTP_CTRL_CRC_FAIL)

/*! @brief Set the CRC_FAIL field to a new value. */
#define BW_OCOTP_CTRL_CRC_FAIL(x, v) (HW_OCOTP_CTRL_WR(x, (HW_OCOTP_CTRL_RD(x) & ~BM_OCOTP_CTRL_CRC_FAIL) | BF_OCOTP_CTRL_CRC_FAIL(v)))
/*@}*/

/*!
 * @name Register OCOTP_CTRL, field RSVD1[15:13] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_OCOTP_CTRL_RSVD1  (13U)         /*!< Bit position for OCOTP_CTRL_RSVD1. */
#define BM_OCOTP_CTRL_RSVD1  (0x0000E000U) /*!< Bit mask for OCOTP_CTRL_RSVD1. */
#define BS_OCOTP_CTRL_RSVD1  (3U)          /*!< Bit field size in bits for OCOTP_CTRL_RSVD1. */

/*! @brief Read current value of the OCOTP_CTRL_RSVD1 field. */
#define BR_OCOTP_CTRL_RSVD1(x) (HW_OCOTP_CTRL(x).B.RSVD1)
/*@}*/

/*!
 * @name Register OCOTP_CTRL, field WR_UNLOCK[31:16] (RW)
 *
 * Write 0x3E77 to enable OTP write accesses. This register must be unlocked on
 * a write-by-write basis (a write is initiated when HW_OCOTP_DATA is written),
 * so the UNLOCK bit must contain the correct key value during all writes to
 * HW_OCOTP_DATA, otherwise a write is not initiated. This field is automatically
 * cleared after a successful write completion (clearing of BUSY).
 *
 * Values:
 * - 11111001110111 - Key needed to unlock HW_OCOTP_DATA register.
 */
/*@{*/
#define BP_OCOTP_CTRL_WR_UNLOCK (16U)      /*!< Bit position for OCOTP_CTRL_WR_UNLOCK. */
#define BM_OCOTP_CTRL_WR_UNLOCK (0xFFFF0000U) /*!< Bit mask for OCOTP_CTRL_WR_UNLOCK. */
#define BS_OCOTP_CTRL_WR_UNLOCK (16U)      /*!< Bit field size in bits for OCOTP_CTRL_WR_UNLOCK. */

#define BV_OCOTP_CTRL_WR_UNLOCK_KEY    (0x3E77U)     /*!< Bit field value for OCOTP_CTRL_WR_UNLOCK: Key needed to unlock HW_OCOTP_DATA register. */

/*! @brief Read current value of the OCOTP_CTRL_WR_UNLOCK field. */
#define BR_OCOTP_CTRL_WR_UNLOCK(x) (HW_OCOTP_CTRL(x).B.WR_UNLOCK)

/*! @brief Format value for bitfield OCOTP_CTRL_WR_UNLOCK. */
#define BF_OCOTP_CTRL_WR_UNLOCK(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CTRL_WR_UNLOCK) & BM_OCOTP_CTRL_WR_UNLOCK)

/*! @brief Set the WR_UNLOCK field to a new value. */
#define BW_OCOTP_CTRL_WR_UNLOCK(x, v) (HW_OCOTP_CTRL_WR(x, (HW_OCOTP_CTRL_RD(x) & ~BM_OCOTP_CTRL_WR_UNLOCK) | BF_OCOTP_CTRL_WR_UNLOCK(v)))
/*@}*/




/*******************************************************************************
 * HW_OCOTP_TIMING - OTP Controller Timing Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_TIMING - OTP Controller Timing Register (RW)
 *
 * Reset value: 0x01461299U
 *
 * This register specifies timing parameters of programming and reading the
 * OCOTP fuse array. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_timing
{
    uint32_t U;
    struct _hw_ocotp_timing_bitfields
    {
        uint32_t PROG : 12;            /*!< [11:0]  */
        uint32_t FSOURCE : 8;          /*!< [19:12]  */
        uint32_t RSRVD0 : 12;          /*!< [31:20] This field is reserved. */
    } B;
} hw_ocotp_timing_t;

/*!
 * @name Constants and macros for entire OCOTP_TIMING register
 */
/*@{*/
#define HW_OCOTP_TIMING_ADDR(x)  ((uintptr_t)(x) + 0x10U)

#define HW_OCOTP_TIMING(x)       (*(__IO hw_ocotp_timing_t *) HW_OCOTP_TIMING_ADDR(x))
#define HW_OCOTP_TIMING_RD(x)    (HW_OCOTP_TIMING(x).U)
#define HW_OCOTP_TIMING_WR(x, v) (HW_OCOTP_TIMING(x).U = (v))
#define HW_OCOTP_TIMING_SET(x, v) (HW_OCOTP_TIMING_WR(x, HW_OCOTP_TIMING_RD(x) |  (v)))
#define HW_OCOTP_TIMING_CLR(x, v) (HW_OCOTP_TIMING_WR(x, HW_OCOTP_TIMING_RD(x) & ~(v)))
#define HW_OCOTP_TIMING_TOG(x, v) (HW_OCOTP_TIMING_WR(x, HW_OCOTP_TIMING_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_TIMING bitfields
 */

/*!
 * @name Register OCOTP_TIMING, field PROG[11:0] (RW)
 *
 * This count value specifies the strobe period in one time write OTP. tPRW =
 * (PROG - 1) / IPG_CLK_FREQ. It is given in number of IPG_CLK periods.
 */
/*@{*/
#define BP_OCOTP_TIMING_PROG (0U)          /*!< Bit position for OCOTP_TIMING_PROG. */
#define BM_OCOTP_TIMING_PROG (0x00000FFFU) /*!< Bit mask for OCOTP_TIMING_PROG. */
#define BS_OCOTP_TIMING_PROG (12U)         /*!< Bit field size in bits for OCOTP_TIMING_PROG. */

/*! @brief Read current value of the OCOTP_TIMING_PROG field. */
#define BR_OCOTP_TIMING_PROG(x) (HW_OCOTP_TIMING(x).B.PROG)

/*! @brief Format value for bitfield OCOTP_TIMING_PROG. */
#define BF_OCOTP_TIMING_PROG(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_TIMING_PROG) & BM_OCOTP_TIMING_PROG)

/*! @brief Set the PROG field to a new value. */
#define BW_OCOTP_TIMING_PROG(x, v) (HW_OCOTP_TIMING_WR(x, (HW_OCOTP_TIMING_RD(x) & ~BM_OCOTP_TIMING_PROG) | BF_OCOTP_TIMING_PROG(v)))
/*@}*/

/*!
 * @name Register OCOTP_TIMING, field FSOURCE[19:12] (RW)
 *
 * This count value specifies FSOURCE to PROG setup / hold time. tFSRCS = tFSRCH
 * = (FSOURCE + 1) / IPG_CLK_FREQ. It is given in number of IPG_CLK periods.
 */
/*@{*/
#define BP_OCOTP_TIMING_FSOURCE (12U)      /*!< Bit position for OCOTP_TIMING_FSOURCE. */
#define BM_OCOTP_TIMING_FSOURCE (0x000FF000U) /*!< Bit mask for OCOTP_TIMING_FSOURCE. */
#define BS_OCOTP_TIMING_FSOURCE (8U)       /*!< Bit field size in bits for OCOTP_TIMING_FSOURCE. */

/*! @brief Read current value of the OCOTP_TIMING_FSOURCE field. */
#define BR_OCOTP_TIMING_FSOURCE(x) (HW_OCOTP_TIMING(x).B.FSOURCE)

/*! @brief Format value for bitfield OCOTP_TIMING_FSOURCE. */
#define BF_OCOTP_TIMING_FSOURCE(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_TIMING_FSOURCE) & BM_OCOTP_TIMING_FSOURCE)

/*! @brief Set the FSOURCE field to a new value. */
#define BW_OCOTP_TIMING_FSOURCE(x, v) (HW_OCOTP_TIMING_WR(x, (HW_OCOTP_TIMING_RD(x) & ~BM_OCOTP_TIMING_FSOURCE) | BF_OCOTP_TIMING_FSOURCE(v)))
/*@}*/

/*!
 * @name Register OCOTP_TIMING, field RSRVD0[31:20] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_OCOTP_TIMING_RSRVD0 (20U)       /*!< Bit position for OCOTP_TIMING_RSRVD0. */
#define BM_OCOTP_TIMING_RSRVD0 (0xFFF00000U) /*!< Bit mask for OCOTP_TIMING_RSRVD0. */
#define BS_OCOTP_TIMING_RSRVD0 (12U)       /*!< Bit field size in bits for OCOTP_TIMING_RSRVD0. */

/*! @brief Read current value of the OCOTP_TIMING_RSRVD0 field. */
#define BR_OCOTP_TIMING_RSRVD0(x) (HW_OCOTP_TIMING(x).B.RSRVD0)
/*@}*/

/*******************************************************************************
 * HW_OCOTP_DATA0 - OTP Controller Write Data Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_DATA0 - OTP Controller Write Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register associates with HW_OCOTP_CTRL to perform one-time writes to the
 * OTP. Please see the "Software Write Sequence" section for operating details.
 * EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_data0
{
    uint32_t U;
    struct _hw_ocotp_data0_bitfields
    {
        uint32_t DATA0 : 32;           /*!< [31:0]  */
    } B;
} hw_ocotp_data0_t;

/*!
 * @name Constants and macros for entire OCOTP_DATA0 register
 */
/*@{*/
#define HW_OCOTP_DATA0_ADDR(x)   ((uintptr_t)(x) + 0x20U)

#define HW_OCOTP_DATA0(x)        (*(__IO hw_ocotp_data0_t *) HW_OCOTP_DATA0_ADDR(x))
#define HW_OCOTP_DATA0_RD(x)     (HW_OCOTP_DATA0(x).U)
#define HW_OCOTP_DATA0_WR(x, v)  (HW_OCOTP_DATA0(x).U = (v))
#define HW_OCOTP_DATA0_SET(x, v) (HW_OCOTP_DATA0_WR(x, HW_OCOTP_DATA0_RD(x) |  (v)))
#define HW_OCOTP_DATA0_CLR(x, v) (HW_OCOTP_DATA0_WR(x, HW_OCOTP_DATA0_RD(x) & ~(v)))
#define HW_OCOTP_DATA0_TOG(x, v) (HW_OCOTP_DATA0_WR(x, HW_OCOTP_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_DATA0 bitfields
 */

/*!
 * @name Register OCOTP_DATA0, field DATA0[31:0] (RW)
 *
 * The program data for first fuse word in one 128 bits OTP. It is used to
 * initiate a write to OTP. Please see the "Software Write Sequence" section for
 * operating details.
 */
/*@{*/
#define BP_OCOTP_DATA0_DATA0 (0U)          /*!< Bit position for OCOTP_DATA0_DATA0. */
#define BM_OCOTP_DATA0_DATA0 (0xFFFFFFFFU) /*!< Bit mask for OCOTP_DATA0_DATA0. */
#define BS_OCOTP_DATA0_DATA0 (32U)         /*!< Bit field size in bits for OCOTP_DATA0_DATA0. */

/*! @brief Read current value of the OCOTP_DATA0_DATA0 field. */
#define BR_OCOTP_DATA0_DATA0(x) (HW_OCOTP_DATA0(x).U)

/*! @brief Format value for bitfield OCOTP_DATA0_DATA0. */
#define BF_OCOTP_DATA0_DATA0(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_DATA0_DATA0) & BM_OCOTP_DATA0_DATA0)

/*! @brief Set the DATA0 field to a new value. */
#define BW_OCOTP_DATA0_DATA0(x, v) (HW_OCOTP_DATA0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_DATA1 - OTP Controller Write Data Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_DATA1 - OTP Controller Write Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register associates with HW_OCOTP_CTRL to perform one-time writes to the
 * OTP. Please see the "Software Write Sequence" section for operating details.
 * EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_data1
{
    uint32_t U;
    struct _hw_ocotp_data1_bitfields
    {
        uint32_t DATA1 : 32;           /*!< [31:0]  */
    } B;
} hw_ocotp_data1_t;

/*!
 * @name Constants and macros for entire OCOTP_DATA1 register
 */
/*@{*/
#define HW_OCOTP_DATA1_ADDR(x)   ((uintptr_t)(x) + 0x30U)

#define HW_OCOTP_DATA1(x)        (*(__IO hw_ocotp_data1_t *) HW_OCOTP_DATA1_ADDR(x))
#define HW_OCOTP_DATA1_RD(x)     (HW_OCOTP_DATA1(x).U)
#define HW_OCOTP_DATA1_WR(x, v)  (HW_OCOTP_DATA1(x).U = (v))
#define HW_OCOTP_DATA1_SET(x, v) (HW_OCOTP_DATA1_WR(x, HW_OCOTP_DATA1_RD(x) |  (v)))
#define HW_OCOTP_DATA1_CLR(x, v) (HW_OCOTP_DATA1_WR(x, HW_OCOTP_DATA1_RD(x) & ~(v)))
#define HW_OCOTP_DATA1_TOG(x, v) (HW_OCOTP_DATA1_WR(x, HW_OCOTP_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_DATA1 bitfields
 */

/*!
 * @name Register OCOTP_DATA1, field DATA1[31:0] (RW)
 *
 * The program data for second fuse word in one 128 bits OTP.
 */
/*@{*/
#define BP_OCOTP_DATA1_DATA1 (0U)          /*!< Bit position for OCOTP_DATA1_DATA1. */
#define BM_OCOTP_DATA1_DATA1 (0xFFFFFFFFU) /*!< Bit mask for OCOTP_DATA1_DATA1. */
#define BS_OCOTP_DATA1_DATA1 (32U)         /*!< Bit field size in bits for OCOTP_DATA1_DATA1. */

/*! @brief Read current value of the OCOTP_DATA1_DATA1 field. */
#define BR_OCOTP_DATA1_DATA1(x) (HW_OCOTP_DATA1(x).U)

/*! @brief Format value for bitfield OCOTP_DATA1_DATA1. */
#define BF_OCOTP_DATA1_DATA1(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_DATA1_DATA1) & BM_OCOTP_DATA1_DATA1)

/*! @brief Set the DATA1 field to a new value. */
#define BW_OCOTP_DATA1_DATA1(x, v) (HW_OCOTP_DATA1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_DATA2 - OTP Controller Write Data Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_DATA2 - OTP Controller Write Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register associates with HW_OCOTP_CTRL to perform one-time writes to the
 * OTP. Please see the "Software Write Sequence" section for operating details.
 * EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_data2
{
    uint32_t U;
    struct _hw_ocotp_data2_bitfields
    {
        uint32_t DATA2 : 32;           /*!< [31:0]  */
    } B;
} hw_ocotp_data2_t;

/*!
 * @name Constants and macros for entire OCOTP_DATA2 register
 */
/*@{*/
#define HW_OCOTP_DATA2_ADDR(x)   ((uintptr_t)(x) + 0x40U)

#define HW_OCOTP_DATA2(x)        (*(__IO hw_ocotp_data2_t *) HW_OCOTP_DATA2_ADDR(x))
#define HW_OCOTP_DATA2_RD(x)     (HW_OCOTP_DATA2(x).U)
#define HW_OCOTP_DATA2_WR(x, v)  (HW_OCOTP_DATA2(x).U = (v))
#define HW_OCOTP_DATA2_SET(x, v) (HW_OCOTP_DATA2_WR(x, HW_OCOTP_DATA2_RD(x) |  (v)))
#define HW_OCOTP_DATA2_CLR(x, v) (HW_OCOTP_DATA2_WR(x, HW_OCOTP_DATA2_RD(x) & ~(v)))
#define HW_OCOTP_DATA2_TOG(x, v) (HW_OCOTP_DATA2_WR(x, HW_OCOTP_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_DATA2 bitfields
 */

/*!
 * @name Register OCOTP_DATA2, field DATA2[31:0] (RW)
 *
 * The program data for third fuse word in one 128 bits OTP.
 */
/*@{*/
#define BP_OCOTP_DATA2_DATA2 (0U)          /*!< Bit position for OCOTP_DATA2_DATA2. */
#define BM_OCOTP_DATA2_DATA2 (0xFFFFFFFFU) /*!< Bit mask for OCOTP_DATA2_DATA2. */
#define BS_OCOTP_DATA2_DATA2 (32U)         /*!< Bit field size in bits for OCOTP_DATA2_DATA2. */

/*! @brief Read current value of the OCOTP_DATA2_DATA2 field. */
#define BR_OCOTP_DATA2_DATA2(x) (HW_OCOTP_DATA2(x).U)

/*! @brief Format value for bitfield OCOTP_DATA2_DATA2. */
#define BF_OCOTP_DATA2_DATA2(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_DATA2_DATA2) & BM_OCOTP_DATA2_DATA2)

/*! @brief Set the DATA2 field to a new value. */
#define BW_OCOTP_DATA2_DATA2(x, v) (HW_OCOTP_DATA2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_DATA3 - OTP Controller Write Data Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_DATA3 - OTP Controller Write Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register associates with HW_OCOTP_CTRL to perform one-time writes to the
 * OTP. Please see the "Software Write Sequence" section for operating details.
 * EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_data3
{
    uint32_t U;
    struct _hw_ocotp_data3_bitfields
    {
        uint32_t DATA3 : 32;           /*!< [31:0]  */
    } B;
} hw_ocotp_data3_t;

/*!
 * @name Constants and macros for entire OCOTP_DATA3 register
 */
/*@{*/
#define HW_OCOTP_DATA3_ADDR(x)   ((uintptr_t)(x) + 0x50U)

#define HW_OCOTP_DATA3(x)        (*(__IO hw_ocotp_data3_t *) HW_OCOTP_DATA3_ADDR(x))
#define HW_OCOTP_DATA3_RD(x)     (HW_OCOTP_DATA3(x).U)
#define HW_OCOTP_DATA3_WR(x, v)  (HW_OCOTP_DATA3(x).U = (v))
#define HW_OCOTP_DATA3_SET(x, v) (HW_OCOTP_DATA3_WR(x, HW_OCOTP_DATA3_RD(x) |  (v)))
#define HW_OCOTP_DATA3_CLR(x, v) (HW_OCOTP_DATA3_WR(x, HW_OCOTP_DATA3_RD(x) & ~(v)))
#define HW_OCOTP_DATA3_TOG(x, v) (HW_OCOTP_DATA3_WR(x, HW_OCOTP_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_DATA3 bitfields
 */

/*!
 * @name Register OCOTP_DATA3, field DATA3[31:0] (RW)
 *
 * The program data for the last fuse word in one 128 bits OTP.
 */
/*@{*/
#define BP_OCOTP_DATA3_DATA3 (0U)          /*!< Bit position for OCOTP_DATA3_DATA3. */
#define BM_OCOTP_DATA3_DATA3 (0xFFFFFFFFU) /*!< Bit mask for OCOTP_DATA3_DATA3. */
#define BS_OCOTP_DATA3_DATA3 (32U)         /*!< Bit field size in bits for OCOTP_DATA3_DATA3. */

/*! @brief Read current value of the OCOTP_DATA3_DATA3 field. */
#define BR_OCOTP_DATA3_DATA3(x) (HW_OCOTP_DATA3(x).U)

/*! @brief Format value for bitfield OCOTP_DATA3_DATA3. */
#define BF_OCOTP_DATA3_DATA3(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_DATA3_DATA3) & BM_OCOTP_DATA3_DATA3)

/*! @brief Set the DATA3 field to a new value. */
#define BW_OCOTP_DATA3_DATA3(x, v) (HW_OCOTP_DATA3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_READ_CTRL - OTP Controller Write Data Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_READ_CTRL - OTP Controller Write Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register associates with HW_OCOTP_CTRL to perform one time read to the
 * OTP. Please see the "Software read Sequence" section for operating details.
 * EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_read_ctrl
{
    uint32_t U;
    struct _hw_ocotp_read_ctrl_bitfields
    {
        uint32_t READ_FUSE : 1;        /*!< [0]  */
        uint32_t RSVD0 : 31;           /*!< [31:1] This field is reserved. */
    } B;
} hw_ocotp_read_ctrl_t;

/*!
 * @name Constants and macros for entire OCOTP_READ_CTRL register
 */
/*@{*/
#define HW_OCOTP_READ_CTRL_ADDR(x) ((uintptr_t)(x) + 0x60U)

#define HW_OCOTP_READ_CTRL(x)    (*(__IO hw_ocotp_read_ctrl_t *) HW_OCOTP_READ_CTRL_ADDR(x))
#define HW_OCOTP_READ_CTRL_RD(x) (HW_OCOTP_READ_CTRL(x).U)
#define HW_OCOTP_READ_CTRL_WR(x, v) (HW_OCOTP_READ_CTRL(x).U = (v))
#define HW_OCOTP_READ_CTRL_SET(x, v) (HW_OCOTP_READ_CTRL_WR(x, HW_OCOTP_READ_CTRL_RD(x) |  (v)))
#define HW_OCOTP_READ_CTRL_CLR(x, v) (HW_OCOTP_READ_CTRL_WR(x, HW_OCOTP_READ_CTRL_RD(x) & ~(v)))
#define HW_OCOTP_READ_CTRL_TOG(x, v) (HW_OCOTP_READ_CTRL_WR(x, HW_OCOTP_READ_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_READ_CTRL bitfields
 */

/*!
 * @name Register OCOTP_READ_CTRL, field READ_FUSE[0] (RW)
 *
 * Used to initiate a read to OTP. Please see the "Software read Sequence"
 * section for operating details.
 */
/*@{*/
#define BP_OCOTP_READ_CTRL_READ_FUSE (0U)  /*!< Bit position for OCOTP_READ_CTRL_READ_FUSE. */
#define BM_OCOTP_READ_CTRL_READ_FUSE (0x00000001U) /*!< Bit mask for OCOTP_READ_CTRL_READ_FUSE. */
#define BS_OCOTP_READ_CTRL_READ_FUSE (1U)  /*!< Bit field size in bits for OCOTP_READ_CTRL_READ_FUSE. */

/*! @brief Read current value of the OCOTP_READ_CTRL_READ_FUSE field. */
#define BR_OCOTP_READ_CTRL_READ_FUSE(x) (HW_OCOTP_READ_CTRL(x).B.READ_FUSE)

/*! @brief Format value for bitfield OCOTP_READ_CTRL_READ_FUSE. */
#define BF_OCOTP_READ_CTRL_READ_FUSE(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_READ_CTRL_READ_FUSE) & BM_OCOTP_READ_CTRL_READ_FUSE)

/*! @brief Set the READ_FUSE field to a new value. */
#define BW_OCOTP_READ_CTRL_READ_FUSE(x, v) (HW_OCOTP_READ_CTRL_WR(x, (HW_OCOTP_READ_CTRL_RD(x) & ~BM_OCOTP_READ_CTRL_READ_FUSE) | BF_OCOTP_READ_CTRL_READ_FUSE(v)))
/*@}*/

/*!
 * @name Register OCOTP_READ_CTRL, field RSVD0[31:1] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_OCOTP_READ_CTRL_RSVD0 (1U)      /*!< Bit position for OCOTP_READ_CTRL_RSVD0. */
#define BM_OCOTP_READ_CTRL_RSVD0 (0xFFFFFFFEU) /*!< Bit mask for OCOTP_READ_CTRL_RSVD0. */
#define BS_OCOTP_READ_CTRL_RSVD0 (31U)     /*!< Bit field size in bits for OCOTP_READ_CTRL_RSVD0. */

/*! @brief Read current value of the OCOTP_READ_CTRL_RSVD0 field. */
#define BR_OCOTP_READ_CTRL_RSVD0(x) (HW_OCOTP_READ_CTRL(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_OCOTP_READ_FUSE_DATA0 - OTP Controller Read Data Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_READ_FUSE_DATA0 - OTP Controller Read Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_read_fuse_data0
{
    uint32_t U;
    struct _hw_ocotp_read_fuse_data0_bitfields
    {
        uint32_t DATA0 : 32;           /*!< [31:0]  */
    } B;
} hw_ocotp_read_fuse_data0_t;

/*!
 * @name Constants and macros for entire OCOTP_READ_FUSE_DATA0 register
 */
/*@{*/
#define HW_OCOTP_READ_FUSE_DATA0_ADDR(x) ((uintptr_t)(x) + 0x70U)

#define HW_OCOTP_READ_FUSE_DATA0(x) (*(__IO hw_ocotp_read_fuse_data0_t *) HW_OCOTP_READ_FUSE_DATA0_ADDR(x))
#define HW_OCOTP_READ_FUSE_DATA0_RD(x) (HW_OCOTP_READ_FUSE_DATA0(x).U)
#define HW_OCOTP_READ_FUSE_DATA0_WR(x, v) (HW_OCOTP_READ_FUSE_DATA0(x).U = (v))
#define HW_OCOTP_READ_FUSE_DATA0_SET(x, v) (HW_OCOTP_READ_FUSE_DATA0_WR(x, HW_OCOTP_READ_FUSE_DATA0_RD(x) |  (v)))
#define HW_OCOTP_READ_FUSE_DATA0_CLR(x, v) (HW_OCOTP_READ_FUSE_DATA0_WR(x, HW_OCOTP_READ_FUSE_DATA0_RD(x) & ~(v)))
#define HW_OCOTP_READ_FUSE_DATA0_TOG(x, v) (HW_OCOTP_READ_FUSE_DATA0_WR(x, HW_OCOTP_READ_FUSE_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_READ_FUSE_DATA0 bitfields
 */

/*!
 * @name Register OCOTP_READ_FUSE_DATA0, field DATA0[31:0] (RW)
 *
 * The first fuse word data read from one OTP.
 */
/*@{*/
#define BP_OCOTP_READ_FUSE_DATA0_DATA0 (0U) /*!< Bit position for OCOTP_READ_FUSE_DATA0_DATA0. */
#define BM_OCOTP_READ_FUSE_DATA0_DATA0 (0xFFFFFFFFU) /*!< Bit mask for OCOTP_READ_FUSE_DATA0_DATA0. */
#define BS_OCOTP_READ_FUSE_DATA0_DATA0 (32U) /*!< Bit field size in bits for OCOTP_READ_FUSE_DATA0_DATA0. */

/*! @brief Read current value of the OCOTP_READ_FUSE_DATA0_DATA0 field. */
#define BR_OCOTP_READ_FUSE_DATA0_DATA0(x) (HW_OCOTP_READ_FUSE_DATA0(x).U)

/*! @brief Format value for bitfield OCOTP_READ_FUSE_DATA0_DATA0. */
#define BF_OCOTP_READ_FUSE_DATA0_DATA0(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_READ_FUSE_DATA0_DATA0) & BM_OCOTP_READ_FUSE_DATA0_DATA0)

/*! @brief Set the DATA0 field to a new value. */
#define BW_OCOTP_READ_FUSE_DATA0_DATA0(x, v) (HW_OCOTP_READ_FUSE_DATA0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_READ_FUSE_DATA1 - OTP Controller Read Data Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_READ_FUSE_DATA1 - OTP Controller Read Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_read_fuse_data1
{
    uint32_t U;
    struct _hw_ocotp_read_fuse_data1_bitfields
    {
        uint32_t DATA1 : 32;           /*!< [31:0]  */
    } B;
} hw_ocotp_read_fuse_data1_t;

/*!
 * @name Constants and macros for entire OCOTP_READ_FUSE_DATA1 register
 */
/*@{*/
#define HW_OCOTP_READ_FUSE_DATA1_ADDR(x) ((uintptr_t)(x) + 0x80U)

#define HW_OCOTP_READ_FUSE_DATA1(x) (*(__IO hw_ocotp_read_fuse_data1_t *) HW_OCOTP_READ_FUSE_DATA1_ADDR(x))
#define HW_OCOTP_READ_FUSE_DATA1_RD(x) (HW_OCOTP_READ_FUSE_DATA1(x).U)
#define HW_OCOTP_READ_FUSE_DATA1_WR(x, v) (HW_OCOTP_READ_FUSE_DATA1(x).U = (v))
#define HW_OCOTP_READ_FUSE_DATA1_SET(x, v) (HW_OCOTP_READ_FUSE_DATA1_WR(x, HW_OCOTP_READ_FUSE_DATA1_RD(x) |  (v)))
#define HW_OCOTP_READ_FUSE_DATA1_CLR(x, v) (HW_OCOTP_READ_FUSE_DATA1_WR(x, HW_OCOTP_READ_FUSE_DATA1_RD(x) & ~(v)))
#define HW_OCOTP_READ_FUSE_DATA1_TOG(x, v) (HW_OCOTP_READ_FUSE_DATA1_WR(x, HW_OCOTP_READ_FUSE_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_READ_FUSE_DATA1 bitfields
 */

/*!
 * @name Register OCOTP_READ_FUSE_DATA1, field DATA1[31:0] (RW)
 *
 * The second fuse word data read from one OTP.
 */
/*@{*/
#define BP_OCOTP_READ_FUSE_DATA1_DATA1 (0U) /*!< Bit position for OCOTP_READ_FUSE_DATA1_DATA1. */
#define BM_OCOTP_READ_FUSE_DATA1_DATA1 (0xFFFFFFFFU) /*!< Bit mask for OCOTP_READ_FUSE_DATA1_DATA1. */
#define BS_OCOTP_READ_FUSE_DATA1_DATA1 (32U) /*!< Bit field size in bits for OCOTP_READ_FUSE_DATA1_DATA1. */

/*! @brief Read current value of the OCOTP_READ_FUSE_DATA1_DATA1 field. */
#define BR_OCOTP_READ_FUSE_DATA1_DATA1(x) (HW_OCOTP_READ_FUSE_DATA1(x).U)

/*! @brief Format value for bitfield OCOTP_READ_FUSE_DATA1_DATA1. */
#define BF_OCOTP_READ_FUSE_DATA1_DATA1(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_READ_FUSE_DATA1_DATA1) & BM_OCOTP_READ_FUSE_DATA1_DATA1)

/*! @brief Set the DATA1 field to a new value. */
#define BW_OCOTP_READ_FUSE_DATA1_DATA1(x, v) (HW_OCOTP_READ_FUSE_DATA1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_READ_FUSE_DATA2 - OTP Controller Read Data Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_READ_FUSE_DATA2 - OTP Controller Read Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_read_fuse_data2
{
    uint32_t U;
    struct _hw_ocotp_read_fuse_data2_bitfields
    {
        uint32_t DATA2 : 32;           /*!< [31:0]  */
    } B;
} hw_ocotp_read_fuse_data2_t;

/*!
 * @name Constants and macros for entire OCOTP_READ_FUSE_DATA2 register
 */
/*@{*/
#define HW_OCOTP_READ_FUSE_DATA2_ADDR(x) ((uintptr_t)(x) + 0x90U)

#define HW_OCOTP_READ_FUSE_DATA2(x) (*(__IO hw_ocotp_read_fuse_data2_t *) HW_OCOTP_READ_FUSE_DATA2_ADDR(x))
#define HW_OCOTP_READ_FUSE_DATA2_RD(x) (HW_OCOTP_READ_FUSE_DATA2(x).U)
#define HW_OCOTP_READ_FUSE_DATA2_WR(x, v) (HW_OCOTP_READ_FUSE_DATA2(x).U = (v))
#define HW_OCOTP_READ_FUSE_DATA2_SET(x, v) (HW_OCOTP_READ_FUSE_DATA2_WR(x, HW_OCOTP_READ_FUSE_DATA2_RD(x) |  (v)))
#define HW_OCOTP_READ_FUSE_DATA2_CLR(x, v) (HW_OCOTP_READ_FUSE_DATA2_WR(x, HW_OCOTP_READ_FUSE_DATA2_RD(x) & ~(v)))
#define HW_OCOTP_READ_FUSE_DATA2_TOG(x, v) (HW_OCOTP_READ_FUSE_DATA2_WR(x, HW_OCOTP_READ_FUSE_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_READ_FUSE_DATA2 bitfields
 */

/*!
 * @name Register OCOTP_READ_FUSE_DATA2, field DATA2[31:0] (RW)
 *
 * The third fuse word data read from one OTP.
 */
/*@{*/
#define BP_OCOTP_READ_FUSE_DATA2_DATA2 (0U) /*!< Bit position for OCOTP_READ_FUSE_DATA2_DATA2. */
#define BM_OCOTP_READ_FUSE_DATA2_DATA2 (0xFFFFFFFFU) /*!< Bit mask for OCOTP_READ_FUSE_DATA2_DATA2. */
#define BS_OCOTP_READ_FUSE_DATA2_DATA2 (32U) /*!< Bit field size in bits for OCOTP_READ_FUSE_DATA2_DATA2. */

/*! @brief Read current value of the OCOTP_READ_FUSE_DATA2_DATA2 field. */
#define BR_OCOTP_READ_FUSE_DATA2_DATA2(x) (HW_OCOTP_READ_FUSE_DATA2(x).U)

/*! @brief Format value for bitfield OCOTP_READ_FUSE_DATA2_DATA2. */
#define BF_OCOTP_READ_FUSE_DATA2_DATA2(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_READ_FUSE_DATA2_DATA2) & BM_OCOTP_READ_FUSE_DATA2_DATA2)

/*! @brief Set the DATA2 field to a new value. */
#define BW_OCOTP_READ_FUSE_DATA2_DATA2(x, v) (HW_OCOTP_READ_FUSE_DATA2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_READ_FUSE_DATA3 - OTP Controller Read Data Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_READ_FUSE_DATA3 - OTP Controller Read Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_read_fuse_data3
{
    uint32_t U;
    struct _hw_ocotp_read_fuse_data3_bitfields
    {
        uint32_t DATA3 : 32;           /*!< [31:0]  */
    } B;
} hw_ocotp_read_fuse_data3_t;

/*!
 * @name Constants and macros for entire OCOTP_READ_FUSE_DATA3 register
 */
/*@{*/
#define HW_OCOTP_READ_FUSE_DATA3_ADDR(x) ((uintptr_t)(x) + 0xA0U)

#define HW_OCOTP_READ_FUSE_DATA3(x) (*(__IO hw_ocotp_read_fuse_data3_t *) HW_OCOTP_READ_FUSE_DATA3_ADDR(x))
#define HW_OCOTP_READ_FUSE_DATA3_RD(x) (HW_OCOTP_READ_FUSE_DATA3(x).U)
#define HW_OCOTP_READ_FUSE_DATA3_WR(x, v) (HW_OCOTP_READ_FUSE_DATA3(x).U = (v))
#define HW_OCOTP_READ_FUSE_DATA3_SET(x, v) (HW_OCOTP_READ_FUSE_DATA3_WR(x, HW_OCOTP_READ_FUSE_DATA3_RD(x) |  (v)))
#define HW_OCOTP_READ_FUSE_DATA3_CLR(x, v) (HW_OCOTP_READ_FUSE_DATA3_WR(x, HW_OCOTP_READ_FUSE_DATA3_RD(x) & ~(v)))
#define HW_OCOTP_READ_FUSE_DATA3_TOG(x, v) (HW_OCOTP_READ_FUSE_DATA3_WR(x, HW_OCOTP_READ_FUSE_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_READ_FUSE_DATA3 bitfields
 */

/*!
 * @name Register OCOTP_READ_FUSE_DATA3, field DATA3[31:0] (RW)
 *
 * The last fuse word data read from one OTP.
 */
/*@{*/
#define BP_OCOTP_READ_FUSE_DATA3_DATA3 (0U) /*!< Bit position for OCOTP_READ_FUSE_DATA3_DATA3. */
#define BM_OCOTP_READ_FUSE_DATA3_DATA3 (0xFFFFFFFFU) /*!< Bit mask for OCOTP_READ_FUSE_DATA3_DATA3. */
#define BS_OCOTP_READ_FUSE_DATA3_DATA3 (32U) /*!< Bit field size in bits for OCOTP_READ_FUSE_DATA3_DATA3. */

/*! @brief Read current value of the OCOTP_READ_FUSE_DATA3_DATA3 field. */
#define BR_OCOTP_READ_FUSE_DATA3_DATA3(x) (HW_OCOTP_READ_FUSE_DATA3(x).U)

/*! @brief Format value for bitfield OCOTP_READ_FUSE_DATA3_DATA3. */
#define BF_OCOTP_READ_FUSE_DATA3_DATA3(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_READ_FUSE_DATA3_DATA3) & BM_OCOTP_READ_FUSE_DATA3_DATA3)

/*! @brief Set the DATA3 field to a new value. */
#define BW_OCOTP_READ_FUSE_DATA3_DATA3(x, v) (HW_OCOTP_READ_FUSE_DATA3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SW_STICKY - Sticky bit Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SW_STICKY - Sticky bit Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Some sticky bits are used by software to lock some fuse area, shadow
 * registers, and other features. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_sw_sticky
{
    uint32_t U;
    struct _hw_ocotp_sw_sticky_bitfields
    {
        uint32_t RSVD0 : 1;            /*!< [0] This field is reserved. */
        uint32_t SRK_REVOKE_LOCK : 1;  /*!< [1]  */
        uint32_t FIELD_RETURN_LOCK : 1; /*!< [2]  */
        uint32_t RSVD1 : 29;           /*!< [31:3] This field is reserved. */
    } B;
} hw_ocotp_sw_sticky_t;

/*!
 * @name Constants and macros for entire OCOTP_SW_STICKY register
 */
/*@{*/
#define HW_OCOTP_SW_STICKY_ADDR(x) ((uintptr_t)(x) + 0xB0U)

#define HW_OCOTP_SW_STICKY(x)    (*(__IO hw_ocotp_sw_sticky_t *) HW_OCOTP_SW_STICKY_ADDR(x))
#define HW_OCOTP_SW_STICKY_RD(x) (HW_OCOTP_SW_STICKY(x).U)
#define HW_OCOTP_SW_STICKY_WR(x, v) (HW_OCOTP_SW_STICKY(x).U = (v))
#define HW_OCOTP_SW_STICKY_SET(x, v) (HW_OCOTP_SW_STICKY_WR(x, HW_OCOTP_SW_STICKY_RD(x) |  (v)))
#define HW_OCOTP_SW_STICKY_CLR(x, v) (HW_OCOTP_SW_STICKY_WR(x, HW_OCOTP_SW_STICKY_RD(x) & ~(v)))
#define HW_OCOTP_SW_STICKY_TOG(x, v) (HW_OCOTP_SW_STICKY_WR(x, HW_OCOTP_SW_STICKY_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SW_STICKY bitfields
 */

/*!
 * @name Register OCOTP_SW_STICKY, field RSVD0[0] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_OCOTP_SW_STICKY_RSVD0 (0U)      /*!< Bit position for OCOTP_SW_STICKY_RSVD0. */
#define BM_OCOTP_SW_STICKY_RSVD0 (0x00000001U) /*!< Bit mask for OCOTP_SW_STICKY_RSVD0. */
#define BS_OCOTP_SW_STICKY_RSVD0 (1U)      /*!< Bit field size in bits for OCOTP_SW_STICKY_RSVD0. */

/*! @brief Read current value of the OCOTP_SW_STICKY_RSVD0 field. */
#define BR_OCOTP_SW_STICKY_RSVD0(x) (HW_OCOTP_SW_STICKY(x).B.RSVD0)
/*@}*/

/*!
 * @name Register OCOTP_SW_STICKY, field SRK_REVOKE_LOCK[1] (RW)
 *
 * Shadow register write and OTP write lock for SRK_REVOKE region. When set, the
 * writing of this region's shadow register and OTP fuse word are blocked. Once
 * this bit is set, it is always high unless a POR is issued.
 */
/*@{*/
#define BP_OCOTP_SW_STICKY_SRK_REVOKE_LOCK (1U) /*!< Bit position for OCOTP_SW_STICKY_SRK_REVOKE_LOCK. */
#define BM_OCOTP_SW_STICKY_SRK_REVOKE_LOCK (0x00000002U) /*!< Bit mask for OCOTP_SW_STICKY_SRK_REVOKE_LOCK. */
#define BS_OCOTP_SW_STICKY_SRK_REVOKE_LOCK (1U) /*!< Bit field size in bits for OCOTP_SW_STICKY_SRK_REVOKE_LOCK. */

/*! @brief Read current value of the OCOTP_SW_STICKY_SRK_REVOKE_LOCK field. */
#define BR_OCOTP_SW_STICKY_SRK_REVOKE_LOCK(x) (HW_OCOTP_SW_STICKY(x).B.SRK_REVOKE_LOCK)

/*! @brief Format value for bitfield OCOTP_SW_STICKY_SRK_REVOKE_LOCK. */
#define BF_OCOTP_SW_STICKY_SRK_REVOKE_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SW_STICKY_SRK_REVOKE_LOCK) & BM_OCOTP_SW_STICKY_SRK_REVOKE_LOCK)

/*! @brief Set the SRK_REVOKE_LOCK field to a new value. */
#define BW_OCOTP_SW_STICKY_SRK_REVOKE_LOCK(x, v) (HW_OCOTP_SW_STICKY_WR(x, (HW_OCOTP_SW_STICKY_RD(x) & ~BM_OCOTP_SW_STICKY_SRK_REVOKE_LOCK) | BF_OCOTP_SW_STICKY_SRK_REVOKE_LOCK(v)))
/*@}*/

/*!
 * @name Register OCOTP_SW_STICKY, field FIELD_RETURN_LOCK[2] (RW)
 *
 * Shadow register write and OTP write lock for FIELD_RETURN region. When set,
 * the writing of this region's shadow register and OTP fuse word are blocked.
 * Once this bit is set, it is always high unless a POR is issued.
 */
/*@{*/
#define BP_OCOTP_SW_STICKY_FIELD_RETURN_LOCK (2U) /*!< Bit position for OCOTP_SW_STICKY_FIELD_RETURN_LOCK. */
#define BM_OCOTP_SW_STICKY_FIELD_RETURN_LOCK (0x00000004U) /*!< Bit mask for OCOTP_SW_STICKY_FIELD_RETURN_LOCK. */
#define BS_OCOTP_SW_STICKY_FIELD_RETURN_LOCK (1U) /*!< Bit field size in bits for OCOTP_SW_STICKY_FIELD_RETURN_LOCK. */

/*! @brief Read current value of the OCOTP_SW_STICKY_FIELD_RETURN_LOCK field. */
#define BR_OCOTP_SW_STICKY_FIELD_RETURN_LOCK(x) (HW_OCOTP_SW_STICKY(x).B.FIELD_RETURN_LOCK)

/*! @brief Format value for bitfield OCOTP_SW_STICKY_FIELD_RETURN_LOCK. */
#define BF_OCOTP_SW_STICKY_FIELD_RETURN_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SW_STICKY_FIELD_RETURN_LOCK) & BM_OCOTP_SW_STICKY_FIELD_RETURN_LOCK)

/*! @brief Set the FIELD_RETURN_LOCK field to a new value. */
#define BW_OCOTP_SW_STICKY_FIELD_RETURN_LOCK(x, v) (HW_OCOTP_SW_STICKY_WR(x, (HW_OCOTP_SW_STICKY_RD(x) & ~BM_OCOTP_SW_STICKY_FIELD_RETURN_LOCK) | BF_OCOTP_SW_STICKY_FIELD_RETURN_LOCK(v)))
/*@}*/

/*!
 * @name Register OCOTP_SW_STICKY, field RSVD1[31:3] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_OCOTP_SW_STICKY_RSVD1 (3U)      /*!< Bit position for OCOTP_SW_STICKY_RSVD1. */
#define BM_OCOTP_SW_STICKY_RSVD1 (0xFFFFFFF8U) /*!< Bit mask for OCOTP_SW_STICKY_RSVD1. */
#define BS_OCOTP_SW_STICKY_RSVD1 (29U)     /*!< Bit field size in bits for OCOTP_SW_STICKY_RSVD1. */

/*! @brief Read current value of the OCOTP_SW_STICKY_RSVD1 field. */
#define BR_OCOTP_SW_STICKY_RSVD1(x) (HW_OCOTP_SW_STICKY(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SCS - Software Controllable Signals Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SCS - Software Controllable Signals Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * OCOTP_SCS: 0x0C0 OCOTP_SCS_SET: 0x0C4 OCOTP_SCS_CLR: 0x0C8 OCOTP_SCS_TOG:
 * 0x0CC This register holds volatile configuration values that can be set and
 * locked by verified software. All values are back to their default values after POR.
 * EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_scs
{
    uint32_t U;
    struct _hw_ocotp_scs_bitfields
    {
        uint32_t HAB_JDE : 1;          /*!< [0] HAB JTAG Debug Enable. */
        uint32_t SPARE : 30;           /*!< [30:1]  */
        uint32_t LOCK : 1;             /*!< [31]  */
    } B;
} hw_ocotp_scs_t;

/*!
 * @name Constants and macros for entire OCOTP_SCS register
 */
/*@{*/
#define HW_OCOTP_SCS_ADDR(x)     ((uintptr_t)(x) + 0xC0U)
#define HW_OCOTP_SCS_SET_ADDR(x) (HW_OCOTP_SCS_ADDR(x) + 0x4U)
#define HW_OCOTP_SCS_CLR_ADDR(x) (HW_OCOTP_SCS_ADDR(x) + 0x8U)
#define HW_OCOTP_SCS_TOG_ADDR(x) (HW_OCOTP_SCS_ADDR(x) + 0xCU)

#define HW_OCOTP_SCS(x)          (*(__IO hw_ocotp_scs_t *) HW_OCOTP_SCS_ADDR(x))
#define HW_OCOTP_SCS_RD(x)       (HW_OCOTP_SCS(x).U)
#define HW_OCOTP_SCS_WR(x, v)    (HW_OCOTP_SCS(x).U = (v))
#define HW_OCOTP_SCS_SET(x, v)   ((*(uint32_t *) HW_OCOTP_SCS_SET_ADDR(x)) = (v))
#define HW_OCOTP_SCS_CLR(x, v)   ((*(uint32_t *) HW_OCOTP_SCS_CLR_ADDR(x)) = (v))
#define HW_OCOTP_SCS_TOG(x, v)   ((*(uint32_t *) HW_OCOTP_SCS_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SCS bitfields
 */

/*!
 * @name Register OCOTP_SCS, field HAB_JDE[0] (RW)
 *
 * This bit is used by the HAB to enable JTAG debugging, assuming that a
 * properly signed command to do it, so it can be found and validated by the HAB. The
 * HAB must lock the register before passing control to the OS depend on whether
 * JTAG debugging has been enabled. Once JTAG is enabled by this bit, it cannot be
 * disabled unless the system is reset by POR.
 *
 * Values:
 * - 0 - JTAG debugging is not enabled by the HAB (it can be enabled by other
 *     mechanisms).
 * - 1 - JTAG debugging is enabled by the HAB (though this signal may be gated
 *     off).
 */
/*@{*/
#define BP_OCOTP_SCS_HAB_JDE (0U)          /*!< Bit position for OCOTP_SCS_HAB_JDE. */
#define BM_OCOTP_SCS_HAB_JDE (0x00000001U) /*!< Bit mask for OCOTP_SCS_HAB_JDE. */
#define BS_OCOTP_SCS_HAB_JDE (1U)          /*!< Bit field size in bits for OCOTP_SCS_HAB_JDE. */

/*! @brief Read current value of the OCOTP_SCS_HAB_JDE field. */
#define BR_OCOTP_SCS_HAB_JDE(x) (HW_OCOTP_SCS(x).B.HAB_JDE)

/*! @brief Format value for bitfield OCOTP_SCS_HAB_JDE. */
#define BF_OCOTP_SCS_HAB_JDE(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SCS_HAB_JDE) & BM_OCOTP_SCS_HAB_JDE)

/*! @brief Set the HAB_JDE field to a new value. */
#define BW_OCOTP_SCS_HAB_JDE(x, v) (HW_OCOTP_SCS_WR(x, (HW_OCOTP_SCS_RD(x) & ~BM_OCOTP_SCS_HAB_JDE) | BF_OCOTP_SCS_HAB_JDE(v)))
/*@}*/

/*!
 * @name Register OCOTP_SCS, field SPARE[30:1] (RW)
 *
 * Unallocated read / write bits of implementation for specific software use.
 */
/*@{*/
#define BP_OCOTP_SCS_SPARE   (1U)          /*!< Bit position for OCOTP_SCS_SPARE. */
#define BM_OCOTP_SCS_SPARE   (0x7FFFFFFEU) /*!< Bit mask for OCOTP_SCS_SPARE. */
#define BS_OCOTP_SCS_SPARE   (30U)         /*!< Bit field size in bits for OCOTP_SCS_SPARE. */

/*! @brief Read current value of the OCOTP_SCS_SPARE field. */
#define BR_OCOTP_SCS_SPARE(x) (HW_OCOTP_SCS(x).B.SPARE)

/*! @brief Format value for bitfield OCOTP_SCS_SPARE. */
#define BF_OCOTP_SCS_SPARE(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SCS_SPARE) & BM_OCOTP_SCS_SPARE)

/*! @brief Set the SPARE field to a new value. */
#define BW_OCOTP_SCS_SPARE(x, v) (HW_OCOTP_SCS_WR(x, (HW_OCOTP_SCS_RD(x) & ~BM_OCOTP_SCS_SPARE) | BF_OCOTP_SCS_SPARE(v)))
/*@}*/

/*!
 * @name Register OCOTP_SCS, field LOCK[31] (RW)
 *
 * When set, all of the bits in this register are locked and cannot be changed
 * during SW programming. This bit is only reset after a POR is issued.
 */
/*@{*/
#define BP_OCOTP_SCS_LOCK    (31U)         /*!< Bit position for OCOTP_SCS_LOCK. */
#define BM_OCOTP_SCS_LOCK    (0x80000000U) /*!< Bit mask for OCOTP_SCS_LOCK. */
#define BS_OCOTP_SCS_LOCK    (1U)          /*!< Bit field size in bits for OCOTP_SCS_LOCK. */

/*! @brief Read current value of the OCOTP_SCS_LOCK field. */
#define BR_OCOTP_SCS_LOCK(x) (HW_OCOTP_SCS(x).B.LOCK)

/*! @brief Format value for bitfield OCOTP_SCS_LOCK. */
#define BF_OCOTP_SCS_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SCS_LOCK) & BM_OCOTP_SCS_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_OCOTP_SCS_LOCK(x, v) (HW_OCOTP_SCS_WR(x, (HW_OCOTP_SCS_RD(x) & ~BM_OCOTP_SCS_LOCK) | BF_OCOTP_SCS_LOCK(v)))
/*@}*/




/*******************************************************************************
 * HW_OCOTP_CRC_ADDR - OTP Controller CRC test address
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_CRC_ADDR - OTP Controller CRC test address (RW)
 *
 * Reset value: 0x00000000U
 *
 * The OCOTP Data Register is used for OTP Read EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_crc_addr
{
    uint32_t U;
    struct _hw_ocotp_crc_addr_bitfields
    {
        uint32_t DATA_START_ADDR : 8;  /*!< [7:0]  */
        uint32_t DATA_END_ADDR : 8;    /*!< [15:8]  */
        uint32_t CRC_ADDR : 2;         /*!< [17:16]  */
        uint32_t RSVD0 : 14;           /*!< [31:18] This field is reserved. */
    } B;
} hw_ocotp_crc_addr_t;

/*!
 * @name Constants and macros for entire OCOTP_CRC_ADDR register
 */
/*@{*/
#define HW_OCOTP_CRC_ADDR_ADDR(x) ((uintptr_t)(x) + 0xD0U)

#define HW_OCOTP_CRC_ADDR(x)     (*(__IO hw_ocotp_crc_addr_t *) HW_OCOTP_CRC_ADDR_ADDR(x))
#define HW_OCOTP_CRC_ADDR_RD(x)  (HW_OCOTP_CRC_ADDR(x).U)
#define HW_OCOTP_CRC_ADDR_WR(x, v) (HW_OCOTP_CRC_ADDR(x).U = (v))
#define HW_OCOTP_CRC_ADDR_SET(x, v) (HW_OCOTP_CRC_ADDR_WR(x, HW_OCOTP_CRC_ADDR_RD(x) |  (v)))
#define HW_OCOTP_CRC_ADDR_CLR(x, v) (HW_OCOTP_CRC_ADDR_WR(x, HW_OCOTP_CRC_ADDR_RD(x) & ~(v)))
#define HW_OCOTP_CRC_ADDR_TOG(x, v) (HW_OCOTP_CRC_ADDR_WR(x, HW_OCOTP_CRC_ADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_CRC_ADDR bitfields
 */

/*!
 * @name Register OCOTP_CRC_ADDR, field DATA_START_ADDR[7:0] (RW)
 *
 * Start address of fuse word location is for CRC calculation.
 */
/*@{*/
#define BP_OCOTP_CRC_ADDR_DATA_START_ADDR (0U) /*!< Bit position for OCOTP_CRC_ADDR_DATA_START_ADDR. */
#define BM_OCOTP_CRC_ADDR_DATA_START_ADDR (0x000000FFU) /*!< Bit mask for OCOTP_CRC_ADDR_DATA_START_ADDR. */
#define BS_OCOTP_CRC_ADDR_DATA_START_ADDR (8U) /*!< Bit field size in bits for OCOTP_CRC_ADDR_DATA_START_ADDR. */

/*! @brief Read current value of the OCOTP_CRC_ADDR_DATA_START_ADDR field. */
#define BR_OCOTP_CRC_ADDR_DATA_START_ADDR(x) (HW_OCOTP_CRC_ADDR(x).B.DATA_START_ADDR)

/*! @brief Format value for bitfield OCOTP_CRC_ADDR_DATA_START_ADDR. */
#define BF_OCOTP_CRC_ADDR_DATA_START_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CRC_ADDR_DATA_START_ADDR) & BM_OCOTP_CRC_ADDR_DATA_START_ADDR)

/*! @brief Set the DATA_START_ADDR field to a new value. */
#define BW_OCOTP_CRC_ADDR_DATA_START_ADDR(x, v) (HW_OCOTP_CRC_ADDR_WR(x, (HW_OCOTP_CRC_ADDR_RD(x) & ~BM_OCOTP_CRC_ADDR_DATA_START_ADDR) | BF_OCOTP_CRC_ADDR_DATA_START_ADDR(v)))
/*@}*/

/*!
 * @name Register OCOTP_CRC_ADDR, field DATA_END_ADDR[15:8] (RW)
 *
 * End address of fuse word location is for CRC calculation.
 */
/*@{*/
#define BP_OCOTP_CRC_ADDR_DATA_END_ADDR (8U) /*!< Bit position for OCOTP_CRC_ADDR_DATA_END_ADDR. */
#define BM_OCOTP_CRC_ADDR_DATA_END_ADDR (0x0000FF00U) /*!< Bit mask for OCOTP_CRC_ADDR_DATA_END_ADDR. */
#define BS_OCOTP_CRC_ADDR_DATA_END_ADDR (8U) /*!< Bit field size in bits for OCOTP_CRC_ADDR_DATA_END_ADDR. */

/*! @brief Read current value of the OCOTP_CRC_ADDR_DATA_END_ADDR field. */
#define BR_OCOTP_CRC_ADDR_DATA_END_ADDR(x) (HW_OCOTP_CRC_ADDR(x).B.DATA_END_ADDR)

/*! @brief Format value for bitfield OCOTP_CRC_ADDR_DATA_END_ADDR. */
#define BF_OCOTP_CRC_ADDR_DATA_END_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CRC_ADDR_DATA_END_ADDR) & BM_OCOTP_CRC_ADDR_DATA_END_ADDR)

/*! @brief Set the DATA_END_ADDR field to a new value. */
#define BW_OCOTP_CRC_ADDR_DATA_END_ADDR(x, v) (HW_OCOTP_CRC_ADDR_WR(x, (HW_OCOTP_CRC_ADDR_RD(x) & ~BM_OCOTP_CRC_ADDR_DATA_END_ADDR) | BF_OCOTP_CRC_ADDR_DATA_END_ADDR(v)))
/*@}*/

/*!
 * @name Register OCOTP_CRC_ADDR, field CRC_ADDR[17:16] (RW)
 *
 * Address of 32-bit CRC result is for comparing.
 */
/*@{*/
#define BP_OCOTP_CRC_ADDR_CRC_ADDR (16U)   /*!< Bit position for OCOTP_CRC_ADDR_CRC_ADDR. */
#define BM_OCOTP_CRC_ADDR_CRC_ADDR (0x00030000U) /*!< Bit mask for OCOTP_CRC_ADDR_CRC_ADDR. */
#define BS_OCOTP_CRC_ADDR_CRC_ADDR (2U)    /*!< Bit field size in bits for OCOTP_CRC_ADDR_CRC_ADDR. */

/*! @brief Read current value of the OCOTP_CRC_ADDR_CRC_ADDR field. */
#define BR_OCOTP_CRC_ADDR_CRC_ADDR(x) (HW_OCOTP_CRC_ADDR(x).B.CRC_ADDR)

/*! @brief Format value for bitfield OCOTP_CRC_ADDR_CRC_ADDR. */
#define BF_OCOTP_CRC_ADDR_CRC_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CRC_ADDR_CRC_ADDR) & BM_OCOTP_CRC_ADDR_CRC_ADDR)

/*! @brief Set the CRC_ADDR field to a new value. */
#define BW_OCOTP_CRC_ADDR_CRC_ADDR(x, v) (HW_OCOTP_CRC_ADDR_WR(x, (HW_OCOTP_CRC_ADDR_RD(x) & ~BM_OCOTP_CRC_ADDR_CRC_ADDR) | BF_OCOTP_CRC_ADDR_CRC_ADDR(v)))
/*@}*/

/*!
 * @name Register OCOTP_CRC_ADDR, field RSVD0[31:18] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_OCOTP_CRC_ADDR_RSVD0 (18U)      /*!< Bit position for OCOTP_CRC_ADDR_RSVD0. */
#define BM_OCOTP_CRC_ADDR_RSVD0 (0xFFFC0000U) /*!< Bit mask for OCOTP_CRC_ADDR_RSVD0. */
#define BS_OCOTP_CRC_ADDR_RSVD0 (14U)      /*!< Bit field size in bits for OCOTP_CRC_ADDR_RSVD0. */

/*! @brief Read current value of the OCOTP_CRC_ADDR_RSVD0 field. */
#define BR_OCOTP_CRC_ADDR_RSVD0(x) (HW_OCOTP_CRC_ADDR(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_OCOTP_CRC_VALUE - OTP Controller CRC Value Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_CRC_VALUE - OTP Controller CRC Value Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The CRC32 value is based on CRC_ADDR. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_crc_value
{
    uint32_t U;
    struct _hw_ocotp_crc_value_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_crc_value_t;

/*!
 * @name Constants and macros for entire OCOTP_CRC_VALUE register
 */
/*@{*/
#define HW_OCOTP_CRC_VALUE_ADDR(x) ((uintptr_t)(x) + 0xE0U)

#define HW_OCOTP_CRC_VALUE(x)    (*(__IO hw_ocotp_crc_value_t *) HW_OCOTP_CRC_VALUE_ADDR(x))
#define HW_OCOTP_CRC_VALUE_RD(x) (HW_OCOTP_CRC_VALUE(x).U)
#define HW_OCOTP_CRC_VALUE_WR(x, v) (HW_OCOTP_CRC_VALUE(x).U = (v))
#define HW_OCOTP_CRC_VALUE_SET(x, v) (HW_OCOTP_CRC_VALUE_WR(x, HW_OCOTP_CRC_VALUE_RD(x) |  (v)))
#define HW_OCOTP_CRC_VALUE_CLR(x, v) (HW_OCOTP_CRC_VALUE_WR(x, HW_OCOTP_CRC_VALUE_RD(x) & ~(v)))
#define HW_OCOTP_CRC_VALUE_TOG(x, v) (HW_OCOTP_CRC_VALUE_WR(x, HW_OCOTP_CRC_VALUE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_CRC_VALUE bitfields
 */

/*!
 * @name Register OCOTP_CRC_VALUE, field DATA[31:0] (RW)
 *
 * The CRC32 value is based on CRC_ADDR.
 */
/*@{*/
#define BP_OCOTP_CRC_VALUE_DATA (0U)       /*!< Bit position for OCOTP_CRC_VALUE_DATA. */
#define BM_OCOTP_CRC_VALUE_DATA (0xFFFFFFFFU) /*!< Bit mask for OCOTP_CRC_VALUE_DATA. */
#define BS_OCOTP_CRC_VALUE_DATA (32U)      /*!< Bit field size in bits for OCOTP_CRC_VALUE_DATA. */

/*! @brief Read current value of the OCOTP_CRC_VALUE_DATA field. */
#define BR_OCOTP_CRC_VALUE_DATA(x) (HW_OCOTP_CRC_VALUE(x).U)

/*! @brief Format value for bitfield OCOTP_CRC_VALUE_DATA. */
#define BF_OCOTP_CRC_VALUE_DATA(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CRC_VALUE_DATA) & BM_OCOTP_CRC_VALUE_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_OCOTP_CRC_VALUE_DATA(x, v) (HW_OCOTP_CRC_VALUE_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_VERSION - OTP Controller Version Register
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_VERSION - OTP Controller Version Register (RO)
 *
 * Reset value: 0x03000000U
 *
 * This register always returns a known read value for debug purposes. It
 * indicates the version of the block. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_version
{
    uint32_t U;
    struct _hw_ocotp_version_bitfields
    {
        uint32_t STEP : 16;            /*!< [15:0]  */
        uint32_t MINOR : 8;            /*!< [23:16]  */
        uint32_t MAJOR : 8;            /*!< [31:24]  */
    } B;
} hw_ocotp_version_t;

/*!
 * @name Constants and macros for entire OCOTP_VERSION register
 */
/*@{*/
#define HW_OCOTP_VERSION_ADDR(x) ((uintptr_t)(x) + 0xF0U)

#define HW_OCOTP_VERSION(x)      (*(__I hw_ocotp_version_t *) HW_OCOTP_VERSION_ADDR(x))
#define HW_OCOTP_VERSION_RD(x)   (HW_OCOTP_VERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual OCOTP_VERSION bitfields
 */

/*!
 * @name Register OCOTP_VERSION, field STEP[15:0] (RO)
 *
 * Fixed read-only values reflect the stepping of the RTL version.
 */
/*@{*/
#define BP_OCOTP_VERSION_STEP (0U)         /*!< Bit position for OCOTP_VERSION_STEP. */
#define BM_OCOTP_VERSION_STEP (0x0000FFFFU) /*!< Bit mask for OCOTP_VERSION_STEP. */
#define BS_OCOTP_VERSION_STEP (16U)        /*!< Bit field size in bits for OCOTP_VERSION_STEP. */

/*! @brief Read current value of the OCOTP_VERSION_STEP field. */
#define BR_OCOTP_VERSION_STEP(x) (HW_OCOTP_VERSION(x).B.STEP)
/*@}*/

/*!
 * @name Register OCOTP_VERSION, field MINOR[23:16] (RO)
 *
 * Fixed read-only values reflect the MINOR field of the RTL version.
 */
/*@{*/
#define BP_OCOTP_VERSION_MINOR (16U)       /*!< Bit position for OCOTP_VERSION_MINOR. */
#define BM_OCOTP_VERSION_MINOR (0x00FF0000U) /*!< Bit mask for OCOTP_VERSION_MINOR. */
#define BS_OCOTP_VERSION_MINOR (8U)        /*!< Bit field size in bits for OCOTP_VERSION_MINOR. */

/*! @brief Read current value of the OCOTP_VERSION_MINOR field. */
#define BR_OCOTP_VERSION_MINOR(x) (HW_OCOTP_VERSION(x).B.MINOR)
/*@}*/

/*!
 * @name Register OCOTP_VERSION, field MAJOR[31:24] (RO)
 *
 * Fixed read-only values reflect the MAJOR field of the RTL version.
 */
/*@{*/
#define BP_OCOTP_VERSION_MAJOR (24U)       /*!< Bit position for OCOTP_VERSION_MAJOR. */
#define BM_OCOTP_VERSION_MAJOR (0xFF000000U) /*!< Bit mask for OCOTP_VERSION_MAJOR. */
#define BS_OCOTP_VERSION_MAJOR (8U)        /*!< Bit field size in bits for OCOTP_VERSION_MAJOR. */

/*! @brief Read current value of the OCOTP_VERSION_MAJOR field. */
#define BR_OCOTP_VERSION_MAJOR(x) (HW_OCOTP_VERSION(x).B.MAJOR)
/*@}*/

/*******************************************************************************
 * HW_OCOTP_LOCK - Value of OTP Bank0 Word0 (Lock controls)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_LOCK - Value of OTP Bank0 Word0 (Lock controls) (RO)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS] EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_lock
{
    uint32_t U;
    struct _hw_ocotp_lock_bitfields
    {
        uint32_t TESTER : 2;           /*!< [1:0]  */
        uint32_t BOOT_CFG : 2;         /*!< [3:2]  */
        uint32_t MEM_TRIM : 2;         /*!< [5:4]  */
        uint32_t ANALOG : 2;           /*!< [7:6]  */
        uint32_t OTPMK : 1;            /*!< [8]  */
        uint32_t SRK : 1;              /*!< [9]  */
        uint32_t SJC_RESP : 1;         /*!< [10]  */
        uint32_t RSVD0 : 1;            /*!< [11] This field is reserved. */
        uint32_t USB_ID : 2;           /*!< [13:12]  */
        uint32_t MAC_ADDR : 2;         /*!< [15:14]  */
        uint32_t MAU_KEY : 1;          /*!< [16]  */
        uint32_t ROM_PATCH : 1;        /*!< [17]  */
        uint32_t RSVD1 : 2;            /*!< [19:18] This field is reserved. */
        uint32_t GP1 : 2;              /*!< [21:20]  */
        uint32_t GP2 : 2;              /*!< [23:22]  */
        uint32_t RSVD2 : 4;            /*!< [27:24] This field is reserved. */
        uint32_t CRC_GP1 : 2;          /*!< [29:28]  */
        uint32_t CRC_GP2 : 2;          /*!< [31:30]  */
    } B;
} hw_ocotp_lock_t;

/*!
 * @name Constants and macros for entire OCOTP_LOCK register
 */
/*@{*/
#define HW_OCOTP_LOCK_ADDR(x)    ((uintptr_t)(x) + 0x400U)

#define HW_OCOTP_LOCK(x)         (*(__I hw_ocotp_lock_t *) HW_OCOTP_LOCK_ADDR(x))
#define HW_OCOTP_LOCK_RD(x)      (HW_OCOTP_LOCK(x).U)
/*@}*/

/*
 * Constants & macros for individual OCOTP_LOCK bitfields
 */

/*!
 * @name Register OCOTP_LOCK, field TESTER[1:0] (RO)
 *
 * Status of shadow register and OTP write lock for tester region. When bit 1 is
 * set, the writing of this region's shadow register is blocked. When bit 0 is
 * set, the writing of this region's OTP fuse word is blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_TESTER (0U)          /*!< Bit position for OCOTP_LOCK_TESTER. */
#define BM_OCOTP_LOCK_TESTER (0x00000003U) /*!< Bit mask for OCOTP_LOCK_TESTER. */
#define BS_OCOTP_LOCK_TESTER (2U)          /*!< Bit field size in bits for OCOTP_LOCK_TESTER. */

/*! @brief Read current value of the OCOTP_LOCK_TESTER field. */
#define BR_OCOTP_LOCK_TESTER(x) (HW_OCOTP_LOCK(x).B.TESTER)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field BOOT_CFG[3:2] (RO)
 *
 * Status of shadow register and OTP write lock for BOOT_CFG region. When bit 1
 * is set, the writing of this region's shadow register is blocked. When bit 0 is
 * set, the writing of this region's OTP fuse word is blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_BOOT_CFG (2U)        /*!< Bit position for OCOTP_LOCK_BOOT_CFG. */
#define BM_OCOTP_LOCK_BOOT_CFG (0x0000000CU) /*!< Bit mask for OCOTP_LOCK_BOOT_CFG. */
#define BS_OCOTP_LOCK_BOOT_CFG (2U)        /*!< Bit field size in bits for OCOTP_LOCK_BOOT_CFG. */

/*! @brief Read current value of the OCOTP_LOCK_BOOT_CFG field. */
#define BR_OCOTP_LOCK_BOOT_CFG(x) (HW_OCOTP_LOCK(x).B.BOOT_CFG)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field MEM_TRIM[5:4] (RO)
 *
 * Status of shadow register and OTP write lock for MEM_TRIM region. When bit 1
 * is set, the writing of this region's shadow register is blocked. When bit 0 is
 * set, the writing of this region's OTP fuse word is blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_MEM_TRIM (4U)        /*!< Bit position for OCOTP_LOCK_MEM_TRIM. */
#define BM_OCOTP_LOCK_MEM_TRIM (0x00000030U) /*!< Bit mask for OCOTP_LOCK_MEM_TRIM. */
#define BS_OCOTP_LOCK_MEM_TRIM (2U)        /*!< Bit field size in bits for OCOTP_LOCK_MEM_TRIM. */

/*! @brief Read current value of the OCOTP_LOCK_MEM_TRIM field. */
#define BR_OCOTP_LOCK_MEM_TRIM(x) (HW_OCOTP_LOCK(x).B.MEM_TRIM)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field ANALOG[7:6] (RO)
 *
 * Status of shadow register and OTP write lock for analog region. When bit 1 is
 * set, the writing of this region's shadow register is blocked. When bit 0 is
 * set, the writing of this region's OTP fuse word is blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_ANALOG (6U)          /*!< Bit position for OCOTP_LOCK_ANALOG. */
#define BM_OCOTP_LOCK_ANALOG (0x000000C0U) /*!< Bit mask for OCOTP_LOCK_ANALOG. */
#define BS_OCOTP_LOCK_ANALOG (2U)          /*!< Bit field size in bits for OCOTP_LOCK_ANALOG. */

/*! @brief Read current value of the OCOTP_LOCK_ANALOG field. */
#define BR_OCOTP_LOCK_ANALOG(x) (HW_OCOTP_LOCK(x).B.ANALOG)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field OTPMK[8] (RO)
 *
 * Status of shadow register read and write, OTP read and write lock for OTPMK
 * region. When set, the writing of this region's shadow register and OTP fuse
 * word are blocked. The read of this region's shadow register and OTP fuse word are
 * also blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_OTPMK  (8U)          /*!< Bit position for OCOTP_LOCK_OTPMK. */
#define BM_OCOTP_LOCK_OTPMK  (0x00000100U) /*!< Bit mask for OCOTP_LOCK_OTPMK. */
#define BS_OCOTP_LOCK_OTPMK  (1U)          /*!< Bit field size in bits for OCOTP_LOCK_OTPMK. */

/*! @brief Read current value of the OCOTP_LOCK_OTPMK field. */
#define BR_OCOTP_LOCK_OTPMK(x) (HW_OCOTP_LOCK(x).B.OTPMK)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field SRK[9] (RO)
 *
 * Status of shadow register and OTP write lock for SRK region. When set, the
 * writing of this region's shadow register and OTP fuse word are blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_SRK    (9U)          /*!< Bit position for OCOTP_LOCK_SRK. */
#define BM_OCOTP_LOCK_SRK    (0x00000200U) /*!< Bit mask for OCOTP_LOCK_SRK. */
#define BS_OCOTP_LOCK_SRK    (1U)          /*!< Bit field size in bits for OCOTP_LOCK_SRK. */

/*! @brief Read current value of the OCOTP_LOCK_SRK field. */
#define BR_OCOTP_LOCK_SRK(x) (HW_OCOTP_LOCK(x).B.SRK)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field SJC_RESP[10] (RO)
 *
 * Status of shadow register read and write, OTP read and write lock for
 * SJC_RESP region. When set, the writing of this region's shadow register and OTP fuse
 * word are blocked. The read of this region's shadow register and OTP fuse word
 * are also blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_SJC_RESP (10U)       /*!< Bit position for OCOTP_LOCK_SJC_RESP. */
#define BM_OCOTP_LOCK_SJC_RESP (0x00000400U) /*!< Bit mask for OCOTP_LOCK_SJC_RESP. */
#define BS_OCOTP_LOCK_SJC_RESP (1U)        /*!< Bit field size in bits for OCOTP_LOCK_SJC_RESP. */

/*! @brief Read current value of the OCOTP_LOCK_SJC_RESP field. */
#define BR_OCOTP_LOCK_SJC_RESP(x) (HW_OCOTP_LOCK(x).B.SJC_RESP)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field RSVD0[11] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_OCOTP_LOCK_RSVD0  (11U)         /*!< Bit position for OCOTP_LOCK_RSVD0. */
#define BM_OCOTP_LOCK_RSVD0  (0x00000800U) /*!< Bit mask for OCOTP_LOCK_RSVD0. */
#define BS_OCOTP_LOCK_RSVD0  (1U)          /*!< Bit field size in bits for OCOTP_LOCK_RSVD0. */

/*! @brief Read current value of the OCOTP_LOCK_RSVD0 field. */
#define BR_OCOTP_LOCK_RSVD0(x) (HW_OCOTP_LOCK(x).B.RSVD0)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field USB_ID[13:12] (RO)
 *
 * Status of shadow register and OTP write lock for USB_ID region. When bit 1 is
 * set, the writing of this region's shadow register is blocked. When bit 0 is
 * set, the writing of this region's OTP fuse word is blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_USB_ID (12U)         /*!< Bit position for OCOTP_LOCK_USB_ID. */
#define BM_OCOTP_LOCK_USB_ID (0x00003000U) /*!< Bit mask for OCOTP_LOCK_USB_ID. */
#define BS_OCOTP_LOCK_USB_ID (2U)          /*!< Bit field size in bits for OCOTP_LOCK_USB_ID. */

/*! @brief Read current value of the OCOTP_LOCK_USB_ID field. */
#define BR_OCOTP_LOCK_USB_ID(x) (HW_OCOTP_LOCK(x).B.USB_ID)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field MAC_ADDR[15:14] (RO)
 *
 * Status of shadow register and OTP write lock for MAC_ADDR region. When bit 1
 * is set, the writing of this region's shadow register is blocked. When bit 0 is
 * set, the writing of this region's OTP fuse word is blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_MAC_ADDR (14U)       /*!< Bit position for OCOTP_LOCK_MAC_ADDR. */
#define BM_OCOTP_LOCK_MAC_ADDR (0x0000C000U) /*!< Bit mask for OCOTP_LOCK_MAC_ADDR. */
#define BS_OCOTP_LOCK_MAC_ADDR (2U)        /*!< Bit field size in bits for OCOTP_LOCK_MAC_ADDR. */

/*! @brief Read current value of the OCOTP_LOCK_MAC_ADDR field. */
#define BR_OCOTP_LOCK_MAC_ADDR(x) (HW_OCOTP_LOCK(x).B.MAC_ADDR)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field MAU_KEY[16] (RO)
 *
 * Status of shadow register read and write, OTP read and write lock for
 * MANUFACTURE_KEY region. When set, the writing of this region's shadow register and
 * OTP fuse word are blocked. The read of this region's shadow register and OTP
 * fuse word are also blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_MAU_KEY (16U)        /*!< Bit position for OCOTP_LOCK_MAU_KEY. */
#define BM_OCOTP_LOCK_MAU_KEY (0x00010000U) /*!< Bit mask for OCOTP_LOCK_MAU_KEY. */
#define BS_OCOTP_LOCK_MAU_KEY (1U)         /*!< Bit field size in bits for OCOTP_LOCK_MAU_KEY. */

/*! @brief Read current value of the OCOTP_LOCK_MAU_KEY field. */
#define BR_OCOTP_LOCK_MAU_KEY(x) (HW_OCOTP_LOCK(x).B.MAU_KEY)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field ROM_PATCH[17] (RO)
 *
 * Status of shadow register and OTP write lock for ROM_PATCH region. When set,
 * the writing of this region's shadow register and OTP fuse word are blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_ROM_PATCH (17U)      /*!< Bit position for OCOTP_LOCK_ROM_PATCH. */
#define BM_OCOTP_LOCK_ROM_PATCH (0x00020000U) /*!< Bit mask for OCOTP_LOCK_ROM_PATCH. */
#define BS_OCOTP_LOCK_ROM_PATCH (1U)       /*!< Bit field size in bits for OCOTP_LOCK_ROM_PATCH. */

/*! @brief Read current value of the OCOTP_LOCK_ROM_PATCH field. */
#define BR_OCOTP_LOCK_ROM_PATCH(x) (HW_OCOTP_LOCK(x).B.ROM_PATCH)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field RSVD1[19:18] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_OCOTP_LOCK_RSVD1  (18U)         /*!< Bit position for OCOTP_LOCK_RSVD1. */
#define BM_OCOTP_LOCK_RSVD1  (0x000C0000U) /*!< Bit mask for OCOTP_LOCK_RSVD1. */
#define BS_OCOTP_LOCK_RSVD1  (2U)          /*!< Bit field size in bits for OCOTP_LOCK_RSVD1. */

/*! @brief Read current value of the OCOTP_LOCK_RSVD1 field. */
#define BR_OCOTP_LOCK_RSVD1(x) (HW_OCOTP_LOCK(x).B.RSVD1)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field GP1[21:20] (RO)
 *
 * Status of shadow register and OTP write lock for GP1 region. When bit 1 is
 * set, the writing of this region's shadow register is blocked. When bit 0 is set,
 * the writing of this region's OTP fuse word is blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_GP1    (20U)         /*!< Bit position for OCOTP_LOCK_GP1. */
#define BM_OCOTP_LOCK_GP1    (0x00300000U) /*!< Bit mask for OCOTP_LOCK_GP1. */
#define BS_OCOTP_LOCK_GP1    (2U)          /*!< Bit field size in bits for OCOTP_LOCK_GP1. */

/*! @brief Read current value of the OCOTP_LOCK_GP1 field. */
#define BR_OCOTP_LOCK_GP1(x) (HW_OCOTP_LOCK(x).B.GP1)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field GP2[23:22] (RO)
 *
 * Status of shadow register and OTP write lock for GP2 region. When bit 1 is
 * set, the writing of this region's shadow register is blocked. When bit 0 is set,
 * the writing of this region's OTP fuse word is blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_GP2    (22U)         /*!< Bit position for OCOTP_LOCK_GP2. */
#define BM_OCOTP_LOCK_GP2    (0x00C00000U) /*!< Bit mask for OCOTP_LOCK_GP2. */
#define BS_OCOTP_LOCK_GP2    (2U)          /*!< Bit field size in bits for OCOTP_LOCK_GP2. */

/*! @brief Read current value of the OCOTP_LOCK_GP2 field. */
#define BR_OCOTP_LOCK_GP2(x) (HW_OCOTP_LOCK(x).B.GP2)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field RSVD2[27:24] (RO)
 *
 * This read-only field is reserved and always has the value 0.
 */
/*@{*/
#define BP_OCOTP_LOCK_RSVD2  (24U)         /*!< Bit position for OCOTP_LOCK_RSVD2. */
#define BM_OCOTP_LOCK_RSVD2  (0x0F000000U) /*!< Bit mask for OCOTP_LOCK_RSVD2. */
#define BS_OCOTP_LOCK_RSVD2  (4U)          /*!< Bit field size in bits for OCOTP_LOCK_RSVD2. */

/*! @brief Read current value of the OCOTP_LOCK_RSVD2 field. */
#define BR_OCOTP_LOCK_RSVD2(x) (HW_OCOTP_LOCK(x).B.RSVD2)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field CRC_GP1[29:28] (RO)
 *
 * Status of shadow register write and read, OTP write and read lock for CRC_GP1
 * region. When bit 1 is set, the reading and writing of this region's OTP fuse
 * and reading of shadow register are blocked. When bit 0 is set, the writing of
 * this region's shadow register and OTP fuse are blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_CRC_GP1 (28U)        /*!< Bit position for OCOTP_LOCK_CRC_GP1. */
#define BM_OCOTP_LOCK_CRC_GP1 (0x30000000U) /*!< Bit mask for OCOTP_LOCK_CRC_GP1. */
#define BS_OCOTP_LOCK_CRC_GP1 (2U)         /*!< Bit field size in bits for OCOTP_LOCK_CRC_GP1. */

/*! @brief Read current value of the OCOTP_LOCK_CRC_GP1 field. */
#define BR_OCOTP_LOCK_CRC_GP1(x) (HW_OCOTP_LOCK(x).B.CRC_GP1)
/*@}*/

/*!
 * @name Register OCOTP_LOCK, field CRC_GP2[31:30] (RO)
 *
 * Status of shadow register write and read, OTP write and read lock for CRC_GP2
 * region. When bit 1 is set, the reading and writing of this region's OTP fuse
 * and reading of shadow register are blocked. When bit 0 is set, the writing of
 * this region's shadow register and OTP fuse are blocked.
 */
/*@{*/
#define BP_OCOTP_LOCK_CRC_GP2 (30U)        /*!< Bit position for OCOTP_LOCK_CRC_GP2. */
#define BM_OCOTP_LOCK_CRC_GP2 (0xC0000000U) /*!< Bit mask for OCOTP_LOCK_CRC_GP2. */
#define BS_OCOTP_LOCK_CRC_GP2 (2U)         /*!< Bit field size in bits for OCOTP_LOCK_CRC_GP2. */

/*! @brief Read current value of the OCOTP_LOCK_CRC_GP2 field. */
#define BR_OCOTP_LOCK_CRC_GP2(x) (HW_OCOTP_LOCK(x).B.CRC_GP2)
/*@}*/

/*******************************************************************************
 * HW_OCOTP_TESTER0 - Value of OTP Bank0 Word1 (Tester Information)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_TESTER0 - Value of OTP Bank0 Word1 (Tester Information) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_tester0
{
    uint32_t U;
    struct _hw_ocotp_tester0_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_tester0_t;

/*!
 * @name Constants and macros for entire OCOTP_TESTER0 register
 */
/*@{*/
#define HW_OCOTP_TESTER0_ADDR(x) ((uintptr_t)(x) + 0x410U)

#define HW_OCOTP_TESTER0(x)      (*(__IO hw_ocotp_tester0_t *) HW_OCOTP_TESTER0_ADDR(x))
#define HW_OCOTP_TESTER0_RD(x)   (HW_OCOTP_TESTER0(x).U)
#define HW_OCOTP_TESTER0_WR(x, v) (HW_OCOTP_TESTER0(x).U = (v))
#define HW_OCOTP_TESTER0_SET(x, v) (HW_OCOTP_TESTER0_WR(x, HW_OCOTP_TESTER0_RD(x) |  (v)))
#define HW_OCOTP_TESTER0_CLR(x, v) (HW_OCOTP_TESTER0_WR(x, HW_OCOTP_TESTER0_RD(x) & ~(v)))
#define HW_OCOTP_TESTER0_TOG(x, v) (HW_OCOTP_TESTER0_WR(x, HW_OCOTP_TESTER0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_TESTER0 bitfields
 */

/*!
 * @name Register OCOTP_TESTER0, field BITS[31:0] (RW)
 *
 * It reflects value of OTP Bank 0, word 1. These bits become read-only after
 * the HW_OCOTP_LOCK_TESTER[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_TESTER0_BITS (0U)         /*!< Bit position for OCOTP_TESTER0_BITS. */
#define BM_OCOTP_TESTER0_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_TESTER0_BITS. */
#define BS_OCOTP_TESTER0_BITS (32U)        /*!< Bit field size in bits for OCOTP_TESTER0_BITS. */

/*! @brief Read current value of the OCOTP_TESTER0_BITS field. */
#define BR_OCOTP_TESTER0_BITS(x) (HW_OCOTP_TESTER0(x).U)

/*! @brief Format value for bitfield OCOTP_TESTER0_BITS. */
#define BF_OCOTP_TESTER0_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_TESTER0_BITS) & BM_OCOTP_TESTER0_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_TESTER0_BITS(x, v) (HW_OCOTP_TESTER0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_TESTER1 - Value of OTP Bank0 Word2 (Tester Information)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_TESTER1 - Value of OTP Bank0 Word2 (Tester Information) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_tester1
{
    uint32_t U;
    struct _hw_ocotp_tester1_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_tester1_t;

/*!
 * @name Constants and macros for entire OCOTP_TESTER1 register
 */
/*@{*/
#define HW_OCOTP_TESTER1_ADDR(x) ((uintptr_t)(x) + 0x420U)

#define HW_OCOTP_TESTER1(x)      (*(__IO hw_ocotp_tester1_t *) HW_OCOTP_TESTER1_ADDR(x))
#define HW_OCOTP_TESTER1_RD(x)   (HW_OCOTP_TESTER1(x).U)
#define HW_OCOTP_TESTER1_WR(x, v) (HW_OCOTP_TESTER1(x).U = (v))
#define HW_OCOTP_TESTER1_SET(x, v) (HW_OCOTP_TESTER1_WR(x, HW_OCOTP_TESTER1_RD(x) |  (v)))
#define HW_OCOTP_TESTER1_CLR(x, v) (HW_OCOTP_TESTER1_WR(x, HW_OCOTP_TESTER1_RD(x) & ~(v)))
#define HW_OCOTP_TESTER1_TOG(x, v) (HW_OCOTP_TESTER1_WR(x, HW_OCOTP_TESTER1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_TESTER1 bitfields
 */

/*!
 * @name Register OCOTP_TESTER1, field BITS[31:0] (RW)
 *
 * It reflects value of OTP Bank 0, word 2. These bits become read-only after
 * the HW_OCOTP_LOCK_TESTER[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_TESTER1_BITS (0U)         /*!< Bit position for OCOTP_TESTER1_BITS. */
#define BM_OCOTP_TESTER1_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_TESTER1_BITS. */
#define BS_OCOTP_TESTER1_BITS (32U)        /*!< Bit field size in bits for OCOTP_TESTER1_BITS. */

/*! @brief Read current value of the OCOTP_TESTER1_BITS field. */
#define BR_OCOTP_TESTER1_BITS(x) (HW_OCOTP_TESTER1(x).U)

/*! @brief Format value for bitfield OCOTP_TESTER1_BITS. */
#define BF_OCOTP_TESTER1_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_TESTER1_BITS) & BM_OCOTP_TESTER1_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_TESTER1_BITS(x, v) (HW_OCOTP_TESTER1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_TESTER2 - Value of OTP Bank0 Word3 (Tester Information)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_TESTER2 - Value of OTP Bank0 Word3 (Tester Information) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_tester2
{
    uint32_t U;
    struct _hw_ocotp_tester2_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_tester2_t;

/*!
 * @name Constants and macros for entire OCOTP_TESTER2 register
 */
/*@{*/
#define HW_OCOTP_TESTER2_ADDR(x) ((uintptr_t)(x) + 0x430U)

#define HW_OCOTP_TESTER2(x)      (*(__IO hw_ocotp_tester2_t *) HW_OCOTP_TESTER2_ADDR(x))
#define HW_OCOTP_TESTER2_RD(x)   (HW_OCOTP_TESTER2(x).U)
#define HW_OCOTP_TESTER2_WR(x, v) (HW_OCOTP_TESTER2(x).U = (v))
#define HW_OCOTP_TESTER2_SET(x, v) (HW_OCOTP_TESTER2_WR(x, HW_OCOTP_TESTER2_RD(x) |  (v)))
#define HW_OCOTP_TESTER2_CLR(x, v) (HW_OCOTP_TESTER2_WR(x, HW_OCOTP_TESTER2_RD(x) & ~(v)))
#define HW_OCOTP_TESTER2_TOG(x, v) (HW_OCOTP_TESTER2_WR(x, HW_OCOTP_TESTER2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_TESTER2 bitfields
 */

/*!
 * @name Register OCOTP_TESTER2, field BITS[31:0] (RW)
 *
 * It reflects value of OTP Bank 0, word 3. These bits become read-only after
 * the HW_OCOTP_LOCK_TESTER[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_TESTER2_BITS (0U)         /*!< Bit position for OCOTP_TESTER2_BITS. */
#define BM_OCOTP_TESTER2_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_TESTER2_BITS. */
#define BS_OCOTP_TESTER2_BITS (32U)        /*!< Bit field size in bits for OCOTP_TESTER2_BITS. */

/*! @brief Read current value of the OCOTP_TESTER2_BITS field. */
#define BR_OCOTP_TESTER2_BITS(x) (HW_OCOTP_TESTER2(x).U)

/*! @brief Format value for bitfield OCOTP_TESTER2_BITS. */
#define BF_OCOTP_TESTER2_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_TESTER2_BITS) & BM_OCOTP_TESTER2_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_TESTER2_BITS(x, v) (HW_OCOTP_TESTER2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_TESTER3 - Value of OTP Bank1 Word0 (Tester Information)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_TESTER3 - Value of OTP Bank1 Word0 (Tester Information) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_tester3
{
    uint32_t U;
    struct _hw_ocotp_tester3_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_tester3_t;

/*!
 * @name Constants and macros for entire OCOTP_TESTER3 register
 */
/*@{*/
#define HW_OCOTP_TESTER3_ADDR(x) ((uintptr_t)(x) + 0x440U)

#define HW_OCOTP_TESTER3(x)      (*(__IO hw_ocotp_tester3_t *) HW_OCOTP_TESTER3_ADDR(x))
#define HW_OCOTP_TESTER3_RD(x)   (HW_OCOTP_TESTER3(x).U)
#define HW_OCOTP_TESTER3_WR(x, v) (HW_OCOTP_TESTER3(x).U = (v))
#define HW_OCOTP_TESTER3_SET(x, v) (HW_OCOTP_TESTER3_WR(x, HW_OCOTP_TESTER3_RD(x) |  (v)))
#define HW_OCOTP_TESTER3_CLR(x, v) (HW_OCOTP_TESTER3_WR(x, HW_OCOTP_TESTER3_RD(x) & ~(v)))
#define HW_OCOTP_TESTER3_TOG(x, v) (HW_OCOTP_TESTER3_WR(x, HW_OCOTP_TESTER3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_TESTER3 bitfields
 */

/*!
 * @name Register OCOTP_TESTER3, field BITS[31:0] (RW)
 *
 * It reflects value of OTP Bank 1, word 0. These bits become read-only after
 * the HW_OCOTP_LOCK_TESTER[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_TESTER3_BITS (0U)         /*!< Bit position for OCOTP_TESTER3_BITS. */
#define BM_OCOTP_TESTER3_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_TESTER3_BITS. */
#define BS_OCOTP_TESTER3_BITS (32U)        /*!< Bit field size in bits for OCOTP_TESTER3_BITS. */

/*! @brief Read current value of the OCOTP_TESTER3_BITS field. */
#define BR_OCOTP_TESTER3_BITS(x) (HW_OCOTP_TESTER3(x).U)

/*! @brief Format value for bitfield OCOTP_TESTER3_BITS. */
#define BF_OCOTP_TESTER3_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_TESTER3_BITS) & BM_OCOTP_TESTER3_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_TESTER3_BITS(x, v) (HW_OCOTP_TESTER3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_TESTER4 - Value of OTP Bank1 Word1 (Tester Information)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_TESTER4 - Value of OTP Bank1 Word1 (Tester Information) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_tester4
{
    uint32_t U;
    struct _hw_ocotp_tester4_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_tester4_t;

/*!
 * @name Constants and macros for entire OCOTP_TESTER4 register
 */
/*@{*/
#define HW_OCOTP_TESTER4_ADDR(x) ((uintptr_t)(x) + 0x450U)

#define HW_OCOTP_TESTER4(x)      (*(__IO hw_ocotp_tester4_t *) HW_OCOTP_TESTER4_ADDR(x))
#define HW_OCOTP_TESTER4_RD(x)   (HW_OCOTP_TESTER4(x).U)
#define HW_OCOTP_TESTER4_WR(x, v) (HW_OCOTP_TESTER4(x).U = (v))
#define HW_OCOTP_TESTER4_SET(x, v) (HW_OCOTP_TESTER4_WR(x, HW_OCOTP_TESTER4_RD(x) |  (v)))
#define HW_OCOTP_TESTER4_CLR(x, v) (HW_OCOTP_TESTER4_WR(x, HW_OCOTP_TESTER4_RD(x) & ~(v)))
#define HW_OCOTP_TESTER4_TOG(x, v) (HW_OCOTP_TESTER4_WR(x, HW_OCOTP_TESTER4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_TESTER4 bitfields
 */

/*!
 * @name Register OCOTP_TESTER4, field BITS[31:0] (RW)
 *
 * It reflects value of OTP Bank 1, word 1. These bits become read-only after
 * the HW_OCOTP_LOCK_TESTER[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_TESTER4_BITS (0U)         /*!< Bit position for OCOTP_TESTER4_BITS. */
#define BM_OCOTP_TESTER4_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_TESTER4_BITS. */
#define BS_OCOTP_TESTER4_BITS (32U)        /*!< Bit field size in bits for OCOTP_TESTER4_BITS. */

/*! @brief Read current value of the OCOTP_TESTER4_BITS field. */
#define BR_OCOTP_TESTER4_BITS(x) (HW_OCOTP_TESTER4(x).U)

/*! @brief Format value for bitfield OCOTP_TESTER4_BITS. */
#define BF_OCOTP_TESTER4_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_TESTER4_BITS) & BM_OCOTP_TESTER4_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_TESTER4_BITS(x, v) (HW_OCOTP_TESTER4_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_TESTER5 - Value of OTP Bank1 Word2 (Tester Information)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_TESTER5 - Value of OTP Bank1 Word2 (Tester Information) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_tester5
{
    uint32_t U;
    struct _hw_ocotp_tester5_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_tester5_t;

/*!
 * @name Constants and macros for entire OCOTP_TESTER5 register
 */
/*@{*/
#define HW_OCOTP_TESTER5_ADDR(x) ((uintptr_t)(x) + 0x460U)

#define HW_OCOTP_TESTER5(x)      (*(__IO hw_ocotp_tester5_t *) HW_OCOTP_TESTER5_ADDR(x))
#define HW_OCOTP_TESTER5_RD(x)   (HW_OCOTP_TESTER5(x).U)
#define HW_OCOTP_TESTER5_WR(x, v) (HW_OCOTP_TESTER5(x).U = (v))
#define HW_OCOTP_TESTER5_SET(x, v) (HW_OCOTP_TESTER5_WR(x, HW_OCOTP_TESTER5_RD(x) |  (v)))
#define HW_OCOTP_TESTER5_CLR(x, v) (HW_OCOTP_TESTER5_WR(x, HW_OCOTP_TESTER5_RD(x) & ~(v)))
#define HW_OCOTP_TESTER5_TOG(x, v) (HW_OCOTP_TESTER5_WR(x, HW_OCOTP_TESTER5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_TESTER5 bitfields
 */

/*!
 * @name Register OCOTP_TESTER5, field BITS[31:0] (RW)
 *
 * It reflects value of OTP Bank 1, word 2. These bits become read-only after
 * the HW_OCOTP_LOCK_TESTER[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_TESTER5_BITS (0U)         /*!< Bit position for OCOTP_TESTER5_BITS. */
#define BM_OCOTP_TESTER5_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_TESTER5_BITS. */
#define BS_OCOTP_TESTER5_BITS (32U)        /*!< Bit field size in bits for OCOTP_TESTER5_BITS. */

/*! @brief Read current value of the OCOTP_TESTER5_BITS field. */
#define BR_OCOTP_TESTER5_BITS(x) (HW_OCOTP_TESTER5(x).U)

/*! @brief Format value for bitfield OCOTP_TESTER5_BITS. */
#define BF_OCOTP_TESTER5_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_TESTER5_BITS) & BM_OCOTP_TESTER5_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_TESTER5_BITS(x, v) (HW_OCOTP_TESTER5_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_BOOT_CFG0 - Value of OTP Bank1 Word3 (Boot Configuration Information)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_BOOT_CFG0 - Value of OTP Bank1 Word3 (Boot Configuration Information) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS] EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_boot_cfg0
{
    uint32_t U;
    struct _hw_ocotp_boot_cfg0_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_boot_cfg0_t;

/*!
 * @name Constants and macros for entire OCOTP_BOOT_CFG0 register
 */
/*@{*/
#define HW_OCOTP_BOOT_CFG0_ADDR(x) ((uintptr_t)(x) + 0x470U)

#define HW_OCOTP_BOOT_CFG0(x)    (*(__IO hw_ocotp_boot_cfg0_t *) HW_OCOTP_BOOT_CFG0_ADDR(x))
#define HW_OCOTP_BOOT_CFG0_RD(x) (HW_OCOTP_BOOT_CFG0(x).U)
#define HW_OCOTP_BOOT_CFG0_WR(x, v) (HW_OCOTP_BOOT_CFG0(x).U = (v))
#define HW_OCOTP_BOOT_CFG0_SET(x, v) (HW_OCOTP_BOOT_CFG0_WR(x, HW_OCOTP_BOOT_CFG0_RD(x) |  (v)))
#define HW_OCOTP_BOOT_CFG0_CLR(x, v) (HW_OCOTP_BOOT_CFG0_WR(x, HW_OCOTP_BOOT_CFG0_RD(x) & ~(v)))
#define HW_OCOTP_BOOT_CFG0_TOG(x, v) (HW_OCOTP_BOOT_CFG0_WR(x, HW_OCOTP_BOOT_CFG0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_BOOT_CFG0 bitfields
 */

/*!
 * @name Register OCOTP_BOOT_CFG0, field BITS[31:0] (RW)
 *
 * It reflects value of OTP Bank 1, word 3. These bits become read-only after
 * the HW_OCOTP_LOCK_BOOT_CFG[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_BOOT_CFG0_BITS (0U)       /*!< Bit position for OCOTP_BOOT_CFG0_BITS. */
#define BM_OCOTP_BOOT_CFG0_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_BOOT_CFG0_BITS. */
#define BS_OCOTP_BOOT_CFG0_BITS (32U)      /*!< Bit field size in bits for OCOTP_BOOT_CFG0_BITS. */

/*! @brief Read current value of the OCOTP_BOOT_CFG0_BITS field. */
#define BR_OCOTP_BOOT_CFG0_BITS(x) (HW_OCOTP_BOOT_CFG0(x).U)

/*! @brief Format value for bitfield OCOTP_BOOT_CFG0_BITS. */
#define BF_OCOTP_BOOT_CFG0_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_BOOT_CFG0_BITS) & BM_OCOTP_BOOT_CFG0_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_BOOT_CFG0_BITS(x, v) (HW_OCOTP_BOOT_CFG0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_BOOT_CFG1 - Value of OTP Bank2 Word0 (Boot Configuration Information)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_BOOT_CFG1 - Value of OTP Bank2 Word0 (Boot Configuration Information) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_boot_cfg1
{
    uint32_t U;
    struct _hw_ocotp_boot_cfg1_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_boot_cfg1_t;

/*!
 * @name Constants and macros for entire OCOTP_BOOT_CFG1 register
 */
/*@{*/
#define HW_OCOTP_BOOT_CFG1_ADDR(x) ((uintptr_t)(x) + 0x480U)

#define HW_OCOTP_BOOT_CFG1(x)    (*(__IO hw_ocotp_boot_cfg1_t *) HW_OCOTP_BOOT_CFG1_ADDR(x))
#define HW_OCOTP_BOOT_CFG1_RD(x) (HW_OCOTP_BOOT_CFG1(x).U)
#define HW_OCOTP_BOOT_CFG1_WR(x, v) (HW_OCOTP_BOOT_CFG1(x).U = (v))
#define HW_OCOTP_BOOT_CFG1_SET(x, v) (HW_OCOTP_BOOT_CFG1_WR(x, HW_OCOTP_BOOT_CFG1_RD(x) |  (v)))
#define HW_OCOTP_BOOT_CFG1_CLR(x, v) (HW_OCOTP_BOOT_CFG1_WR(x, HW_OCOTP_BOOT_CFG1_RD(x) & ~(v)))
#define HW_OCOTP_BOOT_CFG1_TOG(x, v) (HW_OCOTP_BOOT_CFG1_WR(x, HW_OCOTP_BOOT_CFG1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_BOOT_CFG1 bitfields
 */

/*!
 * @name Register OCOTP_BOOT_CFG1, field BITS[31:0] (RW)
 *
 * It reflects value of OTP bank 2, word 0. These bits become read-only after
 * the HW_OCOTP_LOCK_BOOT_CFG[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_BOOT_CFG1_BITS (0U)       /*!< Bit position for OCOTP_BOOT_CFG1_BITS. */
#define BM_OCOTP_BOOT_CFG1_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_BOOT_CFG1_BITS. */
#define BS_OCOTP_BOOT_CFG1_BITS (32U)      /*!< Bit field size in bits for OCOTP_BOOT_CFG1_BITS. */

/*! @brief Read current value of the OCOTP_BOOT_CFG1_BITS field. */
#define BR_OCOTP_BOOT_CFG1_BITS(x) (HW_OCOTP_BOOT_CFG1(x).U)

/*! @brief Format value for bitfield OCOTP_BOOT_CFG1_BITS. */
#define BF_OCOTP_BOOT_CFG1_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_BOOT_CFG1_BITS) & BM_OCOTP_BOOT_CFG1_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_BOOT_CFG1_BITS(x, v) (HW_OCOTP_BOOT_CFG1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_BOOT_CFG2 - Value of OTP Bank2 Word1 (Boot Configuration Information)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_BOOT_CFG2 - Value of OTP Bank2 Word1 (Boot Configuration Information) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_boot_cfg2
{
    uint32_t U;
    struct _hw_ocotp_boot_cfg2_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_boot_cfg2_t;

/*!
 * @name Constants and macros for entire OCOTP_BOOT_CFG2 register
 */
/*@{*/
#define HW_OCOTP_BOOT_CFG2_ADDR(x) ((uintptr_t)(x) + 0x490U)

#define HW_OCOTP_BOOT_CFG2(x)    (*(__IO hw_ocotp_boot_cfg2_t *) HW_OCOTP_BOOT_CFG2_ADDR(x))
#define HW_OCOTP_BOOT_CFG2_RD(x) (HW_OCOTP_BOOT_CFG2(x).U)
#define HW_OCOTP_BOOT_CFG2_WR(x, v) (HW_OCOTP_BOOT_CFG2(x).U = (v))
#define HW_OCOTP_BOOT_CFG2_SET(x, v) (HW_OCOTP_BOOT_CFG2_WR(x, HW_OCOTP_BOOT_CFG2_RD(x) |  (v)))
#define HW_OCOTP_BOOT_CFG2_CLR(x, v) (HW_OCOTP_BOOT_CFG2_WR(x, HW_OCOTP_BOOT_CFG2_RD(x) & ~(v)))
#define HW_OCOTP_BOOT_CFG2_TOG(x, v) (HW_OCOTP_BOOT_CFG2_WR(x, HW_OCOTP_BOOT_CFG2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_BOOT_CFG2 bitfields
 */

/*!
 * @name Register OCOTP_BOOT_CFG2, field BITS[31:0] (RW)
 *
 * It reflects value of OTP bank 2, word 1. These bits become read-only after
 * the HW_OCOTP_LOCK_BOOT_CFG[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_BOOT_CFG2_BITS (0U)       /*!< Bit position for OCOTP_BOOT_CFG2_BITS. */
#define BM_OCOTP_BOOT_CFG2_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_BOOT_CFG2_BITS. */
#define BS_OCOTP_BOOT_CFG2_BITS (32U)      /*!< Bit field size in bits for OCOTP_BOOT_CFG2_BITS. */

/*! @brief Read current value of the OCOTP_BOOT_CFG2_BITS field. */
#define BR_OCOTP_BOOT_CFG2_BITS(x) (HW_OCOTP_BOOT_CFG2(x).U)

/*! @brief Format value for bitfield OCOTP_BOOT_CFG2_BITS. */
#define BF_OCOTP_BOOT_CFG2_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_BOOT_CFG2_BITS) & BM_OCOTP_BOOT_CFG2_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_BOOT_CFG2_BITS(x, v) (HW_OCOTP_BOOT_CFG2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_BOOT_CFG3 - Value of OTP Bank2 Word2 (Boot Configuration Information)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_BOOT_CFG3 - Value of OTP Bank2 Word2 (Boot Configuration Information) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_boot_cfg3
{
    uint32_t U;
    struct _hw_ocotp_boot_cfg3_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_boot_cfg3_t;

/*!
 * @name Constants and macros for entire OCOTP_BOOT_CFG3 register
 */
/*@{*/
#define HW_OCOTP_BOOT_CFG3_ADDR(x) ((uintptr_t)(x) + 0x4A0U)

#define HW_OCOTP_BOOT_CFG3(x)    (*(__IO hw_ocotp_boot_cfg3_t *) HW_OCOTP_BOOT_CFG3_ADDR(x))
#define HW_OCOTP_BOOT_CFG3_RD(x) (HW_OCOTP_BOOT_CFG3(x).U)
#define HW_OCOTP_BOOT_CFG3_WR(x, v) (HW_OCOTP_BOOT_CFG3(x).U = (v))
#define HW_OCOTP_BOOT_CFG3_SET(x, v) (HW_OCOTP_BOOT_CFG3_WR(x, HW_OCOTP_BOOT_CFG3_RD(x) |  (v)))
#define HW_OCOTP_BOOT_CFG3_CLR(x, v) (HW_OCOTP_BOOT_CFG3_WR(x, HW_OCOTP_BOOT_CFG3_RD(x) & ~(v)))
#define HW_OCOTP_BOOT_CFG3_TOG(x, v) (HW_OCOTP_BOOT_CFG3_WR(x, HW_OCOTP_BOOT_CFG3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_BOOT_CFG3 bitfields
 */

/*!
 * @name Register OCOTP_BOOT_CFG3, field BITS[31:0] (RW)
 *
 * It reflects value of OTP bank 2, word 2. These bits become read-only after
 * the HW_OCOTP_LOCK_BOOT_CFG[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_BOOT_CFG3_BITS (0U)       /*!< Bit position for OCOTP_BOOT_CFG3_BITS. */
#define BM_OCOTP_BOOT_CFG3_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_BOOT_CFG3_BITS. */
#define BS_OCOTP_BOOT_CFG3_BITS (32U)      /*!< Bit field size in bits for OCOTP_BOOT_CFG3_BITS. */

/*! @brief Read current value of the OCOTP_BOOT_CFG3_BITS field. */
#define BR_OCOTP_BOOT_CFG3_BITS(x) (HW_OCOTP_BOOT_CFG3(x).U)

/*! @brief Format value for bitfield OCOTP_BOOT_CFG3_BITS. */
#define BF_OCOTP_BOOT_CFG3_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_BOOT_CFG3_BITS) & BM_OCOTP_BOOT_CFG3_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_BOOT_CFG3_BITS(x, v) (HW_OCOTP_BOOT_CFG3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_BOOT_CFG4 - Value of OTP Bank2 Word3 (BOOT Configuration Information)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_BOOT_CFG4 - Value of OTP Bank2 Word3 (BOOT Configuration Information) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it copied from the OTP. It can be re-loaded by setting
 * HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_boot_cfg4
{
    uint32_t U;
    struct _hw_ocotp_boot_cfg4_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_boot_cfg4_t;

/*!
 * @name Constants and macros for entire OCOTP_BOOT_CFG4 register
 */
/*@{*/
#define HW_OCOTP_BOOT_CFG4_ADDR(x) ((uintptr_t)(x) + 0x4B0U)

#define HW_OCOTP_BOOT_CFG4(x)    (*(__IO hw_ocotp_boot_cfg4_t *) HW_OCOTP_BOOT_CFG4_ADDR(x))
#define HW_OCOTP_BOOT_CFG4_RD(x) (HW_OCOTP_BOOT_CFG4(x).U)
#define HW_OCOTP_BOOT_CFG4_WR(x, v) (HW_OCOTP_BOOT_CFG4(x).U = (v))
#define HW_OCOTP_BOOT_CFG4_SET(x, v) (HW_OCOTP_BOOT_CFG4_WR(x, HW_OCOTP_BOOT_CFG4_RD(x) |  (v)))
#define HW_OCOTP_BOOT_CFG4_CLR(x, v) (HW_OCOTP_BOOT_CFG4_WR(x, HW_OCOTP_BOOT_CFG4_RD(x) & ~(v)))
#define HW_OCOTP_BOOT_CFG4_TOG(x, v) (HW_OCOTP_BOOT_CFG4_WR(x, HW_OCOTP_BOOT_CFG4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_BOOT_CFG4 bitfields
 */

/*!
 * @name Register OCOTP_BOOT_CFG4, field BITS[31:0] (RW)
 *
 * It reflects value of OTP bank 2, word 3. These bits become read-only after
 * the HW_OCOTP_LOCK_BOOT_CFG[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_BOOT_CFG4_BITS (0U)       /*!< Bit position for OCOTP_BOOT_CFG4_BITS. */
#define BM_OCOTP_BOOT_CFG4_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_BOOT_CFG4_BITS. */
#define BS_OCOTP_BOOT_CFG4_BITS (32U)      /*!< Bit field size in bits for OCOTP_BOOT_CFG4_BITS. */

/*! @brief Read current value of the OCOTP_BOOT_CFG4_BITS field. */
#define BR_OCOTP_BOOT_CFG4_BITS(x) (HW_OCOTP_BOOT_CFG4(x).U)

/*! @brief Format value for bitfield OCOTP_BOOT_CFG4_BITS. */
#define BF_OCOTP_BOOT_CFG4_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_BOOT_CFG4_BITS) & BM_OCOTP_BOOT_CFG4_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_BOOT_CFG4_BITS(x, v) (HW_OCOTP_BOOT_CFG4_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MEM_TRIM0 - Value of OTP Bank3 Word0 (Memory Related Information)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MEM_TRIM0 - Value of OTP Bank3 Word0 (Memory Related Information) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mem_trim0
{
    uint32_t U;
    struct _hw_ocotp_mem_trim0_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mem_trim0_t;

/*!
 * @name Constants and macros for entire OCOTP_MEM_TRIM0 register
 */
/*@{*/
#define HW_OCOTP_MEM_TRIM0_ADDR(x) ((uintptr_t)(x) + 0x4C0U)

#define HW_OCOTP_MEM_TRIM0(x)    (*(__IO hw_ocotp_mem_trim0_t *) HW_OCOTP_MEM_TRIM0_ADDR(x))
#define HW_OCOTP_MEM_TRIM0_RD(x) (HW_OCOTP_MEM_TRIM0(x).U)
#define HW_OCOTP_MEM_TRIM0_WR(x, v) (HW_OCOTP_MEM_TRIM0(x).U = (v))
#define HW_OCOTP_MEM_TRIM0_SET(x, v) (HW_OCOTP_MEM_TRIM0_WR(x, HW_OCOTP_MEM_TRIM0_RD(x) |  (v)))
#define HW_OCOTP_MEM_TRIM0_CLR(x, v) (HW_OCOTP_MEM_TRIM0_WR(x, HW_OCOTP_MEM_TRIM0_RD(x) & ~(v)))
#define HW_OCOTP_MEM_TRIM0_TOG(x, v) (HW_OCOTP_MEM_TRIM0_WR(x, HW_OCOTP_MEM_TRIM0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MEM_TRIM0 bitfields
 */

/*!
 * @name Register OCOTP_MEM_TRIM0, field BITS[31:0] (RW)
 *
 * It reflects value of OTP bank 3, word 0. These bits become read-only after
 * the HW_OCOTP_LOCK_MEM_TRIM[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_MEM_TRIM0_BITS (0U)       /*!< Bit position for OCOTP_MEM_TRIM0_BITS. */
#define BM_OCOTP_MEM_TRIM0_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MEM_TRIM0_BITS. */
#define BS_OCOTP_MEM_TRIM0_BITS (32U)      /*!< Bit field size in bits for OCOTP_MEM_TRIM0_BITS. */

/*! @brief Read current value of the OCOTP_MEM_TRIM0_BITS field. */
#define BR_OCOTP_MEM_TRIM0_BITS(x) (HW_OCOTP_MEM_TRIM0(x).U)

/*! @brief Format value for bitfield OCOTP_MEM_TRIM0_BITS. */
#define BF_OCOTP_MEM_TRIM0_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MEM_TRIM0_BITS) & BM_OCOTP_MEM_TRIM0_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MEM_TRIM0_BITS(x, v) (HW_OCOTP_MEM_TRIM0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MEM_TRIM1 - Value of OTP Bank3 Word1 (Memory Related Information)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MEM_TRIM1 - Value of OTP Bank3 Word1 (Memory Related Information) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mem_trim1
{
    uint32_t U;
    struct _hw_ocotp_mem_trim1_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mem_trim1_t;

/*!
 * @name Constants and macros for entire OCOTP_MEM_TRIM1 register
 */
/*@{*/
#define HW_OCOTP_MEM_TRIM1_ADDR(x) ((uintptr_t)(x) + 0x4D0U)

#define HW_OCOTP_MEM_TRIM1(x)    (*(__IO hw_ocotp_mem_trim1_t *) HW_OCOTP_MEM_TRIM1_ADDR(x))
#define HW_OCOTP_MEM_TRIM1_RD(x) (HW_OCOTP_MEM_TRIM1(x).U)
#define HW_OCOTP_MEM_TRIM1_WR(x, v) (HW_OCOTP_MEM_TRIM1(x).U = (v))
#define HW_OCOTP_MEM_TRIM1_SET(x, v) (HW_OCOTP_MEM_TRIM1_WR(x, HW_OCOTP_MEM_TRIM1_RD(x) |  (v)))
#define HW_OCOTP_MEM_TRIM1_CLR(x, v) (HW_OCOTP_MEM_TRIM1_WR(x, HW_OCOTP_MEM_TRIM1_RD(x) & ~(v)))
#define HW_OCOTP_MEM_TRIM1_TOG(x, v) (HW_OCOTP_MEM_TRIM1_WR(x, HW_OCOTP_MEM_TRIM1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MEM_TRIM1 bitfields
 */

/*!
 * @name Register OCOTP_MEM_TRIM1, field BITS[31:0] (RW)
 *
 * It reflects value of OTP bank 3, word 1. These bits become read-only after
 * the HW_OCOTP_LOCK_MEM_TRIM[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_MEM_TRIM1_BITS (0U)       /*!< Bit position for OCOTP_MEM_TRIM1_BITS. */
#define BM_OCOTP_MEM_TRIM1_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MEM_TRIM1_BITS. */
#define BS_OCOTP_MEM_TRIM1_BITS (32U)      /*!< Bit field size in bits for OCOTP_MEM_TRIM1_BITS. */

/*! @brief Read current value of the OCOTP_MEM_TRIM1_BITS field. */
#define BR_OCOTP_MEM_TRIM1_BITS(x) (HW_OCOTP_MEM_TRIM1(x).U)

/*! @brief Format value for bitfield OCOTP_MEM_TRIM1_BITS. */
#define BF_OCOTP_MEM_TRIM1_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MEM_TRIM1_BITS) & BM_OCOTP_MEM_TRIM1_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MEM_TRIM1_BITS(x, v) (HW_OCOTP_MEM_TRIM1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_ANA0 - Value of OTP Bank3 Word2 (Analog Information)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_ANA0 - Value of OTP Bank3 Word2 (Analog Information) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_ana0
{
    uint32_t U;
    struct _hw_ocotp_ana0_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_ana0_t;

/*!
 * @name Constants and macros for entire OCOTP_ANA0 register
 */
/*@{*/
#define HW_OCOTP_ANA0_ADDR(x)    ((uintptr_t)(x) + 0x4E0U)

#define HW_OCOTP_ANA0(x)         (*(__IO hw_ocotp_ana0_t *) HW_OCOTP_ANA0_ADDR(x))
#define HW_OCOTP_ANA0_RD(x)      (HW_OCOTP_ANA0(x).U)
#define HW_OCOTP_ANA0_WR(x, v)   (HW_OCOTP_ANA0(x).U = (v))
#define HW_OCOTP_ANA0_SET(x, v)  (HW_OCOTP_ANA0_WR(x, HW_OCOTP_ANA0_RD(x) |  (v)))
#define HW_OCOTP_ANA0_CLR(x, v)  (HW_OCOTP_ANA0_WR(x, HW_OCOTP_ANA0_RD(x) & ~(v)))
#define HW_OCOTP_ANA0_TOG(x, v)  (HW_OCOTP_ANA0_WR(x, HW_OCOTP_ANA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_ANA0 bitfields
 */

/*!
 * @name Register OCOTP_ANA0, field BITS[31:0] (RW)
 *
 * It reflects value of OTP bank 3, word 2. These bits become read-only after
 * the HW_OCOTP_LOCK_ANALOG[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_ANA0_BITS   (0U)          /*!< Bit position for OCOTP_ANA0_BITS. */
#define BM_OCOTP_ANA0_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_ANA0_BITS. */
#define BS_OCOTP_ANA0_BITS   (32U)         /*!< Bit field size in bits for OCOTP_ANA0_BITS. */

/*! @brief Read current value of the OCOTP_ANA0_BITS field. */
#define BR_OCOTP_ANA0_BITS(x) (HW_OCOTP_ANA0(x).U)

/*! @brief Format value for bitfield OCOTP_ANA0_BITS. */
#define BF_OCOTP_ANA0_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_ANA0_BITS) & BM_OCOTP_ANA0_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_ANA0_BITS(x, v) (HW_OCOTP_ANA0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_ANA1 - Value of OTP Bank3 Word3 (Analog Info.)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_ANA1 - Value of OTP Bank3 Word3 (Analog Info.) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_ana1
{
    uint32_t U;
    struct _hw_ocotp_ana1_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_ana1_t;

/*!
 * @name Constants and macros for entire OCOTP_ANA1 register
 */
/*@{*/
#define HW_OCOTP_ANA1_ADDR(x)    ((uintptr_t)(x) + 0x4F0U)

#define HW_OCOTP_ANA1(x)         (*(__IO hw_ocotp_ana1_t *) HW_OCOTP_ANA1_ADDR(x))
#define HW_OCOTP_ANA1_RD(x)      (HW_OCOTP_ANA1(x).U)
#define HW_OCOTP_ANA1_WR(x, v)   (HW_OCOTP_ANA1(x).U = (v))
#define HW_OCOTP_ANA1_SET(x, v)  (HW_OCOTP_ANA1_WR(x, HW_OCOTP_ANA1_RD(x) |  (v)))
#define HW_OCOTP_ANA1_CLR(x, v)  (HW_OCOTP_ANA1_WR(x, HW_OCOTP_ANA1_RD(x) & ~(v)))
#define HW_OCOTP_ANA1_TOG(x, v)  (HW_OCOTP_ANA1_WR(x, HW_OCOTP_ANA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_ANA1 bitfields
 */

/*!
 * @name Register OCOTP_ANA1, field BITS[31:0] (RW)
 *
 * It reflects value of OTP bank 3, word 3. These bits become read-only after
 * the HW_OCOTP_LOCK_ANALOG[1] bit is set.
 */
/*@{*/
#define BP_OCOTP_ANA1_BITS   (0U)          /*!< Bit position for OCOTP_ANA1_BITS. */
#define BM_OCOTP_ANA1_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_ANA1_BITS. */
#define BS_OCOTP_ANA1_BITS   (32U)         /*!< Bit field size in bits for OCOTP_ANA1_BITS. */

/*! @brief Read current value of the OCOTP_ANA1_BITS field. */
#define BR_OCOTP_ANA1_BITS(x) (HW_OCOTP_ANA1(x).U)

/*! @brief Format value for bitfield OCOTP_ANA1_BITS. */
#define BF_OCOTP_ANA1_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_ANA1_BITS) & BM_OCOTP_ANA1_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_ANA1_BITS(x, v) (HW_OCOTP_ANA1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_OTPMK0 - Shadow Register for OTP Bank4 Word0 (OTPMK Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_OTPMK0 - Shadow Register for OTP Bank4 Word0 (OTPMK Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_otpmk0
{
    uint32_t U;
    struct _hw_ocotp_otpmk0_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_otpmk0_t;

/*!
 * @name Constants and macros for entire OCOTP_OTPMK0 register
 */
/*@{*/
#define HW_OCOTP_OTPMK0_ADDR(x)  ((uintptr_t)(x) + 0x500U)

#define HW_OCOTP_OTPMK0(x)       (*(__IO hw_ocotp_otpmk0_t *) HW_OCOTP_OTPMK0_ADDR(x))
#define HW_OCOTP_OTPMK0_RD(x)    (HW_OCOTP_OTPMK0(x).U)
#define HW_OCOTP_OTPMK0_WR(x, v) (HW_OCOTP_OTPMK0(x).U = (v))
#define HW_OCOTP_OTPMK0_SET(x, v) (HW_OCOTP_OTPMK0_WR(x, HW_OCOTP_OTPMK0_RD(x) |  (v)))
#define HW_OCOTP_OTPMK0_CLR(x, v) (HW_OCOTP_OTPMK0_WR(x, HW_OCOTP_OTPMK0_RD(x) & ~(v)))
#define HW_OCOTP_OTPMK0_TOG(x, v) (HW_OCOTP_OTPMK0_WR(x, HW_OCOTP_OTPMK0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_OTPMK0 bitfields
 */

/*!
 * @name Register OCOTP_OTPMK0, field BITS[31:0] (RW)
 *
 * Shadow register for the OTPMK Key word0 (Copy of OTP Bank 4, word 0). These
 * bits cannot be read and written after the HW_OCOTP_LOCK_OTPMK bit is set. If
 * read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_OTPMK0_BITS (0U)          /*!< Bit position for OCOTP_OTPMK0_BITS. */
#define BM_OCOTP_OTPMK0_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_OTPMK0_BITS. */
#define BS_OCOTP_OTPMK0_BITS (32U)         /*!< Bit field size in bits for OCOTP_OTPMK0_BITS. */

/*! @brief Read current value of the OCOTP_OTPMK0_BITS field. */
#define BR_OCOTP_OTPMK0_BITS(x) (HW_OCOTP_OTPMK0(x).U)

/*! @brief Format value for bitfield OCOTP_OTPMK0_BITS. */
#define BF_OCOTP_OTPMK0_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_OTPMK0_BITS) & BM_OCOTP_OTPMK0_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_OTPMK0_BITS(x, v) (HW_OCOTP_OTPMK0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_OTPMK1 - Shadow Register for OTP Bank4 Word1 (OTPMK Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_OTPMK1 - Shadow Register for OTP Bank4 Word1 (OTPMK Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_otpmk1
{
    uint32_t U;
    struct _hw_ocotp_otpmk1_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_otpmk1_t;

/*!
 * @name Constants and macros for entire OCOTP_OTPMK1 register
 */
/*@{*/
#define HW_OCOTP_OTPMK1_ADDR(x)  ((uintptr_t)(x) + 0x510U)

#define HW_OCOTP_OTPMK1(x)       (*(__IO hw_ocotp_otpmk1_t *) HW_OCOTP_OTPMK1_ADDR(x))
#define HW_OCOTP_OTPMK1_RD(x)    (HW_OCOTP_OTPMK1(x).U)
#define HW_OCOTP_OTPMK1_WR(x, v) (HW_OCOTP_OTPMK1(x).U = (v))
#define HW_OCOTP_OTPMK1_SET(x, v) (HW_OCOTP_OTPMK1_WR(x, HW_OCOTP_OTPMK1_RD(x) |  (v)))
#define HW_OCOTP_OTPMK1_CLR(x, v) (HW_OCOTP_OTPMK1_WR(x, HW_OCOTP_OTPMK1_RD(x) & ~(v)))
#define HW_OCOTP_OTPMK1_TOG(x, v) (HW_OCOTP_OTPMK1_WR(x, HW_OCOTP_OTPMK1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_OTPMK1 bitfields
 */

/*!
 * @name Register OCOTP_OTPMK1, field BITS[31:0] (RW)
 *
 * Shadow register for the OTPMK Key word1 (Copy of OTP Bank 4, word 1). These
 * bits cannot be read and written after the HW_OCOTP_LOCK_OTPMK bit is set. If
 * read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_OTPMK1_BITS (0U)          /*!< Bit position for OCOTP_OTPMK1_BITS. */
#define BM_OCOTP_OTPMK1_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_OTPMK1_BITS. */
#define BS_OCOTP_OTPMK1_BITS (32U)         /*!< Bit field size in bits for OCOTP_OTPMK1_BITS. */

/*! @brief Read current value of the OCOTP_OTPMK1_BITS field. */
#define BR_OCOTP_OTPMK1_BITS(x) (HW_OCOTP_OTPMK1(x).U)

/*! @brief Format value for bitfield OCOTP_OTPMK1_BITS. */
#define BF_OCOTP_OTPMK1_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_OTPMK1_BITS) & BM_OCOTP_OTPMK1_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_OTPMK1_BITS(x, v) (HW_OCOTP_OTPMK1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_OTPMK2 - Shadow Register for OTP Bank4 Word2 (OTPMK Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_OTPMK2 - Shadow Register for OTP Bank4 Word2 (OTPMK Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_otpmk2
{
    uint32_t U;
    struct _hw_ocotp_otpmk2_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_otpmk2_t;

/*!
 * @name Constants and macros for entire OCOTP_OTPMK2 register
 */
/*@{*/
#define HW_OCOTP_OTPMK2_ADDR(x)  ((uintptr_t)(x) + 0x520U)

#define HW_OCOTP_OTPMK2(x)       (*(__IO hw_ocotp_otpmk2_t *) HW_OCOTP_OTPMK2_ADDR(x))
#define HW_OCOTP_OTPMK2_RD(x)    (HW_OCOTP_OTPMK2(x).U)
#define HW_OCOTP_OTPMK2_WR(x, v) (HW_OCOTP_OTPMK2(x).U = (v))
#define HW_OCOTP_OTPMK2_SET(x, v) (HW_OCOTP_OTPMK2_WR(x, HW_OCOTP_OTPMK2_RD(x) |  (v)))
#define HW_OCOTP_OTPMK2_CLR(x, v) (HW_OCOTP_OTPMK2_WR(x, HW_OCOTP_OTPMK2_RD(x) & ~(v)))
#define HW_OCOTP_OTPMK2_TOG(x, v) (HW_OCOTP_OTPMK2_WR(x, HW_OCOTP_OTPMK2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_OTPMK2 bitfields
 */

/*!
 * @name Register OCOTP_OTPMK2, field BITS[31:0] (RW)
 *
 * Shadow register for the OTPMK Key word2 (Copy of OTP Bank 4, word 2). These
 * bits cannot be read and written after the HW_OCOTP_LOCK_OTPMK bit is set. If
 * read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_OTPMK2_BITS (0U)          /*!< Bit position for OCOTP_OTPMK2_BITS. */
#define BM_OCOTP_OTPMK2_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_OTPMK2_BITS. */
#define BS_OCOTP_OTPMK2_BITS (32U)         /*!< Bit field size in bits for OCOTP_OTPMK2_BITS. */

/*! @brief Read current value of the OCOTP_OTPMK2_BITS field. */
#define BR_OCOTP_OTPMK2_BITS(x) (HW_OCOTP_OTPMK2(x).U)

/*! @brief Format value for bitfield OCOTP_OTPMK2_BITS. */
#define BF_OCOTP_OTPMK2_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_OTPMK2_BITS) & BM_OCOTP_OTPMK2_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_OTPMK2_BITS(x, v) (HW_OCOTP_OTPMK2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_OTPMK3 - Shadow Register for OTP Bank4 Word3 (OTPMK Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_OTPMK3 - Shadow Register for OTP Bank4 Word3 (OTPMK Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_otpmk3
{
    uint32_t U;
    struct _hw_ocotp_otpmk3_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_otpmk3_t;

/*!
 * @name Constants and macros for entire OCOTP_OTPMK3 register
 */
/*@{*/
#define HW_OCOTP_OTPMK3_ADDR(x)  ((uintptr_t)(x) + 0x530U)

#define HW_OCOTP_OTPMK3(x)       (*(__IO hw_ocotp_otpmk3_t *) HW_OCOTP_OTPMK3_ADDR(x))
#define HW_OCOTP_OTPMK3_RD(x)    (HW_OCOTP_OTPMK3(x).U)
#define HW_OCOTP_OTPMK3_WR(x, v) (HW_OCOTP_OTPMK3(x).U = (v))
#define HW_OCOTP_OTPMK3_SET(x, v) (HW_OCOTP_OTPMK3_WR(x, HW_OCOTP_OTPMK3_RD(x) |  (v)))
#define HW_OCOTP_OTPMK3_CLR(x, v) (HW_OCOTP_OTPMK3_WR(x, HW_OCOTP_OTPMK3_RD(x) & ~(v)))
#define HW_OCOTP_OTPMK3_TOG(x, v) (HW_OCOTP_OTPMK3_WR(x, HW_OCOTP_OTPMK3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_OTPMK3 bitfields
 */

/*!
 * @name Register OCOTP_OTPMK3, field BITS[31:0] (RW)
 *
 * Shadow register for the OTPMK Key word3 (Copy of OTP Bank 4, word 3). These
 * bits cannot be read and written after the HW_OCOTP_LOCK_OTPMK bit is set. If
 * read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_OTPMK3_BITS (0U)          /*!< Bit position for OCOTP_OTPMK3_BITS. */
#define BM_OCOTP_OTPMK3_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_OTPMK3_BITS. */
#define BS_OCOTP_OTPMK3_BITS (32U)         /*!< Bit field size in bits for OCOTP_OTPMK3_BITS. */

/*! @brief Read current value of the OCOTP_OTPMK3_BITS field. */
#define BR_OCOTP_OTPMK3_BITS(x) (HW_OCOTP_OTPMK3(x).U)

/*! @brief Format value for bitfield OCOTP_OTPMK3_BITS. */
#define BF_OCOTP_OTPMK3_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_OTPMK3_BITS) & BM_OCOTP_OTPMK3_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_OTPMK3_BITS(x, v) (HW_OCOTP_OTPMK3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_OTPMK4 - Shadow Register for OTP Bank5 Word0 (OTPMK Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_OTPMK4 - Shadow Register for OTP Bank5 Word0 (OTPMK Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_otpmk4
{
    uint32_t U;
    struct _hw_ocotp_otpmk4_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_otpmk4_t;

/*!
 * @name Constants and macros for entire OCOTP_OTPMK4 register
 */
/*@{*/
#define HW_OCOTP_OTPMK4_ADDR(x)  ((uintptr_t)(x) + 0x540U)

#define HW_OCOTP_OTPMK4(x)       (*(__IO hw_ocotp_otpmk4_t *) HW_OCOTP_OTPMK4_ADDR(x))
#define HW_OCOTP_OTPMK4_RD(x)    (HW_OCOTP_OTPMK4(x).U)
#define HW_OCOTP_OTPMK4_WR(x, v) (HW_OCOTP_OTPMK4(x).U = (v))
#define HW_OCOTP_OTPMK4_SET(x, v) (HW_OCOTP_OTPMK4_WR(x, HW_OCOTP_OTPMK4_RD(x) |  (v)))
#define HW_OCOTP_OTPMK4_CLR(x, v) (HW_OCOTP_OTPMK4_WR(x, HW_OCOTP_OTPMK4_RD(x) & ~(v)))
#define HW_OCOTP_OTPMK4_TOG(x, v) (HW_OCOTP_OTPMK4_WR(x, HW_OCOTP_OTPMK4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_OTPMK4 bitfields
 */

/*!
 * @name Register OCOTP_OTPMK4, field BITS[31:0] (RW)
 *
 * Shadow register for the OTPMK Key word4 (Copy of OTP Bank 5, word 0). These
 * bits cannot be read and written after the HW_OCOTP_LOCK_OTPMK bit is set. If
 * read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_OTPMK4_BITS (0U)          /*!< Bit position for OCOTP_OTPMK4_BITS. */
#define BM_OCOTP_OTPMK4_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_OTPMK4_BITS. */
#define BS_OCOTP_OTPMK4_BITS (32U)         /*!< Bit field size in bits for OCOTP_OTPMK4_BITS. */

/*! @brief Read current value of the OCOTP_OTPMK4_BITS field. */
#define BR_OCOTP_OTPMK4_BITS(x) (HW_OCOTP_OTPMK4(x).U)

/*! @brief Format value for bitfield OCOTP_OTPMK4_BITS. */
#define BF_OCOTP_OTPMK4_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_OTPMK4_BITS) & BM_OCOTP_OTPMK4_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_OTPMK4_BITS(x, v) (HW_OCOTP_OTPMK4_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_OTPMK5 - Shadow Register for OTP Bank5 Word1 (OTPMK Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_OTPMK5 - Shadow Register for OTP Bank5 Word1 (OTPMK Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_otpmk5
{
    uint32_t U;
    struct _hw_ocotp_otpmk5_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_otpmk5_t;

/*!
 * @name Constants and macros for entire OCOTP_OTPMK5 register
 */
/*@{*/
#define HW_OCOTP_OTPMK5_ADDR(x)  ((uintptr_t)(x) + 0x550U)

#define HW_OCOTP_OTPMK5(x)       (*(__IO hw_ocotp_otpmk5_t *) HW_OCOTP_OTPMK5_ADDR(x))
#define HW_OCOTP_OTPMK5_RD(x)    (HW_OCOTP_OTPMK5(x).U)
#define HW_OCOTP_OTPMK5_WR(x, v) (HW_OCOTP_OTPMK5(x).U = (v))
#define HW_OCOTP_OTPMK5_SET(x, v) (HW_OCOTP_OTPMK5_WR(x, HW_OCOTP_OTPMK5_RD(x) |  (v)))
#define HW_OCOTP_OTPMK5_CLR(x, v) (HW_OCOTP_OTPMK5_WR(x, HW_OCOTP_OTPMK5_RD(x) & ~(v)))
#define HW_OCOTP_OTPMK5_TOG(x, v) (HW_OCOTP_OTPMK5_WR(x, HW_OCOTP_OTPMK5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_OTPMK5 bitfields
 */

/*!
 * @name Register OCOTP_OTPMK5, field BITS[31:0] (RW)
 *
 * Shadow register for the OTPMK Key word5 (Copy of OTP Bank 5, word 1). These
 * bits cannot be read and written after the HW_OCOTP_LOCK_OTPMK bit is set. If
 * read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_OTPMK5_BITS (0U)          /*!< Bit position for OCOTP_OTPMK5_BITS. */
#define BM_OCOTP_OTPMK5_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_OTPMK5_BITS. */
#define BS_OCOTP_OTPMK5_BITS (32U)         /*!< Bit field size in bits for OCOTP_OTPMK5_BITS. */

/*! @brief Read current value of the OCOTP_OTPMK5_BITS field. */
#define BR_OCOTP_OTPMK5_BITS(x) (HW_OCOTP_OTPMK5(x).U)

/*! @brief Format value for bitfield OCOTP_OTPMK5_BITS. */
#define BF_OCOTP_OTPMK5_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_OTPMK5_BITS) & BM_OCOTP_OTPMK5_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_OTPMK5_BITS(x, v) (HW_OCOTP_OTPMK5_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_OTPMK6 - Shadow Register for OTP Bank5 Word2 (OTPMK Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_OTPMK6 - Shadow Register for OTP Bank5 Word2 (OTPMK Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_otpmk6
{
    uint32_t U;
    struct _hw_ocotp_otpmk6_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_otpmk6_t;

/*!
 * @name Constants and macros for entire OCOTP_OTPMK6 register
 */
/*@{*/
#define HW_OCOTP_OTPMK6_ADDR(x)  ((uintptr_t)(x) + 0x560U)

#define HW_OCOTP_OTPMK6(x)       (*(__IO hw_ocotp_otpmk6_t *) HW_OCOTP_OTPMK6_ADDR(x))
#define HW_OCOTP_OTPMK6_RD(x)    (HW_OCOTP_OTPMK6(x).U)
#define HW_OCOTP_OTPMK6_WR(x, v) (HW_OCOTP_OTPMK6(x).U = (v))
#define HW_OCOTP_OTPMK6_SET(x, v) (HW_OCOTP_OTPMK6_WR(x, HW_OCOTP_OTPMK6_RD(x) |  (v)))
#define HW_OCOTP_OTPMK6_CLR(x, v) (HW_OCOTP_OTPMK6_WR(x, HW_OCOTP_OTPMK6_RD(x) & ~(v)))
#define HW_OCOTP_OTPMK6_TOG(x, v) (HW_OCOTP_OTPMK6_WR(x, HW_OCOTP_OTPMK6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_OTPMK6 bitfields
 */

/*!
 * @name Register OCOTP_OTPMK6, field BITS[31:0] (RW)
 *
 * Shadow register for the OTPMK Key word6 (Copy of OTP Bank 5, word 2). These
 * bits cannot be read and written after the HW_OCOTP_LOCK_OTPMK bit is set. If
 * read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_OTPMK6_BITS (0U)          /*!< Bit position for OCOTP_OTPMK6_BITS. */
#define BM_OCOTP_OTPMK6_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_OTPMK6_BITS. */
#define BS_OCOTP_OTPMK6_BITS (32U)         /*!< Bit field size in bits for OCOTP_OTPMK6_BITS. */

/*! @brief Read current value of the OCOTP_OTPMK6_BITS field. */
#define BR_OCOTP_OTPMK6_BITS(x) (HW_OCOTP_OTPMK6(x).U)

/*! @brief Format value for bitfield OCOTP_OTPMK6_BITS. */
#define BF_OCOTP_OTPMK6_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_OTPMK6_BITS) & BM_OCOTP_OTPMK6_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_OTPMK6_BITS(x, v) (HW_OCOTP_OTPMK6_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_OTPMK7 - Shadow Register for OTP Bank5 Word3 (OTPMK Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_OTPMK7 - Shadow Register for OTP Bank5 Word3 (OTPMK Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_otpmk7
{
    uint32_t U;
    struct _hw_ocotp_otpmk7_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_otpmk7_t;

/*!
 * @name Constants and macros for entire OCOTP_OTPMK7 register
 */
/*@{*/
#define HW_OCOTP_OTPMK7_ADDR(x)  ((uintptr_t)(x) + 0x570U)

#define HW_OCOTP_OTPMK7(x)       (*(__IO hw_ocotp_otpmk7_t *) HW_OCOTP_OTPMK7_ADDR(x))
#define HW_OCOTP_OTPMK7_RD(x)    (HW_OCOTP_OTPMK7(x).U)
#define HW_OCOTP_OTPMK7_WR(x, v) (HW_OCOTP_OTPMK7(x).U = (v))
#define HW_OCOTP_OTPMK7_SET(x, v) (HW_OCOTP_OTPMK7_WR(x, HW_OCOTP_OTPMK7_RD(x) |  (v)))
#define HW_OCOTP_OTPMK7_CLR(x, v) (HW_OCOTP_OTPMK7_WR(x, HW_OCOTP_OTPMK7_RD(x) & ~(v)))
#define HW_OCOTP_OTPMK7_TOG(x, v) (HW_OCOTP_OTPMK7_WR(x, HW_OCOTP_OTPMK7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_OTPMK7 bitfields
 */

/*!
 * @name Register OCOTP_OTPMK7, field BITS[31:0] (RW)
 *
 * Shadow register for the OTPMK Key word7 (Copy of OTP Bank 5, word 3). These
 * bits cannot be read and written after the HW_OCOTP_LOCK_OTPMK bit is set. If
 * read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_OTPMK7_BITS (0U)          /*!< Bit position for OCOTP_OTPMK7_BITS. */
#define BM_OCOTP_OTPMK7_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_OTPMK7_BITS. */
#define BS_OCOTP_OTPMK7_BITS (32U)         /*!< Bit field size in bits for OCOTP_OTPMK7_BITS. */

/*! @brief Read current value of the OCOTP_OTPMK7_BITS field. */
#define BR_OCOTP_OTPMK7_BITS(x) (HW_OCOTP_OTPMK7(x).U)

/*! @brief Format value for bitfield OCOTP_OTPMK7_BITS. */
#define BF_OCOTP_OTPMK7_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_OTPMK7_BITS) & BM_OCOTP_OTPMK7_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_OTPMK7_BITS(x, v) (HW_OCOTP_OTPMK7_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SRK0 - Shadow Register for OTP Bank6 Word0 (SRK Hash)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SRK0 - Shadow Register for OTP Bank6 Word0 (SRK Hash) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_srk0
{
    uint32_t U;
    struct _hw_ocotp_srk0_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_srk0_t;

/*!
 * @name Constants and macros for entire OCOTP_SRK0 register
 */
/*@{*/
#define HW_OCOTP_SRK0_ADDR(x)    ((uintptr_t)(x) + 0x580U)

#define HW_OCOTP_SRK0(x)         (*(__IO hw_ocotp_srk0_t *) HW_OCOTP_SRK0_ADDR(x))
#define HW_OCOTP_SRK0_RD(x)      (HW_OCOTP_SRK0(x).U)
#define HW_OCOTP_SRK0_WR(x, v)   (HW_OCOTP_SRK0(x).U = (v))
#define HW_OCOTP_SRK0_SET(x, v)  (HW_OCOTP_SRK0_WR(x, HW_OCOTP_SRK0_RD(x) |  (v)))
#define HW_OCOTP_SRK0_CLR(x, v)  (HW_OCOTP_SRK0_WR(x, HW_OCOTP_SRK0_RD(x) & ~(v)))
#define HW_OCOTP_SRK0_TOG(x, v)  (HW_OCOTP_SRK0_WR(x, HW_OCOTP_SRK0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SRK0 bitfields
 */

/*!
 * @name Register OCOTP_SRK0, field BITS[31:0] (RW)
 *
 * Shadow register for the hash of the Super Root Key word0 (Copy of OTP Bank 6,
 * word 0). These bits become read-only after the HW_OCOTP_LOCK_SRK bit is set.
 */
/*@{*/
#define BP_OCOTP_SRK0_BITS   (0U)          /*!< Bit position for OCOTP_SRK0_BITS. */
#define BM_OCOTP_SRK0_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SRK0_BITS. */
#define BS_OCOTP_SRK0_BITS   (32U)         /*!< Bit field size in bits for OCOTP_SRK0_BITS. */

/*! @brief Read current value of the OCOTP_SRK0_BITS field. */
#define BR_OCOTP_SRK0_BITS(x) (HW_OCOTP_SRK0(x).U)

/*! @brief Format value for bitfield OCOTP_SRK0_BITS. */
#define BF_OCOTP_SRK0_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SRK0_BITS) & BM_OCOTP_SRK0_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SRK0_BITS(x, v) (HW_OCOTP_SRK0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SRK1 - Shadow Register for OTP Bank6 Word1 (SRK Hash)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SRK1 - Shadow Register for OTP Bank6 Word1 (SRK Hash) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_srk1
{
    uint32_t U;
    struct _hw_ocotp_srk1_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_srk1_t;

/*!
 * @name Constants and macros for entire OCOTP_SRK1 register
 */
/*@{*/
#define HW_OCOTP_SRK1_ADDR(x)    ((uintptr_t)(x) + 0x590U)

#define HW_OCOTP_SRK1(x)         (*(__IO hw_ocotp_srk1_t *) HW_OCOTP_SRK1_ADDR(x))
#define HW_OCOTP_SRK1_RD(x)      (HW_OCOTP_SRK1(x).U)
#define HW_OCOTP_SRK1_WR(x, v)   (HW_OCOTP_SRK1(x).U = (v))
#define HW_OCOTP_SRK1_SET(x, v)  (HW_OCOTP_SRK1_WR(x, HW_OCOTP_SRK1_RD(x) |  (v)))
#define HW_OCOTP_SRK1_CLR(x, v)  (HW_OCOTP_SRK1_WR(x, HW_OCOTP_SRK1_RD(x) & ~(v)))
#define HW_OCOTP_SRK1_TOG(x, v)  (HW_OCOTP_SRK1_WR(x, HW_OCOTP_SRK1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SRK1 bitfields
 */

/*!
 * @name Register OCOTP_SRK1, field BITS[31:0] (RW)
 *
 * Shadow register for the hash of the Super Root Key word1 (Copy of OTP Bank 6,
 * word 1). These bits become read-only after the HW_OCOTP_LOCK_SRK bit is set.
 */
/*@{*/
#define BP_OCOTP_SRK1_BITS   (0U)          /*!< Bit position for OCOTP_SRK1_BITS. */
#define BM_OCOTP_SRK1_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SRK1_BITS. */
#define BS_OCOTP_SRK1_BITS   (32U)         /*!< Bit field size in bits for OCOTP_SRK1_BITS. */

/*! @brief Read current value of the OCOTP_SRK1_BITS field. */
#define BR_OCOTP_SRK1_BITS(x) (HW_OCOTP_SRK1(x).U)

/*! @brief Format value for bitfield OCOTP_SRK1_BITS. */
#define BF_OCOTP_SRK1_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SRK1_BITS) & BM_OCOTP_SRK1_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SRK1_BITS(x, v) (HW_OCOTP_SRK1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SRK2 - Shadow Register for OTP Bank6 Word2 (SRK Hash)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SRK2 - Shadow Register for OTP Bank6 Word2 (SRK Hash) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_srk2
{
    uint32_t U;
    struct _hw_ocotp_srk2_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_srk2_t;

/*!
 * @name Constants and macros for entire OCOTP_SRK2 register
 */
/*@{*/
#define HW_OCOTP_SRK2_ADDR(x)    ((uintptr_t)(x) + 0x5A0U)

#define HW_OCOTP_SRK2(x)         (*(__IO hw_ocotp_srk2_t *) HW_OCOTP_SRK2_ADDR(x))
#define HW_OCOTP_SRK2_RD(x)      (HW_OCOTP_SRK2(x).U)
#define HW_OCOTP_SRK2_WR(x, v)   (HW_OCOTP_SRK2(x).U = (v))
#define HW_OCOTP_SRK2_SET(x, v)  (HW_OCOTP_SRK2_WR(x, HW_OCOTP_SRK2_RD(x) |  (v)))
#define HW_OCOTP_SRK2_CLR(x, v)  (HW_OCOTP_SRK2_WR(x, HW_OCOTP_SRK2_RD(x) & ~(v)))
#define HW_OCOTP_SRK2_TOG(x, v)  (HW_OCOTP_SRK2_WR(x, HW_OCOTP_SRK2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SRK2 bitfields
 */

/*!
 * @name Register OCOTP_SRK2, field BITS[31:0] (RW)
 *
 * Shadow register for the hash of the Super Root Key word2 (Copy of OTP Bank 6,
 * word 2). These bits become read-only after the HW_OCOTP_LOCK_SRK bit is set.
 */
/*@{*/
#define BP_OCOTP_SRK2_BITS   (0U)          /*!< Bit position for OCOTP_SRK2_BITS. */
#define BM_OCOTP_SRK2_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SRK2_BITS. */
#define BS_OCOTP_SRK2_BITS   (32U)         /*!< Bit field size in bits for OCOTP_SRK2_BITS. */

/*! @brief Read current value of the OCOTP_SRK2_BITS field. */
#define BR_OCOTP_SRK2_BITS(x) (HW_OCOTP_SRK2(x).U)

/*! @brief Format value for bitfield OCOTP_SRK2_BITS. */
#define BF_OCOTP_SRK2_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SRK2_BITS) & BM_OCOTP_SRK2_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SRK2_BITS(x, v) (HW_OCOTP_SRK2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SRK3 - Shadow Register for OTP Bank6 Word3 (SRK Hash)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SRK3 - Shadow Register for OTP Bank6 Word3 (SRK Hash) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_srk3
{
    uint32_t U;
    struct _hw_ocotp_srk3_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_srk3_t;

/*!
 * @name Constants and macros for entire OCOTP_SRK3 register
 */
/*@{*/
#define HW_OCOTP_SRK3_ADDR(x)    ((uintptr_t)(x) + 0x5B0U)

#define HW_OCOTP_SRK3(x)         (*(__IO hw_ocotp_srk3_t *) HW_OCOTP_SRK3_ADDR(x))
#define HW_OCOTP_SRK3_RD(x)      (HW_OCOTP_SRK3(x).U)
#define HW_OCOTP_SRK3_WR(x, v)   (HW_OCOTP_SRK3(x).U = (v))
#define HW_OCOTP_SRK3_SET(x, v)  (HW_OCOTP_SRK3_WR(x, HW_OCOTP_SRK3_RD(x) |  (v)))
#define HW_OCOTP_SRK3_CLR(x, v)  (HW_OCOTP_SRK3_WR(x, HW_OCOTP_SRK3_RD(x) & ~(v)))
#define HW_OCOTP_SRK3_TOG(x, v)  (HW_OCOTP_SRK3_WR(x, HW_OCOTP_SRK3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SRK3 bitfields
 */

/*!
 * @name Register OCOTP_SRK3, field BITS[31:0] (RW)
 *
 * Shadow register for the hash of the Super Root Key word3 (Copy of OTP Bank 6,
 * word 3). These bits become read-only after the HW_OCOTP_LOCK_SRK bit is set.
 */
/*@{*/
#define BP_OCOTP_SRK3_BITS   (0U)          /*!< Bit position for OCOTP_SRK3_BITS. */
#define BM_OCOTP_SRK3_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SRK3_BITS. */
#define BS_OCOTP_SRK3_BITS   (32U)         /*!< Bit field size in bits for OCOTP_SRK3_BITS. */

/*! @brief Read current value of the OCOTP_SRK3_BITS field. */
#define BR_OCOTP_SRK3_BITS(x) (HW_OCOTP_SRK3(x).U)

/*! @brief Format value for bitfield OCOTP_SRK3_BITS. */
#define BF_OCOTP_SRK3_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SRK3_BITS) & BM_OCOTP_SRK3_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SRK3_BITS(x, v) (HW_OCOTP_SRK3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SRK4 - Shadow Register for OTP Bank7 Word0 (SRK Hash)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SRK4 - Shadow Register for OTP Bank7 Word0 (SRK Hash) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_srk4
{
    uint32_t U;
    struct _hw_ocotp_srk4_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_srk4_t;

/*!
 * @name Constants and macros for entire OCOTP_SRK4 register
 */
/*@{*/
#define HW_OCOTP_SRK4_ADDR(x)    ((uintptr_t)(x) + 0x5C0U)

#define HW_OCOTP_SRK4(x)         (*(__IO hw_ocotp_srk4_t *) HW_OCOTP_SRK4_ADDR(x))
#define HW_OCOTP_SRK4_RD(x)      (HW_OCOTP_SRK4(x).U)
#define HW_OCOTP_SRK4_WR(x, v)   (HW_OCOTP_SRK4(x).U = (v))
#define HW_OCOTP_SRK4_SET(x, v)  (HW_OCOTP_SRK4_WR(x, HW_OCOTP_SRK4_RD(x) |  (v)))
#define HW_OCOTP_SRK4_CLR(x, v)  (HW_OCOTP_SRK4_WR(x, HW_OCOTP_SRK4_RD(x) & ~(v)))
#define HW_OCOTP_SRK4_TOG(x, v)  (HW_OCOTP_SRK4_WR(x, HW_OCOTP_SRK4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SRK4 bitfields
 */

/*!
 * @name Register OCOTP_SRK4, field BITS[31:0] (RW)
 *
 * Shadow register for the hash of the Super Root Key word4 (Copy of OTP Bank 7,
 * word 0). These bits become read-only after the HW_OCOTP_LOCK_SRK bit is set.
 */
/*@{*/
#define BP_OCOTP_SRK4_BITS   (0U)          /*!< Bit position for OCOTP_SRK4_BITS. */
#define BM_OCOTP_SRK4_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SRK4_BITS. */
#define BS_OCOTP_SRK4_BITS   (32U)         /*!< Bit field size in bits for OCOTP_SRK4_BITS. */

/*! @brief Read current value of the OCOTP_SRK4_BITS field. */
#define BR_OCOTP_SRK4_BITS(x) (HW_OCOTP_SRK4(x).U)

/*! @brief Format value for bitfield OCOTP_SRK4_BITS. */
#define BF_OCOTP_SRK4_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SRK4_BITS) & BM_OCOTP_SRK4_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SRK4_BITS(x, v) (HW_OCOTP_SRK4_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SRK5 - Shadow Register for OTP Bank7 Word1 (SRK Hash)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SRK5 - Shadow Register for OTP Bank7 Word1 (SRK Hash) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_srk5
{
    uint32_t U;
    struct _hw_ocotp_srk5_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_srk5_t;

/*!
 * @name Constants and macros for entire OCOTP_SRK5 register
 */
/*@{*/
#define HW_OCOTP_SRK5_ADDR(x)    ((uintptr_t)(x) + 0x5D0U)

#define HW_OCOTP_SRK5(x)         (*(__IO hw_ocotp_srk5_t *) HW_OCOTP_SRK5_ADDR(x))
#define HW_OCOTP_SRK5_RD(x)      (HW_OCOTP_SRK5(x).U)
#define HW_OCOTP_SRK5_WR(x, v)   (HW_OCOTP_SRK5(x).U = (v))
#define HW_OCOTP_SRK5_SET(x, v)  (HW_OCOTP_SRK5_WR(x, HW_OCOTP_SRK5_RD(x) |  (v)))
#define HW_OCOTP_SRK5_CLR(x, v)  (HW_OCOTP_SRK5_WR(x, HW_OCOTP_SRK5_RD(x) & ~(v)))
#define HW_OCOTP_SRK5_TOG(x, v)  (HW_OCOTP_SRK5_WR(x, HW_OCOTP_SRK5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SRK5 bitfields
 */

/*!
 * @name Register OCOTP_SRK5, field BITS[31:0] (RW)
 *
 * Shadow register for the hash of the Super Root Key word5 (Copy of OTP Bank 7,
 * word 1). These bits become read-only after the HW_OCOTP_LOCK_SRK bit is set.
 */
/*@{*/
#define BP_OCOTP_SRK5_BITS   (0U)          /*!< Bit position for OCOTP_SRK5_BITS. */
#define BM_OCOTP_SRK5_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SRK5_BITS. */
#define BS_OCOTP_SRK5_BITS   (32U)         /*!< Bit field size in bits for OCOTP_SRK5_BITS. */

/*! @brief Read current value of the OCOTP_SRK5_BITS field. */
#define BR_OCOTP_SRK5_BITS(x) (HW_OCOTP_SRK5(x).U)

/*! @brief Format value for bitfield OCOTP_SRK5_BITS. */
#define BF_OCOTP_SRK5_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SRK5_BITS) & BM_OCOTP_SRK5_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SRK5_BITS(x, v) (HW_OCOTP_SRK5_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SRK6 - Shadow Register for OTP Bank7 Word2 (SRK Hash)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SRK6 - Shadow Register for OTP Bank7 Word2 (SRK Hash) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_srk6
{
    uint32_t U;
    struct _hw_ocotp_srk6_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_srk6_t;

/*!
 * @name Constants and macros for entire OCOTP_SRK6 register
 */
/*@{*/
#define HW_OCOTP_SRK6_ADDR(x)    ((uintptr_t)(x) + 0x5E0U)

#define HW_OCOTP_SRK6(x)         (*(__IO hw_ocotp_srk6_t *) HW_OCOTP_SRK6_ADDR(x))
#define HW_OCOTP_SRK6_RD(x)      (HW_OCOTP_SRK6(x).U)
#define HW_OCOTP_SRK6_WR(x, v)   (HW_OCOTP_SRK6(x).U = (v))
#define HW_OCOTP_SRK6_SET(x, v)  (HW_OCOTP_SRK6_WR(x, HW_OCOTP_SRK6_RD(x) |  (v)))
#define HW_OCOTP_SRK6_CLR(x, v)  (HW_OCOTP_SRK6_WR(x, HW_OCOTP_SRK6_RD(x) & ~(v)))
#define HW_OCOTP_SRK6_TOG(x, v)  (HW_OCOTP_SRK6_WR(x, HW_OCOTP_SRK6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SRK6 bitfields
 */

/*!
 * @name Register OCOTP_SRK6, field BITS[31:0] (RW)
 *
 * Shadow register for the hash of the Super Root Key word6 (Copy of OTP Bank 7,
 * word 2). These bits become read-only after the HW_OCOTP_LOCK_SRK bit is set.
 */
/*@{*/
#define BP_OCOTP_SRK6_BITS   (0U)          /*!< Bit position for OCOTP_SRK6_BITS. */
#define BM_OCOTP_SRK6_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SRK6_BITS. */
#define BS_OCOTP_SRK6_BITS   (32U)         /*!< Bit field size in bits for OCOTP_SRK6_BITS. */

/*! @brief Read current value of the OCOTP_SRK6_BITS field. */
#define BR_OCOTP_SRK6_BITS(x) (HW_OCOTP_SRK6(x).U)

/*! @brief Format value for bitfield OCOTP_SRK6_BITS. */
#define BF_OCOTP_SRK6_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SRK6_BITS) & BM_OCOTP_SRK6_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SRK6_BITS(x, v) (HW_OCOTP_SRK6_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SRK7 - Shadow Register for OTP Bank7 Word3 (SRK Hash)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SRK7 - Shadow Register for OTP Bank7 Word3 (SRK Hash) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_srk7
{
    uint32_t U;
    struct _hw_ocotp_srk7_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_srk7_t;

/*!
 * @name Constants and macros for entire OCOTP_SRK7 register
 */
/*@{*/
#define HW_OCOTP_SRK7_ADDR(x)    ((uintptr_t)(x) + 0x5F0U)

#define HW_OCOTP_SRK7(x)         (*(__IO hw_ocotp_srk7_t *) HW_OCOTP_SRK7_ADDR(x))
#define HW_OCOTP_SRK7_RD(x)      (HW_OCOTP_SRK7(x).U)
#define HW_OCOTP_SRK7_WR(x, v)   (HW_OCOTP_SRK7(x).U = (v))
#define HW_OCOTP_SRK7_SET(x, v)  (HW_OCOTP_SRK7_WR(x, HW_OCOTP_SRK7_RD(x) |  (v)))
#define HW_OCOTP_SRK7_CLR(x, v)  (HW_OCOTP_SRK7_WR(x, HW_OCOTP_SRK7_RD(x) & ~(v)))
#define HW_OCOTP_SRK7_TOG(x, v)  (HW_OCOTP_SRK7_WR(x, HW_OCOTP_SRK7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SRK7 bitfields
 */

/*!
 * @name Register OCOTP_SRK7, field BITS[31:0] (RW)
 *
 * Shadow register for the hash of the Super Root Key word7 (Copy of OTP Bank 7,
 * word 3). These bits become read-only after the HW_OCOTP_LOCK_SRK bit is set.
 */
/*@{*/
#define BP_OCOTP_SRK7_BITS   (0U)          /*!< Bit position for OCOTP_SRK7_BITS. */
#define BM_OCOTP_SRK7_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SRK7_BITS. */
#define BS_OCOTP_SRK7_BITS   (32U)         /*!< Bit field size in bits for OCOTP_SRK7_BITS. */

/*! @brief Read current value of the OCOTP_SRK7_BITS field. */
#define BR_OCOTP_SRK7_BITS(x) (HW_OCOTP_SRK7(x).U)

/*! @brief Format value for bitfield OCOTP_SRK7_BITS. */
#define BF_OCOTP_SRK7_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SRK7_BITS) & BM_OCOTP_SRK7_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SRK7_BITS(x, v) (HW_OCOTP_SRK7_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SJC_RESP0 - Value of OTP Bank8 Word0 (Secure JTAG Response Field)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SJC_RESP0 - Value of OTP Bank8 Word0 (Secure JTAG Response Field) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS] EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_sjc_resp0
{
    uint32_t U;
    struct _hw_ocotp_sjc_resp0_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_sjc_resp0_t;

/*!
 * @name Constants and macros for entire OCOTP_SJC_RESP0 register
 */
/*@{*/
#define HW_OCOTP_SJC_RESP0_ADDR(x) ((uintptr_t)(x) + 0x600U)

#define HW_OCOTP_SJC_RESP0(x)    (*(__IO hw_ocotp_sjc_resp0_t *) HW_OCOTP_SJC_RESP0_ADDR(x))
#define HW_OCOTP_SJC_RESP0_RD(x) (HW_OCOTP_SJC_RESP0(x).U)
#define HW_OCOTP_SJC_RESP0_WR(x, v) (HW_OCOTP_SJC_RESP0(x).U = (v))
#define HW_OCOTP_SJC_RESP0_SET(x, v) (HW_OCOTP_SJC_RESP0_WR(x, HW_OCOTP_SJC_RESP0_RD(x) |  (v)))
#define HW_OCOTP_SJC_RESP0_CLR(x, v) (HW_OCOTP_SJC_RESP0_WR(x, HW_OCOTP_SJC_RESP0_RD(x) & ~(v)))
#define HW_OCOTP_SJC_RESP0_TOG(x, v) (HW_OCOTP_SJC_RESP0_WR(x, HW_OCOTP_SJC_RESP0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SJC_RESP0 bitfields
 */

/*!
 * @name Register OCOTP_SJC_RESP0, field BITS[31:0] (RW)
 *
 * Shadow register for the SJC_RESP Key word0 (Copy of OTP Bank 8, word 0).
 * These bits cannot be read and written after the HW_OCOTP_LOCK_SJC_RESP bit is set.
 * If read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_SJC_RESP0_BITS (0U)       /*!< Bit position for OCOTP_SJC_RESP0_BITS. */
#define BM_OCOTP_SJC_RESP0_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SJC_RESP0_BITS. */
#define BS_OCOTP_SJC_RESP0_BITS (32U)      /*!< Bit field size in bits for OCOTP_SJC_RESP0_BITS. */

/*! @brief Read current value of the OCOTP_SJC_RESP0_BITS field. */
#define BR_OCOTP_SJC_RESP0_BITS(x) (HW_OCOTP_SJC_RESP0(x).U)

/*! @brief Format value for bitfield OCOTP_SJC_RESP0_BITS. */
#define BF_OCOTP_SJC_RESP0_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SJC_RESP0_BITS) & BM_OCOTP_SJC_RESP0_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SJC_RESP0_BITS(x, v) (HW_OCOTP_SJC_RESP0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SJC_RESP1 - Value of OTP Bank8 Word1 (Secure JTAG Response Field)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SJC_RESP1 - Value of OTP Bank8 Word1 (Secure JTAG Response Field) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS] EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_sjc_resp1
{
    uint32_t U;
    struct _hw_ocotp_sjc_resp1_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_sjc_resp1_t;

/*!
 * @name Constants and macros for entire OCOTP_SJC_RESP1 register
 */
/*@{*/
#define HW_OCOTP_SJC_RESP1_ADDR(x) ((uintptr_t)(x) + 0x610U)

#define HW_OCOTP_SJC_RESP1(x)    (*(__IO hw_ocotp_sjc_resp1_t *) HW_OCOTP_SJC_RESP1_ADDR(x))
#define HW_OCOTP_SJC_RESP1_RD(x) (HW_OCOTP_SJC_RESP1(x).U)
#define HW_OCOTP_SJC_RESP1_WR(x, v) (HW_OCOTP_SJC_RESP1(x).U = (v))
#define HW_OCOTP_SJC_RESP1_SET(x, v) (HW_OCOTP_SJC_RESP1_WR(x, HW_OCOTP_SJC_RESP1_RD(x) |  (v)))
#define HW_OCOTP_SJC_RESP1_CLR(x, v) (HW_OCOTP_SJC_RESP1_WR(x, HW_OCOTP_SJC_RESP1_RD(x) & ~(v)))
#define HW_OCOTP_SJC_RESP1_TOG(x, v) (HW_OCOTP_SJC_RESP1_WR(x, HW_OCOTP_SJC_RESP1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SJC_RESP1 bitfields
 */

/*!
 * @name Register OCOTP_SJC_RESP1, field BITS[31:0] (RW)
 *
 * Shadow register for the SJC_RESP Key word1 (Copy of OTP Bank 8, word 1).
 * These bits cannot be read and written after the HW_OCOTP_LOCK_SJC_RESP bit is set.
 * If read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_SJC_RESP1_BITS (0U)       /*!< Bit position for OCOTP_SJC_RESP1_BITS. */
#define BM_OCOTP_SJC_RESP1_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SJC_RESP1_BITS. */
#define BS_OCOTP_SJC_RESP1_BITS (32U)      /*!< Bit field size in bits for OCOTP_SJC_RESP1_BITS. */

/*! @brief Read current value of the OCOTP_SJC_RESP1_BITS field. */
#define BR_OCOTP_SJC_RESP1_BITS(x) (HW_OCOTP_SJC_RESP1(x).U)

/*! @brief Format value for bitfield OCOTP_SJC_RESP1_BITS. */
#define BF_OCOTP_SJC_RESP1_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SJC_RESP1_BITS) & BM_OCOTP_SJC_RESP1_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SJC_RESP1_BITS(x, v) (HW_OCOTP_SJC_RESP1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_USB_ID - Value of OTP Bank8 Word2 (USB ID info)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_USB_ID - Value of OTP Bank8 Word2 (USB ID info) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_usb_id
{
    uint32_t U;
    struct _hw_ocotp_usb_id_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_usb_id_t;

/*!
 * @name Constants and macros for entire OCOTP_USB_ID register
 */
/*@{*/
#define HW_OCOTP_USB_ID_ADDR(x)  ((uintptr_t)(x) + 0x620U)

#define HW_OCOTP_USB_ID(x)       (*(__IO hw_ocotp_usb_id_t *) HW_OCOTP_USB_ID_ADDR(x))
#define HW_OCOTP_USB_ID_RD(x)    (HW_OCOTP_USB_ID(x).U)
#define HW_OCOTP_USB_ID_WR(x, v) (HW_OCOTP_USB_ID(x).U = (v))
#define HW_OCOTP_USB_ID_SET(x, v) (HW_OCOTP_USB_ID_WR(x, HW_OCOTP_USB_ID_RD(x) |  (v)))
#define HW_OCOTP_USB_ID_CLR(x, v) (HW_OCOTP_USB_ID_WR(x, HW_OCOTP_USB_ID_RD(x) & ~(v)))
#define HW_OCOTP_USB_ID_TOG(x, v) (HW_OCOTP_USB_ID_WR(x, HW_OCOTP_USB_ID_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_USB_ID bitfields
 */

/*!
 * @name Register OCOTP_USB_ID, field BITS[31:0] (RW)
 *
 * It reflects the value of OTP Bank 8, word 2.
 */
/*@{*/
#define BP_OCOTP_USB_ID_BITS (0U)          /*!< Bit position for OCOTP_USB_ID_BITS. */
#define BM_OCOTP_USB_ID_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_USB_ID_BITS. */
#define BS_OCOTP_USB_ID_BITS (32U)         /*!< Bit field size in bits for OCOTP_USB_ID_BITS. */

/*! @brief Read current value of the OCOTP_USB_ID_BITS field. */
#define BR_OCOTP_USB_ID_BITS(x) (HW_OCOTP_USB_ID(x).U)

/*! @brief Format value for bitfield OCOTP_USB_ID_BITS. */
#define BF_OCOTP_USB_ID_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_USB_ID_BITS) & BM_OCOTP_USB_ID_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_USB_ID_BITS(x, v) (HW_OCOTP_USB_ID_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_FIELD_RETURN - Value of OTP Bank8 Word3 (Field Return)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_FIELD_RETURN - Value of OTP Bank8 Word3 (Field Return) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It cannot be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_field_return
{
    uint32_t U;
    struct _hw_ocotp_field_return_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_field_return_t;

/*!
 * @name Constants and macros for entire OCOTP_FIELD_RETURN register
 */
/*@{*/
#define HW_OCOTP_FIELD_RETURN_ADDR(x) ((uintptr_t)(x) + 0x630U)

#define HW_OCOTP_FIELD_RETURN(x) (*(__IO hw_ocotp_field_return_t *) HW_OCOTP_FIELD_RETURN_ADDR(x))
#define HW_OCOTP_FIELD_RETURN_RD(x) (HW_OCOTP_FIELD_RETURN(x).U)
#define HW_OCOTP_FIELD_RETURN_WR(x, v) (HW_OCOTP_FIELD_RETURN(x).U = (v))
#define HW_OCOTP_FIELD_RETURN_SET(x, v) (HW_OCOTP_FIELD_RETURN_WR(x, HW_OCOTP_FIELD_RETURN_RD(x) |  (v)))
#define HW_OCOTP_FIELD_RETURN_CLR(x, v) (HW_OCOTP_FIELD_RETURN_WR(x, HW_OCOTP_FIELD_RETURN_RD(x) & ~(v)))
#define HW_OCOTP_FIELD_RETURN_TOG(x, v) (HW_OCOTP_FIELD_RETURN_WR(x, HW_OCOTP_FIELD_RETURN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_FIELD_RETURN bitfields
 */

/*!
 * @name Register OCOTP_FIELD_RETURN, field BITS[31:0] (RW)
 *
 * It reflects the value of OTP Bank 8, word 3.
 */
/*@{*/
#define BP_OCOTP_FIELD_RETURN_BITS (0U)    /*!< Bit position for OCOTP_FIELD_RETURN_BITS. */
#define BM_OCOTP_FIELD_RETURN_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_FIELD_RETURN_BITS. */
#define BS_OCOTP_FIELD_RETURN_BITS (32U)   /*!< Bit field size in bits for OCOTP_FIELD_RETURN_BITS. */

/*! @brief Read current value of the OCOTP_FIELD_RETURN_BITS field. */
#define BR_OCOTP_FIELD_RETURN_BITS(x) (HW_OCOTP_FIELD_RETURN(x).U)

/*! @brief Format value for bitfield OCOTP_FIELD_RETURN_BITS. */
#define BF_OCOTP_FIELD_RETURN_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_FIELD_RETURN_BITS) & BM_OCOTP_FIELD_RETURN_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_FIELD_RETURN_BITS(x, v) (HW_OCOTP_FIELD_RETURN_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MAC_ADDR0 - Value of OTP Bank9 Word0 (MAC Address)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MAC_ADDR0 - Value of OTP Bank9 Word0 (MAC Address) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS] EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mac_addr0
{
    uint32_t U;
    struct _hw_ocotp_mac_addr0_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mac_addr0_t;

/*!
 * @name Constants and macros for entire OCOTP_MAC_ADDR0 register
 */
/*@{*/
#define HW_OCOTP_MAC_ADDR0_ADDR(x) ((uintptr_t)(x) + 0x640U)

#define HW_OCOTP_MAC_ADDR0(x)    (*(__IO hw_ocotp_mac_addr0_t *) HW_OCOTP_MAC_ADDR0_ADDR(x))
#define HW_OCOTP_MAC_ADDR0_RD(x) (HW_OCOTP_MAC_ADDR0(x).U)
#define HW_OCOTP_MAC_ADDR0_WR(x, v) (HW_OCOTP_MAC_ADDR0(x).U = (v))
#define HW_OCOTP_MAC_ADDR0_SET(x, v) (HW_OCOTP_MAC_ADDR0_WR(x, HW_OCOTP_MAC_ADDR0_RD(x) |  (v)))
#define HW_OCOTP_MAC_ADDR0_CLR(x, v) (HW_OCOTP_MAC_ADDR0_WR(x, HW_OCOTP_MAC_ADDR0_RD(x) & ~(v)))
#define HW_OCOTP_MAC_ADDR0_TOG(x, v) (HW_OCOTP_MAC_ADDR0_WR(x, HW_OCOTP_MAC_ADDR0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MAC_ADDR0 bitfields
 */

/*!
 * @name Register OCOTP_MAC_ADDR0, field BITS[31:0] (RW)
 *
 * It reflects the value of OTP Bank 9, word 0.
 */
/*@{*/
#define BP_OCOTP_MAC_ADDR0_BITS (0U)       /*!< Bit position for OCOTP_MAC_ADDR0_BITS. */
#define BM_OCOTP_MAC_ADDR0_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MAC_ADDR0_BITS. */
#define BS_OCOTP_MAC_ADDR0_BITS (32U)      /*!< Bit field size in bits for OCOTP_MAC_ADDR0_BITS. */

/*! @brief Read current value of the OCOTP_MAC_ADDR0_BITS field. */
#define BR_OCOTP_MAC_ADDR0_BITS(x) (HW_OCOTP_MAC_ADDR0(x).U)

/*! @brief Format value for bitfield OCOTP_MAC_ADDR0_BITS. */
#define BF_OCOTP_MAC_ADDR0_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MAC_ADDR0_BITS) & BM_OCOTP_MAC_ADDR0_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MAC_ADDR0_BITS(x, v) (HW_OCOTP_MAC_ADDR0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MAC_ADDR1 - Value of OTP Bank9 Word1 (MAC Address)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MAC_ADDR1 - Value of OTP Bank9 Word1 (MAC Address) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mac_addr1
{
    uint32_t U;
    struct _hw_ocotp_mac_addr1_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mac_addr1_t;

/*!
 * @name Constants and macros for entire OCOTP_MAC_ADDR1 register
 */
/*@{*/
#define HW_OCOTP_MAC_ADDR1_ADDR(x) ((uintptr_t)(x) + 0x650U)

#define HW_OCOTP_MAC_ADDR1(x)    (*(__IO hw_ocotp_mac_addr1_t *) HW_OCOTP_MAC_ADDR1_ADDR(x))
#define HW_OCOTP_MAC_ADDR1_RD(x) (HW_OCOTP_MAC_ADDR1(x).U)
#define HW_OCOTP_MAC_ADDR1_WR(x, v) (HW_OCOTP_MAC_ADDR1(x).U = (v))
#define HW_OCOTP_MAC_ADDR1_SET(x, v) (HW_OCOTP_MAC_ADDR1_WR(x, HW_OCOTP_MAC_ADDR1_RD(x) |  (v)))
#define HW_OCOTP_MAC_ADDR1_CLR(x, v) (HW_OCOTP_MAC_ADDR1_WR(x, HW_OCOTP_MAC_ADDR1_RD(x) & ~(v)))
#define HW_OCOTP_MAC_ADDR1_TOG(x, v) (HW_OCOTP_MAC_ADDR1_WR(x, HW_OCOTP_MAC_ADDR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MAC_ADDR1 bitfields
 */

/*!
 * @name Register OCOTP_MAC_ADDR1, field BITS[31:0] (RW)
 *
 * It reflects the value of OTP Bank 9, word 1.
 */
/*@{*/
#define BP_OCOTP_MAC_ADDR1_BITS (0U)       /*!< Bit position for OCOTP_MAC_ADDR1_BITS. */
#define BM_OCOTP_MAC_ADDR1_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MAC_ADDR1_BITS. */
#define BS_OCOTP_MAC_ADDR1_BITS (32U)      /*!< Bit field size in bits for OCOTP_MAC_ADDR1_BITS. */

/*! @brief Read current value of the OCOTP_MAC_ADDR1_BITS field. */
#define BR_OCOTP_MAC_ADDR1_BITS(x) (HW_OCOTP_MAC_ADDR1(x).U)

/*! @brief Format value for bitfield OCOTP_MAC_ADDR1_BITS. */
#define BF_OCOTP_MAC_ADDR1_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MAC_ADDR1_BITS) & BM_OCOTP_MAC_ADDR1_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MAC_ADDR1_BITS(x, v) (HW_OCOTP_MAC_ADDR1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MAC_ADDR2 - Value of OTP Bank9 Word2 (MAC Address)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MAC_ADDR2 - Value of OTP Bank9 Word2 (MAC Address) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mac_addr2
{
    uint32_t U;
    struct _hw_ocotp_mac_addr2_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mac_addr2_t;

/*!
 * @name Constants and macros for entire OCOTP_MAC_ADDR2 register
 */
/*@{*/
#define HW_OCOTP_MAC_ADDR2_ADDR(x) ((uintptr_t)(x) + 0x660U)

#define HW_OCOTP_MAC_ADDR2(x)    (*(__IO hw_ocotp_mac_addr2_t *) HW_OCOTP_MAC_ADDR2_ADDR(x))
#define HW_OCOTP_MAC_ADDR2_RD(x) (HW_OCOTP_MAC_ADDR2(x).U)
#define HW_OCOTP_MAC_ADDR2_WR(x, v) (HW_OCOTP_MAC_ADDR2(x).U = (v))
#define HW_OCOTP_MAC_ADDR2_SET(x, v) (HW_OCOTP_MAC_ADDR2_WR(x, HW_OCOTP_MAC_ADDR2_RD(x) |  (v)))
#define HW_OCOTP_MAC_ADDR2_CLR(x, v) (HW_OCOTP_MAC_ADDR2_WR(x, HW_OCOTP_MAC_ADDR2_RD(x) & ~(v)))
#define HW_OCOTP_MAC_ADDR2_TOG(x, v) (HW_OCOTP_MAC_ADDR2_WR(x, HW_OCOTP_MAC_ADDR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MAC_ADDR2 bitfields
 */

/*!
 * @name Register OCOTP_MAC_ADDR2, field BITS[31:0] (RW)
 *
 * It reflects the value of OTP Bank 9, word 2.
 */
/*@{*/
#define BP_OCOTP_MAC_ADDR2_BITS (0U)       /*!< Bit position for OCOTP_MAC_ADDR2_BITS. */
#define BM_OCOTP_MAC_ADDR2_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MAC_ADDR2_BITS. */
#define BS_OCOTP_MAC_ADDR2_BITS (32U)      /*!< Bit field size in bits for OCOTP_MAC_ADDR2_BITS. */

/*! @brief Read current value of the OCOTP_MAC_ADDR2_BITS field. */
#define BR_OCOTP_MAC_ADDR2_BITS(x) (HW_OCOTP_MAC_ADDR2(x).U)

/*! @brief Format value for bitfield OCOTP_MAC_ADDR2_BITS. */
#define BF_OCOTP_MAC_ADDR2_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MAC_ADDR2_BITS) & BM_OCOTP_MAC_ADDR2_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MAC_ADDR2_BITS(x, v) (HW_OCOTP_MAC_ADDR2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_SRK_REVOKE - Value of OTP Bank9 Word3 (SRK Revoke)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_SRK_REVOKE - Value of OTP Bank9 Word3 (SRK Revoke) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_srk_revoke
{
    uint32_t U;
    struct _hw_ocotp_srk_revoke_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_srk_revoke_t;

/*!
 * @name Constants and macros for entire OCOTP_SRK_REVOKE register
 */
/*@{*/
#define HW_OCOTP_SRK_REVOKE_ADDR(x) ((uintptr_t)(x) + 0x670U)

#define HW_OCOTP_SRK_REVOKE(x)   (*(__IO hw_ocotp_srk_revoke_t *) HW_OCOTP_SRK_REVOKE_ADDR(x))
#define HW_OCOTP_SRK_REVOKE_RD(x) (HW_OCOTP_SRK_REVOKE(x).U)
#define HW_OCOTP_SRK_REVOKE_WR(x, v) (HW_OCOTP_SRK_REVOKE(x).U = (v))
#define HW_OCOTP_SRK_REVOKE_SET(x, v) (HW_OCOTP_SRK_REVOKE_WR(x, HW_OCOTP_SRK_REVOKE_RD(x) |  (v)))
#define HW_OCOTP_SRK_REVOKE_CLR(x, v) (HW_OCOTP_SRK_REVOKE_WR(x, HW_OCOTP_SRK_REVOKE_RD(x) & ~(v)))
#define HW_OCOTP_SRK_REVOKE_TOG(x, v) (HW_OCOTP_SRK_REVOKE_WR(x, HW_OCOTP_SRK_REVOKE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_SRK_REVOKE bitfields
 */

/*!
 * @name Register OCOTP_SRK_REVOKE, field BITS[31:0] (RW)
 *
 * It reflects the value of OTP Bank 9, word 3.
 */
/*@{*/
#define BP_OCOTP_SRK_REVOKE_BITS (0U)      /*!< Bit position for OCOTP_SRK_REVOKE_BITS. */
#define BM_OCOTP_SRK_REVOKE_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_SRK_REVOKE_BITS. */
#define BS_OCOTP_SRK_REVOKE_BITS (32U)     /*!< Bit field size in bits for OCOTP_SRK_REVOKE_BITS. */

/*! @brief Read current value of the OCOTP_SRK_REVOKE_BITS field. */
#define BR_OCOTP_SRK_REVOKE_BITS(x) (HW_OCOTP_SRK_REVOKE(x).U)

/*! @brief Format value for bitfield OCOTP_SRK_REVOKE_BITS. */
#define BF_OCOTP_SRK_REVOKE_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_SRK_REVOKE_BITS) & BM_OCOTP_SRK_REVOKE_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_SRK_REVOKE_BITS(x, v) (HW_OCOTP_SRK_REVOKE_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MAU_KEY0 - Shadow Register for OTP Bank10 Word0 (MAU Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MAU_KEY0 - Shadow Register for OTP Bank10 Word0 (MAU Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mau_key0
{
    uint32_t U;
    struct _hw_ocotp_mau_key0_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mau_key0_t;

/*!
 * @name Constants and macros for entire OCOTP_MAU_KEY0 register
 */
/*@{*/
#define HW_OCOTP_MAU_KEY0_ADDR(x) ((uintptr_t)(x) + 0x680U)

#define HW_OCOTP_MAU_KEY0(x)     (*(__IO hw_ocotp_mau_key0_t *) HW_OCOTP_MAU_KEY0_ADDR(x))
#define HW_OCOTP_MAU_KEY0_RD(x)  (HW_OCOTP_MAU_KEY0(x).U)
#define HW_OCOTP_MAU_KEY0_WR(x, v) (HW_OCOTP_MAU_KEY0(x).U = (v))
#define HW_OCOTP_MAU_KEY0_SET(x, v) (HW_OCOTP_MAU_KEY0_WR(x, HW_OCOTP_MAU_KEY0_RD(x) |  (v)))
#define HW_OCOTP_MAU_KEY0_CLR(x, v) (HW_OCOTP_MAU_KEY0_WR(x, HW_OCOTP_MAU_KEY0_RD(x) & ~(v)))
#define HW_OCOTP_MAU_KEY0_TOG(x, v) (HW_OCOTP_MAU_KEY0_WR(x, HW_OCOTP_MAU_KEY0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MAU_KEY0 bitfields
 */

/*!
 * @name Register OCOTP_MAU_KEY0, field BITS[31:0] (RW)
 *
 * Shadow register for the MAU Key word0 (Copy of OTP Bank 10, word 0). These
 * bits cannot be read and written after the HW_OCOTP_LOCK_MAU_KEY bit is set. If
 * read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_MAU_KEY0_BITS (0U)        /*!< Bit position for OCOTP_MAU_KEY0_BITS. */
#define BM_OCOTP_MAU_KEY0_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MAU_KEY0_BITS. */
#define BS_OCOTP_MAU_KEY0_BITS (32U)       /*!< Bit field size in bits for OCOTP_MAU_KEY0_BITS. */

/*! @brief Read current value of the OCOTP_MAU_KEY0_BITS field. */
#define BR_OCOTP_MAU_KEY0_BITS(x) (HW_OCOTP_MAU_KEY0(x).U)

/*! @brief Format value for bitfield OCOTP_MAU_KEY0_BITS. */
#define BF_OCOTP_MAU_KEY0_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MAU_KEY0_BITS) & BM_OCOTP_MAU_KEY0_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MAU_KEY0_BITS(x, v) (HW_OCOTP_MAU_KEY0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MAU_KEY1 - Shadow Register for OTP Bank10 Word1 (MAU Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MAU_KEY1 - Shadow Register for OTP Bank10 Word1 (MAU Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mau_key1
{
    uint32_t U;
    struct _hw_ocotp_mau_key1_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mau_key1_t;

/*!
 * @name Constants and macros for entire OCOTP_MAU_KEY1 register
 */
/*@{*/
#define HW_OCOTP_MAU_KEY1_ADDR(x) ((uintptr_t)(x) + 0x690U)

#define HW_OCOTP_MAU_KEY1(x)     (*(__IO hw_ocotp_mau_key1_t *) HW_OCOTP_MAU_KEY1_ADDR(x))
#define HW_OCOTP_MAU_KEY1_RD(x)  (HW_OCOTP_MAU_KEY1(x).U)
#define HW_OCOTP_MAU_KEY1_WR(x, v) (HW_OCOTP_MAU_KEY1(x).U = (v))
#define HW_OCOTP_MAU_KEY1_SET(x, v) (HW_OCOTP_MAU_KEY1_WR(x, HW_OCOTP_MAU_KEY1_RD(x) |  (v)))
#define HW_OCOTP_MAU_KEY1_CLR(x, v) (HW_OCOTP_MAU_KEY1_WR(x, HW_OCOTP_MAU_KEY1_RD(x) & ~(v)))
#define HW_OCOTP_MAU_KEY1_TOG(x, v) (HW_OCOTP_MAU_KEY1_WR(x, HW_OCOTP_MAU_KEY1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MAU_KEY1 bitfields
 */

/*!
 * @name Register OCOTP_MAU_KEY1, field BITS[31:0] (RW)
 *
 * Shadow register for the MAU Key word1 (Copy of OTP Bank 10, word 1). These
 * bits cannot be read and written after the HW_OCOTP_LOCK_MAU_KEY bit is set. If
 * read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_MAU_KEY1_BITS (0U)        /*!< Bit position for OCOTP_MAU_KEY1_BITS. */
#define BM_OCOTP_MAU_KEY1_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MAU_KEY1_BITS. */
#define BS_OCOTP_MAU_KEY1_BITS (32U)       /*!< Bit field size in bits for OCOTP_MAU_KEY1_BITS. */

/*! @brief Read current value of the OCOTP_MAU_KEY1_BITS field. */
#define BR_OCOTP_MAU_KEY1_BITS(x) (HW_OCOTP_MAU_KEY1(x).U)

/*! @brief Format value for bitfield OCOTP_MAU_KEY1_BITS. */
#define BF_OCOTP_MAU_KEY1_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MAU_KEY1_BITS) & BM_OCOTP_MAU_KEY1_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MAU_KEY1_BITS(x, v) (HW_OCOTP_MAU_KEY1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MAU_KEY2 - Shadow Register for OTP Bank10 Word2 (MAU Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MAU_KEY2 - Shadow Register for OTP Bank10 Word2 (MAU Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mau_key2
{
    uint32_t U;
    struct _hw_ocotp_mau_key2_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mau_key2_t;

/*!
 * @name Constants and macros for entire OCOTP_MAU_KEY2 register
 */
/*@{*/
#define HW_OCOTP_MAU_KEY2_ADDR(x) ((uintptr_t)(x) + 0x6A0U)

#define HW_OCOTP_MAU_KEY2(x)     (*(__IO hw_ocotp_mau_key2_t *) HW_OCOTP_MAU_KEY2_ADDR(x))
#define HW_OCOTP_MAU_KEY2_RD(x)  (HW_OCOTP_MAU_KEY2(x).U)
#define HW_OCOTP_MAU_KEY2_WR(x, v) (HW_OCOTP_MAU_KEY2(x).U = (v))
#define HW_OCOTP_MAU_KEY2_SET(x, v) (HW_OCOTP_MAU_KEY2_WR(x, HW_OCOTP_MAU_KEY2_RD(x) |  (v)))
#define HW_OCOTP_MAU_KEY2_CLR(x, v) (HW_OCOTP_MAU_KEY2_WR(x, HW_OCOTP_MAU_KEY2_RD(x) & ~(v)))
#define HW_OCOTP_MAU_KEY2_TOG(x, v) (HW_OCOTP_MAU_KEY2_WR(x, HW_OCOTP_MAU_KEY2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MAU_KEY2 bitfields
 */

/*!
 * @name Register OCOTP_MAU_KEY2, field BITS[31:0] (RW)
 *
 * Shadow register for the MAU Key word2 (Copy of OTP Bank 10, word 2). These
 * bits cannot be read and written after the HW_OCOTP_LOCK_MAU_KEY bit is set. If
 * read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_MAU_KEY2_BITS (0U)        /*!< Bit position for OCOTP_MAU_KEY2_BITS. */
#define BM_OCOTP_MAU_KEY2_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MAU_KEY2_BITS. */
#define BS_OCOTP_MAU_KEY2_BITS (32U)       /*!< Bit field size in bits for OCOTP_MAU_KEY2_BITS. */

/*! @brief Read current value of the OCOTP_MAU_KEY2_BITS field. */
#define BR_OCOTP_MAU_KEY2_BITS(x) (HW_OCOTP_MAU_KEY2(x).U)

/*! @brief Format value for bitfield OCOTP_MAU_KEY2_BITS. */
#define BF_OCOTP_MAU_KEY2_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MAU_KEY2_BITS) & BM_OCOTP_MAU_KEY2_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MAU_KEY2_BITS(x, v) (HW_OCOTP_MAU_KEY2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MAU_KEY3 - Shadow Register for OTP Bank10 Word3 (MAU Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MAU_KEY3 - Shadow Register for OTP Bank10 Word3 (MAU Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mau_key3
{
    uint32_t U;
    struct _hw_ocotp_mau_key3_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mau_key3_t;

/*!
 * @name Constants and macros for entire OCOTP_MAU_KEY3 register
 */
/*@{*/
#define HW_OCOTP_MAU_KEY3_ADDR(x) ((uintptr_t)(x) + 0x6B0U)

#define HW_OCOTP_MAU_KEY3(x)     (*(__IO hw_ocotp_mau_key3_t *) HW_OCOTP_MAU_KEY3_ADDR(x))
#define HW_OCOTP_MAU_KEY3_RD(x)  (HW_OCOTP_MAU_KEY3(x).U)
#define HW_OCOTP_MAU_KEY3_WR(x, v) (HW_OCOTP_MAU_KEY3(x).U = (v))
#define HW_OCOTP_MAU_KEY3_SET(x, v) (HW_OCOTP_MAU_KEY3_WR(x, HW_OCOTP_MAU_KEY3_RD(x) |  (v)))
#define HW_OCOTP_MAU_KEY3_CLR(x, v) (HW_OCOTP_MAU_KEY3_WR(x, HW_OCOTP_MAU_KEY3_RD(x) & ~(v)))
#define HW_OCOTP_MAU_KEY3_TOG(x, v) (HW_OCOTP_MAU_KEY3_WR(x, HW_OCOTP_MAU_KEY3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MAU_KEY3 bitfields
 */

/*!
 * @name Register OCOTP_MAU_KEY3, field BITS[31:0] (RW)
 *
 * Shadow register for the MAU Key word3 (Copy of OTP Bank 10, word 3). These
 * bits cannot be read and written after the HW_OCOTP_LOCK_MAU_KEY bit is set. If
 * read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_MAU_KEY3_BITS (0U)        /*!< Bit position for OCOTP_MAU_KEY3_BITS. */
#define BM_OCOTP_MAU_KEY3_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MAU_KEY3_BITS. */
#define BS_OCOTP_MAU_KEY3_BITS (32U)       /*!< Bit field size in bits for OCOTP_MAU_KEY3_BITS. */

/*! @brief Read current value of the OCOTP_MAU_KEY3_BITS field. */
#define BR_OCOTP_MAU_KEY3_BITS(x) (HW_OCOTP_MAU_KEY3(x).U)

/*! @brief Format value for bitfield OCOTP_MAU_KEY3_BITS. */
#define BF_OCOTP_MAU_KEY3_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MAU_KEY3_BITS) & BM_OCOTP_MAU_KEY3_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MAU_KEY3_BITS(x, v) (HW_OCOTP_MAU_KEY3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MAU_KEY4 - Shadow Register for OTP Bank11 Word0 (MAU Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MAU_KEY4 - Shadow Register for OTP Bank11 Word0 (MAU Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mau_key4
{
    uint32_t U;
    struct _hw_ocotp_mau_key4_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mau_key4_t;

/*!
 * @name Constants and macros for entire OCOTP_MAU_KEY4 register
 */
/*@{*/
#define HW_OCOTP_MAU_KEY4_ADDR(x) ((uintptr_t)(x) + 0x6C0U)

#define HW_OCOTP_MAU_KEY4(x)     (*(__IO hw_ocotp_mau_key4_t *) HW_OCOTP_MAU_KEY4_ADDR(x))
#define HW_OCOTP_MAU_KEY4_RD(x)  (HW_OCOTP_MAU_KEY4(x).U)
#define HW_OCOTP_MAU_KEY4_WR(x, v) (HW_OCOTP_MAU_KEY4(x).U = (v))
#define HW_OCOTP_MAU_KEY4_SET(x, v) (HW_OCOTP_MAU_KEY4_WR(x, HW_OCOTP_MAU_KEY4_RD(x) |  (v)))
#define HW_OCOTP_MAU_KEY4_CLR(x, v) (HW_OCOTP_MAU_KEY4_WR(x, HW_OCOTP_MAU_KEY4_RD(x) & ~(v)))
#define HW_OCOTP_MAU_KEY4_TOG(x, v) (HW_OCOTP_MAU_KEY4_WR(x, HW_OCOTP_MAU_KEY4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MAU_KEY4 bitfields
 */

/*!
 * @name Register OCOTP_MAU_KEY4, field BITS[31:0] (RW)
 *
 * Shadow register for the MAU Key word4 (Copy of OTP Bank 11, word 0). These
 * bits cannot be read and written after the HW_OCOTP_LOCK_MAU_KEY bit is set. If
 * read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_MAU_KEY4_BITS (0U)        /*!< Bit position for OCOTP_MAU_KEY4_BITS. */
#define BM_OCOTP_MAU_KEY4_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MAU_KEY4_BITS. */
#define BS_OCOTP_MAU_KEY4_BITS (32U)       /*!< Bit field size in bits for OCOTP_MAU_KEY4_BITS. */

/*! @brief Read current value of the OCOTP_MAU_KEY4_BITS field. */
#define BR_OCOTP_MAU_KEY4_BITS(x) (HW_OCOTP_MAU_KEY4(x).U)

/*! @brief Format value for bitfield OCOTP_MAU_KEY4_BITS. */
#define BF_OCOTP_MAU_KEY4_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MAU_KEY4_BITS) & BM_OCOTP_MAU_KEY4_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MAU_KEY4_BITS(x, v) (HW_OCOTP_MAU_KEY4_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MAU_KEY5 - Shadow Register for OTP Bank11 Word1 (MAU Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MAU_KEY5 - Shadow Register for OTP Bank11 Word1 (MAU Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mau_key5
{
    uint32_t U;
    struct _hw_ocotp_mau_key5_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mau_key5_t;

/*!
 * @name Constants and macros for entire OCOTP_MAU_KEY5 register
 */
/*@{*/
#define HW_OCOTP_MAU_KEY5_ADDR(x) ((uintptr_t)(x) + 0x6D0U)

#define HW_OCOTP_MAU_KEY5(x)     (*(__IO hw_ocotp_mau_key5_t *) HW_OCOTP_MAU_KEY5_ADDR(x))
#define HW_OCOTP_MAU_KEY5_RD(x)  (HW_OCOTP_MAU_KEY5(x).U)
#define HW_OCOTP_MAU_KEY5_WR(x, v) (HW_OCOTP_MAU_KEY5(x).U = (v))
#define HW_OCOTP_MAU_KEY5_SET(x, v) (HW_OCOTP_MAU_KEY5_WR(x, HW_OCOTP_MAU_KEY5_RD(x) |  (v)))
#define HW_OCOTP_MAU_KEY5_CLR(x, v) (HW_OCOTP_MAU_KEY5_WR(x, HW_OCOTP_MAU_KEY5_RD(x) & ~(v)))
#define HW_OCOTP_MAU_KEY5_TOG(x, v) (HW_OCOTP_MAU_KEY5_WR(x, HW_OCOTP_MAU_KEY5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MAU_KEY5 bitfields
 */

/*!
 * @name Register OCOTP_MAU_KEY5, field BITS[31:0] (RW)
 *
 * Shadow register for the MAU Key word5 (Copy of OTP Bank 11, word 1). These
 * bits cannot be read and written after the HW_OCOTP_LOCK_MAU_KEY bit is set. If
 * read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_MAU_KEY5_BITS (0U)        /*!< Bit position for OCOTP_MAU_KEY5_BITS. */
#define BM_OCOTP_MAU_KEY5_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MAU_KEY5_BITS. */
#define BS_OCOTP_MAU_KEY5_BITS (32U)       /*!< Bit field size in bits for OCOTP_MAU_KEY5_BITS. */

/*! @brief Read current value of the OCOTP_MAU_KEY5_BITS field. */
#define BR_OCOTP_MAU_KEY5_BITS(x) (HW_OCOTP_MAU_KEY5(x).U)

/*! @brief Format value for bitfield OCOTP_MAU_KEY5_BITS. */
#define BF_OCOTP_MAU_KEY5_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MAU_KEY5_BITS) & BM_OCOTP_MAU_KEY5_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MAU_KEY5_BITS(x, v) (HW_OCOTP_MAU_KEY5_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MAU_KEY6 - Shadow Register for OTP Bank11 Word2 (MAU Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MAU_KEY6 - Shadow Register for OTP Bank11 Word2 (MAU Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mau_key6
{
    uint32_t U;
    struct _hw_ocotp_mau_key6_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mau_key6_t;

/*!
 * @name Constants and macros for entire OCOTP_MAU_KEY6 register
 */
/*@{*/
#define HW_OCOTP_MAU_KEY6_ADDR(x) ((uintptr_t)(x) + 0x6E0U)

#define HW_OCOTP_MAU_KEY6(x)     (*(__IO hw_ocotp_mau_key6_t *) HW_OCOTP_MAU_KEY6_ADDR(x))
#define HW_OCOTP_MAU_KEY6_RD(x)  (HW_OCOTP_MAU_KEY6(x).U)
#define HW_OCOTP_MAU_KEY6_WR(x, v) (HW_OCOTP_MAU_KEY6(x).U = (v))
#define HW_OCOTP_MAU_KEY6_SET(x, v) (HW_OCOTP_MAU_KEY6_WR(x, HW_OCOTP_MAU_KEY6_RD(x) |  (v)))
#define HW_OCOTP_MAU_KEY6_CLR(x, v) (HW_OCOTP_MAU_KEY6_WR(x, HW_OCOTP_MAU_KEY6_RD(x) & ~(v)))
#define HW_OCOTP_MAU_KEY6_TOG(x, v) (HW_OCOTP_MAU_KEY6_WR(x, HW_OCOTP_MAU_KEY6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MAU_KEY6 bitfields
 */

/*!
 * @name Register OCOTP_MAU_KEY6, field BITS[31:0] (RW)
 *
 * Shadow register for the MAU Key word6 (Copy of OTP Bank 11, word 2). These
 * bits cannot be read and written after the HW_OCOTP_LOCK_MAU_KEY bit is set. If
 * read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_MAU_KEY6_BITS (0U)        /*!< Bit position for OCOTP_MAU_KEY6_BITS. */
#define BM_OCOTP_MAU_KEY6_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MAU_KEY6_BITS. */
#define BS_OCOTP_MAU_KEY6_BITS (32U)       /*!< Bit field size in bits for OCOTP_MAU_KEY6_BITS. */

/*! @brief Read current value of the OCOTP_MAU_KEY6_BITS field. */
#define BR_OCOTP_MAU_KEY6_BITS(x) (HW_OCOTP_MAU_KEY6(x).U)

/*! @brief Format value for bitfield OCOTP_MAU_KEY6_BITS. */
#define BF_OCOTP_MAU_KEY6_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MAU_KEY6_BITS) & BM_OCOTP_MAU_KEY6_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MAU_KEY6_BITS(x, v) (HW_OCOTP_MAU_KEY6_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_MAU_KEY7 - Shadow Register for OTP Bank11 Word3 (MAU Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_MAU_KEY7 - Shadow Register for OTP Bank11 Word3 (MAU Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_mau_key7
{
    uint32_t U;
    struct _hw_ocotp_mau_key7_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_mau_key7_t;

/*!
 * @name Constants and macros for entire OCOTP_MAU_KEY7 register
 */
/*@{*/
#define HW_OCOTP_MAU_KEY7_ADDR(x) ((uintptr_t)(x) + 0x6F0U)

#define HW_OCOTP_MAU_KEY7(x)     (*(__IO hw_ocotp_mau_key7_t *) HW_OCOTP_MAU_KEY7_ADDR(x))
#define HW_OCOTP_MAU_KEY7_RD(x)  (HW_OCOTP_MAU_KEY7(x).U)
#define HW_OCOTP_MAU_KEY7_WR(x, v) (HW_OCOTP_MAU_KEY7(x).U = (v))
#define HW_OCOTP_MAU_KEY7_SET(x, v) (HW_OCOTP_MAU_KEY7_WR(x, HW_OCOTP_MAU_KEY7_RD(x) |  (v)))
#define HW_OCOTP_MAU_KEY7_CLR(x, v) (HW_OCOTP_MAU_KEY7_WR(x, HW_OCOTP_MAU_KEY7_RD(x) & ~(v)))
#define HW_OCOTP_MAU_KEY7_TOG(x, v) (HW_OCOTP_MAU_KEY7_WR(x, HW_OCOTP_MAU_KEY7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_MAU_KEY7 bitfields
 */

/*!
 * @name Register OCOTP_MAU_KEY7, field BITS[31:0] (RW)
 *
 * Shadow register for the MAU Key word7 (Copy of OTP Bank 11, word 3). These
 * bits cannot be read and written after the HW_OCOTP_LOCK_MAU_KEY bit is set. If
 * read, returns 0xBADA_BADA and sets HW_OCOTP_CTRL[ERROR].
 */
/*@{*/
#define BP_OCOTP_MAU_KEY7_BITS (0U)        /*!< Bit position for OCOTP_MAU_KEY7_BITS. */
#define BM_OCOTP_MAU_KEY7_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_MAU_KEY7_BITS. */
#define BS_OCOTP_MAU_KEY7_BITS (32U)       /*!< Bit field size in bits for OCOTP_MAU_KEY7_BITS. */

/*! @brief Read current value of the OCOTP_MAU_KEY7_BITS field. */
#define BR_OCOTP_MAU_KEY7_BITS(x) (HW_OCOTP_MAU_KEY7(x).U)

/*! @brief Format value for bitfield OCOTP_MAU_KEY7_BITS. */
#define BF_OCOTP_MAU_KEY7_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_MAU_KEY7_BITS) & BM_OCOTP_MAU_KEY7_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_MAU_KEY7_BITS(x, v) (HW_OCOTP_MAU_KEY7_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_GP10 - Value of OTP Bank14 Word0
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_GP10 - Value of OTP Bank14 Word0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_gp10
{
    uint32_t U;
    struct _hw_ocotp_gp10_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_gp10_t;

/*!
 * @name Constants and macros for entire OCOTP_GP10 register
 */
/*@{*/
#define HW_OCOTP_GP10_ADDR(x)    ((uintptr_t)(x) + 0x780U)

#define HW_OCOTP_GP10(x)         (*(__IO hw_ocotp_gp10_t *) HW_OCOTP_GP10_ADDR(x))
#define HW_OCOTP_GP10_RD(x)      (HW_OCOTP_GP10(x).U)
#define HW_OCOTP_GP10_WR(x, v)   (HW_OCOTP_GP10(x).U = (v))
#define HW_OCOTP_GP10_SET(x, v)  (HW_OCOTP_GP10_WR(x, HW_OCOTP_GP10_RD(x) |  (v)))
#define HW_OCOTP_GP10_CLR(x, v)  (HW_OCOTP_GP10_WR(x, HW_OCOTP_GP10_RD(x) & ~(v)))
#define HW_OCOTP_GP10_TOG(x, v)  (HW_OCOTP_GP10_WR(x, HW_OCOTP_GP10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_GP10 bitfields
 */

/*!
 * @name Register OCOTP_GP10, field BITS[31:0] (RW)
 *
 * It reflects the value of OTP Bank 14, word 0.
 */
/*@{*/
#define BP_OCOTP_GP10_BITS   (0U)          /*!< Bit position for OCOTP_GP10_BITS. */
#define BM_OCOTP_GP10_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_GP10_BITS. */
#define BS_OCOTP_GP10_BITS   (32U)         /*!< Bit field size in bits for OCOTP_GP10_BITS. */

/*! @brief Read current value of the OCOTP_GP10_BITS field. */
#define BR_OCOTP_GP10_BITS(x) (HW_OCOTP_GP10(x).U)

/*! @brief Format value for bitfield OCOTP_GP10_BITS. */
#define BF_OCOTP_GP10_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_GP10_BITS) & BM_OCOTP_GP10_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_GP10_BITS(x, v) (HW_OCOTP_GP10_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_GP11 - Value of OTP Bank14 Word1
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_GP11 - Value of OTP Bank14 Word1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_gp11
{
    uint32_t U;
    struct _hw_ocotp_gp11_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_gp11_t;

/*!
 * @name Constants and macros for entire OCOTP_GP11 register
 */
/*@{*/
#define HW_OCOTP_GP11_ADDR(x)    ((uintptr_t)(x) + 0x790U)

#define HW_OCOTP_GP11(x)         (*(__IO hw_ocotp_gp11_t *) HW_OCOTP_GP11_ADDR(x))
#define HW_OCOTP_GP11_RD(x)      (HW_OCOTP_GP11(x).U)
#define HW_OCOTP_GP11_WR(x, v)   (HW_OCOTP_GP11(x).U = (v))
#define HW_OCOTP_GP11_SET(x, v)  (HW_OCOTP_GP11_WR(x, HW_OCOTP_GP11_RD(x) |  (v)))
#define HW_OCOTP_GP11_CLR(x, v)  (HW_OCOTP_GP11_WR(x, HW_OCOTP_GP11_RD(x) & ~(v)))
#define HW_OCOTP_GP11_TOG(x, v)  (HW_OCOTP_GP11_WR(x, HW_OCOTP_GP11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_GP11 bitfields
 */

/*!
 * @name Register OCOTP_GP11, field BITS[31:0] (RW)
 *
 * It reflects the value of OTP Bank 14, word 1.
 */
/*@{*/
#define BP_OCOTP_GP11_BITS   (0U)          /*!< Bit position for OCOTP_GP11_BITS. */
#define BM_OCOTP_GP11_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_GP11_BITS. */
#define BS_OCOTP_GP11_BITS   (32U)         /*!< Bit field size in bits for OCOTP_GP11_BITS. */

/*! @brief Read current value of the OCOTP_GP11_BITS field. */
#define BR_OCOTP_GP11_BITS(x) (HW_OCOTP_GP11(x).U)

/*! @brief Format value for bitfield OCOTP_GP11_BITS. */
#define BF_OCOTP_GP11_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_GP11_BITS) & BM_OCOTP_GP11_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_GP11_BITS(x, v) (HW_OCOTP_GP11_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_GP20 - Value of OTP Bank14 Word2
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_GP20 - Value of OTP Bank14 Word2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_gp20
{
    uint32_t U;
    struct _hw_ocotp_gp20_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_gp20_t;

/*!
 * @name Constants and macros for entire OCOTP_GP20 register
 */
/*@{*/
#define HW_OCOTP_GP20_ADDR(x)    ((uintptr_t)(x) + 0x7A0U)

#define HW_OCOTP_GP20(x)         (*(__IO hw_ocotp_gp20_t *) HW_OCOTP_GP20_ADDR(x))
#define HW_OCOTP_GP20_RD(x)      (HW_OCOTP_GP20(x).U)
#define HW_OCOTP_GP20_WR(x, v)   (HW_OCOTP_GP20(x).U = (v))
#define HW_OCOTP_GP20_SET(x, v)  (HW_OCOTP_GP20_WR(x, HW_OCOTP_GP20_RD(x) |  (v)))
#define HW_OCOTP_GP20_CLR(x, v)  (HW_OCOTP_GP20_WR(x, HW_OCOTP_GP20_RD(x) & ~(v)))
#define HW_OCOTP_GP20_TOG(x, v)  (HW_OCOTP_GP20_WR(x, HW_OCOTP_GP20_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_GP20 bitfields
 */

/*!
 * @name Register OCOTP_GP20, field BITS[31:0] (RW)
 *
 * It reflects the value of OTP Bank 14, word 2.
 */
/*@{*/
#define BP_OCOTP_GP20_BITS   (0U)          /*!< Bit position for OCOTP_GP20_BITS. */
#define BM_OCOTP_GP20_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_GP20_BITS. */
#define BS_OCOTP_GP20_BITS   (32U)         /*!< Bit field size in bits for OCOTP_GP20_BITS. */

/*! @brief Read current value of the OCOTP_GP20_BITS field. */
#define BR_OCOTP_GP20_BITS(x) (HW_OCOTP_GP20(x).U)

/*! @brief Format value for bitfield OCOTP_GP20_BITS. */
#define BF_OCOTP_GP20_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_GP20_BITS) & BM_OCOTP_GP20_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_GP20_BITS(x, v) (HW_OCOTP_GP20_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_GP21 - Value of OTP Bank14 Word3
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_GP21 - Value of OTP Bank14 Word3 (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_gp21
{
    uint32_t U;
    struct _hw_ocotp_gp21_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_gp21_t;

/*!
 * @name Constants and macros for entire OCOTP_GP21 register
 */
/*@{*/
#define HW_OCOTP_GP21_ADDR(x)    ((uintptr_t)(x) + 0x7B0U)

#define HW_OCOTP_GP21(x)         (*(__IO hw_ocotp_gp21_t *) HW_OCOTP_GP21_ADDR(x))
#define HW_OCOTP_GP21_RD(x)      (HW_OCOTP_GP21(x).U)
#define HW_OCOTP_GP21_WR(x, v)   (HW_OCOTP_GP21(x).U = (v))
#define HW_OCOTP_GP21_SET(x, v)  (HW_OCOTP_GP21_WR(x, HW_OCOTP_GP21_RD(x) |  (v)))
#define HW_OCOTP_GP21_CLR(x, v)  (HW_OCOTP_GP21_WR(x, HW_OCOTP_GP21_RD(x) & ~(v)))
#define HW_OCOTP_GP21_TOG(x, v)  (HW_OCOTP_GP21_WR(x, HW_OCOTP_GP21_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_GP21 bitfields
 */

/*!
 * @name Register OCOTP_GP21, field BITS[31:0] (RW)
 *
 * It reflects the value of OTP Bank 14, word 3.
 */
/*@{*/
#define BP_OCOTP_GP21_BITS   (0U)          /*!< Bit position for OCOTP_GP21_BITS. */
#define BM_OCOTP_GP21_BITS   (0xFFFFFFFFU) /*!< Bit mask for OCOTP_GP21_BITS. */
#define BS_OCOTP_GP21_BITS   (32U)         /*!< Bit field size in bits for OCOTP_GP21_BITS. */

/*! @brief Read current value of the OCOTP_GP21_BITS field. */
#define BR_OCOTP_GP21_BITS(x) (HW_OCOTP_GP21(x).U)

/*! @brief Format value for bitfield OCOTP_GP21_BITS. */
#define BF_OCOTP_GP21_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_GP21_BITS) & BM_OCOTP_GP21_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_GP21_BITS(x, v) (HW_OCOTP_GP21_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_CRC_GP10 - Value of OTP Bank15 Word0 (CRC Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_CRC_GP10 - Value of OTP Bank15 Word0 (CRC Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_crc_gp10
{
    uint32_t U;
    struct _hw_ocotp_crc_gp10_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_crc_gp10_t;

/*!
 * @name Constants and macros for entire OCOTP_CRC_GP10 register
 */
/*@{*/
#define HW_OCOTP_CRC_GP10_ADDR(x) ((uintptr_t)(x) + 0x7C0U)

#define HW_OCOTP_CRC_GP10(x)     (*(__IO hw_ocotp_crc_gp10_t *) HW_OCOTP_CRC_GP10_ADDR(x))
#define HW_OCOTP_CRC_GP10_RD(x)  (HW_OCOTP_CRC_GP10(x).U)
#define HW_OCOTP_CRC_GP10_WR(x, v) (HW_OCOTP_CRC_GP10(x).U = (v))
#define HW_OCOTP_CRC_GP10_SET(x, v) (HW_OCOTP_CRC_GP10_WR(x, HW_OCOTP_CRC_GP10_RD(x) |  (v)))
#define HW_OCOTP_CRC_GP10_CLR(x, v) (HW_OCOTP_CRC_GP10_WR(x, HW_OCOTP_CRC_GP10_RD(x) & ~(v)))
#define HW_OCOTP_CRC_GP10_TOG(x, v) (HW_OCOTP_CRC_GP10_WR(x, HW_OCOTP_CRC_GP10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_CRC_GP10 bitfields
 */

/*!
 * @name Register OCOTP_CRC_GP10, field BITS[31:0] (RW)
 *
 * It reflects the value of OTP Bank 15, word 0.
 */
/*@{*/
#define BP_OCOTP_CRC_GP10_BITS (0U)        /*!< Bit position for OCOTP_CRC_GP10_BITS. */
#define BM_OCOTP_CRC_GP10_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_CRC_GP10_BITS. */
#define BS_OCOTP_CRC_GP10_BITS (32U)       /*!< Bit field size in bits for OCOTP_CRC_GP10_BITS. */

/*! @brief Read current value of the OCOTP_CRC_GP10_BITS field. */
#define BR_OCOTP_CRC_GP10_BITS(x) (HW_OCOTP_CRC_GP10(x).U)

/*! @brief Format value for bitfield OCOTP_CRC_GP10_BITS. */
#define BF_OCOTP_CRC_GP10_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CRC_GP10_BITS) & BM_OCOTP_CRC_GP10_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_CRC_GP10_BITS(x, v) (HW_OCOTP_CRC_GP10_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_CRC_GP11 - Value of OTP Bank15 Word1 (CRC Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_CRC_GP11 - Value of OTP Bank15 Word1 (CRC Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_crc_gp11
{
    uint32_t U;
    struct _hw_ocotp_crc_gp11_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_crc_gp11_t;

/*!
 * @name Constants and macros for entire OCOTP_CRC_GP11 register
 */
/*@{*/
#define HW_OCOTP_CRC_GP11_ADDR(x) ((uintptr_t)(x) + 0x7D0U)

#define HW_OCOTP_CRC_GP11(x)     (*(__IO hw_ocotp_crc_gp11_t *) HW_OCOTP_CRC_GP11_ADDR(x))
#define HW_OCOTP_CRC_GP11_RD(x)  (HW_OCOTP_CRC_GP11(x).U)
#define HW_OCOTP_CRC_GP11_WR(x, v) (HW_OCOTP_CRC_GP11(x).U = (v))
#define HW_OCOTP_CRC_GP11_SET(x, v) (HW_OCOTP_CRC_GP11_WR(x, HW_OCOTP_CRC_GP11_RD(x) |  (v)))
#define HW_OCOTP_CRC_GP11_CLR(x, v) (HW_OCOTP_CRC_GP11_WR(x, HW_OCOTP_CRC_GP11_RD(x) & ~(v)))
#define HW_OCOTP_CRC_GP11_TOG(x, v) (HW_OCOTP_CRC_GP11_WR(x, HW_OCOTP_CRC_GP11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_CRC_GP11 bitfields
 */

/*!
 * @name Register OCOTP_CRC_GP11, field BITS[31:0] (RW)
 *
 * It reflects the value of OTP Bank 15, word 1.
 */
/*@{*/
#define BP_OCOTP_CRC_GP11_BITS (0U)        /*!< Bit position for OCOTP_CRC_GP11_BITS. */
#define BM_OCOTP_CRC_GP11_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_CRC_GP11_BITS. */
#define BS_OCOTP_CRC_GP11_BITS (32U)       /*!< Bit field size in bits for OCOTP_CRC_GP11_BITS. */

/*! @brief Read current value of the OCOTP_CRC_GP11_BITS field. */
#define BR_OCOTP_CRC_GP11_BITS(x) (HW_OCOTP_CRC_GP11(x).U)

/*! @brief Format value for bitfield OCOTP_CRC_GP11_BITS. */
#define BF_OCOTP_CRC_GP11_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CRC_GP11_BITS) & BM_OCOTP_CRC_GP11_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_CRC_GP11_BITS(x, v) (HW_OCOTP_CRC_GP11_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_CRC_GP20 - Value of OTP Bank15 Word2 (CRC Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_CRC_GP20 - Value of OTP Bank15 Word2 (CRC Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_crc_gp20
{
    uint32_t U;
    struct _hw_ocotp_crc_gp20_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_crc_gp20_t;

/*!
 * @name Constants and macros for entire OCOTP_CRC_GP20 register
 */
/*@{*/
#define HW_OCOTP_CRC_GP20_ADDR(x) ((uintptr_t)(x) + 0x7E0U)

#define HW_OCOTP_CRC_GP20(x)     (*(__IO hw_ocotp_crc_gp20_t *) HW_OCOTP_CRC_GP20_ADDR(x))
#define HW_OCOTP_CRC_GP20_RD(x)  (HW_OCOTP_CRC_GP20(x).U)
#define HW_OCOTP_CRC_GP20_WR(x, v) (HW_OCOTP_CRC_GP20(x).U = (v))
#define HW_OCOTP_CRC_GP20_SET(x, v) (HW_OCOTP_CRC_GP20_WR(x, HW_OCOTP_CRC_GP20_RD(x) |  (v)))
#define HW_OCOTP_CRC_GP20_CLR(x, v) (HW_OCOTP_CRC_GP20_WR(x, HW_OCOTP_CRC_GP20_RD(x) & ~(v)))
#define HW_OCOTP_CRC_GP20_TOG(x, v) (HW_OCOTP_CRC_GP20_WR(x, HW_OCOTP_CRC_GP20_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_CRC_GP20 bitfields
 */

/*!
 * @name Register OCOTP_CRC_GP20, field BITS[31:0] (RW)
 *
 * It reflects the value of OTP Bank 15, word 2.
 */
/*@{*/
#define BP_OCOTP_CRC_GP20_BITS (0U)        /*!< Bit position for OCOTP_CRC_GP20_BITS. */
#define BM_OCOTP_CRC_GP20_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_CRC_GP20_BITS. */
#define BS_OCOTP_CRC_GP20_BITS (32U)       /*!< Bit field size in bits for OCOTP_CRC_GP20_BITS. */

/*! @brief Read current value of the OCOTP_CRC_GP20_BITS field. */
#define BR_OCOTP_CRC_GP20_BITS(x) (HW_OCOTP_CRC_GP20(x).U)

/*! @brief Format value for bitfield OCOTP_CRC_GP20_BITS. */
#define BF_OCOTP_CRC_GP20_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CRC_GP20_BITS) & BM_OCOTP_CRC_GP20_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_CRC_GP20_BITS(x, v) (HW_OCOTP_CRC_GP20_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OCOTP_CRC_GP21 - Value of OTP Bank15 Word3 (CRC Key)
 ******************************************************************************/

/*!
 * @brief HW_OCOTP_CRC_GP21 - Value of OTP Bank15 Word3 (CRC Key) (RW)
 *
 * Reset value: 0x00000000U
 *
 * After reset, it automatically copied from the OTP. It can be re-loaded by
 * setting HW_OCOTP_CTRL[RELOAD_SHADOWS]. EXAMPLE Empty Example.
 */
typedef union _hw_ocotp_crc_gp21
{
    uint32_t U;
    struct _hw_ocotp_crc_gp21_bitfields
    {
        uint32_t BITS : 32;            /*!< [31:0]  */
    } B;
} hw_ocotp_crc_gp21_t;

/*!
 * @name Constants and macros for entire OCOTP_CRC_GP21 register
 */
/*@{*/
#define HW_OCOTP_CRC_GP21_ADDR(x) ((uintptr_t)(x) + 0x7F0U)

#define HW_OCOTP_CRC_GP21(x)     (*(__IO hw_ocotp_crc_gp21_t *) HW_OCOTP_CRC_GP21_ADDR(x))
#define HW_OCOTP_CRC_GP21_RD(x)  (HW_OCOTP_CRC_GP21(x).U)
#define HW_OCOTP_CRC_GP21_WR(x, v) (HW_OCOTP_CRC_GP21(x).U = (v))
#define HW_OCOTP_CRC_GP21_SET(x, v) (HW_OCOTP_CRC_GP21_WR(x, HW_OCOTP_CRC_GP21_RD(x) |  (v)))
#define HW_OCOTP_CRC_GP21_CLR(x, v) (HW_OCOTP_CRC_GP21_WR(x, HW_OCOTP_CRC_GP21_RD(x) & ~(v)))
#define HW_OCOTP_CRC_GP21_TOG(x, v) (HW_OCOTP_CRC_GP21_WR(x, HW_OCOTP_CRC_GP21_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OCOTP_CRC_GP21 bitfields
 */

/*!
 * @name Register OCOTP_CRC_GP21, field BITS[31:0] (RW)
 *
 * It reflects the value of OTP Bank 15, word 3.
 */
/*@{*/
#define BP_OCOTP_CRC_GP21_BITS (0U)        /*!< Bit position for OCOTP_CRC_GP21_BITS. */
#define BM_OCOTP_CRC_GP21_BITS (0xFFFFFFFFU) /*!< Bit mask for OCOTP_CRC_GP21_BITS. */
#define BS_OCOTP_CRC_GP21_BITS (32U)       /*!< Bit field size in bits for OCOTP_CRC_GP21_BITS. */

/*! @brief Read current value of the OCOTP_CRC_GP21_BITS field. */
#define BR_OCOTP_CRC_GP21_BITS(x) (HW_OCOTP_CRC_GP21(x).U)

/*! @brief Format value for bitfield OCOTP_CRC_GP21_BITS. */
#define BF_OCOTP_CRC_GP21_BITS(v) ((uint32_t)((uint32_t)(v) << BP_OCOTP_CRC_GP21_BITS) & BM_OCOTP_CRC_GP21_BITS)

/*! @brief Set the BITS field to a new value. */
#define BW_OCOTP_CRC_GP21_BITS(x, v) (HW_OCOTP_CRC_GP21_WR(x, v))
/*@}*/

/*******************************************************************************
 * hw_ocotp_t - module struct
 ******************************************************************************/
/*!
 * @brief All OCOTP module registers.
 */
#pragma pack(1)
typedef struct _hw_ocotp
{
    __IO hw_ocotp_ctrl_t CTRL;             /*!< [0x0] OTP Controller Control Register */
    uint8_t _reserved0[12];
    __IO hw_ocotp_timing_t TIMING;         /*!< [0x10] OTP Controller Timing Register */
    uint8_t _reserved1[12];
    __IO hw_ocotp_data0_t DATA0;           /*!< [0x20] OTP Controller Write Data Register */
    uint8_t _reserved2[12];
    __IO hw_ocotp_data1_t DATA1;           /*!< [0x30] OTP Controller Write Data Register */
    uint8_t _reserved3[12];
    __IO hw_ocotp_data2_t DATA2;           /*!< [0x40] OTP Controller Write Data Register */
    uint8_t _reserved4[12];
    __IO hw_ocotp_data3_t DATA3;           /*!< [0x50] OTP Controller Write Data Register */
    uint8_t _reserved5[12];
    __IO hw_ocotp_read_ctrl_t READ_CTRL;   /*!< [0x60] OTP Controller Write Data Register */
    uint8_t _reserved6[12];
    __IO hw_ocotp_read_fuse_data0_t READ_FUSE_DATA0; /*!< [0x70] OTP Controller Read Data Register */
    uint8_t _reserved7[12];
    __IO hw_ocotp_read_fuse_data1_t READ_FUSE_DATA1; /*!< [0x80] OTP Controller Read Data Register */
    uint8_t _reserved8[12];
    __IO hw_ocotp_read_fuse_data2_t READ_FUSE_DATA2; /*!< [0x90] OTP Controller Read Data Register */
    uint8_t _reserved9[12];
    __IO hw_ocotp_read_fuse_data3_t READ_FUSE_DATA3; /*!< [0xA0] OTP Controller Read Data Register */
    uint8_t _reserved10[12];
    __IO hw_ocotp_sw_sticky_t SW_STICKY;   /*!< [0xB0] Sticky bit Register */
    uint8_t _reserved11[12];
    __IO hw_ocotp_scs_t SCS;               /*!< [0xC0] Software Controllable Signals Register */
    uint8_t _reserved12[12];
    __IO hw_ocotp_crc_addr_t CRC_ADDR;     /*!< [0xD0] OTP Controller CRC test address */
    uint8_t _reserved13[12];
    __IO hw_ocotp_crc_value_t CRC_VALUE;   /*!< [0xE0] OTP Controller CRC Value Register */
    uint8_t _reserved14[12];
    __I hw_ocotp_version_t VERSION;        /*!< [0xF0] OTP Controller Version Register */
    uint8_t _reserved15[780];
    __I hw_ocotp_lock_t LOCK;              /*!< [0x400] Value of OTP Bank0 Word0 (Lock controls) */
    uint8_t _reserved16[12];
    __IO hw_ocotp_tester0_t TESTER0;       /*!< [0x410] Value of OTP Bank0 Word1 (Tester Information) */
    uint8_t _reserved17[12];
    __IO hw_ocotp_tester1_t TESTER1;       /*!< [0x420] Value of OTP Bank0 Word2 (Tester Information) */
    uint8_t _reserved18[12];
    __IO hw_ocotp_tester2_t TESTER2;       /*!< [0x430] Value of OTP Bank0 Word3 (Tester Information) */
    uint8_t _reserved19[12];
    __IO hw_ocotp_tester3_t TESTER3;       /*!< [0x440] Value of OTP Bank1 Word0 (Tester Information) */
    uint8_t _reserved20[12];
    __IO hw_ocotp_tester4_t TESTER4;       /*!< [0x450] Value of OTP Bank1 Word1 (Tester Information) */
    uint8_t _reserved21[12];
    __IO hw_ocotp_tester5_t TESTER5;       /*!< [0x460] Value of OTP Bank1 Word2 (Tester Information) */
    uint8_t _reserved22[12];
    __IO hw_ocotp_boot_cfg0_t BOOT_CFG0;   /*!< [0x470] Value of OTP Bank1 Word3 (Boot Configuration Information) */
    uint8_t _reserved23[12];
    __IO hw_ocotp_boot_cfg1_t BOOT_CFG1;   /*!< [0x480] Value of OTP Bank2 Word0 (Boot Configuration Information) */
    uint8_t _reserved24[12];
    __IO hw_ocotp_boot_cfg2_t BOOT_CFG2;   /*!< [0x490] Value of OTP Bank2 Word1 (Boot Configuration Information) */
    uint8_t _reserved25[12];
    __IO hw_ocotp_boot_cfg3_t BOOT_CFG3;   /*!< [0x4A0] Value of OTP Bank2 Word2 (Boot Configuration Information) */
    uint8_t _reserved26[12];
    __IO hw_ocotp_boot_cfg4_t BOOT_CFG4;   /*!< [0x4B0] Value of OTP Bank2 Word3 (BOOT Configuration Information) */
    uint8_t _reserved27[12];
    __IO hw_ocotp_mem_trim0_t MEM_TRIM0;   /*!< [0x4C0] Value of OTP Bank3 Word0 (Memory Related Information) */
    uint8_t _reserved28[12];
    __IO hw_ocotp_mem_trim1_t MEM_TRIM1;   /*!< [0x4D0] Value of OTP Bank3 Word1 (Memory Related Information) */
    uint8_t _reserved29[12];
    __IO hw_ocotp_ana0_t ANA0;             /*!< [0x4E0] Value of OTP Bank3 Word2 (Analog Information) */
    uint8_t _reserved30[12];
    __IO hw_ocotp_ana1_t ANA1;             /*!< [0x4F0] Value of OTP Bank3 Word3 (Analog Info.) */
    uint8_t _reserved31[12];
    __IO hw_ocotp_otpmk0_t OTPMK0;         /*!< [0x500] Shadow Register for OTP Bank4 Word0 (OTPMK Key) */
    uint8_t _reserved32[12];
    __IO hw_ocotp_otpmk1_t OTPMK1;         /*!< [0x510] Shadow Register for OTP Bank4 Word1 (OTPMK Key) */
    uint8_t _reserved33[12];
    __IO hw_ocotp_otpmk2_t OTPMK2;         /*!< [0x520] Shadow Register for OTP Bank4 Word2 (OTPMK Key) */
    uint8_t _reserved34[12];
    __IO hw_ocotp_otpmk3_t OTPMK3;         /*!< [0x530] Shadow Register for OTP Bank4 Word3 (OTPMK Key) */
    uint8_t _reserved35[12];
    __IO hw_ocotp_otpmk4_t OTPMK4;         /*!< [0x540] Shadow Register for OTP Bank5 Word0 (OTPMK Key) */
    uint8_t _reserved36[12];
    __IO hw_ocotp_otpmk5_t OTPMK5;         /*!< [0x550] Shadow Register for OTP Bank5 Word1 (OTPMK Key) */
    uint8_t _reserved37[12];
    __IO hw_ocotp_otpmk6_t OTPMK6;         /*!< [0x560] Shadow Register for OTP Bank5 Word2 (OTPMK Key) */
    uint8_t _reserved38[12];
    __IO hw_ocotp_otpmk7_t OTPMK7;         /*!< [0x570] Shadow Register for OTP Bank5 Word3 (OTPMK Key) */
    uint8_t _reserved39[12];
    __IO hw_ocotp_srk0_t SRK0;             /*!< [0x580] Shadow Register for OTP Bank6 Word0 (SRK Hash) */
    uint8_t _reserved40[12];
    __IO hw_ocotp_srk1_t SRK1;             /*!< [0x590] Shadow Register for OTP Bank6 Word1 (SRK Hash) */
    uint8_t _reserved41[12];
    __IO hw_ocotp_srk2_t SRK2;             /*!< [0x5A0] Shadow Register for OTP Bank6 Word2 (SRK Hash) */
    uint8_t _reserved42[12];
    __IO hw_ocotp_srk3_t SRK3;             /*!< [0x5B0] Shadow Register for OTP Bank6 Word3 (SRK Hash) */
    uint8_t _reserved43[12];
    __IO hw_ocotp_srk4_t SRK4;             /*!< [0x5C0] Shadow Register for OTP Bank7 Word0 (SRK Hash) */
    uint8_t _reserved44[12];
    __IO hw_ocotp_srk5_t SRK5;             /*!< [0x5D0] Shadow Register for OTP Bank7 Word1 (SRK Hash) */
    uint8_t _reserved45[12];
    __IO hw_ocotp_srk6_t SRK6;             /*!< [0x5E0] Shadow Register for OTP Bank7 Word2 (SRK Hash) */
    uint8_t _reserved46[12];
    __IO hw_ocotp_srk7_t SRK7;             /*!< [0x5F0] Shadow Register for OTP Bank7 Word3 (SRK Hash) */
    uint8_t _reserved47[12];
    __IO hw_ocotp_sjc_resp0_t SJC_RESP0;   /*!< [0x600] Value of OTP Bank8 Word0 (Secure JTAG Response Field) */
    uint8_t _reserved48[12];
    __IO hw_ocotp_sjc_resp1_t SJC_RESP1;   /*!< [0x610] Value of OTP Bank8 Word1 (Secure JTAG Response Field) */
    uint8_t _reserved49[12];
    __IO hw_ocotp_usb_id_t USB_ID;         /*!< [0x620] Value of OTP Bank8 Word2 (USB ID info) */
    uint8_t _reserved50[12];
    __IO hw_ocotp_field_return_t FIELD_RETURN; /*!< [0x630] Value of OTP Bank8 Word3 (Field Return) */
    uint8_t _reserved51[12];
    __IO hw_ocotp_mac_addr0_t MAC_ADDR0;   /*!< [0x640] Value of OTP Bank9 Word0 (MAC Address) */
    uint8_t _reserved52[12];
    __IO hw_ocotp_mac_addr1_t MAC_ADDR1;   /*!< [0x650] Value of OTP Bank9 Word1 (MAC Address) */
    uint8_t _reserved53[12];
    __IO hw_ocotp_mac_addr2_t MAC_ADDR2;   /*!< [0x660] Value of OTP Bank9 Word2 (MAC Address) */
    uint8_t _reserved54[12];
    __IO hw_ocotp_srk_revoke_t SRK_REVOKE; /*!< [0x670] Value of OTP Bank9 Word3 (SRK Revoke) */
    uint8_t _reserved55[12];
    __IO hw_ocotp_mau_key0_t MAU_KEY0;     /*!< [0x680] Shadow Register for OTP Bank10 Word0 (MAU Key) */
    uint8_t _reserved56[12];
    __IO hw_ocotp_mau_key1_t MAU_KEY1;     /*!< [0x690] Shadow Register for OTP Bank10 Word1 (MAU Key) */
    uint8_t _reserved57[12];
    __IO hw_ocotp_mau_key2_t MAU_KEY2;     /*!< [0x6A0] Shadow Register for OTP Bank10 Word2 (MAU Key) */
    uint8_t _reserved58[12];
    __IO hw_ocotp_mau_key3_t MAU_KEY3;     /*!< [0x6B0] Shadow Register for OTP Bank10 Word3 (MAU Key) */
    uint8_t _reserved59[12];
    __IO hw_ocotp_mau_key4_t MAU_KEY4;     /*!< [0x6C0] Shadow Register for OTP Bank11 Word0 (MAU Key) */
    uint8_t _reserved60[12];
    __IO hw_ocotp_mau_key5_t MAU_KEY5;     /*!< [0x6D0] Shadow Register for OTP Bank11 Word1 (MAU Key) */
    uint8_t _reserved61[12];
    __IO hw_ocotp_mau_key6_t MAU_KEY6;     /*!< [0x6E0] Shadow Register for OTP Bank11 Word2 (MAU Key) */
    uint8_t _reserved62[12];
    __IO hw_ocotp_mau_key7_t MAU_KEY7;     /*!< [0x6F0] Shadow Register for OTP Bank11 Word3 (MAU Key) */
    uint8_t _reserved63[140];
    __IO hw_ocotp_gp10_t GP10;             /*!< [0x780] Value of OTP Bank14 Word0 */
    uint8_t _reserved64[12];
    __IO hw_ocotp_gp11_t GP11;             /*!< [0x790] Value of OTP Bank14 Word1 */
    uint8_t _reserved65[12];
    __IO hw_ocotp_gp20_t GP20;             /*!< [0x7A0] Value of OTP Bank14 Word2 */
    uint8_t _reserved66[12];
    __IO hw_ocotp_gp21_t GP21;             /*!< [0x7B0] Value of OTP Bank14 Word3 */
    uint8_t _reserved67[12];
    __IO hw_ocotp_crc_gp10_t CRC_GP10;     /*!< [0x7C0] Value of OTP Bank15 Word0 (CRC Key) */
    uint8_t _reserved68[12];
    __IO hw_ocotp_crc_gp11_t CRC_GP11;     /*!< [0x7D0] Value of OTP Bank15 Word1 (CRC Key) */
    uint8_t _reserved69[12];
    __IO hw_ocotp_crc_gp20_t CRC_GP20;     /*!< [0x7E0] Value of OTP Bank15 Word2 (CRC Key) */
    uint8_t _reserved70[12];
    __IO hw_ocotp_crc_gp21_t CRC_GP21;     /*!< [0x7F0] Value of OTP Bank15 Word3 (CRC Key) */
} hw_ocotp_t;
#pragma pack()

/*! @brief Macro to access all OCOTP registers. */
/*! @param x OCOTP module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_OCOTP_REGS(OCOTP_BASE)</code>. */
#define HW_OCOTP_REGS(x) (*(hw_ocotp_t *)(x))

/*
 * iMX7D PCIE_PHY_CMN
 *
 * PCIe PHY CMN Registers
 *
 * Registers defined in this header file:
 * - HW_PCIE_PHY_CMN_REG01 - Impedance Calibration Register
 * - HW_PCIE_PHY_CMN_REG02 -
 * - HW_PCIE_PHY_CMN_REG03 -
 * - HW_PCIE_PHY_CMN_REG04 -
 * - HW_PCIE_PHY_CMN_REG05 -
 * - HW_PCIE_PHY_CMN_REG06 -
 * - HW_PCIE_PHY_CMN_REG07 -
 * - HW_PCIE_PHY_CMN_REG0B -
 * - HW_PCIE_PHY_CMN_REG08 -
 * - HW_PCIE_PHY_CMN_REG09 -
 * - HW_PCIE_PHY_CMN_REG11 -
 * - HW_PCIE_PHY_CMN_REG15 -
 * - HW_PCIE_PHY_CMN_REG16 -
 * - HW_PCIE_PHY_CMN_REG17 -
 * - HW_PCIE_PHY_CMN_REG18 -
 * - HW_PCIE_PHY_CMN_REG19 -
 * - HW_PCIE_PHY_CMN_REG1A -
 *
 * - hw_pcie_phy_cmn_t - Struct containing all module registers.
 */

#define HW_PCIE_PHY_CMN_INSTANCE_COUNT (1U) /*!< Number of instances of the PCIE_PHY_CMN module. */
#define HW_PCIE_PHY_CMN (0U) /*!< Instance number for PCIE_PHY_CMN. */
#define PCIE_PHY_CMN_BASE     (0x306D0000U) /*!< Base address for PCIE_PHY_CMN. */
/*! Array initializer of PCIE_PHY_CMN base addresses. */
#define PCIE_PHY_CMN_BASE_ADDRS { PCIE_PHY_CMN_BASE }

/*******************************************************************************
 * HW_PCIE_PHY_CMN_REG01 - Impedance Calibration Register
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_CMN_REG01 - Impedance Calibration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * When FORCE pin is set to "1", TX and RX impedance can be controlled by manual
 * code setting of TCODE[3:0] and RCODE[3:0] respectively. It is not recommend
 * using this feature in normal case and used for debug only.
 */
typedef union _hw_pcie_phy_cmn_reg01
{
    uint32_t U;
    struct _hw_pcie_phy_cmn_reg01_bitfields
    {
        uint32_t TCODE : 4;            /*!< [3:0] Manual TX Impedance Control */
        uint32_t RCODE : 4;            /*!< [7:4] Manual RX Impedance Control */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_cmn_reg01_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_CMN_REG01 register
 */
/*@{*/
#define HW_PCIE_PHY_CMN_REG01_ADDR(x) ((uintptr_t)(x) + 0x4U)

#define HW_PCIE_PHY_CMN_REG01(x) (*(__IO hw_pcie_phy_cmn_reg01_t *) HW_PCIE_PHY_CMN_REG01_ADDR(x))
#define HW_PCIE_PHY_CMN_REG01_RD(x) (HW_PCIE_PHY_CMN_REG01(x).U)
#define HW_PCIE_PHY_CMN_REG01_WR(x, v) (HW_PCIE_PHY_CMN_REG01(x).U = (v))
#define HW_PCIE_PHY_CMN_REG01_SET(x, v) (HW_PCIE_PHY_CMN_REG01_WR(x, HW_PCIE_PHY_CMN_REG01_RD(x) |  (v)))
#define HW_PCIE_PHY_CMN_REG01_CLR(x, v) (HW_PCIE_PHY_CMN_REG01_WR(x, HW_PCIE_PHY_CMN_REG01_RD(x) & ~(v)))
#define HW_PCIE_PHY_CMN_REG01_TOG(x, v) (HW_PCIE_PHY_CMN_REG01_WR(x, HW_PCIE_PHY_CMN_REG01_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_CMN_REG01 bitfields
 */

/*!
 * @name Register PCIE_PHY_CMN_REG01, field TCODE[3:0] (RW)
 *
 * Values:
 * - 0000 - Large
 * - 1111 - Small
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG01_TCODE (0U)   /*!< Bit position for PCIE_PHY_CMN_REG01_TCODE. */
#define BM_PCIE_PHY_CMN_REG01_TCODE (0x0000000FU) /*!< Bit mask for PCIE_PHY_CMN_REG01_TCODE. */
#define BS_PCIE_PHY_CMN_REG01_TCODE (4U)   /*!< Bit field size in bits for PCIE_PHY_CMN_REG01_TCODE. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG01_TCODE field. */
#define BR_PCIE_PHY_CMN_REG01_TCODE(x) (HW_PCIE_PHY_CMN_REG01(x).B.TCODE)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG01_TCODE. */
#define BF_PCIE_PHY_CMN_REG01_TCODE(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG01_TCODE) & BM_PCIE_PHY_CMN_REG01_TCODE)

/*! @brief Set the TCODE field to a new value. */
#define BW_PCIE_PHY_CMN_REG01_TCODE(x, v) (HW_PCIE_PHY_CMN_REG01_WR(x, (HW_PCIE_PHY_CMN_REG01_RD(x) & ~BM_PCIE_PHY_CMN_REG01_TCODE) | BF_PCIE_PHY_CMN_REG01_TCODE(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_CMN_REG01, field RCODE[7:4] (RW)
 *
 * Values:
 * - 0000 - Large
 * - 1111 - Small
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG01_RCODE (4U)   /*!< Bit position for PCIE_PHY_CMN_REG01_RCODE. */
#define BM_PCIE_PHY_CMN_REG01_RCODE (0x000000F0U) /*!< Bit mask for PCIE_PHY_CMN_REG01_RCODE. */
#define BS_PCIE_PHY_CMN_REG01_RCODE (4U)   /*!< Bit field size in bits for PCIE_PHY_CMN_REG01_RCODE. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG01_RCODE field. */
#define BR_PCIE_PHY_CMN_REG01_RCODE(x) (HW_PCIE_PHY_CMN_REG01(x).B.RCODE)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG01_RCODE. */
#define BF_PCIE_PHY_CMN_REG01_RCODE(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG01_RCODE) & BM_PCIE_PHY_CMN_REG01_RCODE)

/*! @brief Set the RCODE field to a new value. */
#define BW_PCIE_PHY_CMN_REG01_RCODE(x, v) (HW_PCIE_PHY_CMN_REG01_WR(x, (HW_PCIE_PHY_CMN_REG01_RD(x) & ~BM_PCIE_PHY_CMN_REG01_RCODE) | BF_PCIE_PHY_CMN_REG01_RCODE(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_CMN_REG02 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_CMN_REG02 -  (RW)
 *
 * Reset value: 0x00000014U
 */
typedef union _hw_pcie_phy_cmn_reg02
{
    uint32_t U;
    struct _hw_pcie_phy_cmn_reg02_bitfields
    {
        uint32_t FORCE : 1;            /*!< [0] Manual Impedance Control Enable */
        uint32_t RESERVED0 : 3;        /*!< [3:1]  */
        uint32_t PDIV : 4;             /*!< [7:4] PLL Pre-divider Ratio Control */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_cmn_reg02_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_CMN_REG02 register
 */
/*@{*/
#define HW_PCIE_PHY_CMN_REG02_ADDR(x) ((uintptr_t)(x) + 0x8U)

#define HW_PCIE_PHY_CMN_REG02(x) (*(__IO hw_pcie_phy_cmn_reg02_t *) HW_PCIE_PHY_CMN_REG02_ADDR(x))
#define HW_PCIE_PHY_CMN_REG02_RD(x) (HW_PCIE_PHY_CMN_REG02(x).U)
#define HW_PCIE_PHY_CMN_REG02_WR(x, v) (HW_PCIE_PHY_CMN_REG02(x).U = (v))
#define HW_PCIE_PHY_CMN_REG02_SET(x, v) (HW_PCIE_PHY_CMN_REG02_WR(x, HW_PCIE_PHY_CMN_REG02_RD(x) |  (v)))
#define HW_PCIE_PHY_CMN_REG02_CLR(x, v) (HW_PCIE_PHY_CMN_REG02_WR(x, HW_PCIE_PHY_CMN_REG02_RD(x) & ~(v)))
#define HW_PCIE_PHY_CMN_REG02_TOG(x, v) (HW_PCIE_PHY_CMN_REG02_WR(x, HW_PCIE_PHY_CMN_REG02_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_CMN_REG02 bitfields
 */

/*!
 * @name Register PCIE_PHY_CMN_REG02, field FORCE[0] (RW)
 *
 * When FORCE pin is set to '1', TX and RX impedance can be controlled by manual
 * code setting of TCODE[3:0] and RCODE[3:0] respectively. It is recommend using
 * this feature in normal case and used for debug only.
 *
 * Values:
 * - 0 - Auto Calibration (Default Value)
 * - 1 - Manual Impedance Control Enable
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG02_FORCE (0U)   /*!< Bit position for PCIE_PHY_CMN_REG02_FORCE. */
#define BM_PCIE_PHY_CMN_REG02_FORCE (0x00000001U) /*!< Bit mask for PCIE_PHY_CMN_REG02_FORCE. */
#define BS_PCIE_PHY_CMN_REG02_FORCE (1U)   /*!< Bit field size in bits for PCIE_PHY_CMN_REG02_FORCE. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG02_FORCE field. */
#define BR_PCIE_PHY_CMN_REG02_FORCE(x) (HW_PCIE_PHY_CMN_REG02(x).B.FORCE)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG02_FORCE. */
#define BF_PCIE_PHY_CMN_REG02_FORCE(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG02_FORCE) & BM_PCIE_PHY_CMN_REG02_FORCE)

/*! @brief Set the FORCE field to a new value. */
#define BW_PCIE_PHY_CMN_REG02_FORCE(x, v) (HW_PCIE_PHY_CMN_REG02_WR(x, (HW_PCIE_PHY_CMN_REG02_RD(x) & ~BM_PCIE_PHY_CMN_REG02_FORCE) | BF_PCIE_PHY_CMN_REG02_FORCE(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_CMN_REG02, field PDIV[7:4] (RW)
 *
 * Values:
 * - 0000 - GND
 * - 0001 - 1/1 (Default)
 * - 0010 - 1/2
 * - 0011 - 1/3
 * - 0100 - 1/4
 * - 0101 - 1/5
 * - 0110 - 1/6
 * - 0111 - 1/7
 * - 1000 - 1/8
 * - 1001 - 1/9
 * - 1010 - 1/10
 * - 1011 - 1/11
 * - 1111 - 1/11
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG02_PDIV (4U)    /*!< Bit position for PCIE_PHY_CMN_REG02_PDIV. */
#define BM_PCIE_PHY_CMN_REG02_PDIV (0x000000F0U) /*!< Bit mask for PCIE_PHY_CMN_REG02_PDIV. */
#define BS_PCIE_PHY_CMN_REG02_PDIV (4U)    /*!< Bit field size in bits for PCIE_PHY_CMN_REG02_PDIV. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG02_PDIV field. */
#define BR_PCIE_PHY_CMN_REG02_PDIV(x) (HW_PCIE_PHY_CMN_REG02(x).B.PDIV)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG02_PDIV. */
#define BF_PCIE_PHY_CMN_REG02_PDIV(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG02_PDIV) & BM_PCIE_PHY_CMN_REG02_PDIV)

/*! @brief Set the PDIV field to a new value. */
#define BW_PCIE_PHY_CMN_REG02_PDIV(x, v) (HW_PCIE_PHY_CMN_REG02_WR(x, (HW_PCIE_PHY_CMN_REG02_RD(x) & ~BM_PCIE_PHY_CMN_REG02_PDIV) | BF_PCIE_PHY_CMN_REG02_PDIV(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_CMN_REG03 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_CMN_REG03 -  (RW)
 *
 * Reset value: 0x000000E1U
 *
 * This register is prepared for the PLL target setting and cannot be changed at
 * all. The operation cannot be guaranteed for any changes without written
 * permission.
 */
typedef union _hw_pcie_phy_cmn_reg03
{
    uint32_t U;
    struct _hw_pcie_phy_cmn_reg03_bitfields
    {
        uint32_t CTRL_CP : 4;          /*!< [3:0] PLL Bias Control */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_pcie_phy_cmn_reg03_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_CMN_REG03 register
 */
/*@{*/
#define HW_PCIE_PHY_CMN_REG03_ADDR(x) ((uintptr_t)(x) + 0x12U)

#define HW_PCIE_PHY_CMN_REG03(x) (*(__IO hw_pcie_phy_cmn_reg03_t *) HW_PCIE_PHY_CMN_REG03_ADDR(x))
#define HW_PCIE_PHY_CMN_REG03_RD(x) (HW_PCIE_PHY_CMN_REG03(x).U)
#define HW_PCIE_PHY_CMN_REG03_WR(x, v) (HW_PCIE_PHY_CMN_REG03(x).U = (v))
#define HW_PCIE_PHY_CMN_REG03_SET(x, v) (HW_PCIE_PHY_CMN_REG03_WR(x, HW_PCIE_PHY_CMN_REG03_RD(x) |  (v)))
#define HW_PCIE_PHY_CMN_REG03_CLR(x, v) (HW_PCIE_PHY_CMN_REG03_WR(x, HW_PCIE_PHY_CMN_REG03_RD(x) & ~(v)))
#define HW_PCIE_PHY_CMN_REG03_TOG(x, v) (HW_PCIE_PHY_CMN_REG03_WR(x, HW_PCIE_PHY_CMN_REG03_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_CMN_REG03 bitfields
 */

/*!
 * @name Register PCIE_PHY_CMN_REG03, field CTRL_CP[3:0] (RW)
 *
 * Values:
 * - 0001 - Default for SATA
 * - 0011 - Default for PCIe
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG03_CTRL_CP (0U) /*!< Bit position for PCIE_PHY_CMN_REG03_CTRL_CP. */
#define BM_PCIE_PHY_CMN_REG03_CTRL_CP (0x0000000FU) /*!< Bit mask for PCIE_PHY_CMN_REG03_CTRL_CP. */
#define BS_PCIE_PHY_CMN_REG03_CTRL_CP (4U) /*!< Bit field size in bits for PCIE_PHY_CMN_REG03_CTRL_CP. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG03_CTRL_CP field. */
#define BR_PCIE_PHY_CMN_REG03_CTRL_CP(x) (HW_PCIE_PHY_CMN_REG03(x).B.CTRL_CP)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG03_CTRL_CP. */
#define BF_PCIE_PHY_CMN_REG03_CTRL_CP(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG03_CTRL_CP) & BM_PCIE_PHY_CMN_REG03_CTRL_CP)

/*! @brief Set the CTRL_CP field to a new value. */
#define BW_PCIE_PHY_CMN_REG03_CTRL_CP(x, v) (HW_PCIE_PHY_CMN_REG03_WR(x, (HW_PCIE_PHY_CMN_REG03_RD(x) & ~BM_PCIE_PHY_CMN_REG03_CTRL_CP) | BF_PCIE_PHY_CMN_REG03_CTRL_CP(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_CMN_REG04 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_CMN_REG04 -  (RW)
 *
 * Reset value: 0x00000035U
 *
 * This register is prepared for the PLL target setting and cannot be changed at
 * all. The operation cannot be guaranteed for any changes without written
 * permission.
 */
typedef union _hw_pcie_phy_cmn_reg04
{
    uint32_t U;
    struct _hw_pcie_phy_cmn_reg04_bitfields
    {
        uint32_t RESERVED0 : 1;        /*!< [0]  */
        uint32_t CTRL_C : 3;           /*!< [3:1] PLL Loop Filter Cap control */
        uint32_t CTRL_R : 4;           /*!< [7:4] PLL Loop Filter Res control */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_cmn_reg04_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_CMN_REG04 register
 */
/*@{*/
#define HW_PCIE_PHY_CMN_REG04_ADDR(x) ((uintptr_t)(x) + 0x16U)

#define HW_PCIE_PHY_CMN_REG04(x) (*(__IO hw_pcie_phy_cmn_reg04_t *) HW_PCIE_PHY_CMN_REG04_ADDR(x))
#define HW_PCIE_PHY_CMN_REG04_RD(x) (HW_PCIE_PHY_CMN_REG04(x).U)
#define HW_PCIE_PHY_CMN_REG04_WR(x, v) (HW_PCIE_PHY_CMN_REG04(x).U = (v))
#define HW_PCIE_PHY_CMN_REG04_SET(x, v) (HW_PCIE_PHY_CMN_REG04_WR(x, HW_PCIE_PHY_CMN_REG04_RD(x) |  (v)))
#define HW_PCIE_PHY_CMN_REG04_CLR(x, v) (HW_PCIE_PHY_CMN_REG04_WR(x, HW_PCIE_PHY_CMN_REG04_RD(x) & ~(v)))
#define HW_PCIE_PHY_CMN_REG04_TOG(x, v) (HW_PCIE_PHY_CMN_REG04_WR(x, HW_PCIE_PHY_CMN_REG04_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_CMN_REG04 bitfields
 */

/*!
 * @name Register PCIE_PHY_CMN_REG04, field CTRL_C[3:1] (RW)
 *
 * Values:
 * - 010 - Default for SATA
 * - 100 - Default for PCIe
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG04_CTRL_C (1U)  /*!< Bit position for PCIE_PHY_CMN_REG04_CTRL_C. */
#define BM_PCIE_PHY_CMN_REG04_CTRL_C (0x0000000EU) /*!< Bit mask for PCIE_PHY_CMN_REG04_CTRL_C. */
#define BS_PCIE_PHY_CMN_REG04_CTRL_C (3U)  /*!< Bit field size in bits for PCIE_PHY_CMN_REG04_CTRL_C. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG04_CTRL_C field. */
#define BR_PCIE_PHY_CMN_REG04_CTRL_C(x) (HW_PCIE_PHY_CMN_REG04(x).B.CTRL_C)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG04_CTRL_C. */
#define BF_PCIE_PHY_CMN_REG04_CTRL_C(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG04_CTRL_C) & BM_PCIE_PHY_CMN_REG04_CTRL_C)

/*! @brief Set the CTRL_C field to a new value. */
#define BW_PCIE_PHY_CMN_REG04_CTRL_C(x, v) (HW_PCIE_PHY_CMN_REG04_WR(x, (HW_PCIE_PHY_CMN_REG04_RD(x) & ~BM_PCIE_PHY_CMN_REG04_CTRL_C) | BF_PCIE_PHY_CMN_REG04_CTRL_C(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_CMN_REG04, field CTRL_R[7:4] (RW)
 *
 * Values:
 * - 0011 - Default for SATA
 * - 1011 - Default for PCIe
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG04_CTRL_R (4U)  /*!< Bit position for PCIE_PHY_CMN_REG04_CTRL_R. */
#define BM_PCIE_PHY_CMN_REG04_CTRL_R (0x000000F0U) /*!< Bit mask for PCIE_PHY_CMN_REG04_CTRL_R. */
#define BS_PCIE_PHY_CMN_REG04_CTRL_R (4U)  /*!< Bit field size in bits for PCIE_PHY_CMN_REG04_CTRL_R. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG04_CTRL_R field. */
#define BR_PCIE_PHY_CMN_REG04_CTRL_R(x) (HW_PCIE_PHY_CMN_REG04(x).B.CTRL_R)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG04_CTRL_R. */
#define BF_PCIE_PHY_CMN_REG04_CTRL_R(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG04_CTRL_R) & BM_PCIE_PHY_CMN_REG04_CTRL_R)

/*! @brief Set the CTRL_R field to a new value. */
#define BW_PCIE_PHY_CMN_REG04_CTRL_R(x, v) (HW_PCIE_PHY_CMN_REG04_WR(x, (HW_PCIE_PHY_CMN_REG04_RD(x) & ~BM_PCIE_PHY_CMN_REG04_CTRL_R) | BF_PCIE_PHY_CMN_REG04_CTRL_R(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_CMN_REG05 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_CMN_REG05 -  (RW)
 *
 * Reset value: 0x00000029U
 *
 * This register is prepared for the PLL target setting and cannot be changed at
 * all. The operation cannot be guaranteed for any changes without written
 * permission.
 */
typedef union _hw_pcie_phy_cmn_reg05
{
    uint32_t U;
    struct _hw_pcie_phy_cmn_reg05_bitfields
    {
        uint32_t RESERVED0 : 6;        /*!< [5:0]  */
        uint32_t DCC_FB_EN : 1;        /*!< [6] PLL DCC Feadback Enable */
        uint32_t CKFB_MON_EN : 1;      /*!< [7] PLL Clock Monitoring Enable */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_cmn_reg05_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_CMN_REG05 register
 */
/*@{*/
#define HW_PCIE_PHY_CMN_REG05_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_PCIE_PHY_CMN_REG05(x) (*(__IO hw_pcie_phy_cmn_reg05_t *) HW_PCIE_PHY_CMN_REG05_ADDR(x))
#define HW_PCIE_PHY_CMN_REG05_RD(x) (HW_PCIE_PHY_CMN_REG05(x).U)
#define HW_PCIE_PHY_CMN_REG05_WR(x, v) (HW_PCIE_PHY_CMN_REG05(x).U = (v))
#define HW_PCIE_PHY_CMN_REG05_SET(x, v) (HW_PCIE_PHY_CMN_REG05_WR(x, HW_PCIE_PHY_CMN_REG05_RD(x) |  (v)))
#define HW_PCIE_PHY_CMN_REG05_CLR(x, v) (HW_PCIE_PHY_CMN_REG05_WR(x, HW_PCIE_PHY_CMN_REG05_RD(x) & ~(v)))
#define HW_PCIE_PHY_CMN_REG05_TOG(x, v) (HW_PCIE_PHY_CMN_REG05_WR(x, HW_PCIE_PHY_CMN_REG05_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_CMN_REG05 bitfields
 */

/*!
 * @name Register PCIE_PHY_CMN_REG05, field DCC_FB_EN[6] (RW)
 *
 * Values:
 * - 0 - (Default Value)
 * - 1 -
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG05_DCC_FB_EN (6U) /*!< Bit position for PCIE_PHY_CMN_REG05_DCC_FB_EN. */
#define BM_PCIE_PHY_CMN_REG05_DCC_FB_EN (0x00000040U) /*!< Bit mask for PCIE_PHY_CMN_REG05_DCC_FB_EN. */
#define BS_PCIE_PHY_CMN_REG05_DCC_FB_EN (1U) /*!< Bit field size in bits for PCIE_PHY_CMN_REG05_DCC_FB_EN. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG05_DCC_FB_EN field. */
#define BR_PCIE_PHY_CMN_REG05_DCC_FB_EN(x) (HW_PCIE_PHY_CMN_REG05(x).B.DCC_FB_EN)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG05_DCC_FB_EN. */
#define BF_PCIE_PHY_CMN_REG05_DCC_FB_EN(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG05_DCC_FB_EN) & BM_PCIE_PHY_CMN_REG05_DCC_FB_EN)

/*! @brief Set the DCC_FB_EN field to a new value. */
#define BW_PCIE_PHY_CMN_REG05_DCC_FB_EN(x, v) (HW_PCIE_PHY_CMN_REG05_WR(x, (HW_PCIE_PHY_CMN_REG05_RD(x) & ~BM_PCIE_PHY_CMN_REG05_DCC_FB_EN) | BF_PCIE_PHY_CMN_REG05_DCC_FB_EN(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_CMN_REG05, field CKFB_MON_EN[7] (RW)
 *
 * Values:
 * - 0 - (Default Value)
 * - 1 -
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG05_CKFB_MON_EN (7U) /*!< Bit position for PCIE_PHY_CMN_REG05_CKFB_MON_EN. */
#define BM_PCIE_PHY_CMN_REG05_CKFB_MON_EN (0x00000080U) /*!< Bit mask for PCIE_PHY_CMN_REG05_CKFB_MON_EN. */
#define BS_PCIE_PHY_CMN_REG05_CKFB_MON_EN (1U) /*!< Bit field size in bits for PCIE_PHY_CMN_REG05_CKFB_MON_EN. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG05_CKFB_MON_EN field. */
#define BR_PCIE_PHY_CMN_REG05_CKFB_MON_EN(x) (HW_PCIE_PHY_CMN_REG05(x).B.CKFB_MON_EN)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG05_CKFB_MON_EN. */
#define BF_PCIE_PHY_CMN_REG05_CKFB_MON_EN(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG05_CKFB_MON_EN) & BM_PCIE_PHY_CMN_REG05_CKFB_MON_EN)

/*! @brief Set the CKFB_MON_EN field to a new value. */
#define BW_PCIE_PHY_CMN_REG05_CKFB_MON_EN(x, v) (HW_PCIE_PHY_CMN_REG05_WR(x, (HW_PCIE_PHY_CMN_REG05_RD(x) & ~BM_PCIE_PHY_CMN_REG05_CKFB_MON_EN) | BF_PCIE_PHY_CMN_REG05_CKFB_MON_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_CMN_REG06 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_CMN_REG06 -  (RW)
 *
 * Reset value: 0x00000083U
 */
typedef union _hw_pcie_phy_cmn_reg06
{
    uint32_t U;
    struct _hw_pcie_phy_cmn_reg06_bitfields
    {
        uint32_t SD_DIV : 3;           /*!< [2:0] Sigma Delta CLK control */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t CK100M_EN : 1;        /*!< [4] CK100M Enable */
        uint32_t RESERVED1 : 2;        /*!< [6:5]  */
        uint32_t MDIV_HS : 1;          /*!< [7] PLL Main-divider Ratio Control */
        uint32_t RESERVED2 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_cmn_reg06_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_CMN_REG06 register
 */
/*@{*/
#define HW_PCIE_PHY_CMN_REG06_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_PCIE_PHY_CMN_REG06(x) (*(__IO hw_pcie_phy_cmn_reg06_t *) HW_PCIE_PHY_CMN_REG06_ADDR(x))
#define HW_PCIE_PHY_CMN_REG06_RD(x) (HW_PCIE_PHY_CMN_REG06(x).U)
#define HW_PCIE_PHY_CMN_REG06_WR(x, v) (HW_PCIE_PHY_CMN_REG06(x).U = (v))
#define HW_PCIE_PHY_CMN_REG06_SET(x, v) (HW_PCIE_PHY_CMN_REG06_WR(x, HW_PCIE_PHY_CMN_REG06_RD(x) |  (v)))
#define HW_PCIE_PHY_CMN_REG06_CLR(x, v) (HW_PCIE_PHY_CMN_REG06_WR(x, HW_PCIE_PHY_CMN_REG06_RD(x) & ~(v)))
#define HW_PCIE_PHY_CMN_REG06_TOG(x, v) (HW_PCIE_PHY_CMN_REG06_WR(x, HW_PCIE_PHY_CMN_REG06_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_CMN_REG06 bitfields
 */

/*!
 * @name Register PCIE_PHY_CMN_REG06, field SD_DIV[2:0] (RW)
 *
 * It is prepared for the PLL target setting and should not be changed at all.
 * The operation cannot be guaranteed for any change without written permission.
 *
 * Values:
 * - 100 - Default for PCIe
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG06_SD_DIV (0U)  /*!< Bit position for PCIE_PHY_CMN_REG06_SD_DIV. */
#define BM_PCIE_PHY_CMN_REG06_SD_DIV (0x00000007U) /*!< Bit mask for PCIE_PHY_CMN_REG06_SD_DIV. */
#define BS_PCIE_PHY_CMN_REG06_SD_DIV (3U)  /*!< Bit field size in bits for PCIE_PHY_CMN_REG06_SD_DIV. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG06_SD_DIV field. */
#define BR_PCIE_PHY_CMN_REG06_SD_DIV(x) (HW_PCIE_PHY_CMN_REG06(x).B.SD_DIV)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG06_SD_DIV. */
#define BF_PCIE_PHY_CMN_REG06_SD_DIV(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG06_SD_DIV) & BM_PCIE_PHY_CMN_REG06_SD_DIV)

/*! @brief Set the SD_DIV field to a new value. */
#define BW_PCIE_PHY_CMN_REG06_SD_DIV(x, v) (HW_PCIE_PHY_CMN_REG06_WR(x, (HW_PCIE_PHY_CMN_REG06_RD(x) & ~BM_PCIE_PHY_CMN_REG06_SD_DIV) | BF_PCIE_PHY_CMN_REG06_SD_DIV(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_CMN_REG06, field CK100M_EN[4] (RW)
 *
 * It is also useful to monitor the REF_CKO clock in the ATE test because input
 * reference clock connection can be checked. This CK100M_EN is used to enable
 * 100MHz differential clock output for the PCIe PHY.
 *
 * Values:
 * - 0 - Static State
 * - 1 - 100 MHz REFCLK Output Enable
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG06_CK100M_EN (4U) /*!< Bit position for PCIE_PHY_CMN_REG06_CK100M_EN. */
#define BM_PCIE_PHY_CMN_REG06_CK100M_EN (0x00000010U) /*!< Bit mask for PCIE_PHY_CMN_REG06_CK100M_EN. */
#define BS_PCIE_PHY_CMN_REG06_CK100M_EN (1U) /*!< Bit field size in bits for PCIE_PHY_CMN_REG06_CK100M_EN. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG06_CK100M_EN field. */
#define BR_PCIE_PHY_CMN_REG06_CK100M_EN(x) (HW_PCIE_PHY_CMN_REG06(x).B.CK100M_EN)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG06_CK100M_EN. */
#define BF_PCIE_PHY_CMN_REG06_CK100M_EN(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG06_CK100M_EN) & BM_PCIE_PHY_CMN_REG06_CK100M_EN)

/*! @brief Set the CK100M_EN field to a new value. */
#define BW_PCIE_PHY_CMN_REG06_CK100M_EN(x, v) (HW_PCIE_PHY_CMN_REG06_WR(x, (HW_PCIE_PHY_CMN_REG06_RD(x) & ~BM_PCIE_PHY_CMN_REG06_CK100M_EN) | BF_PCIE_PHY_CMN_REG06_CK100M_EN(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_CMN_REG06, field MDIV_HS[7] (RW)
 *
 * Values:
 * - 0 - 1/1
 * - 1 - 1/2 (Divide by 2, default)
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG06_MDIV_HS (7U) /*!< Bit position for PCIE_PHY_CMN_REG06_MDIV_HS. */
#define BM_PCIE_PHY_CMN_REG06_MDIV_HS (0x00000080U) /*!< Bit mask for PCIE_PHY_CMN_REG06_MDIV_HS. */
#define BS_PCIE_PHY_CMN_REG06_MDIV_HS (1U) /*!< Bit field size in bits for PCIE_PHY_CMN_REG06_MDIV_HS. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG06_MDIV_HS field. */
#define BR_PCIE_PHY_CMN_REG06_MDIV_HS(x) (HW_PCIE_PHY_CMN_REG06(x).B.MDIV_HS)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG06_MDIV_HS. */
#define BF_PCIE_PHY_CMN_REG06_MDIV_HS(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG06_MDIV_HS) & BM_PCIE_PHY_CMN_REG06_MDIV_HS)

/*! @brief Set the MDIV_HS field to a new value. */
#define BW_PCIE_PHY_CMN_REG06_MDIV_HS(x, v) (HW_PCIE_PHY_CMN_REG06_WR(x, (HW_PCIE_PHY_CMN_REG06_RD(x) & ~BM_PCIE_PHY_CMN_REG06_MDIV_HS) | BF_PCIE_PHY_CMN_REG06_MDIV_HS(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_CMN_REG07 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_CMN_REG07 -  (RW)
 *
 * Reset value: 0x0000003CU
 */
typedef union _hw_pcie_phy_cmn_reg07
{
    uint32_t U;
    struct _hw_pcie_phy_cmn_reg07_bitfields
    {
        uint32_t MDIV_MS : 8;          /*!< [7:0] PLL Main-divider Ratio Control */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_cmn_reg07_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_CMN_REG07 register
 */
/*@{*/
#define HW_PCIE_PHY_CMN_REG07_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_PCIE_PHY_CMN_REG07(x) (*(__IO hw_pcie_phy_cmn_reg07_t *) HW_PCIE_PHY_CMN_REG07_ADDR(x))
#define HW_PCIE_PHY_CMN_REG07_RD(x) (HW_PCIE_PHY_CMN_REG07(x).U)
#define HW_PCIE_PHY_CMN_REG07_WR(x, v) (HW_PCIE_PHY_CMN_REG07(x).U = (v))
#define HW_PCIE_PHY_CMN_REG07_SET(x, v) (HW_PCIE_PHY_CMN_REG07_WR(x, HW_PCIE_PHY_CMN_REG07_RD(x) |  (v)))
#define HW_PCIE_PHY_CMN_REG07_CLR(x, v) (HW_PCIE_PHY_CMN_REG07_WR(x, HW_PCIE_PHY_CMN_REG07_RD(x) & ~(v)))
#define HW_PCIE_PHY_CMN_REG07_TOG(x, v) (HW_PCIE_PHY_CMN_REG07_WR(x, HW_PCIE_PHY_CMN_REG07_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_CMN_REG07 bitfields
 */

/*!
 * @name Register PCIE_PHY_CMN_REG07, field MDIV_MS[7:0] (RW)
 *
 * Values:
 * - 00000000 - GND
 * - 00001011 - GND
 * - 00001100 - 1/12
 * - 00001101 - 1/13
 * - 00011001 - 1/25
 * - 00111100 - 1/60
 * - 11111110 - 1/254
 * - 11111111 - 1/255
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG07_MDIV_MS (0U) /*!< Bit position for PCIE_PHY_CMN_REG07_MDIV_MS. */
#define BM_PCIE_PHY_CMN_REG07_MDIV_MS (0x000000FFU) /*!< Bit mask for PCIE_PHY_CMN_REG07_MDIV_MS. */
#define BS_PCIE_PHY_CMN_REG07_MDIV_MS (8U) /*!< Bit field size in bits for PCIE_PHY_CMN_REG07_MDIV_MS. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG07_MDIV_MS field. */
#define BR_PCIE_PHY_CMN_REG07_MDIV_MS(x) (HW_PCIE_PHY_CMN_REG07(x).B.MDIV_MS)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG07_MDIV_MS. */
#define BF_PCIE_PHY_CMN_REG07_MDIV_MS(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG07_MDIV_MS) & BM_PCIE_PHY_CMN_REG07_MDIV_MS)

/*! @brief Set the MDIV_MS field to a new value. */
#define BW_PCIE_PHY_CMN_REG07_MDIV_MS(x, v) (HW_PCIE_PHY_CMN_REG07_WR(x, (HW_PCIE_PHY_CMN_REG07_RD(x) & ~BM_PCIE_PHY_CMN_REG07_MDIV_MS) | BF_PCIE_PHY_CMN_REG07_MDIV_MS(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_CMN_REG0B -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_CMN_REG0B -  (RW)
 *
 * Reset value: 0x0000003FU
 */
typedef union _hw_pcie_phy_cmn_reg0b
{
    uint32_t U;
    struct _hw_pcie_phy_cmn_reg0b_bitfields
    {
        uint32_t SSC : 7;              /*!< [6:0] SSC Amount Control */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_pcie_phy_cmn_reg0b_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_CMN_REG0B register
 */
/*@{*/
#define HW_PCIE_PHY_CMN_REG0B_ADDR(x) ((uintptr_t)(x) + 0x2CU)

#define HW_PCIE_PHY_CMN_REG0B(x) (*(__IO hw_pcie_phy_cmn_reg0b_t *) HW_PCIE_PHY_CMN_REG0B_ADDR(x))
#define HW_PCIE_PHY_CMN_REG0B_RD(x) (HW_PCIE_PHY_CMN_REG0B(x).U)
#define HW_PCIE_PHY_CMN_REG0B_WR(x, v) (HW_PCIE_PHY_CMN_REG0B(x).U = (v))
#define HW_PCIE_PHY_CMN_REG0B_SET(x, v) (HW_PCIE_PHY_CMN_REG0B_WR(x, HW_PCIE_PHY_CMN_REG0B_RD(x) |  (v)))
#define HW_PCIE_PHY_CMN_REG0B_CLR(x, v) (HW_PCIE_PHY_CMN_REG0B_WR(x, HW_PCIE_PHY_CMN_REG0B_RD(x) & ~(v)))
#define HW_PCIE_PHY_CMN_REG0B_TOG(x, v) (HW_PCIE_PHY_CMN_REG0B_WR(x, HW_PCIE_PHY_CMN_REG0B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_CMN_REG0B bitfields
 */

/*!
 * @name Register PCIE_PHY_CMN_REG0B, field SSC[6:0] (RW)
 *
 * The amount of SSC modulation can be controlled by using SSC[6:0] and
 * SSC_CNTL[1:0]. For example, SSC modulation amount = 20833 * SSC_CNTL[1:0] / SSC[6:0]
 * ppm. In case of SSC[6:0] = 0011111 (62x) and SSC_CNTL[1:0] = 00 (1x), then SSC
 * modulation = 20833 * 1 / 31 = 672 ppm.
 *
 * Values:
 * - 0010101 - 21x (Minimum allowed value)
 * - 0011111 - 31x (PCIe Default)
 * - 0111111 - 63x (SATA Default)
 * - 1111111 - 127x
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG0B_SSC (0U)     /*!< Bit position for PCIE_PHY_CMN_REG0B_SSC. */
#define BM_PCIE_PHY_CMN_REG0B_SSC (0x0000007FU) /*!< Bit mask for PCIE_PHY_CMN_REG0B_SSC. */
#define BS_PCIE_PHY_CMN_REG0B_SSC (7U)     /*!< Bit field size in bits for PCIE_PHY_CMN_REG0B_SSC. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG0B_SSC field. */
#define BR_PCIE_PHY_CMN_REG0B_SSC(x) (HW_PCIE_PHY_CMN_REG0B(x).B.SSC)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG0B_SSC. */
#define BF_PCIE_PHY_CMN_REG0B_SSC(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG0B_SSC) & BM_PCIE_PHY_CMN_REG0B_SSC)

/*! @brief Set the SSC field to a new value. */
#define BW_PCIE_PHY_CMN_REG0B_SSC(x, v) (HW_PCIE_PHY_CMN_REG0B_WR(x, (HW_PCIE_PHY_CMN_REG0B_RD(x) & ~BM_PCIE_PHY_CMN_REG0B_SSC) | BF_PCIE_PHY_CMN_REG0B_SSC(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_CMN_REG08 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_CMN_REG08 -  (RW)
 *
 * Reset value: 0x0000005EU
 */
typedef union _hw_pcie_phy_cmn_reg08
{
    uint32_t U;
    struct _hw_pcie_phy_cmn_reg08_bitfields
    {
        uint32_t PI_EN : 1;            /*!< [0] PI Enable */
        uint32_t PI_STR : 4;           /*!< [4:1] PI Buffer strength control */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_pcie_phy_cmn_reg08_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_CMN_REG08 register
 */
/*@{*/
#define HW_PCIE_PHY_CMN_REG08_ADDR(x) ((uintptr_t)(x) + 0x32U)

#define HW_PCIE_PHY_CMN_REG08(x) (*(__IO hw_pcie_phy_cmn_reg08_t *) HW_PCIE_PHY_CMN_REG08_ADDR(x))
#define HW_PCIE_PHY_CMN_REG08_RD(x) (HW_PCIE_PHY_CMN_REG08(x).U)
#define HW_PCIE_PHY_CMN_REG08_WR(x, v) (HW_PCIE_PHY_CMN_REG08(x).U = (v))
#define HW_PCIE_PHY_CMN_REG08_SET(x, v) (HW_PCIE_PHY_CMN_REG08_WR(x, HW_PCIE_PHY_CMN_REG08_RD(x) |  (v)))
#define HW_PCIE_PHY_CMN_REG08_CLR(x, v) (HW_PCIE_PHY_CMN_REG08_WR(x, HW_PCIE_PHY_CMN_REG08_RD(x) & ~(v)))
#define HW_PCIE_PHY_CMN_REG08_TOG(x, v) (HW_PCIE_PHY_CMN_REG08_WR(x, HW_PCIE_PHY_CMN_REG08_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_CMN_REG08 bitfields
 */

/*!
 * @name Register PCIE_PHY_CMN_REG08, field PI_EN[0] (RW)
 *
 * Values:
 * - 0 - PI Disable (Default)
 * - 1 - PI Enable
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG08_PI_EN (0U)   /*!< Bit position for PCIE_PHY_CMN_REG08_PI_EN. */
#define BM_PCIE_PHY_CMN_REG08_PI_EN (0x00000001U) /*!< Bit mask for PCIE_PHY_CMN_REG08_PI_EN. */
#define BS_PCIE_PHY_CMN_REG08_PI_EN (1U)   /*!< Bit field size in bits for PCIE_PHY_CMN_REG08_PI_EN. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG08_PI_EN field. */
#define BR_PCIE_PHY_CMN_REG08_PI_EN(x) (HW_PCIE_PHY_CMN_REG08(x).B.PI_EN)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG08_PI_EN. */
#define BF_PCIE_PHY_CMN_REG08_PI_EN(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG08_PI_EN) & BM_PCIE_PHY_CMN_REG08_PI_EN)

/*! @brief Set the PI_EN field to a new value. */
#define BW_PCIE_PHY_CMN_REG08_PI_EN(x, v) (HW_PCIE_PHY_CMN_REG08_WR(x, (HW_PCIE_PHY_CMN_REG08_RD(x) & ~BM_PCIE_PHY_CMN_REG08_PI_EN) | BF_PCIE_PHY_CMN_REG08_PI_EN(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_CMN_REG08, field PI_STR[4:1] (RO)
 *
 * It is prepared for the PLL target setting and cannot be changed at all. The
 * operation cannot be guaranteed for any changes without written permission.
 *
 * Values:
 * - 1111 - Default for SATA
 * - 0011 - Default for PCIe
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG08_PI_STR (1U)  /*!< Bit position for PCIE_PHY_CMN_REG08_PI_STR. */
#define BM_PCIE_PHY_CMN_REG08_PI_STR (0x0000001EU) /*!< Bit mask for PCIE_PHY_CMN_REG08_PI_STR. */
#define BS_PCIE_PHY_CMN_REG08_PI_STR (4U)  /*!< Bit field size in bits for PCIE_PHY_CMN_REG08_PI_STR. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG08_PI_STR field. */
#define BR_PCIE_PHY_CMN_REG08_PI_STR(x) (HW_PCIE_PHY_CMN_REG08(x).B.PI_STR)
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_CMN_REG09 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_CMN_REG09 -  (RW)
 *
 * Reset value: 0x00000013U
 */
typedef union _hw_pcie_phy_cmn_reg09
{
    uint32_t U;
    struct _hw_pcie_phy_cmn_reg09_bitfields
    {
        uint32_t RESERVED0 : 5;        /*!< [4:0]  */
        uint32_t SSC_CNTL : 2;         /*!< [6:5] SSC Control */
        uint32_t RESERVED1 : 25;       /*!< [31:7]  */
    } B;
} hw_pcie_phy_cmn_reg09_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_CMN_REG09 register
 */
/*@{*/
#define HW_PCIE_PHY_CMN_REG09_ADDR(x) ((uintptr_t)(x) + 0x36U)

#define HW_PCIE_PHY_CMN_REG09(x) (*(__IO hw_pcie_phy_cmn_reg09_t *) HW_PCIE_PHY_CMN_REG09_ADDR(x))
#define HW_PCIE_PHY_CMN_REG09_RD(x) (HW_PCIE_PHY_CMN_REG09(x).U)
#define HW_PCIE_PHY_CMN_REG09_WR(x, v) (HW_PCIE_PHY_CMN_REG09(x).U = (v))
#define HW_PCIE_PHY_CMN_REG09_SET(x, v) (HW_PCIE_PHY_CMN_REG09_WR(x, HW_PCIE_PHY_CMN_REG09_RD(x) |  (v)))
#define HW_PCIE_PHY_CMN_REG09_CLR(x, v) (HW_PCIE_PHY_CMN_REG09_WR(x, HW_PCIE_PHY_CMN_REG09_RD(x) & ~(v)))
#define HW_PCIE_PHY_CMN_REG09_TOG(x, v) (HW_PCIE_PHY_CMN_REG09_WR(x, HW_PCIE_PHY_CMN_REG09_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_CMN_REG09 bitfields
 */

/*!
 * @name Register PCIE_PHY_CMN_REG09, field SSC_CNTL[6:5] (RW)
 *
 * The amount of SSC modulation can be controlled by using SSC[6:0] and
 * SSC_CNTL[1:0]. For example, SSC modulation amount = 20833 * SSC_CNTL[1:0] / SSC[6:0]
 * ppm. In case of SSC[6:0] = 0011111 (62x) and SSC_CNTL[1:0] = 00 (1x), then SSC
 * modulation = 20833 * 1 / 31 = 672 ppm.
 *
 * Values:
 * - 00 - 1x (Default)
 * - 01 - 2x
 * - 10 - 4x
 * - 11 - 8x
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG09_SSC_CNTL (5U) /*!< Bit position for PCIE_PHY_CMN_REG09_SSC_CNTL. */
#define BM_PCIE_PHY_CMN_REG09_SSC_CNTL (0x00000060U) /*!< Bit mask for PCIE_PHY_CMN_REG09_SSC_CNTL. */
#define BS_PCIE_PHY_CMN_REG09_SSC_CNTL (2U) /*!< Bit field size in bits for PCIE_PHY_CMN_REG09_SSC_CNTL. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG09_SSC_CNTL field. */
#define BR_PCIE_PHY_CMN_REG09_SSC_CNTL(x) (HW_PCIE_PHY_CMN_REG09(x).B.SSC_CNTL)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG09_SSC_CNTL. */
#define BF_PCIE_PHY_CMN_REG09_SSC_CNTL(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG09_SSC_CNTL) & BM_PCIE_PHY_CMN_REG09_SSC_CNTL)

/*! @brief Set the SSC_CNTL field to a new value. */
#define BW_PCIE_PHY_CMN_REG09_SSC_CNTL(x, v) (HW_PCIE_PHY_CMN_REG09_WR(x, (HW_PCIE_PHY_CMN_REG09_RD(x) & ~BM_PCIE_PHY_CMN_REG09_SSC_CNTL) | BF_PCIE_PHY_CMN_REG09_SSC_CNTL(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_CMN_REG11 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_CMN_REG11 -  (RW)
 *
 * Reset value: 0x000000FCU
 *
 * This register is prepared for the PLL target setting and cannot be changed at
 * all. The operation cannot be guaranteed for any changes without written
 * permission.
 */
typedef union _hw_pcie_phy_cmn_reg11
{
    uint32_t U;
    struct _hw_pcie_phy_cmn_reg11_bitfields
    {
        uint32_t PREF : 8;             /*!< [7:0] PLL Reference Control */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_cmn_reg11_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_CMN_REG11 register
 */
/*@{*/
#define HW_PCIE_PHY_CMN_REG11_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_PCIE_PHY_CMN_REG11(x) (*(__IO hw_pcie_phy_cmn_reg11_t *) HW_PCIE_PHY_CMN_REG11_ADDR(x))
#define HW_PCIE_PHY_CMN_REG11_RD(x) (HW_PCIE_PHY_CMN_REG11(x).U)
#define HW_PCIE_PHY_CMN_REG11_WR(x, v) (HW_PCIE_PHY_CMN_REG11(x).U = (v))
#define HW_PCIE_PHY_CMN_REG11_SET(x, v) (HW_PCIE_PHY_CMN_REG11_WR(x, HW_PCIE_PHY_CMN_REG11_RD(x) |  (v)))
#define HW_PCIE_PHY_CMN_REG11_CLR(x, v) (HW_PCIE_PHY_CMN_REG11_WR(x, HW_PCIE_PHY_CMN_REG11_RD(x) & ~(v)))
#define HW_PCIE_PHY_CMN_REG11_TOG(x, v) (HW_PCIE_PHY_CMN_REG11_WR(x, HW_PCIE_PHY_CMN_REG11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_CMN_REG11 bitfields
 */

/*!
 * @name Register PCIE_PHY_CMN_REG11, field PREF[7:0] (RW)
 *
 * Values:
 * - 11111100 - (Default Value)
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG11_PREF (0U)    /*!< Bit position for PCIE_PHY_CMN_REG11_PREF. */
#define BM_PCIE_PHY_CMN_REG11_PREF (0x000000FFU) /*!< Bit mask for PCIE_PHY_CMN_REG11_PREF. */
#define BS_PCIE_PHY_CMN_REG11_PREF (8U)    /*!< Bit field size in bits for PCIE_PHY_CMN_REG11_PREF. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG11_PREF field. */
#define BR_PCIE_PHY_CMN_REG11_PREF(x) (HW_PCIE_PHY_CMN_REG11(x).B.PREF)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG11_PREF. */
#define BF_PCIE_PHY_CMN_REG11_PREF(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG11_PREF) & BM_PCIE_PHY_CMN_REG11_PREF)

/*! @brief Set the PREF field to a new value. */
#define BW_PCIE_PHY_CMN_REG11_PREF(x, v) (HW_PCIE_PHY_CMN_REG11_WR(x, (HW_PCIE_PHY_CMN_REG11_RD(x) & ~BM_PCIE_PHY_CMN_REG11_PREF) | BF_PCIE_PHY_CMN_REG11_PREF(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_CMN_REG15 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_CMN_REG15 -  (RW)
 *
 * Reset value: 0x00000004U
 *
 * When you would like to disable all blocks of CMN, then PD_CMN is needed to be
 * asserted (PD_CMN = 1). This PC_CMN powerdown mode can be used to save the
 * power consumption for the unused CMN block. In the PHY, RESET pins for CMN block
 * can be controlled by register for the debug purpose.
 */
typedef union _hw_pcie_phy_cmn_reg15
{
    uint32_t U;
    struct _hw_pcie_phy_cmn_reg15_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t MON_EN : 1;           /*!< [4] Clock Monitoring Enable */
        uint32_t PD_SCMN : 2;          /*!< [6:5] CMN Sub-block Powerdown */
        uint32_t PHY_CMNPD_EN : 1;     /*!< [7] CMN Sub-block PD Control */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_cmn_reg15_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_CMN_REG15 register
 */
/*@{*/
#define HW_PCIE_PHY_CMN_REG15_ADDR(x) ((uintptr_t)(x) + 0x60U)

#define HW_PCIE_PHY_CMN_REG15(x) (*(__IO hw_pcie_phy_cmn_reg15_t *) HW_PCIE_PHY_CMN_REG15_ADDR(x))
#define HW_PCIE_PHY_CMN_REG15_RD(x) (HW_PCIE_PHY_CMN_REG15(x).U)
#define HW_PCIE_PHY_CMN_REG15_WR(x, v) (HW_PCIE_PHY_CMN_REG15(x).U = (v))
#define HW_PCIE_PHY_CMN_REG15_SET(x, v) (HW_PCIE_PHY_CMN_REG15_WR(x, HW_PCIE_PHY_CMN_REG15_RD(x) |  (v)))
#define HW_PCIE_PHY_CMN_REG15_CLR(x, v) (HW_PCIE_PHY_CMN_REG15_WR(x, HW_PCIE_PHY_CMN_REG15_RD(x) & ~(v)))
#define HW_PCIE_PHY_CMN_REG15_TOG(x, v) (HW_PCIE_PHY_CMN_REG15_WR(x, HW_PCIE_PHY_CMN_REG15_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_CMN_REG15 bitfields
 */

/*!
 * @name Register PCIE_PHY_CMN_REG15, field MON_EN[4] (RW)
 *
 * When MON_EN is "high", clock from PLL could be monitored via TESTCLKOUT port.
 * The frequency of clock is 75 MHz. During the ATE test or bench test, this PLL
 * clock monitoring feature can be used for debug.
 *
 * Values:
 * - 0 - Static State (Default Value)
 * - 1 - Clock Monitoring Enable
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG15_MON_EN (4U)  /*!< Bit position for PCIE_PHY_CMN_REG15_MON_EN. */
#define BM_PCIE_PHY_CMN_REG15_MON_EN (0x00000010U) /*!< Bit mask for PCIE_PHY_CMN_REG15_MON_EN. */
#define BS_PCIE_PHY_CMN_REG15_MON_EN (1U)  /*!< Bit field size in bits for PCIE_PHY_CMN_REG15_MON_EN. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG15_MON_EN field. */
#define BR_PCIE_PHY_CMN_REG15_MON_EN(x) (HW_PCIE_PHY_CMN_REG15(x).B.MON_EN)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG15_MON_EN. */
#define BF_PCIE_PHY_CMN_REG15_MON_EN(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG15_MON_EN) & BM_PCIE_PHY_CMN_REG15_MON_EN)

/*! @brief Set the MON_EN field to a new value. */
#define BW_PCIE_PHY_CMN_REG15_MON_EN(x, v) (HW_PCIE_PHY_CMN_REG15_WR(x, (HW_PCIE_PHY_CMN_REG15_RD(x) & ~BM_PCIE_PHY_CMN_REG15_MON_EN) | BF_PCIE_PHY_CMN_REG15_MON_EN(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_CMN_REG15, field PD_SCMN[6:5] (RW)
 *
 * Values:
 * - 00 - Common block enabled (Default)
 * - 10 - Fine control option for PD
 * - 01 - Fine control option for PD
 * - 11 - Fine control option for PD
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG15_PD_SCMN (5U) /*!< Bit position for PCIE_PHY_CMN_REG15_PD_SCMN. */
#define BM_PCIE_PHY_CMN_REG15_PD_SCMN (0x00000060U) /*!< Bit mask for PCIE_PHY_CMN_REG15_PD_SCMN. */
#define BS_PCIE_PHY_CMN_REG15_PD_SCMN (2U) /*!< Bit field size in bits for PCIE_PHY_CMN_REG15_PD_SCMN. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG15_PD_SCMN field. */
#define BR_PCIE_PHY_CMN_REG15_PD_SCMN(x) (HW_PCIE_PHY_CMN_REG15(x).B.PD_SCMN)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG15_PD_SCMN. */
#define BF_PCIE_PHY_CMN_REG15_PD_SCMN(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG15_PD_SCMN) & BM_PCIE_PHY_CMN_REG15_PD_SCMN)

/*! @brief Set the PD_SCMN field to a new value. */
#define BW_PCIE_PHY_CMN_REG15_PD_SCMN(x, v) (HW_PCIE_PHY_CMN_REG15_WR(x, (HW_PCIE_PHY_CMN_REG15_RD(x) & ~BM_PCIE_PHY_CMN_REG15_PD_SCMN) | BF_PCIE_PHY_CMN_REG15_PD_SCMN(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_CMN_REG15, field PHY_CMNPD_EN[7] (RW)
 *
 * Values:
 * - 0 - Disabled for common block PD control
 * - 1 - Enabled for common block PD control
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG15_PHY_CMNPD_EN (7U) /*!< Bit position for PCIE_PHY_CMN_REG15_PHY_CMNPD_EN. */
#define BM_PCIE_PHY_CMN_REG15_PHY_CMNPD_EN (0x00000080U) /*!< Bit mask for PCIE_PHY_CMN_REG15_PHY_CMNPD_EN. */
#define BS_PCIE_PHY_CMN_REG15_PHY_CMNPD_EN (1U) /*!< Bit field size in bits for PCIE_PHY_CMN_REG15_PHY_CMNPD_EN. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG15_PHY_CMNPD_EN field. */
#define BR_PCIE_PHY_CMN_REG15_PHY_CMNPD_EN(x) (HW_PCIE_PHY_CMN_REG15(x).B.PHY_CMNPD_EN)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG15_PHY_CMNPD_EN. */
#define BF_PCIE_PHY_CMN_REG15_PHY_CMNPD_EN(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG15_PHY_CMNPD_EN) & BM_PCIE_PHY_CMN_REG15_PHY_CMNPD_EN)

/*! @brief Set the PHY_CMNPD_EN field to a new value. */
#define BW_PCIE_PHY_CMN_REG15_PHY_CMNPD_EN(x, v) (HW_PCIE_PHY_CMN_REG15_WR(x, (HW_PCIE_PHY_CMN_REG15_RD(x) & ~BM_PCIE_PHY_CMN_REG15_PHY_CMNPD_EN) | BF_PCIE_PHY_CMN_REG15_PHY_CMNPD_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_CMN_REG16 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_CMN_REG16 -  (RW)
 *
 * Reset value: 0x00000001U
 */
typedef union _hw_pcie_phy_cmn_reg16
{
    uint32_t U;
    struct _hw_pcie_phy_cmn_reg16_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t PHY_SSC_EN : 2;       /*!< [3:2] SSC Enable */
        uint32_t RESERVED1 : 28;       /*!< [31:4]  */
    } B;
} hw_pcie_phy_cmn_reg16_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_CMN_REG16 register
 */
/*@{*/
#define HW_PCIE_PHY_CMN_REG16_ADDR(x) ((uintptr_t)(x) + 0x64U)

#define HW_PCIE_PHY_CMN_REG16(x) (*(__IO hw_pcie_phy_cmn_reg16_t *) HW_PCIE_PHY_CMN_REG16_ADDR(x))
#define HW_PCIE_PHY_CMN_REG16_RD(x) (HW_PCIE_PHY_CMN_REG16(x).U)
#define HW_PCIE_PHY_CMN_REG16_WR(x, v) (HW_PCIE_PHY_CMN_REG16(x).U = (v))
#define HW_PCIE_PHY_CMN_REG16_SET(x, v) (HW_PCIE_PHY_CMN_REG16_WR(x, HW_PCIE_PHY_CMN_REG16_RD(x) |  (v)))
#define HW_PCIE_PHY_CMN_REG16_CLR(x, v) (HW_PCIE_PHY_CMN_REG16_WR(x, HW_PCIE_PHY_CMN_REG16_RD(x) & ~(v)))
#define HW_PCIE_PHY_CMN_REG16_TOG(x, v) (HW_PCIE_PHY_CMN_REG16_WR(x, HW_PCIE_PHY_CMN_REG16_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_CMN_REG16 bitfields
 */

/*!
 * @name Register PCIE_PHY_CMN_REG16, field PHY_SSC_EN[3:2] (RW)
 *
 * This SSC feature can be enabled with SSC_EN pin from SoC and only the amount
 * of SSC can be controlled with these registers for debug.When the SSC is
 * enabled, PCIE_TX_P/N signal pins and the PCIE_REFCLKOUT_P/N signal pins would be SSC
 * modulated. In addition, SSC mode can be overrided by (I2C or APB) register
 * setting with I2C_SSC_EN[1:0] for debug purpose.
 *
 * Values:
 * - 0x - SSC control by primary port (SSC_EN)
 * - 10 - SSC mode disabled by register setting
 * - 11 - SSC mode enabled by register setting
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG16_PHY_SSC_EN (2U) /*!< Bit position for PCIE_PHY_CMN_REG16_PHY_SSC_EN. */
#define BM_PCIE_PHY_CMN_REG16_PHY_SSC_EN (0x0000000CU) /*!< Bit mask for PCIE_PHY_CMN_REG16_PHY_SSC_EN. */
#define BS_PCIE_PHY_CMN_REG16_PHY_SSC_EN (2U) /*!< Bit field size in bits for PCIE_PHY_CMN_REG16_PHY_SSC_EN. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG16_PHY_SSC_EN field. */
#define BR_PCIE_PHY_CMN_REG16_PHY_SSC_EN(x) (HW_PCIE_PHY_CMN_REG16(x).B.PHY_SSC_EN)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG16_PHY_SSC_EN. */
#define BF_PCIE_PHY_CMN_REG16_PHY_SSC_EN(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG16_PHY_SSC_EN) & BM_PCIE_PHY_CMN_REG16_PHY_SSC_EN)

/*! @brief Set the PHY_SSC_EN field to a new value. */
#define BW_PCIE_PHY_CMN_REG16_PHY_SSC_EN(x, v) (HW_PCIE_PHY_CMN_REG16_WR(x, (HW_PCIE_PHY_CMN_REG16_RD(x) & ~BM_PCIE_PHY_CMN_REG16_PHY_SSC_EN) | BF_PCIE_PHY_CMN_REG16_PHY_SSC_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_CMN_REG17 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_CMN_REG17 -  (RW)
 *
 * Reset value: 0x00000001U
 */
typedef union _hw_pcie_phy_cmn_reg17
{
    uint32_t U;
    struct _hw_pcie_phy_cmn_reg17_bitfields
    {
        uint32_t RDIV : 4;             /*!< [3:0] PLL Ref-divider Ratio Control */
        uint32_t RDIV_EN : 1;          /*!< [4] PLL Ref-divider Enable */
        uint32_t RESERVED0 : 2;        /*!< [6:5]  */
        uint32_t TG_CODE_EN : 1;       /*!< [7] PLL Frequency Control Enable */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_cmn_reg17_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_CMN_REG17 register
 */
/*@{*/
#define HW_PCIE_PHY_CMN_REG17_ADDR(x) ((uintptr_t)(x) + 0x68U)

#define HW_PCIE_PHY_CMN_REG17(x) (*(__IO hw_pcie_phy_cmn_reg17_t *) HW_PCIE_PHY_CMN_REG17_ADDR(x))
#define HW_PCIE_PHY_CMN_REG17_RD(x) (HW_PCIE_PHY_CMN_REG17(x).U)
#define HW_PCIE_PHY_CMN_REG17_WR(x, v) (HW_PCIE_PHY_CMN_REG17(x).U = (v))
#define HW_PCIE_PHY_CMN_REG17_SET(x, v) (HW_PCIE_PHY_CMN_REG17_WR(x, HW_PCIE_PHY_CMN_REG17_RD(x) |  (v)))
#define HW_PCIE_PHY_CMN_REG17_CLR(x, v) (HW_PCIE_PHY_CMN_REG17_WR(x, HW_PCIE_PHY_CMN_REG17_RD(x) & ~(v)))
#define HW_PCIE_PHY_CMN_REG17_TOG(x, v) (HW_PCIE_PHY_CMN_REG17_WR(x, HW_PCIE_PHY_CMN_REG17_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_CMN_REG17 bitfields
 */

/*!
 * @name Register PCIE_PHY_CMN_REG17, field RDIV[3:0] (RW)
 *
 * Values:
 * - 0010 - 1/2 (Divide by 2, default)
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG17_RDIV (0U)    /*!< Bit position for PCIE_PHY_CMN_REG17_RDIV. */
#define BM_PCIE_PHY_CMN_REG17_RDIV (0x0000000FU) /*!< Bit mask for PCIE_PHY_CMN_REG17_RDIV. */
#define BS_PCIE_PHY_CMN_REG17_RDIV (4U)    /*!< Bit field size in bits for PCIE_PHY_CMN_REG17_RDIV. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG17_RDIV field. */
#define BR_PCIE_PHY_CMN_REG17_RDIV(x) (HW_PCIE_PHY_CMN_REG17(x).B.RDIV)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG17_RDIV. */
#define BF_PCIE_PHY_CMN_REG17_RDIV(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG17_RDIV) & BM_PCIE_PHY_CMN_REG17_RDIV)

/*! @brief Set the RDIV field to a new value. */
#define BW_PCIE_PHY_CMN_REG17_RDIV(x, v) (HW_PCIE_PHY_CMN_REG17_WR(x, (HW_PCIE_PHY_CMN_REG17_RD(x) & ~BM_PCIE_PHY_CMN_REG17_RDIV) | BF_PCIE_PHY_CMN_REG17_RDIV(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_CMN_REG17, field RDIV_EN[4] (RW)
 *
 * In the PCIe PHY, the reference clock frequency should be 100 MHz. However
 * only 50 MHz reference clock is available, then try to use this seeting for test
 * purpose (For example, Reg02 = 14h, Reg17 = 12h. PDIV[3:0] = 0001, RDIV[3:0] =
 * 0010, and RDIV_EN = 1).
 *
 * Values:
 * - 0 - Disabled
 * - 1 - Enabled
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG17_RDIV_EN (4U) /*!< Bit position for PCIE_PHY_CMN_REG17_RDIV_EN. */
#define BM_PCIE_PHY_CMN_REG17_RDIV_EN (0x00000010U) /*!< Bit mask for PCIE_PHY_CMN_REG17_RDIV_EN. */
#define BS_PCIE_PHY_CMN_REG17_RDIV_EN (1U) /*!< Bit field size in bits for PCIE_PHY_CMN_REG17_RDIV_EN. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG17_RDIV_EN field. */
#define BR_PCIE_PHY_CMN_REG17_RDIV_EN(x) (HW_PCIE_PHY_CMN_REG17(x).B.RDIV_EN)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG17_RDIV_EN. */
#define BF_PCIE_PHY_CMN_REG17_RDIV_EN(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG17_RDIV_EN) & BM_PCIE_PHY_CMN_REG17_RDIV_EN)

/*! @brief Set the RDIV_EN field to a new value. */
#define BW_PCIE_PHY_CMN_REG17_RDIV_EN(x, v) (HW_PCIE_PHY_CMN_REG17_WR(x, (HW_PCIE_PHY_CMN_REG17_RD(x) & ~BM_PCIE_PHY_CMN_REG17_RDIV_EN) | BF_PCIE_PHY_CMN_REG17_RDIV_EN(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_CMN_REG17, field TG_CODE_EN[7] (RW)
 *
 * It is prepared for the PLL target setting and cannot be changed at all. The
 * operation cannot be guaranteed for any changes without written permission.
 *
 * Values:
 * - 0 - Disable TG_CODE_EN
 * - 1 - Enable TG_CODE_EN
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG17_TG_CODE_EN (7U) /*!< Bit position for PCIE_PHY_CMN_REG17_TG_CODE_EN. */
#define BM_PCIE_PHY_CMN_REG17_TG_CODE_EN (0x00000080U) /*!< Bit mask for PCIE_PHY_CMN_REG17_TG_CODE_EN. */
#define BS_PCIE_PHY_CMN_REG17_TG_CODE_EN (1U) /*!< Bit field size in bits for PCIE_PHY_CMN_REG17_TG_CODE_EN. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG17_TG_CODE_EN field. */
#define BR_PCIE_PHY_CMN_REG17_TG_CODE_EN(x) (HW_PCIE_PHY_CMN_REG17(x).B.TG_CODE_EN)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG17_TG_CODE_EN. */
#define BF_PCIE_PHY_CMN_REG17_TG_CODE_EN(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG17_TG_CODE_EN) & BM_PCIE_PHY_CMN_REG17_TG_CODE_EN)

/*! @brief Set the TG_CODE_EN field to a new value. */
#define BW_PCIE_PHY_CMN_REG17_TG_CODE_EN(x, v) (HW_PCIE_PHY_CMN_REG17_WR(x, (HW_PCIE_PHY_CMN_REG17_RD(x) & ~BM_PCIE_PHY_CMN_REG17_TG_CODE_EN) | BF_PCIE_PHY_CMN_REG17_TG_CODE_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_CMN_REG18 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_CMN_REG18 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is prepared for the PLL target setting and should not be
 * changed at all. The operation cannot be guaranteed for any change without written
 * permission.
 */
typedef union _hw_pcie_phy_cmn_reg18
{
    uint32_t U;
    struct _hw_pcie_phy_cmn_reg18_bitfields
    {
        uint32_t TG_CODE : 8;          /*!< [7:0] PLL Frequency Control */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_cmn_reg18_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_CMN_REG18 register
 */
/*@{*/
#define HW_PCIE_PHY_CMN_REG18_ADDR(x) ((uintptr_t)(x) + 0x72U)

#define HW_PCIE_PHY_CMN_REG18(x) (*(__IO hw_pcie_phy_cmn_reg18_t *) HW_PCIE_PHY_CMN_REG18_ADDR(x))
#define HW_PCIE_PHY_CMN_REG18_RD(x) (HW_PCIE_PHY_CMN_REG18(x).U)
#define HW_PCIE_PHY_CMN_REG18_WR(x, v) (HW_PCIE_PHY_CMN_REG18(x).U = (v))
#define HW_PCIE_PHY_CMN_REG18_SET(x, v) (HW_PCIE_PHY_CMN_REG18_WR(x, HW_PCIE_PHY_CMN_REG18_RD(x) |  (v)))
#define HW_PCIE_PHY_CMN_REG18_CLR(x, v) (HW_PCIE_PHY_CMN_REG18_WR(x, HW_PCIE_PHY_CMN_REG18_RD(x) & ~(v)))
#define HW_PCIE_PHY_CMN_REG18_TOG(x, v) (HW_PCIE_PHY_CMN_REG18_WR(x, HW_PCIE_PHY_CMN_REG18_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_CMN_REG18 bitfields
 */

/*!
 * @name Register PCIE_PHY_CMN_REG18, field TG_CODE[7:0] (RW)
 *
 * Values:
 * - 00000000 - (Default Value)
 * - 11111111 -
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG18_TG_CODE (0U) /*!< Bit position for PCIE_PHY_CMN_REG18_TG_CODE. */
#define BM_PCIE_PHY_CMN_REG18_TG_CODE (0x000000FFU) /*!< Bit mask for PCIE_PHY_CMN_REG18_TG_CODE. */
#define BS_PCIE_PHY_CMN_REG18_TG_CODE (8U) /*!< Bit field size in bits for PCIE_PHY_CMN_REG18_TG_CODE. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG18_TG_CODE field. */
#define BR_PCIE_PHY_CMN_REG18_TG_CODE(x) (HW_PCIE_PHY_CMN_REG18(x).B.TG_CODE)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG18_TG_CODE. */
#define BF_PCIE_PHY_CMN_REG18_TG_CODE(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG18_TG_CODE) & BM_PCIE_PHY_CMN_REG18_TG_CODE)

/*! @brief Set the TG_CODE field to a new value. */
#define BW_PCIE_PHY_CMN_REG18_TG_CODE(x, v) (HW_PCIE_PHY_CMN_REG18_WR(x, (HW_PCIE_PHY_CMN_REG18_RD(x) & ~BM_PCIE_PHY_CMN_REG18_TG_CODE) | BF_PCIE_PHY_CMN_REG18_TG_CODE(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_CMN_REG19 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_CMN_REG19 -  (RW)
 *
 * Reset value: 0x00000043U
 *
 * This register is prepared for the PLL target setting and cannot be changed at
 * all. The operation cannot be guaranteed for any changes without written
 * permission.
 */
typedef union _hw_pcie_phy_cmn_reg19
{
    uint32_t U;
    struct _hw_pcie_phy_cmn_reg19_bitfields
    {
        uint32_t TOL : 3;              /*!< [2:0] PLL Tolerance Control */
        uint32_t PD_CMN : 1;           /*!< [3] CMN All Block Powerdown */
        uint32_t RTOL : 4;             /*!< [7:4] PLL Tolerance Control */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_cmn_reg19_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_CMN_REG19 register
 */
/*@{*/
#define HW_PCIE_PHY_CMN_REG19_ADDR(x) ((uintptr_t)(x) + 0x76U)

#define HW_PCIE_PHY_CMN_REG19(x) (*(__IO hw_pcie_phy_cmn_reg19_t *) HW_PCIE_PHY_CMN_REG19_ADDR(x))
#define HW_PCIE_PHY_CMN_REG19_RD(x) (HW_PCIE_PHY_CMN_REG19(x).U)
#define HW_PCIE_PHY_CMN_REG19_WR(x, v) (HW_PCIE_PHY_CMN_REG19(x).U = (v))
#define HW_PCIE_PHY_CMN_REG19_SET(x, v) (HW_PCIE_PHY_CMN_REG19_WR(x, HW_PCIE_PHY_CMN_REG19_RD(x) |  (v)))
#define HW_PCIE_PHY_CMN_REG19_CLR(x, v) (HW_PCIE_PHY_CMN_REG19_WR(x, HW_PCIE_PHY_CMN_REG19_RD(x) & ~(v)))
#define HW_PCIE_PHY_CMN_REG19_TOG(x, v) (HW_PCIE_PHY_CMN_REG19_WR(x, HW_PCIE_PHY_CMN_REG19_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_CMN_REG19 bitfields
 */

/*!
 * @name Register PCIE_PHY_CMN_REG19, field TOL[2:0] (RW)
 *
 * Values:
 * - 011 - (Default Value)
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG19_TOL (0U)     /*!< Bit position for PCIE_PHY_CMN_REG19_TOL. */
#define BM_PCIE_PHY_CMN_REG19_TOL (0x00000007U) /*!< Bit mask for PCIE_PHY_CMN_REG19_TOL. */
#define BS_PCIE_PHY_CMN_REG19_TOL (3U)     /*!< Bit field size in bits for PCIE_PHY_CMN_REG19_TOL. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG19_TOL field. */
#define BR_PCIE_PHY_CMN_REG19_TOL(x) (HW_PCIE_PHY_CMN_REG19(x).B.TOL)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG19_TOL. */
#define BF_PCIE_PHY_CMN_REG19_TOL(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG19_TOL) & BM_PCIE_PHY_CMN_REG19_TOL)

/*! @brief Set the TOL field to a new value. */
#define BW_PCIE_PHY_CMN_REG19_TOL(x, v) (HW_PCIE_PHY_CMN_REG19_WR(x, (HW_PCIE_PHY_CMN_REG19_RD(x) & ~BM_PCIE_PHY_CMN_REG19_TOL) | BF_PCIE_PHY_CMN_REG19_TOL(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_CMN_REG19, field PD_CMN[3] (RW)
 *
 * When disable all blocks of CMN, then PD_CMN is needed to be asserted (PD_CMN
 * = 1). This PC_CMN powerdown mode can be used to save the power consumption for
 * the unused CMN block.
 *
 * Values:
 * - 0 - Common block enabled (Default)
 * - 1 - Common block all powerdown
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG19_PD_CMN (3U)  /*!< Bit position for PCIE_PHY_CMN_REG19_PD_CMN. */
#define BM_PCIE_PHY_CMN_REG19_PD_CMN (0x00000008U) /*!< Bit mask for PCIE_PHY_CMN_REG19_PD_CMN. */
#define BS_PCIE_PHY_CMN_REG19_PD_CMN (1U)  /*!< Bit field size in bits for PCIE_PHY_CMN_REG19_PD_CMN. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG19_PD_CMN field. */
#define BR_PCIE_PHY_CMN_REG19_PD_CMN(x) (HW_PCIE_PHY_CMN_REG19(x).B.PD_CMN)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG19_PD_CMN. */
#define BF_PCIE_PHY_CMN_REG19_PD_CMN(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG19_PD_CMN) & BM_PCIE_PHY_CMN_REG19_PD_CMN)

/*! @brief Set the PD_CMN field to a new value. */
#define BW_PCIE_PHY_CMN_REG19_PD_CMN(x, v) (HW_PCIE_PHY_CMN_REG19_WR(x, (HW_PCIE_PHY_CMN_REG19_RD(x) & ~BM_PCIE_PHY_CMN_REG19_PD_CMN) | BF_PCIE_PHY_CMN_REG19_PD_CMN(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_CMN_REG19, field RTOL[7:4] (RW)
 *
 * Values:
 * - 0100 - (Default Value)
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG19_RTOL (4U)    /*!< Bit position for PCIE_PHY_CMN_REG19_RTOL. */
#define BM_PCIE_PHY_CMN_REG19_RTOL (0x000000F0U) /*!< Bit mask for PCIE_PHY_CMN_REG19_RTOL. */
#define BS_PCIE_PHY_CMN_REG19_RTOL (4U)    /*!< Bit field size in bits for PCIE_PHY_CMN_REG19_RTOL. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG19_RTOL field. */
#define BR_PCIE_PHY_CMN_REG19_RTOL(x) (HW_PCIE_PHY_CMN_REG19(x).B.RTOL)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG19_RTOL. */
#define BF_PCIE_PHY_CMN_REG19_RTOL(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG19_RTOL) & BM_PCIE_PHY_CMN_REG19_RTOL)

/*! @brief Set the RTOL field to a new value. */
#define BW_PCIE_PHY_CMN_REG19_RTOL(x, v) (HW_PCIE_PHY_CMN_REG19_WR(x, (HW_PCIE_PHY_CMN_REG19_RD(x) & ~BM_PCIE_PHY_CMN_REG19_RTOL) | BF_PCIE_PHY_CMN_REG19_RTOL(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_CMN_REG1A -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_CMN_REG1A -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is prepared for the PLL target setting and should not be
 * changed at all. The operation can not be guaranteed for any change without written
 * permission.
 */
typedef union _hw_pcie_phy_cmn_reg1a
{
    uint32_t U;
    struct _hw_pcie_phy_cmn_reg1a_bitfields
    {
        uint32_t CMNRST : 8;           /*!< [7:0] CMN Reset Control */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_cmn_reg1a_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_CMN_REG1A register
 */
/*@{*/
#define HW_PCIE_PHY_CMN_REG1A_ADDR(x) ((uintptr_t)(x) + 0x80U)

#define HW_PCIE_PHY_CMN_REG1A(x) (*(__IO hw_pcie_phy_cmn_reg1a_t *) HW_PCIE_PHY_CMN_REG1A_ADDR(x))
#define HW_PCIE_PHY_CMN_REG1A_RD(x) (HW_PCIE_PHY_CMN_REG1A(x).U)
#define HW_PCIE_PHY_CMN_REG1A_WR(x, v) (HW_PCIE_PHY_CMN_REG1A(x).U = (v))
#define HW_PCIE_PHY_CMN_REG1A_SET(x, v) (HW_PCIE_PHY_CMN_REG1A_WR(x, HW_PCIE_PHY_CMN_REG1A_RD(x) |  (v)))
#define HW_PCIE_PHY_CMN_REG1A_CLR(x, v) (HW_PCIE_PHY_CMN_REG1A_WR(x, HW_PCIE_PHY_CMN_REG1A_RD(x) & ~(v)))
#define HW_PCIE_PHY_CMN_REG1A_TOG(x, v) (HW_PCIE_PHY_CMN_REG1A_WR(x, HW_PCIE_PHY_CMN_REG1A_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_CMN_REG1A bitfields
 */

/*!
 * @name Register PCIE_PHY_CMN_REG1A, field CMNRST[7:0] (RW)
 *
 * In the PHY, RESET pins for CMN block can be controlled by register for the
 * debug purpose.
 *
 * Values:
 * - 10000000 - Fine control option for RESET
 * - 11111111 - Fine control option for RESET
 */
/*@{*/
#define BP_PCIE_PHY_CMN_REG1A_CMNRST (0U)  /*!< Bit position for PCIE_PHY_CMN_REG1A_CMNRST. */
#define BM_PCIE_PHY_CMN_REG1A_CMNRST (0x000000FFU) /*!< Bit mask for PCIE_PHY_CMN_REG1A_CMNRST. */
#define BS_PCIE_PHY_CMN_REG1A_CMNRST (8U)  /*!< Bit field size in bits for PCIE_PHY_CMN_REG1A_CMNRST. */

/*! @brief Read current value of the PCIE_PHY_CMN_REG1A_CMNRST field. */
#define BR_PCIE_PHY_CMN_REG1A_CMNRST(x) (HW_PCIE_PHY_CMN_REG1A(x).B.CMNRST)

/*! @brief Format value for bitfield PCIE_PHY_CMN_REG1A_CMNRST. */
#define BF_PCIE_PHY_CMN_REG1A_CMNRST(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_CMN_REG1A_CMNRST) & BM_PCIE_PHY_CMN_REG1A_CMNRST)

/*! @brief Set the CMNRST field to a new value. */
#define BW_PCIE_PHY_CMN_REG1A_CMNRST(x, v) (HW_PCIE_PHY_CMN_REG1A_WR(x, (HW_PCIE_PHY_CMN_REG1A_RD(x) & ~BM_PCIE_PHY_CMN_REG1A_CMNRST) | BF_PCIE_PHY_CMN_REG1A_CMNRST(v)))
/*@}*/

/*******************************************************************************
 * hw_pcie_phy_cmn_t - module struct
 ******************************************************************************/
/*!
 * @brief All PCIE_PHY_CMN module registers.
 */
#pragma pack(1)
typedef struct _hw_pcie_phy_cmn
{
    uint8_t _reserved0[4];
    __IO hw_pcie_phy_cmn_reg01_t REG01;    /*!< [0x4] Impedance Calibration Register */
    __IO hw_pcie_phy_cmn_reg02_t REG02;    /*!< [0x8]  */
    uint8_t _reserved1[6];
    __IO hw_pcie_phy_cmn_reg03_t REG03;    /*!< [0x12]  */
    __IO hw_pcie_phy_cmn_reg04_t REG04;    /*!< [0x16]  */
    uint8_t _reserved2[6];
    __IO hw_pcie_phy_cmn_reg05_t REG05;    /*!< [0x20]  */
    __IO hw_pcie_phy_cmn_reg06_t REG06;    /*!< [0x24]  */
    __IO hw_pcie_phy_cmn_reg07_t REG07;    /*!< [0x28]  */
    __IO hw_pcie_phy_cmn_reg0b_t REG0B;    /*!< [0x2C]  */
    uint8_t _reserved3[2];
    __IO hw_pcie_phy_cmn_reg08_t REG08;    /*!< [0x32]  */
    __IO hw_pcie_phy_cmn_reg09_t REG09;    /*!< [0x36]  */
    uint8_t _reserved4[6];
    __IO hw_pcie_phy_cmn_reg11_t REG11;    /*!< [0x40]  */
    uint8_t _reserved5[28];
    __IO hw_pcie_phy_cmn_reg15_t REG15;    /*!< [0x60]  */
    __IO hw_pcie_phy_cmn_reg16_t REG16;    /*!< [0x64]  */
    __IO hw_pcie_phy_cmn_reg17_t REG17;    /*!< [0x68]  */
    uint8_t _reserved6[6];
    __IO hw_pcie_phy_cmn_reg18_t REG18;    /*!< [0x72]  */
    __IO hw_pcie_phy_cmn_reg19_t REG19;    /*!< [0x76]  */
    uint8_t _reserved7[6];
    __IO hw_pcie_phy_cmn_reg1a_t REG1A;    /*!< [0x80]  */
} hw_pcie_phy_cmn_t;
#pragma pack()

/*! @brief Macro to access all PCIE_PHY_CMN registers. */
/*! @param x PCIE_PHY_CMN module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_PCIE_PHY_CMN_REGS(PCIE_PHY_CMN_BASE)</code>. */
#define HW_PCIE_PHY_CMN_REGS(x) (*(hw_pcie_phy_cmn_t *)(x))

/*
 * iMX7D PCIE_PHY_TRSV
 *
 * PCIe PHY TRSV Registers
 *
 * Registers defined in this header file:
 * - HW_PCIE_PHY_TRSV_REG21 -
 * - HW_PCIE_PHY_TRSV_REG22 -
 * - HW_PCIE_PHY_TRSV_REG24 -
 * - HW_PCIE_PHY_TRSV_REG2B -
 * - HW_PCIE_PHY_TRSV_REG3A -
 * - HW_PCIE_PHY_TRSV_REG3E -
 * - HW_PCIE_PHY_TRSV_REG25 -
 * - HW_PCIE_PHY_TRSV_REG26 -
 * - HW_PCIE_PHY_TRSV_REG29 -
 * - HW_PCIE_PHY_TRSV_REG31 -
 * - HW_PCIE_PHY_TRSV_REG33 -
 * - HW_PCIE_PHY_TRSV_REG36 -
 * - HW_PCIE_PHY_TRSV_REG37 -
 * - HW_PCIE_PHY_TRSV_REG38 -
 * - HW_PCIE_PHY_TRSV_REG39 -
 * - HW_PCIE_PHY_TRSV_REG40 -
 * - HW_PCIE_PHY_TRSV_REG42 -
 *
 * - hw_pcie_phy_trsv_t - Struct containing all module registers.
 */

#define HW_PCIE_PHY_TRSV_INSTANCE_COUNT (1U) /*!< Number of instances of the PCIE_PHY_TRSV module. */
#define HW_PCIE_PHY_TRSV (0U) /*!< Instance number for PCIE_PHY_TRSV. */
#define PCIE_PHY_TRSV_BASE    (0x306D0000U) /*!< Base address for PCIE_PHY_TRSV. */
/*! Array initializer of PCIE_PHY_TRSV base addresses. */
#define PCIE_PHY_TRSV_BASE_ADDRS { PCIE_PHY_TRSV_BASE }

/*******************************************************************************
 * HW_PCIE_PHY_TRSV_REG21 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_TRSV_REG21 -  (RW)
 *
 * Reset value: 0x00000016U
 */
typedef union _hw_pcie_phy_trsv_reg21
{
    uint32_t U;
    struct _hw_pcie_phy_trsv_reg21_bitfields
    {
        uint32_t EMP_LVL : 5;          /*!< [4:0] TX De-emphasis Level Control */
        uint32_t RESERVED0 : 2;        /*!< [6:5]  */
        uint32_t DRVR_PDH : 1;         /*!< [7] TX Driver Option */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_trsv_reg21_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_TRSV_REG21 register
 */
/*@{*/
#define HW_PCIE_PHY_TRSV_REG21_ADDR(x) ((uintptr_t)(x) + 0x84U)

#define HW_PCIE_PHY_TRSV_REG21(x) (*(__IO hw_pcie_phy_trsv_reg21_t *) HW_PCIE_PHY_TRSV_REG21_ADDR(x))
#define HW_PCIE_PHY_TRSV_REG21_RD(x) (HW_PCIE_PHY_TRSV_REG21(x).U)
#define HW_PCIE_PHY_TRSV_REG21_WR(x, v) (HW_PCIE_PHY_TRSV_REG21(x).U = (v))
#define HW_PCIE_PHY_TRSV_REG21_SET(x, v) (HW_PCIE_PHY_TRSV_REG21_WR(x, HW_PCIE_PHY_TRSV_REG21_RD(x) |  (v)))
#define HW_PCIE_PHY_TRSV_REG21_CLR(x, v) (HW_PCIE_PHY_TRSV_REG21_WR(x, HW_PCIE_PHY_TRSV_REG21_RD(x) & ~(v)))
#define HW_PCIE_PHY_TRSV_REG21_TOG(x, v) (HW_PCIE_PHY_TRSV_REG21_WR(x, HW_PCIE_PHY_TRSV_REG21_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_TRSV_REG21 bitfields
 */

/*!
 * @name Register PCIE_PHY_TRSV_REG21, field EMP_LVL[4:0] (RW)
 *
 * For the TX properties such as amplitude and de-emphasis, please use default
 * setting for the first time evaluation. If the PHY is connected through a long
 * cable, (or media), generally high pre-emphasis level setting would be better.
 * But there would be optimization setting points according to the cable length.
 * TX amplitude and de-emphasis ratio can be calculated as follows. Vtx-noemp-pkpk
 * means differential peak to peak amplitude when there is no de-emphasis.
 * Vtx-diff-pkpk means differential peak to peak amplitude which is included
 * de-emphasis. And Vtx-deemp-pkpk means differential inner flatted peak to peak amplitude
 * which is reduced by de-emphasis. Vtx-noemp-pkpk = ( 7.5 * bit(DRV_LVL[5]) +
 * 3.75 * bit (DRV_LVL[4]) + 2 * bit(DRV_LVL[3]) + 1 * bit (DRV_LVL[2]) + 0.5 *
 * bit (DRV_LVL[1]) + 0.25 * bit (DRV_LVL[0]) + 7.5 ) * 5.32 Vtx-diff-pkpk = ( (
 * 7.5 * bit (DRV_LVL[5]) + 3.75 * bit (DRV_LVL[4]) + 2 * bit (DRV_LVL[3]) + 1 *
 * bit (DRV_LVL[2]) + 0.5 * bit (DRV_LVL[1]) + 0.25 * bit (DRV_LVL[0]) + 7.5 ) + (
 * 3.75 * bit (EMP_LVL[4]) + 2 * bit (EMP_LVL[3]) + 1 * bit (EMP_LVL[2]) + 0.5 *
 * bit (EMP_LVL[1]) + 0.25 * bit (EMP_LVL[0]) ) * 0.7 ) * 5.32 Vtx-deemp-pkpk = (
 * ( 7.5 * bit (DRV_LVL[5]) + 3.75 * bit (DRV_LVL[4]) + 2 * bit (DRV_LVL[3]) + 1
 * * bit (DRV_LVL[2]) + 0.5 * bit (DRV_LVL[1]) + 0.25 * bit (DRV_LVL[0]) + 7.5 )
 * - ( 3.75 * bit (EMP_LVL[4]) + 2 * bit (EMP_LVL[3]) + 1 * bit (EMP_LVL[2]) +
 * 0.5 * bit (EMP_LVL[1]) + 0.25 * bit (EMP_LVL[0]) ) ) * 5.32 TX De-emphasis can
 * be calculated as follows: De − emphasis = −20 log ((Vtx - deemp - pkpk) /
 * (Vtx - diff - pkpk)) (dB) For example DRV_LVL[5:0] = 100000 and EMP_LVL[4:0] =
 * 01000.Vtx − diff − pkpk = 7.5 + 0 + 0 + 0 + 0 + 0 + 7.5 + 0.7 * 0 + 2 + 0
 * + 0 + 0 * 5.32 = 872 mVpkpk De − emphasis = −20 log (7.5 + 0 + 0 + 0 + 0
 * + 0 + 7.5 − (0 + 2 + 0 + 0 + 0)) / (7.5 + 0 + 0 + 0 + 0 + 0 + 7.5 + 0.7 * (0
 * + 2 + 0 + 0 + 0)) = 2 dB
 *
 * Values:
 * - 00000 - No de-emphasis
 * - 00100 - Default for SATA
 * - 10100 - 3.5 dB de-emphasis
 * - 11110 - -6 dB dB de-emphasis
 * - 11111 - Max de-emphasis
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG21_EMP_LVL (0U) /*!< Bit position for PCIE_PHY_TRSV_REG21_EMP_LVL. */
#define BM_PCIE_PHY_TRSV_REG21_EMP_LVL (0x0000001FU) /*!< Bit mask for PCIE_PHY_TRSV_REG21_EMP_LVL. */
#define BS_PCIE_PHY_TRSV_REG21_EMP_LVL (5U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG21_EMP_LVL. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG21_EMP_LVL field. */
#define BR_PCIE_PHY_TRSV_REG21_EMP_LVL(x) (HW_PCIE_PHY_TRSV_REG21(x).B.EMP_LVL)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG21_EMP_LVL. */
#define BF_PCIE_PHY_TRSV_REG21_EMP_LVL(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG21_EMP_LVL) & BM_PCIE_PHY_TRSV_REG21_EMP_LVL)

/*! @brief Set the EMP_LVL field to a new value. */
#define BW_PCIE_PHY_TRSV_REG21_EMP_LVL(x, v) (HW_PCIE_PHY_TRSV_REG21_WR(x, (HW_PCIE_PHY_TRSV_REG21_RD(x) & ~BM_PCIE_PHY_TRSV_REG21_EMP_LVL) | BF_PCIE_PHY_TRSV_REG21_EMP_LVL(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_TRSV_REG21, field DRVR_PDH[7] (RW)
 *
 * Values:
 * - 0 - Default for PCIe
 * - 1 - Reduce Power consumption
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG21_DRVR_PDH (7U) /*!< Bit position for PCIE_PHY_TRSV_REG21_DRVR_PDH. */
#define BM_PCIE_PHY_TRSV_REG21_DRVR_PDH (0x00000080U) /*!< Bit mask for PCIE_PHY_TRSV_REG21_DRVR_PDH. */
#define BS_PCIE_PHY_TRSV_REG21_DRVR_PDH (1U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG21_DRVR_PDH. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG21_DRVR_PDH field. */
#define BR_PCIE_PHY_TRSV_REG21_DRVR_PDH(x) (HW_PCIE_PHY_TRSV_REG21(x).B.DRVR_PDH)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG21_DRVR_PDH. */
#define BF_PCIE_PHY_TRSV_REG21_DRVR_PDH(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG21_DRVR_PDH) & BM_PCIE_PHY_TRSV_REG21_DRVR_PDH)

/*! @brief Set the DRVR_PDH field to a new value. */
#define BW_PCIE_PHY_TRSV_REG21_DRVR_PDH(x, v) (HW_PCIE_PHY_TRSV_REG21_WR(x, (HW_PCIE_PHY_TRSV_REG21_RD(x) & ~BM_PCIE_PHY_TRSV_REG21_DRVR_PDH) | BF_PCIE_PHY_TRSV_REG21_DRVR_PDH(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_TRSV_REG22 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_TRSV_REG22 -  (RW)
 *
 * Reset value: 0x0000002AU
 */
typedef union _hw_pcie_phy_trsv_reg22
{
    uint32_t U;
    struct _hw_pcie_phy_trsv_reg22_bitfields
    {
        uint32_t DRV_LVL : 6;          /*!< [5:0] TX Differential Output
                                        * (PCIE_TX_P/PCIE_TX_N) Amplitude Control */
        uint32_t RESERVED0 : 26;       /*!< [31:6]  */
    } B;
} hw_pcie_phy_trsv_reg22_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_TRSV_REG22 register
 */
/*@{*/
#define HW_PCIE_PHY_TRSV_REG22_ADDR(x) ((uintptr_t)(x) + 0x88U)

#define HW_PCIE_PHY_TRSV_REG22(x) (*(__IO hw_pcie_phy_trsv_reg22_t *) HW_PCIE_PHY_TRSV_REG22_ADDR(x))
#define HW_PCIE_PHY_TRSV_REG22_RD(x) (HW_PCIE_PHY_TRSV_REG22(x).U)
#define HW_PCIE_PHY_TRSV_REG22_WR(x, v) (HW_PCIE_PHY_TRSV_REG22(x).U = (v))
#define HW_PCIE_PHY_TRSV_REG22_SET(x, v) (HW_PCIE_PHY_TRSV_REG22_WR(x, HW_PCIE_PHY_TRSV_REG22_RD(x) |  (v)))
#define HW_PCIE_PHY_TRSV_REG22_CLR(x, v) (HW_PCIE_PHY_TRSV_REG22_WR(x, HW_PCIE_PHY_TRSV_REG22_RD(x) & ~(v)))
#define HW_PCIE_PHY_TRSV_REG22_TOG(x, v) (HW_PCIE_PHY_TRSV_REG22_WR(x, HW_PCIE_PHY_TRSV_REG22_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_TRSV_REG22 bitfields
 */

/*!
 * @name Register PCIE_PHY_TRSV_REG22, field DRV_LVL[5:0] (RW)
 *
 * Values:
 * - 000000 - Minimum Swing
 * - 100000 - Default Swing for SATA
 * - 101010 - Default Swing for PCIe
 * - 111111 - Maximum Swing
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG22_DRV_LVL (0U) /*!< Bit position for PCIE_PHY_TRSV_REG22_DRV_LVL. */
#define BM_PCIE_PHY_TRSV_REG22_DRV_LVL (0x0000003FU) /*!< Bit mask for PCIE_PHY_TRSV_REG22_DRV_LVL. */
#define BS_PCIE_PHY_TRSV_REG22_DRV_LVL (6U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG22_DRV_LVL. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG22_DRV_LVL field. */
#define BR_PCIE_PHY_TRSV_REG22_DRV_LVL(x) (HW_PCIE_PHY_TRSV_REG22(x).B.DRV_LVL)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG22_DRV_LVL. */
#define BF_PCIE_PHY_TRSV_REG22_DRV_LVL(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG22_DRV_LVL) & BM_PCIE_PHY_TRSV_REG22_DRV_LVL)

/*! @brief Set the DRV_LVL field to a new value. */
#define BW_PCIE_PHY_TRSV_REG22_DRV_LVL(x, v) (HW_PCIE_PHY_TRSV_REG22_WR(x, (HW_PCIE_PHY_TRSV_REG22_RD(x) & ~BM_PCIE_PHY_TRSV_REG22_DRV_LVL) | BF_PCIE_PHY_TRSV_REG22_DRV_LVL(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_TRSV_REG24 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_TRSV_REG24 -  (RW)
 *
 * Reset value: 0x00000048U
 *
 * For the RX squelch detector threshold votlage, this threshold voltage can be
 * changed intentionally for debug purpose. In the noisy application, the
 * threshold voltage of squelch detector might be increased for better detection
 * although it could cause the violation in the specification. RX equalizer setting
 * might be changed to have better signal quality. For example, RX input jitter from
 * ISI (Inter Symbol Interference) can be improved with RX equalization feature.
 */
typedef union _hw_pcie_phy_trsv_reg24
{
    uint32_t U;
    struct _hw_pcie_phy_trsv_reg24_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t RX_EQ_SEL : 1;        /*!< [3] RX Equalizer Select Enable */
        uint32_t RX_SS : 2;            /*!< [5:4] RX Sense Control */
        uint32_t RX_EQS : 1;           /*!< [6] RX Equalizer Select */
        uint32_t RX_SS_PD : 1;         /*!< [7] RX Sense Powerdown */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_trsv_reg24_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_TRSV_REG24 register
 */
/*@{*/
#define HW_PCIE_PHY_TRSV_REG24_ADDR(x) ((uintptr_t)(x) + 0x96U)

#define HW_PCIE_PHY_TRSV_REG24(x) (*(__IO hw_pcie_phy_trsv_reg24_t *) HW_PCIE_PHY_TRSV_REG24_ADDR(x))
#define HW_PCIE_PHY_TRSV_REG24_RD(x) (HW_PCIE_PHY_TRSV_REG24(x).U)
#define HW_PCIE_PHY_TRSV_REG24_WR(x, v) (HW_PCIE_PHY_TRSV_REG24(x).U = (v))
#define HW_PCIE_PHY_TRSV_REG24_SET(x, v) (HW_PCIE_PHY_TRSV_REG24_WR(x, HW_PCIE_PHY_TRSV_REG24_RD(x) |  (v)))
#define HW_PCIE_PHY_TRSV_REG24_CLR(x, v) (HW_PCIE_PHY_TRSV_REG24_WR(x, HW_PCIE_PHY_TRSV_REG24_RD(x) & ~(v)))
#define HW_PCIE_PHY_TRSV_REG24_TOG(x, v) (HW_PCIE_PHY_TRSV_REG24_WR(x, HW_PCIE_PHY_TRSV_REG24_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_TRSV_REG24 bitfields
 */

/*!
 * @name Register PCIE_PHY_TRSV_REG24, field RX_EQ_SEL[3] (RW)
 *
 * Values:
 * - 0 -
 * - 1 - Manual: Default
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG24_RX_EQ_SEL (3U) /*!< Bit position for PCIE_PHY_TRSV_REG24_RX_EQ_SEL. */
#define BM_PCIE_PHY_TRSV_REG24_RX_EQ_SEL (0x00000008U) /*!< Bit mask for PCIE_PHY_TRSV_REG24_RX_EQ_SEL. */
#define BS_PCIE_PHY_TRSV_REG24_RX_EQ_SEL (1U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG24_RX_EQ_SEL. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG24_RX_EQ_SEL field. */
#define BR_PCIE_PHY_TRSV_REG24_RX_EQ_SEL(x) (HW_PCIE_PHY_TRSV_REG24(x).B.RX_EQ_SEL)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG24_RX_EQ_SEL. */
#define BF_PCIE_PHY_TRSV_REG24_RX_EQ_SEL(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG24_RX_EQ_SEL) & BM_PCIE_PHY_TRSV_REG24_RX_EQ_SEL)

/*! @brief Set the RX_EQ_SEL field to a new value. */
#define BW_PCIE_PHY_TRSV_REG24_RX_EQ_SEL(x, v) (HW_PCIE_PHY_TRSV_REG24_WR(x, (HW_PCIE_PHY_TRSV_REG24_RD(x) & ~BM_PCIE_PHY_TRSV_REG24_RX_EQ_SEL) | BF_PCIE_PHY_TRSV_REG24_RX_EQ_SEL(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_TRSV_REG24, field RX_SS[5:4] (RW)
 *
 * Values:
 * - 00 - Default
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG24_RX_SS (4U)  /*!< Bit position for PCIE_PHY_TRSV_REG24_RX_SS. */
#define BM_PCIE_PHY_TRSV_REG24_RX_SS (0x00000030U) /*!< Bit mask for PCIE_PHY_TRSV_REG24_RX_SS. */
#define BS_PCIE_PHY_TRSV_REG24_RX_SS (2U)  /*!< Bit field size in bits for PCIE_PHY_TRSV_REG24_RX_SS. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG24_RX_SS field. */
#define BR_PCIE_PHY_TRSV_REG24_RX_SS(x) (HW_PCIE_PHY_TRSV_REG24(x).B.RX_SS)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG24_RX_SS. */
#define BF_PCIE_PHY_TRSV_REG24_RX_SS(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG24_RX_SS) & BM_PCIE_PHY_TRSV_REG24_RX_SS)

/*! @brief Set the RX_SS field to a new value. */
#define BW_PCIE_PHY_TRSV_REG24_RX_SS(x, v) (HW_PCIE_PHY_TRSV_REG24_WR(x, (HW_PCIE_PHY_TRSV_REG24_RD(x) & ~BM_PCIE_PHY_TRSV_REG24_RX_SS) | BF_PCIE_PHY_TRSV_REG24_RX_SS(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_TRSV_REG24, field RX_EQS[6] (RW)
 *
 * Values:
 * - 0 -
 * - 1 - Default
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG24_RX_EQS (6U) /*!< Bit position for PCIE_PHY_TRSV_REG24_RX_EQS. */
#define BM_PCIE_PHY_TRSV_REG24_RX_EQS (0x00000040U) /*!< Bit mask for PCIE_PHY_TRSV_REG24_RX_EQS. */
#define BS_PCIE_PHY_TRSV_REG24_RX_EQS (1U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG24_RX_EQS. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG24_RX_EQS field. */
#define BR_PCIE_PHY_TRSV_REG24_RX_EQS(x) (HW_PCIE_PHY_TRSV_REG24(x).B.RX_EQS)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG24_RX_EQS. */
#define BF_PCIE_PHY_TRSV_REG24_RX_EQS(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG24_RX_EQS) & BM_PCIE_PHY_TRSV_REG24_RX_EQS)

/*! @brief Set the RX_EQS field to a new value. */
#define BW_PCIE_PHY_TRSV_REG24_RX_EQS(x, v) (HW_PCIE_PHY_TRSV_REG24_WR(x, (HW_PCIE_PHY_TRSV_REG24_RD(x) & ~BM_PCIE_PHY_TRSV_REG24_RX_EQS) | BF_PCIE_PHY_TRSV_REG24_RX_EQS(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_TRSV_REG24, field RX_SS_PD[7] (RW)
 *
 * Values:
 * - 0 - Default
 * - 1 - Powerdown for Sense
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG24_RX_SS_PD (7U) /*!< Bit position for PCIE_PHY_TRSV_REG24_RX_SS_PD. */
#define BM_PCIE_PHY_TRSV_REG24_RX_SS_PD (0x00000080U) /*!< Bit mask for PCIE_PHY_TRSV_REG24_RX_SS_PD. */
#define BS_PCIE_PHY_TRSV_REG24_RX_SS_PD (1U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG24_RX_SS_PD. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG24_RX_SS_PD field. */
#define BR_PCIE_PHY_TRSV_REG24_RX_SS_PD(x) (HW_PCIE_PHY_TRSV_REG24(x).B.RX_SS_PD)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG24_RX_SS_PD. */
#define BF_PCIE_PHY_TRSV_REG24_RX_SS_PD(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG24_RX_SS_PD) & BM_PCIE_PHY_TRSV_REG24_RX_SS_PD)

/*! @brief Set the RX_SS_PD field to a new value. */
#define BW_PCIE_PHY_TRSV_REG24_RX_SS_PD(x, v) (HW_PCIE_PHY_TRSV_REG24_WR(x, (HW_PCIE_PHY_TRSV_REG24_RD(x) & ~BM_PCIE_PHY_TRSV_REG24_RX_SS_PD) | BF_PCIE_PHY_TRSV_REG24_RX_SS_PD(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_TRSV_REG2B -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_TRSV_REG2B -  (RW)
 *
 * Reset value: 0x00000081U
 */
typedef union _hw_pcie_phy_trsv_reg2b
{
    uint32_t U;
    struct _hw_pcie_phy_trsv_reg2b_bitfields
    {
        uint32_t RXCDR : 4;            /*!< [3:0] RX CDR BW Control */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_pcie_phy_trsv_reg2b_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_TRSV_REG2B register
 */
/*@{*/
#define HW_PCIE_PHY_TRSV_REG2B_ADDR(x) ((uintptr_t)(x) + 0xACU)

#define HW_PCIE_PHY_TRSV_REG2B(x) (*(__IO hw_pcie_phy_trsv_reg2b_t *) HW_PCIE_PHY_TRSV_REG2B_ADDR(x))
#define HW_PCIE_PHY_TRSV_REG2B_RD(x) (HW_PCIE_PHY_TRSV_REG2B(x).U)
#define HW_PCIE_PHY_TRSV_REG2B_WR(x, v) (HW_PCIE_PHY_TRSV_REG2B(x).U = (v))
#define HW_PCIE_PHY_TRSV_REG2B_SET(x, v) (HW_PCIE_PHY_TRSV_REG2B_WR(x, HW_PCIE_PHY_TRSV_REG2B_RD(x) |  (v)))
#define HW_PCIE_PHY_TRSV_REG2B_CLR(x, v) (HW_PCIE_PHY_TRSV_REG2B_WR(x, HW_PCIE_PHY_TRSV_REG2B_RD(x) & ~(v)))
#define HW_PCIE_PHY_TRSV_REG2B_TOG(x, v) (HW_PCIE_PHY_TRSV_REG2B_WR(x, HW_PCIE_PHY_TRSV_REG2B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_TRSV_REG2B bitfields
 */

/*!
 * @name Register PCIE_PHY_TRSV_REG2B, field RXCDR[3:0] (RW)
 *
 * RX CDR(Clock and data recovery) BW(bandwidth) can be adjusted using
 * RXCDR[7:0], however do not change it. It may cause the performance degradation and can
 * not guarantee the operation.
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG2B_RXCDR (0U)  /*!< Bit position for PCIE_PHY_TRSV_REG2B_RXCDR. */
#define BM_PCIE_PHY_TRSV_REG2B_RXCDR (0x0000000FU) /*!< Bit mask for PCIE_PHY_TRSV_REG2B_RXCDR. */
#define BS_PCIE_PHY_TRSV_REG2B_RXCDR (4U)  /*!< Bit field size in bits for PCIE_PHY_TRSV_REG2B_RXCDR. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG2B_RXCDR field. */
#define BR_PCIE_PHY_TRSV_REG2B_RXCDR(x) (HW_PCIE_PHY_TRSV_REG2B(x).B.RXCDR)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG2B_RXCDR. */
#define BF_PCIE_PHY_TRSV_REG2B_RXCDR(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG2B_RXCDR) & BM_PCIE_PHY_TRSV_REG2B_RXCDR)

/*! @brief Set the RXCDR field to a new value. */
#define BW_PCIE_PHY_TRSV_REG2B_RXCDR(x, v) (HW_PCIE_PHY_TRSV_REG2B_WR(x, (HW_PCIE_PHY_TRSV_REG2B_RD(x) & ~BM_PCIE_PHY_TRSV_REG2B_RXCDR) | BF_PCIE_PHY_TRSV_REG2B_RXCDR(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_TRSV_REG3A -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_TRSV_REG3A -  (RW)
 *
 * Reset value: 0x00000008U
 *
 * This register can be used for the serial data (PCIE_TX_P / PCIE_TX_N or
 * PCIE_RX_P / PCIE_RX_N) polarity inversion. Some cases, if high-speed signal pins
 * are twisted or connected through vias, using this polarity. TX and RX parallel
 * data also can have bit and / or byte order change to be flexible with
 * connection errors between the PHY and the LINK controller.
 */
typedef union _hw_pcie_phy_trsv_reg3a
{
    uint32_t U;
    struct _hw_pcie_phy_trsv_reg3a_bitfields
    {
        uint32_t TDIMODE : 1;          /*!< [0] TX BitWidth Select */
        uint32_t RDIMODE : 1;          /*!< [1] RX BitWidth Select */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t COMDET_EN : 1;        /*!< [3] Comma Detection Enable */
        uint32_t RESERVED1 : 28;       /*!< [31:4]  */
    } B;
} hw_pcie_phy_trsv_reg3a_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_TRSV_REG3A register
 */
/*@{*/
#define HW_PCIE_PHY_TRSV_REG3A_ADDR(x) ((uintptr_t)(x) + 0xE8U)

#define HW_PCIE_PHY_TRSV_REG3A(x) (*(__IO hw_pcie_phy_trsv_reg3a_t *) HW_PCIE_PHY_TRSV_REG3A_ADDR(x))
#define HW_PCIE_PHY_TRSV_REG3A_RD(x) (HW_PCIE_PHY_TRSV_REG3A(x).U)
#define HW_PCIE_PHY_TRSV_REG3A_WR(x, v) (HW_PCIE_PHY_TRSV_REG3A(x).U = (v))
#define HW_PCIE_PHY_TRSV_REG3A_SET(x, v) (HW_PCIE_PHY_TRSV_REG3A_WR(x, HW_PCIE_PHY_TRSV_REG3A_RD(x) |  (v)))
#define HW_PCIE_PHY_TRSV_REG3A_CLR(x, v) (HW_PCIE_PHY_TRSV_REG3A_WR(x, HW_PCIE_PHY_TRSV_REG3A_RD(x) & ~(v)))
#define HW_PCIE_PHY_TRSV_REG3A_TOG(x, v) (HW_PCIE_PHY_TRSV_REG3A_WR(x, HW_PCIE_PHY_TRSV_REG3A_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_TRSV_REG3A bitfields
 */

/*!
 * @name Register PCIE_PHY_TRSV_REG3A, field TDIMODE[0] (RW)
 *
 * Values:
 * - 0 - 20-bit Mode (Default)
 * - 1 - 40-bit Mode
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG3A_TDIMODE (0U) /*!< Bit position for PCIE_PHY_TRSV_REG3A_TDIMODE. */
#define BM_PCIE_PHY_TRSV_REG3A_TDIMODE (0x00000001U) /*!< Bit mask for PCIE_PHY_TRSV_REG3A_TDIMODE. */
#define BS_PCIE_PHY_TRSV_REG3A_TDIMODE (1U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG3A_TDIMODE. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG3A_TDIMODE field. */
#define BR_PCIE_PHY_TRSV_REG3A_TDIMODE(x) (HW_PCIE_PHY_TRSV_REG3A(x).B.TDIMODE)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG3A_TDIMODE. */
#define BF_PCIE_PHY_TRSV_REG3A_TDIMODE(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG3A_TDIMODE) & BM_PCIE_PHY_TRSV_REG3A_TDIMODE)

/*! @brief Set the TDIMODE field to a new value. */
#define BW_PCIE_PHY_TRSV_REG3A_TDIMODE(x, v) (HW_PCIE_PHY_TRSV_REG3A_WR(x, (HW_PCIE_PHY_TRSV_REG3A_RD(x) & ~BM_PCIE_PHY_TRSV_REG3A_TDIMODE) | BF_PCIE_PHY_TRSV_REG3A_TDIMODE(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_TRSV_REG3A, field RDIMODE[1] (RW)
 *
 * Values:
 * - 0 - 20-bit Mode (Default)
 * - 1 - 40-bit Mode
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG3A_RDIMODE (1U) /*!< Bit position for PCIE_PHY_TRSV_REG3A_RDIMODE. */
#define BM_PCIE_PHY_TRSV_REG3A_RDIMODE (0x00000002U) /*!< Bit mask for PCIE_PHY_TRSV_REG3A_RDIMODE. */
#define BS_PCIE_PHY_TRSV_REG3A_RDIMODE (1U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG3A_RDIMODE. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG3A_RDIMODE field. */
#define BR_PCIE_PHY_TRSV_REG3A_RDIMODE(x) (HW_PCIE_PHY_TRSV_REG3A(x).B.RDIMODE)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG3A_RDIMODE. */
#define BF_PCIE_PHY_TRSV_REG3A_RDIMODE(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG3A_RDIMODE) & BM_PCIE_PHY_TRSV_REG3A_RDIMODE)

/*! @brief Set the RDIMODE field to a new value. */
#define BW_PCIE_PHY_TRSV_REG3A_RDIMODE(x, v) (HW_PCIE_PHY_TRSV_REG3A_WR(x, (HW_PCIE_PHY_TRSV_REG3A_RD(x) & ~BM_PCIE_PHY_TRSV_REG3A_RDIMODE) | BF_PCIE_PHY_TRSV_REG3A_RDIMODE(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_TRSV_REG3A, field COMDET_EN[3] (RW)
 *
 * When COMDET_EN is "low", RXD[0:19] is not aligned for debug purpose.When
 * ADD_ALIGN is asserted (ADD_ALIGN = 1), ALIGNp is added during the pattern
 * generation in BIST mode.
 *
 * Values:
 * - 0 - Comma Detection Disable
 * - 1 - Comma Detection Enable (Default)
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG3A_COMDET_EN (3U) /*!< Bit position for PCIE_PHY_TRSV_REG3A_COMDET_EN. */
#define BM_PCIE_PHY_TRSV_REG3A_COMDET_EN (0x00000008U) /*!< Bit mask for PCIE_PHY_TRSV_REG3A_COMDET_EN. */
#define BS_PCIE_PHY_TRSV_REG3A_COMDET_EN (1U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG3A_COMDET_EN. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG3A_COMDET_EN field. */
#define BR_PCIE_PHY_TRSV_REG3A_COMDET_EN(x) (HW_PCIE_PHY_TRSV_REG3A(x).B.COMDET_EN)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG3A_COMDET_EN. */
#define BF_PCIE_PHY_TRSV_REG3A_COMDET_EN(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG3A_COMDET_EN) & BM_PCIE_PHY_TRSV_REG3A_COMDET_EN)

/*! @brief Set the COMDET_EN field to a new value. */
#define BW_PCIE_PHY_TRSV_REG3A_COMDET_EN(x, v) (HW_PCIE_PHY_TRSV_REG3A_WR(x, (HW_PCIE_PHY_TRSV_REG3A_RD(x) & ~BM_PCIE_PHY_TRSV_REG3A_COMDET_EN) | BF_PCIE_PHY_TRSV_REG3A_COMDET_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_TRSV_REG3E -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_TRSV_REG3E -  (RW)
 *
 * Reset value: 0x00000004U
 */
typedef union _hw_pcie_phy_trsv_reg3e
{
    uint32_t U;
    struct _hw_pcie_phy_trsv_reg3e_bitfields
    {
        uint32_t DET_CNT : 4;          /*!< [3:0] RX Detection Control */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_pcie_phy_trsv_reg3e_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_TRSV_REG3E register
 */
/*@{*/
#define HW_PCIE_PHY_TRSV_REG3E_ADDR(x) ((uintptr_t)(x) + 0xF8U)

#define HW_PCIE_PHY_TRSV_REG3E(x) (*(__IO hw_pcie_phy_trsv_reg3e_t *) HW_PCIE_PHY_TRSV_REG3E_ADDR(x))
#define HW_PCIE_PHY_TRSV_REG3E_RD(x) (HW_PCIE_PHY_TRSV_REG3E(x).U)
#define HW_PCIE_PHY_TRSV_REG3E_WR(x, v) (HW_PCIE_PHY_TRSV_REG3E(x).U = (v))
#define HW_PCIE_PHY_TRSV_REG3E_SET(x, v) (HW_PCIE_PHY_TRSV_REG3E_WR(x, HW_PCIE_PHY_TRSV_REG3E_RD(x) |  (v)))
#define HW_PCIE_PHY_TRSV_REG3E_CLR(x, v) (HW_PCIE_PHY_TRSV_REG3E_WR(x, HW_PCIE_PHY_TRSV_REG3E_RD(x) & ~(v)))
#define HW_PCIE_PHY_TRSV_REG3E_TOG(x, v) (HW_PCIE_PHY_TRSV_REG3E_WR(x, HW_PCIE_PHY_TRSV_REG3E_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_TRSV_REG3E bitfields
 */

/*!
 * @name Register PCIE_PHY_TRSV_REG3E, field DET_CNT[3:0] (RW)
 *
 * For the DET_CNT[3:0], the number of K28.5 detection for RX_VALID can be
 * changed.
 *
 * Values:
 * - 0000 - No detection
 * - 0100 - Four K28.5 detection (Default)
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG3E_DET_CNT (0U) /*!< Bit position for PCIE_PHY_TRSV_REG3E_DET_CNT. */
#define BM_PCIE_PHY_TRSV_REG3E_DET_CNT (0x0000000FU) /*!< Bit mask for PCIE_PHY_TRSV_REG3E_DET_CNT. */
#define BS_PCIE_PHY_TRSV_REG3E_DET_CNT (4U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG3E_DET_CNT. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG3E_DET_CNT field. */
#define BR_PCIE_PHY_TRSV_REG3E_DET_CNT(x) (HW_PCIE_PHY_TRSV_REG3E(x).B.DET_CNT)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG3E_DET_CNT. */
#define BF_PCIE_PHY_TRSV_REG3E_DET_CNT(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG3E_DET_CNT) & BM_PCIE_PHY_TRSV_REG3E_DET_CNT)

/*! @brief Set the DET_CNT field to a new value. */
#define BW_PCIE_PHY_TRSV_REG3E_DET_CNT(x, v) (HW_PCIE_PHY_TRSV_REG3E_WR(x, (HW_PCIE_PHY_TRSV_REG3E_RD(x) & ~BM_PCIE_PHY_TRSV_REG3E_DET_CNT) | BF_PCIE_PHY_TRSV_REG3E_DET_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_TRSV_REG25 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_TRSV_REG25 -  (RW)
 *
 * Reset value: 0x00000042U
 *
 * For the RX squelch detector threshold votlage, this threshold voltage can be
 * changed intentionally for debug purpose. In the noisy application, the
 * threshold voltage of squelch detector might be increased for better detection
 * although it could cause the violation in the specification. RX equalizer setting
 * might be changed to have better signal quality. For example, RX input jitter from
 * ISI (Inter Symbol Interference) can be improved with RX equalization feature.
 */
typedef union _hw_pcie_phy_trsv_reg25
{
    uint32_t U;
    struct _hw_pcie_phy_trsv_reg25_bitfields
    {
        uint32_t RXEQS : 3;            /*!< [2:0] RX Equalizer Setting */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t RXEQ : 4;             /*!< [7:4] RX Equalizer Control */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_trsv_reg25_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_TRSV_REG25 register
 */
/*@{*/
#define HW_PCIE_PHY_TRSV_REG25_ADDR(x) ((uintptr_t)(x) + 0x100U)

#define HW_PCIE_PHY_TRSV_REG25(x) (*(__IO hw_pcie_phy_trsv_reg25_t *) HW_PCIE_PHY_TRSV_REG25_ADDR(x))
#define HW_PCIE_PHY_TRSV_REG25_RD(x) (HW_PCIE_PHY_TRSV_REG25(x).U)
#define HW_PCIE_PHY_TRSV_REG25_WR(x, v) (HW_PCIE_PHY_TRSV_REG25(x).U = (v))
#define HW_PCIE_PHY_TRSV_REG25_SET(x, v) (HW_PCIE_PHY_TRSV_REG25_WR(x, HW_PCIE_PHY_TRSV_REG25_RD(x) |  (v)))
#define HW_PCIE_PHY_TRSV_REG25_CLR(x, v) (HW_PCIE_PHY_TRSV_REG25_WR(x, HW_PCIE_PHY_TRSV_REG25_RD(x) & ~(v)))
#define HW_PCIE_PHY_TRSV_REG25_TOG(x, v) (HW_PCIE_PHY_TRSV_REG25_WR(x, HW_PCIE_PHY_TRSV_REG25_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_TRSV_REG25 bitfields
 */

/*!
 * @name Register PCIE_PHY_TRSV_REG25, field RXEQS[2:0] (RW)
 *
 * Values:
 * - 0100 - Default
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG25_RXEQS (0U)  /*!< Bit position for PCIE_PHY_TRSV_REG25_RXEQS. */
#define BM_PCIE_PHY_TRSV_REG25_RXEQS (0x00000007U) /*!< Bit mask for PCIE_PHY_TRSV_REG25_RXEQS. */
#define BS_PCIE_PHY_TRSV_REG25_RXEQS (3U)  /*!< Bit field size in bits for PCIE_PHY_TRSV_REG25_RXEQS. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG25_RXEQS field. */
#define BR_PCIE_PHY_TRSV_REG25_RXEQS(x) (HW_PCIE_PHY_TRSV_REG25(x).B.RXEQS)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG25_RXEQS. */
#define BF_PCIE_PHY_TRSV_REG25_RXEQS(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG25_RXEQS) & BM_PCIE_PHY_TRSV_REG25_RXEQS)

/*! @brief Set the RXEQS field to a new value. */
#define BW_PCIE_PHY_TRSV_REG25_RXEQS(x, v) (HW_PCIE_PHY_TRSV_REG25_WR(x, (HW_PCIE_PHY_TRSV_REG25_RD(x) & ~BM_PCIE_PHY_TRSV_REG25_RXEQS) | BF_PCIE_PHY_TRSV_REG25_RXEQS(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_TRSV_REG25, field RXEQ[7:4] (RW)
 *
 * Values:
 * - 0100 - Default
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG25_RXEQ (4U)   /*!< Bit position for PCIE_PHY_TRSV_REG25_RXEQ. */
#define BM_PCIE_PHY_TRSV_REG25_RXEQ (0x000000F0U) /*!< Bit mask for PCIE_PHY_TRSV_REG25_RXEQ. */
#define BS_PCIE_PHY_TRSV_REG25_RXEQ (4U)   /*!< Bit field size in bits for PCIE_PHY_TRSV_REG25_RXEQ. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG25_RXEQ field. */
#define BR_PCIE_PHY_TRSV_REG25_RXEQ(x) (HW_PCIE_PHY_TRSV_REG25(x).B.RXEQ)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG25_RXEQ. */
#define BF_PCIE_PHY_TRSV_REG25_RXEQ(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG25_RXEQ) & BM_PCIE_PHY_TRSV_REG25_RXEQ)

/*! @brief Set the RXEQ field to a new value. */
#define BW_PCIE_PHY_TRSV_REG25_RXEQ(x, v) (HW_PCIE_PHY_TRSV_REG25_WR(x, (HW_PCIE_PHY_TRSV_REG25_RD(x) & ~BM_PCIE_PHY_TRSV_REG25_RXEQ) | BF_PCIE_PHY_TRSV_REG25_RXEQ(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_TRSV_REG26 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_TRSV_REG26 -  (RW)
 *
 * Reset value: 0x000000BCU
 */
typedef union _hw_pcie_phy_trsv_reg26
{
    uint32_t U;
    struct _hw_pcie_phy_trsv_reg26_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t SQTH : 3;             /*!< [6:4] RX Squelch Detect Threshold Control */
        uint32_t RESERVED1 : 25;       /*!< [31:7]  */
    } B;
} hw_pcie_phy_trsv_reg26_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_TRSV_REG26 register
 */
/*@{*/
#define HW_PCIE_PHY_TRSV_REG26_ADDR(x) ((uintptr_t)(x) + 0x104U)

#define HW_PCIE_PHY_TRSV_REG26(x) (*(__IO hw_pcie_phy_trsv_reg26_t *) HW_PCIE_PHY_TRSV_REG26_ADDR(x))
#define HW_PCIE_PHY_TRSV_REG26_RD(x) (HW_PCIE_PHY_TRSV_REG26(x).U)
#define HW_PCIE_PHY_TRSV_REG26_WR(x, v) (HW_PCIE_PHY_TRSV_REG26(x).U = (v))
#define HW_PCIE_PHY_TRSV_REG26_SET(x, v) (HW_PCIE_PHY_TRSV_REG26_WR(x, HW_PCIE_PHY_TRSV_REG26_RD(x) |  (v)))
#define HW_PCIE_PHY_TRSV_REG26_CLR(x, v) (HW_PCIE_PHY_TRSV_REG26_WR(x, HW_PCIE_PHY_TRSV_REG26_RD(x) & ~(v)))
#define HW_PCIE_PHY_TRSV_REG26_TOG(x, v) (HW_PCIE_PHY_TRSV_REG26_WR(x, HW_PCIE_PHY_TRSV_REG26_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_TRSV_REG26 bitfields
 */

/*!
 * @name Register PCIE_PHY_TRSV_REG26, field SQTH[6:4] (RW)
 *
 * Values:
 * - 000 - Min threshold
 * - 011 - Default threshold voltage of squelch detect
 * - 111 - Max threshold
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG26_SQTH (4U)   /*!< Bit position for PCIE_PHY_TRSV_REG26_SQTH. */
#define BM_PCIE_PHY_TRSV_REG26_SQTH (0x00000070U) /*!< Bit mask for PCIE_PHY_TRSV_REG26_SQTH. */
#define BS_PCIE_PHY_TRSV_REG26_SQTH (3U)   /*!< Bit field size in bits for PCIE_PHY_TRSV_REG26_SQTH. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG26_SQTH field. */
#define BR_PCIE_PHY_TRSV_REG26_SQTH(x) (HW_PCIE_PHY_TRSV_REG26(x).B.SQTH)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG26_SQTH. */
#define BF_PCIE_PHY_TRSV_REG26_SQTH(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG26_SQTH) & BM_PCIE_PHY_TRSV_REG26_SQTH)

/*! @brief Set the SQTH field to a new value. */
#define BW_PCIE_PHY_TRSV_REG26_SQTH(x, v) (HW_PCIE_PHY_TRSV_REG26_WR(x, (HW_PCIE_PHY_TRSV_REG26_RD(x) & ~BM_PCIE_PHY_TRSV_REG26_SQTH) | BF_PCIE_PHY_TRSV_REG26_SQTH(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_TRSV_REG29 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_TRSV_REG29 -  (RW)
 *
 * Reset value: 0x0000000CU
 */
typedef union _hw_pcie_phy_trsv_reg29
{
    uint32_t U;
    struct _hw_pcie_phy_trsv_reg29_bitfields
    {
        uint32_t BIAS : 8;             /*!< [7:0] TRSV Bias Current Control */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_trsv_reg29_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_TRSV_REG29 register
 */
/*@{*/
#define HW_PCIE_PHY_TRSV_REG29_ADDR(x) ((uintptr_t)(x) + 0x116U)

#define HW_PCIE_PHY_TRSV_REG29(x) (*(__IO hw_pcie_phy_trsv_reg29_t *) HW_PCIE_PHY_TRSV_REG29_ADDR(x))
#define HW_PCIE_PHY_TRSV_REG29_RD(x) (HW_PCIE_PHY_TRSV_REG29(x).U)
#define HW_PCIE_PHY_TRSV_REG29_WR(x, v) (HW_PCIE_PHY_TRSV_REG29(x).U = (v))
#define HW_PCIE_PHY_TRSV_REG29_SET(x, v) (HW_PCIE_PHY_TRSV_REG29_WR(x, HW_PCIE_PHY_TRSV_REG29_RD(x) |  (v)))
#define HW_PCIE_PHY_TRSV_REG29_CLR(x, v) (HW_PCIE_PHY_TRSV_REG29_WR(x, HW_PCIE_PHY_TRSV_REG29_RD(x) & ~(v)))
#define HW_PCIE_PHY_TRSV_REG29_TOG(x, v) (HW_PCIE_PHY_TRSV_REG29_WR(x, HW_PCIE_PHY_TRSV_REG29_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_TRSV_REG29 bitfields
 */

/*!
 * @name Register PCIE_PHY_TRSV_REG29, field BIAS[7:0] (RW)
 *
 * Values:
 * - 00000100 - Default for SATA
 * - 00001100 - Default for PCIe
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG29_BIAS (0U)   /*!< Bit position for PCIE_PHY_TRSV_REG29_BIAS. */
#define BM_PCIE_PHY_TRSV_REG29_BIAS (0x000000FFU) /*!< Bit mask for PCIE_PHY_TRSV_REG29_BIAS. */
#define BS_PCIE_PHY_TRSV_REG29_BIAS (8U)   /*!< Bit field size in bits for PCIE_PHY_TRSV_REG29_BIAS. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG29_BIAS field. */
#define BR_PCIE_PHY_TRSV_REG29_BIAS(x) (HW_PCIE_PHY_TRSV_REG29(x).B.BIAS)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG29_BIAS. */
#define BF_PCIE_PHY_TRSV_REG29_BIAS(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG29_BIAS) & BM_PCIE_PHY_TRSV_REG29_BIAS)

/*! @brief Set the BIAS field to a new value. */
#define BW_PCIE_PHY_TRSV_REG29_BIAS(x, v) (HW_PCIE_PHY_TRSV_REG29_WR(x, (HW_PCIE_PHY_TRSV_REG29_RD(x) & ~BM_PCIE_PHY_TRSV_REG29_BIAS) | BF_PCIE_PHY_TRSV_REG29_BIAS(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_TRSV_REG31 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_TRSV_REG31 -  (RW)
 *
 * Reset value: 0x00000035U
 */
typedef union _hw_pcie_phy_trsv_reg31
{
    uint32_t U;
    struct _hw_pcie_phy_trsv_reg31_bitfields
    {
        uint32_t RESERVED0 : 7;        /*!< [6:0]  */
        uint32_t PD_TSV : 1;           /*!< [7] Transceiver Block All Powerdown Enable
                                        * */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_trsv_reg31_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_TRSV_REG31 register
 */
/*@{*/
#define HW_PCIE_PHY_TRSV_REG31_ADDR(x) ((uintptr_t)(x) + 0x124U)

#define HW_PCIE_PHY_TRSV_REG31(x) (*(__IO hw_pcie_phy_trsv_reg31_t *) HW_PCIE_PHY_TRSV_REG31_ADDR(x))
#define HW_PCIE_PHY_TRSV_REG31_RD(x) (HW_PCIE_PHY_TRSV_REG31(x).U)
#define HW_PCIE_PHY_TRSV_REG31_WR(x, v) (HW_PCIE_PHY_TRSV_REG31(x).U = (v))
#define HW_PCIE_PHY_TRSV_REG31_SET(x, v) (HW_PCIE_PHY_TRSV_REG31_WR(x, HW_PCIE_PHY_TRSV_REG31_RD(x) |  (v)))
#define HW_PCIE_PHY_TRSV_REG31_CLR(x, v) (HW_PCIE_PHY_TRSV_REG31_WR(x, HW_PCIE_PHY_TRSV_REG31_RD(x) & ~(v)))
#define HW_PCIE_PHY_TRSV_REG31_TOG(x, v) (HW_PCIE_PHY_TRSV_REG31_WR(x, HW_PCIE_PHY_TRSV_REG31_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_TRSV_REG31 bitfields
 */

/*!
 * @name Register PCIE_PHY_TRSV_REG31, field PD_TSV[7] (RW)
 *
 * Values:
 * - 0 - Transceiver Block powerdown disable
 * - 1 - Transceiver Block powerdown enable
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG31_PD_TSV (7U) /*!< Bit position for PCIE_PHY_TRSV_REG31_PD_TSV. */
#define BM_PCIE_PHY_TRSV_REG31_PD_TSV (0x00000080U) /*!< Bit mask for PCIE_PHY_TRSV_REG31_PD_TSV. */
#define BS_PCIE_PHY_TRSV_REG31_PD_TSV (1U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG31_PD_TSV. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG31_PD_TSV field. */
#define BR_PCIE_PHY_TRSV_REG31_PD_TSV(x) (HW_PCIE_PHY_TRSV_REG31(x).B.PD_TSV)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG31_PD_TSV. */
#define BF_PCIE_PHY_TRSV_REG31_PD_TSV(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG31_PD_TSV) & BM_PCIE_PHY_TRSV_REG31_PD_TSV)

/*! @brief Set the PD_TSV field to a new value. */
#define BW_PCIE_PHY_TRSV_REG31_PD_TSV(x, v) (HW_PCIE_PHY_TRSV_REG31_WR(x, (HW_PCIE_PHY_TRSV_REG31_RD(x) & ~BM_PCIE_PHY_TRSV_REG31_PD_TSV) | BF_PCIE_PHY_TRSV_REG31_PD_TSV(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_TRSV_REG33 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_TRSV_REG33 -  (RO)
 *
 * Reset value: 0x00000020U
 */
typedef union _hw_pcie_phy_trsv_reg33
{
    uint32_t U;
    struct _hw_pcie_phy_trsv_reg33_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_pcie_phy_trsv_reg33_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_TRSV_REG33 register
 */
/*@{*/
#define HW_PCIE_PHY_TRSV_REG33_ADDR(x) ((uintptr_t)(x) + 0x132U)

#define HW_PCIE_PHY_TRSV_REG33(x) (*(__I hw_pcie_phy_trsv_reg33_t *) HW_PCIE_PHY_TRSV_REG33_ADDR(x))
#define HW_PCIE_PHY_TRSV_REG33_RD(x) (HW_PCIE_PHY_TRSV_REG33(x).U)
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_TRSV_REG33 bitfields
 */

/*******************************************************************************
 * HW_PCIE_PHY_TRSV_REG36 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_TRSV_REG36 -  (RW)
 *
 * Reset value: 0x000000B0U
 */
typedef union _hw_pcie_phy_trsv_reg36
{
    uint32_t U;
    struct _hw_pcie_phy_trsv_reg36_bitfields
    {
        uint32_t SR_LVL : 3;           /*!< [2:0] TX Slew-rate Control */
        uint32_t TX_SWING : 1;         /*!< [3] TX Driver Control */
        uint32_t DRVR_CNT : 2;         /*!< [5:4] TX Driver Common Mode Control */
        uint32_t RESERVED0 : 26;       /*!< [31:6]  */
    } B;
} hw_pcie_phy_trsv_reg36_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_TRSV_REG36 register
 */
/*@{*/
#define HW_PCIE_PHY_TRSV_REG36_ADDR(x) ((uintptr_t)(x) + 0x144U)

#define HW_PCIE_PHY_TRSV_REG36(x) (*(__IO hw_pcie_phy_trsv_reg36_t *) HW_PCIE_PHY_TRSV_REG36_ADDR(x))
#define HW_PCIE_PHY_TRSV_REG36_RD(x) (HW_PCIE_PHY_TRSV_REG36(x).U)
#define HW_PCIE_PHY_TRSV_REG36_WR(x, v) (HW_PCIE_PHY_TRSV_REG36(x).U = (v))
#define HW_PCIE_PHY_TRSV_REG36_SET(x, v) (HW_PCIE_PHY_TRSV_REG36_WR(x, HW_PCIE_PHY_TRSV_REG36_RD(x) |  (v)))
#define HW_PCIE_PHY_TRSV_REG36_CLR(x, v) (HW_PCIE_PHY_TRSV_REG36_WR(x, HW_PCIE_PHY_TRSV_REG36_RD(x) & ~(v)))
#define HW_PCIE_PHY_TRSV_REG36_TOG(x, v) (HW_PCIE_PHY_TRSV_REG36_WR(x, HW_PCIE_PHY_TRSV_REG36_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_TRSV_REG36 bitfields
 */

/*!
 * @name Register PCIE_PHY_TRSV_REG36, field SR_LVL[2:0] (RW)
 *
 * Values:
 * - 000 - Default (~ 60 pS)
 * - 001 - ~ 90 pS
 * - 010 - ~ 120 pS
 * - 011 - ~ 150 pS
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG36_SR_LVL (0U) /*!< Bit position for PCIE_PHY_TRSV_REG36_SR_LVL. */
#define BM_PCIE_PHY_TRSV_REG36_SR_LVL (0x00000007U) /*!< Bit mask for PCIE_PHY_TRSV_REG36_SR_LVL. */
#define BS_PCIE_PHY_TRSV_REG36_SR_LVL (3U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG36_SR_LVL. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG36_SR_LVL field. */
#define BR_PCIE_PHY_TRSV_REG36_SR_LVL(x) (HW_PCIE_PHY_TRSV_REG36(x).B.SR_LVL)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG36_SR_LVL. */
#define BF_PCIE_PHY_TRSV_REG36_SR_LVL(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG36_SR_LVL) & BM_PCIE_PHY_TRSV_REG36_SR_LVL)

/*! @brief Set the SR_LVL field to a new value. */
#define BW_PCIE_PHY_TRSV_REG36_SR_LVL(x, v) (HW_PCIE_PHY_TRSV_REG36_WR(x, (HW_PCIE_PHY_TRSV_REG36_RD(x) & ~BM_PCIE_PHY_TRSV_REG36_SR_LVL) | BF_PCIE_PHY_TRSV_REG36_SR_LVL(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_TRSV_REG36, field TX_SWING[3] (RW)
 *
 * TX swing level can be changed according to the TX de-emphasis level control
 * setting. TX voltage swing unit step is different. TX swing specification may be
 * changed because of PVT variation. If you reduce TX swing, TX IO power
 * consumption would be also reduced proportionally. If the PHY is connected through a
 * long cable, you had better large swing setting because of the loss in the
 * channel. For the Compliance test, the test point should checked first and sometimes
 * the de- embedding of cable and/or PCB trace might be needed.
 *
 * Values:
 * - 0 - Full-swing (Default)
 * - 1 - Half-swing
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG36_TX_SWING (3U) /*!< Bit position for PCIE_PHY_TRSV_REG36_TX_SWING. */
#define BM_PCIE_PHY_TRSV_REG36_TX_SWING (0x00000008U) /*!< Bit mask for PCIE_PHY_TRSV_REG36_TX_SWING. */
#define BS_PCIE_PHY_TRSV_REG36_TX_SWING (1U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG36_TX_SWING. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG36_TX_SWING field. */
#define BR_PCIE_PHY_TRSV_REG36_TX_SWING(x) (HW_PCIE_PHY_TRSV_REG36(x).B.TX_SWING)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG36_TX_SWING. */
#define BF_PCIE_PHY_TRSV_REG36_TX_SWING(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG36_TX_SWING) & BM_PCIE_PHY_TRSV_REG36_TX_SWING)

/*! @brief Set the TX_SWING field to a new value. */
#define BW_PCIE_PHY_TRSV_REG36_TX_SWING(x, v) (HW_PCIE_PHY_TRSV_REG36_WR(x, (HW_PCIE_PHY_TRSV_REG36_RD(x) & ~BM_PCIE_PHY_TRSV_REG36_TX_SWING) | BF_PCIE_PHY_TRSV_REG36_TX_SWING(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_TRSV_REG36, field DRVR_CNT[5:4] (RW)
 *
 * Values:
 * - 00 - Default for SATA
 * - 11 - Default for PCIe
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG36_DRVR_CNT (4U) /*!< Bit position for PCIE_PHY_TRSV_REG36_DRVR_CNT. */
#define BM_PCIE_PHY_TRSV_REG36_DRVR_CNT (0x00000030U) /*!< Bit mask for PCIE_PHY_TRSV_REG36_DRVR_CNT. */
#define BS_PCIE_PHY_TRSV_REG36_DRVR_CNT (2U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG36_DRVR_CNT. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG36_DRVR_CNT field. */
#define BR_PCIE_PHY_TRSV_REG36_DRVR_CNT(x) (HW_PCIE_PHY_TRSV_REG36(x).B.DRVR_CNT)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG36_DRVR_CNT. */
#define BF_PCIE_PHY_TRSV_REG36_DRVR_CNT(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG36_DRVR_CNT) & BM_PCIE_PHY_TRSV_REG36_DRVR_CNT)

/*! @brief Set the DRVR_CNT field to a new value. */
#define BW_PCIE_PHY_TRSV_REG36_DRVR_CNT(x, v) (HW_PCIE_PHY_TRSV_REG36_WR(x, (HW_PCIE_PHY_TRSV_REG36_RD(x) & ~BM_PCIE_PHY_TRSV_REG36_DRVR_CNT) | BF_PCIE_PHY_TRSV_REG36_DRVR_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_TRSV_REG37 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_TRSV_REG37 -  (RO)
 *
 * Reset value: 0x000000A0U
 */
typedef union _hw_pcie_phy_trsv_reg37
{
    uint32_t U;
    struct _hw_pcie_phy_trsv_reg37_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_pcie_phy_trsv_reg37_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_TRSV_REG37 register
 */
/*@{*/
#define HW_PCIE_PHY_TRSV_REG37_ADDR(x) ((uintptr_t)(x) + 0x148U)

#define HW_PCIE_PHY_TRSV_REG37(x) (*(__I hw_pcie_phy_trsv_reg37_t *) HW_PCIE_PHY_TRSV_REG37_ADDR(x))
#define HW_PCIE_PHY_TRSV_REG37_RD(x) (HW_PCIE_PHY_TRSV_REG37(x).U)
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_TRSV_REG37 bitfields
 */

/*******************************************************************************
 * HW_PCIE_PHY_TRSV_REG38 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_TRSV_REG38 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * TX and RX parallel data also can have bit and / or byte order change to be
 * flexible with connection errors between the PHY and the LINK controller. This
 * BIST mode would be used for ATE test and addition features such as loopback mode
 * can be controlled with the proper register settings. Make sure the powerdown
 * mode control pins are not enabled. (i.e. these powerdown mode pins should be
 * controllable by register in the SoC). These loopback mode are not Compliance
 * mode which is usually implemented in the LINK controller side.When LB_EN is
 * "high", Loopback mode works. This LB_EN is used with LB_MODE[1:0]. If you would
 * like to use TX to RX serial loopback, you should set LB_EN = "1" and LB_MODE =
 * "00'.
 */
typedef union _hw_pcie_phy_trsv_reg38
{
    uint32_t U;
    struct _hw_pcie_phy_trsv_reg38_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t ADD_ALIGN : 1;        /*!< [3] Align Primitive Control */
        uint32_t RX_INV : 1;           /*!< [4]  */
        uint32_t TX_INV : 1;           /*!< [5] TX Inversion Control */
        uint32_t RESERVED1 : 26;       /*!< [31:6]  */
    } B;
} hw_pcie_phy_trsv_reg38_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_TRSV_REG38 register
 */
/*@{*/
#define HW_PCIE_PHY_TRSV_REG38_ADDR(x) ((uintptr_t)(x) + 0x152U)

#define HW_PCIE_PHY_TRSV_REG38(x) (*(__IO hw_pcie_phy_trsv_reg38_t *) HW_PCIE_PHY_TRSV_REG38_ADDR(x))
#define HW_PCIE_PHY_TRSV_REG38_RD(x) (HW_PCIE_PHY_TRSV_REG38(x).U)
#define HW_PCIE_PHY_TRSV_REG38_WR(x, v) (HW_PCIE_PHY_TRSV_REG38(x).U = (v))
#define HW_PCIE_PHY_TRSV_REG38_SET(x, v) (HW_PCIE_PHY_TRSV_REG38_WR(x, HW_PCIE_PHY_TRSV_REG38_RD(x) |  (v)))
#define HW_PCIE_PHY_TRSV_REG38_CLR(x, v) (HW_PCIE_PHY_TRSV_REG38_WR(x, HW_PCIE_PHY_TRSV_REG38_RD(x) & ~(v)))
#define HW_PCIE_PHY_TRSV_REG38_TOG(x, v) (HW_PCIE_PHY_TRSV_REG38_WR(x, HW_PCIE_PHY_TRSV_REG38_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_TRSV_REG38 bitfields
 */

/*!
 * @name Register PCIE_PHY_TRSV_REG38, field ADD_ALIGN[3] (RW)
 *
 * Values:
 * - 0 - No
 * - 1 - ALIGNp is added.
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG38_ADD_ALIGN (3U) /*!< Bit position for PCIE_PHY_TRSV_REG38_ADD_ALIGN. */
#define BM_PCIE_PHY_TRSV_REG38_ADD_ALIGN (0x00000008U) /*!< Bit mask for PCIE_PHY_TRSV_REG38_ADD_ALIGN. */
#define BS_PCIE_PHY_TRSV_REG38_ADD_ALIGN (1U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG38_ADD_ALIGN. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG38_ADD_ALIGN field. */
#define BR_PCIE_PHY_TRSV_REG38_ADD_ALIGN(x) (HW_PCIE_PHY_TRSV_REG38(x).B.ADD_ALIGN)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG38_ADD_ALIGN. */
#define BF_PCIE_PHY_TRSV_REG38_ADD_ALIGN(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG38_ADD_ALIGN) & BM_PCIE_PHY_TRSV_REG38_ADD_ALIGN)

/*! @brief Set the ADD_ALIGN field to a new value. */
#define BW_PCIE_PHY_TRSV_REG38_ADD_ALIGN(x, v) (HW_PCIE_PHY_TRSV_REG38_WR(x, (HW_PCIE_PHY_TRSV_REG38_RD(x) & ~BM_PCIE_PHY_TRSV_REG38_ADD_ALIGN) | BF_PCIE_PHY_TRSV_REG38_ADD_ALIGN(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_TRSV_REG38, field RX_INV[4] (RW)
 *
 * Values:
 * - 0 - Normal Mode (Default Value)
 * - 1 - PCIE_RX_P/PCIE_RX_N Output Data
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG38_RX_INV (4U) /*!< Bit position for PCIE_PHY_TRSV_REG38_RX_INV. */
#define BM_PCIE_PHY_TRSV_REG38_RX_INV (0x00000010U) /*!< Bit mask for PCIE_PHY_TRSV_REG38_RX_INV. */
#define BS_PCIE_PHY_TRSV_REG38_RX_INV (1U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG38_RX_INV. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG38_RX_INV field. */
#define BR_PCIE_PHY_TRSV_REG38_RX_INV(x) (HW_PCIE_PHY_TRSV_REG38(x).B.RX_INV)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG38_RX_INV. */
#define BF_PCIE_PHY_TRSV_REG38_RX_INV(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG38_RX_INV) & BM_PCIE_PHY_TRSV_REG38_RX_INV)

/*! @brief Set the RX_INV field to a new value. */
#define BW_PCIE_PHY_TRSV_REG38_RX_INV(x, v) (HW_PCIE_PHY_TRSV_REG38_WR(x, (HW_PCIE_PHY_TRSV_REG38_RD(x) & ~BM_PCIE_PHY_TRSV_REG38_RX_INV) | BF_PCIE_PHY_TRSV_REG38_RX_INV(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_TRSV_REG38, field TX_INV[5] (RW)
 *
 * This register is used for the serial data (PCIE_TX_P / PCIE_TX_N or PCIE_RX_P
 * / PCIE_RX_N) polarity inversion. Some cases, if high-speed signal pins are
 * twisted or connected through vias, using this polarity.
 *
 * Values:
 * - 0 - Normal Mode (Default Value)
 * - 1 - PCIE_TX_P/PCIE_TX_N Output Data
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG38_TX_INV (5U) /*!< Bit position for PCIE_PHY_TRSV_REG38_TX_INV. */
#define BM_PCIE_PHY_TRSV_REG38_TX_INV (0x00000020U) /*!< Bit mask for PCIE_PHY_TRSV_REG38_TX_INV. */
#define BS_PCIE_PHY_TRSV_REG38_TX_INV (1U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG38_TX_INV. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG38_TX_INV field. */
#define BR_PCIE_PHY_TRSV_REG38_TX_INV(x) (HW_PCIE_PHY_TRSV_REG38(x).B.TX_INV)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG38_TX_INV. */
#define BF_PCIE_PHY_TRSV_REG38_TX_INV(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG38_TX_INV) & BM_PCIE_PHY_TRSV_REG38_TX_INV)

/*! @brief Set the TX_INV field to a new value. */
#define BW_PCIE_PHY_TRSV_REG38_TX_INV(x, v) (HW_PCIE_PHY_TRSV_REG38_WR(x, (HW_PCIE_PHY_TRSV_REG38_RD(x) & ~BM_PCIE_PHY_TRSV_REG38_TX_INV) | BF_PCIE_PHY_TRSV_REG38_TX_INV(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_TRSV_REG39 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_TRSV_REG39 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register can be used for the serial data (PCIE_TX_P / PCIE_TX_N or
 * PCIE_RX_P / PCIE_RX_N) polarity inversion. Some cases, if high-speed signal pins
 * are twisted or connected through vias, you can use this polarity. TX and RX
 * parallel data also can have bit and / or byte order change to be flexible with
 * connection errors between the PHY and the LINK controller.
 */
typedef union _hw_pcie_phy_trsv_reg39
{
    uint32_t U;
    struct _hw_pcie_phy_trsv_reg39_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t TD_ORD : 2;           /*!< [5:4] TX Bit Order Control */
        uint32_t RD_ORD : 2;           /*!< [7:6] RX Bit Order Control */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_trsv_reg39_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_TRSV_REG39 register
 */
/*@{*/
#define HW_PCIE_PHY_TRSV_REG39_ADDR(x) ((uintptr_t)(x) + 0x156U)

#define HW_PCIE_PHY_TRSV_REG39(x) (*(__IO hw_pcie_phy_trsv_reg39_t *) HW_PCIE_PHY_TRSV_REG39_ADDR(x))
#define HW_PCIE_PHY_TRSV_REG39_RD(x) (HW_PCIE_PHY_TRSV_REG39(x).U)
#define HW_PCIE_PHY_TRSV_REG39_WR(x, v) (HW_PCIE_PHY_TRSV_REG39(x).U = (v))
#define HW_PCIE_PHY_TRSV_REG39_SET(x, v) (HW_PCIE_PHY_TRSV_REG39_WR(x, HW_PCIE_PHY_TRSV_REG39_RD(x) |  (v)))
#define HW_PCIE_PHY_TRSV_REG39_CLR(x, v) (HW_PCIE_PHY_TRSV_REG39_WR(x, HW_PCIE_PHY_TRSV_REG39_RD(x) & ~(v)))
#define HW_PCIE_PHY_TRSV_REG39_TOG(x, v) (HW_PCIE_PHY_TRSV_REG39_WR(x, HW_PCIE_PHY_TRSV_REG39_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_TRSV_REG39 bitfields
 */

/*!
 * @name Register PCIE_PHY_TRSV_REG39, field TD_ORD[5:4] (RW)
 *
 * Values:
 * - 00 - No Order Reverse. TXD[0] to TXD[9] is transmitted and then TXD[10] to
 *     TXD[19] is transmitted for TXD[0:19].
 * - 01 - Bit Order Reverse. TXD[9] to TXD[0] is transmitted and then TXD[19] to
 *     TXD[10] is transmitted.
 * - 10 - Byte Order Reverse. TXD[10] to TXD[19] is transmitted and then TXD[0]
 *     to TXD[9] is transmitted.
 * - 11 - Bit and Byte Order Reverse. RXD[19] to RXD[10] is received and then
 *     RXD[9] to RXD[0] is received.
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG39_TD_ORD (4U) /*!< Bit position for PCIE_PHY_TRSV_REG39_TD_ORD. */
#define BM_PCIE_PHY_TRSV_REG39_TD_ORD (0x00000030U) /*!< Bit mask for PCIE_PHY_TRSV_REG39_TD_ORD. */
#define BS_PCIE_PHY_TRSV_REG39_TD_ORD (2U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG39_TD_ORD. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG39_TD_ORD field. */
#define BR_PCIE_PHY_TRSV_REG39_TD_ORD(x) (HW_PCIE_PHY_TRSV_REG39(x).B.TD_ORD)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG39_TD_ORD. */
#define BF_PCIE_PHY_TRSV_REG39_TD_ORD(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG39_TD_ORD) & BM_PCIE_PHY_TRSV_REG39_TD_ORD)

/*! @brief Set the TD_ORD field to a new value. */
#define BW_PCIE_PHY_TRSV_REG39_TD_ORD(x, v) (HW_PCIE_PHY_TRSV_REG39_WR(x, (HW_PCIE_PHY_TRSV_REG39_RD(x) & ~BM_PCIE_PHY_TRSV_REG39_TD_ORD) | BF_PCIE_PHY_TRSV_REG39_TD_ORD(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_TRSV_REG39, field RD_ORD[7:6] (RW)
 *
 * Values:
 * - 00 - No Order Reverse. RXD[0] to RXD[9] is received and then RXD[10] to
 *     RXD[19] is received for RXD[0:19].
 * - 01 - Bit Order Reverse. RXD[9] to RXD[0] is received and then RXD[19] to
 *     RXD[10] is received.
 * - 10 - Byte Order Reverse. RXD[10] to RXD[19] is received and then RXD[0] to
 *     RXD[9] is received.
 * - 11 - Bit and Byte Order Reverse. RXD[19] to RXD[10] is received and then
 *     RXD[9] to RXD[0] is received.
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG39_RD_ORD (6U) /*!< Bit position for PCIE_PHY_TRSV_REG39_RD_ORD. */
#define BM_PCIE_PHY_TRSV_REG39_RD_ORD (0x000000C0U) /*!< Bit mask for PCIE_PHY_TRSV_REG39_RD_ORD. */
#define BS_PCIE_PHY_TRSV_REG39_RD_ORD (2U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG39_RD_ORD. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG39_RD_ORD field. */
#define BR_PCIE_PHY_TRSV_REG39_RD_ORD(x) (HW_PCIE_PHY_TRSV_REG39(x).B.RD_ORD)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG39_RD_ORD. */
#define BF_PCIE_PHY_TRSV_REG39_RD_ORD(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG39_RD_ORD) & BM_PCIE_PHY_TRSV_REG39_RD_ORD)

/*! @brief Set the RD_ORD field to a new value. */
#define BW_PCIE_PHY_TRSV_REG39_RD_ORD(x, v) (HW_PCIE_PHY_TRSV_REG39_WR(x, (HW_PCIE_PHY_TRSV_REG39_RD(x) & ~BM_PCIE_PHY_TRSV_REG39_RD_ORD) | BF_PCIE_PHY_TRSV_REG39_RD_ORD(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_TRSV_REG40 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_TRSV_REG40 -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_pcie_phy_trsv_reg40
{
    uint32_t U;
    struct _hw_pcie_phy_trsv_reg40_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t PD_TRAS : 5;          /*!< [6:2] TRSV Sub-block Powerdown */
        uint32_t PHY_TRSV_EN : 1;      /*!< [7] TRSV Sub-block PD Control */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_trsv_reg40_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_TRSV_REG40 register
 */
/*@{*/
#define HW_PCIE_PHY_TRSV_REG40_ADDR(x) ((uintptr_t)(x) + 0x160U)

#define HW_PCIE_PHY_TRSV_REG40(x) (*(__IO hw_pcie_phy_trsv_reg40_t *) HW_PCIE_PHY_TRSV_REG40_ADDR(x))
#define HW_PCIE_PHY_TRSV_REG40_RD(x) (HW_PCIE_PHY_TRSV_REG40(x).U)
#define HW_PCIE_PHY_TRSV_REG40_WR(x, v) (HW_PCIE_PHY_TRSV_REG40(x).U = (v))
#define HW_PCIE_PHY_TRSV_REG40_SET(x, v) (HW_PCIE_PHY_TRSV_REG40_WR(x, HW_PCIE_PHY_TRSV_REG40_RD(x) |  (v)))
#define HW_PCIE_PHY_TRSV_REG40_CLR(x, v) (HW_PCIE_PHY_TRSV_REG40_WR(x, HW_PCIE_PHY_TRSV_REG40_RD(x) & ~(v)))
#define HW_PCIE_PHY_TRSV_REG40_TOG(x, v) (HW_PCIE_PHY_TRSV_REG40_WR(x, HW_PCIE_PHY_TRSV_REG40_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_TRSV_REG40 bitfields
 */

/*!
 * @name Register PCIE_PHY_TRSV_REG40, field PD_TRAS[6:2] (RW)
 *
 * When Reg40 bit<6> = 1, RX Deserializer power down. When Reg40 bit<5> = 1, TX
 * Serializer power down. When Reg40 bit<4> = 1, RXAFE power down. When Reg40
 * bit<3> = 1, TX DRVR power down. When Reg40 bit<2> = 1, RX TERM power down.
 *
 * Values:
 * - 0000 - Enable
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG40_PD_TRAS (2U) /*!< Bit position for PCIE_PHY_TRSV_REG40_PD_TRAS. */
#define BM_PCIE_PHY_TRSV_REG40_PD_TRAS (0x0000007CU) /*!< Bit mask for PCIE_PHY_TRSV_REG40_PD_TRAS. */
#define BS_PCIE_PHY_TRSV_REG40_PD_TRAS (5U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG40_PD_TRAS. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG40_PD_TRAS field. */
#define BR_PCIE_PHY_TRSV_REG40_PD_TRAS(x) (HW_PCIE_PHY_TRSV_REG40(x).B.PD_TRAS)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG40_PD_TRAS. */
#define BF_PCIE_PHY_TRSV_REG40_PD_TRAS(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG40_PD_TRAS) & BM_PCIE_PHY_TRSV_REG40_PD_TRAS)

/*! @brief Set the PD_TRAS field to a new value. */
#define BW_PCIE_PHY_TRSV_REG40_PD_TRAS(x, v) (HW_PCIE_PHY_TRSV_REG40_WR(x, (HW_PCIE_PHY_TRSV_REG40_RD(x) & ~BM_PCIE_PHY_TRSV_REG40_PD_TRAS) | BF_PCIE_PHY_TRSV_REG40_PD_TRAS(v)))
/*@}*/

/*!
 * @name Register PCIE_PHY_TRSV_REG40, field PHY_TRSV_EN[7] (RW)
 *
 * Values:
 * - 0 - Disabled for TRSV block PD control
 * - 1 - Enabled for TRSV block PD control
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG40_PHY_TRSV_EN (7U) /*!< Bit position for PCIE_PHY_TRSV_REG40_PHY_TRSV_EN. */
#define BM_PCIE_PHY_TRSV_REG40_PHY_TRSV_EN (0x00000080U) /*!< Bit mask for PCIE_PHY_TRSV_REG40_PHY_TRSV_EN. */
#define BS_PCIE_PHY_TRSV_REG40_PHY_TRSV_EN (1U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG40_PHY_TRSV_EN. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG40_PHY_TRSV_EN field. */
#define BR_PCIE_PHY_TRSV_REG40_PHY_TRSV_EN(x) (HW_PCIE_PHY_TRSV_REG40(x).B.PHY_TRSV_EN)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG40_PHY_TRSV_EN. */
#define BF_PCIE_PHY_TRSV_REG40_PHY_TRSV_EN(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG40_PHY_TRSV_EN) & BM_PCIE_PHY_TRSV_REG40_PHY_TRSV_EN)

/*! @brief Set the PHY_TRSV_EN field to a new value. */
#define BW_PCIE_PHY_TRSV_REG40_PHY_TRSV_EN(x, v) (HW_PCIE_PHY_TRSV_REG40_WR(x, (HW_PCIE_PHY_TRSV_REG40_RD(x) & ~BM_PCIE_PHY_TRSV_REG40_PHY_TRSV_EN) | BF_PCIE_PHY_TRSV_REG40_PHY_TRSV_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_PCIE_PHY_TRSV_REG42 -
 ******************************************************************************/

/*!
 * @brief HW_PCIE_PHY_TRSV_REG42 -  (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_pcie_phy_trsv_reg42
{
    uint32_t U;
    struct _hw_pcie_phy_trsv_reg42_bitfields
    {
        uint32_t TRSVRST : 8;          /*!< [7:0] TRSV Reset Control */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_pcie_phy_trsv_reg42_t;

/*!
 * @name Constants and macros for entire PCIE_PHY_TRSV_REG42 register
 */
/*@{*/
#define HW_PCIE_PHY_TRSV_REG42_ADDR(x) ((uintptr_t)(x) + 0x168U)

#define HW_PCIE_PHY_TRSV_REG42(x) (*(__IO hw_pcie_phy_trsv_reg42_t *) HW_PCIE_PHY_TRSV_REG42_ADDR(x))
#define HW_PCIE_PHY_TRSV_REG42_RD(x) (HW_PCIE_PHY_TRSV_REG42(x).U)
#define HW_PCIE_PHY_TRSV_REG42_WR(x, v) (HW_PCIE_PHY_TRSV_REG42(x).U = (v))
#define HW_PCIE_PHY_TRSV_REG42_SET(x, v) (HW_PCIE_PHY_TRSV_REG42_WR(x, HW_PCIE_PHY_TRSV_REG42_RD(x) |  (v)))
#define HW_PCIE_PHY_TRSV_REG42_CLR(x, v) (HW_PCIE_PHY_TRSV_REG42_WR(x, HW_PCIE_PHY_TRSV_REG42_RD(x) & ~(v)))
#define HW_PCIE_PHY_TRSV_REG42_TOG(x, v) (HW_PCIE_PHY_TRSV_REG42_WR(x, HW_PCIE_PHY_TRSV_REG42_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PCIE_PHY_TRSV_REG42 bitfields
 */

/*!
 * @name Register PCIE_PHY_TRSV_REG42, field TRSVRST[7:0] (RW)
 *
 * Values:
 * - 10000000 - Fine control option for RESET
 * - 11111111 - Fine control option for RESET
 */
/*@{*/
#define BP_PCIE_PHY_TRSV_REG42_TRSVRST (0U) /*!< Bit position for PCIE_PHY_TRSV_REG42_TRSVRST. */
#define BM_PCIE_PHY_TRSV_REG42_TRSVRST (0x000000FFU) /*!< Bit mask for PCIE_PHY_TRSV_REG42_TRSVRST. */
#define BS_PCIE_PHY_TRSV_REG42_TRSVRST (8U) /*!< Bit field size in bits for PCIE_PHY_TRSV_REG42_TRSVRST. */

/*! @brief Read current value of the PCIE_PHY_TRSV_REG42_TRSVRST field. */
#define BR_PCIE_PHY_TRSV_REG42_TRSVRST(x) (HW_PCIE_PHY_TRSV_REG42(x).B.TRSVRST)

/*! @brief Format value for bitfield PCIE_PHY_TRSV_REG42_TRSVRST. */
#define BF_PCIE_PHY_TRSV_REG42_TRSVRST(v) ((uint32_t)((uint32_t)(v) << BP_PCIE_PHY_TRSV_REG42_TRSVRST) & BM_PCIE_PHY_TRSV_REG42_TRSVRST)

/*! @brief Set the TRSVRST field to a new value. */
#define BW_PCIE_PHY_TRSV_REG42_TRSVRST(x, v) (HW_PCIE_PHY_TRSV_REG42_WR(x, (HW_PCIE_PHY_TRSV_REG42_RD(x) & ~BM_PCIE_PHY_TRSV_REG42_TRSVRST) | BF_PCIE_PHY_TRSV_REG42_TRSVRST(v)))
/*@}*/

/*******************************************************************************
 * hw_pcie_phy_trsv_t - module struct
 ******************************************************************************/
/*!
 * @brief All PCIE_PHY_TRSV module registers.
 */
#pragma pack(1)
typedef struct _hw_pcie_phy_trsv
{
    uint8_t _reserved0[132];
    __IO hw_pcie_phy_trsv_reg21_t REG21;   /*!< [0x84]  */
    __IO hw_pcie_phy_trsv_reg22_t REG22;   /*!< [0x88]  */
    uint8_t _reserved1[10];
    __IO hw_pcie_phy_trsv_reg24_t REG24;   /*!< [0x96]  */
    uint8_t _reserved2[18];
    __IO hw_pcie_phy_trsv_reg2b_t REG2B;   /*!< [0xAC]  */
    uint8_t _reserved3[56];
    __IO hw_pcie_phy_trsv_reg3a_t REG3A;   /*!< [0xE8]  */
    uint8_t _reserved4[12];
    __IO hw_pcie_phy_trsv_reg3e_t REG3E;   /*!< [0xF8]  */
    uint8_t _reserved5[4];
    __IO hw_pcie_phy_trsv_reg25_t REG25;   /*!< [0x100]  */
    __IO hw_pcie_phy_trsv_reg26_t REG26;   /*!< [0x104]  */
    uint8_t _reserved6[14];
    __IO hw_pcie_phy_trsv_reg29_t REG29;   /*!< [0x116]  */
    uint8_t _reserved7[10];
    __IO hw_pcie_phy_trsv_reg31_t REG31;   /*!< [0x124]  */
    uint8_t _reserved8[10];
    __I hw_pcie_phy_trsv_reg33_t REG33;    /*!< [0x132]  */
    uint8_t _reserved9[14];
    __IO hw_pcie_phy_trsv_reg36_t REG36;   /*!< [0x144]  */
    __I hw_pcie_phy_trsv_reg37_t REG37;    /*!< [0x148]  */
    uint8_t _reserved10[6];
    __IO hw_pcie_phy_trsv_reg38_t REG38;   /*!< [0x152]  */
    __IO hw_pcie_phy_trsv_reg39_t REG39;   /*!< [0x156]  */
    uint8_t _reserved11[6];
    __IO hw_pcie_phy_trsv_reg40_t REG40;   /*!< [0x160]  */
    uint8_t _reserved12[4];
    __IO hw_pcie_phy_trsv_reg42_t REG42;   /*!< [0x168]  */
} hw_pcie_phy_trsv_t;
#pragma pack()

/*! @brief Macro to access all PCIE_PHY_TRSV registers. */
/*! @param x PCIE_PHY_TRSV module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_PCIE_PHY_TRSV_REGS(PCIE_PHY_TRSV_BASE)</code>. */
#define HW_PCIE_PHY_TRSV_REGS(x) (*(hw_pcie_phy_trsv_t *)(x))

/*
 * iMX7D PMU
 *
 * PMU
 *
 * Registers defined in this header file:
 * - HW_PMU_REG_1P0A - Anadig 1.0V A Regulator Control Register
 * - HW_PMU_REG_1P0D - Anadig 1.0V D Regulator Control Register
 * - HW_PMU_REG_HSIC_1P2 - Anadig 1.2V HSIC Regulator Control Register
 * - HW_PMU_REG_LPSR_1P0 - Anadig 1.0V Low Power State Retention Regulator Control Register
 * - HW_PMU_REF - Anadig Reference Analog Control and Status Register
 * - HW_PMU_LOWPWR_CTRL - Anadig Low Power Control Register
 *
 * - hw_pmu_t - Struct containing all module registers.
 */

#define HW_PMU_INSTANCE_COUNT (1U) /*!< Number of instances of the PMU module. */
#define HW_PMU (0U) /*!< Instance number for PMU. */
#define PMU_BASE              (0x30360200U) /*!< Base address for PMU. */
/*! Array initializer of PMU base addresses. */
#define PMU_BASE_ADDRS        { PMU_BASE }

/*******************************************************************************
 * HW_PMU_REG_1P0A - Anadig 1.0V A Regulator Control Register
 ******************************************************************************/

/*!
 * @brief HW_PMU_REG_1P0A - Anadig 1.0V A Regulator Control Register (RW)
 *
 * Reset value: 0x00001073U
 *
 * This register defines the control and status bits for the 1.1V regulator.
 * This regulator is designed to power the digital portions of the analog cells.
 */
typedef union _hw_pmu_reg_1p0a
{
    uint32_t U;
    struct _hw_pmu_reg_1p0a_bitfields
    {
        uint32_t ENABLE_LINREG : 1;    /*!< [0]  */
        uint32_t ENABLE_BO : 1;        /*!< [1]  */
        uint32_t ENABLE_ILIMIT : 1;    /*!< [2]  */
        uint32_t ENABLE_PULLDOWN : 1;  /*!< [3]  */
        uint32_t BO_OFFSET : 3;        /*!< [6:4]  */
        uint32_t ENABLE_PWRUPLOAD : 1; /*!< [7]  */
        uint32_t OUTPUT_TRG : 5;       /*!< [12:8]  */
        uint32_t RSVD0 : 3;            /*!< [15:13]  */
        uint32_t BO : 1;               /*!< [16]  */
        uint32_t OK : 1;               /*!< [17]  */
        uint32_t ENABLE_WEAK_LINREG : 1; /*!< [18]  */
        uint32_t SELREF_WEAK_LINREG : 1; /*!< [19]  */
        uint32_t REG_TEST : 4;         /*!< [23:20]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_pmu_reg_1p0a_t;

/*!
 * @name Constants and macros for entire PMU_REG_1P0A register
 */
/*@{*/
#define HW_PMU_REG_1P0A_ADDR(x)  ((uintptr_t)(x) + 0x200U)
#define HW_PMU_REG_1P0A_SET_ADDR(x) (HW_PMU_REG_1P0A_ADDR(x) + 0x4U)
#define HW_PMU_REG_1P0A_CLR_ADDR(x) (HW_PMU_REG_1P0A_ADDR(x) + 0x8U)
#define HW_PMU_REG_1P0A_TOG_ADDR(x) (HW_PMU_REG_1P0A_ADDR(x) + 0xCU)

#define HW_PMU_REG_1P0A(x)       (*(__IO hw_pmu_reg_1p0a_t *) HW_PMU_REG_1P0A_ADDR(x))
#define HW_PMU_REG_1P0A_RD(x)    (HW_PMU_REG_1P0A(x).U)
#define HW_PMU_REG_1P0A_WR(x, v) (HW_PMU_REG_1P0A(x).U = (v))
#define HW_PMU_REG_1P0A_SET(x, v) ((*(uint32_t *) HW_PMU_REG_1P0A_SET_ADDR(x)) = (v))
#define HW_PMU_REG_1P0A_CLR(x, v) ((*(uint32_t *) HW_PMU_REG_1P0A_CLR_ADDR(x)) = (v))
#define HW_PMU_REG_1P0A_TOG(x, v) ((*(uint32_t *) HW_PMU_REG_1P0A_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual PMU_REG_1P0A bitfields
 */

/*!
 * @name Register PMU_REG_1P0A, field ENABLE_LINREG[0] (RW)
 *
 * Control bit to enable the regulator output.
 */
/*@{*/
#define BP_PMU_REG_1P0A_ENABLE_LINREG (0U) /*!< Bit position for PMU_REG_1P0A_ENABLE_LINREG. */
#define BM_PMU_REG_1P0A_ENABLE_LINREG (0x00000001U) /*!< Bit mask for PMU_REG_1P0A_ENABLE_LINREG. */
#define BS_PMU_REG_1P0A_ENABLE_LINREG (1U) /*!< Bit field size in bits for PMU_REG_1P0A_ENABLE_LINREG. */

/*! @brief Read current value of the PMU_REG_1P0A_ENABLE_LINREG field. */
#define BR_PMU_REG_1P0A_ENABLE_LINREG(x) (HW_PMU_REG_1P0A(x).B.ENABLE_LINREG)

/*! @brief Format value for bitfield PMU_REG_1P0A_ENABLE_LINREG. */
#define BF_PMU_REG_1P0A_ENABLE_LINREG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0A_ENABLE_LINREG) & BM_PMU_REG_1P0A_ENABLE_LINREG)

/*! @brief Set the ENABLE_LINREG field to a new value. */
#define BW_PMU_REG_1P0A_ENABLE_LINREG(x, v) (HW_PMU_REG_1P0A_WR(x, (HW_PMU_REG_1P0A_RD(x) & ~BM_PMU_REG_1P0A_ENABLE_LINREG) | BF_PMU_REG_1P0A_ENABLE_LINREG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0A, field ENABLE_BO[1] (RW)
 *
 * Control bit to enable the brown-out circuitry in the regulator.
 */
/*@{*/
#define BP_PMU_REG_1P0A_ENABLE_BO (1U)     /*!< Bit position for PMU_REG_1P0A_ENABLE_BO. */
#define BM_PMU_REG_1P0A_ENABLE_BO (0x00000002U) /*!< Bit mask for PMU_REG_1P0A_ENABLE_BO. */
#define BS_PMU_REG_1P0A_ENABLE_BO (1U)     /*!< Bit field size in bits for PMU_REG_1P0A_ENABLE_BO. */

/*! @brief Read current value of the PMU_REG_1P0A_ENABLE_BO field. */
#define BR_PMU_REG_1P0A_ENABLE_BO(x) (HW_PMU_REG_1P0A(x).B.ENABLE_BO)

/*! @brief Format value for bitfield PMU_REG_1P0A_ENABLE_BO. */
#define BF_PMU_REG_1P0A_ENABLE_BO(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0A_ENABLE_BO) & BM_PMU_REG_1P0A_ENABLE_BO)

/*! @brief Set the ENABLE_BO field to a new value. */
#define BW_PMU_REG_1P0A_ENABLE_BO(x, v) (HW_PMU_REG_1P0A_WR(x, (HW_PMU_REG_1P0A_RD(x) & ~BM_PMU_REG_1P0A_ENABLE_BO) | BF_PMU_REG_1P0A_ENABLE_BO(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0A, field ENABLE_ILIMIT[2] (RW)
 *
 * Control bit to enable the current-limit circuitry in the regulator.
 */
/*@{*/
#define BP_PMU_REG_1P0A_ENABLE_ILIMIT (2U) /*!< Bit position for PMU_REG_1P0A_ENABLE_ILIMIT. */
#define BM_PMU_REG_1P0A_ENABLE_ILIMIT (0x00000004U) /*!< Bit mask for PMU_REG_1P0A_ENABLE_ILIMIT. */
#define BS_PMU_REG_1P0A_ENABLE_ILIMIT (1U) /*!< Bit field size in bits for PMU_REG_1P0A_ENABLE_ILIMIT. */

/*! @brief Read current value of the PMU_REG_1P0A_ENABLE_ILIMIT field. */
#define BR_PMU_REG_1P0A_ENABLE_ILIMIT(x) (HW_PMU_REG_1P0A(x).B.ENABLE_ILIMIT)

/*! @brief Format value for bitfield PMU_REG_1P0A_ENABLE_ILIMIT. */
#define BF_PMU_REG_1P0A_ENABLE_ILIMIT(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0A_ENABLE_ILIMIT) & BM_PMU_REG_1P0A_ENABLE_ILIMIT)

/*! @brief Set the ENABLE_ILIMIT field to a new value. */
#define BW_PMU_REG_1P0A_ENABLE_ILIMIT(x, v) (HW_PMU_REG_1P0A_WR(x, (HW_PMU_REG_1P0A_RD(x) & ~BM_PMU_REG_1P0A_ENABLE_ILIMIT) | BF_PMU_REG_1P0A_ENABLE_ILIMIT(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0A, field ENABLE_PULLDOWN[3] (RW)
 *
 * Control bit to enable the pull-down circuitry in the regulator
 */
/*@{*/
#define BP_PMU_REG_1P0A_ENABLE_PULLDOWN (3U) /*!< Bit position for PMU_REG_1P0A_ENABLE_PULLDOWN. */
#define BM_PMU_REG_1P0A_ENABLE_PULLDOWN (0x00000008U) /*!< Bit mask for PMU_REG_1P0A_ENABLE_PULLDOWN. */
#define BS_PMU_REG_1P0A_ENABLE_PULLDOWN (1U) /*!< Bit field size in bits for PMU_REG_1P0A_ENABLE_PULLDOWN. */

/*! @brief Read current value of the PMU_REG_1P0A_ENABLE_PULLDOWN field. */
#define BR_PMU_REG_1P0A_ENABLE_PULLDOWN(x) (HW_PMU_REG_1P0A(x).B.ENABLE_PULLDOWN)

/*! @brief Format value for bitfield PMU_REG_1P0A_ENABLE_PULLDOWN. */
#define BF_PMU_REG_1P0A_ENABLE_PULLDOWN(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0A_ENABLE_PULLDOWN) & BM_PMU_REG_1P0A_ENABLE_PULLDOWN)

/*! @brief Set the ENABLE_PULLDOWN field to a new value. */
#define BW_PMU_REG_1P0A_ENABLE_PULLDOWN(x, v) (HW_PMU_REG_1P0A_WR(x, (HW_PMU_REG_1P0A_RD(x) & ~BM_PMU_REG_1P0A_ENABLE_PULLDOWN) | BF_PMU_REG_1P0A_ENABLE_PULLDOWN(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0A, field BO_OFFSET[6:4] (RW)
 *
 * Control bits to adjust the regulator brown-out offset voltage in 25mV steps.
 * The brown-out level is relative to the programmed target voltage. The reset
 * brown-out offset is 175mV below the programmed target level.
 */
/*@{*/
#define BP_PMU_REG_1P0A_BO_OFFSET (4U)     /*!< Bit position for PMU_REG_1P0A_BO_OFFSET. */
#define BM_PMU_REG_1P0A_BO_OFFSET (0x00000070U) /*!< Bit mask for PMU_REG_1P0A_BO_OFFSET. */
#define BS_PMU_REG_1P0A_BO_OFFSET (3U)     /*!< Bit field size in bits for PMU_REG_1P0A_BO_OFFSET. */

/*! @brief Read current value of the PMU_REG_1P0A_BO_OFFSET field. */
#define BR_PMU_REG_1P0A_BO_OFFSET(x) (HW_PMU_REG_1P0A(x).B.BO_OFFSET)

/*! @brief Format value for bitfield PMU_REG_1P0A_BO_OFFSET. */
#define BF_PMU_REG_1P0A_BO_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0A_BO_OFFSET) & BM_PMU_REG_1P0A_BO_OFFSET)

/*! @brief Set the BO_OFFSET field to a new value. */
#define BW_PMU_REG_1P0A_BO_OFFSET(x, v) (HW_PMU_REG_1P0A_WR(x, (HW_PMU_REG_1P0A_RD(x) & ~BM_PMU_REG_1P0A_BO_OFFSET) | BF_PMU_REG_1P0A_BO_OFFSET(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0A, field ENABLE_PWRUPLOAD[7] (RW)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_PMU_REG_1P0A_ENABLE_PWRUPLOAD (7U) /*!< Bit position for PMU_REG_1P0A_ENABLE_PWRUPLOAD. */
#define BM_PMU_REG_1P0A_ENABLE_PWRUPLOAD (0x00000080U) /*!< Bit mask for PMU_REG_1P0A_ENABLE_PWRUPLOAD. */
#define BS_PMU_REG_1P0A_ENABLE_PWRUPLOAD (1U) /*!< Bit field size in bits for PMU_REG_1P0A_ENABLE_PWRUPLOAD. */

/*! @brief Read current value of the PMU_REG_1P0A_ENABLE_PWRUPLOAD field. */
#define BR_PMU_REG_1P0A_ENABLE_PWRUPLOAD(x) (HW_PMU_REG_1P0A(x).B.ENABLE_PWRUPLOAD)

/*! @brief Format value for bitfield PMU_REG_1P0A_ENABLE_PWRUPLOAD. */
#define BF_PMU_REG_1P0A_ENABLE_PWRUPLOAD(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0A_ENABLE_PWRUPLOAD) & BM_PMU_REG_1P0A_ENABLE_PWRUPLOAD)

/*! @brief Set the ENABLE_PWRUPLOAD field to a new value. */
#define BW_PMU_REG_1P0A_ENABLE_PWRUPLOAD(x, v) (HW_PMU_REG_1P0A_WR(x, (HW_PMU_REG_1P0A_RD(x) & ~BM_PMU_REG_1P0A_ENABLE_PWRUPLOAD) | BF_PMU_REG_1P0A_ENABLE_PWRUPLOAD(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0A, field OUTPUT_TRG[12:8] (RW)
 *
 * Control bits to adjust the regulator output voltage in 25mV steps. 0x18 -
 * 1.2V; 0x10 - 1.0V; 0x08 - 0.8V. Note that the programmable output of the
 * regulator excedes the maximum and minimum supply limits for the chip.
 */
/*@{*/
#define BP_PMU_REG_1P0A_OUTPUT_TRG (8U)    /*!< Bit position for PMU_REG_1P0A_OUTPUT_TRG. */
#define BM_PMU_REG_1P0A_OUTPUT_TRG (0x00001F00U) /*!< Bit mask for PMU_REG_1P0A_OUTPUT_TRG. */
#define BS_PMU_REG_1P0A_OUTPUT_TRG (5U)    /*!< Bit field size in bits for PMU_REG_1P0A_OUTPUT_TRG. */

/*! @brief Read current value of the PMU_REG_1P0A_OUTPUT_TRG field. */
#define BR_PMU_REG_1P0A_OUTPUT_TRG(x) (HW_PMU_REG_1P0A(x).B.OUTPUT_TRG)

/*! @brief Format value for bitfield PMU_REG_1P0A_OUTPUT_TRG. */
#define BF_PMU_REG_1P0A_OUTPUT_TRG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0A_OUTPUT_TRG) & BM_PMU_REG_1P0A_OUTPUT_TRG)

/*! @brief Set the OUTPUT_TRG field to a new value. */
#define BW_PMU_REG_1P0A_OUTPUT_TRG(x, v) (HW_PMU_REG_1P0A_WR(x, (HW_PMU_REG_1P0A_RD(x) & ~BM_PMU_REG_1P0A_OUTPUT_TRG) | BF_PMU_REG_1P0A_OUTPUT_TRG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0A, field RSVD0[15:13] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_PMU_REG_1P0A_RSVD0 (13U)        /*!< Bit position for PMU_REG_1P0A_RSVD0. */
#define BM_PMU_REG_1P0A_RSVD0 (0x0000E000U) /*!< Bit mask for PMU_REG_1P0A_RSVD0. */
#define BS_PMU_REG_1P0A_RSVD0 (3U)         /*!< Bit field size in bits for PMU_REG_1P0A_RSVD0. */

/*! @brief Read current value of the PMU_REG_1P0A_RSVD0 field. */
#define BR_PMU_REG_1P0A_RSVD0(x) (HW_PMU_REG_1P0A(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PMU_REG_1P0A, field BO[16] (RW)
 *
 * Interrupt/status bit that signals when a brown-out is detected on the
 * regulator output. Sticky bit, write 1 to this field to clear.
 */
/*@{*/
#define BP_PMU_REG_1P0A_BO   (16U)         /*!< Bit position for PMU_REG_1P0A_BO. */
#define BM_PMU_REG_1P0A_BO   (0x00010000U) /*!< Bit mask for PMU_REG_1P0A_BO. */
#define BS_PMU_REG_1P0A_BO   (1U)          /*!< Bit field size in bits for PMU_REG_1P0A_BO. */

/*! @brief Read current value of the PMU_REG_1P0A_BO field. */
#define BR_PMU_REG_1P0A_BO(x) (HW_PMU_REG_1P0A(x).B.BO)

/*! @brief Format value for bitfield PMU_REG_1P0A_BO. */
#define BF_PMU_REG_1P0A_BO(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0A_BO) & BM_PMU_REG_1P0A_BO)

/*! @brief Set the BO field to a new value. */
#define BW_PMU_REG_1P0A_BO(x, v) (HW_PMU_REG_1P0A_WR(x, (HW_PMU_REG_1P0A_RD(x) & ~BM_PMU_REG_1P0A_BO) | BF_PMU_REG_1P0A_BO(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0A, field OK[17] (RO)
 *
 * Status bit that signals when the regulator output is ok.
 */
/*@{*/
#define BP_PMU_REG_1P0A_OK   (17U)         /*!< Bit position for PMU_REG_1P0A_OK. */
#define BM_PMU_REG_1P0A_OK   (0x00020000U) /*!< Bit mask for PMU_REG_1P0A_OK. */
#define BS_PMU_REG_1P0A_OK   (1U)          /*!< Bit field size in bits for PMU_REG_1P0A_OK. */

/*! @brief Read current value of the PMU_REG_1P0A_OK field. */
#define BR_PMU_REG_1P0A_OK(x) (HW_PMU_REG_1P0A(x).B.OK)
/*@}*/

/*!
 * @name Register PMU_REG_1P0A, field ENABLE_WEAK_LINREG[18] (RW)
 *
 * Enables the weak 1p1 regulator. This regulator can be used when the main 1p1
 * regulator is disabled, under low-power conditions.
 */
/*@{*/
#define BP_PMU_REG_1P0A_ENABLE_WEAK_LINREG (18U) /*!< Bit position for PMU_REG_1P0A_ENABLE_WEAK_LINREG. */
#define BM_PMU_REG_1P0A_ENABLE_WEAK_LINREG (0x00040000U) /*!< Bit mask for PMU_REG_1P0A_ENABLE_WEAK_LINREG. */
#define BS_PMU_REG_1P0A_ENABLE_WEAK_LINREG (1U) /*!< Bit field size in bits for PMU_REG_1P0A_ENABLE_WEAK_LINREG. */

/*! @brief Read current value of the PMU_REG_1P0A_ENABLE_WEAK_LINREG field. */
#define BR_PMU_REG_1P0A_ENABLE_WEAK_LINREG(x) (HW_PMU_REG_1P0A(x).B.ENABLE_WEAK_LINREG)

/*! @brief Format value for bitfield PMU_REG_1P0A_ENABLE_WEAK_LINREG. */
#define BF_PMU_REG_1P0A_ENABLE_WEAK_LINREG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0A_ENABLE_WEAK_LINREG) & BM_PMU_REG_1P0A_ENABLE_WEAK_LINREG)

/*! @brief Set the ENABLE_WEAK_LINREG field to a new value. */
#define BW_PMU_REG_1P0A_ENABLE_WEAK_LINREG(x, v) (HW_PMU_REG_1P0A_WR(x, (HW_PMU_REG_1P0A_RD(x) & ~BM_PMU_REG_1P0A_ENABLE_WEAK_LINREG) | BF_PMU_REG_1P0A_ENABLE_WEAK_LINREG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0A, field SELREF_WEAK_LINREG[19] (RW)
 *
 * Selects the source for the reference voltage of the weak 1p1 regulator:
 * 0x0=weak-linreg output tracks low-power-bandgap voltage, 0x1=weak-linreg output
 * tracks VDD_SOC_CAP voltage.
 */
/*@{*/
#define BP_PMU_REG_1P0A_SELREF_WEAK_LINREG (19U) /*!< Bit position for PMU_REG_1P0A_SELREF_WEAK_LINREG. */
#define BM_PMU_REG_1P0A_SELREF_WEAK_LINREG (0x00080000U) /*!< Bit mask for PMU_REG_1P0A_SELREF_WEAK_LINREG. */
#define BS_PMU_REG_1P0A_SELREF_WEAK_LINREG (1U) /*!< Bit field size in bits for PMU_REG_1P0A_SELREF_WEAK_LINREG. */

/*! @brief Read current value of the PMU_REG_1P0A_SELREF_WEAK_LINREG field. */
#define BR_PMU_REG_1P0A_SELREF_WEAK_LINREG(x) (HW_PMU_REG_1P0A(x).B.SELREF_WEAK_LINREG)

/*! @brief Format value for bitfield PMU_REG_1P0A_SELREF_WEAK_LINREG. */
#define BF_PMU_REG_1P0A_SELREF_WEAK_LINREG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0A_SELREF_WEAK_LINREG) & BM_PMU_REG_1P0A_SELREF_WEAK_LINREG)

/*! @brief Set the SELREF_WEAK_LINREG field to a new value. */
#define BW_PMU_REG_1P0A_SELREF_WEAK_LINREG(x, v) (HW_PMU_REG_1P0A_WR(x, (HW_PMU_REG_1P0A_RD(x) & ~BM_PMU_REG_1P0A_SELREF_WEAK_LINREG) | BF_PMU_REG_1P0A_SELREF_WEAK_LINREG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0A, field REG_TEST[23:20] (RW)
 *
 * Test bits to monitor different analog signals though anamux.
 */
/*@{*/
#define BP_PMU_REG_1P0A_REG_TEST (20U)     /*!< Bit position for PMU_REG_1P0A_REG_TEST. */
#define BM_PMU_REG_1P0A_REG_TEST (0x00F00000U) /*!< Bit mask for PMU_REG_1P0A_REG_TEST. */
#define BS_PMU_REG_1P0A_REG_TEST (4U)      /*!< Bit field size in bits for PMU_REG_1P0A_REG_TEST. */

/*! @brief Read current value of the PMU_REG_1P0A_REG_TEST field. */
#define BR_PMU_REG_1P0A_REG_TEST(x) (HW_PMU_REG_1P0A(x).B.REG_TEST)

/*! @brief Format value for bitfield PMU_REG_1P0A_REG_TEST. */
#define BF_PMU_REG_1P0A_REG_TEST(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0A_REG_TEST) & BM_PMU_REG_1P0A_REG_TEST)

/*! @brief Set the REG_TEST field to a new value. */
#define BW_PMU_REG_1P0A_REG_TEST(x, v) (HW_PMU_REG_1P0A_WR(x, (HW_PMU_REG_1P0A_RD(x) & ~BM_PMU_REG_1P0A_REG_TEST) | BF_PMU_REG_1P0A_REG_TEST(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0A, field RSVD1[31:24] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_PMU_REG_1P0A_RSVD1 (24U)        /*!< Bit position for PMU_REG_1P0A_RSVD1. */
#define BM_PMU_REG_1P0A_RSVD1 (0xFF000000U) /*!< Bit mask for PMU_REG_1P0A_RSVD1. */
#define BS_PMU_REG_1P0A_RSVD1 (8U)         /*!< Bit field size in bits for PMU_REG_1P0A_RSVD1. */

/*! @brief Read current value of the PMU_REG_1P0A_RSVD1 field. */
#define BR_PMU_REG_1P0A_RSVD1(x) (HW_PMU_REG_1P0A(x).B.RSVD1)
/*@}*/




/*******************************************************************************
 * HW_PMU_REG_1P0D - Anadig 1.0V D Regulator Control Register
 ******************************************************************************/

/*!
 * @brief HW_PMU_REG_1P0D - Anadig 1.0V D Regulator Control Register (RW)
 *
 * Reset value: 0x00001078U
 *
 * This register defines the control and status bits for the 1.1V regulator.
 * This regulator is designed to power the digital portions of the analog cells.
 */
typedef union _hw_pmu_reg_1p0d
{
    uint32_t U;
    struct _hw_pmu_reg_1p0d_bitfields
    {
        uint32_t ENABLE_LINREG : 1;    /*!< [0]  */
        uint32_t ENABLE_BO : 1;        /*!< [1]  */
        uint32_t ENABLE_ILIMIT : 1;    /*!< [2]  */
        uint32_t ENABLE_PULLDOWN : 1;  /*!< [3]  */
        uint32_t BO_OFFSET : 3;        /*!< [6:4]  */
        uint32_t ENABLE_PWRUPLOAD : 1; /*!< [7]  */
        uint32_t OUTPUT_TRG : 5;       /*!< [12:8]  */
        uint32_t RSVD0 : 3;            /*!< [15:13]  */
        uint32_t BO : 1;               /*!< [16]  */
        uint32_t OK : 1;               /*!< [17]  */
        uint32_t ENABLE_WEAK_LINREG : 1; /*!< [18]  */
        uint32_t SELREF_WEAK_LINREG : 1; /*!< [19]  */
        uint32_t REG_TEST : 4;         /*!< [23:20]  */
        uint32_t RSVD1 : 7;            /*!< [30:24]  */
        uint32_t OVERRIDE : 1;         /*!< [31]  */
    } B;
} hw_pmu_reg_1p0d_t;

/*!
 * @name Constants and macros for entire PMU_REG_1P0D register
 */
/*@{*/
#define HW_PMU_REG_1P0D_ADDR(x)  ((uintptr_t)(x) + 0x210U)
#define HW_PMU_REG_1P0D_SET_ADDR(x) (HW_PMU_REG_1P0D_ADDR(x) + 0x4U)
#define HW_PMU_REG_1P0D_CLR_ADDR(x) (HW_PMU_REG_1P0D_ADDR(x) + 0x8U)
#define HW_PMU_REG_1P0D_TOG_ADDR(x) (HW_PMU_REG_1P0D_ADDR(x) + 0xCU)

#define HW_PMU_REG_1P0D(x)       (*(__IO hw_pmu_reg_1p0d_t *) HW_PMU_REG_1P0D_ADDR(x))
#define HW_PMU_REG_1P0D_RD(x)    (HW_PMU_REG_1P0D(x).U)
#define HW_PMU_REG_1P0D_WR(x, v) (HW_PMU_REG_1P0D(x).U = (v))
#define HW_PMU_REG_1P0D_SET(x, v) ((*(uint32_t *) HW_PMU_REG_1P0D_SET_ADDR(x)) = (v))
#define HW_PMU_REG_1P0D_CLR(x, v) ((*(uint32_t *) HW_PMU_REG_1P0D_CLR_ADDR(x)) = (v))
#define HW_PMU_REG_1P0D_TOG(x, v) ((*(uint32_t *) HW_PMU_REG_1P0D_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual PMU_REG_1P0D bitfields
 */

/*!
 * @name Register PMU_REG_1P0D, field ENABLE_LINREG[0] (RW)
 *
 * Control bit to enable the regulator output.
 */
/*@{*/
#define BP_PMU_REG_1P0D_ENABLE_LINREG (0U) /*!< Bit position for PMU_REG_1P0D_ENABLE_LINREG. */
#define BM_PMU_REG_1P0D_ENABLE_LINREG (0x00000001U) /*!< Bit mask for PMU_REG_1P0D_ENABLE_LINREG. */
#define BS_PMU_REG_1P0D_ENABLE_LINREG (1U) /*!< Bit field size in bits for PMU_REG_1P0D_ENABLE_LINREG. */

/*! @brief Read current value of the PMU_REG_1P0D_ENABLE_LINREG field. */
#define BR_PMU_REG_1P0D_ENABLE_LINREG(x) (HW_PMU_REG_1P0D(x).B.ENABLE_LINREG)

/*! @brief Format value for bitfield PMU_REG_1P0D_ENABLE_LINREG. */
#define BF_PMU_REG_1P0D_ENABLE_LINREG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0D_ENABLE_LINREG) & BM_PMU_REG_1P0D_ENABLE_LINREG)

/*! @brief Set the ENABLE_LINREG field to a new value. */
#define BW_PMU_REG_1P0D_ENABLE_LINREG(x, v) (HW_PMU_REG_1P0D_WR(x, (HW_PMU_REG_1P0D_RD(x) & ~BM_PMU_REG_1P0D_ENABLE_LINREG) | BF_PMU_REG_1P0D_ENABLE_LINREG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0D, field ENABLE_BO[1] (RW)
 *
 * Control bit to enable the brown-out circuitry in the regulator.
 */
/*@{*/
#define BP_PMU_REG_1P0D_ENABLE_BO (1U)     /*!< Bit position for PMU_REG_1P0D_ENABLE_BO. */
#define BM_PMU_REG_1P0D_ENABLE_BO (0x00000002U) /*!< Bit mask for PMU_REG_1P0D_ENABLE_BO. */
#define BS_PMU_REG_1P0D_ENABLE_BO (1U)     /*!< Bit field size in bits for PMU_REG_1P0D_ENABLE_BO. */

/*! @brief Read current value of the PMU_REG_1P0D_ENABLE_BO field. */
#define BR_PMU_REG_1P0D_ENABLE_BO(x) (HW_PMU_REG_1P0D(x).B.ENABLE_BO)

/*! @brief Format value for bitfield PMU_REG_1P0D_ENABLE_BO. */
#define BF_PMU_REG_1P0D_ENABLE_BO(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0D_ENABLE_BO) & BM_PMU_REG_1P0D_ENABLE_BO)

/*! @brief Set the ENABLE_BO field to a new value. */
#define BW_PMU_REG_1P0D_ENABLE_BO(x, v) (HW_PMU_REG_1P0D_WR(x, (HW_PMU_REG_1P0D_RD(x) & ~BM_PMU_REG_1P0D_ENABLE_BO) | BF_PMU_REG_1P0D_ENABLE_BO(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0D, field ENABLE_ILIMIT[2] (RW)
 *
 * Control bit to enable the current-limit circuitry in the regulator.
 */
/*@{*/
#define BP_PMU_REG_1P0D_ENABLE_ILIMIT (2U) /*!< Bit position for PMU_REG_1P0D_ENABLE_ILIMIT. */
#define BM_PMU_REG_1P0D_ENABLE_ILIMIT (0x00000004U) /*!< Bit mask for PMU_REG_1P0D_ENABLE_ILIMIT. */
#define BS_PMU_REG_1P0D_ENABLE_ILIMIT (1U) /*!< Bit field size in bits for PMU_REG_1P0D_ENABLE_ILIMIT. */

/*! @brief Read current value of the PMU_REG_1P0D_ENABLE_ILIMIT field. */
#define BR_PMU_REG_1P0D_ENABLE_ILIMIT(x) (HW_PMU_REG_1P0D(x).B.ENABLE_ILIMIT)

/*! @brief Format value for bitfield PMU_REG_1P0D_ENABLE_ILIMIT. */
#define BF_PMU_REG_1P0D_ENABLE_ILIMIT(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0D_ENABLE_ILIMIT) & BM_PMU_REG_1P0D_ENABLE_ILIMIT)

/*! @brief Set the ENABLE_ILIMIT field to a new value. */
#define BW_PMU_REG_1P0D_ENABLE_ILIMIT(x, v) (HW_PMU_REG_1P0D_WR(x, (HW_PMU_REG_1P0D_RD(x) & ~BM_PMU_REG_1P0D_ENABLE_ILIMIT) | BF_PMU_REG_1P0D_ENABLE_ILIMIT(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0D, field ENABLE_PULLDOWN[3] (RW)
 *
 * Control bit to enable the pull-down circuitry in the regulator
 */
/*@{*/
#define BP_PMU_REG_1P0D_ENABLE_PULLDOWN (3U) /*!< Bit position for PMU_REG_1P0D_ENABLE_PULLDOWN. */
#define BM_PMU_REG_1P0D_ENABLE_PULLDOWN (0x00000008U) /*!< Bit mask for PMU_REG_1P0D_ENABLE_PULLDOWN. */
#define BS_PMU_REG_1P0D_ENABLE_PULLDOWN (1U) /*!< Bit field size in bits for PMU_REG_1P0D_ENABLE_PULLDOWN. */

/*! @brief Read current value of the PMU_REG_1P0D_ENABLE_PULLDOWN field. */
#define BR_PMU_REG_1P0D_ENABLE_PULLDOWN(x) (HW_PMU_REG_1P0D(x).B.ENABLE_PULLDOWN)

/*! @brief Format value for bitfield PMU_REG_1P0D_ENABLE_PULLDOWN. */
#define BF_PMU_REG_1P0D_ENABLE_PULLDOWN(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0D_ENABLE_PULLDOWN) & BM_PMU_REG_1P0D_ENABLE_PULLDOWN)

/*! @brief Set the ENABLE_PULLDOWN field to a new value. */
#define BW_PMU_REG_1P0D_ENABLE_PULLDOWN(x, v) (HW_PMU_REG_1P0D_WR(x, (HW_PMU_REG_1P0D_RD(x) & ~BM_PMU_REG_1P0D_ENABLE_PULLDOWN) | BF_PMU_REG_1P0D_ENABLE_PULLDOWN(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0D, field BO_OFFSET[6:4] (RW)
 *
 * Control bits to adjust the regulator brown-out offset voltage in 25mV steps.
 * The brown-out level is relative to the programmed target voltage. The reset
 * brown-out offset is 175mV below the programmed target code.
 */
/*@{*/
#define BP_PMU_REG_1P0D_BO_OFFSET (4U)     /*!< Bit position for PMU_REG_1P0D_BO_OFFSET. */
#define BM_PMU_REG_1P0D_BO_OFFSET (0x00000070U) /*!< Bit mask for PMU_REG_1P0D_BO_OFFSET. */
#define BS_PMU_REG_1P0D_BO_OFFSET (3U)     /*!< Bit field size in bits for PMU_REG_1P0D_BO_OFFSET. */

/*! @brief Read current value of the PMU_REG_1P0D_BO_OFFSET field. */
#define BR_PMU_REG_1P0D_BO_OFFSET(x) (HW_PMU_REG_1P0D(x).B.BO_OFFSET)

/*! @brief Format value for bitfield PMU_REG_1P0D_BO_OFFSET. */
#define BF_PMU_REG_1P0D_BO_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0D_BO_OFFSET) & BM_PMU_REG_1P0D_BO_OFFSET)

/*! @brief Set the BO_OFFSET field to a new value. */
#define BW_PMU_REG_1P0D_BO_OFFSET(x, v) (HW_PMU_REG_1P0D_WR(x, (HW_PMU_REG_1P0D_RD(x) & ~BM_PMU_REG_1P0D_BO_OFFSET) | BF_PMU_REG_1P0D_BO_OFFSET(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0D, field ENABLE_PWRUPLOAD[7] (RW)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_PMU_REG_1P0D_ENABLE_PWRUPLOAD (7U) /*!< Bit position for PMU_REG_1P0D_ENABLE_PWRUPLOAD. */
#define BM_PMU_REG_1P0D_ENABLE_PWRUPLOAD (0x00000080U) /*!< Bit mask for PMU_REG_1P0D_ENABLE_PWRUPLOAD. */
#define BS_PMU_REG_1P0D_ENABLE_PWRUPLOAD (1U) /*!< Bit field size in bits for PMU_REG_1P0D_ENABLE_PWRUPLOAD. */

/*! @brief Read current value of the PMU_REG_1P0D_ENABLE_PWRUPLOAD field. */
#define BR_PMU_REG_1P0D_ENABLE_PWRUPLOAD(x) (HW_PMU_REG_1P0D(x).B.ENABLE_PWRUPLOAD)

/*! @brief Format value for bitfield PMU_REG_1P0D_ENABLE_PWRUPLOAD. */
#define BF_PMU_REG_1P0D_ENABLE_PWRUPLOAD(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0D_ENABLE_PWRUPLOAD) & BM_PMU_REG_1P0D_ENABLE_PWRUPLOAD)

/*! @brief Set the ENABLE_PWRUPLOAD field to a new value. */
#define BW_PMU_REG_1P0D_ENABLE_PWRUPLOAD(x, v) (HW_PMU_REG_1P0D_WR(x, (HW_PMU_REG_1P0D_RD(x) & ~BM_PMU_REG_1P0D_ENABLE_PWRUPLOAD) | BF_PMU_REG_1P0D_ENABLE_PWRUPLOAD(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0D, field OUTPUT_TRG[12:8] (RW)
 *
 * Control bits to adjust the regulator output voltage in 25mV steps. 0x18 -
 * 1.2V; 0x10 - 1.0V; 0x08 - 0.8V. Note that the programmable output of the
 * regulator excedes the maximum and minimum supply limits for the chip.
 */
/*@{*/
#define BP_PMU_REG_1P0D_OUTPUT_TRG (8U)    /*!< Bit position for PMU_REG_1P0D_OUTPUT_TRG. */
#define BM_PMU_REG_1P0D_OUTPUT_TRG (0x00001F00U) /*!< Bit mask for PMU_REG_1P0D_OUTPUT_TRG. */
#define BS_PMU_REG_1P0D_OUTPUT_TRG (5U)    /*!< Bit field size in bits for PMU_REG_1P0D_OUTPUT_TRG. */

/*! @brief Read current value of the PMU_REG_1P0D_OUTPUT_TRG field. */
#define BR_PMU_REG_1P0D_OUTPUT_TRG(x) (HW_PMU_REG_1P0D(x).B.OUTPUT_TRG)

/*! @brief Format value for bitfield PMU_REG_1P0D_OUTPUT_TRG. */
#define BF_PMU_REG_1P0D_OUTPUT_TRG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0D_OUTPUT_TRG) & BM_PMU_REG_1P0D_OUTPUT_TRG)

/*! @brief Set the OUTPUT_TRG field to a new value. */
#define BW_PMU_REG_1P0D_OUTPUT_TRG(x, v) (HW_PMU_REG_1P0D_WR(x, (HW_PMU_REG_1P0D_RD(x) & ~BM_PMU_REG_1P0D_OUTPUT_TRG) | BF_PMU_REG_1P0D_OUTPUT_TRG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0D, field RSVD0[15:13] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_PMU_REG_1P0D_RSVD0 (13U)        /*!< Bit position for PMU_REG_1P0D_RSVD0. */
#define BM_PMU_REG_1P0D_RSVD0 (0x0000E000U) /*!< Bit mask for PMU_REG_1P0D_RSVD0. */
#define BS_PMU_REG_1P0D_RSVD0 (3U)         /*!< Bit field size in bits for PMU_REG_1P0D_RSVD0. */

/*! @brief Read current value of the PMU_REG_1P0D_RSVD0 field. */
#define BR_PMU_REG_1P0D_RSVD0(x) (HW_PMU_REG_1P0D(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PMU_REG_1P0D, field BO[16] (RW)
 *
 * Interrupt/status bit that signals when a brown-out is detected on the
 * regulator output. Sticky bit, write 1 to this field to clear.
 */
/*@{*/
#define BP_PMU_REG_1P0D_BO   (16U)         /*!< Bit position for PMU_REG_1P0D_BO. */
#define BM_PMU_REG_1P0D_BO   (0x00010000U) /*!< Bit mask for PMU_REG_1P0D_BO. */
#define BS_PMU_REG_1P0D_BO   (1U)          /*!< Bit field size in bits for PMU_REG_1P0D_BO. */

/*! @brief Read current value of the PMU_REG_1P0D_BO field. */
#define BR_PMU_REG_1P0D_BO(x) (HW_PMU_REG_1P0D(x).B.BO)

/*! @brief Format value for bitfield PMU_REG_1P0D_BO. */
#define BF_PMU_REG_1P0D_BO(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0D_BO) & BM_PMU_REG_1P0D_BO)

/*! @brief Set the BO field to a new value. */
#define BW_PMU_REG_1P0D_BO(x, v) (HW_PMU_REG_1P0D_WR(x, (HW_PMU_REG_1P0D_RD(x) & ~BM_PMU_REG_1P0D_BO) | BF_PMU_REG_1P0D_BO(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0D, field OK[17] (RO)
 *
 * Status bit that signals when the regulator output is ok.
 */
/*@{*/
#define BP_PMU_REG_1P0D_OK   (17U)         /*!< Bit position for PMU_REG_1P0D_OK. */
#define BM_PMU_REG_1P0D_OK   (0x00020000U) /*!< Bit mask for PMU_REG_1P0D_OK. */
#define BS_PMU_REG_1P0D_OK   (1U)          /*!< Bit field size in bits for PMU_REG_1P0D_OK. */

/*! @brief Read current value of the PMU_REG_1P0D_OK field. */
#define BR_PMU_REG_1P0D_OK(x) (HW_PMU_REG_1P0D(x).B.OK)
/*@}*/

/*!
 * @name Register PMU_REG_1P0D, field ENABLE_WEAK_LINREG[18] (RW)
 *
 * Enables the weak 1p1 regulator. This regulator can be used when the main 1p1
 * regulator is disabled, under low-power conditions.
 */
/*@{*/
#define BP_PMU_REG_1P0D_ENABLE_WEAK_LINREG (18U) /*!< Bit position for PMU_REG_1P0D_ENABLE_WEAK_LINREG. */
#define BM_PMU_REG_1P0D_ENABLE_WEAK_LINREG (0x00040000U) /*!< Bit mask for PMU_REG_1P0D_ENABLE_WEAK_LINREG. */
#define BS_PMU_REG_1P0D_ENABLE_WEAK_LINREG (1U) /*!< Bit field size in bits for PMU_REG_1P0D_ENABLE_WEAK_LINREG. */

/*! @brief Read current value of the PMU_REG_1P0D_ENABLE_WEAK_LINREG field. */
#define BR_PMU_REG_1P0D_ENABLE_WEAK_LINREG(x) (HW_PMU_REG_1P0D(x).B.ENABLE_WEAK_LINREG)

/*! @brief Format value for bitfield PMU_REG_1P0D_ENABLE_WEAK_LINREG. */
#define BF_PMU_REG_1P0D_ENABLE_WEAK_LINREG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0D_ENABLE_WEAK_LINREG) & BM_PMU_REG_1P0D_ENABLE_WEAK_LINREG)

/*! @brief Set the ENABLE_WEAK_LINREG field to a new value. */
#define BW_PMU_REG_1P0D_ENABLE_WEAK_LINREG(x, v) (HW_PMU_REG_1P0D_WR(x, (HW_PMU_REG_1P0D_RD(x) & ~BM_PMU_REG_1P0D_ENABLE_WEAK_LINREG) | BF_PMU_REG_1P0D_ENABLE_WEAK_LINREG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0D, field SELREF_WEAK_LINREG[19] (RW)
 *
 * Selects the source for the reference voltage of the weak 1p1 regulator:
 * 0x0=weak-linreg output tracks low-power-bandgap voltage, 0x1=weak-linreg output
 * tracks VDD_SOC_CAP voltage.
 */
/*@{*/
#define BP_PMU_REG_1P0D_SELREF_WEAK_LINREG (19U) /*!< Bit position for PMU_REG_1P0D_SELREF_WEAK_LINREG. */
#define BM_PMU_REG_1P0D_SELREF_WEAK_LINREG (0x00080000U) /*!< Bit mask for PMU_REG_1P0D_SELREF_WEAK_LINREG. */
#define BS_PMU_REG_1P0D_SELREF_WEAK_LINREG (1U) /*!< Bit field size in bits for PMU_REG_1P0D_SELREF_WEAK_LINREG. */

/*! @brief Read current value of the PMU_REG_1P0D_SELREF_WEAK_LINREG field. */
#define BR_PMU_REG_1P0D_SELREF_WEAK_LINREG(x) (HW_PMU_REG_1P0D(x).B.SELREF_WEAK_LINREG)

/*! @brief Format value for bitfield PMU_REG_1P0D_SELREF_WEAK_LINREG. */
#define BF_PMU_REG_1P0D_SELREF_WEAK_LINREG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0D_SELREF_WEAK_LINREG) & BM_PMU_REG_1P0D_SELREF_WEAK_LINREG)

/*! @brief Set the SELREF_WEAK_LINREG field to a new value. */
#define BW_PMU_REG_1P0D_SELREF_WEAK_LINREG(x, v) (HW_PMU_REG_1P0D_WR(x, (HW_PMU_REG_1P0D_RD(x) & ~BM_PMU_REG_1P0D_SELREF_WEAK_LINREG) | BF_PMU_REG_1P0D_SELREF_WEAK_LINREG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0D, field REG_TEST[23:20] (RW)
 *
 * Test bits to monitor different analog signals though anamux.
 */
/*@{*/
#define BP_PMU_REG_1P0D_REG_TEST (20U)     /*!< Bit position for PMU_REG_1P0D_REG_TEST. */
#define BM_PMU_REG_1P0D_REG_TEST (0x00F00000U) /*!< Bit mask for PMU_REG_1P0D_REG_TEST. */
#define BS_PMU_REG_1P0D_REG_TEST (4U)      /*!< Bit field size in bits for PMU_REG_1P0D_REG_TEST. */

/*! @brief Read current value of the PMU_REG_1P0D_REG_TEST field. */
#define BR_PMU_REG_1P0D_REG_TEST(x) (HW_PMU_REG_1P0D(x).B.REG_TEST)

/*! @brief Format value for bitfield PMU_REG_1P0D_REG_TEST. */
#define BF_PMU_REG_1P0D_REG_TEST(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0D_REG_TEST) & BM_PMU_REG_1P0D_REG_TEST)

/*! @brief Set the REG_TEST field to a new value. */
#define BW_PMU_REG_1P0D_REG_TEST(x, v) (HW_PMU_REG_1P0D_WR(x, (HW_PMU_REG_1P0D_RD(x) & ~BM_PMU_REG_1P0D_REG_TEST) | BF_PMU_REG_1P0D_REG_TEST(v)))
/*@}*/

/*!
 * @name Register PMU_REG_1P0D, field RSVD1[30:24] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_PMU_REG_1P0D_RSVD1 (24U)        /*!< Bit position for PMU_REG_1P0D_RSVD1. */
#define BM_PMU_REG_1P0D_RSVD1 (0x7F000000U) /*!< Bit mask for PMU_REG_1P0D_RSVD1. */
#define BS_PMU_REG_1P0D_RSVD1 (7U)         /*!< Bit field size in bits for PMU_REG_1P0D_RSVD1. */

/*! @brief Read current value of the PMU_REG_1P0D_RSVD1 field. */
#define BR_PMU_REG_1P0D_RSVD1(x) (HW_PMU_REG_1P0D(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PMU_REG_1P0D, field OVERRIDE[31] (RW)
 *
 * The OVERRIDE bit allows the GPC module to automatically override portions of
 * the register.
 */
/*@{*/
#define BP_PMU_REG_1P0D_OVERRIDE (31U)     /*!< Bit position for PMU_REG_1P0D_OVERRIDE. */
#define BM_PMU_REG_1P0D_OVERRIDE (0x80000000U) /*!< Bit mask for PMU_REG_1P0D_OVERRIDE. */
#define BS_PMU_REG_1P0D_OVERRIDE (1U)      /*!< Bit field size in bits for PMU_REG_1P0D_OVERRIDE. */

/*! @brief Read current value of the PMU_REG_1P0D_OVERRIDE field. */
#define BR_PMU_REG_1P0D_OVERRIDE(x) (HW_PMU_REG_1P0D(x).B.OVERRIDE)

/*! @brief Format value for bitfield PMU_REG_1P0D_OVERRIDE. */
#define BF_PMU_REG_1P0D_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_1P0D_OVERRIDE) & BM_PMU_REG_1P0D_OVERRIDE)

/*! @brief Set the OVERRIDE field to a new value. */
#define BW_PMU_REG_1P0D_OVERRIDE(x, v) (HW_PMU_REG_1P0D_WR(x, (HW_PMU_REG_1P0D_RD(x) & ~BM_PMU_REG_1P0D_OVERRIDE) | BF_PMU_REG_1P0D_OVERRIDE(v)))
/*@}*/




/*******************************************************************************
 * HW_PMU_REG_HSIC_1P2 - Anadig 1.2V HSIC Regulator Control Register
 ******************************************************************************/

/*!
 * @brief HW_PMU_REG_HSIC_1P2 - Anadig 1.2V HSIC Regulator Control Register (RW)
 *
 * Reset value: 0x00001878U
 *
 * This register defines the control and status bits for the 1.1V regulator.
 * This regulator is designed to power the digital portions of the analog cells.
 */
typedef union _hw_pmu_reg_hsic_1p2
{
    uint32_t U;
    struct _hw_pmu_reg_hsic_1p2_bitfields
    {
        uint32_t ENABLE_LINREG : 1;    /*!< [0]  */
        uint32_t ENABLE_BO : 1;        /*!< [1]  */
        uint32_t ENABLE_ILIMIT : 1;    /*!< [2]  */
        uint32_t ENABLE_PULLDOWN : 1;  /*!< [3]  */
        uint32_t BO_OFFSET : 3;        /*!< [6:4]  */
        uint32_t ENABLE_PWRUPLOAD : 1; /*!< [7]  */
        uint32_t OUTPUT_TRG : 5;       /*!< [12:8]  */
        uint32_t RSVD0 : 3;            /*!< [15:13]  */
        uint32_t BO : 1;               /*!< [16]  */
        uint32_t OK : 1;               /*!< [17]  */
        uint32_t ENABLE_WEAK_LINREG : 1; /*!< [18]  */
        uint32_t SELREF_WEAK_LINREG : 1; /*!< [19]  */
        uint32_t REG_TEST : 4;         /*!< [23:20]  */
        uint32_t RSVD1 : 7;            /*!< [30:24]  */
        uint32_t OVERRIDE : 1;         /*!< [31]  */
    } B;
} hw_pmu_reg_hsic_1p2_t;

/*!
 * @name Constants and macros for entire PMU_REG_HSIC_1P2 register
 */
/*@{*/
#define HW_PMU_REG_HSIC_1P2_ADDR(x) ((uintptr_t)(x) + 0x220U)
#define HW_PMU_REG_HSIC_1P2_SET_ADDR(x) (HW_PMU_REG_HSIC_1P2_ADDR(x) + 0x4U)
#define HW_PMU_REG_HSIC_1P2_CLR_ADDR(x) (HW_PMU_REG_HSIC_1P2_ADDR(x) + 0x8U)
#define HW_PMU_REG_HSIC_1P2_TOG_ADDR(x) (HW_PMU_REG_HSIC_1P2_ADDR(x) + 0xCU)

#define HW_PMU_REG_HSIC_1P2(x)   (*(__IO hw_pmu_reg_hsic_1p2_t *) HW_PMU_REG_HSIC_1P2_ADDR(x))
#define HW_PMU_REG_HSIC_1P2_RD(x) (HW_PMU_REG_HSIC_1P2(x).U)
#define HW_PMU_REG_HSIC_1P2_WR(x, v) (HW_PMU_REG_HSIC_1P2(x).U = (v))
#define HW_PMU_REG_HSIC_1P2_SET(x, v) ((*(uint32_t *) HW_PMU_REG_HSIC_1P2_SET_ADDR(x)) = (v))
#define HW_PMU_REG_HSIC_1P2_CLR(x, v) ((*(uint32_t *) HW_PMU_REG_HSIC_1P2_CLR_ADDR(x)) = (v))
#define HW_PMU_REG_HSIC_1P2_TOG(x, v) ((*(uint32_t *) HW_PMU_REG_HSIC_1P2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual PMU_REG_HSIC_1P2 bitfields
 */

/*!
 * @name Register PMU_REG_HSIC_1P2, field ENABLE_LINREG[0] (RW)
 *
 * Control bit to enable the regulator output.
 */
/*@{*/
#define BP_PMU_REG_HSIC_1P2_ENABLE_LINREG (0U) /*!< Bit position for PMU_REG_HSIC_1P2_ENABLE_LINREG. */
#define BM_PMU_REG_HSIC_1P2_ENABLE_LINREG (0x00000001U) /*!< Bit mask for PMU_REG_HSIC_1P2_ENABLE_LINREG. */
#define BS_PMU_REG_HSIC_1P2_ENABLE_LINREG (1U) /*!< Bit field size in bits for PMU_REG_HSIC_1P2_ENABLE_LINREG. */

/*! @brief Read current value of the PMU_REG_HSIC_1P2_ENABLE_LINREG field. */
#define BR_PMU_REG_HSIC_1P2_ENABLE_LINREG(x) (HW_PMU_REG_HSIC_1P2(x).B.ENABLE_LINREG)

/*! @brief Format value for bitfield PMU_REG_HSIC_1P2_ENABLE_LINREG. */
#define BF_PMU_REG_HSIC_1P2_ENABLE_LINREG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_HSIC_1P2_ENABLE_LINREG) & BM_PMU_REG_HSIC_1P2_ENABLE_LINREG)

/*! @brief Set the ENABLE_LINREG field to a new value. */
#define BW_PMU_REG_HSIC_1P2_ENABLE_LINREG(x, v) (HW_PMU_REG_HSIC_1P2_WR(x, (HW_PMU_REG_HSIC_1P2_RD(x) & ~BM_PMU_REG_HSIC_1P2_ENABLE_LINREG) | BF_PMU_REG_HSIC_1P2_ENABLE_LINREG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_HSIC_1P2, field ENABLE_BO[1] (RW)
 *
 * Control bit to enable the brown-out circuitry in the regulator.
 */
/*@{*/
#define BP_PMU_REG_HSIC_1P2_ENABLE_BO (1U) /*!< Bit position for PMU_REG_HSIC_1P2_ENABLE_BO. */
#define BM_PMU_REG_HSIC_1P2_ENABLE_BO (0x00000002U) /*!< Bit mask for PMU_REG_HSIC_1P2_ENABLE_BO. */
#define BS_PMU_REG_HSIC_1P2_ENABLE_BO (1U) /*!< Bit field size in bits for PMU_REG_HSIC_1P2_ENABLE_BO. */

/*! @brief Read current value of the PMU_REG_HSIC_1P2_ENABLE_BO field. */
#define BR_PMU_REG_HSIC_1P2_ENABLE_BO(x) (HW_PMU_REG_HSIC_1P2(x).B.ENABLE_BO)

/*! @brief Format value for bitfield PMU_REG_HSIC_1P2_ENABLE_BO. */
#define BF_PMU_REG_HSIC_1P2_ENABLE_BO(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_HSIC_1P2_ENABLE_BO) & BM_PMU_REG_HSIC_1P2_ENABLE_BO)

/*! @brief Set the ENABLE_BO field to a new value. */
#define BW_PMU_REG_HSIC_1P2_ENABLE_BO(x, v) (HW_PMU_REG_HSIC_1P2_WR(x, (HW_PMU_REG_HSIC_1P2_RD(x) & ~BM_PMU_REG_HSIC_1P2_ENABLE_BO) | BF_PMU_REG_HSIC_1P2_ENABLE_BO(v)))
/*@}*/

/*!
 * @name Register PMU_REG_HSIC_1P2, field ENABLE_ILIMIT[2] (RW)
 *
 * Control bit to enable the current-limit circuitry in the regulator.
 */
/*@{*/
#define BP_PMU_REG_HSIC_1P2_ENABLE_ILIMIT (2U) /*!< Bit position for PMU_REG_HSIC_1P2_ENABLE_ILIMIT. */
#define BM_PMU_REG_HSIC_1P2_ENABLE_ILIMIT (0x00000004U) /*!< Bit mask for PMU_REG_HSIC_1P2_ENABLE_ILIMIT. */
#define BS_PMU_REG_HSIC_1P2_ENABLE_ILIMIT (1U) /*!< Bit field size in bits for PMU_REG_HSIC_1P2_ENABLE_ILIMIT. */

/*! @brief Read current value of the PMU_REG_HSIC_1P2_ENABLE_ILIMIT field. */
#define BR_PMU_REG_HSIC_1P2_ENABLE_ILIMIT(x) (HW_PMU_REG_HSIC_1P2(x).B.ENABLE_ILIMIT)

/*! @brief Format value for bitfield PMU_REG_HSIC_1P2_ENABLE_ILIMIT. */
#define BF_PMU_REG_HSIC_1P2_ENABLE_ILIMIT(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_HSIC_1P2_ENABLE_ILIMIT) & BM_PMU_REG_HSIC_1P2_ENABLE_ILIMIT)

/*! @brief Set the ENABLE_ILIMIT field to a new value. */
#define BW_PMU_REG_HSIC_1P2_ENABLE_ILIMIT(x, v) (HW_PMU_REG_HSIC_1P2_WR(x, (HW_PMU_REG_HSIC_1P2_RD(x) & ~BM_PMU_REG_HSIC_1P2_ENABLE_ILIMIT) | BF_PMU_REG_HSIC_1P2_ENABLE_ILIMIT(v)))
/*@}*/

/*!
 * @name Register PMU_REG_HSIC_1P2, field ENABLE_PULLDOWN[3] (RW)
 *
 * Control bit to enable the pull-down circuitry in the regulator
 */
/*@{*/
#define BP_PMU_REG_HSIC_1P2_ENABLE_PULLDOWN (3U) /*!< Bit position for PMU_REG_HSIC_1P2_ENABLE_PULLDOWN. */
#define BM_PMU_REG_HSIC_1P2_ENABLE_PULLDOWN (0x00000008U) /*!< Bit mask for PMU_REG_HSIC_1P2_ENABLE_PULLDOWN. */
#define BS_PMU_REG_HSIC_1P2_ENABLE_PULLDOWN (1U) /*!< Bit field size in bits for PMU_REG_HSIC_1P2_ENABLE_PULLDOWN. */

/*! @brief Read current value of the PMU_REG_HSIC_1P2_ENABLE_PULLDOWN field. */
#define BR_PMU_REG_HSIC_1P2_ENABLE_PULLDOWN(x) (HW_PMU_REG_HSIC_1P2(x).B.ENABLE_PULLDOWN)

/*! @brief Format value for bitfield PMU_REG_HSIC_1P2_ENABLE_PULLDOWN. */
#define BF_PMU_REG_HSIC_1P2_ENABLE_PULLDOWN(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_HSIC_1P2_ENABLE_PULLDOWN) & BM_PMU_REG_HSIC_1P2_ENABLE_PULLDOWN)

/*! @brief Set the ENABLE_PULLDOWN field to a new value. */
#define BW_PMU_REG_HSIC_1P2_ENABLE_PULLDOWN(x, v) (HW_PMU_REG_HSIC_1P2_WR(x, (HW_PMU_REG_HSIC_1P2_RD(x) & ~BM_PMU_REG_HSIC_1P2_ENABLE_PULLDOWN) | BF_PMU_REG_HSIC_1P2_ENABLE_PULLDOWN(v)))
/*@}*/

/*!
 * @name Register PMU_REG_HSIC_1P2, field BO_OFFSET[6:4] (RW)
 *
 * Control bits to adjust the regulator brown-out offset voltage in 25mV steps.
 * The brown-out level is relative to the programmed target voltage. The reset
 * brown-out offset is 175mV below the programmed target code.
 */
/*@{*/
#define BP_PMU_REG_HSIC_1P2_BO_OFFSET (4U) /*!< Bit position for PMU_REG_HSIC_1P2_BO_OFFSET. */
#define BM_PMU_REG_HSIC_1P2_BO_OFFSET (0x00000070U) /*!< Bit mask for PMU_REG_HSIC_1P2_BO_OFFSET. */
#define BS_PMU_REG_HSIC_1P2_BO_OFFSET (3U) /*!< Bit field size in bits for PMU_REG_HSIC_1P2_BO_OFFSET. */

/*! @brief Read current value of the PMU_REG_HSIC_1P2_BO_OFFSET field. */
#define BR_PMU_REG_HSIC_1P2_BO_OFFSET(x) (HW_PMU_REG_HSIC_1P2(x).B.BO_OFFSET)

/*! @brief Format value for bitfield PMU_REG_HSIC_1P2_BO_OFFSET. */
#define BF_PMU_REG_HSIC_1P2_BO_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_HSIC_1P2_BO_OFFSET) & BM_PMU_REG_HSIC_1P2_BO_OFFSET)

/*! @brief Set the BO_OFFSET field to a new value. */
#define BW_PMU_REG_HSIC_1P2_BO_OFFSET(x, v) (HW_PMU_REG_HSIC_1P2_WR(x, (HW_PMU_REG_HSIC_1P2_RD(x) & ~BM_PMU_REG_HSIC_1P2_BO_OFFSET) | BF_PMU_REG_HSIC_1P2_BO_OFFSET(v)))
/*@}*/

/*!
 * @name Register PMU_REG_HSIC_1P2, field ENABLE_PWRUPLOAD[7] (RW)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_PMU_REG_HSIC_1P2_ENABLE_PWRUPLOAD (7U) /*!< Bit position for PMU_REG_HSIC_1P2_ENABLE_PWRUPLOAD. */
#define BM_PMU_REG_HSIC_1P2_ENABLE_PWRUPLOAD (0x00000080U) /*!< Bit mask for PMU_REG_HSIC_1P2_ENABLE_PWRUPLOAD. */
#define BS_PMU_REG_HSIC_1P2_ENABLE_PWRUPLOAD (1U) /*!< Bit field size in bits for PMU_REG_HSIC_1P2_ENABLE_PWRUPLOAD. */

/*! @brief Read current value of the PMU_REG_HSIC_1P2_ENABLE_PWRUPLOAD field. */
#define BR_PMU_REG_HSIC_1P2_ENABLE_PWRUPLOAD(x) (HW_PMU_REG_HSIC_1P2(x).B.ENABLE_PWRUPLOAD)

/*! @brief Format value for bitfield PMU_REG_HSIC_1P2_ENABLE_PWRUPLOAD. */
#define BF_PMU_REG_HSIC_1P2_ENABLE_PWRUPLOAD(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_HSIC_1P2_ENABLE_PWRUPLOAD) & BM_PMU_REG_HSIC_1P2_ENABLE_PWRUPLOAD)

/*! @brief Set the ENABLE_PWRUPLOAD field to a new value. */
#define BW_PMU_REG_HSIC_1P2_ENABLE_PWRUPLOAD(x, v) (HW_PMU_REG_HSIC_1P2_WR(x, (HW_PMU_REG_HSIC_1P2_RD(x) & ~BM_PMU_REG_HSIC_1P2_ENABLE_PWRUPLOAD) | BF_PMU_REG_HSIC_1P2_ENABLE_PWRUPLOAD(v)))
/*@}*/

/*!
 * @name Register PMU_REG_HSIC_1P2, field OUTPUT_TRG[12:8] (RW)
 *
 * Control bits to adjust the regulator output voltage in 25mV steps. 0x1c -
 * 1.3V; 0x18 - 1.2V; 0x14 - 1.1V. Note that the programmable output of the
 * regulator excedes the maximum and minimum supply limits for the chip.
 */
/*@{*/
#define BP_PMU_REG_HSIC_1P2_OUTPUT_TRG (8U) /*!< Bit position for PMU_REG_HSIC_1P2_OUTPUT_TRG. */
#define BM_PMU_REG_HSIC_1P2_OUTPUT_TRG (0x00001F00U) /*!< Bit mask for PMU_REG_HSIC_1P2_OUTPUT_TRG. */
#define BS_PMU_REG_HSIC_1P2_OUTPUT_TRG (5U) /*!< Bit field size in bits for PMU_REG_HSIC_1P2_OUTPUT_TRG. */

/*! @brief Read current value of the PMU_REG_HSIC_1P2_OUTPUT_TRG field. */
#define BR_PMU_REG_HSIC_1P2_OUTPUT_TRG(x) (HW_PMU_REG_HSIC_1P2(x).B.OUTPUT_TRG)

/*! @brief Format value for bitfield PMU_REG_HSIC_1P2_OUTPUT_TRG. */
#define BF_PMU_REG_HSIC_1P2_OUTPUT_TRG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_HSIC_1P2_OUTPUT_TRG) & BM_PMU_REG_HSIC_1P2_OUTPUT_TRG)

/*! @brief Set the OUTPUT_TRG field to a new value. */
#define BW_PMU_REG_HSIC_1P2_OUTPUT_TRG(x, v) (HW_PMU_REG_HSIC_1P2_WR(x, (HW_PMU_REG_HSIC_1P2_RD(x) & ~BM_PMU_REG_HSIC_1P2_OUTPUT_TRG) | BF_PMU_REG_HSIC_1P2_OUTPUT_TRG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_HSIC_1P2, field RSVD0[15:13] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_PMU_REG_HSIC_1P2_RSVD0 (13U)    /*!< Bit position for PMU_REG_HSIC_1P2_RSVD0. */
#define BM_PMU_REG_HSIC_1P2_RSVD0 (0x0000E000U) /*!< Bit mask for PMU_REG_HSIC_1P2_RSVD0. */
#define BS_PMU_REG_HSIC_1P2_RSVD0 (3U)     /*!< Bit field size in bits for PMU_REG_HSIC_1P2_RSVD0. */

/*! @brief Read current value of the PMU_REG_HSIC_1P2_RSVD0 field. */
#define BR_PMU_REG_HSIC_1P2_RSVD0(x) (HW_PMU_REG_HSIC_1P2(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PMU_REG_HSIC_1P2, field BO[16] (RW)
 *
 * Interrupt/status bit that signals when a brown-out is detected on the
 * regulator output. Sticky bit, write 1 to this field to clear.
 */
/*@{*/
#define BP_PMU_REG_HSIC_1P2_BO (16U)       /*!< Bit position for PMU_REG_HSIC_1P2_BO. */
#define BM_PMU_REG_HSIC_1P2_BO (0x00010000U) /*!< Bit mask for PMU_REG_HSIC_1P2_BO. */
#define BS_PMU_REG_HSIC_1P2_BO (1U)        /*!< Bit field size in bits for PMU_REG_HSIC_1P2_BO. */

/*! @brief Read current value of the PMU_REG_HSIC_1P2_BO field. */
#define BR_PMU_REG_HSIC_1P2_BO(x) (HW_PMU_REG_HSIC_1P2(x).B.BO)

/*! @brief Format value for bitfield PMU_REG_HSIC_1P2_BO. */
#define BF_PMU_REG_HSIC_1P2_BO(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_HSIC_1P2_BO) & BM_PMU_REG_HSIC_1P2_BO)

/*! @brief Set the BO field to a new value. */
#define BW_PMU_REG_HSIC_1P2_BO(x, v) (HW_PMU_REG_HSIC_1P2_WR(x, (HW_PMU_REG_HSIC_1P2_RD(x) & ~BM_PMU_REG_HSIC_1P2_BO) | BF_PMU_REG_HSIC_1P2_BO(v)))
/*@}*/

/*!
 * @name Register PMU_REG_HSIC_1P2, field OK[17] (RO)
 *
 * Status bit that signals when the regulator output is ok.
 */
/*@{*/
#define BP_PMU_REG_HSIC_1P2_OK (17U)       /*!< Bit position for PMU_REG_HSIC_1P2_OK. */
#define BM_PMU_REG_HSIC_1P2_OK (0x00020000U) /*!< Bit mask for PMU_REG_HSIC_1P2_OK. */
#define BS_PMU_REG_HSIC_1P2_OK (1U)        /*!< Bit field size in bits for PMU_REG_HSIC_1P2_OK. */

/*! @brief Read current value of the PMU_REG_HSIC_1P2_OK field. */
#define BR_PMU_REG_HSIC_1P2_OK(x) (HW_PMU_REG_HSIC_1P2(x).B.OK)
/*@}*/

/*!
 * @name Register PMU_REG_HSIC_1P2, field ENABLE_WEAK_LINREG[18] (RW)
 *
 * Enables the weak 1p1 regulator. This regulator can be used when the main 1p1
 * regulator is disabled, under low-power conditions.
 */
/*@{*/
#define BP_PMU_REG_HSIC_1P2_ENABLE_WEAK_LINREG (18U) /*!< Bit position for PMU_REG_HSIC_1P2_ENABLE_WEAK_LINREG. */
#define BM_PMU_REG_HSIC_1P2_ENABLE_WEAK_LINREG (0x00040000U) /*!< Bit mask for PMU_REG_HSIC_1P2_ENABLE_WEAK_LINREG. */
#define BS_PMU_REG_HSIC_1P2_ENABLE_WEAK_LINREG (1U) /*!< Bit field size in bits for PMU_REG_HSIC_1P2_ENABLE_WEAK_LINREG. */

/*! @brief Read current value of the PMU_REG_HSIC_1P2_ENABLE_WEAK_LINREG field. */
#define BR_PMU_REG_HSIC_1P2_ENABLE_WEAK_LINREG(x) (HW_PMU_REG_HSIC_1P2(x).B.ENABLE_WEAK_LINREG)

/*! @brief Format value for bitfield PMU_REG_HSIC_1P2_ENABLE_WEAK_LINREG. */
#define BF_PMU_REG_HSIC_1P2_ENABLE_WEAK_LINREG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_HSIC_1P2_ENABLE_WEAK_LINREG) & BM_PMU_REG_HSIC_1P2_ENABLE_WEAK_LINREG)

/*! @brief Set the ENABLE_WEAK_LINREG field to a new value. */
#define BW_PMU_REG_HSIC_1P2_ENABLE_WEAK_LINREG(x, v) (HW_PMU_REG_HSIC_1P2_WR(x, (HW_PMU_REG_HSIC_1P2_RD(x) & ~BM_PMU_REG_HSIC_1P2_ENABLE_WEAK_LINREG) | BF_PMU_REG_HSIC_1P2_ENABLE_WEAK_LINREG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_HSIC_1P2, field SELREF_WEAK_LINREG[19] (RW)
 *
 * Selects the source for the reference voltage of the weak 1p1 regulator:
 * 0x0=weak-linreg output tracks low-power-bandgap voltage, 0x1=weak-linreg output
 * tracks VDD_SOC_CAP voltage.
 */
/*@{*/
#define BP_PMU_REG_HSIC_1P2_SELREF_WEAK_LINREG (19U) /*!< Bit position for PMU_REG_HSIC_1P2_SELREF_WEAK_LINREG. */
#define BM_PMU_REG_HSIC_1P2_SELREF_WEAK_LINREG (0x00080000U) /*!< Bit mask for PMU_REG_HSIC_1P2_SELREF_WEAK_LINREG. */
#define BS_PMU_REG_HSIC_1P2_SELREF_WEAK_LINREG (1U) /*!< Bit field size in bits for PMU_REG_HSIC_1P2_SELREF_WEAK_LINREG. */

/*! @brief Read current value of the PMU_REG_HSIC_1P2_SELREF_WEAK_LINREG field. */
#define BR_PMU_REG_HSIC_1P2_SELREF_WEAK_LINREG(x) (HW_PMU_REG_HSIC_1P2(x).B.SELREF_WEAK_LINREG)

/*! @brief Format value for bitfield PMU_REG_HSIC_1P2_SELREF_WEAK_LINREG. */
#define BF_PMU_REG_HSIC_1P2_SELREF_WEAK_LINREG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_HSIC_1P2_SELREF_WEAK_LINREG) & BM_PMU_REG_HSIC_1P2_SELREF_WEAK_LINREG)

/*! @brief Set the SELREF_WEAK_LINREG field to a new value. */
#define BW_PMU_REG_HSIC_1P2_SELREF_WEAK_LINREG(x, v) (HW_PMU_REG_HSIC_1P2_WR(x, (HW_PMU_REG_HSIC_1P2_RD(x) & ~BM_PMU_REG_HSIC_1P2_SELREF_WEAK_LINREG) | BF_PMU_REG_HSIC_1P2_SELREF_WEAK_LINREG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_HSIC_1P2, field REG_TEST[23:20] (RW)
 *
 * Test bits to monitor different analog signals though anamux.
 */
/*@{*/
#define BP_PMU_REG_HSIC_1P2_REG_TEST (20U) /*!< Bit position for PMU_REG_HSIC_1P2_REG_TEST. */
#define BM_PMU_REG_HSIC_1P2_REG_TEST (0x00F00000U) /*!< Bit mask for PMU_REG_HSIC_1P2_REG_TEST. */
#define BS_PMU_REG_HSIC_1P2_REG_TEST (4U)  /*!< Bit field size in bits for PMU_REG_HSIC_1P2_REG_TEST. */

/*! @brief Read current value of the PMU_REG_HSIC_1P2_REG_TEST field. */
#define BR_PMU_REG_HSIC_1P2_REG_TEST(x) (HW_PMU_REG_HSIC_1P2(x).B.REG_TEST)

/*! @brief Format value for bitfield PMU_REG_HSIC_1P2_REG_TEST. */
#define BF_PMU_REG_HSIC_1P2_REG_TEST(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_HSIC_1P2_REG_TEST) & BM_PMU_REG_HSIC_1P2_REG_TEST)

/*! @brief Set the REG_TEST field to a new value. */
#define BW_PMU_REG_HSIC_1P2_REG_TEST(x, v) (HW_PMU_REG_HSIC_1P2_WR(x, (HW_PMU_REG_HSIC_1P2_RD(x) & ~BM_PMU_REG_HSIC_1P2_REG_TEST) | BF_PMU_REG_HSIC_1P2_REG_TEST(v)))
/*@}*/

/*!
 * @name Register PMU_REG_HSIC_1P2, field RSVD1[30:24] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_PMU_REG_HSIC_1P2_RSVD1 (24U)    /*!< Bit position for PMU_REG_HSIC_1P2_RSVD1. */
#define BM_PMU_REG_HSIC_1P2_RSVD1 (0x7F000000U) /*!< Bit mask for PMU_REG_HSIC_1P2_RSVD1. */
#define BS_PMU_REG_HSIC_1P2_RSVD1 (7U)     /*!< Bit field size in bits for PMU_REG_HSIC_1P2_RSVD1. */

/*! @brief Read current value of the PMU_REG_HSIC_1P2_RSVD1 field. */
#define BR_PMU_REG_HSIC_1P2_RSVD1(x) (HW_PMU_REG_HSIC_1P2(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PMU_REG_HSIC_1P2, field OVERRIDE[31] (RW)
 *
 * The OVERRIDE bit allows the GPC module to automatically override portions of
 * the register.
 */
/*@{*/
#define BP_PMU_REG_HSIC_1P2_OVERRIDE (31U) /*!< Bit position for PMU_REG_HSIC_1P2_OVERRIDE. */
#define BM_PMU_REG_HSIC_1P2_OVERRIDE (0x80000000U) /*!< Bit mask for PMU_REG_HSIC_1P2_OVERRIDE. */
#define BS_PMU_REG_HSIC_1P2_OVERRIDE (1U)  /*!< Bit field size in bits for PMU_REG_HSIC_1P2_OVERRIDE. */

/*! @brief Read current value of the PMU_REG_HSIC_1P2_OVERRIDE field. */
#define BR_PMU_REG_HSIC_1P2_OVERRIDE(x) (HW_PMU_REG_HSIC_1P2(x).B.OVERRIDE)

/*! @brief Format value for bitfield PMU_REG_HSIC_1P2_OVERRIDE. */
#define BF_PMU_REG_HSIC_1P2_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_HSIC_1P2_OVERRIDE) & BM_PMU_REG_HSIC_1P2_OVERRIDE)

/*! @brief Set the OVERRIDE field to a new value. */
#define BW_PMU_REG_HSIC_1P2_OVERRIDE(x, v) (HW_PMU_REG_HSIC_1P2_WR(x, (HW_PMU_REG_HSIC_1P2_RD(x) & ~BM_PMU_REG_HSIC_1P2_OVERRIDE) | BF_PMU_REG_HSIC_1P2_OVERRIDE(v)))
/*@}*/




/*******************************************************************************
 * HW_PMU_REG_LPSR_1P0 - Anadig 1.0V Low Power State Retention Regulator Control Register
 ******************************************************************************/

/*!
 * @brief HW_PMU_REG_LPSR_1P0 - Anadig 1.0V Low Power State Retention Regulator Control Register (RW)
 *
 * Reset value: 0x000010FBU
 *
 * This register defines the control and status bits for the 1.1V regulator.
 * This regulator is designed to power the digital portions of the analog cells.
 */
typedef union _hw_pmu_reg_lpsr_1p0
{
    uint32_t U;
    struct _hw_pmu_reg_lpsr_1p0_bitfields
    {
        uint32_t ENABLE_LINREG : 1;    /*!< [0]  */
        uint32_t ENABLE_BO : 1;        /*!< [1]  */
        uint32_t ENABLE_ILIMIT : 1;    /*!< [2]  */
        uint32_t ENABLE_PULLDOWN : 1;  /*!< [3]  */
        uint32_t BO_OFFSET : 3;        /*!< [6:4]  */
        uint32_t ENABLE_PWRUPLOAD : 1; /*!< [7]  */
        uint32_t OUTPUT_TRG : 5;       /*!< [12:8]  */
        uint32_t RSVD0 : 3;            /*!< [15:13]  */
        uint32_t BO : 1;               /*!< [16]  */
        uint32_t OK : 1;               /*!< [17]  */
        uint32_t ENABLE_WEAK_LINREG : 1; /*!< [18]  */
        uint32_t SELREF_WEAK_LINREG : 1; /*!< [19]  */
        uint32_t REG_TEST : 4;         /*!< [23:20]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_pmu_reg_lpsr_1p0_t;

/*!
 * @name Constants and macros for entire PMU_REG_LPSR_1P0 register
 */
/*@{*/
#define HW_PMU_REG_LPSR_1P0_ADDR(x) ((uintptr_t)(x) + 0x230U)
#define HW_PMU_REG_LPSR_1P0_SET_ADDR(x) (HW_PMU_REG_LPSR_1P0_ADDR(x) + 0x4U)
#define HW_PMU_REG_LPSR_1P0_CLR_ADDR(x) (HW_PMU_REG_LPSR_1P0_ADDR(x) + 0x8U)
#define HW_PMU_REG_LPSR_1P0_TOG_ADDR(x) (HW_PMU_REG_LPSR_1P0_ADDR(x) + 0xCU)

#define HW_PMU_REG_LPSR_1P0(x)   (*(__IO hw_pmu_reg_lpsr_1p0_t *) HW_PMU_REG_LPSR_1P0_ADDR(x))
#define HW_PMU_REG_LPSR_1P0_RD(x) (HW_PMU_REG_LPSR_1P0(x).U)
#define HW_PMU_REG_LPSR_1P0_WR(x, v) (HW_PMU_REG_LPSR_1P0(x).U = (v))
#define HW_PMU_REG_LPSR_1P0_SET(x, v) ((*(uint32_t *) HW_PMU_REG_LPSR_1P0_SET_ADDR(x)) = (v))
#define HW_PMU_REG_LPSR_1P0_CLR(x, v) ((*(uint32_t *) HW_PMU_REG_LPSR_1P0_CLR_ADDR(x)) = (v))
#define HW_PMU_REG_LPSR_1P0_TOG(x, v) ((*(uint32_t *) HW_PMU_REG_LPSR_1P0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual PMU_REG_LPSR_1P0 bitfields
 */

/*!
 * @name Register PMU_REG_LPSR_1P0, field ENABLE_LINREG[0] (RW)
 *
 * Always enabled, field not used
 */
/*@{*/
#define BP_PMU_REG_LPSR_1P0_ENABLE_LINREG (0U) /*!< Bit position for PMU_REG_LPSR_1P0_ENABLE_LINREG. */
#define BM_PMU_REG_LPSR_1P0_ENABLE_LINREG (0x00000001U) /*!< Bit mask for PMU_REG_LPSR_1P0_ENABLE_LINREG. */
#define BS_PMU_REG_LPSR_1P0_ENABLE_LINREG (1U) /*!< Bit field size in bits for PMU_REG_LPSR_1P0_ENABLE_LINREG. */

/*! @brief Read current value of the PMU_REG_LPSR_1P0_ENABLE_LINREG field. */
#define BR_PMU_REG_LPSR_1P0_ENABLE_LINREG(x) (HW_PMU_REG_LPSR_1P0(x).B.ENABLE_LINREG)

/*! @brief Format value for bitfield PMU_REG_LPSR_1P0_ENABLE_LINREG. */
#define BF_PMU_REG_LPSR_1P0_ENABLE_LINREG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_LPSR_1P0_ENABLE_LINREG) & BM_PMU_REG_LPSR_1P0_ENABLE_LINREG)

/*! @brief Set the ENABLE_LINREG field to a new value. */
#define BW_PMU_REG_LPSR_1P0_ENABLE_LINREG(x, v) (HW_PMU_REG_LPSR_1P0_WR(x, (HW_PMU_REG_LPSR_1P0_RD(x) & ~BM_PMU_REG_LPSR_1P0_ENABLE_LINREG) | BF_PMU_REG_LPSR_1P0_ENABLE_LINREG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_LPSR_1P0, field ENABLE_BO[1] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_PMU_REG_LPSR_1P0_ENABLE_BO (1U) /*!< Bit position for PMU_REG_LPSR_1P0_ENABLE_BO. */
#define BM_PMU_REG_LPSR_1P0_ENABLE_BO (0x00000002U) /*!< Bit mask for PMU_REG_LPSR_1P0_ENABLE_BO. */
#define BS_PMU_REG_LPSR_1P0_ENABLE_BO (1U) /*!< Bit field size in bits for PMU_REG_LPSR_1P0_ENABLE_BO. */

/*! @brief Read current value of the PMU_REG_LPSR_1P0_ENABLE_BO field. */
#define BR_PMU_REG_LPSR_1P0_ENABLE_BO(x) (HW_PMU_REG_LPSR_1P0(x).B.ENABLE_BO)

/*! @brief Format value for bitfield PMU_REG_LPSR_1P0_ENABLE_BO. */
#define BF_PMU_REG_LPSR_1P0_ENABLE_BO(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_LPSR_1P0_ENABLE_BO) & BM_PMU_REG_LPSR_1P0_ENABLE_BO)

/*! @brief Set the ENABLE_BO field to a new value. */
#define BW_PMU_REG_LPSR_1P0_ENABLE_BO(x, v) (HW_PMU_REG_LPSR_1P0_WR(x, (HW_PMU_REG_LPSR_1P0_RD(x) & ~BM_PMU_REG_LPSR_1P0_ENABLE_BO) | BF_PMU_REG_LPSR_1P0_ENABLE_BO(v)))
/*@}*/

/*!
 * @name Register PMU_REG_LPSR_1P0, field ENABLE_ILIMIT[2] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_PMU_REG_LPSR_1P0_ENABLE_ILIMIT (2U) /*!< Bit position for PMU_REG_LPSR_1P0_ENABLE_ILIMIT. */
#define BM_PMU_REG_LPSR_1P0_ENABLE_ILIMIT (0x00000004U) /*!< Bit mask for PMU_REG_LPSR_1P0_ENABLE_ILIMIT. */
#define BS_PMU_REG_LPSR_1P0_ENABLE_ILIMIT (1U) /*!< Bit field size in bits for PMU_REG_LPSR_1P0_ENABLE_ILIMIT. */

/*! @brief Read current value of the PMU_REG_LPSR_1P0_ENABLE_ILIMIT field. */
#define BR_PMU_REG_LPSR_1P0_ENABLE_ILIMIT(x) (HW_PMU_REG_LPSR_1P0(x).B.ENABLE_ILIMIT)

/*! @brief Format value for bitfield PMU_REG_LPSR_1P0_ENABLE_ILIMIT. */
#define BF_PMU_REG_LPSR_1P0_ENABLE_ILIMIT(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_LPSR_1P0_ENABLE_ILIMIT) & BM_PMU_REG_LPSR_1P0_ENABLE_ILIMIT)

/*! @brief Set the ENABLE_ILIMIT field to a new value. */
#define BW_PMU_REG_LPSR_1P0_ENABLE_ILIMIT(x, v) (HW_PMU_REG_LPSR_1P0_WR(x, (HW_PMU_REG_LPSR_1P0_RD(x) & ~BM_PMU_REG_LPSR_1P0_ENABLE_ILIMIT) | BF_PMU_REG_LPSR_1P0_ENABLE_ILIMIT(v)))
/*@}*/

/*!
 * @name Register PMU_REG_LPSR_1P0, field ENABLE_PULLDOWN[3] (RW)
 *
 * Enables a ~50kohm load to ground. Typically software would clear this if not
 * necessary.
 */
/*@{*/
#define BP_PMU_REG_LPSR_1P0_ENABLE_PULLDOWN (3U) /*!< Bit position for PMU_REG_LPSR_1P0_ENABLE_PULLDOWN. */
#define BM_PMU_REG_LPSR_1P0_ENABLE_PULLDOWN (0x00000008U) /*!< Bit mask for PMU_REG_LPSR_1P0_ENABLE_PULLDOWN. */
#define BS_PMU_REG_LPSR_1P0_ENABLE_PULLDOWN (1U) /*!< Bit field size in bits for PMU_REG_LPSR_1P0_ENABLE_PULLDOWN. */

/*! @brief Read current value of the PMU_REG_LPSR_1P0_ENABLE_PULLDOWN field. */
#define BR_PMU_REG_LPSR_1P0_ENABLE_PULLDOWN(x) (HW_PMU_REG_LPSR_1P0(x).B.ENABLE_PULLDOWN)

/*! @brief Format value for bitfield PMU_REG_LPSR_1P0_ENABLE_PULLDOWN. */
#define BF_PMU_REG_LPSR_1P0_ENABLE_PULLDOWN(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_LPSR_1P0_ENABLE_PULLDOWN) & BM_PMU_REG_LPSR_1P0_ENABLE_PULLDOWN)

/*! @brief Set the ENABLE_PULLDOWN field to a new value. */
#define BW_PMU_REG_LPSR_1P0_ENABLE_PULLDOWN(x, v) (HW_PMU_REG_LPSR_1P0_WR(x, (HW_PMU_REG_LPSR_1P0_RD(x) & ~BM_PMU_REG_LPSR_1P0_ENABLE_PULLDOWN) | BF_PMU_REG_LPSR_1P0_ENABLE_PULLDOWN(v)))
/*@}*/

/*!
 * @name Register PMU_REG_LPSR_1P0, field BO_OFFSET[6:4] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_PMU_REG_LPSR_1P0_BO_OFFSET (4U) /*!< Bit position for PMU_REG_LPSR_1P0_BO_OFFSET. */
#define BM_PMU_REG_LPSR_1P0_BO_OFFSET (0x00000070U) /*!< Bit mask for PMU_REG_LPSR_1P0_BO_OFFSET. */
#define BS_PMU_REG_LPSR_1P0_BO_OFFSET (3U) /*!< Bit field size in bits for PMU_REG_LPSR_1P0_BO_OFFSET. */

/*! @brief Read current value of the PMU_REG_LPSR_1P0_BO_OFFSET field. */
#define BR_PMU_REG_LPSR_1P0_BO_OFFSET(x) (HW_PMU_REG_LPSR_1P0(x).B.BO_OFFSET)

/*! @brief Format value for bitfield PMU_REG_LPSR_1P0_BO_OFFSET. */
#define BF_PMU_REG_LPSR_1P0_BO_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_LPSR_1P0_BO_OFFSET) & BM_PMU_REG_LPSR_1P0_BO_OFFSET)

/*! @brief Set the BO_OFFSET field to a new value. */
#define BW_PMU_REG_LPSR_1P0_BO_OFFSET(x, v) (HW_PMU_REG_LPSR_1P0_WR(x, (HW_PMU_REG_LPSR_1P0_RD(x) & ~BM_PMU_REG_LPSR_1P0_BO_OFFSET) | BF_PMU_REG_LPSR_1P0_BO_OFFSET(v)))
/*@}*/

/*!
 * @name Register PMU_REG_LPSR_1P0, field ENABLE_PWRUPLOAD[7] (RW)
 *
 * Enables a ~100kohm load to ground. Typically software would clear this if not
 * necessary.
 */
/*@{*/
#define BP_PMU_REG_LPSR_1P0_ENABLE_PWRUPLOAD (7U) /*!< Bit position for PMU_REG_LPSR_1P0_ENABLE_PWRUPLOAD. */
#define BM_PMU_REG_LPSR_1P0_ENABLE_PWRUPLOAD (0x00000080U) /*!< Bit mask for PMU_REG_LPSR_1P0_ENABLE_PWRUPLOAD. */
#define BS_PMU_REG_LPSR_1P0_ENABLE_PWRUPLOAD (1U) /*!< Bit field size in bits for PMU_REG_LPSR_1P0_ENABLE_PWRUPLOAD. */

/*! @brief Read current value of the PMU_REG_LPSR_1P0_ENABLE_PWRUPLOAD field. */
#define BR_PMU_REG_LPSR_1P0_ENABLE_PWRUPLOAD(x) (HW_PMU_REG_LPSR_1P0(x).B.ENABLE_PWRUPLOAD)

/*! @brief Format value for bitfield PMU_REG_LPSR_1P0_ENABLE_PWRUPLOAD. */
#define BF_PMU_REG_LPSR_1P0_ENABLE_PWRUPLOAD(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_LPSR_1P0_ENABLE_PWRUPLOAD) & BM_PMU_REG_LPSR_1P0_ENABLE_PWRUPLOAD)

/*! @brief Set the ENABLE_PWRUPLOAD field to a new value. */
#define BW_PMU_REG_LPSR_1P0_ENABLE_PWRUPLOAD(x, v) (HW_PMU_REG_LPSR_1P0_WR(x, (HW_PMU_REG_LPSR_1P0_RD(x) & ~BM_PMU_REG_LPSR_1P0_ENABLE_PWRUPLOAD) | BF_PMU_REG_LPSR_1P0_ENABLE_PWRUPLOAD(v)))
/*@}*/

/*!
 * @name Register PMU_REG_LPSR_1P0, field OUTPUT_TRG[12:8] (RW)
 *
 * Not used.
 */
/*@{*/
#define BP_PMU_REG_LPSR_1P0_OUTPUT_TRG (8U) /*!< Bit position for PMU_REG_LPSR_1P0_OUTPUT_TRG. */
#define BM_PMU_REG_LPSR_1P0_OUTPUT_TRG (0x00001F00U) /*!< Bit mask for PMU_REG_LPSR_1P0_OUTPUT_TRG. */
#define BS_PMU_REG_LPSR_1P0_OUTPUT_TRG (5U) /*!< Bit field size in bits for PMU_REG_LPSR_1P0_OUTPUT_TRG. */

/*! @brief Read current value of the PMU_REG_LPSR_1P0_OUTPUT_TRG field. */
#define BR_PMU_REG_LPSR_1P0_OUTPUT_TRG(x) (HW_PMU_REG_LPSR_1P0(x).B.OUTPUT_TRG)

/*! @brief Format value for bitfield PMU_REG_LPSR_1P0_OUTPUT_TRG. */
#define BF_PMU_REG_LPSR_1P0_OUTPUT_TRG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_LPSR_1P0_OUTPUT_TRG) & BM_PMU_REG_LPSR_1P0_OUTPUT_TRG)

/*! @brief Set the OUTPUT_TRG field to a new value. */
#define BW_PMU_REG_LPSR_1P0_OUTPUT_TRG(x, v) (HW_PMU_REG_LPSR_1P0_WR(x, (HW_PMU_REG_LPSR_1P0_RD(x) & ~BM_PMU_REG_LPSR_1P0_OUTPUT_TRG) | BF_PMU_REG_LPSR_1P0_OUTPUT_TRG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_LPSR_1P0, field RSVD0[15:13] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_PMU_REG_LPSR_1P0_RSVD0 (13U)    /*!< Bit position for PMU_REG_LPSR_1P0_RSVD0. */
#define BM_PMU_REG_LPSR_1P0_RSVD0 (0x0000E000U) /*!< Bit mask for PMU_REG_LPSR_1P0_RSVD0. */
#define BS_PMU_REG_LPSR_1P0_RSVD0 (3U)     /*!< Bit field size in bits for PMU_REG_LPSR_1P0_RSVD0. */

/*! @brief Read current value of the PMU_REG_LPSR_1P0_RSVD0 field. */
#define BR_PMU_REG_LPSR_1P0_RSVD0(x) (HW_PMU_REG_LPSR_1P0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PMU_REG_LPSR_1P0, field BO[16] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_PMU_REG_LPSR_1P0_BO (16U)       /*!< Bit position for PMU_REG_LPSR_1P0_BO. */
#define BM_PMU_REG_LPSR_1P0_BO (0x00010000U) /*!< Bit mask for PMU_REG_LPSR_1P0_BO. */
#define BS_PMU_REG_LPSR_1P0_BO (1U)        /*!< Bit field size in bits for PMU_REG_LPSR_1P0_BO. */

/*! @brief Read current value of the PMU_REG_LPSR_1P0_BO field. */
#define BR_PMU_REG_LPSR_1P0_BO(x) (HW_PMU_REG_LPSR_1P0(x).B.BO)

/*! @brief Format value for bitfield PMU_REG_LPSR_1P0_BO. */
#define BF_PMU_REG_LPSR_1P0_BO(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_LPSR_1P0_BO) & BM_PMU_REG_LPSR_1P0_BO)

/*! @brief Set the BO field to a new value. */
#define BW_PMU_REG_LPSR_1P0_BO(x, v) (HW_PMU_REG_LPSR_1P0_WR(x, (HW_PMU_REG_LPSR_1P0_RD(x) & ~BM_PMU_REG_LPSR_1P0_BO) | BF_PMU_REG_LPSR_1P0_BO(v)))
/*@}*/

/*!
 * @name Register PMU_REG_LPSR_1P0, field OK[17] (RO)
 *
 * Always 1 after reset
 */
/*@{*/
#define BP_PMU_REG_LPSR_1P0_OK (17U)       /*!< Bit position for PMU_REG_LPSR_1P0_OK. */
#define BM_PMU_REG_LPSR_1P0_OK (0x00020000U) /*!< Bit mask for PMU_REG_LPSR_1P0_OK. */
#define BS_PMU_REG_LPSR_1P0_OK (1U)        /*!< Bit field size in bits for PMU_REG_LPSR_1P0_OK. */

/*! @brief Read current value of the PMU_REG_LPSR_1P0_OK field. */
#define BR_PMU_REG_LPSR_1P0_OK(x) (HW_PMU_REG_LPSR_1P0(x).B.OK)
/*@}*/

/*!
 * @name Register PMU_REG_LPSR_1P0, field ENABLE_WEAK_LINREG[18] (RW)
 *
 * Not used, always on.
 */
/*@{*/
#define BP_PMU_REG_LPSR_1P0_ENABLE_WEAK_LINREG (18U) /*!< Bit position for PMU_REG_LPSR_1P0_ENABLE_WEAK_LINREG. */
#define BM_PMU_REG_LPSR_1P0_ENABLE_WEAK_LINREG (0x00040000U) /*!< Bit mask for PMU_REG_LPSR_1P0_ENABLE_WEAK_LINREG. */
#define BS_PMU_REG_LPSR_1P0_ENABLE_WEAK_LINREG (1U) /*!< Bit field size in bits for PMU_REG_LPSR_1P0_ENABLE_WEAK_LINREG. */

/*! @brief Read current value of the PMU_REG_LPSR_1P0_ENABLE_WEAK_LINREG field. */
#define BR_PMU_REG_LPSR_1P0_ENABLE_WEAK_LINREG(x) (HW_PMU_REG_LPSR_1P0(x).B.ENABLE_WEAK_LINREG)

/*! @brief Format value for bitfield PMU_REG_LPSR_1P0_ENABLE_WEAK_LINREG. */
#define BF_PMU_REG_LPSR_1P0_ENABLE_WEAK_LINREG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_LPSR_1P0_ENABLE_WEAK_LINREG) & BM_PMU_REG_LPSR_1P0_ENABLE_WEAK_LINREG)

/*! @brief Set the ENABLE_WEAK_LINREG field to a new value. */
#define BW_PMU_REG_LPSR_1P0_ENABLE_WEAK_LINREG(x, v) (HW_PMU_REG_LPSR_1P0_WR(x, (HW_PMU_REG_LPSR_1P0_RD(x) & ~BM_PMU_REG_LPSR_1P0_ENABLE_WEAK_LINREG) | BF_PMU_REG_LPSR_1P0_ENABLE_WEAK_LINREG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_LPSR_1P0, field SELREF_WEAK_LINREG[19] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_PMU_REG_LPSR_1P0_SELREF_WEAK_LINREG (19U) /*!< Bit position for PMU_REG_LPSR_1P0_SELREF_WEAK_LINREG. */
#define BM_PMU_REG_LPSR_1P0_SELREF_WEAK_LINREG (0x00080000U) /*!< Bit mask for PMU_REG_LPSR_1P0_SELREF_WEAK_LINREG. */
#define BS_PMU_REG_LPSR_1P0_SELREF_WEAK_LINREG (1U) /*!< Bit field size in bits for PMU_REG_LPSR_1P0_SELREF_WEAK_LINREG. */

/*! @brief Read current value of the PMU_REG_LPSR_1P0_SELREF_WEAK_LINREG field. */
#define BR_PMU_REG_LPSR_1P0_SELREF_WEAK_LINREG(x) (HW_PMU_REG_LPSR_1P0(x).B.SELREF_WEAK_LINREG)

/*! @brief Format value for bitfield PMU_REG_LPSR_1P0_SELREF_WEAK_LINREG. */
#define BF_PMU_REG_LPSR_1P0_SELREF_WEAK_LINREG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_LPSR_1P0_SELREF_WEAK_LINREG) & BM_PMU_REG_LPSR_1P0_SELREF_WEAK_LINREG)

/*! @brief Set the SELREF_WEAK_LINREG field to a new value. */
#define BW_PMU_REG_LPSR_1P0_SELREF_WEAK_LINREG(x, v) (HW_PMU_REG_LPSR_1P0_WR(x, (HW_PMU_REG_LPSR_1P0_RD(x) & ~BM_PMU_REG_LPSR_1P0_SELREF_WEAK_LINREG) | BF_PMU_REG_LPSR_1P0_SELREF_WEAK_LINREG(v)))
/*@}*/

/*!
 * @name Register PMU_REG_LPSR_1P0, field REG_TEST[23:20] (RW)
 *
 * Not used
 */
/*@{*/
#define BP_PMU_REG_LPSR_1P0_REG_TEST (20U) /*!< Bit position for PMU_REG_LPSR_1P0_REG_TEST. */
#define BM_PMU_REG_LPSR_1P0_REG_TEST (0x00F00000U) /*!< Bit mask for PMU_REG_LPSR_1P0_REG_TEST. */
#define BS_PMU_REG_LPSR_1P0_REG_TEST (4U)  /*!< Bit field size in bits for PMU_REG_LPSR_1P0_REG_TEST. */

/*! @brief Read current value of the PMU_REG_LPSR_1P0_REG_TEST field. */
#define BR_PMU_REG_LPSR_1P0_REG_TEST(x) (HW_PMU_REG_LPSR_1P0(x).B.REG_TEST)

/*! @brief Format value for bitfield PMU_REG_LPSR_1P0_REG_TEST. */
#define BF_PMU_REG_LPSR_1P0_REG_TEST(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REG_LPSR_1P0_REG_TEST) & BM_PMU_REG_LPSR_1P0_REG_TEST)

/*! @brief Set the REG_TEST field to a new value. */
#define BW_PMU_REG_LPSR_1P0_REG_TEST(x, v) (HW_PMU_REG_LPSR_1P0_WR(x, (HW_PMU_REG_LPSR_1P0_RD(x) & ~BM_PMU_REG_LPSR_1P0_REG_TEST) | BF_PMU_REG_LPSR_1P0_REG_TEST(v)))
/*@}*/

/*!
 * @name Register PMU_REG_LPSR_1P0, field RSVD1[31:24] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_PMU_REG_LPSR_1P0_RSVD1 (24U)    /*!< Bit position for PMU_REG_LPSR_1P0_RSVD1. */
#define BM_PMU_REG_LPSR_1P0_RSVD1 (0xFF000000U) /*!< Bit mask for PMU_REG_LPSR_1P0_RSVD1. */
#define BS_PMU_REG_LPSR_1P0_RSVD1 (8U)     /*!< Bit field size in bits for PMU_REG_LPSR_1P0_RSVD1. */

/*! @brief Read current value of the PMU_REG_LPSR_1P0_RSVD1 field. */
#define BR_PMU_REG_LPSR_1P0_RSVD1(x) (HW_PMU_REG_LPSR_1P0(x).B.RSVD1)
/*@}*/




/*******************************************************************************
 * HW_PMU_REF - Anadig Reference Analog Control and Status Register
 ******************************************************************************/

/*!
 * @brief HW_PMU_REF - Anadig Reference Analog Control and Status Register (RW)
 *
 * Reset value: 0x00002000U
 *
 * This register defines the control and status bits for miscellaneous analog
 * blocks.
 */
typedef union _hw_pmu_ref
{
    uint32_t U;
    struct _hw_pmu_ref_bitfields
    {
        uint32_t REFTOP_PWD : 1;       /*!< [0]  */
        uint32_t REFTOP_PWDVBGUP : 1;  /*!< [1]  */
        uint32_t REFTOP_LOWPOWER : 1;  /*!< [2]  */
        uint32_t REFTOP_SELFBIASOFF : 1; /*!< [3]  */
        uint32_t REFTOP_VBGADJ : 3;    /*!< [6:4]  */
        uint32_t REFTOP_VBGUP : 1;     /*!< [7]  */
        uint32_t REFTOP_BIAS_TST : 2;  /*!< [9:8]  */
        uint32_t LPBG_SEL : 1;         /*!< [10]  */
        uint32_t LPBG_TEST : 1;        /*!< [11]  */
        uint32_t REFTOP_IBIAS_OFF : 1; /*!< [12]  */
        uint32_t REFTOP_LINREGREF_EN : 1; /*!< [13]  */
        uint32_t RSVD1 : 18;           /*!< [31:14]  */
    } B;
} hw_pmu_ref_t;

/*!
 * @name Constants and macros for entire PMU_REF register
 */
/*@{*/
#define HW_PMU_REF_ADDR(x)       ((uintptr_t)(x) + 0x270U)
#define HW_PMU_REF_SET_ADDR(x)   (HW_PMU_REF_ADDR(x) + 0x4U)
#define HW_PMU_REF_CLR_ADDR(x)   (HW_PMU_REF_ADDR(x) + 0x8U)
#define HW_PMU_REF_TOG_ADDR(x)   (HW_PMU_REF_ADDR(x) + 0xCU)

#define HW_PMU_REF(x)            (*(__IO hw_pmu_ref_t *) HW_PMU_REF_ADDR(x))
#define HW_PMU_REF_RD(x)         (HW_PMU_REF(x).U)
#define HW_PMU_REF_WR(x, v)      (HW_PMU_REF(x).U = (v))
#define HW_PMU_REF_SET(x, v)     ((*(uint32_t *) HW_PMU_REF_SET_ADDR(x)) = (v))
#define HW_PMU_REF_CLR(x, v)     ((*(uint32_t *) HW_PMU_REF_CLR_ADDR(x)) = (v))
#define HW_PMU_REF_TOG(x, v)     ((*(uint32_t *) HW_PMU_REF_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual PMU_REF bitfields
 */

/*!
 * @name Register PMU_REF, field REFTOP_PWD[0] (RW)
 *
 * Control bit to power-down the analog bandgap reference circuitry.
 */
/*@{*/
#define BP_PMU_REF_REFTOP_PWD (0U)         /*!< Bit position for PMU_REF_REFTOP_PWD. */
#define BM_PMU_REF_REFTOP_PWD (0x00000001U) /*!< Bit mask for PMU_REF_REFTOP_PWD. */
#define BS_PMU_REF_REFTOP_PWD (1U)         /*!< Bit field size in bits for PMU_REF_REFTOP_PWD. */

/*! @brief Read current value of the PMU_REF_REFTOP_PWD field. */
#define BR_PMU_REF_REFTOP_PWD(x) (HW_PMU_REF(x).B.REFTOP_PWD)

/*! @brief Format value for bitfield PMU_REF_REFTOP_PWD. */
#define BF_PMU_REF_REFTOP_PWD(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REF_REFTOP_PWD) & BM_PMU_REF_REFTOP_PWD)

/*! @brief Set the REFTOP_PWD field to a new value. */
#define BW_PMU_REF_REFTOP_PWD(x, v) (HW_PMU_REF_WR(x, (HW_PMU_REF_RD(x) & ~BM_PMU_REF_REFTOP_PWD) | BF_PMU_REF_REFTOP_PWD(v)))
/*@}*/

/*!
 * @name Register PMU_REF, field REFTOP_PWDVBGUP[1] (RW)
 *
 * Control bit to power-down the VBG-up detection circuitry in the analog
 * bandgap.
 */
/*@{*/
#define BP_PMU_REF_REFTOP_PWDVBGUP (1U)    /*!< Bit position for PMU_REF_REFTOP_PWDVBGUP. */
#define BM_PMU_REF_REFTOP_PWDVBGUP (0x00000002U) /*!< Bit mask for PMU_REF_REFTOP_PWDVBGUP. */
#define BS_PMU_REF_REFTOP_PWDVBGUP (1U)    /*!< Bit field size in bits for PMU_REF_REFTOP_PWDVBGUP. */

/*! @brief Read current value of the PMU_REF_REFTOP_PWDVBGUP field. */
#define BR_PMU_REF_REFTOP_PWDVBGUP(x) (HW_PMU_REF(x).B.REFTOP_PWDVBGUP)

/*! @brief Format value for bitfield PMU_REF_REFTOP_PWDVBGUP. */
#define BF_PMU_REF_REFTOP_PWDVBGUP(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REF_REFTOP_PWDVBGUP) & BM_PMU_REF_REFTOP_PWDVBGUP)

/*! @brief Set the REFTOP_PWDVBGUP field to a new value. */
#define BW_PMU_REF_REFTOP_PWDVBGUP(x, v) (HW_PMU_REF_WR(x, (HW_PMU_REF_RD(x) & ~BM_PMU_REF_REFTOP_PWDVBGUP) | BF_PMU_REF_REFTOP_PWDVBGUP(v)))
/*@}*/

/*!
 * @name Register PMU_REF, field REFTOP_LOWPOWER[2] (RW)
 *
 * Freescale debug/test only. Control bit to enable the low-power mode in the
 * analog bandgap.
 */
/*@{*/
#define BP_PMU_REF_REFTOP_LOWPOWER (2U)    /*!< Bit position for PMU_REF_REFTOP_LOWPOWER. */
#define BM_PMU_REF_REFTOP_LOWPOWER (0x00000004U) /*!< Bit mask for PMU_REF_REFTOP_LOWPOWER. */
#define BS_PMU_REF_REFTOP_LOWPOWER (1U)    /*!< Bit field size in bits for PMU_REF_REFTOP_LOWPOWER. */

/*! @brief Read current value of the PMU_REF_REFTOP_LOWPOWER field. */
#define BR_PMU_REF_REFTOP_LOWPOWER(x) (HW_PMU_REF(x).B.REFTOP_LOWPOWER)

/*! @brief Format value for bitfield PMU_REF_REFTOP_LOWPOWER. */
#define BF_PMU_REF_REFTOP_LOWPOWER(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REF_REFTOP_LOWPOWER) & BM_PMU_REF_REFTOP_LOWPOWER)

/*! @brief Set the REFTOP_LOWPOWER field to a new value. */
#define BW_PMU_REF_REFTOP_LOWPOWER(x, v) (HW_PMU_REF_WR(x, (HW_PMU_REF_RD(x) & ~BM_PMU_REF_REFTOP_LOWPOWER) | BF_PMU_REF_REFTOP_LOWPOWER(v)))
/*@}*/

/*!
 * @name Register PMU_REF, field REFTOP_SELFBIASOFF[3] (RW)
 *
 * Control bit to disable the self-bias circuit in the analog bandgap. The
 * self-bias circuit is used by the bandgap during startup. This bit should be set
 * after the bandgap has stabilized and is necessary for best noise performance of
 * analog blocks using the outputs of the bandgap.
 */
/*@{*/
#define BP_PMU_REF_REFTOP_SELFBIASOFF (3U) /*!< Bit position for PMU_REF_REFTOP_SELFBIASOFF. */
#define BM_PMU_REF_REFTOP_SELFBIASOFF (0x00000008U) /*!< Bit mask for PMU_REF_REFTOP_SELFBIASOFF. */
#define BS_PMU_REF_REFTOP_SELFBIASOFF (1U) /*!< Bit field size in bits for PMU_REF_REFTOP_SELFBIASOFF. */

/*! @brief Read current value of the PMU_REF_REFTOP_SELFBIASOFF field. */
#define BR_PMU_REF_REFTOP_SELFBIASOFF(x) (HW_PMU_REF(x).B.REFTOP_SELFBIASOFF)

/*! @brief Format value for bitfield PMU_REF_REFTOP_SELFBIASOFF. */
#define BF_PMU_REF_REFTOP_SELFBIASOFF(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REF_REFTOP_SELFBIASOFF) & BM_PMU_REF_REFTOP_SELFBIASOFF)

/*! @brief Set the REFTOP_SELFBIASOFF field to a new value. */
#define BW_PMU_REF_REFTOP_SELFBIASOFF(x, v) (HW_PMU_REF_WR(x, (HW_PMU_REF_RD(x) & ~BM_PMU_REF_REFTOP_SELFBIASOFF) | BF_PMU_REF_REFTOP_SELFBIASOFF(v)))
/*@}*/

/*!
 * @name Register PMU_REF, field REFTOP_VBGADJ[6:4] (RW)
 *
 * Freescale debug/test bits
 */
/*@{*/
#define BP_PMU_REF_REFTOP_VBGADJ (4U)      /*!< Bit position for PMU_REF_REFTOP_VBGADJ. */
#define BM_PMU_REF_REFTOP_VBGADJ (0x00000070U) /*!< Bit mask for PMU_REF_REFTOP_VBGADJ. */
#define BS_PMU_REF_REFTOP_VBGADJ (3U)      /*!< Bit field size in bits for PMU_REF_REFTOP_VBGADJ. */

/*! @brief Read current value of the PMU_REF_REFTOP_VBGADJ field. */
#define BR_PMU_REF_REFTOP_VBGADJ(x) (HW_PMU_REF(x).B.REFTOP_VBGADJ)

/*! @brief Format value for bitfield PMU_REF_REFTOP_VBGADJ. */
#define BF_PMU_REF_REFTOP_VBGADJ(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REF_REFTOP_VBGADJ) & BM_PMU_REF_REFTOP_VBGADJ)

/*! @brief Set the REFTOP_VBGADJ field to a new value. */
#define BW_PMU_REF_REFTOP_VBGADJ(x, v) (HW_PMU_REF_WR(x, (HW_PMU_REF_RD(x) & ~BM_PMU_REF_REFTOP_VBGADJ) | BF_PMU_REF_REFTOP_VBGADJ(v)))
/*@}*/

/*!
 * @name Register PMU_REF, field REFTOP_VBGUP[7] (RO)
 *
 * Status bit which signals that the analog bandgap voltage is up and stable.
 */
/*@{*/
#define BP_PMU_REF_REFTOP_VBGUP (7U)       /*!< Bit position for PMU_REF_REFTOP_VBGUP. */
#define BM_PMU_REF_REFTOP_VBGUP (0x00000080U) /*!< Bit mask for PMU_REF_REFTOP_VBGUP. */
#define BS_PMU_REF_REFTOP_VBGUP (1U)       /*!< Bit field size in bits for PMU_REF_REFTOP_VBGUP. */

/*! @brief Read current value of the PMU_REF_REFTOP_VBGUP field. */
#define BR_PMU_REF_REFTOP_VBGUP(x) (HW_PMU_REF(x).B.REFTOP_VBGUP)
/*@}*/

/*!
 * @name Register PMU_REF, field REFTOP_BIAS_TST[9:8] (RW)
 *
 * Freescale debug/test bits 0x0 - nom, 0x1 - 90% Ibias, 0x2 - 80% Ibias, 0x3
 * 110% Ibias
 */
/*@{*/
#define BP_PMU_REF_REFTOP_BIAS_TST (8U)    /*!< Bit position for PMU_REF_REFTOP_BIAS_TST. */
#define BM_PMU_REF_REFTOP_BIAS_TST (0x00000300U) /*!< Bit mask for PMU_REF_REFTOP_BIAS_TST. */
#define BS_PMU_REF_REFTOP_BIAS_TST (2U)    /*!< Bit field size in bits for PMU_REF_REFTOP_BIAS_TST. */

/*! @brief Read current value of the PMU_REF_REFTOP_BIAS_TST field. */
#define BR_PMU_REF_REFTOP_BIAS_TST(x) (HW_PMU_REF(x).B.REFTOP_BIAS_TST)

/*! @brief Format value for bitfield PMU_REF_REFTOP_BIAS_TST. */
#define BF_PMU_REF_REFTOP_BIAS_TST(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REF_REFTOP_BIAS_TST) & BM_PMU_REF_REFTOP_BIAS_TST)

/*! @brief Set the REFTOP_BIAS_TST field to a new value. */
#define BW_PMU_REF_REFTOP_BIAS_TST(x, v) (HW_PMU_REF_WR(x, (HW_PMU_REF_RD(x) & ~BM_PMU_REF_REFTOP_BIAS_TST) | BF_PMU_REF_REFTOP_BIAS_TST(v)))
/*@}*/

/*!
 * @name Register PMU_REF, field LPBG_SEL[10] (RW)
 *
 * Bandgap select. 0 - normal power bandgap; 1 - low power bandgap.
 */
/*@{*/
#define BP_PMU_REF_LPBG_SEL  (10U)         /*!< Bit position for PMU_REF_LPBG_SEL. */
#define BM_PMU_REF_LPBG_SEL  (0x00000400U) /*!< Bit mask for PMU_REF_LPBG_SEL. */
#define BS_PMU_REF_LPBG_SEL  (1U)          /*!< Bit field size in bits for PMU_REF_LPBG_SEL. */

/*! @brief Read current value of the PMU_REF_LPBG_SEL field. */
#define BR_PMU_REF_LPBG_SEL(x) (HW_PMU_REF(x).B.LPBG_SEL)

/*! @brief Format value for bitfield PMU_REF_LPBG_SEL. */
#define BF_PMU_REF_LPBG_SEL(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REF_LPBG_SEL) & BM_PMU_REF_LPBG_SEL)

/*! @brief Set the LPBG_SEL field to a new value. */
#define BW_PMU_REF_LPBG_SEL(x, v) (HW_PMU_REF_WR(x, (HW_PMU_REF_RD(x) & ~BM_PMU_REF_LPBG_SEL) | BF_PMU_REF_LPBG_SEL(v)))
/*@}*/

/*!
 * @name Register PMU_REF, field LPBG_TEST[11] (RW)
 *
 * Low power bandgap test bit.. Freescale debug/test purposes only.
 */
/*@{*/
#define BP_PMU_REF_LPBG_TEST (11U)         /*!< Bit position for PMU_REF_LPBG_TEST. */
#define BM_PMU_REF_LPBG_TEST (0x00000800U) /*!< Bit mask for PMU_REF_LPBG_TEST. */
#define BS_PMU_REF_LPBG_TEST (1U)          /*!< Bit field size in bits for PMU_REF_LPBG_TEST. */

/*! @brief Read current value of the PMU_REF_LPBG_TEST field. */
#define BR_PMU_REF_LPBG_TEST(x) (HW_PMU_REF(x).B.LPBG_TEST)

/*! @brief Format value for bitfield PMU_REF_LPBG_TEST. */
#define BF_PMU_REF_LPBG_TEST(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REF_LPBG_TEST) & BM_PMU_REF_LPBG_TEST)

/*! @brief Set the LPBG_TEST field to a new value. */
#define BW_PMU_REF_LPBG_TEST(x, v) (HW_PMU_REF_WR(x, (HW_PMU_REF_RD(x) & ~BM_PMU_REF_LPBG_TEST) | BF_PMU_REF_LPBG_TEST(v)))
/*@}*/

/*!
 * @name Register PMU_REF, field REFTOP_IBIAS_OFF[12] (RW)
 *
 * Low power reftop ibias disable. This bit switches the bias current source
 * from this reference to the low power bandgap.
 */
/*@{*/
#define BP_PMU_REF_REFTOP_IBIAS_OFF (12U)  /*!< Bit position for PMU_REF_REFTOP_IBIAS_OFF. */
#define BM_PMU_REF_REFTOP_IBIAS_OFF (0x00001000U) /*!< Bit mask for PMU_REF_REFTOP_IBIAS_OFF. */
#define BS_PMU_REF_REFTOP_IBIAS_OFF (1U)   /*!< Bit field size in bits for PMU_REF_REFTOP_IBIAS_OFF. */

/*! @brief Read current value of the PMU_REF_REFTOP_IBIAS_OFF field. */
#define BR_PMU_REF_REFTOP_IBIAS_OFF(x) (HW_PMU_REF(x).B.REFTOP_IBIAS_OFF)

/*! @brief Format value for bitfield PMU_REF_REFTOP_IBIAS_OFF. */
#define BF_PMU_REF_REFTOP_IBIAS_OFF(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REF_REFTOP_IBIAS_OFF) & BM_PMU_REF_REFTOP_IBIAS_OFF)

/*! @brief Set the REFTOP_IBIAS_OFF field to a new value. */
#define BW_PMU_REF_REFTOP_IBIAS_OFF(x, v) (HW_PMU_REF_WR(x, (HW_PMU_REF_RD(x) & ~BM_PMU_REF_REFTOP_IBIAS_OFF) | BF_PMU_REF_REFTOP_IBIAS_OFF(v)))
/*@}*/

/*!
 * @name Register PMU_REF, field REFTOP_LINREGREF_EN[13] (RW)
 *
 * Enables buffer from the main bandgap for use with the linear regulators. This
 * bit is useful to save power when the regulators are configured to use the low
 * power bandgap voltage.
 */
/*@{*/
#define BP_PMU_REF_REFTOP_LINREGREF_EN (13U) /*!< Bit position for PMU_REF_REFTOP_LINREGREF_EN. */
#define BM_PMU_REF_REFTOP_LINREGREF_EN (0x00002000U) /*!< Bit mask for PMU_REF_REFTOP_LINREGREF_EN. */
#define BS_PMU_REF_REFTOP_LINREGREF_EN (1U) /*!< Bit field size in bits for PMU_REF_REFTOP_LINREGREF_EN. */

/*! @brief Read current value of the PMU_REF_REFTOP_LINREGREF_EN field. */
#define BR_PMU_REF_REFTOP_LINREGREF_EN(x) (HW_PMU_REF(x).B.REFTOP_LINREGREF_EN)

/*! @brief Format value for bitfield PMU_REF_REFTOP_LINREGREF_EN. */
#define BF_PMU_REF_REFTOP_LINREGREF_EN(v) ((uint32_t)((uint32_t)(v) << BP_PMU_REF_REFTOP_LINREGREF_EN) & BM_PMU_REF_REFTOP_LINREGREF_EN)

/*! @brief Set the REFTOP_LINREGREF_EN field to a new value. */
#define BW_PMU_REF_REFTOP_LINREGREF_EN(x, v) (HW_PMU_REF_WR(x, (HW_PMU_REF_RD(x) & ~BM_PMU_REF_REFTOP_LINREGREF_EN) | BF_PMU_REF_REFTOP_LINREGREF_EN(v)))
/*@}*/

/*!
 * @name Register PMU_REF, field RSVD1[31:14] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_PMU_REF_RSVD1     (14U)         /*!< Bit position for PMU_REF_RSVD1. */
#define BM_PMU_REF_RSVD1     (0xFFFFC000U) /*!< Bit mask for PMU_REF_RSVD1. */
#define BS_PMU_REF_RSVD1     (18U)         /*!< Bit field size in bits for PMU_REF_RSVD1. */

/*! @brief Read current value of the PMU_REF_RSVD1 field. */
#define BR_PMU_REF_RSVD1(x)  (HW_PMU_REF(x).B.RSVD1)
/*@}*/




/*******************************************************************************
 * HW_PMU_LOWPWR_CTRL - Anadig Low Power Control Register
 ******************************************************************************/

/*!
 * @brief HW_PMU_LOWPWR_CTRL - Anadig Low Power Control Register (RW)
 *
 * Reset value: 0x00003F00U
 *
 * This register defines fields for low power capabilities of the analog.
 */
typedef union _hw_pmu_lowpwr_ctrl
{
    uint32_t U;
    struct _hw_pmu_lowpwr_ctrl_bitfields
    {
        uint32_t STOP_MODE_CONFIG : 2; /*!< [1:0]  */
        uint32_t RSVD0 : 6;            /*!< [7:2]  */
        uint32_t L1_PWRGATE : 1;       /*!< [8]  */
        uint32_t L2_PWRGATE : 1;       /*!< [9]  */
        uint32_t CPU_PWRGATE : 1;      /*!< [10]  */
        uint32_t DISPLAY_PWRGATE : 1;  /*!< [11]  */
        uint32_t MIX_PWRGATE : 1;      /*!< [12]  */
        uint32_t GPU_PWRGATE : 1;      /*!< [13]  */
        uint32_t CONTROL0 : 10;        /*!< [23:14]  */
        uint32_t CONTROL1 : 8;         /*!< [31:24]  */
    } B;
} hw_pmu_lowpwr_ctrl_t;

/*!
 * @name Constants and macros for entire PMU_LOWPWR_CTRL register
 */
/*@{*/
#define HW_PMU_LOWPWR_CTRL_ADDR(x) ((uintptr_t)(x) + 0x330U)
#define HW_PMU_LOWPWR_CTRL_SET_ADDR(x) (HW_PMU_LOWPWR_CTRL_ADDR(x) + 0x4U)
#define HW_PMU_LOWPWR_CTRL_CLR_ADDR(x) (HW_PMU_LOWPWR_CTRL_ADDR(x) + 0x8U)
#define HW_PMU_LOWPWR_CTRL_TOG_ADDR(x) (HW_PMU_LOWPWR_CTRL_ADDR(x) + 0xCU)

#define HW_PMU_LOWPWR_CTRL(x)    (*(__IO hw_pmu_lowpwr_ctrl_t *) HW_PMU_LOWPWR_CTRL_ADDR(x))
#define HW_PMU_LOWPWR_CTRL_RD(x) (HW_PMU_LOWPWR_CTRL(x).U)
#define HW_PMU_LOWPWR_CTRL_WR(x, v) (HW_PMU_LOWPWR_CTRL(x).U = (v))
#define HW_PMU_LOWPWR_CTRL_SET(x, v) ((*(uint32_t *) HW_PMU_LOWPWR_CTRL_SET_ADDR(x)) = (v))
#define HW_PMU_LOWPWR_CTRL_CLR(x, v) ((*(uint32_t *) HW_PMU_LOWPWR_CTRL_CLR_ADDR(x)) = (v))
#define HW_PMU_LOWPWR_CTRL_TOG(x, v) ((*(uint32_t *) HW_PMU_LOWPWR_CTRL_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual PMU_LOWPWR_CTRL bitfields
 */

/*!
 * @name Register PMU_LOWPWR_CTRL, field STOP_MODE_CONFIG[1:0] (RW)
 *
 * Configure the analog behavior in stop mode.
 *
 * Values:
 * - 0 - All analog except RTC powered down on stop mode assertion. XtalOsc = on
 *     RCOsc = off
 * - 1 - Certain analog functions, such as certain regulators left up. XtalOsc =
 *     on RCOsc = off
 */
/*@{*/
#define BP_PMU_LOWPWR_CTRL_STOP_MODE_CONFIG (0U) /*!< Bit position for PMU_LOWPWR_CTRL_STOP_MODE_CONFIG. */
#define BM_PMU_LOWPWR_CTRL_STOP_MODE_CONFIG (0x00000003U) /*!< Bit mask for PMU_LOWPWR_CTRL_STOP_MODE_CONFIG. */
#define BS_PMU_LOWPWR_CTRL_STOP_MODE_CONFIG (2U) /*!< Bit field size in bits for PMU_LOWPWR_CTRL_STOP_MODE_CONFIG. */

/*! @brief Read current value of the PMU_LOWPWR_CTRL_STOP_MODE_CONFIG field. */
#define BR_PMU_LOWPWR_CTRL_STOP_MODE_CONFIG(x) (HW_PMU_LOWPWR_CTRL(x).B.STOP_MODE_CONFIG)

/*! @brief Format value for bitfield PMU_LOWPWR_CTRL_STOP_MODE_CONFIG. */
#define BF_PMU_LOWPWR_CTRL_STOP_MODE_CONFIG(v) ((uint32_t)((uint32_t)(v) << BP_PMU_LOWPWR_CTRL_STOP_MODE_CONFIG) & BM_PMU_LOWPWR_CTRL_STOP_MODE_CONFIG)

/*! @brief Set the STOP_MODE_CONFIG field to a new value. */
#define BW_PMU_LOWPWR_CTRL_STOP_MODE_CONFIG(x, v) (HW_PMU_LOWPWR_CTRL_WR(x, (HW_PMU_LOWPWR_CTRL_RD(x) & ~BM_PMU_LOWPWR_CTRL_STOP_MODE_CONFIG) | BF_PMU_LOWPWR_CTRL_STOP_MODE_CONFIG(v)))
/*@}*/

/*!
 * @name Register PMU_LOWPWR_CTRL, field RSVD0[7:2] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_PMU_LOWPWR_CTRL_RSVD0 (2U)      /*!< Bit position for PMU_LOWPWR_CTRL_RSVD0. */
#define BM_PMU_LOWPWR_CTRL_RSVD0 (0x000000FCU) /*!< Bit mask for PMU_LOWPWR_CTRL_RSVD0. */
#define BS_PMU_LOWPWR_CTRL_RSVD0 (6U)      /*!< Bit field size in bits for PMU_LOWPWR_CTRL_RSVD0. */

/*! @brief Read current value of the PMU_LOWPWR_CTRL_RSVD0 field. */
#define BR_PMU_LOWPWR_CTRL_RSVD0(x) (HW_PMU_LOWPWR_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PMU_LOWPWR_CTRL, field L1_PWRGATE[8] (RW)
 *
 * L1 power gate control. Used as software mask. Set to zero to force ungated.
 */
/*@{*/
#define BP_PMU_LOWPWR_CTRL_L1_PWRGATE (8U) /*!< Bit position for PMU_LOWPWR_CTRL_L1_PWRGATE. */
#define BM_PMU_LOWPWR_CTRL_L1_PWRGATE (0x00000100U) /*!< Bit mask for PMU_LOWPWR_CTRL_L1_PWRGATE. */
#define BS_PMU_LOWPWR_CTRL_L1_PWRGATE (1U) /*!< Bit field size in bits for PMU_LOWPWR_CTRL_L1_PWRGATE. */

/*! @brief Read current value of the PMU_LOWPWR_CTRL_L1_PWRGATE field. */
#define BR_PMU_LOWPWR_CTRL_L1_PWRGATE(x) (HW_PMU_LOWPWR_CTRL(x).B.L1_PWRGATE)

/*! @brief Format value for bitfield PMU_LOWPWR_CTRL_L1_PWRGATE. */
#define BF_PMU_LOWPWR_CTRL_L1_PWRGATE(v) ((uint32_t)((uint32_t)(v) << BP_PMU_LOWPWR_CTRL_L1_PWRGATE) & BM_PMU_LOWPWR_CTRL_L1_PWRGATE)

/*! @brief Set the L1_PWRGATE field to a new value. */
#define BW_PMU_LOWPWR_CTRL_L1_PWRGATE(x, v) (HW_PMU_LOWPWR_CTRL_WR(x, (HW_PMU_LOWPWR_CTRL_RD(x) & ~BM_PMU_LOWPWR_CTRL_L1_PWRGATE) | BF_PMU_LOWPWR_CTRL_L1_PWRGATE(v)))
/*@}*/

/*!
 * @name Register PMU_LOWPWR_CTRL, field L2_PWRGATE[9] (RW)
 *
 * L2 power gate control. Used as software mask. Set to zero to force ungated.
 */
/*@{*/
#define BP_PMU_LOWPWR_CTRL_L2_PWRGATE (9U) /*!< Bit position for PMU_LOWPWR_CTRL_L2_PWRGATE. */
#define BM_PMU_LOWPWR_CTRL_L2_PWRGATE (0x00000200U) /*!< Bit mask for PMU_LOWPWR_CTRL_L2_PWRGATE. */
#define BS_PMU_LOWPWR_CTRL_L2_PWRGATE (1U) /*!< Bit field size in bits for PMU_LOWPWR_CTRL_L2_PWRGATE. */

/*! @brief Read current value of the PMU_LOWPWR_CTRL_L2_PWRGATE field. */
#define BR_PMU_LOWPWR_CTRL_L2_PWRGATE(x) (HW_PMU_LOWPWR_CTRL(x).B.L2_PWRGATE)

/*! @brief Format value for bitfield PMU_LOWPWR_CTRL_L2_PWRGATE. */
#define BF_PMU_LOWPWR_CTRL_L2_PWRGATE(v) ((uint32_t)((uint32_t)(v) << BP_PMU_LOWPWR_CTRL_L2_PWRGATE) & BM_PMU_LOWPWR_CTRL_L2_PWRGATE)

/*! @brief Set the L2_PWRGATE field to a new value. */
#define BW_PMU_LOWPWR_CTRL_L2_PWRGATE(x, v) (HW_PMU_LOWPWR_CTRL_WR(x, (HW_PMU_LOWPWR_CTRL_RD(x) & ~BM_PMU_LOWPWR_CTRL_L2_PWRGATE) | BF_PMU_LOWPWR_CTRL_L2_PWRGATE(v)))
/*@}*/

/*!
 * @name Register PMU_LOWPWR_CTRL, field CPU_PWRGATE[10] (RW)
 *
 * GPU power gate control. Used as software mask. Set to zero to force ungated.
 */
/*@{*/
#define BP_PMU_LOWPWR_CTRL_CPU_PWRGATE (10U) /*!< Bit position for PMU_LOWPWR_CTRL_CPU_PWRGATE. */
#define BM_PMU_LOWPWR_CTRL_CPU_PWRGATE (0x00000400U) /*!< Bit mask for PMU_LOWPWR_CTRL_CPU_PWRGATE. */
#define BS_PMU_LOWPWR_CTRL_CPU_PWRGATE (1U) /*!< Bit field size in bits for PMU_LOWPWR_CTRL_CPU_PWRGATE. */

/*! @brief Read current value of the PMU_LOWPWR_CTRL_CPU_PWRGATE field. */
#define BR_PMU_LOWPWR_CTRL_CPU_PWRGATE(x) (HW_PMU_LOWPWR_CTRL(x).B.CPU_PWRGATE)

/*! @brief Format value for bitfield PMU_LOWPWR_CTRL_CPU_PWRGATE. */
#define BF_PMU_LOWPWR_CTRL_CPU_PWRGATE(v) ((uint32_t)((uint32_t)(v) << BP_PMU_LOWPWR_CTRL_CPU_PWRGATE) & BM_PMU_LOWPWR_CTRL_CPU_PWRGATE)

/*! @brief Set the CPU_PWRGATE field to a new value. */
#define BW_PMU_LOWPWR_CTRL_CPU_PWRGATE(x, v) (HW_PMU_LOWPWR_CTRL_WR(x, (HW_PMU_LOWPWR_CTRL_RD(x) & ~BM_PMU_LOWPWR_CTRL_CPU_PWRGATE) | BF_PMU_LOWPWR_CTRL_CPU_PWRGATE(v)))
/*@}*/

/*!
 * @name Register PMU_LOWPWR_CTRL, field DISPLAY_PWRGATE[11] (RW)
 *
 * Display power gate control. Used as software mask. Set to zero to force
 * ungated.
 */
/*@{*/
#define BP_PMU_LOWPWR_CTRL_DISPLAY_PWRGATE (11U) /*!< Bit position for PMU_LOWPWR_CTRL_DISPLAY_PWRGATE. */
#define BM_PMU_LOWPWR_CTRL_DISPLAY_PWRGATE (0x00000800U) /*!< Bit mask for PMU_LOWPWR_CTRL_DISPLAY_PWRGATE. */
#define BS_PMU_LOWPWR_CTRL_DISPLAY_PWRGATE (1U) /*!< Bit field size in bits for PMU_LOWPWR_CTRL_DISPLAY_PWRGATE. */

/*! @brief Read current value of the PMU_LOWPWR_CTRL_DISPLAY_PWRGATE field. */
#define BR_PMU_LOWPWR_CTRL_DISPLAY_PWRGATE(x) (HW_PMU_LOWPWR_CTRL(x).B.DISPLAY_PWRGATE)

/*! @brief Format value for bitfield PMU_LOWPWR_CTRL_DISPLAY_PWRGATE. */
#define BF_PMU_LOWPWR_CTRL_DISPLAY_PWRGATE(v) ((uint32_t)((uint32_t)(v) << BP_PMU_LOWPWR_CTRL_DISPLAY_PWRGATE) & BM_PMU_LOWPWR_CTRL_DISPLAY_PWRGATE)

/*! @brief Set the DISPLAY_PWRGATE field to a new value. */
#define BW_PMU_LOWPWR_CTRL_DISPLAY_PWRGATE(x, v) (HW_PMU_LOWPWR_CTRL_WR(x, (HW_PMU_LOWPWR_CTRL_RD(x) & ~BM_PMU_LOWPWR_CTRL_DISPLAY_PWRGATE) | BF_PMU_LOWPWR_CTRL_DISPLAY_PWRGATE(v)))
/*@}*/

/*!
 * @name Register PMU_LOWPWR_CTRL, field MIX_PWRGATE[12] (RW)
 *
 * Display power gate control. Used as software mask. Set to zero to force
 * ungated.
 */
/*@{*/
#define BP_PMU_LOWPWR_CTRL_MIX_PWRGATE (12U) /*!< Bit position for PMU_LOWPWR_CTRL_MIX_PWRGATE. */
#define BM_PMU_LOWPWR_CTRL_MIX_PWRGATE (0x00001000U) /*!< Bit mask for PMU_LOWPWR_CTRL_MIX_PWRGATE. */
#define BS_PMU_LOWPWR_CTRL_MIX_PWRGATE (1U) /*!< Bit field size in bits for PMU_LOWPWR_CTRL_MIX_PWRGATE. */

/*! @brief Read current value of the PMU_LOWPWR_CTRL_MIX_PWRGATE field. */
#define BR_PMU_LOWPWR_CTRL_MIX_PWRGATE(x) (HW_PMU_LOWPWR_CTRL(x).B.MIX_PWRGATE)

/*! @brief Format value for bitfield PMU_LOWPWR_CTRL_MIX_PWRGATE. */
#define BF_PMU_LOWPWR_CTRL_MIX_PWRGATE(v) ((uint32_t)((uint32_t)(v) << BP_PMU_LOWPWR_CTRL_MIX_PWRGATE) & BM_PMU_LOWPWR_CTRL_MIX_PWRGATE)

/*! @brief Set the MIX_PWRGATE field to a new value. */
#define BW_PMU_LOWPWR_CTRL_MIX_PWRGATE(x, v) (HW_PMU_LOWPWR_CTRL_WR(x, (HW_PMU_LOWPWR_CTRL_RD(x) & ~BM_PMU_LOWPWR_CTRL_MIX_PWRGATE) | BF_PMU_LOWPWR_CTRL_MIX_PWRGATE(v)))
/*@}*/

/*!
 * @name Register PMU_LOWPWR_CTRL, field GPU_PWRGATE[13] (RW)
 *
 * GPU power gate control. Used as software mask. Set to zero to force ungated.
 */
/*@{*/
#define BP_PMU_LOWPWR_CTRL_GPU_PWRGATE (13U) /*!< Bit position for PMU_LOWPWR_CTRL_GPU_PWRGATE. */
#define BM_PMU_LOWPWR_CTRL_GPU_PWRGATE (0x00002000U) /*!< Bit mask for PMU_LOWPWR_CTRL_GPU_PWRGATE. */
#define BS_PMU_LOWPWR_CTRL_GPU_PWRGATE (1U) /*!< Bit field size in bits for PMU_LOWPWR_CTRL_GPU_PWRGATE. */

/*! @brief Read current value of the PMU_LOWPWR_CTRL_GPU_PWRGATE field. */
#define BR_PMU_LOWPWR_CTRL_GPU_PWRGATE(x) (HW_PMU_LOWPWR_CTRL(x).B.GPU_PWRGATE)

/*! @brief Format value for bitfield PMU_LOWPWR_CTRL_GPU_PWRGATE. */
#define BF_PMU_LOWPWR_CTRL_GPU_PWRGATE(v) ((uint32_t)((uint32_t)(v) << BP_PMU_LOWPWR_CTRL_GPU_PWRGATE) & BM_PMU_LOWPWR_CTRL_GPU_PWRGATE)

/*! @brief Set the GPU_PWRGATE field to a new value. */
#define BW_PMU_LOWPWR_CTRL_GPU_PWRGATE(x, v) (HW_PMU_LOWPWR_CTRL_WR(x, (HW_PMU_LOWPWR_CTRL_RD(x) & ~BM_PMU_LOWPWR_CTRL_GPU_PWRGATE) | BF_PMU_LOWPWR_CTRL_GPU_PWRGATE(v)))
/*@}*/

/*!
 * @name Register PMU_LOWPWR_CTRL, field CONTROL0[23:14] (RW)
 *
 * Reserved control bits.
 */
/*@{*/
#define BP_PMU_LOWPWR_CTRL_CONTROL0 (14U)  /*!< Bit position for PMU_LOWPWR_CTRL_CONTROL0. */
#define BM_PMU_LOWPWR_CTRL_CONTROL0 (0x00FFC000U) /*!< Bit mask for PMU_LOWPWR_CTRL_CONTROL0. */
#define BS_PMU_LOWPWR_CTRL_CONTROL0 (10U)  /*!< Bit field size in bits for PMU_LOWPWR_CTRL_CONTROL0. */

/*! @brief Read current value of the PMU_LOWPWR_CTRL_CONTROL0 field. */
#define BR_PMU_LOWPWR_CTRL_CONTROL0(x) (HW_PMU_LOWPWR_CTRL(x).B.CONTROL0)

/*! @brief Format value for bitfield PMU_LOWPWR_CTRL_CONTROL0. */
#define BF_PMU_LOWPWR_CTRL_CONTROL0(v) ((uint32_t)((uint32_t)(v) << BP_PMU_LOWPWR_CTRL_CONTROL0) & BM_PMU_LOWPWR_CTRL_CONTROL0)

/*! @brief Set the CONTROL0 field to a new value. */
#define BW_PMU_LOWPWR_CTRL_CONTROL0(x, v) (HW_PMU_LOWPWR_CTRL_WR(x, (HW_PMU_LOWPWR_CTRL_RD(x) & ~BM_PMU_LOWPWR_CTRL_CONTROL0) | BF_PMU_LOWPWR_CTRL_CONTROL0(v)))
/*@}*/

/*!
 * @name Register PMU_LOWPWR_CTRL, field CONTROL1[31:24] (RO)
 *
 * Reserved control bits.
 */
/*@{*/
#define BP_PMU_LOWPWR_CTRL_CONTROL1 (24U)  /*!< Bit position for PMU_LOWPWR_CTRL_CONTROL1. */
#define BM_PMU_LOWPWR_CTRL_CONTROL1 (0xFF000000U) /*!< Bit mask for PMU_LOWPWR_CTRL_CONTROL1. */
#define BS_PMU_LOWPWR_CTRL_CONTROL1 (8U)   /*!< Bit field size in bits for PMU_LOWPWR_CTRL_CONTROL1. */

/*! @brief Read current value of the PMU_LOWPWR_CTRL_CONTROL1 field. */
#define BR_PMU_LOWPWR_CTRL_CONTROL1(x) (HW_PMU_LOWPWR_CTRL(x).B.CONTROL1)
/*@}*/




/*******************************************************************************
 * hw_pmu_t - module struct
 ******************************************************************************/
/*!
 * @brief All PMU module registers.
 */
#pragma pack(1)
typedef struct _hw_pmu
{
    uint8_t _reserved0[512];
    __IO hw_pmu_reg_1p0a_t REG_1P0A;       /*!< [0x200] Anadig 1.0V A Regulator Control Register */
    uint8_t _reserved1[12];
    __IO hw_pmu_reg_1p0d_t REG_1P0D;       /*!< [0x210] Anadig 1.0V D Regulator Control Register */
    uint8_t _reserved2[12];
    __IO hw_pmu_reg_hsic_1p2_t REG_HSIC_1P2; /*!< [0x220] Anadig 1.2V HSIC Regulator Control Register */
    uint8_t _reserved3[12];
    __IO hw_pmu_reg_lpsr_1p0_t REG_LPSR_1P0; /*!< [0x230] Anadig 1.0V Low Power State Retention Regulator Control Register */
    uint8_t _reserved4[60];
    __IO hw_pmu_ref_t REF;                 /*!< [0x270] Anadig Reference Analog Control and Status Register */
    uint8_t _reserved5[188];
    __IO hw_pmu_lowpwr_ctrl_t LOWPWR_CTRL; /*!< [0x330] Anadig Low Power Control Register */
} hw_pmu_t;
#pragma pack()

/*! @brief Macro to access all PMU registers. */
/*! @param x PMU module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_PMU_REGS(PMU_BASE)</code>. */
#define HW_PMU_REGS(x) (*(hw_pmu_t *)(x))

/*
 * iMX7D PWM
 *
 * Pulse Width Modulation (PWM)
 *
 * Registers defined in this header file:
 * - HW_PWM_PWMCR - PWM Control Register
 * - HW_PWM_PWMSR - PWM Status Register
 * - HW_PWM_PWMIR - PWM Interrupt Register
 * - HW_PWM_PWMSAR - PWM Sample Register
 * - HW_PWM_PWMPR - PWM Period Register
 * - HW_PWM_PWMCNR - PWM Counter Register
 *
 * - hw_pwm_t - Struct containing all module registers.
 */

#define HW_PWM_INSTANCE_COUNT (4U) /*!< Number of instances of the PWM module. */
#define HW_PWM1 (0U) /*!< Instance number for PWM1. */
#define HW_PWM2 (1U) /*!< Instance number for PWM2. */
#define HW_PWM3 (2U) /*!< Instance number for PWM3. */
#define HW_PWM4 (3U) /*!< Instance number for PWM4. */
#define PWM1_BASE             (0x30660000U) /*!< Base address for PWM1. */
#define PWM2_BASE             (0x30670000U) /*!< Base address for PWM2. */
#define PWM3_BASE             (0x30680000U) /*!< Base address for PWM3. */
#define PWM4_BASE             (0x30690000U) /*!< Base address for PWM4. */
/*! Array initializer of PWM base addresses. */
#define PWM_BASE_ADDRS        { PWM1_BASE, PWM2_BASE, PWM3_BASE, PWM4_BASE }

/*******************************************************************************
 * HW_PWM_PWMCR - PWM Control Register
 ******************************************************************************/

/*!
 * @brief HW_PWM_PWMCR - PWM Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PWM control register (PWM_PWMCR) is used to configure the operating
 * settings of the PWM. It contains the prescaler for the clock division.
 */
typedef union _hw_pwm_pwmcr
{
    uint32_t U;
    struct _hw_pwm_pwmcr_bitfields
    {
        uint32_t EN : 1;               /*!< [0]  */
        uint32_t REPEAT : 2;           /*!< [2:1]  */
        uint32_t SWR : 1;              /*!< [3]  */
        uint32_t PRESCALER : 12;       /*!< [15:4]  */
        uint32_t CLKSRC : 2;           /*!< [17:16]  */
        uint32_t POUTC : 2;            /*!< [19:18]  */
        uint32_t HCTR : 1;             /*!< [20]  */
        uint32_t BCTR : 1;             /*!< [21]  */
        uint32_t DBGEN : 1;            /*!< [22]  */
        uint32_t WAITEN : 1;           /*!< [23]  */
        uint32_t DOZEN : 1;            /*!< [24]  */
        uint32_t STOPEN : 1;           /*!< [25]  */
        uint32_t FWM : 2;              /*!< [27:26]  */
        uint32_t RESERVED0 : 4;        /*!< [31:28]  */
    } B;
} hw_pwm_pwmcr_t;

/*!
 * @name Constants and macros for entire PWM_PWMCR register
 */
/*@{*/
#define HW_PWM_PWMCR_ADDR(x)     ((uintptr_t)(x) + 0x0U)

#define HW_PWM_PWMCR(x)          (*(__IO hw_pwm_pwmcr_t *) HW_PWM_PWMCR_ADDR(x))
#define HW_PWM_PWMCR_RD(x)       (HW_PWM_PWMCR(x).U)
#define HW_PWM_PWMCR_WR(x, v)    (HW_PWM_PWMCR(x).U = (v))
#define HW_PWM_PWMCR_SET(x, v)   (HW_PWM_PWMCR_WR(x, HW_PWM_PWMCR_RD(x) |  (v)))
#define HW_PWM_PWMCR_CLR(x, v)   (HW_PWM_PWMCR_WR(x, HW_PWM_PWMCR_RD(x) & ~(v)))
#define HW_PWM_PWMCR_TOG(x, v)   (HW_PWM_PWMCR_WR(x, HW_PWM_PWMCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PWM_PWMCR bitfields
 */

/*!
 * @name Register PWM_PWMCR, field EN[0] (RW)
 *
 * PWM Enable. This bit enables the PWM. If this bit is not enabled, the clock
 * prescaler and the counter is reset. When the PWM is enabled, it begins a new
 * period, the output pin is set to start a new period while the prescaler and
 * counter are released and counting begins. To make the PWM work with softreset and
 * disable/enable, users can do software reset by seting the SWR bit, wait
 * software reset done, configure the registers, and then enable the PWM by setting
 * this bit to "1" Users can also disable/enable the PWM if PWM would like to be
 * stopped and resumed with same registers configurations .
 *
 * Values:
 * - 0 - PWM disabled
 * - 1 - PWM enabled
 */
/*@{*/
#define BP_PWM_PWMCR_EN      (0U)          /*!< Bit position for PWM_PWMCR_EN. */
#define BM_PWM_PWMCR_EN      (0x00000001U) /*!< Bit mask for PWM_PWMCR_EN. */
#define BS_PWM_PWMCR_EN      (1U)          /*!< Bit field size in bits for PWM_PWMCR_EN. */

/*! @brief Read current value of the PWM_PWMCR_EN field. */
#define BR_PWM_PWMCR_EN(x)   (HW_PWM_PWMCR(x).B.EN)

/*! @brief Format value for bitfield PWM_PWMCR_EN. */
#define BF_PWM_PWMCR_EN(v)   ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_EN) & BM_PWM_PWMCR_EN)

/*! @brief Set the EN field to a new value. */
#define BW_PWM_PWMCR_EN(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_EN) | BF_PWM_PWMCR_EN(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field REPEAT[2:1] (RW)
 *
 * Sample Repeat. This bit field determines the number of times each sample from
 * the FIFO is to be used.
 *
 * Values:
 * - 00 - Use each sample once
 * - 01 - Use each sample twice
 * - 10 - Use each sample four times
 * - 11 - Use each sample eight times
 */
/*@{*/
#define BP_PWM_PWMCR_REPEAT  (1U)          /*!< Bit position for PWM_PWMCR_REPEAT. */
#define BM_PWM_PWMCR_REPEAT  (0x00000006U) /*!< Bit mask for PWM_PWMCR_REPEAT. */
#define BS_PWM_PWMCR_REPEAT  (2U)          /*!< Bit field size in bits for PWM_PWMCR_REPEAT. */

/*! @brief Read current value of the PWM_PWMCR_REPEAT field. */
#define BR_PWM_PWMCR_REPEAT(x) (HW_PWM_PWMCR(x).B.REPEAT)

/*! @brief Format value for bitfield PWM_PWMCR_REPEAT. */
#define BF_PWM_PWMCR_REPEAT(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_REPEAT) & BM_PWM_PWMCR_REPEAT)

/*! @brief Set the REPEAT field to a new value. */
#define BW_PWM_PWMCR_REPEAT(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_REPEAT) | BF_PWM_PWMCR_REPEAT(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field SWR[3] (RW)
 *
 * Software Reset. PWM is reset when this bit is set to 1. It is a self clearing
 * bit. A write 1 to this bit is a single wait state write cycle. When the block
 * is in reset state this bit is set and is cleared when the reset procedure is
 * over. Setting this bit resets all the registers to their reset values except
 * for the STOPEN, DOZEN, WAITEN, and DBGEN bits in this control register.
 *
 * Values:
 * - 0 - PWM is out of reset
 * - 1 - PWM is undergoing reset
 */
/*@{*/
#define BP_PWM_PWMCR_SWR     (3U)          /*!< Bit position for PWM_PWMCR_SWR. */
#define BM_PWM_PWMCR_SWR     (0x00000008U) /*!< Bit mask for PWM_PWMCR_SWR. */
#define BS_PWM_PWMCR_SWR     (1U)          /*!< Bit field size in bits for PWM_PWMCR_SWR. */

/*! @brief Read current value of the PWM_PWMCR_SWR field. */
#define BR_PWM_PWMCR_SWR(x)  (HW_PWM_PWMCR(x).B.SWR)

/*! @brief Format value for bitfield PWM_PWMCR_SWR. */
#define BF_PWM_PWMCR_SWR(v)  ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_SWR) & BM_PWM_PWMCR_SWR)

/*! @brief Set the SWR field to a new value. */
#define BW_PWM_PWMCR_SWR(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_SWR) | BF_PWM_PWMCR_SWR(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field PRESCALER[15:4] (RW)
 *
 * Counter Clock Prescaler Value. This bit field determines the value by which
 * the clock will be divided before it goes to the counter.
 *
 * Values:
 * - 0 - Divide by 1
 * - 1 - Divide by 2
 * - 111111111111 - Divide by 4096
 */
/*@{*/
#define BP_PWM_PWMCR_PRESCALER (4U)        /*!< Bit position for PWM_PWMCR_PRESCALER. */
#define BM_PWM_PWMCR_PRESCALER (0x0000FFF0U) /*!< Bit mask for PWM_PWMCR_PRESCALER. */
#define BS_PWM_PWMCR_PRESCALER (12U)       /*!< Bit field size in bits for PWM_PWMCR_PRESCALER. */

/*! @brief Read current value of the PWM_PWMCR_PRESCALER field. */
#define BR_PWM_PWMCR_PRESCALER(x) (HW_PWM_PWMCR(x).B.PRESCALER)

/*! @brief Format value for bitfield PWM_PWMCR_PRESCALER. */
#define BF_PWM_PWMCR_PRESCALER(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_PRESCALER) & BM_PWM_PWMCR_PRESCALER)

/*! @brief Set the PRESCALER field to a new value. */
#define BW_PWM_PWMCR_PRESCALER(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_PRESCALER) | BF_PWM_PWMCR_PRESCALER(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field CLKSRC[17:16] (RW)
 *
 * Select Clock Source. These bits determine which clock input will be selected
 * for running the counter. After reset the system functional clock is selected.
 * The input clock can also be turned off if these bits are set to 00. This field
 * value should only be changed when the PWM is disabled
 *
 * Values:
 * - 00 - Clock is off
 * - 01 - ipg_clk
 * - 10 - ipg_clk_highfreq
 * - 11 - ipg_clk_32k
 */
/*@{*/
#define BP_PWM_PWMCR_CLKSRC  (16U)         /*!< Bit position for PWM_PWMCR_CLKSRC. */
#define BM_PWM_PWMCR_CLKSRC  (0x00030000U) /*!< Bit mask for PWM_PWMCR_CLKSRC. */
#define BS_PWM_PWMCR_CLKSRC  (2U)          /*!< Bit field size in bits for PWM_PWMCR_CLKSRC. */

/*! @brief Read current value of the PWM_PWMCR_CLKSRC field. */
#define BR_PWM_PWMCR_CLKSRC(x) (HW_PWM_PWMCR(x).B.CLKSRC)

/*! @brief Format value for bitfield PWM_PWMCR_CLKSRC. */
#define BF_PWM_PWMCR_CLKSRC(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_CLKSRC) & BM_PWM_PWMCR_CLKSRC)

/*! @brief Set the CLKSRC field to a new value. */
#define BW_PWM_PWMCR_CLKSRC(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_CLKSRC) | BF_PWM_PWMCR_CLKSRC(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field POUTC[19:18] (RW)
 *
 * PWM Output Configuration. This bit field determines the mode of PWM output on
 * the output pin.
 *
 * Values:
 * - 00 - Output pin is set at rollover and cleared at comparison
 * - 01 - Output pin is cleared at rollover and set at comparison
 * - 10 - PWM output is disconnected
 * - 11 - PWM output is disconnected
 */
/*@{*/
#define BP_PWM_PWMCR_POUTC   (18U)         /*!< Bit position for PWM_PWMCR_POUTC. */
#define BM_PWM_PWMCR_POUTC   (0x000C0000U) /*!< Bit mask for PWM_PWMCR_POUTC. */
#define BS_PWM_PWMCR_POUTC   (2U)          /*!< Bit field size in bits for PWM_PWMCR_POUTC. */

/*! @brief Read current value of the PWM_PWMCR_POUTC field. */
#define BR_PWM_PWMCR_POUTC(x) (HW_PWM_PWMCR(x).B.POUTC)

/*! @brief Format value for bitfield PWM_PWMCR_POUTC. */
#define BF_PWM_PWMCR_POUTC(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_POUTC) & BM_PWM_PWMCR_POUTC)

/*! @brief Set the POUTC field to a new value. */
#define BW_PWM_PWMCR_POUTC(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_POUTC) | BF_PWM_PWMCR_POUTC(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field HCTR[20] (RW)
 *
 * Half-word Data Swap Control. This bit determines which half word data from
 * the 32-bit IP Bus interface is written into the lower 16 bits of the sample
 * register.
 *
 * Values:
 * - 0 - Half word swapping does not take place
 * - 1 - Half words from write data bus are swapped
 */
/*@{*/
#define BP_PWM_PWMCR_HCTR    (20U)         /*!< Bit position for PWM_PWMCR_HCTR. */
#define BM_PWM_PWMCR_HCTR    (0x00100000U) /*!< Bit mask for PWM_PWMCR_HCTR. */
#define BS_PWM_PWMCR_HCTR    (1U)          /*!< Bit field size in bits for PWM_PWMCR_HCTR. */

/*! @brief Read current value of the PWM_PWMCR_HCTR field. */
#define BR_PWM_PWMCR_HCTR(x) (HW_PWM_PWMCR(x).B.HCTR)

/*! @brief Format value for bitfield PWM_PWMCR_HCTR. */
#define BF_PWM_PWMCR_HCTR(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_HCTR) & BM_PWM_PWMCR_HCTR)

/*! @brief Set the HCTR field to a new value. */
#define BW_PWM_PWMCR_HCTR(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_HCTR) | BF_PWM_PWMCR_HCTR(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field BCTR[21] (RW)
 *
 * Byte Data Swap Control. This bit determines the byte ordering of the 16-bit
 * data when it goes into the FIFO from the sample register.
 *
 * Values:
 * - 0 - byte ordering remains the same
 * - 1 - byte ordering is reversed
 */
/*@{*/
#define BP_PWM_PWMCR_BCTR    (21U)         /*!< Bit position for PWM_PWMCR_BCTR. */
#define BM_PWM_PWMCR_BCTR    (0x00200000U) /*!< Bit mask for PWM_PWMCR_BCTR. */
#define BS_PWM_PWMCR_BCTR    (1U)          /*!< Bit field size in bits for PWM_PWMCR_BCTR. */

/*! @brief Read current value of the PWM_PWMCR_BCTR field. */
#define BR_PWM_PWMCR_BCTR(x) (HW_PWM_PWMCR(x).B.BCTR)

/*! @brief Format value for bitfield PWM_PWMCR_BCTR. */
#define BF_PWM_PWMCR_BCTR(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_BCTR) & BM_PWM_PWMCR_BCTR)

/*! @brief Set the BCTR field to a new value. */
#define BW_PWM_PWMCR_BCTR(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_BCTR) | BF_PWM_PWMCR_BCTR(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field DBGEN[22] (RW)
 *
 * Debug Mode Enable. This bit keeps the PWM functional in debug mode. When this
 * bit is cleared, the input clock is gated off in debug mode. This bit is not
 * affected by software reset. It is cleared by hardware reset.
 *
 * Values:
 * - 0 - Inactive in debug mode
 * - 1 - Active in debug mode
 */
/*@{*/
#define BP_PWM_PWMCR_DBGEN   (22U)         /*!< Bit position for PWM_PWMCR_DBGEN. */
#define BM_PWM_PWMCR_DBGEN   (0x00400000U) /*!< Bit mask for PWM_PWMCR_DBGEN. */
#define BS_PWM_PWMCR_DBGEN   (1U)          /*!< Bit field size in bits for PWM_PWMCR_DBGEN. */

/*! @brief Read current value of the PWM_PWMCR_DBGEN field. */
#define BR_PWM_PWMCR_DBGEN(x) (HW_PWM_PWMCR(x).B.DBGEN)

/*! @brief Format value for bitfield PWM_PWMCR_DBGEN. */
#define BF_PWM_PWMCR_DBGEN(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_DBGEN) & BM_PWM_PWMCR_DBGEN)

/*! @brief Set the DBGEN field to a new value. */
#define BW_PWM_PWMCR_DBGEN(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_DBGEN) | BF_PWM_PWMCR_DBGEN(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field WAITEN[23] (RW)
 *
 * Wait Mode Enable. This bit keeps the PWM functional in wait mode. When this
 * bit is cleared, the input clock is gated off in wait mode. This bit is not
 * affected by software reset. It is cleared by hardware reset.
 *
 * Values:
 * - 0 - Inactive in wait mode
 * - 1 - Active in wait mode
 */
/*@{*/
#define BP_PWM_PWMCR_WAITEN  (23U)         /*!< Bit position for PWM_PWMCR_WAITEN. */
#define BM_PWM_PWMCR_WAITEN  (0x00800000U) /*!< Bit mask for PWM_PWMCR_WAITEN. */
#define BS_PWM_PWMCR_WAITEN  (1U)          /*!< Bit field size in bits for PWM_PWMCR_WAITEN. */

/*! @brief Read current value of the PWM_PWMCR_WAITEN field. */
#define BR_PWM_PWMCR_WAITEN(x) (HW_PWM_PWMCR(x).B.WAITEN)

/*! @brief Format value for bitfield PWM_PWMCR_WAITEN. */
#define BF_PWM_PWMCR_WAITEN(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_WAITEN) & BM_PWM_PWMCR_WAITEN)

/*! @brief Set the WAITEN field to a new value. */
#define BW_PWM_PWMCR_WAITEN(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_WAITEN) | BF_PWM_PWMCR_WAITEN(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field DOZEN[24] (RW)
 *
 * Doze Mode Enable. This bit keeps the PWM functional in doze mode. When this
 * bit is cleared, the input clock is gated off in doze mode. This bit is not
 * affected by software reset. It is cleared by hardware reset.
 *
 * Values:
 * - 0 - Inactive in doze mode
 * - 1 - Active in doze mode
 */
/*@{*/
#define BP_PWM_PWMCR_DOZEN   (24U)         /*!< Bit position for PWM_PWMCR_DOZEN. */
#define BM_PWM_PWMCR_DOZEN   (0x01000000U) /*!< Bit mask for PWM_PWMCR_DOZEN. */
#define BS_PWM_PWMCR_DOZEN   (1U)          /*!< Bit field size in bits for PWM_PWMCR_DOZEN. */

/*! @brief Read current value of the PWM_PWMCR_DOZEN field. */
#define BR_PWM_PWMCR_DOZEN(x) (HW_PWM_PWMCR(x).B.DOZEN)

/*! @brief Format value for bitfield PWM_PWMCR_DOZEN. */
#define BF_PWM_PWMCR_DOZEN(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_DOZEN) & BM_PWM_PWMCR_DOZEN)

/*! @brief Set the DOZEN field to a new value. */
#define BW_PWM_PWMCR_DOZEN(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_DOZEN) | BF_PWM_PWMCR_DOZEN(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field STOPEN[25] (RW)
 *
 * Stop Mode Enable. This bit keeps the PWM functional while in stop mode. When
 * this bit is cleared, the input clock is gated off in stop mode. This bit is
 * not affected by software reset. It is cleared by hardware reset.
 *
 * Values:
 * - 0 - Inactive in stop mode
 * - 1 - Active in stop mode
 */
/*@{*/
#define BP_PWM_PWMCR_STOPEN  (25U)         /*!< Bit position for PWM_PWMCR_STOPEN. */
#define BM_PWM_PWMCR_STOPEN  (0x02000000U) /*!< Bit mask for PWM_PWMCR_STOPEN. */
#define BS_PWM_PWMCR_STOPEN  (1U)          /*!< Bit field size in bits for PWM_PWMCR_STOPEN. */

/*! @brief Read current value of the PWM_PWMCR_STOPEN field. */
#define BR_PWM_PWMCR_STOPEN(x) (HW_PWM_PWMCR(x).B.STOPEN)

/*! @brief Format value for bitfield PWM_PWMCR_STOPEN. */
#define BF_PWM_PWMCR_STOPEN(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_STOPEN) & BM_PWM_PWMCR_STOPEN)

/*! @brief Set the STOPEN field to a new value. */
#define BW_PWM_PWMCR_STOPEN(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_STOPEN) | BF_PWM_PWMCR_STOPEN(v)))
/*@}*/

/*!
 * @name Register PWM_PWMCR, field FWM[27:26] (RW)
 *
 * FIFO Water Mark. These bits are used to set the data level at which the FIFO
 * empty flag will be set and the corresponding interrupt generated
 *
 * Values:
 * - 00 - FIFO empty flag is set when there are more than or equal to 1 empty
 *     slots in FIFO
 * - 01 - FIFO empty flag is set when there are more than or equal to 2 empty
 *     slots in FIFO
 * - 10 - FIFO empty flag is set when there are more than or equal to 3 empty
 *     slots in FIFO
 * - 11 - FIFO empty flag is set when there are more than or equal to 4 empty
 *     slots in FIFO
 */
/*@{*/
#define BP_PWM_PWMCR_FWM     (26U)         /*!< Bit position for PWM_PWMCR_FWM. */
#define BM_PWM_PWMCR_FWM     (0x0C000000U) /*!< Bit mask for PWM_PWMCR_FWM. */
#define BS_PWM_PWMCR_FWM     (2U)          /*!< Bit field size in bits for PWM_PWMCR_FWM. */

/*! @brief Read current value of the PWM_PWMCR_FWM field. */
#define BR_PWM_PWMCR_FWM(x)  (HW_PWM_PWMCR(x).B.FWM)

/*! @brief Format value for bitfield PWM_PWMCR_FWM. */
#define BF_PWM_PWMCR_FWM(v)  ((uint32_t)((uint32_t)(v) << BP_PWM_PWMCR_FWM) & BM_PWM_PWMCR_FWM)

/*! @brief Set the FWM field to a new value. */
#define BW_PWM_PWMCR_FWM(x, v) (HW_PWM_PWMCR_WR(x, (HW_PWM_PWMCR_RD(x) & ~BM_PWM_PWMCR_FWM) | BF_PWM_PWMCR_FWM(v)))
/*@}*/

/*******************************************************************************
 * HW_PWM_PWMSR - PWM Status Register
 ******************************************************************************/

/*!
 * @brief HW_PWM_PWMSR - PWM Status Register (RW)
 *
 * Reset value: 0x00000008U
 *
 * The PWM status register (PWM_PWMSR) contains seven bits which display the
 * state of the FIFO and the occurrence of rollover and compare events. The FIFOAV
 * bit is read-only but the other four bits can be cleared by writing 1 to them.
 * The FE, ROV, and CMP bits are associated with FIFO-Empty, Roll-over, and
 * Compare interrupts, respectively.
 */
typedef union _hw_pwm_pwmsr
{
    uint32_t U;
    struct _hw_pwm_pwmsr_bitfields
    {
        uint32_t FIFOAV : 3;           /*!< [2:0]  */
        uint32_t FE : 1;               /*!< [3]  */
        uint32_t ROV : 1;              /*!< [4]  */
        uint32_t CMP : 1;              /*!< [5]  */
        uint32_t FWE : 1;              /*!< [6]  */
        uint32_t RESERVED0 : 25;       /*!< [31:7]  */
    } B;
} hw_pwm_pwmsr_t;

/*!
 * @name Constants and macros for entire PWM_PWMSR register
 */
/*@{*/
#define HW_PWM_PWMSR_ADDR(x)     ((uintptr_t)(x) + 0x4U)

#define HW_PWM_PWMSR(x)          (*(__IO hw_pwm_pwmsr_t *) HW_PWM_PWMSR_ADDR(x))
#define HW_PWM_PWMSR_RD(x)       (HW_PWM_PWMSR(x).U)
#define HW_PWM_PWMSR_WR(x, v)    (HW_PWM_PWMSR(x).U = (v))
#define HW_PWM_PWMSR_SET(x, v)   (HW_PWM_PWMSR_WR(x, HW_PWM_PWMSR_RD(x) |  (v)))
#define HW_PWM_PWMSR_CLR(x, v)   (HW_PWM_PWMSR_WR(x, HW_PWM_PWMSR_RD(x) & ~(v)))
#define HW_PWM_PWMSR_TOG(x, v)   (HW_PWM_PWMSR_WR(x, HW_PWM_PWMSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PWM_PWMSR bitfields
 */

/*!
 * @name Register PWM_PWMSR, field FIFOAV[2:0] (RO)
 *
 * FIFO Available. These read-only bits indicate the data level remaining in the
 * FIFO. An attempted write to these bits will not affect their value and no
 * transfer error is generated.
 *
 * Values:
 * - 000 - No data available
 * - 001 - 1 word of data in FIFO
 * - 010 - 2 words of data in FIFO
 * - 011 - 3 words of data in FIFO
 * - 100 - 4 words of data in FIFO
 * - 101 - unused
 * - 110 - unused
 * - 111 - unused
 */
/*@{*/
#define BP_PWM_PWMSR_FIFOAV  (0U)          /*!< Bit position for PWM_PWMSR_FIFOAV. */
#define BM_PWM_PWMSR_FIFOAV  (0x00000007U) /*!< Bit mask for PWM_PWMSR_FIFOAV. */
#define BS_PWM_PWMSR_FIFOAV  (3U)          /*!< Bit field size in bits for PWM_PWMSR_FIFOAV. */

/*! @brief Read current value of the PWM_PWMSR_FIFOAV field. */
#define BR_PWM_PWMSR_FIFOAV(x) (HW_PWM_PWMSR(x).B.FIFOAV)
/*@}*/

/*!
 * @name Register PWM_PWMSR, field FE[3] (W1C)
 *
 * FIFO Empty Status Bit. This bit indicates the FIFO data level in comparison
 * to the water level set by FWM field in the control register.
 *
 * Values:
 * - 0 - Data level is above water mark
 * - 1 - When the data level falls below the mark set by FWM field
 */
/*@{*/
#define BP_PWM_PWMSR_FE      (3U)          /*!< Bit position for PWM_PWMSR_FE. */
#define BM_PWM_PWMSR_FE      (0x00000008U) /*!< Bit mask for PWM_PWMSR_FE. */
#define BS_PWM_PWMSR_FE      (1U)          /*!< Bit field size in bits for PWM_PWMSR_FE. */

/*! @brief Read current value of the PWM_PWMSR_FE field. */
#define BR_PWM_PWMSR_FE(x)   (HW_PWM_PWMSR(x).B.FE)

/*! @brief Format value for bitfield PWM_PWMSR_FE. */
#define BF_PWM_PWMSR_FE(v)   ((uint32_t)((uint32_t)(v) << BP_PWM_PWMSR_FE) & BM_PWM_PWMSR_FE)

/*! @brief Set the FE field to a new value. */
#define BW_PWM_PWMSR_FE(x, v) (HW_PWM_PWMSR_WR(x, (HW_PWM_PWMSR_RD(x) & ~(BM_PWM_PWMSR_FE | BM_PWM_PWMSR_ROV | BM_PWM_PWMSR_CMP | BM_PWM_PWMSR_FWE)) | BF_PWM_PWMSR_FE(v)))
/*@}*/

/*!
 * @name Register PWM_PWMSR, field ROV[4] (W1C)
 *
 * Roll-over Status. This bit shows that a roll-over event has occurred.
 *
 * Values:
 * - 0 - Roll-over event not occurred
 * - 1 - Roll-over event occurred
 */
/*@{*/
#define BP_PWM_PWMSR_ROV     (4U)          /*!< Bit position for PWM_PWMSR_ROV. */
#define BM_PWM_PWMSR_ROV     (0x00000010U) /*!< Bit mask for PWM_PWMSR_ROV. */
#define BS_PWM_PWMSR_ROV     (1U)          /*!< Bit field size in bits for PWM_PWMSR_ROV. */

/*! @brief Read current value of the PWM_PWMSR_ROV field. */
#define BR_PWM_PWMSR_ROV(x)  (HW_PWM_PWMSR(x).B.ROV)

/*! @brief Format value for bitfield PWM_PWMSR_ROV. */
#define BF_PWM_PWMSR_ROV(v)  ((uint32_t)((uint32_t)(v) << BP_PWM_PWMSR_ROV) & BM_PWM_PWMSR_ROV)

/*! @brief Set the ROV field to a new value. */
#define BW_PWM_PWMSR_ROV(x, v) (HW_PWM_PWMSR_WR(x, (HW_PWM_PWMSR_RD(x) & ~(BM_PWM_PWMSR_ROV | BM_PWM_PWMSR_FE | BM_PWM_PWMSR_CMP | BM_PWM_PWMSR_FWE)) | BF_PWM_PWMSR_ROV(v)))
/*@}*/

/*!
 * @name Register PWM_PWMSR, field CMP[5] (W1C)
 *
 * Compare Status. This bit shows that a compare event has occurred.
 *
 * Values:
 * - 0 - Compare event not occurred
 * - 1 - Compare event occurred
 */
/*@{*/
#define BP_PWM_PWMSR_CMP     (5U)          /*!< Bit position for PWM_PWMSR_CMP. */
#define BM_PWM_PWMSR_CMP     (0x00000020U) /*!< Bit mask for PWM_PWMSR_CMP. */
#define BS_PWM_PWMSR_CMP     (1U)          /*!< Bit field size in bits for PWM_PWMSR_CMP. */

/*! @brief Read current value of the PWM_PWMSR_CMP field. */
#define BR_PWM_PWMSR_CMP(x)  (HW_PWM_PWMSR(x).B.CMP)

/*! @brief Format value for bitfield PWM_PWMSR_CMP. */
#define BF_PWM_PWMSR_CMP(v)  ((uint32_t)((uint32_t)(v) << BP_PWM_PWMSR_CMP) & BM_PWM_PWMSR_CMP)

/*! @brief Set the CMP field to a new value. */
#define BW_PWM_PWMSR_CMP(x, v) (HW_PWM_PWMSR_WR(x, (HW_PWM_PWMSR_RD(x) & ~(BM_PWM_PWMSR_CMP | BM_PWM_PWMSR_FE | BM_PWM_PWMSR_ROV | BM_PWM_PWMSR_FWE)) | BF_PWM_PWMSR_CMP(v)))
/*@}*/

/*!
 * @name Register PWM_PWMSR, field FWE[6] (W1C)
 *
 * FIFO Write Error Status. This bit shows that an attempt has been made to
 * write FIFO when it is full.
 *
 * Values:
 * - 0 - FIFO write error not occurred
 * - 1 - FIFO write error occurred
 */
/*@{*/
#define BP_PWM_PWMSR_FWE     (6U)          /*!< Bit position for PWM_PWMSR_FWE. */
#define BM_PWM_PWMSR_FWE     (0x00000040U) /*!< Bit mask for PWM_PWMSR_FWE. */
#define BS_PWM_PWMSR_FWE     (1U)          /*!< Bit field size in bits for PWM_PWMSR_FWE. */

/*! @brief Read current value of the PWM_PWMSR_FWE field. */
#define BR_PWM_PWMSR_FWE(x)  (HW_PWM_PWMSR(x).B.FWE)

/*! @brief Format value for bitfield PWM_PWMSR_FWE. */
#define BF_PWM_PWMSR_FWE(v)  ((uint32_t)((uint32_t)(v) << BP_PWM_PWMSR_FWE) & BM_PWM_PWMSR_FWE)

/*! @brief Set the FWE field to a new value. */
#define BW_PWM_PWMSR_FWE(x, v) (HW_PWM_PWMSR_WR(x, (HW_PWM_PWMSR_RD(x) & ~(BM_PWM_PWMSR_FWE | BM_PWM_PWMSR_FE | BM_PWM_PWMSR_ROV | BM_PWM_PWMSR_CMP)) | BF_PWM_PWMSR_FWE(v)))
/*@}*/

/*******************************************************************************
 * HW_PWM_PWMIR - PWM Interrupt Register
 ******************************************************************************/

/*!
 * @brief HW_PWM_PWMIR - PWM Interrupt Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PWM Interrupt register (PWM_PWMIR) contains three bits which control the
 * generation of the compare, rollover and FIFO empty interrupts.
 */
typedef union _hw_pwm_pwmir
{
    uint32_t U;
    struct _hw_pwm_pwmir_bitfields
    {
        uint32_t FIE : 1;              /*!< [0]  */
        uint32_t RIE : 1;              /*!< [1]  */
        uint32_t CIE : 1;              /*!< [2]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_pwm_pwmir_t;

/*!
 * @name Constants and macros for entire PWM_PWMIR register
 */
/*@{*/
#define HW_PWM_PWMIR_ADDR(x)     ((uintptr_t)(x) + 0x8U)

#define HW_PWM_PWMIR(x)          (*(__IO hw_pwm_pwmir_t *) HW_PWM_PWMIR_ADDR(x))
#define HW_PWM_PWMIR_RD(x)       (HW_PWM_PWMIR(x).U)
#define HW_PWM_PWMIR_WR(x, v)    (HW_PWM_PWMIR(x).U = (v))
#define HW_PWM_PWMIR_SET(x, v)   (HW_PWM_PWMIR_WR(x, HW_PWM_PWMIR_RD(x) |  (v)))
#define HW_PWM_PWMIR_CLR(x, v)   (HW_PWM_PWMIR_WR(x, HW_PWM_PWMIR_RD(x) & ~(v)))
#define HW_PWM_PWMIR_TOG(x, v)   (HW_PWM_PWMIR_WR(x, HW_PWM_PWMIR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PWM_PWMIR bitfields
 */

/*!
 * @name Register PWM_PWMIR, field FIE[0] (RW)
 *
 * FIFO Empty Interrupt Enable. This bit controls the generation of the FIFO
 * Empty interrupt.
 *
 * Values:
 * - 0 - FIFO Empty interrupt disabled
 * - 1 - FIFO Empty interrupt enabled
 */
/*@{*/
#define BP_PWM_PWMIR_FIE     (0U)          /*!< Bit position for PWM_PWMIR_FIE. */
#define BM_PWM_PWMIR_FIE     (0x00000001U) /*!< Bit mask for PWM_PWMIR_FIE. */
#define BS_PWM_PWMIR_FIE     (1U)          /*!< Bit field size in bits for PWM_PWMIR_FIE. */

/*! @brief Read current value of the PWM_PWMIR_FIE field. */
#define BR_PWM_PWMIR_FIE(x)  (HW_PWM_PWMIR(x).B.FIE)

/*! @brief Format value for bitfield PWM_PWMIR_FIE. */
#define BF_PWM_PWMIR_FIE(v)  ((uint32_t)((uint32_t)(v) << BP_PWM_PWMIR_FIE) & BM_PWM_PWMIR_FIE)

/*! @brief Set the FIE field to a new value. */
#define BW_PWM_PWMIR_FIE(x, v) (HW_PWM_PWMIR_WR(x, (HW_PWM_PWMIR_RD(x) & ~BM_PWM_PWMIR_FIE) | BF_PWM_PWMIR_FIE(v)))
/*@}*/

/*!
 * @name Register PWM_PWMIR, field RIE[1] (RW)
 *
 * Roll-over Interrupt Enable. This bit controls the generation of the Rollover
 * interrupt.
 *
 * Values:
 * - 0 - Roll-over interrupt not enabled
 * - 1 - Roll-over Interrupt enabled
 */
/*@{*/
#define BP_PWM_PWMIR_RIE     (1U)          /*!< Bit position for PWM_PWMIR_RIE. */
#define BM_PWM_PWMIR_RIE     (0x00000002U) /*!< Bit mask for PWM_PWMIR_RIE. */
#define BS_PWM_PWMIR_RIE     (1U)          /*!< Bit field size in bits for PWM_PWMIR_RIE. */

/*! @brief Read current value of the PWM_PWMIR_RIE field. */
#define BR_PWM_PWMIR_RIE(x)  (HW_PWM_PWMIR(x).B.RIE)

/*! @brief Format value for bitfield PWM_PWMIR_RIE. */
#define BF_PWM_PWMIR_RIE(v)  ((uint32_t)((uint32_t)(v) << BP_PWM_PWMIR_RIE) & BM_PWM_PWMIR_RIE)

/*! @brief Set the RIE field to a new value. */
#define BW_PWM_PWMIR_RIE(x, v) (HW_PWM_PWMIR_WR(x, (HW_PWM_PWMIR_RD(x) & ~BM_PWM_PWMIR_RIE) | BF_PWM_PWMIR_RIE(v)))
/*@}*/

/*!
 * @name Register PWM_PWMIR, field CIE[2] (RW)
 *
 * Compare Interrupt Enable. This bit controls the generation of the Compare
 * interrupt.
 *
 * Values:
 * - 0 - Compare Interrupt not enabled
 * - 1 - Compare Interrupt enabled
 */
/*@{*/
#define BP_PWM_PWMIR_CIE     (2U)          /*!< Bit position for PWM_PWMIR_CIE. */
#define BM_PWM_PWMIR_CIE     (0x00000004U) /*!< Bit mask for PWM_PWMIR_CIE. */
#define BS_PWM_PWMIR_CIE     (1U)          /*!< Bit field size in bits for PWM_PWMIR_CIE. */

/*! @brief Read current value of the PWM_PWMIR_CIE field. */
#define BR_PWM_PWMIR_CIE(x)  (HW_PWM_PWMIR(x).B.CIE)

/*! @brief Format value for bitfield PWM_PWMIR_CIE. */
#define BF_PWM_PWMIR_CIE(v)  ((uint32_t)((uint32_t)(v) << BP_PWM_PWMIR_CIE) & BM_PWM_PWMIR_CIE)

/*! @brief Set the CIE field to a new value. */
#define BW_PWM_PWMIR_CIE(x, v) (HW_PWM_PWMIR_WR(x, (HW_PWM_PWMIR_RD(x) & ~BM_PWM_PWMIR_CIE) | BF_PWM_PWMIR_CIE(v)))
/*@}*/

/*******************************************************************************
 * HW_PWM_PWMSAR - PWM Sample Register
 ******************************************************************************/

/*!
 * @brief HW_PWM_PWMSAR - PWM Sample Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PWM sample register (PWM_PWMSAR) is the input to the FIFO. 16-bit words
 * are loaded into the FIFO. The FIFO can be written at any time, but can be read
 * only when the PWM is enabled. The PWM will run at the last set duty-cycle
 * setting if all the values of the FIFO has been utilized, until the FIFO is
 * reloaded or the PWM is disabled. When a new value is written, the duty cycle changes
 * after the current period is over. A value of zero in the sample register will
 * result in the PWMO output signal always being low/high (POUTC = 00 it will be
 * low and POUTC = 01 it will be high), and no output waveform will be produced.
 * If the value in this register is higher than the PERIOD + 1, the output will
 * never be set/reset depending on POUTC value.
 */
typedef union _hw_pwm_pwmsar
{
    uint32_t U;
    struct _hw_pwm_pwmsar_bitfields
    {
        uint32_t SAMPLE : 16;          /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_pwm_pwmsar_t;

/*!
 * @name Constants and macros for entire PWM_PWMSAR register
 */
/*@{*/
#define HW_PWM_PWMSAR_ADDR(x)    ((uintptr_t)(x) + 0xCU)

#define HW_PWM_PWMSAR(x)         (*(__IO hw_pwm_pwmsar_t *) HW_PWM_PWMSAR_ADDR(x))
#define HW_PWM_PWMSAR_RD(x)      (HW_PWM_PWMSAR(x).U)
#define HW_PWM_PWMSAR_WR(x, v)   (HW_PWM_PWMSAR(x).U = (v))
#define HW_PWM_PWMSAR_SET(x, v)  (HW_PWM_PWMSAR_WR(x, HW_PWM_PWMSAR_RD(x) |  (v)))
#define HW_PWM_PWMSAR_CLR(x, v)  (HW_PWM_PWMSAR_WR(x, HW_PWM_PWMSAR_RD(x) & ~(v)))
#define HW_PWM_PWMSAR_TOG(x, v)  (HW_PWM_PWMSAR_WR(x, HW_PWM_PWMSAR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PWM_PWMSAR bitfields
 */

/*!
 * @name Register PWM_PWMSAR, field SAMPLE[15:0] (RW)
 *
 * Sample Value. This is the input to the 4x16 FIFO. The value in this register
 * denotes the value of the sample being currently used.
 */
/*@{*/
#define BP_PWM_PWMSAR_SAMPLE (0U)          /*!< Bit position for PWM_PWMSAR_SAMPLE. */
#define BM_PWM_PWMSAR_SAMPLE (0x0000FFFFU) /*!< Bit mask for PWM_PWMSAR_SAMPLE. */
#define BS_PWM_PWMSAR_SAMPLE (16U)         /*!< Bit field size in bits for PWM_PWMSAR_SAMPLE. */

/*! @brief Read current value of the PWM_PWMSAR_SAMPLE field. */
#define BR_PWM_PWMSAR_SAMPLE(x) (HW_PWM_PWMSAR(x).B.SAMPLE)

/*! @brief Format value for bitfield PWM_PWMSAR_SAMPLE. */
#define BF_PWM_PWMSAR_SAMPLE(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMSAR_SAMPLE) & BM_PWM_PWMSAR_SAMPLE)

/*! @brief Set the SAMPLE field to a new value. */
#define BW_PWM_PWMSAR_SAMPLE(x, v) (HW_PWM_PWMSAR_WR(x, (HW_PWM_PWMSAR_RD(x) & ~BM_PWM_PWMSAR_SAMPLE) | BF_PWM_PWMSAR_SAMPLE(v)))
/*@}*/

/*******************************************************************************
 * HW_PWM_PWMPR - PWM Period Register
 ******************************************************************************/

/*!
 * @brief HW_PWM_PWMPR - PWM Period Register (RW)
 *
 * Reset value: 0x0000FFFEU
 *
 * The PWM period register (PWM_PWMPR) determines the period of the PWM output
 * signal. After the counter value matches PERIOD + 1, the counter is reset to
 * start another period. PWMO (Hz) = PCLK(Hz) / (period +2) A value of zero in the
 * PWM_PWMPR will result in a period of two clock cycles for the output signal.
 * Writing 0xFFFF to this register will achieve the same result as writing 0xFFFE.
 * A change in the period value due to a write in PWM_PWMPR results in the
 * counter being reset to zero and the start of a new count period. Settings PWM_PWMPR
 * to 0xFFFF when PWMx_PWMCR REPEAT bits are set to non-zero values is not
 * allowed.
 */
typedef union _hw_pwm_pwmpr
{
    uint32_t U;
    struct _hw_pwm_pwmpr_bitfields
    {
        uint32_t PERIOD : 16;          /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_pwm_pwmpr_t;

/*!
 * @name Constants and macros for entire PWM_PWMPR register
 */
/*@{*/
#define HW_PWM_PWMPR_ADDR(x)     ((uintptr_t)(x) + 0x10U)

#define HW_PWM_PWMPR(x)          (*(__IO hw_pwm_pwmpr_t *) HW_PWM_PWMPR_ADDR(x))
#define HW_PWM_PWMPR_RD(x)       (HW_PWM_PWMPR(x).U)
#define HW_PWM_PWMPR_WR(x, v)    (HW_PWM_PWMPR(x).U = (v))
#define HW_PWM_PWMPR_SET(x, v)   (HW_PWM_PWMPR_WR(x, HW_PWM_PWMPR_RD(x) |  (v)))
#define HW_PWM_PWMPR_CLR(x, v)   (HW_PWM_PWMPR_WR(x, HW_PWM_PWMPR_RD(x) & ~(v)))
#define HW_PWM_PWMPR_TOG(x, v)   (HW_PWM_PWMPR_WR(x, HW_PWM_PWMPR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PWM_PWMPR bitfields
 */

/*!
 * @name Register PWM_PWMPR, field PERIOD[15:0] (RW)
 *
 * Period Value. These bits determine the Period of the count cycle. The counter
 * counts up to [Period Value] +1 and is then reset to 0x0000.
 */
/*@{*/
#define BP_PWM_PWMPR_PERIOD  (0U)          /*!< Bit position for PWM_PWMPR_PERIOD. */
#define BM_PWM_PWMPR_PERIOD  (0x0000FFFFU) /*!< Bit mask for PWM_PWMPR_PERIOD. */
#define BS_PWM_PWMPR_PERIOD  (16U)         /*!< Bit field size in bits for PWM_PWMPR_PERIOD. */

/*! @brief Read current value of the PWM_PWMPR_PERIOD field. */
#define BR_PWM_PWMPR_PERIOD(x) (HW_PWM_PWMPR(x).B.PERIOD)

/*! @brief Format value for bitfield PWM_PWMPR_PERIOD. */
#define BF_PWM_PWMPR_PERIOD(v) ((uint32_t)((uint32_t)(v) << BP_PWM_PWMPR_PERIOD) & BM_PWM_PWMPR_PERIOD)

/*! @brief Set the PERIOD field to a new value. */
#define BW_PWM_PWMPR_PERIOD(x, v) (HW_PWM_PWMPR_WR(x, (HW_PWM_PWMPR_RD(x) & ~BM_PWM_PWMPR_PERIOD) | BF_PWM_PWMPR_PERIOD(v)))
/*@}*/

/*******************************************************************************
 * HW_PWM_PWMCNR - PWM Counter Register
 ******************************************************************************/

/*!
 * @brief HW_PWM_PWMCNR - PWM Counter Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The read-only pulse-width modulator counter register (PWM_PWMCNR) contains
 * the current count value and can be read at any time without disturbing the
 * counter.
 */
typedef union _hw_pwm_pwmcnr
{
    uint32_t U;
    struct _hw_pwm_pwmcnr_bitfields
    {
        uint32_t COUNT : 16;           /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_pwm_pwmcnr_t;

/*!
 * @name Constants and macros for entire PWM_PWMCNR register
 */
/*@{*/
#define HW_PWM_PWMCNR_ADDR(x)    ((uintptr_t)(x) + 0x14U)

#define HW_PWM_PWMCNR(x)         (*(__I hw_pwm_pwmcnr_t *) HW_PWM_PWMCNR_ADDR(x))
#define HW_PWM_PWMCNR_RD(x)      (HW_PWM_PWMCNR(x).U)
/*@}*/

/*
 * Constants & macros for individual PWM_PWMCNR bitfields
 */

/*!
 * @name Register PWM_PWMCNR, field COUNT[15:0] (RO)
 *
 * Counter Value. These bits are the counter register value and denotes the
 * current count state the counter register is in.
 */
/*@{*/
#define BP_PWM_PWMCNR_COUNT  (0U)          /*!< Bit position for PWM_PWMCNR_COUNT. */
#define BM_PWM_PWMCNR_COUNT  (0x0000FFFFU) /*!< Bit mask for PWM_PWMCNR_COUNT. */
#define BS_PWM_PWMCNR_COUNT  (16U)         /*!< Bit field size in bits for PWM_PWMCNR_COUNT. */

/*! @brief Read current value of the PWM_PWMCNR_COUNT field. */
#define BR_PWM_PWMCNR_COUNT(x) (HW_PWM_PWMCNR(x).B.COUNT)
/*@}*/

/*******************************************************************************
 * hw_pwm_t - module struct
 ******************************************************************************/
/*!
 * @brief All PWM module registers.
 */
#pragma pack(1)
typedef struct _hw_pwm
{
    __IO hw_pwm_pwmcr_t PWMCR;             /*!< [0x0] PWM Control Register */
    __IO hw_pwm_pwmsr_t PWMSR;             /*!< [0x4] PWM Status Register */
    __IO hw_pwm_pwmir_t PWMIR;             /*!< [0x8] PWM Interrupt Register */
    __IO hw_pwm_pwmsar_t PWMSAR;           /*!< [0xC] PWM Sample Register */
    __IO hw_pwm_pwmpr_t PWMPR;             /*!< [0x10] PWM Period Register */
    __I hw_pwm_pwmcnr_t PWMCNR;            /*!< [0x14] PWM Counter Register */
} hw_pwm_t;
#pragma pack()

/*! @brief Macro to access all PWM registers. */
/*! @param x PWM module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_PWM_REGS(PWM1_BASE)</code>. */
#define HW_PWM_REGS(x) (*(hw_pwm_t *)(x))

/*
 * iMX7D PXP
 *
 * PXP v3.0 Register Reference Index
 *
 * Registers defined in this header file:
 * - HW_PXP_HW_PXP_CTRL - Control Register 0
 * - HW_PXP_HW_PXP_STAT - Status Register
 * - HW_PXP_HW_PXP_OUT_CTRL - Output Buffer Control Register
 * - HW_PXP_HW_PXP_OUT_BUF - Output Frame Buffer Pointer
 * - HW_PXP_HW_PXP_OUT_BUF2 - Output Frame Buffer Pointer #2
 * - HW_PXP_HW_PXP_OUT_PITCH - Output Buffer Pitch
 * - HW_PXP_HW_PXP_OUT_LRC - Output Surface Lower Right Coordinate
 * - HW_PXP_HW_PXP_OUT_PS_ULC - Processed Surface Upper Left Coordinate
 * - HW_PXP_HW_PXP_OUT_PS_LRC - Processed Surface Lower Right Coordinate
 * - HW_PXP_HW_PXP_OUT_AS_ULC - Alpha Surface Upper Left Coordinate
 * - HW_PXP_HW_PXP_OUT_AS_LRC - Alpha Surface Lower Right Coordinate
 * - HW_PXP_HW_PXP_PS_CTRL - Processed Surface (PS) Control Register
 * - HW_PXP_HW_PXP_PS_BUF - PS Input Buffer Address
 * - HW_PXP_HW_PXP_PS_UBUF - PS U/Cb or 2 Plane UV Input Buffer Address
 * - HW_PXP_HW_PXP_PS_VBUF - PS V/Cr Input Buffer Address
 * - HW_PXP_HW_PXP_PS_PITCH - Processed Surface Pitch
 * - HW_PXP_HW_PXP_PS_BACKGROUND_0 - PS Background Color
 * - HW_PXP_HW_PXP_PS_SCALE - PS Scale Factor Register
 * - HW_PXP_HW_PXP_PS_OFFSET - PS Scale Offset Register
 * - HW_PXP_HW_PXP_PS_CLRKEYLOW_0 - PS Color Key Low
 * - HW_PXP_HW_PXP_PS_CLRKEYHIGH_0 - PS Color Key High
 * - HW_PXP_HW_PXP_AS_CTRL - Alpha Surface Control
 * - HW_PXP_HW_PXP_AS_BUF - Alpha Surface Buffer Pointer
 * - HW_PXP_HW_PXP_AS_PITCH - Alpha Surface Pitch
 * - HW_PXP_HW_PXP_AS_CLRKEYLOW_0 - Overlay Color Key Low
 * - HW_PXP_HW_PXP_AS_CLRKEYHIGH_0 - Overlay Color Key High
 * - HW_PXP_HW_PXP_CSC1_COEF0 - Color Space Conversion Coefficient Register 0
 * - HW_PXP_HW_PXP_CSC1_COEF1 - Color Space Conversion Coefficient Register 1
 * - HW_PXP_HW_PXP_CSC1_COEF2 - Color Space Conversion Coefficient Register 2
 * - HW_PXP_HW_PXP_CSC2_CTRL - Color Space Conversion Control Register.
 * - HW_PXP_HW_PXP_CSC2_COEF0 - Color Space Conversion Coefficient Register 0
 * - HW_PXP_HW_PXP_CSC2_COEF1 - Color Space Conversion Coefficient Register 1
 * - HW_PXP_HW_PXP_CSC2_COEF2 - Color Space Conversion Coefficient Register 2
 * - HW_PXP_HW_PXP_CSC2_COEF3 - Color Space Conversion Coefficient Register 3
 * - HW_PXP_HW_PXP_CSC2_COEF4 - Color Space Conversion Coefficient Register 4
 * - HW_PXP_HW_PXP_CSC2_COEF5 - Color Space Conversion Coefficient Register 5
 * - HW_PXP_HW_PXP_LUT_CTRL - Lookup Table Control Register.
 * - HW_PXP_HW_PXP_LUT_ADDR - Lookup Table Control Register.
 * - HW_PXP_HW_PXP_LUT_DATA - Lookup Table Data Register.
 * - HW_PXP_HW_PXP_LUT_EXTMEM - Lookup Table External Memory Address Register.
 * - HW_PXP_HW_PXP_CFA - Color Filter Array Register.
 * - HW_PXP_HW_PXP_ALPHA_A_CTRL - PXP Alpha Engine A Control Register.
 * - HW_PXP_HW_PXP_ALPHA_B_CTRL - PXP Alpha Engine B Control Register.
 * - HW_PXP_HW_PXP_ALPHA_B_CTRL_1 -
 * - HW_PXP_HW_PXP_PS_BACKGROUND_1 - PS Background Color 1
 * - HW_PXP_HW_PXP_PS_CLRKEYLOW_1 - PS Color Key Low 1
 * - HW_PXP_HW_PXP_PS_CLRKEYHIGH_1 - PS Color Key High 1
 * - HW_PXP_HW_PXP_AS_CLRKEYLOW_1 - Overlay Color Key Low
 * - HW_PXP_HW_PXP_AS_CLRKEYHIGH_1 - Overlay Color Key High
 * - HW_PXP_HW_PXP_CTRL2 - Control Register 2
 * - HW_PXP_HW_PXP_POWER_REG0 - PXP Power Control Register.
 * - HW_PXP_HW_PXP_POWER_REG1 - PXP Power Control Register 1.
 * - HW_PXP_HW_PXP_DATA_PATH_CTRL1 -
 * - HW_PXP_HW_PXP_INIT_MEM_CTRL - Initialize memory buffer control Register
 * - HW_PXP_HW_PXP_INIT_MEM_DATA - Write data Register
 * - HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH - Write data Register
 * - HW_PXP_HW_PXP_IRQ_MASK - PXP IRQ Mask Register
 * - HW_PXP_HW_PXP_IRQ - PXP Interrupt Register
 * - HW_PXP_HW_PXP_NEXT - Next Frame Pointer
 * - HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0 - Pre-fetch engine Control Channel 0 Register
 * - HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1 - Pre-fetch engine Control Channel 1 Register
 * - HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH0 - Pre-fetch engine status Channel 0 Register
 * - HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH1 - Store engine status Channel 1 Register
 * - HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0 -
 * - HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0 -
 * - HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1 -
 * - HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1 -
 * - HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0 -
 * - HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1 -
 * - HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0 -
 * - HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1 -
 * - HW_PXP_HW_PXP_INPUT_FETCH_PITCH -
 * - HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0 -
 * - HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1 -
 * - HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0 -
 * - HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1 -
 * - HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0 -
 * - HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1 -
 * - HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0 -
 * - HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0 -
 * - HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1 -
 * - HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1 -
 * - HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0 - Store engine Control Channel 0 Register
 * - HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1 - Store engine Control Channel 1 Register
 * - HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH0 - Store engine status Channel 0 Register
 * - HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH1 - Store engine status Channel 1 Register
 * - HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1 -
 * - HW_PXP_HW_PXP_INPUT_STORE_PITCH -
 * - HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1 -
 * - HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1 -
 * - HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1 -
 * - HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0 -
 * - HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0 -
 * - HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0 - Pre-fetch engine Control Channel 0 Register
 * - HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1 - Pre-fetch engine Control Channel 1 Register
 * - HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH0 - Pre-fetch engine status Channel 0 Register
 * - HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH1 - Store engine status Channel 1 Register
 * - HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0 -
 * - HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0 -
 * - HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1 -
 * - HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1 -
 * - HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0 -
 * - HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1 -
 * - HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0 -
 * - HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1 -
 * - HW_PXP_HW_PXP_DITHER_FETCH_PITCH -
 * - HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0 -
 * - HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1 -
 * - HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0 -
 * - HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1 -
 * - HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0 -
 * - HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1 -
 * - HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0 -
 * - HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0 -
 * - HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1 -
 * - HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1 -
 * - HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0 - Store engine Control Channel 0 Register
 * - HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1 - Store engine Control Channel 1 Register
 * - HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH0 - Store engine status Channel 0 Register
 * - HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH1 - Store engine status Channel 1 Register
 * - HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1 -
 * - HW_PXP_HW_PXP_DITHER_STORE_PITCH -
 * - HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1 -
 * - HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1 -
 * - HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1 -
 * - HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0 -
 * - HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0 -
 * - HW_PXP_HW_PXP_DITHER_CTRL - Dither Control Register 0
 * - HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0 - Final stage lookup value Register
 * - HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1 - Final stage lookup value Register
 * - HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2 - Final stage lookup value Register
 * - HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3 - Final stage lookup value Register
 * - HW_PXP_HW_PXP_HIST_A_CTRL - Histogram Control Register.
 * - HW_PXP_HW_PXP_HIST_A_MASK - Histogram Pixel Mask Register.
 * - HW_PXP_HW_PXP_HIST_A_BUF_SIZE - Histogram Pixel Buffer Size Register.
 * - HW_PXP_HW_PXP_HIST_A_TOTAL_PIXEL - Total Number of Pixels Used by Histogram Engine.
 * - HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X - The X Coordinate Offset for Active Area.
 * - HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y - The Y Coordinate Offset for Active Area.
 * - HW_PXP_HW_PXP_HIST_A_RAW_STAT0 - Histogram Result Based on RAW Pixel Value.
 * - HW_PXP_HW_PXP_HIST_A_RAW_STAT1 - Histogram Result Based on RAW Pixel Value.
 * - HW_PXP_HW_PXP_HIST_B_CTRL - Histogram Control Register.
 * - HW_PXP_HW_PXP_HIST_B_MASK - Histogram Pixel Mask Register.
 * - HW_PXP_HW_PXP_HIST_B_BUF_SIZE - Histogram Pixel Buffer Size Register.
 * - HW_PXP_HW_PXP_HIST_B_TOTAL_PIXEL - Total Number of Pixels Used by Histogram Engine.
 * - HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X - The X Coordinate Offset for Active Area.
 * - HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y - The Y Coordinate Offset for Active Area.
 * - HW_PXP_HW_PXP_HIST_B_RAW_STAT0 - Histogram Result Based on RAW Pixel Value.
 * - HW_PXP_HW_PXP_HIST_B_RAW_STAT1 - Histogram Result Based on RAW Pixel Value.
 * - HW_PXP_HW_PXP_HIST2_PARAM - 2-level Histogram Parameter Register.
 * - HW_PXP_HW_PXP_HIST4_PARAM - 4-level Histogram Parameter Register.
 * - HW_PXP_HW_PXP_HIST8_PARAM0 - 8-level Histogram Parameter 0 Register.
 * - HW_PXP_HW_PXP_HIST8_PARAM1 - 8-level Histogram Parameter 1 Register.
 * - HW_PXP_HW_PXP_HIST16_PARAM0 - 16-level Histogram Parameter 0 Register.
 * - HW_PXP_HW_PXP_HIST16_PARAM1 - 16-level Histogram Parameter 1 Register.
 * - HW_PXP_HW_PXP_HIST16_PARAM2 - 16-level Histogram Parameter 2 Register.
 * - HW_PXP_HW_PXP_HIST16_PARAM3 - 16-level Histogram Parameter 3 Register.
 * - HW_PXP_HW_PXP_HIST32_PARAM0 - 32-level Histogram Parameter 0 Register.
 * - HW_PXP_HW_PXP_HIST32_PARAM1 - 32-level Histogram Parameter 1 Register.
 * - HW_PXP_HW_PXP_HIST32_PARAM2 - 32-level Histogram Parameter 2 Register.
 * - HW_PXP_HW_PXP_HIST32_PARAM3 - 32-level Histogram Parameter 3 Register.
 * - HW_PXP_HW_PXP_HIST32_PARAM4 - 32-level Histogram Parameter 0 Register.
 * - HW_PXP_HW_PXP_HIST32_PARAM5 - 32-level Histogram Parameter 1 Register.
 * - HW_PXP_HW_PXP_HIST32_PARAM6 - 32-level Histogram Parameter 2 Register.
 * - HW_PXP_HW_PXP_HIST32_PARAM7 - 32-level Histogram Parameter 3 Register.
 * - HW_PXP_HW_PXP_COMP_CTRL -
 * - HW_PXP_HW_PXP_COMP_FORMAT0 -
 * - HW_PXP_HW_PXP_COMP_FORMAT1 -
 * - HW_PXP_HW_PXP_COMP_FORMAT2 -
 * - HW_PXP_HW_PXP_COMP_MASK0 -
 * - HW_PXP_HW_PXP_COMP_MASK1 -
 * - HW_PXP_HW_PXP_COMP_BUFFER_SIZE -
 * - HW_PXP_HW_PXP_COMP_SOURCE -
 * - HW_PXP_HW_PXP_COMP_TARGET -
 * - HW_PXP_HW_PXP_COMP_BUFFER_A -
 * - HW_PXP_HW_PXP_COMP_BUFFER_B -
 * - HW_PXP_HW_PXP_COMP_BUFFER_C -
 * - HW_PXP_HW_PXP_COMP_BUFFER_D -
 * - HW_PXP_HW_PXP_COMP_DEBUG -
 * - HW_PXP_HW_PXP_BUS_MUX -
 * - HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0 -
 * - HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1 -
 * - HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0 -
 * - HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1 -
 * - HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH -
 * - HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE -
 *
 * - hw_pxp_t - Struct containing all module registers.
 */

#define HW_PXP_INSTANCE_COUNT (1U) /*!< Number of instances of the PXP module. */
#define HW_PXP (0U) /*!< Instance number for PXP. */
#define PXP_BASE              (0x30700000U) /*!< Base address for PXP. */
/*! Array initializer of PXP base addresses. */
#define PXP_BASE_ADDRS        { PXP_BASE }

/*******************************************************************************
 * HW_PXP_HW_PXP_CTRL - Control Register 0
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_CTRL - Control Register 0 (RW)
 *
 * Reset value: 0xC7008000U
 *
 * The CTRL register contains controls for the PXP module. HW_PXP_CTRL: 0x000
 * HW_PXP_CTRL_SET: 0x004 HW_PXP_CTRL_CLR: 0x008 HW_PXP_CTRL_TOG: 0x00C The Control
 * register contains the primary controls for the PXP block. EXAMPLE
 * REG_CTRL_SET(BM_PXP_CTRL_SFTRST); REG_CTRL_CLR(BM_PXP_CTRL_SFTRST | BM_PXP_CTRL_CLKGATE);
 */
typedef union _hw_pxp_hw_pxp_ctrl
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_ctrl_bitfields
    {
        uint32_t ENABLE : 1;           /*!< [0]  */
        uint32_t IRQ_ENABLE : 1;       /*!< [1]  */
        uint32_t NEXT_IRQ_ENABLE : 1;  /*!< [2]  */
        uint32_t LUT_DMA_IRQ_ENABLE : 1; /*!< [3]  */
        uint32_t ENABLE_LCD0_HANDSHAKE : 1; /*!< [4]  */
        uint32_t HANDSHAKE_ABORT_SKIP : 1; /*!< [5]  */
        uint32_t RSVD0 : 2;            /*!< [7:6]  */
        uint32_t ROTATE0 : 2;          /*!< [9:8]  */
        uint32_t HFLIP0 : 1;           /*!< [10]  */
        uint32_t VFLIP0 : 1;           /*!< [11]  */
        uint32_t ROTATE1 : 2;          /*!< [13:12]  */
        uint32_t HFLIP1 : 1;           /*!< [14]  */
        uint32_t VFLIP1 : 1;           /*!< [15]  */
        uint32_t ENABLE_PS_AS_OUT : 1; /*!< [16]  */
        uint32_t ENABLE_DITHER : 1;    /*!< [17]  */
        uint32_t ENABLE_WFE_A : 1;     /*!< [18]  */
        uint32_t ENABLE_WFE_B : 1;     /*!< [19]  */
        uint32_t ENABLE_INPUT_FETCH_STORE : 1; /*!< [20]  */
        uint32_t ENABLE_ALPHA_B : 1;   /*!< [21]  */
        uint32_t RSVD1 : 1;            /*!< [22]  */
        uint32_t BLOCK_SIZE : 1;       /*!< [23]  */
        uint32_t ENABLE_CSC2 : 1;      /*!< [24]  */
        uint32_t ENABLE_LUT : 1;       /*!< [25]  */
        uint32_t ENABLE_ROTATE0 : 1;   /*!< [26]  */
        uint32_t ENABLE_ROTATE1 : 1;   /*!< [27]  */
        uint32_t EN_REPEAT : 1;        /*!< [28]  */
        uint32_t RSVD4 : 1;            /*!< [29]  */
        uint32_t CLKGATE : 1;          /*!< [30]  */
        uint32_t SFTRST : 1;           /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_CTRL register
 */
/*@{*/
#define HW_PXP_HW_PXP_CTRL_ADDR(x) ((uintptr_t)(x) + 0x0U)

#define HW_PXP_HW_PXP_CTRL(x)    (*(__IO hw_pxp_hw_pxp_ctrl_t *) HW_PXP_HW_PXP_CTRL_ADDR(x))
#define HW_PXP_HW_PXP_CTRL_RD(x) (HW_PXP_HW_PXP_CTRL(x).U)
#define HW_PXP_HW_PXP_CTRL_WR(x, v) (HW_PXP_HW_PXP_CTRL(x).U = (v))
#define HW_PXP_HW_PXP_CTRL_SET(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, HW_PXP_HW_PXP_CTRL_RD(x) |  (v)))
#define HW_PXP_HW_PXP_CTRL_CLR(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, HW_PXP_HW_PXP_CTRL_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_CTRL_TOG(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, HW_PXP_HW_PXP_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_CTRL bitfields
 */

/*!
 * @name Register PXP_HW_PXP_CTRL, field ENABLE[0] (RW)
 *
 * Enables PXP operation with specified parameters. The ENABLE bit will remain
 * set while the PXP is active and will be cleared once the current operation
 * completes. Software should use the IRQ bit in the HW_PXP_STAT when polling for PXP
 * completion.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_ENABLE (0U)     /*!< Bit position for PXP_HW_PXP_CTRL_ENABLE. */
#define BM_PXP_HW_PXP_CTRL_ENABLE (0x00000001U) /*!< Bit mask for PXP_HW_PXP_CTRL_ENABLE. */
#define BS_PXP_HW_PXP_CTRL_ENABLE (1U)     /*!< Bit field size in bits for PXP_HW_PXP_CTRL_ENABLE. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_ENABLE field. */
#define BR_PXP_HW_PXP_CTRL_ENABLE(x) (HW_PXP_HW_PXP_CTRL(x).B.ENABLE)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_ENABLE. */
#define BF_PXP_HW_PXP_CTRL_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_ENABLE) & BM_PXP_HW_PXP_CTRL_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_PXP_HW_PXP_CTRL_ENABLE(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_ENABLE) | BF_PXP_HW_PXP_CTRL_ENABLE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field IRQ_ENABLE[1] (RW)
 *
 * Interrupt enable. NOTE: When using the HW_PXP_NEXT functionality to reprogram
 * the PXP, the new value of this bit will be used and may therefore enable or
 * disable an interrupt unintentionally.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_IRQ_ENABLE (1U) /*!< Bit position for PXP_HW_PXP_CTRL_IRQ_ENABLE. */
#define BM_PXP_HW_PXP_CTRL_IRQ_ENABLE (0x00000002U) /*!< Bit mask for PXP_HW_PXP_CTRL_IRQ_ENABLE. */
#define BS_PXP_HW_PXP_CTRL_IRQ_ENABLE (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL_IRQ_ENABLE. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_IRQ_ENABLE field. */
#define BR_PXP_HW_PXP_CTRL_IRQ_ENABLE(x) (HW_PXP_HW_PXP_CTRL(x).B.IRQ_ENABLE)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_IRQ_ENABLE. */
#define BF_PXP_HW_PXP_CTRL_IRQ_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_IRQ_ENABLE) & BM_PXP_HW_PXP_CTRL_IRQ_ENABLE)

/*! @brief Set the IRQ_ENABLE field to a new value. */
#define BW_PXP_HW_PXP_CTRL_IRQ_ENABLE(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_IRQ_ENABLE) | BF_PXP_HW_PXP_CTRL_IRQ_ENABLE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field NEXT_IRQ_ENABLE[2] (RW)
 *
 * Next command interrupt enable. When set, the PXP will issue an interrupt when
 * a queued command initiated by a write to the PXP_NEXT register has been
 * loaded into the PXP's registers. This interrupt also indicates that a new command
 * may now be queued.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_NEXT_IRQ_ENABLE (2U) /*!< Bit position for PXP_HW_PXP_CTRL_NEXT_IRQ_ENABLE. */
#define BM_PXP_HW_PXP_CTRL_NEXT_IRQ_ENABLE (0x00000004U) /*!< Bit mask for PXP_HW_PXP_CTRL_NEXT_IRQ_ENABLE. */
#define BS_PXP_HW_PXP_CTRL_NEXT_IRQ_ENABLE (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL_NEXT_IRQ_ENABLE. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_NEXT_IRQ_ENABLE field. */
#define BR_PXP_HW_PXP_CTRL_NEXT_IRQ_ENABLE(x) (HW_PXP_HW_PXP_CTRL(x).B.NEXT_IRQ_ENABLE)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_NEXT_IRQ_ENABLE. */
#define BF_PXP_HW_PXP_CTRL_NEXT_IRQ_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_NEXT_IRQ_ENABLE) & BM_PXP_HW_PXP_CTRL_NEXT_IRQ_ENABLE)

/*! @brief Set the NEXT_IRQ_ENABLE field to a new value. */
#define BW_PXP_HW_PXP_CTRL_NEXT_IRQ_ENABLE(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_NEXT_IRQ_ENABLE) | BF_PXP_HW_PXP_CTRL_NEXT_IRQ_ENABLE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field LUT_DMA_IRQ_ENABLE[3] (RW)
 *
 * LUT DMA interrupt enable. When set, the PXP will issue an interrupt when the
 * LUT DMA has finished transferring data.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_LUT_DMA_IRQ_ENABLE (3U) /*!< Bit position for PXP_HW_PXP_CTRL_LUT_DMA_IRQ_ENABLE. */
#define BM_PXP_HW_PXP_CTRL_LUT_DMA_IRQ_ENABLE (0x00000008U) /*!< Bit mask for PXP_HW_PXP_CTRL_LUT_DMA_IRQ_ENABLE. */
#define BS_PXP_HW_PXP_CTRL_LUT_DMA_IRQ_ENABLE (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL_LUT_DMA_IRQ_ENABLE. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_LUT_DMA_IRQ_ENABLE field. */
#define BR_PXP_HW_PXP_CTRL_LUT_DMA_IRQ_ENABLE(x) (HW_PXP_HW_PXP_CTRL(x).B.LUT_DMA_IRQ_ENABLE)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_LUT_DMA_IRQ_ENABLE. */
#define BF_PXP_HW_PXP_CTRL_LUT_DMA_IRQ_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_LUT_DMA_IRQ_ENABLE) & BM_PXP_HW_PXP_CTRL_LUT_DMA_IRQ_ENABLE)

/*! @brief Set the LUT_DMA_IRQ_ENABLE field to a new value. */
#define BW_PXP_HW_PXP_CTRL_LUT_DMA_IRQ_ENABLE(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_LUT_DMA_IRQ_ENABLE) | BF_PXP_HW_PXP_CTRL_LUT_DMA_IRQ_ENABLE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field ENABLE_LCD0_HANDSHAKE[4] (RW)
 *
 * Enable handshake with LCD0 controller. When this is set, the PXP will not
 * process an entire framebuffer, but will instead process rows of NxN blocks in a
 * double-buffer handshake with the LCDIF. This enables the use of the onboard
 * SRAM for a partial frame buffer.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_ENABLE_LCD0_HANDSHAKE (4U) /*!< Bit position for PXP_HW_PXP_CTRL_ENABLE_LCD0_HANDSHAKE. */
#define BM_PXP_HW_PXP_CTRL_ENABLE_LCD0_HANDSHAKE (0x00000010U) /*!< Bit mask for PXP_HW_PXP_CTRL_ENABLE_LCD0_HANDSHAKE. */
#define BS_PXP_HW_PXP_CTRL_ENABLE_LCD0_HANDSHAKE (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL_ENABLE_LCD0_HANDSHAKE. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_ENABLE_LCD0_HANDSHAKE field. */
#define BR_PXP_HW_PXP_CTRL_ENABLE_LCD0_HANDSHAKE(x) (HW_PXP_HW_PXP_CTRL(x).B.ENABLE_LCD0_HANDSHAKE)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_ENABLE_LCD0_HANDSHAKE. */
#define BF_PXP_HW_PXP_CTRL_ENABLE_LCD0_HANDSHAKE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_ENABLE_LCD0_HANDSHAKE) & BM_PXP_HW_PXP_CTRL_ENABLE_LCD0_HANDSHAKE)

/*! @brief Set the ENABLE_LCD0_HANDSHAKE field to a new value. */
#define BW_PXP_HW_PXP_CTRL_ENABLE_LCD0_HANDSHAKE(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_ENABLE_LCD0_HANDSHAKE) | BF_PXP_HW_PXP_CTRL_ENABLE_LCD0_HANDSHAKE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field HANDSHAKE_ABORT_SKIP[5] (RW)
 *
 * When skip is enable, even the abort asserted, pxp will not assert the ready
 * directly but wait for whole block line complete.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_HANDSHAKE_ABORT_SKIP (5U) /*!< Bit position for PXP_HW_PXP_CTRL_HANDSHAKE_ABORT_SKIP. */
#define BM_PXP_HW_PXP_CTRL_HANDSHAKE_ABORT_SKIP (0x00000020U) /*!< Bit mask for PXP_HW_PXP_CTRL_HANDSHAKE_ABORT_SKIP. */
#define BS_PXP_HW_PXP_CTRL_HANDSHAKE_ABORT_SKIP (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL_HANDSHAKE_ABORT_SKIP. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_HANDSHAKE_ABORT_SKIP field. */
#define BR_PXP_HW_PXP_CTRL_HANDSHAKE_ABORT_SKIP(x) (HW_PXP_HW_PXP_CTRL(x).B.HANDSHAKE_ABORT_SKIP)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_HANDSHAKE_ABORT_SKIP. */
#define BF_PXP_HW_PXP_CTRL_HANDSHAKE_ABORT_SKIP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_HANDSHAKE_ABORT_SKIP) & BM_PXP_HW_PXP_CTRL_HANDSHAKE_ABORT_SKIP)

/*! @brief Set the HANDSHAKE_ABORT_SKIP field to a new value. */
#define BW_PXP_HW_PXP_CTRL_HANDSHAKE_ABORT_SKIP(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_HANDSHAKE_ABORT_SKIP) | BF_PXP_HW_PXP_CTRL_HANDSHAKE_ABORT_SKIP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field RSVD0[7:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_RSVD0 (6U)      /*!< Bit position for PXP_HW_PXP_CTRL_RSVD0. */
#define BM_PXP_HW_PXP_CTRL_RSVD0 (0x000000C0U) /*!< Bit mask for PXP_HW_PXP_CTRL_RSVD0. */
#define BS_PXP_HW_PXP_CTRL_RSVD0 (2U)      /*!< Bit field size in bits for PXP_HW_PXP_CTRL_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_RSVD0 field. */
#define BR_PXP_HW_PXP_CTRL_RSVD0(x) (HW_PXP_HW_PXP_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field ROTATE0[9:8] (RW)
 *
 * Indicates the clockwise rotation to be applied at the output buffer. The
 * rotation effect is defined as occurring after the FLIP_X and FLIP_Y permutation.
 *
 * Values:
 * - 0 -
 * - 1 -
 * - 10 -
 * - 11 -
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_ROTATE0 (8U)    /*!< Bit position for PXP_HW_PXP_CTRL_ROTATE0. */
#define BM_PXP_HW_PXP_CTRL_ROTATE0 (0x00000300U) /*!< Bit mask for PXP_HW_PXP_CTRL_ROTATE0. */
#define BS_PXP_HW_PXP_CTRL_ROTATE0 (2U)    /*!< Bit field size in bits for PXP_HW_PXP_CTRL_ROTATE0. */

#define BV_PXP_HW_PXP_CTRL_ROTATE0_ROT_0 (0U)        /*!< Bit field value for PXP_HW_PXP_CTRL_ROTATE0:  */
#define BV_PXP_HW_PXP_CTRL_ROTATE0_ROT_90 (0x1U)     /*!< Bit field value for PXP_HW_PXP_CTRL_ROTATE0:  */
#define BV_PXP_HW_PXP_CTRL_ROTATE0_ROT_180 (0x2U)    /*!< Bit field value for PXP_HW_PXP_CTRL_ROTATE0:  */
#define BV_PXP_HW_PXP_CTRL_ROTATE0_ROT_270 (0x3U)    /*!< Bit field value for PXP_HW_PXP_CTRL_ROTATE0:  */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_ROTATE0 field. */
#define BR_PXP_HW_PXP_CTRL_ROTATE0(x) (HW_PXP_HW_PXP_CTRL(x).B.ROTATE0)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_ROTATE0. */
#define BF_PXP_HW_PXP_CTRL_ROTATE0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_ROTATE0) & BM_PXP_HW_PXP_CTRL_ROTATE0)

/*! @brief Set the ROTATE0 field to a new value. */
#define BW_PXP_HW_PXP_CTRL_ROTATE0(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_ROTATE0) | BF_PXP_HW_PXP_CTRL_ROTATE0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field HFLIP0[10] (RW)
 *
 * Indicates that the output buffer should be flipped horizontally (effect
 * applied before rotation).
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_HFLIP0 (10U)    /*!< Bit position for PXP_HW_PXP_CTRL_HFLIP0. */
#define BM_PXP_HW_PXP_CTRL_HFLIP0 (0x00000400U) /*!< Bit mask for PXP_HW_PXP_CTRL_HFLIP0. */
#define BS_PXP_HW_PXP_CTRL_HFLIP0 (1U)     /*!< Bit field size in bits for PXP_HW_PXP_CTRL_HFLIP0. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_HFLIP0 field. */
#define BR_PXP_HW_PXP_CTRL_HFLIP0(x) (HW_PXP_HW_PXP_CTRL(x).B.HFLIP0)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_HFLIP0. */
#define BF_PXP_HW_PXP_CTRL_HFLIP0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_HFLIP0) & BM_PXP_HW_PXP_CTRL_HFLIP0)

/*! @brief Set the HFLIP0 field to a new value. */
#define BW_PXP_HW_PXP_CTRL_HFLIP0(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_HFLIP0) | BF_PXP_HW_PXP_CTRL_HFLIP0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field VFLIP0[11] (RW)
 *
 * Indicates that the output buffer should be flipped vertically (effect applied
 * before rotation).
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_VFLIP0 (11U)    /*!< Bit position for PXP_HW_PXP_CTRL_VFLIP0. */
#define BM_PXP_HW_PXP_CTRL_VFLIP0 (0x00000800U) /*!< Bit mask for PXP_HW_PXP_CTRL_VFLIP0. */
#define BS_PXP_HW_PXP_CTRL_VFLIP0 (1U)     /*!< Bit field size in bits for PXP_HW_PXP_CTRL_VFLIP0. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_VFLIP0 field. */
#define BR_PXP_HW_PXP_CTRL_VFLIP0(x) (HW_PXP_HW_PXP_CTRL(x).B.VFLIP0)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_VFLIP0. */
#define BF_PXP_HW_PXP_CTRL_VFLIP0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_VFLIP0) & BM_PXP_HW_PXP_CTRL_VFLIP0)

/*! @brief Set the VFLIP0 field to a new value. */
#define BW_PXP_HW_PXP_CTRL_VFLIP0(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_VFLIP0) | BF_PXP_HW_PXP_CTRL_VFLIP0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field ROTATE1[13:12] (RW)
 *
 * Indicates the clockwise rotation to be applied at the input buffer. The
 * rotation effect is defined as occurring after the FLIP_X and FLIP_Y permutation.
 *
 * Values:
 * - 0 -
 * - 1 -
 * - 10 -
 * - 11 -
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_ROTATE1 (12U)   /*!< Bit position for PXP_HW_PXP_CTRL_ROTATE1. */
#define BM_PXP_HW_PXP_CTRL_ROTATE1 (0x00003000U) /*!< Bit mask for PXP_HW_PXP_CTRL_ROTATE1. */
#define BS_PXP_HW_PXP_CTRL_ROTATE1 (2U)    /*!< Bit field size in bits for PXP_HW_PXP_CTRL_ROTATE1. */

#define BV_PXP_HW_PXP_CTRL_ROTATE1_ROT_0 (0U)        /*!< Bit field value for PXP_HW_PXP_CTRL_ROTATE1:  */
#define BV_PXP_HW_PXP_CTRL_ROTATE1_ROT_90 (0x1U)     /*!< Bit field value for PXP_HW_PXP_CTRL_ROTATE1:  */
#define BV_PXP_HW_PXP_CTRL_ROTATE1_ROT_180 (0x2U)    /*!< Bit field value for PXP_HW_PXP_CTRL_ROTATE1:  */
#define BV_PXP_HW_PXP_CTRL_ROTATE1_ROT_270 (0x3U)    /*!< Bit field value for PXP_HW_PXP_CTRL_ROTATE1:  */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_ROTATE1 field. */
#define BR_PXP_HW_PXP_CTRL_ROTATE1(x) (HW_PXP_HW_PXP_CTRL(x).B.ROTATE1)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_ROTATE1. */
#define BF_PXP_HW_PXP_CTRL_ROTATE1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_ROTATE1) & BM_PXP_HW_PXP_CTRL_ROTATE1)

/*! @brief Set the ROTATE1 field to a new value. */
#define BW_PXP_HW_PXP_CTRL_ROTATE1(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_ROTATE1) | BF_PXP_HW_PXP_CTRL_ROTATE1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field HFLIP1[14] (RW)
 *
 * Indicates that the input should be flipped horizontally (effect applied
 * before rotation).
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_HFLIP1 (14U)    /*!< Bit position for PXP_HW_PXP_CTRL_HFLIP1. */
#define BM_PXP_HW_PXP_CTRL_HFLIP1 (0x00004000U) /*!< Bit mask for PXP_HW_PXP_CTRL_HFLIP1. */
#define BS_PXP_HW_PXP_CTRL_HFLIP1 (1U)     /*!< Bit field size in bits for PXP_HW_PXP_CTRL_HFLIP1. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_HFLIP1 field. */
#define BR_PXP_HW_PXP_CTRL_HFLIP1(x) (HW_PXP_HW_PXP_CTRL(x).B.HFLIP1)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_HFLIP1. */
#define BF_PXP_HW_PXP_CTRL_HFLIP1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_HFLIP1) & BM_PXP_HW_PXP_CTRL_HFLIP1)

/*! @brief Set the HFLIP1 field to a new value. */
#define BW_PXP_HW_PXP_CTRL_HFLIP1(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_HFLIP1) | BF_PXP_HW_PXP_CTRL_HFLIP1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field VFLIP1[15] (RW)
 *
 * Indicates that the input should be flipped vertically (effect applied before
 * rotation).
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_VFLIP1 (15U)    /*!< Bit position for PXP_HW_PXP_CTRL_VFLIP1. */
#define BM_PXP_HW_PXP_CTRL_VFLIP1 (0x00008000U) /*!< Bit mask for PXP_HW_PXP_CTRL_VFLIP1. */
#define BS_PXP_HW_PXP_CTRL_VFLIP1 (1U)     /*!< Bit field size in bits for PXP_HW_PXP_CTRL_VFLIP1. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_VFLIP1 field. */
#define BR_PXP_HW_PXP_CTRL_VFLIP1(x) (HW_PXP_HW_PXP_CTRL(x).B.VFLIP1)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_VFLIP1. */
#define BF_PXP_HW_PXP_CTRL_VFLIP1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_VFLIP1) & BM_PXP_HW_PXP_CTRL_VFLIP1)

/*! @brief Set the VFLIP1 field to a new value. */
#define BW_PXP_HW_PXP_CTRL_VFLIP1(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_VFLIP1) | BF_PXP_HW_PXP_CTRL_VFLIP1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field ENABLE_PS_AS_OUT[16] (RW)
 *
 * Enable the PS engine, AS engine, OUTBUF in the PXP primary processing flow.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_ENABLE_PS_AS_OUT (16U) /*!< Bit position for PXP_HW_PXP_CTRL_ENABLE_PS_AS_OUT. */
#define BM_PXP_HW_PXP_CTRL_ENABLE_PS_AS_OUT (0x00010000U) /*!< Bit mask for PXP_HW_PXP_CTRL_ENABLE_PS_AS_OUT. */
#define BS_PXP_HW_PXP_CTRL_ENABLE_PS_AS_OUT (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL_ENABLE_PS_AS_OUT. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_ENABLE_PS_AS_OUT field. */
#define BR_PXP_HW_PXP_CTRL_ENABLE_PS_AS_OUT(x) (HW_PXP_HW_PXP_CTRL(x).B.ENABLE_PS_AS_OUT)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_ENABLE_PS_AS_OUT. */
#define BF_PXP_HW_PXP_CTRL_ENABLE_PS_AS_OUT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_ENABLE_PS_AS_OUT) & BM_PXP_HW_PXP_CTRL_ENABLE_PS_AS_OUT)

/*! @brief Set the ENABLE_PS_AS_OUT field to a new value. */
#define BW_PXP_HW_PXP_CTRL_ENABLE_PS_AS_OUT(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_ENABLE_PS_AS_OUT) | BF_PXP_HW_PXP_CTRL_ENABLE_PS_AS_OUT(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field ENABLE_DITHER[17] (RW)
 *
 * Enable the Dithering engine in the PXP primary processing flow.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_ENABLE_DITHER (17U) /*!< Bit position for PXP_HW_PXP_CTRL_ENABLE_DITHER. */
#define BM_PXP_HW_PXP_CTRL_ENABLE_DITHER (0x00020000U) /*!< Bit mask for PXP_HW_PXP_CTRL_ENABLE_DITHER. */
#define BS_PXP_HW_PXP_CTRL_ENABLE_DITHER (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL_ENABLE_DITHER. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_ENABLE_DITHER field. */
#define BR_PXP_HW_PXP_CTRL_ENABLE_DITHER(x) (HW_PXP_HW_PXP_CTRL(x).B.ENABLE_DITHER)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_ENABLE_DITHER. */
#define BF_PXP_HW_PXP_CTRL_ENABLE_DITHER(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_ENABLE_DITHER) & BM_PXP_HW_PXP_CTRL_ENABLE_DITHER)

/*! @brief Set the ENABLE_DITHER field to a new value. */
#define BW_PXP_HW_PXP_CTRL_ENABLE_DITHER(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_ENABLE_DITHER) | BF_PXP_HW_PXP_CTRL_ENABLE_DITHER(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field ENABLE_WFE_A[18] (RW)
 *
 * Enable the WFE-A engine in the PXP primary processing flow.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_ENABLE_WFE_A (18U) /*!< Bit position for PXP_HW_PXP_CTRL_ENABLE_WFE_A. */
#define BM_PXP_HW_PXP_CTRL_ENABLE_WFE_A (0x00040000U) /*!< Bit mask for PXP_HW_PXP_CTRL_ENABLE_WFE_A. */
#define BS_PXP_HW_PXP_CTRL_ENABLE_WFE_A (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL_ENABLE_WFE_A. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_ENABLE_WFE_A field. */
#define BR_PXP_HW_PXP_CTRL_ENABLE_WFE_A(x) (HW_PXP_HW_PXP_CTRL(x).B.ENABLE_WFE_A)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_ENABLE_WFE_A. */
#define BF_PXP_HW_PXP_CTRL_ENABLE_WFE_A(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_ENABLE_WFE_A) & BM_PXP_HW_PXP_CTRL_ENABLE_WFE_A)

/*! @brief Set the ENABLE_WFE_A field to a new value. */
#define BW_PXP_HW_PXP_CTRL_ENABLE_WFE_A(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_ENABLE_WFE_A) | BF_PXP_HW_PXP_CTRL_ENABLE_WFE_A(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field ENABLE_WFE_B[19] (RW)
 *
 * Enable the WFE-B engine in the PXP primary processing flow.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_ENABLE_WFE_B (19U) /*!< Bit position for PXP_HW_PXP_CTRL_ENABLE_WFE_B. */
#define BM_PXP_HW_PXP_CTRL_ENABLE_WFE_B (0x00080000U) /*!< Bit mask for PXP_HW_PXP_CTRL_ENABLE_WFE_B. */
#define BS_PXP_HW_PXP_CTRL_ENABLE_WFE_B (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL_ENABLE_WFE_B. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_ENABLE_WFE_B field. */
#define BR_PXP_HW_PXP_CTRL_ENABLE_WFE_B(x) (HW_PXP_HW_PXP_CTRL(x).B.ENABLE_WFE_B)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_ENABLE_WFE_B. */
#define BF_PXP_HW_PXP_CTRL_ENABLE_WFE_B(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_ENABLE_WFE_B) & BM_PXP_HW_PXP_CTRL_ENABLE_WFE_B)

/*! @brief Set the ENABLE_WFE_B field to a new value. */
#define BW_PXP_HW_PXP_CTRL_ENABLE_WFE_B(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_ENABLE_WFE_B) | BF_PXP_HW_PXP_CTRL_ENABLE_WFE_B(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field ENABLE_INPUT_FETCH_STORE[20] (RW)
 *
 * Enable the Input Fetch and Store engine in the PXP primary processing flow.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_ENABLE_INPUT_FETCH_STORE (20U) /*!< Bit position for PXP_HW_PXP_CTRL_ENABLE_INPUT_FETCH_STORE. */
#define BM_PXP_HW_PXP_CTRL_ENABLE_INPUT_FETCH_STORE (0x00100000U) /*!< Bit mask for PXP_HW_PXP_CTRL_ENABLE_INPUT_FETCH_STORE. */
#define BS_PXP_HW_PXP_CTRL_ENABLE_INPUT_FETCH_STORE (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL_ENABLE_INPUT_FETCH_STORE. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_ENABLE_INPUT_FETCH_STORE field. */
#define BR_PXP_HW_PXP_CTRL_ENABLE_INPUT_FETCH_STORE(x) (HW_PXP_HW_PXP_CTRL(x).B.ENABLE_INPUT_FETCH_STORE)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_ENABLE_INPUT_FETCH_STORE. */
#define BF_PXP_HW_PXP_CTRL_ENABLE_INPUT_FETCH_STORE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_ENABLE_INPUT_FETCH_STORE) & BM_PXP_HW_PXP_CTRL_ENABLE_INPUT_FETCH_STORE)

/*! @brief Set the ENABLE_INPUT_FETCH_STORE field to a new value. */
#define BW_PXP_HW_PXP_CTRL_ENABLE_INPUT_FETCH_STORE(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_ENABLE_INPUT_FETCH_STORE) | BF_PXP_HW_PXP_CTRL_ENABLE_INPUT_FETCH_STORE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field ENABLE_ALPHA_B[21] (RW)
 *
 * Enable the Alpha-B engine in the PXP primary processing flow.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_ENABLE_ALPHA_B (21U) /*!< Bit position for PXP_HW_PXP_CTRL_ENABLE_ALPHA_B. */
#define BM_PXP_HW_PXP_CTRL_ENABLE_ALPHA_B (0x00200000U) /*!< Bit mask for PXP_HW_PXP_CTRL_ENABLE_ALPHA_B. */
#define BS_PXP_HW_PXP_CTRL_ENABLE_ALPHA_B (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL_ENABLE_ALPHA_B. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_ENABLE_ALPHA_B field. */
#define BR_PXP_HW_PXP_CTRL_ENABLE_ALPHA_B(x) (HW_PXP_HW_PXP_CTRL(x).B.ENABLE_ALPHA_B)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_ENABLE_ALPHA_B. */
#define BF_PXP_HW_PXP_CTRL_ENABLE_ALPHA_B(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_ENABLE_ALPHA_B) & BM_PXP_HW_PXP_CTRL_ENABLE_ALPHA_B)

/*! @brief Set the ENABLE_ALPHA_B field to a new value. */
#define BW_PXP_HW_PXP_CTRL_ENABLE_ALPHA_B(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_ENABLE_ALPHA_B) | BF_PXP_HW_PXP_CTRL_ENABLE_ALPHA_B(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field RSVD1[22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_RSVD1 (22U)     /*!< Bit position for PXP_HW_PXP_CTRL_RSVD1. */
#define BM_PXP_HW_PXP_CTRL_RSVD1 (0x00400000U) /*!< Bit mask for PXP_HW_PXP_CTRL_RSVD1. */
#define BS_PXP_HW_PXP_CTRL_RSVD1 (1U)      /*!< Bit field size in bits for PXP_HW_PXP_CTRL_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_RSVD1 field. */
#define BR_PXP_HW_PXP_CTRL_RSVD1(x) (HW_PXP_HW_PXP_CTRL(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field BLOCK_SIZE[23] (RW)
 *
 * Select the block size to process through the Rotate block.
 *
 * Values:
 * - 0 - Process 8x8 pixel blocks.
 * - 1 - Process 16x16 pixel blocks.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_BLOCK_SIZE (23U) /*!< Bit position for PXP_HW_PXP_CTRL_BLOCK_SIZE. */
#define BM_PXP_HW_PXP_CTRL_BLOCK_SIZE (0x00800000U) /*!< Bit mask for PXP_HW_PXP_CTRL_BLOCK_SIZE. */
#define BS_PXP_HW_PXP_CTRL_BLOCK_SIZE (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL_BLOCK_SIZE. */

#define BV_PXP_HW_PXP_CTRL_BLOCK_SIZE_8X8 (0U)       /*!< Bit field value for PXP_HW_PXP_CTRL_BLOCK_SIZE: Process 8x8 pixel blocks. */
#define BV_PXP_HW_PXP_CTRL_BLOCK_SIZE_16X16 (0x1U)   /*!< Bit field value for PXP_HW_PXP_CTRL_BLOCK_SIZE: Process 16x16 pixel blocks. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_BLOCK_SIZE field. */
#define BR_PXP_HW_PXP_CTRL_BLOCK_SIZE(x) (HW_PXP_HW_PXP_CTRL(x).B.BLOCK_SIZE)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_BLOCK_SIZE. */
#define BF_PXP_HW_PXP_CTRL_BLOCK_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_BLOCK_SIZE) & BM_PXP_HW_PXP_CTRL_BLOCK_SIZE)

/*! @brief Set the BLOCK_SIZE field to a new value. */
#define BW_PXP_HW_PXP_CTRL_BLOCK_SIZE(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_BLOCK_SIZE) | BF_PXP_HW_PXP_CTRL_BLOCK_SIZE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field ENABLE_CSC2[24] (RW)
 *
 * Enable the CSC2 engine in the PXP primary processing flow.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_ENABLE_CSC2 (24U) /*!< Bit position for PXP_HW_PXP_CTRL_ENABLE_CSC2. */
#define BM_PXP_HW_PXP_CTRL_ENABLE_CSC2 (0x01000000U) /*!< Bit mask for PXP_HW_PXP_CTRL_ENABLE_CSC2. */
#define BS_PXP_HW_PXP_CTRL_ENABLE_CSC2 (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL_ENABLE_CSC2. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_ENABLE_CSC2 field. */
#define BR_PXP_HW_PXP_CTRL_ENABLE_CSC2(x) (HW_PXP_HW_PXP_CTRL(x).B.ENABLE_CSC2)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_ENABLE_CSC2. */
#define BF_PXP_HW_PXP_CTRL_ENABLE_CSC2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_ENABLE_CSC2) & BM_PXP_HW_PXP_CTRL_ENABLE_CSC2)

/*! @brief Set the ENABLE_CSC2 field to a new value. */
#define BW_PXP_HW_PXP_CTRL_ENABLE_CSC2(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_ENABLE_CSC2) | BF_PXP_HW_PXP_CTRL_ENABLE_CSC2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field ENABLE_LUT[25] (RW)
 *
 * Enable the LUT engine in the PXP primary processing flow.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_ENABLE_LUT (25U) /*!< Bit position for PXP_HW_PXP_CTRL_ENABLE_LUT. */
#define BM_PXP_HW_PXP_CTRL_ENABLE_LUT (0x02000000U) /*!< Bit mask for PXP_HW_PXP_CTRL_ENABLE_LUT. */
#define BS_PXP_HW_PXP_CTRL_ENABLE_LUT (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL_ENABLE_LUT. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_ENABLE_LUT field. */
#define BR_PXP_HW_PXP_CTRL_ENABLE_LUT(x) (HW_PXP_HW_PXP_CTRL(x).B.ENABLE_LUT)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_ENABLE_LUT. */
#define BF_PXP_HW_PXP_CTRL_ENABLE_LUT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_ENABLE_LUT) & BM_PXP_HW_PXP_CTRL_ENABLE_LUT)

/*! @brief Set the ENABLE_LUT field to a new value. */
#define BW_PXP_HW_PXP_CTRL_ENABLE_LUT(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_ENABLE_LUT) | BF_PXP_HW_PXP_CTRL_ENABLE_LUT(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field ENABLE_ROTATE0[26] (RW)
 *
 * Enable the ROTATE0 engine in the PXP primary processing flow.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_ENABLE_ROTATE0 (26U) /*!< Bit position for PXP_HW_PXP_CTRL_ENABLE_ROTATE0. */
#define BM_PXP_HW_PXP_CTRL_ENABLE_ROTATE0 (0x04000000U) /*!< Bit mask for PXP_HW_PXP_CTRL_ENABLE_ROTATE0. */
#define BS_PXP_HW_PXP_CTRL_ENABLE_ROTATE0 (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL_ENABLE_ROTATE0. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_ENABLE_ROTATE0 field. */
#define BR_PXP_HW_PXP_CTRL_ENABLE_ROTATE0(x) (HW_PXP_HW_PXP_CTRL(x).B.ENABLE_ROTATE0)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_ENABLE_ROTATE0. */
#define BF_PXP_HW_PXP_CTRL_ENABLE_ROTATE0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_ENABLE_ROTATE0) & BM_PXP_HW_PXP_CTRL_ENABLE_ROTATE0)

/*! @brief Set the ENABLE_ROTATE0 field to a new value. */
#define BW_PXP_HW_PXP_CTRL_ENABLE_ROTATE0(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_ENABLE_ROTATE0) | BF_PXP_HW_PXP_CTRL_ENABLE_ROTATE0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field ENABLE_ROTATE1[27] (RW)
 *
 * Enable the ROTATE1 engine in the PXP primary processing flow.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_ENABLE_ROTATE1 (27U) /*!< Bit position for PXP_HW_PXP_CTRL_ENABLE_ROTATE1. */
#define BM_PXP_HW_PXP_CTRL_ENABLE_ROTATE1 (0x08000000U) /*!< Bit mask for PXP_HW_PXP_CTRL_ENABLE_ROTATE1. */
#define BS_PXP_HW_PXP_CTRL_ENABLE_ROTATE1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL_ENABLE_ROTATE1. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_ENABLE_ROTATE1 field. */
#define BR_PXP_HW_PXP_CTRL_ENABLE_ROTATE1(x) (HW_PXP_HW_PXP_CTRL(x).B.ENABLE_ROTATE1)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_ENABLE_ROTATE1. */
#define BF_PXP_HW_PXP_CTRL_ENABLE_ROTATE1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_ENABLE_ROTATE1) & BM_PXP_HW_PXP_CTRL_ENABLE_ROTATE1)

/*! @brief Set the ENABLE_ROTATE1 field to a new value. */
#define BW_PXP_HW_PXP_CTRL_ENABLE_ROTATE1(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_ENABLE_ROTATE1) | BF_PXP_HW_PXP_CTRL_ENABLE_ROTATE1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field EN_REPEAT[28] (RW)
 *
 * Enable the PXP to run continuously. When this bit is set, the PXP will repeat
 * based on the current configuration register settings. If this bit is not set,
 * the PXP will complete the process and enter the idle state ready to accept
 * the next frame to be processed. This bit should be set when the LCDIF handshake
 * mode is enabled so that the next frame is automatically generated for the next
 * screen refresh cycle. If it not set and the handshake mode is enabled, the
 * CPU will have to initiate the PXP for the next refresh cycle. When the PXP NEXT
 * feature is used, it has priority over the REPEAT mode, in that the new
 * register settings are fetched first, and then the next PXP operation will continue.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_EN_REPEAT (28U) /*!< Bit position for PXP_HW_PXP_CTRL_EN_REPEAT. */
#define BM_PXP_HW_PXP_CTRL_EN_REPEAT (0x10000000U) /*!< Bit mask for PXP_HW_PXP_CTRL_EN_REPEAT. */
#define BS_PXP_HW_PXP_CTRL_EN_REPEAT (1U)  /*!< Bit field size in bits for PXP_HW_PXP_CTRL_EN_REPEAT. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_EN_REPEAT field. */
#define BR_PXP_HW_PXP_CTRL_EN_REPEAT(x) (HW_PXP_HW_PXP_CTRL(x).B.EN_REPEAT)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_EN_REPEAT. */
#define BF_PXP_HW_PXP_CTRL_EN_REPEAT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_EN_REPEAT) & BM_PXP_HW_PXP_CTRL_EN_REPEAT)

/*! @brief Set the EN_REPEAT field to a new value. */
#define BW_PXP_HW_PXP_CTRL_EN_REPEAT(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_EN_REPEAT) | BF_PXP_HW_PXP_CTRL_EN_REPEAT(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field RSVD4[29] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_RSVD4 (29U)     /*!< Bit position for PXP_HW_PXP_CTRL_RSVD4. */
#define BM_PXP_HW_PXP_CTRL_RSVD4 (0x20000000U) /*!< Bit mask for PXP_HW_PXP_CTRL_RSVD4. */
#define BS_PXP_HW_PXP_CTRL_RSVD4 (1U)      /*!< Bit field size in bits for PXP_HW_PXP_CTRL_RSVD4. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_RSVD4 field. */
#define BR_PXP_HW_PXP_CTRL_RSVD4(x) (HW_PXP_HW_PXP_CTRL(x).B.RSVD4)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field CLKGATE[30] (RW)
 *
 * This bit must be set to zero for normal operation. When set to one it gates
 * off the clocks to the block.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_CLKGATE (30U)   /*!< Bit position for PXP_HW_PXP_CTRL_CLKGATE. */
#define BM_PXP_HW_PXP_CTRL_CLKGATE (0x40000000U) /*!< Bit mask for PXP_HW_PXP_CTRL_CLKGATE. */
#define BS_PXP_HW_PXP_CTRL_CLKGATE (1U)    /*!< Bit field size in bits for PXP_HW_PXP_CTRL_CLKGATE. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_CLKGATE field. */
#define BR_PXP_HW_PXP_CTRL_CLKGATE(x) (HW_PXP_HW_PXP_CTRL(x).B.CLKGATE)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_CLKGATE. */
#define BF_PXP_HW_PXP_CTRL_CLKGATE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_CLKGATE) & BM_PXP_HW_PXP_CTRL_CLKGATE)

/*! @brief Set the CLKGATE field to a new value. */
#define BW_PXP_HW_PXP_CTRL_CLKGATE(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_CLKGATE) | BF_PXP_HW_PXP_CTRL_CLKGATE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL, field SFTRST[31] (RW)
 *
 * Set this bit to zero to enable normal PXP operation. Set this bit to one
 * (default) to disable clocking with the PXP and hold it in its reset (lowest power)
 * state. This bit can be turned on and then off to reset the PXP block to its
 * default state.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL_SFTRST (31U)    /*!< Bit position for PXP_HW_PXP_CTRL_SFTRST. */
#define BM_PXP_HW_PXP_CTRL_SFTRST (0x80000000U) /*!< Bit mask for PXP_HW_PXP_CTRL_SFTRST. */
#define BS_PXP_HW_PXP_CTRL_SFTRST (1U)     /*!< Bit field size in bits for PXP_HW_PXP_CTRL_SFTRST. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL_SFTRST field. */
#define BR_PXP_HW_PXP_CTRL_SFTRST(x) (HW_PXP_HW_PXP_CTRL(x).B.SFTRST)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL_SFTRST. */
#define BF_PXP_HW_PXP_CTRL_SFTRST(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL_SFTRST) & BM_PXP_HW_PXP_CTRL_SFTRST)

/*! @brief Set the SFTRST field to a new value. */
#define BW_PXP_HW_PXP_CTRL_SFTRST(x, v) (HW_PXP_HW_PXP_CTRL_WR(x, (HW_PXP_HW_PXP_CTRL_RD(x) & ~BM_PXP_HW_PXP_CTRL_SFTRST) | BF_PXP_HW_PXP_CTRL_SFTRST(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_STAT - Status Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_STAT - Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PXP Interrupt Status register provides interrupt status information.
 * HW_PXP_STAT: 0x010 HW_PXP_STAT_SET: 0x014 HW_PXP_STAT_CLR: 0x018 HW_PXP_STAT_TOG:
 * 0x01C This register provides PXP interrupt status and the current X/Y block
 * coordinate that is being processed. EXAMPLE REG_STAT_CLR(BM_PXP_STAT_IRQ); //
 * clear CSC interrupt
 */
typedef union _hw_pxp_hw_pxp_stat
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_stat_bitfields
    {
        uint32_t IRQ0 : 1;             /*!< [0]  */
        uint32_t AXI_WRITE_ERROR_0 : 1; /*!< [1]  */
        uint32_t AXI_READ_ERROR_0 : 1; /*!< [2]  */
        uint32_t NEXT_IRQ : 1;         /*!< [3]  */
        uint32_t AXI_ERROR_ID_0 : 4;   /*!< [7:4]  */
        uint32_t LUT_DMA_LOAD_DONE_IRQ : 1; /*!< [8]  */
        uint32_t AXI_WRITE_ERROR_1 : 1; /*!< [9]  */
        uint32_t AXI_READ_ERROR_1 : 1; /*!< [10]  */
        uint32_t RSVD2 : 1;            /*!< [11]  */
        uint32_t AXI_ERROR_ID_1 : 4;   /*!< [15:12]  */
        uint32_t BLOCKY : 8;           /*!< [23:16]  */
        uint32_t BLOCKX : 8;           /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_stat_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_STAT register
 */
/*@{*/
#define HW_PXP_HW_PXP_STAT_ADDR(x) ((uintptr_t)(x) + 0x10U)

#define HW_PXP_HW_PXP_STAT(x)    (*(__IO hw_pxp_hw_pxp_stat_t *) HW_PXP_HW_PXP_STAT_ADDR(x))
#define HW_PXP_HW_PXP_STAT_RD(x) (HW_PXP_HW_PXP_STAT(x).U)
#define HW_PXP_HW_PXP_STAT_WR(x, v) (HW_PXP_HW_PXP_STAT(x).U = (v))
#define HW_PXP_HW_PXP_STAT_SET(x, v) (HW_PXP_HW_PXP_STAT_WR(x, HW_PXP_HW_PXP_STAT_RD(x) |  (v)))
#define HW_PXP_HW_PXP_STAT_CLR(x, v) (HW_PXP_HW_PXP_STAT_WR(x, HW_PXP_HW_PXP_STAT_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_STAT_TOG(x, v) (HW_PXP_HW_PXP_STAT_WR(x, HW_PXP_HW_PXP_STAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_STAT bitfields
 */

/*!
 * @name Register PXP_HW_PXP_STAT, field IRQ0[0] (RW)
 *
 * Indicates current PXP interrupt status. The IRQ is routed through the pxp_irq
 * when the IRQ_ENABLE bit in the control register is set.
 */
/*@{*/
#define BP_PXP_HW_PXP_STAT_IRQ0 (0U)       /*!< Bit position for PXP_HW_PXP_STAT_IRQ0. */
#define BM_PXP_HW_PXP_STAT_IRQ0 (0x00000001U) /*!< Bit mask for PXP_HW_PXP_STAT_IRQ0. */
#define BS_PXP_HW_PXP_STAT_IRQ0 (1U)       /*!< Bit field size in bits for PXP_HW_PXP_STAT_IRQ0. */

/*! @brief Read current value of the PXP_HW_PXP_STAT_IRQ0 field. */
#define BR_PXP_HW_PXP_STAT_IRQ0(x) (HW_PXP_HW_PXP_STAT(x).B.IRQ0)

/*! @brief Format value for bitfield PXP_HW_PXP_STAT_IRQ0. */
#define BF_PXP_HW_PXP_STAT_IRQ0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_STAT_IRQ0) & BM_PXP_HW_PXP_STAT_IRQ0)

/*! @brief Set the IRQ0 field to a new value. */
#define BW_PXP_HW_PXP_STAT_IRQ0(x, v) (HW_PXP_HW_PXP_STAT_WR(x, (HW_PXP_HW_PXP_STAT_RD(x) & ~BM_PXP_HW_PXP_STAT_IRQ0) | BF_PXP_HW_PXP_STAT_IRQ0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_STAT, field AXI_WRITE_ERROR_0[1] (RW)
 *
 * Indicates PXP encountered an AXI write error and processing has been
 * terminated.
 */
/*@{*/
#define BP_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_0 (1U) /*!< Bit position for PXP_HW_PXP_STAT_AXI_WRITE_ERROR_0. */
#define BM_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_0 (0x00000002U) /*!< Bit mask for PXP_HW_PXP_STAT_AXI_WRITE_ERROR_0. */
#define BS_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_0 (1U) /*!< Bit field size in bits for PXP_HW_PXP_STAT_AXI_WRITE_ERROR_0. */

/*! @brief Read current value of the PXP_HW_PXP_STAT_AXI_WRITE_ERROR_0 field. */
#define BR_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_0(x) (HW_PXP_HW_PXP_STAT(x).B.AXI_WRITE_ERROR_0)

/*! @brief Format value for bitfield PXP_HW_PXP_STAT_AXI_WRITE_ERROR_0. */
#define BF_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_0) & BM_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_0)

/*! @brief Set the AXI_WRITE_ERROR_0 field to a new value. */
#define BW_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_0(x, v) (HW_PXP_HW_PXP_STAT_WR(x, (HW_PXP_HW_PXP_STAT_RD(x) & ~BM_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_0) | BF_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_STAT, field AXI_READ_ERROR_0[2] (RW)
 *
 * Indicates PXP encountered an AXI read error and processing has been
 * terminated.
 */
/*@{*/
#define BP_PXP_HW_PXP_STAT_AXI_READ_ERROR_0 (2U) /*!< Bit position for PXP_HW_PXP_STAT_AXI_READ_ERROR_0. */
#define BM_PXP_HW_PXP_STAT_AXI_READ_ERROR_0 (0x00000004U) /*!< Bit mask for PXP_HW_PXP_STAT_AXI_READ_ERROR_0. */
#define BS_PXP_HW_PXP_STAT_AXI_READ_ERROR_0 (1U) /*!< Bit field size in bits for PXP_HW_PXP_STAT_AXI_READ_ERROR_0. */

/*! @brief Read current value of the PXP_HW_PXP_STAT_AXI_READ_ERROR_0 field. */
#define BR_PXP_HW_PXP_STAT_AXI_READ_ERROR_0(x) (HW_PXP_HW_PXP_STAT(x).B.AXI_READ_ERROR_0)

/*! @brief Format value for bitfield PXP_HW_PXP_STAT_AXI_READ_ERROR_0. */
#define BF_PXP_HW_PXP_STAT_AXI_READ_ERROR_0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_STAT_AXI_READ_ERROR_0) & BM_PXP_HW_PXP_STAT_AXI_READ_ERROR_0)

/*! @brief Set the AXI_READ_ERROR_0 field to a new value. */
#define BW_PXP_HW_PXP_STAT_AXI_READ_ERROR_0(x, v) (HW_PXP_HW_PXP_STAT_WR(x, (HW_PXP_HW_PXP_STAT_RD(x) & ~BM_PXP_HW_PXP_STAT_AXI_READ_ERROR_0) | BF_PXP_HW_PXP_STAT_AXI_READ_ERROR_0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_STAT, field NEXT_IRQ[3] (RW)
 *
 * Indicates that a command issued with the "Next Command" functionality has
 * been issued and that a new command may be initiated with a write to the PXP_NEXT
 * register.
 */
/*@{*/
#define BP_PXP_HW_PXP_STAT_NEXT_IRQ (3U)   /*!< Bit position for PXP_HW_PXP_STAT_NEXT_IRQ. */
#define BM_PXP_HW_PXP_STAT_NEXT_IRQ (0x00000008U) /*!< Bit mask for PXP_HW_PXP_STAT_NEXT_IRQ. */
#define BS_PXP_HW_PXP_STAT_NEXT_IRQ (1U)   /*!< Bit field size in bits for PXP_HW_PXP_STAT_NEXT_IRQ. */

/*! @brief Read current value of the PXP_HW_PXP_STAT_NEXT_IRQ field. */
#define BR_PXP_HW_PXP_STAT_NEXT_IRQ(x) (HW_PXP_HW_PXP_STAT(x).B.NEXT_IRQ)

/*! @brief Format value for bitfield PXP_HW_PXP_STAT_NEXT_IRQ. */
#define BF_PXP_HW_PXP_STAT_NEXT_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_STAT_NEXT_IRQ) & BM_PXP_HW_PXP_STAT_NEXT_IRQ)

/*! @brief Set the NEXT_IRQ field to a new value. */
#define BW_PXP_HW_PXP_STAT_NEXT_IRQ(x, v) (HW_PXP_HW_PXP_STAT_WR(x, (HW_PXP_HW_PXP_STAT_RD(x) & ~BM_PXP_HW_PXP_STAT_NEXT_IRQ) | BF_PXP_HW_PXP_STAT_NEXT_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_STAT, field AXI_ERROR_ID_0[7:4] (RO)
 *
 * Indicates the AXI0 ID of the failing bus operation.
 */
/*@{*/
#define BP_PXP_HW_PXP_STAT_AXI_ERROR_ID_0 (4U) /*!< Bit position for PXP_HW_PXP_STAT_AXI_ERROR_ID_0. */
#define BM_PXP_HW_PXP_STAT_AXI_ERROR_ID_0 (0x000000F0U) /*!< Bit mask for PXP_HW_PXP_STAT_AXI_ERROR_ID_0. */
#define BS_PXP_HW_PXP_STAT_AXI_ERROR_ID_0 (4U) /*!< Bit field size in bits for PXP_HW_PXP_STAT_AXI_ERROR_ID_0. */

/*! @brief Read current value of the PXP_HW_PXP_STAT_AXI_ERROR_ID_0 field. */
#define BR_PXP_HW_PXP_STAT_AXI_ERROR_ID_0(x) (HW_PXP_HW_PXP_STAT(x).B.AXI_ERROR_ID_0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_STAT, field LUT_DMA_LOAD_DONE_IRQ[8] (RW)
 *
 * Indicates that the LUT DMA transfer has completed.
 */
/*@{*/
#define BP_PXP_HW_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ (8U) /*!< Bit position for PXP_HW_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ. */
#define BM_PXP_HW_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ (0x00000100U) /*!< Bit mask for PXP_HW_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ. */
#define BS_PXP_HW_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ (1U) /*!< Bit field size in bits for PXP_HW_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ. */

/*! @brief Read current value of the PXP_HW_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ field. */
#define BR_PXP_HW_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ(x) (HW_PXP_HW_PXP_STAT(x).B.LUT_DMA_LOAD_DONE_IRQ)

/*! @brief Format value for bitfield PXP_HW_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ. */
#define BF_PXP_HW_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ) & BM_PXP_HW_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ)

/*! @brief Set the LUT_DMA_LOAD_DONE_IRQ field to a new value. */
#define BW_PXP_HW_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ(x, v) (HW_PXP_HW_PXP_STAT_WR(x, (HW_PXP_HW_PXP_STAT_RD(x) & ~BM_PXP_HW_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ) | BF_PXP_HW_PXP_STAT_LUT_DMA_LOAD_DONE_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_STAT, field AXI_WRITE_ERROR_1[9] (RW)
 *
 * Indicates PXP encountered an AXI write error and processing has been
 * terminated.
 */
/*@{*/
#define BP_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_1 (9U) /*!< Bit position for PXP_HW_PXP_STAT_AXI_WRITE_ERROR_1. */
#define BM_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_1 (0x00000200U) /*!< Bit mask for PXP_HW_PXP_STAT_AXI_WRITE_ERROR_1. */
#define BS_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_STAT_AXI_WRITE_ERROR_1. */

/*! @brief Read current value of the PXP_HW_PXP_STAT_AXI_WRITE_ERROR_1 field. */
#define BR_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_1(x) (HW_PXP_HW_PXP_STAT(x).B.AXI_WRITE_ERROR_1)

/*! @brief Format value for bitfield PXP_HW_PXP_STAT_AXI_WRITE_ERROR_1. */
#define BF_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_1) & BM_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_1)

/*! @brief Set the AXI_WRITE_ERROR_1 field to a new value. */
#define BW_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_1(x, v) (HW_PXP_HW_PXP_STAT_WR(x, (HW_PXP_HW_PXP_STAT_RD(x) & ~BM_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_1) | BF_PXP_HW_PXP_STAT_AXI_WRITE_ERROR_1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_STAT, field AXI_READ_ERROR_1[10] (RW)
 *
 * Indicates PXP encountered an AXI read error and processing has been
 * terminated.
 */
/*@{*/
#define BP_PXP_HW_PXP_STAT_AXI_READ_ERROR_1 (10U) /*!< Bit position for PXP_HW_PXP_STAT_AXI_READ_ERROR_1. */
#define BM_PXP_HW_PXP_STAT_AXI_READ_ERROR_1 (0x00000400U) /*!< Bit mask for PXP_HW_PXP_STAT_AXI_READ_ERROR_1. */
#define BS_PXP_HW_PXP_STAT_AXI_READ_ERROR_1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_STAT_AXI_READ_ERROR_1. */

/*! @brief Read current value of the PXP_HW_PXP_STAT_AXI_READ_ERROR_1 field. */
#define BR_PXP_HW_PXP_STAT_AXI_READ_ERROR_1(x) (HW_PXP_HW_PXP_STAT(x).B.AXI_READ_ERROR_1)

/*! @brief Format value for bitfield PXP_HW_PXP_STAT_AXI_READ_ERROR_1. */
#define BF_PXP_HW_PXP_STAT_AXI_READ_ERROR_1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_STAT_AXI_READ_ERROR_1) & BM_PXP_HW_PXP_STAT_AXI_READ_ERROR_1)

/*! @brief Set the AXI_READ_ERROR_1 field to a new value. */
#define BW_PXP_HW_PXP_STAT_AXI_READ_ERROR_1(x, v) (HW_PXP_HW_PXP_STAT_WR(x, (HW_PXP_HW_PXP_STAT_RD(x) & ~BM_PXP_HW_PXP_STAT_AXI_READ_ERROR_1) | BF_PXP_HW_PXP_STAT_AXI_READ_ERROR_1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_STAT, field RSVD2[11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_STAT_RSVD2 (11U)     /*!< Bit position for PXP_HW_PXP_STAT_RSVD2. */
#define BM_PXP_HW_PXP_STAT_RSVD2 (0x00000800U) /*!< Bit mask for PXP_HW_PXP_STAT_RSVD2. */
#define BS_PXP_HW_PXP_STAT_RSVD2 (1U)      /*!< Bit field size in bits for PXP_HW_PXP_STAT_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_STAT_RSVD2 field. */
#define BR_PXP_HW_PXP_STAT_RSVD2(x) (HW_PXP_HW_PXP_STAT(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_STAT, field AXI_ERROR_ID_1[15:12] (RO)
 *
 * Indicates the AXI1 ID of the failing bus operation.
 */
/*@{*/
#define BP_PXP_HW_PXP_STAT_AXI_ERROR_ID_1 (12U) /*!< Bit position for PXP_HW_PXP_STAT_AXI_ERROR_ID_1. */
#define BM_PXP_HW_PXP_STAT_AXI_ERROR_ID_1 (0x0000F000U) /*!< Bit mask for PXP_HW_PXP_STAT_AXI_ERROR_ID_1. */
#define BS_PXP_HW_PXP_STAT_AXI_ERROR_ID_1 (4U) /*!< Bit field size in bits for PXP_HW_PXP_STAT_AXI_ERROR_ID_1. */

/*! @brief Read current value of the PXP_HW_PXP_STAT_AXI_ERROR_ID_1 field. */
#define BR_PXP_HW_PXP_STAT_AXI_ERROR_ID_1(x) (HW_PXP_HW_PXP_STAT(x).B.AXI_ERROR_ID_1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_STAT, field BLOCKY[23:16] (RO)
 *
 * Indicates the X coordinate of the block currently being rendered.
 */
/*@{*/
#define BP_PXP_HW_PXP_STAT_BLOCKY (16U)    /*!< Bit position for PXP_HW_PXP_STAT_BLOCKY. */
#define BM_PXP_HW_PXP_STAT_BLOCKY (0x00FF0000U) /*!< Bit mask for PXP_HW_PXP_STAT_BLOCKY. */
#define BS_PXP_HW_PXP_STAT_BLOCKY (8U)     /*!< Bit field size in bits for PXP_HW_PXP_STAT_BLOCKY. */

/*! @brief Read current value of the PXP_HW_PXP_STAT_BLOCKY field. */
#define BR_PXP_HW_PXP_STAT_BLOCKY(x) (HW_PXP_HW_PXP_STAT(x).B.BLOCKY)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_STAT, field BLOCKX[31:24] (RO)
 *
 * Indicates the X coordinate of the block currently being rendered.
 */
/*@{*/
#define BP_PXP_HW_PXP_STAT_BLOCKX (24U)    /*!< Bit position for PXP_HW_PXP_STAT_BLOCKX. */
#define BM_PXP_HW_PXP_STAT_BLOCKX (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_STAT_BLOCKX. */
#define BS_PXP_HW_PXP_STAT_BLOCKX (8U)     /*!< Bit field size in bits for PXP_HW_PXP_STAT_BLOCKX. */

/*! @brief Read current value of the PXP_HW_PXP_STAT_BLOCKX field. */
#define BR_PXP_HW_PXP_STAT_BLOCKX(x) (HW_PXP_HW_PXP_STAT(x).B.BLOCKX)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_OUT_CTRL - Output Buffer Control Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_OUT_CTRL - Output Buffer Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The OUT_CTRL register contains controls for the Output Buffer.
 * HW_PXP_OUT_CTRL: 0x020 HW_PXP_OUT_CTRL_SET: 0x024 HW_PXP_OUT_CTRL_CLR: 0x028
 * HW_PXP_OUT_CTRL_TOG: 0x02C Control register to determine OUT buffer processing. EXAMPLE
 * REG_CTRL_SET(BM_PXP_CTRL_SFTRST); REG_CTRL_CLR(BM_PXP_CTRL_SFTRST |
 * BM_PXP_CTRL_CLKGATE);
 */
typedef union _hw_pxp_hw_pxp_out_ctrl
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_out_ctrl_bitfields
    {
        uint32_t FORMAT : 5;           /*!< [4:0]  */
        uint32_t RSVD0 : 3;            /*!< [7:5]  */
        uint32_t INTERLACED_OUTPUT : 2; /*!< [9:8]  */
        uint32_t RSVD1 : 13;           /*!< [22:10]  */
        uint32_t ALPHA_OUTPUT : 1;     /*!< [23]  */
        uint32_t ALPHA : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_out_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_OUT_CTRL register
 */
/*@{*/
#define HW_PXP_HW_PXP_OUT_CTRL_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_PXP_HW_PXP_OUT_CTRL(x) (*(__IO hw_pxp_hw_pxp_out_ctrl_t *) HW_PXP_HW_PXP_OUT_CTRL_ADDR(x))
#define HW_PXP_HW_PXP_OUT_CTRL_RD(x) (HW_PXP_HW_PXP_OUT_CTRL(x).U)
#define HW_PXP_HW_PXP_OUT_CTRL_WR(x, v) (HW_PXP_HW_PXP_OUT_CTRL(x).U = (v))
#define HW_PXP_HW_PXP_OUT_CTRL_SET(x, v) (HW_PXP_HW_PXP_OUT_CTRL_WR(x, HW_PXP_HW_PXP_OUT_CTRL_RD(x) |  (v)))
#define HW_PXP_HW_PXP_OUT_CTRL_CLR(x, v) (HW_PXP_HW_PXP_OUT_CTRL_WR(x, HW_PXP_HW_PXP_OUT_CTRL_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_OUT_CTRL_TOG(x, v) (HW_PXP_HW_PXP_OUT_CTRL_WR(x, HW_PXP_HW_PXP_OUT_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_OUT_CTRL bitfields
 */

/*!
 * @name Register PXP_HW_PXP_OUT_CTRL, field FORMAT[4:0] (RW)
 *
 * Output framebuffer format. The UV byte lanes are synonymous with CbCr byte
 * lanes for YUV output pixel formats. For example, the YUV2P420 format should be
 * selected when the output is YCbCr 2-plane 420 output format.
 *
 * Values:
 * - 0 - 32-bit pixels
 * - 100 - 32-bit pixels (unpacked 24-bit pixel in 32 bit DWORD.)
 * - 101 - 24-bit pixels (packed 24-bit format)
 * - 1000 - 16-bit pixels
 * - 1001 - 16-bit pixels
 * - 1100 - 16-bit pixels
 * - 1101 - 16-bit pixels
 * - 1110 - 16-bit pixels
 * - 10000 - 32-bit pixels (1-plane XYUV unpacked)
 * - 10010 - 16-bit pixels (1-plane U0,Y0,V0,Y1 interleaved bytes)
 * - 10011 - 16-bit pixels (1-plane V0,Y0,U0,Y1 interleaved bytes)
 * - 10100 - 8-bit monochrome pixels (1-plane Y luma output)
 * - 10101 - 4-bit monochrome pixels (1-plane Y luma, 4 bit truncation)
 * - 11000 - 16-bit pixels (2-plane UV interleaved bytes)
 * - 11001 - 16-bit pixels (2-plane UV)
 * - 11010 - 16-bit pixels (2-plane VU interleaved bytes)
 * - 11011 - 16-bit pixels (2-plane VU)
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_CTRL_FORMAT (0U) /*!< Bit position for PXP_HW_PXP_OUT_CTRL_FORMAT. */
#define BM_PXP_HW_PXP_OUT_CTRL_FORMAT (0x0000001FU) /*!< Bit mask for PXP_HW_PXP_OUT_CTRL_FORMAT. */
#define BS_PXP_HW_PXP_OUT_CTRL_FORMAT (5U) /*!< Bit field size in bits for PXP_HW_PXP_OUT_CTRL_FORMAT. */

#define BV_PXP_HW_PXP_OUT_CTRL_FORMAT_ARGB8888 (0U)  /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_FORMAT: 32-bit pixels */
#define BV_PXP_HW_PXP_OUT_CTRL_FORMAT_RGB888 (0x4U)  /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_FORMAT: 32-bit pixels (unpacked 24-bit pixel in 32 bit DWORD.) */
#define BV_PXP_HW_PXP_OUT_CTRL_FORMAT_RGB888P (0x5U) /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_FORMAT: 24-bit pixels (packed 24-bit format) */
#define BV_PXP_HW_PXP_OUT_CTRL_FORMAT_ARGB1555 (0x8U) /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_FORMAT: 16-bit pixels */
#define BV_PXP_HW_PXP_OUT_CTRL_FORMAT_ARGB4444 (0x9U) /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_FORMAT: 16-bit pixels */
#define BV_PXP_HW_PXP_OUT_CTRL_FORMAT_RGB555 (0xCU)  /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_FORMAT: 16-bit pixels */
#define BV_PXP_HW_PXP_OUT_CTRL_FORMAT_RGB444 (0xDU)  /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_FORMAT: 16-bit pixels */
#define BV_PXP_HW_PXP_OUT_CTRL_FORMAT_RGB565 (0xEU)  /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_FORMAT: 16-bit pixels */
#define BV_PXP_HW_PXP_OUT_CTRL_FORMAT_YUV1P444 (0x10U) /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_FORMAT: 32-bit pixels (1-plane XYUV unpacked) */
#define BV_PXP_HW_PXP_OUT_CTRL_FORMAT_UYVY1P422 (0x12U) /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_FORMAT: 16-bit pixels (1-plane U0,Y0,V0,Y1 interleaved bytes) */
#define BV_PXP_HW_PXP_OUT_CTRL_FORMAT_VYUY1P422 (0x13U) /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_FORMAT: 16-bit pixels (1-plane V0,Y0,U0,Y1 interleaved bytes) */
#define BV_PXP_HW_PXP_OUT_CTRL_FORMAT_Y8 (0x14U)     /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_FORMAT: 8-bit monochrome pixels (1-plane Y luma output) */
#define BV_PXP_HW_PXP_OUT_CTRL_FORMAT_Y4 (0x15U)     /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_FORMAT: 4-bit monochrome pixels (1-plane Y luma, 4 bit truncation) */
#define BV_PXP_HW_PXP_OUT_CTRL_FORMAT_YUV2P422 (0x18U) /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_FORMAT: 16-bit pixels (2-plane UV interleaved bytes) */
#define BV_PXP_HW_PXP_OUT_CTRL_FORMAT_YUV2P420 (0x19U) /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_FORMAT: 16-bit pixels (2-plane UV) */
#define BV_PXP_HW_PXP_OUT_CTRL_FORMAT_YVU2P422 (0x1AU) /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_FORMAT: 16-bit pixels (2-plane VU interleaved bytes) */
#define BV_PXP_HW_PXP_OUT_CTRL_FORMAT_YVU2P420 (0x1BU) /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_FORMAT: 16-bit pixels (2-plane VU) */

/*! @brief Read current value of the PXP_HW_PXP_OUT_CTRL_FORMAT field. */
#define BR_PXP_HW_PXP_OUT_CTRL_FORMAT(x) (HW_PXP_HW_PXP_OUT_CTRL(x).B.FORMAT)

/*! @brief Format value for bitfield PXP_HW_PXP_OUT_CTRL_FORMAT. */
#define BF_PXP_HW_PXP_OUT_CTRL_FORMAT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_OUT_CTRL_FORMAT) & BM_PXP_HW_PXP_OUT_CTRL_FORMAT)

/*! @brief Set the FORMAT field to a new value. */
#define BW_PXP_HW_PXP_OUT_CTRL_FORMAT(x, v) (HW_PXP_HW_PXP_OUT_CTRL_WR(x, (HW_PXP_HW_PXP_OUT_CTRL_RD(x) & ~BM_PXP_HW_PXP_OUT_CTRL_FORMAT) | BF_PXP_HW_PXP_OUT_CTRL_FORMAT(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_CTRL, field RSVD0[7:5] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_CTRL_RSVD0 (5U)  /*!< Bit position for PXP_HW_PXP_OUT_CTRL_RSVD0. */
#define BM_PXP_HW_PXP_OUT_CTRL_RSVD0 (0x000000E0U) /*!< Bit mask for PXP_HW_PXP_OUT_CTRL_RSVD0. */
#define BS_PXP_HW_PXP_OUT_CTRL_RSVD0 (3U)  /*!< Bit field size in bits for PXP_HW_PXP_OUT_CTRL_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_CTRL_RSVD0 field. */
#define BR_PXP_HW_PXP_OUT_CTRL_RSVD0(x) (HW_PXP_HW_PXP_OUT_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_CTRL, field INTERLACED_OUTPUT[9:8] (RW)
 *
 * Determines how the PXP writes it's output data. Output interlacing should not
 * be used in conjunction with input interlacing. Splitting frames into fields
 * is most efficient using output interlacing. 2-plane output formats AND
 * interlaced output is NOT supported.
 *
 * Values:
 * - 0 - All data written in progressive format to the OUTBUF Pointer.
 * - 1 - Interlaced output: only data for field 0 is written to the OUTBUF
 *     Pointer.
 * - 10 - Interlaced output: only data for field 1 is written to the OUTBUF2
 *     Pointer.
 * - 11 - Interlaced output: data for field 0 is written to OUTBUF and data for
 *     field 1 is written to OUTBUF2.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT (8U) /*!< Bit position for PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT. */
#define BM_PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT (0x00000300U) /*!< Bit mask for PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT. */
#define BS_PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT (2U) /*!< Bit field size in bits for PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT. */

#define BV_PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT_PROGRESSIVE (0U) /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT: All data written in progressive format to the OUTBUF Pointer. */
#define BV_PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT_FIELD0 (0x1U) /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT: Interlaced output: only data for field 0 is written to the OUTBUF Pointer. */
#define BV_PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT_FIELD1 (0x2U) /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT: Interlaced output: only data for field 1 is written to the OUTBUF2 Pointer. */
#define BV_PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT_INTERLACED (0x3U) /*!< Bit field value for PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT: Interlaced output: data for field 0 is written to OUTBUF and data for field 1 is written to OUTBUF2. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT field. */
#define BR_PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT(x) (HW_PXP_HW_PXP_OUT_CTRL(x).B.INTERLACED_OUTPUT)

/*! @brief Format value for bitfield PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT. */
#define BF_PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT) & BM_PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT)

/*! @brief Set the INTERLACED_OUTPUT field to a new value. */
#define BW_PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT(x, v) (HW_PXP_HW_PXP_OUT_CTRL_WR(x, (HW_PXP_HW_PXP_OUT_CTRL_RD(x) & ~BM_PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT) | BF_PXP_HW_PXP_OUT_CTRL_INTERLACED_OUTPUT(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_CTRL, field RSVD1[22:10] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_CTRL_RSVD1 (10U) /*!< Bit position for PXP_HW_PXP_OUT_CTRL_RSVD1. */
#define BM_PXP_HW_PXP_OUT_CTRL_RSVD1 (0x007FFC00U) /*!< Bit mask for PXP_HW_PXP_OUT_CTRL_RSVD1. */
#define BS_PXP_HW_PXP_OUT_CTRL_RSVD1 (13U) /*!< Bit field size in bits for PXP_HW_PXP_OUT_CTRL_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_CTRL_RSVD1 field. */
#define BR_PXP_HW_PXP_OUT_CTRL_RSVD1(x) (HW_PXP_HW_PXP_OUT_CTRL(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_CTRL, field ALPHA_OUTPUT[23] (RW)
 *
 * Indicates that alpha component in output buffer pixels should be overwritten
 * by REG_OUT_CTRL[ALPHA] register. If 0, retain their alpha value from the
 * computed alpha for that pixel.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_CTRL_ALPHA_OUTPUT (23U) /*!< Bit position for PXP_HW_PXP_OUT_CTRL_ALPHA_OUTPUT. */
#define BM_PXP_HW_PXP_OUT_CTRL_ALPHA_OUTPUT (0x00800000U) /*!< Bit mask for PXP_HW_PXP_OUT_CTRL_ALPHA_OUTPUT. */
#define BS_PXP_HW_PXP_OUT_CTRL_ALPHA_OUTPUT (1U) /*!< Bit field size in bits for PXP_HW_PXP_OUT_CTRL_ALPHA_OUTPUT. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_CTRL_ALPHA_OUTPUT field. */
#define BR_PXP_HW_PXP_OUT_CTRL_ALPHA_OUTPUT(x) (HW_PXP_HW_PXP_OUT_CTRL(x).B.ALPHA_OUTPUT)

/*! @brief Format value for bitfield PXP_HW_PXP_OUT_CTRL_ALPHA_OUTPUT. */
#define BF_PXP_HW_PXP_OUT_CTRL_ALPHA_OUTPUT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_OUT_CTRL_ALPHA_OUTPUT) & BM_PXP_HW_PXP_OUT_CTRL_ALPHA_OUTPUT)

/*! @brief Set the ALPHA_OUTPUT field to a new value. */
#define BW_PXP_HW_PXP_OUT_CTRL_ALPHA_OUTPUT(x, v) (HW_PXP_HW_PXP_OUT_CTRL_WR(x, (HW_PXP_HW_PXP_OUT_CTRL_RD(x) & ~BM_PXP_HW_PXP_OUT_CTRL_ALPHA_OUTPUT) | BF_PXP_HW_PXP_OUT_CTRL_ALPHA_OUTPUT(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_CTRL, field ALPHA[31:24] (RW)
 *
 * When generating an output buffer with an alpha component, the value in this
 * field will be used when enabled to override the alpha passed through the pixel
 * data pipeline.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_CTRL_ALPHA (24U) /*!< Bit position for PXP_HW_PXP_OUT_CTRL_ALPHA. */
#define BM_PXP_HW_PXP_OUT_CTRL_ALPHA (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_OUT_CTRL_ALPHA. */
#define BS_PXP_HW_PXP_OUT_CTRL_ALPHA (8U)  /*!< Bit field size in bits for PXP_HW_PXP_OUT_CTRL_ALPHA. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_CTRL_ALPHA field. */
#define BR_PXP_HW_PXP_OUT_CTRL_ALPHA(x) (HW_PXP_HW_PXP_OUT_CTRL(x).B.ALPHA)

/*! @brief Format value for bitfield PXP_HW_PXP_OUT_CTRL_ALPHA. */
#define BF_PXP_HW_PXP_OUT_CTRL_ALPHA(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_OUT_CTRL_ALPHA) & BM_PXP_HW_PXP_OUT_CTRL_ALPHA)

/*! @brief Set the ALPHA field to a new value. */
#define BW_PXP_HW_PXP_OUT_CTRL_ALPHA(x, v) (HW_PXP_HW_PXP_OUT_CTRL_WR(x, (HW_PXP_HW_PXP_OUT_CTRL_RD(x) & ~BM_PXP_HW_PXP_OUT_CTRL_ALPHA) | BF_PXP_HW_PXP_OUT_CTRL_ALPHA(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_OUT_BUF - Output Frame Buffer Pointer
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_OUT_BUF - Output Frame Buffer Pointer (RW)
 *
 * Reset value: 0x00000000U
 *
 * Output Framebuffer Pointer. This register points to the beginning of the
 * output frame buffer. This pointer is used for progressive format and field 0 when
 * generating interlaced output. This register is used by the logic to point to
 * the current output location for the output frame buffer. EXAMPLE
 * REG_OUT_BUF_WR( buffer );
 */
typedef union _hw_pxp_hw_pxp_out_buf
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_out_buf_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_out_buf_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_OUT_BUF register
 */
/*@{*/
#define HW_PXP_HW_PXP_OUT_BUF_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_PXP_HW_PXP_OUT_BUF(x) (*(__IO hw_pxp_hw_pxp_out_buf_t *) HW_PXP_HW_PXP_OUT_BUF_ADDR(x))
#define HW_PXP_HW_PXP_OUT_BUF_RD(x) (HW_PXP_HW_PXP_OUT_BUF(x).U)
#define HW_PXP_HW_PXP_OUT_BUF_WR(x, v) (HW_PXP_HW_PXP_OUT_BUF(x).U = (v))
#define HW_PXP_HW_PXP_OUT_BUF_SET(x, v) (HW_PXP_HW_PXP_OUT_BUF_WR(x, HW_PXP_HW_PXP_OUT_BUF_RD(x) |  (v)))
#define HW_PXP_HW_PXP_OUT_BUF_CLR(x, v) (HW_PXP_HW_PXP_OUT_BUF_WR(x, HW_PXP_HW_PXP_OUT_BUF_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_OUT_BUF_TOG(x, v) (HW_PXP_HW_PXP_OUT_BUF_WR(x, HW_PXP_HW_PXP_OUT_BUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_OUT_BUF bitfields
 */

/*!
 * @name Register PXP_HW_PXP_OUT_BUF, field ADDR[31:0] (RW)
 *
 * Current address pointer for the output frame buffer. The address can have any
 * byte alignment. 64B alignment is recommended for optimal performance.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_BUF_ADDR (0U)    /*!< Bit position for PXP_HW_PXP_OUT_BUF_ADDR. */
#define BM_PXP_HW_PXP_OUT_BUF_ADDR (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_OUT_BUF_ADDR. */
#define BS_PXP_HW_PXP_OUT_BUF_ADDR (32U)   /*!< Bit field size in bits for PXP_HW_PXP_OUT_BUF_ADDR. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_BUF_ADDR field. */
#define BR_PXP_HW_PXP_OUT_BUF_ADDR(x) (HW_PXP_HW_PXP_OUT_BUF(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_OUT_BUF_ADDR. */
#define BF_PXP_HW_PXP_OUT_BUF_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_OUT_BUF_ADDR) & BM_PXP_HW_PXP_OUT_BUF_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_PXP_HW_PXP_OUT_BUF_ADDR(x, v) (HW_PXP_HW_PXP_OUT_BUF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_OUT_BUF2 - Output Frame Buffer Pointer #2
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_OUT_BUF2 - Output Frame Buffer Pointer #2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * Output Framebuffer Pointer #2. This register points to the beginning of the
 * output frame buffer for either field 1 when generating interlaced output or for
 * the UV buffer when in YUV 2-plane output modes. Both interlaced output AND
 * 2-plane output modes are not supported in a single PXP operation. This register
 * is NOT used as the pointer to the 2nd buffer when in LCDIF_HANDSHAKE mode.
 * This register is used by the logic to point to the current output location for
 * the field 1 or UV output frame buffer. EXAMPLE REG_OUT_BUF_WR( field0 ); //
 * buffer for interlaced field 0 REG_OUT_BUF2_WR( field1 ); // buffer for interlaced
 * field 1
 */
typedef union _hw_pxp_hw_pxp_out_buf2
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_out_buf2_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_out_buf2_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_OUT_BUF2 register
 */
/*@{*/
#define HW_PXP_HW_PXP_OUT_BUF2_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_PXP_HW_PXP_OUT_BUF2(x) (*(__IO hw_pxp_hw_pxp_out_buf2_t *) HW_PXP_HW_PXP_OUT_BUF2_ADDR(x))
#define HW_PXP_HW_PXP_OUT_BUF2_RD(x) (HW_PXP_HW_PXP_OUT_BUF2(x).U)
#define HW_PXP_HW_PXP_OUT_BUF2_WR(x, v) (HW_PXP_HW_PXP_OUT_BUF2(x).U = (v))
#define HW_PXP_HW_PXP_OUT_BUF2_SET(x, v) (HW_PXP_HW_PXP_OUT_BUF2_WR(x, HW_PXP_HW_PXP_OUT_BUF2_RD(x) |  (v)))
#define HW_PXP_HW_PXP_OUT_BUF2_CLR(x, v) (HW_PXP_HW_PXP_OUT_BUF2_WR(x, HW_PXP_HW_PXP_OUT_BUF2_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_OUT_BUF2_TOG(x, v) (HW_PXP_HW_PXP_OUT_BUF2_WR(x, HW_PXP_HW_PXP_OUT_BUF2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_OUT_BUF2 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_OUT_BUF2, field ADDR[31:0] (RW)
 *
 * Current address pointer for the output frame buffer. The address can have any
 * byte alignment. 64B alignment is recommended for optimal performance.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_BUF2_ADDR (0U)   /*!< Bit position for PXP_HW_PXP_OUT_BUF2_ADDR. */
#define BM_PXP_HW_PXP_OUT_BUF2_ADDR (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_OUT_BUF2_ADDR. */
#define BS_PXP_HW_PXP_OUT_BUF2_ADDR (32U)  /*!< Bit field size in bits for PXP_HW_PXP_OUT_BUF2_ADDR. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_BUF2_ADDR field. */
#define BR_PXP_HW_PXP_OUT_BUF2_ADDR(x) (HW_PXP_HW_PXP_OUT_BUF2(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_OUT_BUF2_ADDR. */
#define BF_PXP_HW_PXP_OUT_BUF2_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_OUT_BUF2_ADDR) & BM_PXP_HW_PXP_OUT_BUF2_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_PXP_HW_PXP_OUT_BUF2_ADDR(x, v) (HW_PXP_HW_PXP_OUT_BUF2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_OUT_PITCH - Output Buffer Pitch
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_OUT_PITCH - Output Buffer Pitch (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the output buffer pitch in bytes. Any byte value will
 * indicate the vertical pitch. This value will be used in output pixel address
 * calculations. EXAMPLE REG_OUT_PITCH_WR( 68 * 4 ); // The output buffer pitch is
 * 68 pixels times 32 bits per pixel
 */
typedef union _hw_pxp_hw_pxp_out_pitch
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_out_pitch_bitfields
    {
        uint32_t PITCH : 16;           /*!< [15:0]  */
        uint32_t RSVD : 16;            /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_out_pitch_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_OUT_PITCH register
 */
/*@{*/
#define HW_PXP_HW_PXP_OUT_PITCH_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_PXP_HW_PXP_OUT_PITCH(x) (*(__IO hw_pxp_hw_pxp_out_pitch_t *) HW_PXP_HW_PXP_OUT_PITCH_ADDR(x))
#define HW_PXP_HW_PXP_OUT_PITCH_RD(x) (HW_PXP_HW_PXP_OUT_PITCH(x).U)
#define HW_PXP_HW_PXP_OUT_PITCH_WR(x, v) (HW_PXP_HW_PXP_OUT_PITCH(x).U = (v))
#define HW_PXP_HW_PXP_OUT_PITCH_SET(x, v) (HW_PXP_HW_PXP_OUT_PITCH_WR(x, HW_PXP_HW_PXP_OUT_PITCH_RD(x) |  (v)))
#define HW_PXP_HW_PXP_OUT_PITCH_CLR(x, v) (HW_PXP_HW_PXP_OUT_PITCH_WR(x, HW_PXP_HW_PXP_OUT_PITCH_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_OUT_PITCH_TOG(x, v) (HW_PXP_HW_PXP_OUT_PITCH_WR(x, HW_PXP_HW_PXP_OUT_PITCH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_OUT_PITCH bitfields
 */

/*!
 * @name Register PXP_HW_PXP_OUT_PITCH, field PITCH[15:0] (RW)
 *
 * Indicates the number of bytes in memory between two vertically adjacent
 * pixels.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_PITCH_PITCH (0U) /*!< Bit position for PXP_HW_PXP_OUT_PITCH_PITCH. */
#define BM_PXP_HW_PXP_OUT_PITCH_PITCH (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_OUT_PITCH_PITCH. */
#define BS_PXP_HW_PXP_OUT_PITCH_PITCH (16U) /*!< Bit field size in bits for PXP_HW_PXP_OUT_PITCH_PITCH. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_PITCH_PITCH field. */
#define BR_PXP_HW_PXP_OUT_PITCH_PITCH(x) (HW_PXP_HW_PXP_OUT_PITCH(x).B.PITCH)

/*! @brief Format value for bitfield PXP_HW_PXP_OUT_PITCH_PITCH. */
#define BF_PXP_HW_PXP_OUT_PITCH_PITCH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_OUT_PITCH_PITCH) & BM_PXP_HW_PXP_OUT_PITCH_PITCH)

/*! @brief Set the PITCH field to a new value. */
#define BW_PXP_HW_PXP_OUT_PITCH_PITCH(x, v) (HW_PXP_HW_PXP_OUT_PITCH_WR(x, (HW_PXP_HW_PXP_OUT_PITCH_RD(x) & ~BM_PXP_HW_PXP_OUT_PITCH_PITCH) | BF_PXP_HW_PXP_OUT_PITCH_PITCH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_PITCH, field RSVD[31:16] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_PITCH_RSVD (16U) /*!< Bit position for PXP_HW_PXP_OUT_PITCH_RSVD. */
#define BM_PXP_HW_PXP_OUT_PITCH_RSVD (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_OUT_PITCH_RSVD. */
#define BS_PXP_HW_PXP_OUT_PITCH_RSVD (16U) /*!< Bit field size in bits for PXP_HW_PXP_OUT_PITCH_RSVD. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_PITCH_RSVD field. */
#define BR_PXP_HW_PXP_OUT_PITCH_RSVD(x) (HW_PXP_HW_PXP_OUT_PITCH(x).B.RSVD)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_OUT_LRC - Output Surface Lower Right Coordinate
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_OUT_LRC - Output Surface Lower Right Coordinate (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the size, or lower right coordinate, of the output
 * buffer NOT rotated. It is implied that the upper left coordinate of the output
 * surface is always [0,0]. When rotating the framebuffer, the PXP will
 * automatically swap the X/Y, or WIDTH/HEIGHT, to accomodate the rotated size. This
 * register sets the size of the output frame buffer in pixels, not blocks. The frame
 * buffer need not be a multiple of NxN pixels. Partial blocks will be written for
 * output frame buffer sizes that are not divisable by N pixels in either
 * dimension. EXAMPLE REG_OUT_LRC[X]=319; // set width of output frame buffer to 320
 * pixels REG_OUT_LRC[Y]=243; // set height of output frame buffer to 244 pixels
 * which is not divisable by block size N REG_OUT_LRC_WR( BF_PXP_OUT_LRC_X(319) |
 * BF_PXP_OUT_LRC_Y(243) );
 */
typedef union _hw_pxp_hw_pxp_out_lrc
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_out_lrc_bitfields
    {
        uint32_t Y : 14;               /*!< [13:0]  */
        uint32_t RSVD0 : 2;            /*!< [15:14]  */
        uint32_t X : 14;               /*!< [29:16]  */
        uint32_t RSVD1 : 2;            /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_out_lrc_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_OUT_LRC register
 */
/*@{*/
#define HW_PXP_HW_PXP_OUT_LRC_ADDR(x) ((uintptr_t)(x) + 0x60U)

#define HW_PXP_HW_PXP_OUT_LRC(x) (*(__IO hw_pxp_hw_pxp_out_lrc_t *) HW_PXP_HW_PXP_OUT_LRC_ADDR(x))
#define HW_PXP_HW_PXP_OUT_LRC_RD(x) (HW_PXP_HW_PXP_OUT_LRC(x).U)
#define HW_PXP_HW_PXP_OUT_LRC_WR(x, v) (HW_PXP_HW_PXP_OUT_LRC(x).U = (v))
#define HW_PXP_HW_PXP_OUT_LRC_SET(x, v) (HW_PXP_HW_PXP_OUT_LRC_WR(x, HW_PXP_HW_PXP_OUT_LRC_RD(x) |  (v)))
#define HW_PXP_HW_PXP_OUT_LRC_CLR(x, v) (HW_PXP_HW_PXP_OUT_LRC_WR(x, HW_PXP_HW_PXP_OUT_LRC_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_OUT_LRC_TOG(x, v) (HW_PXP_HW_PXP_OUT_LRC_WR(x, HW_PXP_HW_PXP_OUT_LRC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_OUT_LRC bitfields
 */

/*!
 * @name Register PXP_HW_PXP_OUT_LRC, field Y[13:0] (RW)
 *
 * Indicates the number of vertical PIXELS in the output surface (non-rotated).
 * The output buffer pixel height minus 1 should be programmed. The image size is
 * not required to be a multiple of 8 pixels. The PXP will clip the pixel output
 * at this boundary.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_LRC_Y (0U)       /*!< Bit position for PXP_HW_PXP_OUT_LRC_Y. */
#define BM_PXP_HW_PXP_OUT_LRC_Y (0x00003FFFU) /*!< Bit mask for PXP_HW_PXP_OUT_LRC_Y. */
#define BS_PXP_HW_PXP_OUT_LRC_Y (14U)      /*!< Bit field size in bits for PXP_HW_PXP_OUT_LRC_Y. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_LRC_Y field. */
#define BR_PXP_HW_PXP_OUT_LRC_Y(x) (HW_PXP_HW_PXP_OUT_LRC(x).B.Y)

/*! @brief Format value for bitfield PXP_HW_PXP_OUT_LRC_Y. */
#define BF_PXP_HW_PXP_OUT_LRC_Y(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_OUT_LRC_Y) & BM_PXP_HW_PXP_OUT_LRC_Y)

/*! @brief Set the Y field to a new value. */
#define BW_PXP_HW_PXP_OUT_LRC_Y(x, v) (HW_PXP_HW_PXP_OUT_LRC_WR(x, (HW_PXP_HW_PXP_OUT_LRC_RD(x) & ~BM_PXP_HW_PXP_OUT_LRC_Y) | BF_PXP_HW_PXP_OUT_LRC_Y(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_LRC, field RSVD0[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_LRC_RSVD0 (14U)  /*!< Bit position for PXP_HW_PXP_OUT_LRC_RSVD0. */
#define BM_PXP_HW_PXP_OUT_LRC_RSVD0 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_OUT_LRC_RSVD0. */
#define BS_PXP_HW_PXP_OUT_LRC_RSVD0 (2U)   /*!< Bit field size in bits for PXP_HW_PXP_OUT_LRC_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_LRC_RSVD0 field. */
#define BR_PXP_HW_PXP_OUT_LRC_RSVD0(x) (HW_PXP_HW_PXP_OUT_LRC(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_LRC, field X[29:16] (RW)
 *
 * Indicates number of horizontal PIXELS in the output surface (non-rotated).
 * The output buffer pixel width minus 1 should be programmed. The image size is
 * not required to be a multiple of 8 pixels. The PXP will clip the pixel output at
 * this boundary.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_LRC_X (16U)      /*!< Bit position for PXP_HW_PXP_OUT_LRC_X. */
#define BM_PXP_HW_PXP_OUT_LRC_X (0x3FFF0000U) /*!< Bit mask for PXP_HW_PXP_OUT_LRC_X. */
#define BS_PXP_HW_PXP_OUT_LRC_X (14U)      /*!< Bit field size in bits for PXP_HW_PXP_OUT_LRC_X. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_LRC_X field. */
#define BR_PXP_HW_PXP_OUT_LRC_X(x) (HW_PXP_HW_PXP_OUT_LRC(x).B.X)

/*! @brief Format value for bitfield PXP_HW_PXP_OUT_LRC_X. */
#define BF_PXP_HW_PXP_OUT_LRC_X(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_OUT_LRC_X) & BM_PXP_HW_PXP_OUT_LRC_X)

/*! @brief Set the X field to a new value. */
#define BW_PXP_HW_PXP_OUT_LRC_X(x, v) (HW_PXP_HW_PXP_OUT_LRC_WR(x, (HW_PXP_HW_PXP_OUT_LRC_RD(x) & ~BM_PXP_HW_PXP_OUT_LRC_X) | BF_PXP_HW_PXP_OUT_LRC_X(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_LRC, field RSVD1[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_LRC_RSVD1 (30U)  /*!< Bit position for PXP_HW_PXP_OUT_LRC_RSVD1. */
#define BM_PXP_HW_PXP_OUT_LRC_RSVD1 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_OUT_LRC_RSVD1. */
#define BS_PXP_HW_PXP_OUT_LRC_RSVD1 (2U)   /*!< Bit field size in bits for PXP_HW_PXP_OUT_LRC_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_LRC_RSVD1 field. */
#define BR_PXP_HW_PXP_OUT_LRC_RSVD1(x) (HW_PXP_HW_PXP_OUT_LRC(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_OUT_PS_ULC - Processed Surface Upper Left Coordinate
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_OUT_PS_ULC - Processed Surface Upper Left Coordinate (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the upper left pixel coordinate for the Processed
 * Surface in the OUTPUT buffer. This register contains the upper left coordinate of
 * the Processed Surface in the output frame buffer (in pixels). Values that are
 * within the REG_OUT_LRC[X,Y] extents are valid. The lowest valid value for
 * these fields is 0,0. If the value of the REG_OUT_PS_ULC is greater than the
 * REG_OUT_LRC, then no PS pixels will be fetched from memory, but only
 * REG_PS_BACKGROUND pixels will be processed by the PS engine. Pixel locations that are greater
 * than or equal to the PS upper left coordinates, less than or equal to the PS
 * lower right coordinates, and within the REG_OUT_LRC extents will use the PS to
 * render pixels into the output buffer. EXAMPLE
 * REG_OUT_PS_ULC_WR(0,0x0002_0002); // Processed Surface upper left coordinate at (X,Y) = 2,2. The PS surface
 * will not effect pixels in the first and second row and column of the output
 * buffer.
 */
typedef union _hw_pxp_hw_pxp_out_ps_ulc
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_out_ps_ulc_bitfields
    {
        uint32_t Y : 14;               /*!< [13:0]  */
        uint32_t RSVD0 : 2;            /*!< [15:14]  */
        uint32_t X : 14;               /*!< [29:16]  */
        uint32_t RSVD1 : 2;            /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_out_ps_ulc_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_OUT_PS_ULC register
 */
/*@{*/
#define HW_PXP_HW_PXP_OUT_PS_ULC_ADDR(x) ((uintptr_t)(x) + 0x70U)

#define HW_PXP_HW_PXP_OUT_PS_ULC(x) (*(__IO hw_pxp_hw_pxp_out_ps_ulc_t *) HW_PXP_HW_PXP_OUT_PS_ULC_ADDR(x))
#define HW_PXP_HW_PXP_OUT_PS_ULC_RD(x) (HW_PXP_HW_PXP_OUT_PS_ULC(x).U)
#define HW_PXP_HW_PXP_OUT_PS_ULC_WR(x, v) (HW_PXP_HW_PXP_OUT_PS_ULC(x).U = (v))
#define HW_PXP_HW_PXP_OUT_PS_ULC_SET(x, v) (HW_PXP_HW_PXP_OUT_PS_ULC_WR(x, HW_PXP_HW_PXP_OUT_PS_ULC_RD(x) |  (v)))
#define HW_PXP_HW_PXP_OUT_PS_ULC_CLR(x, v) (HW_PXP_HW_PXP_OUT_PS_ULC_WR(x, HW_PXP_HW_PXP_OUT_PS_ULC_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_OUT_PS_ULC_TOG(x, v) (HW_PXP_HW_PXP_OUT_PS_ULC_WR(x, HW_PXP_HW_PXP_OUT_PS_ULC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_OUT_PS_ULC bitfields
 */

/*!
 * @name Register PXP_HW_PXP_OUT_PS_ULC, field Y[13:0] (RW)
 *
 * This field indicates the upper left Y-coordinate (in pixels) of the processed
 * surface in the output buffer.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_PS_ULC_Y (0U)    /*!< Bit position for PXP_HW_PXP_OUT_PS_ULC_Y. */
#define BM_PXP_HW_PXP_OUT_PS_ULC_Y (0x00003FFFU) /*!< Bit mask for PXP_HW_PXP_OUT_PS_ULC_Y. */
#define BS_PXP_HW_PXP_OUT_PS_ULC_Y (14U)   /*!< Bit field size in bits for PXP_HW_PXP_OUT_PS_ULC_Y. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_PS_ULC_Y field. */
#define BR_PXP_HW_PXP_OUT_PS_ULC_Y(x) (HW_PXP_HW_PXP_OUT_PS_ULC(x).B.Y)

/*! @brief Format value for bitfield PXP_HW_PXP_OUT_PS_ULC_Y. */
#define BF_PXP_HW_PXP_OUT_PS_ULC_Y(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_OUT_PS_ULC_Y) & BM_PXP_HW_PXP_OUT_PS_ULC_Y)

/*! @brief Set the Y field to a new value. */
#define BW_PXP_HW_PXP_OUT_PS_ULC_Y(x, v) (HW_PXP_HW_PXP_OUT_PS_ULC_WR(x, (HW_PXP_HW_PXP_OUT_PS_ULC_RD(x) & ~BM_PXP_HW_PXP_OUT_PS_ULC_Y) | BF_PXP_HW_PXP_OUT_PS_ULC_Y(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_PS_ULC, field RSVD0[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_PS_ULC_RSVD0 (14U) /*!< Bit position for PXP_HW_PXP_OUT_PS_ULC_RSVD0. */
#define BM_PXP_HW_PXP_OUT_PS_ULC_RSVD0 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_OUT_PS_ULC_RSVD0. */
#define BS_PXP_HW_PXP_OUT_PS_ULC_RSVD0 (2U) /*!< Bit field size in bits for PXP_HW_PXP_OUT_PS_ULC_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_PS_ULC_RSVD0 field. */
#define BR_PXP_HW_PXP_OUT_PS_ULC_RSVD0(x) (HW_PXP_HW_PXP_OUT_PS_ULC(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_PS_ULC, field X[29:16] (RW)
 *
 * This field indicates the upper left X-coordinate (in pixels) of the processed
 * surface (PS) in the output buffer.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_PS_ULC_X (16U)   /*!< Bit position for PXP_HW_PXP_OUT_PS_ULC_X. */
#define BM_PXP_HW_PXP_OUT_PS_ULC_X (0x3FFF0000U) /*!< Bit mask for PXP_HW_PXP_OUT_PS_ULC_X. */
#define BS_PXP_HW_PXP_OUT_PS_ULC_X (14U)   /*!< Bit field size in bits for PXP_HW_PXP_OUT_PS_ULC_X. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_PS_ULC_X field. */
#define BR_PXP_HW_PXP_OUT_PS_ULC_X(x) (HW_PXP_HW_PXP_OUT_PS_ULC(x).B.X)

/*! @brief Format value for bitfield PXP_HW_PXP_OUT_PS_ULC_X. */
#define BF_PXP_HW_PXP_OUT_PS_ULC_X(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_OUT_PS_ULC_X) & BM_PXP_HW_PXP_OUT_PS_ULC_X)

/*! @brief Set the X field to a new value. */
#define BW_PXP_HW_PXP_OUT_PS_ULC_X(x, v) (HW_PXP_HW_PXP_OUT_PS_ULC_WR(x, (HW_PXP_HW_PXP_OUT_PS_ULC_RD(x) & ~BM_PXP_HW_PXP_OUT_PS_ULC_X) | BF_PXP_HW_PXP_OUT_PS_ULC_X(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_PS_ULC, field RSVD1[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_PS_ULC_RSVD1 (30U) /*!< Bit position for PXP_HW_PXP_OUT_PS_ULC_RSVD1. */
#define BM_PXP_HW_PXP_OUT_PS_ULC_RSVD1 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_OUT_PS_ULC_RSVD1. */
#define BS_PXP_HW_PXP_OUT_PS_ULC_RSVD1 (2U) /*!< Bit field size in bits for PXP_HW_PXP_OUT_PS_ULC_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_PS_ULC_RSVD1 field. */
#define BR_PXP_HW_PXP_OUT_PS_ULC_RSVD1(x) (HW_PXP_HW_PXP_OUT_PS_ULC(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_OUT_PS_LRC - Processed Surface Lower Right Coordinate
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_OUT_PS_LRC - Processed Surface Lower Right Coordinate (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the lower right extent for the Processed Surface in
 * the OUTPUT buffer. This register contains the lower right coordinate of the
 * Processed Surface in the output frame buffer (in pixels). Values that are within
 * the REG_OUT_LRC[X,Y] extents are valid. The lowest valid value for these fields
 * is 0,0. Pixel locations that are greater than or equal to the PS upper left
 * coordinates, less than or equal to the PS lower right coordinates, and within
 * the REG_OUT_LRC extents will use the PS to render pixels into the output
 * buffer. EXAMPLE REG_OUT_PS_ULC_WR(0,0x03FF_03FF); // With this UL/LR pair of pixel
 * coordinates, only one pixel at OUT[X,Y]=1023,1023 will use the PS to contribute
 * to its value. REG_OUT_PS_LRC_WR(0,0x03FF_03FF);
 */
typedef union _hw_pxp_hw_pxp_out_ps_lrc
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_out_ps_lrc_bitfields
    {
        uint32_t Y : 14;               /*!< [13:0]  */
        uint32_t RSVD0 : 2;            /*!< [15:14]  */
        uint32_t X : 14;               /*!< [29:16]  */
        uint32_t RSVD1 : 2;            /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_out_ps_lrc_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_OUT_PS_LRC register
 */
/*@{*/
#define HW_PXP_HW_PXP_OUT_PS_LRC_ADDR(x) ((uintptr_t)(x) + 0x80U)

#define HW_PXP_HW_PXP_OUT_PS_LRC(x) (*(__IO hw_pxp_hw_pxp_out_ps_lrc_t *) HW_PXP_HW_PXP_OUT_PS_LRC_ADDR(x))
#define HW_PXP_HW_PXP_OUT_PS_LRC_RD(x) (HW_PXP_HW_PXP_OUT_PS_LRC(x).U)
#define HW_PXP_HW_PXP_OUT_PS_LRC_WR(x, v) (HW_PXP_HW_PXP_OUT_PS_LRC(x).U = (v))
#define HW_PXP_HW_PXP_OUT_PS_LRC_SET(x, v) (HW_PXP_HW_PXP_OUT_PS_LRC_WR(x, HW_PXP_HW_PXP_OUT_PS_LRC_RD(x) |  (v)))
#define HW_PXP_HW_PXP_OUT_PS_LRC_CLR(x, v) (HW_PXP_HW_PXP_OUT_PS_LRC_WR(x, HW_PXP_HW_PXP_OUT_PS_LRC_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_OUT_PS_LRC_TOG(x, v) (HW_PXP_HW_PXP_OUT_PS_LRC_WR(x, HW_PXP_HW_PXP_OUT_PS_LRC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_OUT_PS_LRC bitfields
 */

/*!
 * @name Register PXP_HW_PXP_OUT_PS_LRC, field Y[13:0] (RW)
 *
 * This field indicates the lower right Y-coordinate (in pixels) of the
 * processed surface in the output frame buffer.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_PS_LRC_Y (0U)    /*!< Bit position for PXP_HW_PXP_OUT_PS_LRC_Y. */
#define BM_PXP_HW_PXP_OUT_PS_LRC_Y (0x00003FFFU) /*!< Bit mask for PXP_HW_PXP_OUT_PS_LRC_Y. */
#define BS_PXP_HW_PXP_OUT_PS_LRC_Y (14U)   /*!< Bit field size in bits for PXP_HW_PXP_OUT_PS_LRC_Y. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_PS_LRC_Y field. */
#define BR_PXP_HW_PXP_OUT_PS_LRC_Y(x) (HW_PXP_HW_PXP_OUT_PS_LRC(x).B.Y)

/*! @brief Format value for bitfield PXP_HW_PXP_OUT_PS_LRC_Y. */
#define BF_PXP_HW_PXP_OUT_PS_LRC_Y(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_OUT_PS_LRC_Y) & BM_PXP_HW_PXP_OUT_PS_LRC_Y)

/*! @brief Set the Y field to a new value. */
#define BW_PXP_HW_PXP_OUT_PS_LRC_Y(x, v) (HW_PXP_HW_PXP_OUT_PS_LRC_WR(x, (HW_PXP_HW_PXP_OUT_PS_LRC_RD(x) & ~BM_PXP_HW_PXP_OUT_PS_LRC_Y) | BF_PXP_HW_PXP_OUT_PS_LRC_Y(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_PS_LRC, field RSVD0[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_PS_LRC_RSVD0 (14U) /*!< Bit position for PXP_HW_PXP_OUT_PS_LRC_RSVD0. */
#define BM_PXP_HW_PXP_OUT_PS_LRC_RSVD0 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_OUT_PS_LRC_RSVD0. */
#define BS_PXP_HW_PXP_OUT_PS_LRC_RSVD0 (2U) /*!< Bit field size in bits for PXP_HW_PXP_OUT_PS_LRC_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_PS_LRC_RSVD0 field. */
#define BR_PXP_HW_PXP_OUT_PS_LRC_RSVD0(x) (HW_PXP_HW_PXP_OUT_PS_LRC(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_PS_LRC, field X[29:16] (RW)
 *
 * This field indicates the lower right X-coordinate (in pixels) of the
 * processed surface (PS) in the output frame buffer.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_PS_LRC_X (16U)   /*!< Bit position for PXP_HW_PXP_OUT_PS_LRC_X. */
#define BM_PXP_HW_PXP_OUT_PS_LRC_X (0x3FFF0000U) /*!< Bit mask for PXP_HW_PXP_OUT_PS_LRC_X. */
#define BS_PXP_HW_PXP_OUT_PS_LRC_X (14U)   /*!< Bit field size in bits for PXP_HW_PXP_OUT_PS_LRC_X. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_PS_LRC_X field. */
#define BR_PXP_HW_PXP_OUT_PS_LRC_X(x) (HW_PXP_HW_PXP_OUT_PS_LRC(x).B.X)

/*! @brief Format value for bitfield PXP_HW_PXP_OUT_PS_LRC_X. */
#define BF_PXP_HW_PXP_OUT_PS_LRC_X(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_OUT_PS_LRC_X) & BM_PXP_HW_PXP_OUT_PS_LRC_X)

/*! @brief Set the X field to a new value. */
#define BW_PXP_HW_PXP_OUT_PS_LRC_X(x, v) (HW_PXP_HW_PXP_OUT_PS_LRC_WR(x, (HW_PXP_HW_PXP_OUT_PS_LRC_RD(x) & ~BM_PXP_HW_PXP_OUT_PS_LRC_X) | BF_PXP_HW_PXP_OUT_PS_LRC_X(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_PS_LRC, field RSVD1[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_PS_LRC_RSVD1 (30U) /*!< Bit position for PXP_HW_PXP_OUT_PS_LRC_RSVD1. */
#define BM_PXP_HW_PXP_OUT_PS_LRC_RSVD1 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_OUT_PS_LRC_RSVD1. */
#define BS_PXP_HW_PXP_OUT_PS_LRC_RSVD1 (2U) /*!< Bit field size in bits for PXP_HW_PXP_OUT_PS_LRC_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_PS_LRC_RSVD1 field. */
#define BR_PXP_HW_PXP_OUT_PS_LRC_RSVD1(x) (HW_PXP_HW_PXP_OUT_PS_LRC(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_OUT_AS_ULC - Alpha Surface Upper Left Coordinate
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_OUT_AS_ULC - Alpha Surface Upper Left Coordinate (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the upper left location for the Alpha Surface in the
 * output buffer. This register contains the upper left coordinate of AS in the
 * output frame buffer (in pixels). Values that are within the REG_OUT_LRC[X,Y]
 * extents are valid. The lowest valid value for these fields is 0,0. Pixel
 * locations that are greater than or equal to the upper left coordinates will use the AS
 * to render pixels in the output buffer. EXAMPLE
 * REG_OUT_AS_ULC_WR(0,0x0001_0001); // Alpha Surface upper left coordinate at (X,Y) = 1,1. The AS surface will
 * not effect pixels in the first row or first column of the output buffer.
 */
typedef union _hw_pxp_hw_pxp_out_as_ulc
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_out_as_ulc_bitfields
    {
        uint32_t Y : 14;               /*!< [13:0]  */
        uint32_t RSVD0 : 2;            /*!< [15:14]  */
        uint32_t X : 14;               /*!< [29:16]  */
        uint32_t RSVD1 : 2;            /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_out_as_ulc_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_OUT_AS_ULC register
 */
/*@{*/
#define HW_PXP_HW_PXP_OUT_AS_ULC_ADDR(x) ((uintptr_t)(x) + 0x90U)

#define HW_PXP_HW_PXP_OUT_AS_ULC(x) (*(__IO hw_pxp_hw_pxp_out_as_ulc_t *) HW_PXP_HW_PXP_OUT_AS_ULC_ADDR(x))
#define HW_PXP_HW_PXP_OUT_AS_ULC_RD(x) (HW_PXP_HW_PXP_OUT_AS_ULC(x).U)
#define HW_PXP_HW_PXP_OUT_AS_ULC_WR(x, v) (HW_PXP_HW_PXP_OUT_AS_ULC(x).U = (v))
#define HW_PXP_HW_PXP_OUT_AS_ULC_SET(x, v) (HW_PXP_HW_PXP_OUT_AS_ULC_WR(x, HW_PXP_HW_PXP_OUT_AS_ULC_RD(x) |  (v)))
#define HW_PXP_HW_PXP_OUT_AS_ULC_CLR(x, v) (HW_PXP_HW_PXP_OUT_AS_ULC_WR(x, HW_PXP_HW_PXP_OUT_AS_ULC_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_OUT_AS_ULC_TOG(x, v) (HW_PXP_HW_PXP_OUT_AS_ULC_WR(x, HW_PXP_HW_PXP_OUT_AS_ULC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_OUT_AS_ULC bitfields
 */

/*!
 * @name Register PXP_HW_PXP_OUT_AS_ULC, field Y[13:0] (RW)
 *
 * This field indicates the upper left Y-coordinate (in pixels) of the alpha
 * surface in the output frame buffer.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_AS_ULC_Y (0U)    /*!< Bit position for PXP_HW_PXP_OUT_AS_ULC_Y. */
#define BM_PXP_HW_PXP_OUT_AS_ULC_Y (0x00003FFFU) /*!< Bit mask for PXP_HW_PXP_OUT_AS_ULC_Y. */
#define BS_PXP_HW_PXP_OUT_AS_ULC_Y (14U)   /*!< Bit field size in bits for PXP_HW_PXP_OUT_AS_ULC_Y. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_AS_ULC_Y field. */
#define BR_PXP_HW_PXP_OUT_AS_ULC_Y(x) (HW_PXP_HW_PXP_OUT_AS_ULC(x).B.Y)

/*! @brief Format value for bitfield PXP_HW_PXP_OUT_AS_ULC_Y. */
#define BF_PXP_HW_PXP_OUT_AS_ULC_Y(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_OUT_AS_ULC_Y) & BM_PXP_HW_PXP_OUT_AS_ULC_Y)

/*! @brief Set the Y field to a new value. */
#define BW_PXP_HW_PXP_OUT_AS_ULC_Y(x, v) (HW_PXP_HW_PXP_OUT_AS_ULC_WR(x, (HW_PXP_HW_PXP_OUT_AS_ULC_RD(x) & ~BM_PXP_HW_PXP_OUT_AS_ULC_Y) | BF_PXP_HW_PXP_OUT_AS_ULC_Y(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_AS_ULC, field RSVD0[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_AS_ULC_RSVD0 (14U) /*!< Bit position for PXP_HW_PXP_OUT_AS_ULC_RSVD0. */
#define BM_PXP_HW_PXP_OUT_AS_ULC_RSVD0 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_OUT_AS_ULC_RSVD0. */
#define BS_PXP_HW_PXP_OUT_AS_ULC_RSVD0 (2U) /*!< Bit field size in bits for PXP_HW_PXP_OUT_AS_ULC_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_AS_ULC_RSVD0 field. */
#define BR_PXP_HW_PXP_OUT_AS_ULC_RSVD0(x) (HW_PXP_HW_PXP_OUT_AS_ULC(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_AS_ULC, field X[29:16] (RW)
 *
 * This field indicates the upper left X-coordinate (in pixels) of the alpha
 * surface (AS) in the output frame buffer.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_AS_ULC_X (16U)   /*!< Bit position for PXP_HW_PXP_OUT_AS_ULC_X. */
#define BM_PXP_HW_PXP_OUT_AS_ULC_X (0x3FFF0000U) /*!< Bit mask for PXP_HW_PXP_OUT_AS_ULC_X. */
#define BS_PXP_HW_PXP_OUT_AS_ULC_X (14U)   /*!< Bit field size in bits for PXP_HW_PXP_OUT_AS_ULC_X. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_AS_ULC_X field. */
#define BR_PXP_HW_PXP_OUT_AS_ULC_X(x) (HW_PXP_HW_PXP_OUT_AS_ULC(x).B.X)

/*! @brief Format value for bitfield PXP_HW_PXP_OUT_AS_ULC_X. */
#define BF_PXP_HW_PXP_OUT_AS_ULC_X(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_OUT_AS_ULC_X) & BM_PXP_HW_PXP_OUT_AS_ULC_X)

/*! @brief Set the X field to a new value. */
#define BW_PXP_HW_PXP_OUT_AS_ULC_X(x, v) (HW_PXP_HW_PXP_OUT_AS_ULC_WR(x, (HW_PXP_HW_PXP_OUT_AS_ULC_RD(x) & ~BM_PXP_HW_PXP_OUT_AS_ULC_X) | BF_PXP_HW_PXP_OUT_AS_ULC_X(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_AS_ULC, field RSVD1[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_AS_ULC_RSVD1 (30U) /*!< Bit position for PXP_HW_PXP_OUT_AS_ULC_RSVD1. */
#define BM_PXP_HW_PXP_OUT_AS_ULC_RSVD1 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_OUT_AS_ULC_RSVD1. */
#define BS_PXP_HW_PXP_OUT_AS_ULC_RSVD1 (2U) /*!< Bit field size in bits for PXP_HW_PXP_OUT_AS_ULC_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_AS_ULC_RSVD1 field. */
#define BR_PXP_HW_PXP_OUT_AS_ULC_RSVD1(x) (HW_PXP_HW_PXP_OUT_AS_ULC(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_OUT_AS_LRC - Alpha Surface Lower Right Coordinate
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_OUT_AS_LRC - Alpha Surface Lower Right Coordinate (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the lower right extent for Alpha Surface in the output
 * buffer. This register contains the lower right coordinate of AS in the output
 * frame buffer (in pixels). Values that are within the REG_OUT_LRC[X,Y] extents
 * are valid. The lowest valid value for these fields is 0,0. Pixel locations
 * that are less than or equal to the lower right coordinates will use the AS to
 * render pixels in the output buffer. EXAMPLE REG_AS_LRC_WR(0,0x03FF_03FF); //
 * Alpha Surface lower right coordinate at (X,Y) = 1023,1023.
 */
typedef union _hw_pxp_hw_pxp_out_as_lrc
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_out_as_lrc_bitfields
    {
        uint32_t Y : 14;               /*!< [13:0]  */
        uint32_t RSVD0 : 2;            /*!< [15:14]  */
        uint32_t X : 14;               /*!< [29:16]  */
        uint32_t RSVD1 : 2;            /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_out_as_lrc_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_OUT_AS_LRC register
 */
/*@{*/
#define HW_PXP_HW_PXP_OUT_AS_LRC_ADDR(x) ((uintptr_t)(x) + 0xA0U)

#define HW_PXP_HW_PXP_OUT_AS_LRC(x) (*(__IO hw_pxp_hw_pxp_out_as_lrc_t *) HW_PXP_HW_PXP_OUT_AS_LRC_ADDR(x))
#define HW_PXP_HW_PXP_OUT_AS_LRC_RD(x) (HW_PXP_HW_PXP_OUT_AS_LRC(x).U)
#define HW_PXP_HW_PXP_OUT_AS_LRC_WR(x, v) (HW_PXP_HW_PXP_OUT_AS_LRC(x).U = (v))
#define HW_PXP_HW_PXP_OUT_AS_LRC_SET(x, v) (HW_PXP_HW_PXP_OUT_AS_LRC_WR(x, HW_PXP_HW_PXP_OUT_AS_LRC_RD(x) |  (v)))
#define HW_PXP_HW_PXP_OUT_AS_LRC_CLR(x, v) (HW_PXP_HW_PXP_OUT_AS_LRC_WR(x, HW_PXP_HW_PXP_OUT_AS_LRC_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_OUT_AS_LRC_TOG(x, v) (HW_PXP_HW_PXP_OUT_AS_LRC_WR(x, HW_PXP_HW_PXP_OUT_AS_LRC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_OUT_AS_LRC bitfields
 */

/*!
 * @name Register PXP_HW_PXP_OUT_AS_LRC, field Y[13:0] (RW)
 *
 * This field indicates the lower right Y-coordinate (in pixels) of the alpha
 * surface in the output frame buffer.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_AS_LRC_Y (0U)    /*!< Bit position for PXP_HW_PXP_OUT_AS_LRC_Y. */
#define BM_PXP_HW_PXP_OUT_AS_LRC_Y (0x00003FFFU) /*!< Bit mask for PXP_HW_PXP_OUT_AS_LRC_Y. */
#define BS_PXP_HW_PXP_OUT_AS_LRC_Y (14U)   /*!< Bit field size in bits for PXP_HW_PXP_OUT_AS_LRC_Y. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_AS_LRC_Y field. */
#define BR_PXP_HW_PXP_OUT_AS_LRC_Y(x) (HW_PXP_HW_PXP_OUT_AS_LRC(x).B.Y)

/*! @brief Format value for bitfield PXP_HW_PXP_OUT_AS_LRC_Y. */
#define BF_PXP_HW_PXP_OUT_AS_LRC_Y(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_OUT_AS_LRC_Y) & BM_PXP_HW_PXP_OUT_AS_LRC_Y)

/*! @brief Set the Y field to a new value. */
#define BW_PXP_HW_PXP_OUT_AS_LRC_Y(x, v) (HW_PXP_HW_PXP_OUT_AS_LRC_WR(x, (HW_PXP_HW_PXP_OUT_AS_LRC_RD(x) & ~BM_PXP_HW_PXP_OUT_AS_LRC_Y) | BF_PXP_HW_PXP_OUT_AS_LRC_Y(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_AS_LRC, field RSVD0[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_AS_LRC_RSVD0 (14U) /*!< Bit position for PXP_HW_PXP_OUT_AS_LRC_RSVD0. */
#define BM_PXP_HW_PXP_OUT_AS_LRC_RSVD0 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_OUT_AS_LRC_RSVD0. */
#define BS_PXP_HW_PXP_OUT_AS_LRC_RSVD0 (2U) /*!< Bit field size in bits for PXP_HW_PXP_OUT_AS_LRC_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_AS_LRC_RSVD0 field. */
#define BR_PXP_HW_PXP_OUT_AS_LRC_RSVD0(x) (HW_PXP_HW_PXP_OUT_AS_LRC(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_AS_LRC, field X[29:16] (RW)
 *
 * This field indicates the lower right X-coordinate (in pixels) of the alpha
 * surface (AS) in the output frame buffer.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_AS_LRC_X (16U)   /*!< Bit position for PXP_HW_PXP_OUT_AS_LRC_X. */
#define BM_PXP_HW_PXP_OUT_AS_LRC_X (0x3FFF0000U) /*!< Bit mask for PXP_HW_PXP_OUT_AS_LRC_X. */
#define BS_PXP_HW_PXP_OUT_AS_LRC_X (14U)   /*!< Bit field size in bits for PXP_HW_PXP_OUT_AS_LRC_X. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_AS_LRC_X field. */
#define BR_PXP_HW_PXP_OUT_AS_LRC_X(x) (HW_PXP_HW_PXP_OUT_AS_LRC(x).B.X)

/*! @brief Format value for bitfield PXP_HW_PXP_OUT_AS_LRC_X. */
#define BF_PXP_HW_PXP_OUT_AS_LRC_X(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_OUT_AS_LRC_X) & BM_PXP_HW_PXP_OUT_AS_LRC_X)

/*! @brief Set the X field to a new value. */
#define BW_PXP_HW_PXP_OUT_AS_LRC_X(x, v) (HW_PXP_HW_PXP_OUT_AS_LRC_WR(x, (HW_PXP_HW_PXP_OUT_AS_LRC_RD(x) & ~BM_PXP_HW_PXP_OUT_AS_LRC_X) | BF_PXP_HW_PXP_OUT_AS_LRC_X(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_OUT_AS_LRC, field RSVD1[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_OUT_AS_LRC_RSVD1 (30U) /*!< Bit position for PXP_HW_PXP_OUT_AS_LRC_RSVD1. */
#define BM_PXP_HW_PXP_OUT_AS_LRC_RSVD1 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_OUT_AS_LRC_RSVD1. */
#define BS_PXP_HW_PXP_OUT_AS_LRC_RSVD1 (2U) /*!< Bit field size in bits for PXP_HW_PXP_OUT_AS_LRC_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_OUT_AS_LRC_RSVD1 field. */
#define BR_PXP_HW_PXP_OUT_AS_LRC_RSVD1(x) (HW_PXP_HW_PXP_OUT_AS_LRC(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_PS_CTRL - Processed Surface (PS) Control Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_PS_CTRL - Processed Surface (PS) Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The PS_CTRL register contains controls for the Processed Surface Buffer.
 * HW_PXP_PS_CTRL: 0x0B0 HW_PXP_PS_CTRL_SET: 0x0b4 HW_PXP_PS_CTRL_CLR: 0x0B8
 * HW_PXP_PS_CTRL_TOG: 0x0BC Control register to determine PS buffer processing. EXAMPLE
 * REG_CTRL_SET(BM_PXP_CTRL_SFTRST); REG_CTRL_CLR(BM_PXP_CTRL_SFTRST |
 * BM_PXP_CTRL_CLKGATE);
 */
typedef union _hw_pxp_hw_pxp_ps_ctrl
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_ps_ctrl_bitfields
    {
        uint32_t FORMAT : 6;           /*!< [5:0]  */
        uint32_t WB_SWAP : 1;          /*!< [6]  */
        uint32_t RSVD0 : 1;            /*!< [7]  */
        uint32_t DECY : 2;             /*!< [9:8]  */
        uint32_t DECX : 2;             /*!< [11:10]  */
        uint32_t RSVD1 : 20;           /*!< [31:12]  */
    } B;
} hw_pxp_hw_pxp_ps_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_PS_CTRL register
 */
/*@{*/
#define HW_PXP_HW_PXP_PS_CTRL_ADDR(x) ((uintptr_t)(x) + 0xB0U)

#define HW_PXP_HW_PXP_PS_CTRL(x) (*(__IO hw_pxp_hw_pxp_ps_ctrl_t *) HW_PXP_HW_PXP_PS_CTRL_ADDR(x))
#define HW_PXP_HW_PXP_PS_CTRL_RD(x) (HW_PXP_HW_PXP_PS_CTRL(x).U)
#define HW_PXP_HW_PXP_PS_CTRL_WR(x, v) (HW_PXP_HW_PXP_PS_CTRL(x).U = (v))
#define HW_PXP_HW_PXP_PS_CTRL_SET(x, v) (HW_PXP_HW_PXP_PS_CTRL_WR(x, HW_PXP_HW_PXP_PS_CTRL_RD(x) |  (v)))
#define HW_PXP_HW_PXP_PS_CTRL_CLR(x, v) (HW_PXP_HW_PXP_PS_CTRL_WR(x, HW_PXP_HW_PXP_PS_CTRL_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_PS_CTRL_TOG(x, v) (HW_PXP_HW_PXP_PS_CTRL_WR(x, HW_PXP_HW_PXP_PS_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_PS_CTRL bitfields
 */

/*!
 * @name Register PXP_HW_PXP_PS_CTRL, field FORMAT[5:0] (RW)
 *
 * PS buffer format. To select between YUV and YCbCr formats, see bit 31 of the
 * CSC1_COEF0 register.
 *
 * Values:
 * - 100 - 32-bit pixels (unpacked 24-bit format)
 * - 1100 - 16-bit pixels
 * - 1101 - 16-bit pixels
 * - 1110 - 16-bit pixels
 * - 10000 - 32-bit pixels (1-plane XYUV unpacked)
 * - 10010 - 16-bit pixels (1-plane U0,Y0,V0,Y1 interleaved bytes)
 * - 10011 - 16-bit pixels (1-plane V0,Y0,U0,Y1 interleaved bytes)
 * - 10100 - 8-bit monochrome pixels (1-plane Y luma output)
 * - 10101 - 4-bit monochrome pixels (1-plane Y luma, 4 bit truncation)
 * - 11000 - 16-bit pixels (2-plane UV interleaved bytes)
 * - 11001 - 16-bit pixels (2-plane UV)
 * - 11010 - 16-bit pixels (2-plane VU interleaved bytes)
 * - 11011 - 16-bit pixels (2-plane VU)
 * - 11110 - 16-bit pixels (3-plane format)
 * - 11111 - 16-bit pixels (3-plane format)
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_CTRL_FORMAT (0U)  /*!< Bit position for PXP_HW_PXP_PS_CTRL_FORMAT. */
#define BM_PXP_HW_PXP_PS_CTRL_FORMAT (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_PS_CTRL_FORMAT. */
#define BS_PXP_HW_PXP_PS_CTRL_FORMAT (6U)  /*!< Bit field size in bits for PXP_HW_PXP_PS_CTRL_FORMAT. */

#define BV_PXP_HW_PXP_PS_CTRL_FORMAT_RGB888 (0x4U)   /*!< Bit field value for PXP_HW_PXP_PS_CTRL_FORMAT: 32-bit pixels (unpacked 24-bit format) */
#define BV_PXP_HW_PXP_PS_CTRL_FORMAT_RGB555 (0xCU)   /*!< Bit field value for PXP_HW_PXP_PS_CTRL_FORMAT: 16-bit pixels */
#define BV_PXP_HW_PXP_PS_CTRL_FORMAT_RGB444 (0xDU)   /*!< Bit field value for PXP_HW_PXP_PS_CTRL_FORMAT: 16-bit pixels */
#define BV_PXP_HW_PXP_PS_CTRL_FORMAT_RGB565 (0xEU)   /*!< Bit field value for PXP_HW_PXP_PS_CTRL_FORMAT: 16-bit pixels */
#define BV_PXP_HW_PXP_PS_CTRL_FORMAT_YUV1P444 (0x10U) /*!< Bit field value for PXP_HW_PXP_PS_CTRL_FORMAT: 32-bit pixels (1-plane XYUV unpacked) */
#define BV_PXP_HW_PXP_PS_CTRL_FORMAT_UYVY1P422 (0x12U) /*!< Bit field value for PXP_HW_PXP_PS_CTRL_FORMAT: 16-bit pixels (1-plane U0,Y0,V0,Y1 interleaved bytes) */
#define BV_PXP_HW_PXP_PS_CTRL_FORMAT_VYUY1P422 (0x13U) /*!< Bit field value for PXP_HW_PXP_PS_CTRL_FORMAT: 16-bit pixels (1-plane V0,Y0,U0,Y1 interleaved bytes) */
#define BV_PXP_HW_PXP_PS_CTRL_FORMAT_Y8 (0x14U)      /*!< Bit field value for PXP_HW_PXP_PS_CTRL_FORMAT: 8-bit monochrome pixels (1-plane Y luma output) */
#define BV_PXP_HW_PXP_PS_CTRL_FORMAT_Y4 (0x15U)      /*!< Bit field value for PXP_HW_PXP_PS_CTRL_FORMAT: 4-bit monochrome pixels (1-plane Y luma, 4 bit truncation) */
#define BV_PXP_HW_PXP_PS_CTRL_FORMAT_YUV2P422 (0x18U) /*!< Bit field value for PXP_HW_PXP_PS_CTRL_FORMAT: 16-bit pixels (2-plane UV interleaved bytes) */
#define BV_PXP_HW_PXP_PS_CTRL_FORMAT_YUV2P420 (0x19U) /*!< Bit field value for PXP_HW_PXP_PS_CTRL_FORMAT: 16-bit pixels (2-plane UV) */
#define BV_PXP_HW_PXP_PS_CTRL_FORMAT_YVU2P422 (0x1AU) /*!< Bit field value for PXP_HW_PXP_PS_CTRL_FORMAT: 16-bit pixels (2-plane VU interleaved bytes) */
#define BV_PXP_HW_PXP_PS_CTRL_FORMAT_YVU2P420 (0x1BU) /*!< Bit field value for PXP_HW_PXP_PS_CTRL_FORMAT: 16-bit pixels (2-plane VU) */
#define BV_PXP_HW_PXP_PS_CTRL_FORMAT_YUV422 (0x1EU)  /*!< Bit field value for PXP_HW_PXP_PS_CTRL_FORMAT: 16-bit pixels (3-plane format) */
#define BV_PXP_HW_PXP_PS_CTRL_FORMAT_YUV420 (0x1FU)  /*!< Bit field value for PXP_HW_PXP_PS_CTRL_FORMAT: 16-bit pixels (3-plane format) */

/*! @brief Read current value of the PXP_HW_PXP_PS_CTRL_FORMAT field. */
#define BR_PXP_HW_PXP_PS_CTRL_FORMAT(x) (HW_PXP_HW_PXP_PS_CTRL(x).B.FORMAT)

/*! @brief Format value for bitfield PXP_HW_PXP_PS_CTRL_FORMAT. */
#define BF_PXP_HW_PXP_PS_CTRL_FORMAT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_PS_CTRL_FORMAT) & BM_PXP_HW_PXP_PS_CTRL_FORMAT)

/*! @brief Set the FORMAT field to a new value. */
#define BW_PXP_HW_PXP_PS_CTRL_FORMAT(x, v) (HW_PXP_HW_PXP_PS_CTRL_WR(x, (HW_PXP_HW_PXP_PS_CTRL_RD(x) & ~BM_PXP_HW_PXP_PS_CTRL_FORMAT) | BF_PXP_HW_PXP_PS_CTRL_FORMAT(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_PS_CTRL, field WB_SWAP[6] (RW)
 *
 * Swap bytes in words. For each 16 bit word, the two bytes will be swapped.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_CTRL_WB_SWAP (6U) /*!< Bit position for PXP_HW_PXP_PS_CTRL_WB_SWAP. */
#define BM_PXP_HW_PXP_PS_CTRL_WB_SWAP (0x00000040U) /*!< Bit mask for PXP_HW_PXP_PS_CTRL_WB_SWAP. */
#define BS_PXP_HW_PXP_PS_CTRL_WB_SWAP (1U) /*!< Bit field size in bits for PXP_HW_PXP_PS_CTRL_WB_SWAP. */

/*! @brief Read current value of the PXP_HW_PXP_PS_CTRL_WB_SWAP field. */
#define BR_PXP_HW_PXP_PS_CTRL_WB_SWAP(x) (HW_PXP_HW_PXP_PS_CTRL(x).B.WB_SWAP)

/*! @brief Format value for bitfield PXP_HW_PXP_PS_CTRL_WB_SWAP. */
#define BF_PXP_HW_PXP_PS_CTRL_WB_SWAP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_PS_CTRL_WB_SWAP) & BM_PXP_HW_PXP_PS_CTRL_WB_SWAP)

/*! @brief Set the WB_SWAP field to a new value. */
#define BW_PXP_HW_PXP_PS_CTRL_WB_SWAP(x, v) (HW_PXP_HW_PXP_PS_CTRL_WR(x, (HW_PXP_HW_PXP_PS_CTRL_RD(x) & ~BM_PXP_HW_PXP_PS_CTRL_WB_SWAP) | BF_PXP_HW_PXP_PS_CTRL_WB_SWAP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_PS_CTRL, field RSVD0[7] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_CTRL_RSVD0 (7U)   /*!< Bit position for PXP_HW_PXP_PS_CTRL_RSVD0. */
#define BM_PXP_HW_PXP_PS_CTRL_RSVD0 (0x00000080U) /*!< Bit mask for PXP_HW_PXP_PS_CTRL_RSVD0. */
#define BS_PXP_HW_PXP_PS_CTRL_RSVD0 (1U)   /*!< Bit field size in bits for PXP_HW_PXP_PS_CTRL_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_PS_CTRL_RSVD0 field. */
#define BR_PXP_HW_PXP_PS_CTRL_RSVD0(x) (HW_PXP_HW_PXP_PS_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_PS_CTRL, field DECY[9:8] (RW)
 *
 * Verticle pre decimation filter control.
 *
 * Values:
 * - 0 - Disable pre-decimation filter.
 * - 1 - Decimate PS by 2.
 * - 10 - Decimate PS by 4.
 * - 11 - Decimate PS by 8.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_CTRL_DECY (8U)    /*!< Bit position for PXP_HW_PXP_PS_CTRL_DECY. */
#define BM_PXP_HW_PXP_PS_CTRL_DECY (0x00000300U) /*!< Bit mask for PXP_HW_PXP_PS_CTRL_DECY. */
#define BS_PXP_HW_PXP_PS_CTRL_DECY (2U)    /*!< Bit field size in bits for PXP_HW_PXP_PS_CTRL_DECY. */

#define BV_PXP_HW_PXP_PS_CTRL_DECY_DISABLE (0U)      /*!< Bit field value for PXP_HW_PXP_PS_CTRL_DECY: Disable pre-decimation filter. */
#define BV_PXP_HW_PXP_PS_CTRL_DECY_DECY2 (0x1U)      /*!< Bit field value for PXP_HW_PXP_PS_CTRL_DECY: Decimate PS by 2. */
#define BV_PXP_HW_PXP_PS_CTRL_DECY_DECY4 (0x2U)      /*!< Bit field value for PXP_HW_PXP_PS_CTRL_DECY: Decimate PS by 4. */
#define BV_PXP_HW_PXP_PS_CTRL_DECY_DECY8 (0x3U)      /*!< Bit field value for PXP_HW_PXP_PS_CTRL_DECY: Decimate PS by 8. */

/*! @brief Read current value of the PXP_HW_PXP_PS_CTRL_DECY field. */
#define BR_PXP_HW_PXP_PS_CTRL_DECY(x) (HW_PXP_HW_PXP_PS_CTRL(x).B.DECY)

/*! @brief Format value for bitfield PXP_HW_PXP_PS_CTRL_DECY. */
#define BF_PXP_HW_PXP_PS_CTRL_DECY(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_PS_CTRL_DECY) & BM_PXP_HW_PXP_PS_CTRL_DECY)

/*! @brief Set the DECY field to a new value. */
#define BW_PXP_HW_PXP_PS_CTRL_DECY(x, v) (HW_PXP_HW_PXP_PS_CTRL_WR(x, (HW_PXP_HW_PXP_PS_CTRL_RD(x) & ~BM_PXP_HW_PXP_PS_CTRL_DECY) | BF_PXP_HW_PXP_PS_CTRL_DECY(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_PS_CTRL, field DECX[11:10] (RW)
 *
 * Horizontal pre decimation filter control.
 *
 * Values:
 * - 0 - Disable pre-decimation filter.
 * - 1 - Decimate PS by 2.
 * - 10 - Decimate PS by 4.
 * - 11 - Decimate PS by 8.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_CTRL_DECX (10U)   /*!< Bit position for PXP_HW_PXP_PS_CTRL_DECX. */
#define BM_PXP_HW_PXP_PS_CTRL_DECX (0x00000C00U) /*!< Bit mask for PXP_HW_PXP_PS_CTRL_DECX. */
#define BS_PXP_HW_PXP_PS_CTRL_DECX (2U)    /*!< Bit field size in bits for PXP_HW_PXP_PS_CTRL_DECX. */

#define BV_PXP_HW_PXP_PS_CTRL_DECX_DISABLE (0U)      /*!< Bit field value for PXP_HW_PXP_PS_CTRL_DECX: Disable pre-decimation filter. */
#define BV_PXP_HW_PXP_PS_CTRL_DECX_DECX2 (0x1U)      /*!< Bit field value for PXP_HW_PXP_PS_CTRL_DECX: Decimate PS by 2. */
#define BV_PXP_HW_PXP_PS_CTRL_DECX_DECX4 (0x2U)      /*!< Bit field value for PXP_HW_PXP_PS_CTRL_DECX: Decimate PS by 4. */
#define BV_PXP_HW_PXP_PS_CTRL_DECX_DECX8 (0x3U)      /*!< Bit field value for PXP_HW_PXP_PS_CTRL_DECX: Decimate PS by 8. */

/*! @brief Read current value of the PXP_HW_PXP_PS_CTRL_DECX field. */
#define BR_PXP_HW_PXP_PS_CTRL_DECX(x) (HW_PXP_HW_PXP_PS_CTRL(x).B.DECX)

/*! @brief Format value for bitfield PXP_HW_PXP_PS_CTRL_DECX. */
#define BF_PXP_HW_PXP_PS_CTRL_DECX(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_PS_CTRL_DECX) & BM_PXP_HW_PXP_PS_CTRL_DECX)

/*! @brief Set the DECX field to a new value. */
#define BW_PXP_HW_PXP_PS_CTRL_DECX(x, v) (HW_PXP_HW_PXP_PS_CTRL_WR(x, (HW_PXP_HW_PXP_PS_CTRL_RD(x) & ~BM_PXP_HW_PXP_PS_CTRL_DECX) | BF_PXP_HW_PXP_PS_CTRL_DECX(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_PS_CTRL, field RSVD1[31:12] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_CTRL_RSVD1 (12U)  /*!< Bit position for PXP_HW_PXP_PS_CTRL_RSVD1. */
#define BM_PXP_HW_PXP_PS_CTRL_RSVD1 (0xFFFFF000U) /*!< Bit mask for PXP_HW_PXP_PS_CTRL_RSVD1. */
#define BS_PXP_HW_PXP_PS_CTRL_RSVD1 (20U)  /*!< Bit field size in bits for PXP_HW_PXP_PS_CTRL_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_PS_CTRL_RSVD1 field. */
#define BR_PXP_HW_PXP_PS_CTRL_RSVD1(x) (HW_PXP_HW_PXP_PS_CTRL(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_PS_BUF - PS Input Buffer Address
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_PS_BUF - PS Input Buffer Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * PS Input Buffer Address. This should be programmed to the starting address of
 * the RGB data or Y (luma) data for the PS plane. This register contains the
 * pointer to the Luma/RGB buffer. If the application requires an offset into the
 * PS buffer, then this address can be set so that the desired offset is achieved.
 * Any byte address is valid. For best performance, 64B alignment is
 * recommended. EXAMPLE REG_PS_BUF_WR(image_rgb); // RGB image REG_PS_BUF_WR(image_y); // Y
 * (luma) image data REG_PS_UBUF_WR(image_u); // U (Cb) image data
 * REG_PS_VBUF_WR(image_v); // V (Cr) image data
 */
typedef union _hw_pxp_hw_pxp_ps_buf
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_ps_buf_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_ps_buf_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_PS_BUF register
 */
/*@{*/
#define HW_PXP_HW_PXP_PS_BUF_ADDR(x) ((uintptr_t)(x) + 0xC0U)

#define HW_PXP_HW_PXP_PS_BUF(x)  (*(__IO hw_pxp_hw_pxp_ps_buf_t *) HW_PXP_HW_PXP_PS_BUF_ADDR(x))
#define HW_PXP_HW_PXP_PS_BUF_RD(x) (HW_PXP_HW_PXP_PS_BUF(x).U)
#define HW_PXP_HW_PXP_PS_BUF_WR(x, v) (HW_PXP_HW_PXP_PS_BUF(x).U = (v))
#define HW_PXP_HW_PXP_PS_BUF_SET(x, v) (HW_PXP_HW_PXP_PS_BUF_WR(x, HW_PXP_HW_PXP_PS_BUF_RD(x) |  (v)))
#define HW_PXP_HW_PXP_PS_BUF_CLR(x, v) (HW_PXP_HW_PXP_PS_BUF_WR(x, HW_PXP_HW_PXP_PS_BUF_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_PS_BUF_TOG(x, v) (HW_PXP_HW_PXP_PS_BUF_WR(x, HW_PXP_HW_PXP_PS_BUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_PS_BUF bitfields
 */

/*!
 * @name Register PXP_HW_PXP_PS_BUF, field ADDR[31:0] (RW)
 *
 * Address pointer for the PS RGB or Y (luma) input buffer.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_BUF_ADDR (0U)     /*!< Bit position for PXP_HW_PXP_PS_BUF_ADDR. */
#define BM_PXP_HW_PXP_PS_BUF_ADDR (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_PS_BUF_ADDR. */
#define BS_PXP_HW_PXP_PS_BUF_ADDR (32U)    /*!< Bit field size in bits for PXP_HW_PXP_PS_BUF_ADDR. */

/*! @brief Read current value of the PXP_HW_PXP_PS_BUF_ADDR field. */
#define BR_PXP_HW_PXP_PS_BUF_ADDR(x) (HW_PXP_HW_PXP_PS_BUF(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_PS_BUF_ADDR. */
#define BF_PXP_HW_PXP_PS_BUF_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_PS_BUF_ADDR) & BM_PXP_HW_PXP_PS_BUF_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_PXP_HW_PXP_PS_BUF_ADDR(x, v) (HW_PXP_HW_PXP_PS_BUF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_PS_UBUF - PS U/Cb or 2 Plane UV Input Buffer Address
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_PS_UBUF - PS U/Cb or 2 Plane UV Input Buffer Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * PS Chroma (U/Cb/UV) Input Buffer Address. This register points to the
 * beginning of the PS U/Cb input buffer. In two plane operation, this register points
 * to the beginning of the PS UV chroma input buffer. This register contains the
 * pointer to the Chroma U/Cb or 2 plane UV buffer. This register is unused when
 * processing 1-plane buffer formats. If the application requires an offset into
 * the PS buffer, then this address can be set so that the desired offset is
 * achieved. Any byte address is valid. For best performance, 64B alignment is
 * recommended. EXAMPLE REG_PS_BUF_WR(image_y); // Y (luma) image data
 * REG_PS_UBUF_WR(image_u); // U (Cb) image data REG_PS_VBUF_WR(image_v); // V (Cr) image data
 */
typedef union _hw_pxp_hw_pxp_ps_ubuf
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_ps_ubuf_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_ps_ubuf_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_PS_UBUF register
 */
/*@{*/
#define HW_PXP_HW_PXP_PS_UBUF_ADDR(x) ((uintptr_t)(x) + 0xD0U)

#define HW_PXP_HW_PXP_PS_UBUF(x) (*(__IO hw_pxp_hw_pxp_ps_ubuf_t *) HW_PXP_HW_PXP_PS_UBUF_ADDR(x))
#define HW_PXP_HW_PXP_PS_UBUF_RD(x) (HW_PXP_HW_PXP_PS_UBUF(x).U)
#define HW_PXP_HW_PXP_PS_UBUF_WR(x, v) (HW_PXP_HW_PXP_PS_UBUF(x).U = (v))
#define HW_PXP_HW_PXP_PS_UBUF_SET(x, v) (HW_PXP_HW_PXP_PS_UBUF_WR(x, HW_PXP_HW_PXP_PS_UBUF_RD(x) |  (v)))
#define HW_PXP_HW_PXP_PS_UBUF_CLR(x, v) (HW_PXP_HW_PXP_PS_UBUF_WR(x, HW_PXP_HW_PXP_PS_UBUF_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_PS_UBUF_TOG(x, v) (HW_PXP_HW_PXP_PS_UBUF_WR(x, HW_PXP_HW_PXP_PS_UBUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_PS_UBUF bitfields
 */

/*!
 * @name Register PXP_HW_PXP_PS_UBUF, field ADDR[31:0] (RW)
 *
 * Address pointer for the PS U/Cb or 2 plane UV Chroma input buffer.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_UBUF_ADDR (0U)    /*!< Bit position for PXP_HW_PXP_PS_UBUF_ADDR. */
#define BM_PXP_HW_PXP_PS_UBUF_ADDR (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_PS_UBUF_ADDR. */
#define BS_PXP_HW_PXP_PS_UBUF_ADDR (32U)   /*!< Bit field size in bits for PXP_HW_PXP_PS_UBUF_ADDR. */

/*! @brief Read current value of the PXP_HW_PXP_PS_UBUF_ADDR field. */
#define BR_PXP_HW_PXP_PS_UBUF_ADDR(x) (HW_PXP_HW_PXP_PS_UBUF(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_PS_UBUF_ADDR. */
#define BF_PXP_HW_PXP_PS_UBUF_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_PS_UBUF_ADDR) & BM_PXP_HW_PXP_PS_UBUF_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_PXP_HW_PXP_PS_UBUF_ADDR(x, v) (HW_PXP_HW_PXP_PS_UBUF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_PS_VBUF - PS V/Cr Input Buffer Address
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_PS_VBUF - PS V/Cr Input Buffer Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * PS Chroma (V/Cr) Input Buffer Address. This register points to the beginning
 * of the PS V/Cr input buffer. In one or two plane operation, this register is
 * not used. In monochrome modes Y8 and Y4, the low 16 bits are used as the U/V
 * data in the datapath instead of sourcing U/V data from external buffers. In this
 * case, it represents a fixed value for U/V data. This register contains the
 * pointer to the Chroma V/Cr buffer. For Y8/Y4 modes, the low 16 bits are used as
 * the monochrome U and V values in the data path. Bits [15:8] represent the U
 * data byte, and bits ]7:0] represent the V data byte. Other than with Y8/Y4 input
 * buffer formats, this register is unused when processing 1 or 2-plane buffer
 * formats. If the application requires an offset into the PS buffer, then this
 * address can be set so that the desired offset is achieved. Any byte address is
 * valid. For best performance, 64B alignment is recommended. EXAMPLE
 * REG_PS_BUF_WR(image_y); // Y (luma) image data REG_PS_UBUF_WR(image_u); // U (Cb) image
 * data REG_PS_VBUF_WR(image_v); // V (Cr) image data
 */
typedef union _hw_pxp_hw_pxp_ps_vbuf
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_ps_vbuf_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_ps_vbuf_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_PS_VBUF register
 */
/*@{*/
#define HW_PXP_HW_PXP_PS_VBUF_ADDR(x) ((uintptr_t)(x) + 0xE0U)

#define HW_PXP_HW_PXP_PS_VBUF(x) (*(__IO hw_pxp_hw_pxp_ps_vbuf_t *) HW_PXP_HW_PXP_PS_VBUF_ADDR(x))
#define HW_PXP_HW_PXP_PS_VBUF_RD(x) (HW_PXP_HW_PXP_PS_VBUF(x).U)
#define HW_PXP_HW_PXP_PS_VBUF_WR(x, v) (HW_PXP_HW_PXP_PS_VBUF(x).U = (v))
#define HW_PXP_HW_PXP_PS_VBUF_SET(x, v) (HW_PXP_HW_PXP_PS_VBUF_WR(x, HW_PXP_HW_PXP_PS_VBUF_RD(x) |  (v)))
#define HW_PXP_HW_PXP_PS_VBUF_CLR(x, v) (HW_PXP_HW_PXP_PS_VBUF_WR(x, HW_PXP_HW_PXP_PS_VBUF_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_PS_VBUF_TOG(x, v) (HW_PXP_HW_PXP_PS_VBUF_WR(x, HW_PXP_HW_PXP_PS_VBUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_PS_VBUF bitfields
 */

/*!
 * @name Register PXP_HW_PXP_PS_VBUF, field ADDR[31:0] (RW)
 *
 * Address pointer for the PS V/Cr Chroma input buffer.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_VBUF_ADDR (0U)    /*!< Bit position for PXP_HW_PXP_PS_VBUF_ADDR. */
#define BM_PXP_HW_PXP_PS_VBUF_ADDR (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_PS_VBUF_ADDR. */
#define BS_PXP_HW_PXP_PS_VBUF_ADDR (32U)   /*!< Bit field size in bits for PXP_HW_PXP_PS_VBUF_ADDR. */

/*! @brief Read current value of the PXP_HW_PXP_PS_VBUF_ADDR field. */
#define BR_PXP_HW_PXP_PS_VBUF_ADDR(x) (HW_PXP_HW_PXP_PS_VBUF(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_PS_VBUF_ADDR. */
#define BF_PXP_HW_PXP_PS_VBUF_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_PS_VBUF_ADDR) & BM_PXP_HW_PXP_PS_VBUF_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_PXP_HW_PXP_PS_VBUF_ADDR(x, v) (HW_PXP_HW_PXP_PS_VBUF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_PS_PITCH - Processed Surface Pitch
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_PS_PITCH - Processed Surface Pitch (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the processed surface pitch in bytes. Any byte value
 * will indicate the vertical pitch of the PS source frame buffer. This value will
 * be used in PS pixel address calculations. This value has no relation to the
 * UL and LR registers. It specifies how many bytes are between two vertically
 * adjacent pixels in the input PS surface. For multi-plane formats, the Y buffer
 * pitch should be programmed. For 2-plane YUV422, the UV pitch is the same as the
 * Y pitch. For 3-plane YUV422, the U and V pitch is 1/2 the Y pitch. For 2-plane
 * YUV420, the UV pitch is 1/2 the Y pitch. For 3-plane YUV420, the U and V
 * pitch is 1/4 the Y pitch. All source buffers should comply with these U and V
 * resolution reductions with respect to their Y source buffers. EXAMPLE
 * REG_PS_PITCH_WR( 64 * 4 ); // The output buffer pitch is 64 pixels times 32 bits per pixel
 */
typedef union _hw_pxp_hw_pxp_ps_pitch
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_ps_pitch_bitfields
    {
        uint32_t PITCH : 16;           /*!< [15:0]  */
        uint32_t RSVD : 16;            /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_ps_pitch_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_PS_PITCH register
 */
/*@{*/
#define HW_PXP_HW_PXP_PS_PITCH_ADDR(x) ((uintptr_t)(x) + 0xF0U)

#define HW_PXP_HW_PXP_PS_PITCH(x) (*(__IO hw_pxp_hw_pxp_ps_pitch_t *) HW_PXP_HW_PXP_PS_PITCH_ADDR(x))
#define HW_PXP_HW_PXP_PS_PITCH_RD(x) (HW_PXP_HW_PXP_PS_PITCH(x).U)
#define HW_PXP_HW_PXP_PS_PITCH_WR(x, v) (HW_PXP_HW_PXP_PS_PITCH(x).U = (v))
#define HW_PXP_HW_PXP_PS_PITCH_SET(x, v) (HW_PXP_HW_PXP_PS_PITCH_WR(x, HW_PXP_HW_PXP_PS_PITCH_RD(x) |  (v)))
#define HW_PXP_HW_PXP_PS_PITCH_CLR(x, v) (HW_PXP_HW_PXP_PS_PITCH_WR(x, HW_PXP_HW_PXP_PS_PITCH_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_PS_PITCH_TOG(x, v) (HW_PXP_HW_PXP_PS_PITCH_WR(x, HW_PXP_HW_PXP_PS_PITCH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_PS_PITCH bitfields
 */

/*!
 * @name Register PXP_HW_PXP_PS_PITCH, field PITCH[15:0] (RW)
 *
 * Indicates the number of bytes in memory between two vertically adjacent
 * pixels.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_PITCH_PITCH (0U)  /*!< Bit position for PXP_HW_PXP_PS_PITCH_PITCH. */
#define BM_PXP_HW_PXP_PS_PITCH_PITCH (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_PS_PITCH_PITCH. */
#define BS_PXP_HW_PXP_PS_PITCH_PITCH (16U) /*!< Bit field size in bits for PXP_HW_PXP_PS_PITCH_PITCH. */

/*! @brief Read current value of the PXP_HW_PXP_PS_PITCH_PITCH field. */
#define BR_PXP_HW_PXP_PS_PITCH_PITCH(x) (HW_PXP_HW_PXP_PS_PITCH(x).B.PITCH)

/*! @brief Format value for bitfield PXP_HW_PXP_PS_PITCH_PITCH. */
#define BF_PXP_HW_PXP_PS_PITCH_PITCH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_PS_PITCH_PITCH) & BM_PXP_HW_PXP_PS_PITCH_PITCH)

/*! @brief Set the PITCH field to a new value. */
#define BW_PXP_HW_PXP_PS_PITCH_PITCH(x, v) (HW_PXP_HW_PXP_PS_PITCH_WR(x, (HW_PXP_HW_PXP_PS_PITCH_RD(x) & ~BM_PXP_HW_PXP_PS_PITCH_PITCH) | BF_PXP_HW_PXP_PS_PITCH_PITCH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_PS_PITCH, field RSVD[31:16] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_PITCH_RSVD (16U)  /*!< Bit position for PXP_HW_PXP_PS_PITCH_RSVD. */
#define BM_PXP_HW_PXP_PS_PITCH_RSVD (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_PS_PITCH_RSVD. */
#define BS_PXP_HW_PXP_PS_PITCH_RSVD (16U)  /*!< Bit field size in bits for PXP_HW_PXP_PS_PITCH_RSVD. */

/*! @brief Read current value of the PXP_HW_PXP_PS_PITCH_RSVD field. */
#define BR_PXP_HW_PXP_PS_PITCH_RSVD(x) (HW_PXP_HW_PXP_PS_PITCH(x).B.RSVD)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_PS_BACKGROUND_0 - PS Background Color
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_PS_BACKGROUND_0 - PS Background Color (RW)
 *
 * Reset value: 0x00000000U
 *
 * PS Background Pixel Color. This register provides a pixel value used when
 * processing pixels outside of the region specified by the PS Coordinate registers.
 * This value can effectively be used to set the color of the letterboxing
 * region around the PS image. This value is used by the Alpha A block. This register
 * contains a pixel value to be used for any PS pixels that fall outside the PS
 * extents. This is effectively a background or letterbox color. The CSC1 control
 * and datapath pixel format should be considered when selecting the background
 * color. EXAMPLE REG_PS_BACKGROUND_WR(0x00000000); // letterbox is black
 * REG_PS_BACKGROUND_WR(0x00800000); // letterbox is dark red
 * REG_PS_BACKGROUND_WR(0x00008000); // letterbox is dark green REG_PS_BACKGROUND_WR(0x00000080); //
 * letterbox is dark blue
 */
typedef union _hw_pxp_hw_pxp_ps_background_0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_ps_background_0_bitfields
    {
        uint32_t COLOR : 24;           /*!< [23:0]  */
        uint32_t RSVD : 8;             /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_ps_background_0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_PS_BACKGROUND_0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_PS_BACKGROUND_0_ADDR(x) ((uintptr_t)(x) + 0x100U)

#define HW_PXP_HW_PXP_PS_BACKGROUND_0(x) (*(__IO hw_pxp_hw_pxp_ps_background_0_t *) HW_PXP_HW_PXP_PS_BACKGROUND_0_ADDR(x))
#define HW_PXP_HW_PXP_PS_BACKGROUND_0_RD(x) (HW_PXP_HW_PXP_PS_BACKGROUND_0(x).U)
#define HW_PXP_HW_PXP_PS_BACKGROUND_0_WR(x, v) (HW_PXP_HW_PXP_PS_BACKGROUND_0(x).U = (v))
#define HW_PXP_HW_PXP_PS_BACKGROUND_0_SET(x, v) (HW_PXP_HW_PXP_PS_BACKGROUND_0_WR(x, HW_PXP_HW_PXP_PS_BACKGROUND_0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_PS_BACKGROUND_0_CLR(x, v) (HW_PXP_HW_PXP_PS_BACKGROUND_0_WR(x, HW_PXP_HW_PXP_PS_BACKGROUND_0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_PS_BACKGROUND_0_TOG(x, v) (HW_PXP_HW_PXP_PS_BACKGROUND_0_WR(x, HW_PXP_HW_PXP_PS_BACKGROUND_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_PS_BACKGROUND_0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_PS_BACKGROUND_0, field COLOR[23:0] (RW)
 *
 * Background color (in 24bpp format) for any pixels not within the buffer range
 * specified by the PS ULC/LRC.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_BACKGROUND_0_COLOR (0U) /*!< Bit position for PXP_HW_PXP_PS_BACKGROUND_0_COLOR. */
#define BM_PXP_HW_PXP_PS_BACKGROUND_0_COLOR (0x00FFFFFFU) /*!< Bit mask for PXP_HW_PXP_PS_BACKGROUND_0_COLOR. */
#define BS_PXP_HW_PXP_PS_BACKGROUND_0_COLOR (24U) /*!< Bit field size in bits for PXP_HW_PXP_PS_BACKGROUND_0_COLOR. */

/*! @brief Read current value of the PXP_HW_PXP_PS_BACKGROUND_0_COLOR field. */
#define BR_PXP_HW_PXP_PS_BACKGROUND_0_COLOR(x) (HW_PXP_HW_PXP_PS_BACKGROUND_0(x).B.COLOR)

/*! @brief Format value for bitfield PXP_HW_PXP_PS_BACKGROUND_0_COLOR. */
#define BF_PXP_HW_PXP_PS_BACKGROUND_0_COLOR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_PS_BACKGROUND_0_COLOR) & BM_PXP_HW_PXP_PS_BACKGROUND_0_COLOR)

/*! @brief Set the COLOR field to a new value. */
#define BW_PXP_HW_PXP_PS_BACKGROUND_0_COLOR(x, v) (HW_PXP_HW_PXP_PS_BACKGROUND_0_WR(x, (HW_PXP_HW_PXP_PS_BACKGROUND_0_RD(x) & ~BM_PXP_HW_PXP_PS_BACKGROUND_0_COLOR) | BF_PXP_HW_PXP_PS_BACKGROUND_0_COLOR(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_PS_BACKGROUND_0, field RSVD[31:24] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_BACKGROUND_0_RSVD (24U) /*!< Bit position for PXP_HW_PXP_PS_BACKGROUND_0_RSVD. */
#define BM_PXP_HW_PXP_PS_BACKGROUND_0_RSVD (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_PS_BACKGROUND_0_RSVD. */
#define BS_PXP_HW_PXP_PS_BACKGROUND_0_RSVD (8U) /*!< Bit field size in bits for PXP_HW_PXP_PS_BACKGROUND_0_RSVD. */

/*! @brief Read current value of the PXP_HW_PXP_PS_BACKGROUND_0_RSVD field. */
#define BR_PXP_HW_PXP_PS_BACKGROUND_0_RSVD(x) (HW_PXP_HW_PXP_PS_BACKGROUND_0(x).B.RSVD)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_PS_SCALE - PS Scale Factor Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_PS_SCALE - PS Scale Factor Register (RW)
 *
 * Reset value: 0x10001000U
 *
 * PS Scale Factor. This register provides the scale factor for the PS buffer.
 * The maximum down scaling factor is 1/2 such that the output image in either
 * axis is 1/2 the size of the source. The maximum up scaling factor is 2^12 for
 * either axis. The reciprocal of the scale factor should be loaded into this
 * register. To reduce the PS buffer by a factor of two in the output frame buffer, a
 * value of 10.0000_0000_0000 should be loaded into this register. To scale up by
 * a factor of 4, the value of 1/4, or 00.0100_0000_0000, should be loaded into
 * this register. To scale up by 8/5, the value of 00.1010_0000_0000 should be
 * loaded. EXAMPLE REG_PS_SCALE_WR(0x10001000); // 1:1 scaling (0x1.000)
 * REG_PS_SCALE_WR(0x08000800); // 2x scaling (0x0.800) REG_PS_SCALE_WR(0x20002000); // 1/2x
 * scaling (0x2.000)
 */
typedef union _hw_pxp_hw_pxp_ps_scale
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_ps_scale_bitfields
    {
        uint32_t XSCALE : 15;          /*!< [14:0]  */
        uint32_t RSVD1 : 1;            /*!< [15]  */
        uint32_t YSCALE : 15;          /*!< [30:16]  */
        uint32_t RSVD2 : 1;            /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_ps_scale_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_PS_SCALE register
 */
/*@{*/
#define HW_PXP_HW_PXP_PS_SCALE_ADDR(x) ((uintptr_t)(x) + 0x110U)

#define HW_PXP_HW_PXP_PS_SCALE(x) (*(__IO hw_pxp_hw_pxp_ps_scale_t *) HW_PXP_HW_PXP_PS_SCALE_ADDR(x))
#define HW_PXP_HW_PXP_PS_SCALE_RD(x) (HW_PXP_HW_PXP_PS_SCALE(x).U)
#define HW_PXP_HW_PXP_PS_SCALE_WR(x, v) (HW_PXP_HW_PXP_PS_SCALE(x).U = (v))
#define HW_PXP_HW_PXP_PS_SCALE_SET(x, v) (HW_PXP_HW_PXP_PS_SCALE_WR(x, HW_PXP_HW_PXP_PS_SCALE_RD(x) |  (v)))
#define HW_PXP_HW_PXP_PS_SCALE_CLR(x, v) (HW_PXP_HW_PXP_PS_SCALE_WR(x, HW_PXP_HW_PXP_PS_SCALE_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_PS_SCALE_TOG(x, v) (HW_PXP_HW_PXP_PS_SCALE_WR(x, HW_PXP_HW_PXP_PS_SCALE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_PS_SCALE bitfields
 */

/*!
 * @name Register PXP_HW_PXP_PS_SCALE, field XSCALE[14:0] (RW)
 *
 * This is a two bit integer and 12 bit fractional representation
 * (##.####_####_####) of the X scaling factor for the PS source buffer. The maximum value
 * programmed should be 2 since scaling down by a factor greater than 2 is not
 * supported with the bilinear filter. Decimation and the bilinear filter should be
 * used together to achieve scaling by more than a factor of 2.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_SCALE_XSCALE (0U) /*!< Bit position for PXP_HW_PXP_PS_SCALE_XSCALE. */
#define BM_PXP_HW_PXP_PS_SCALE_XSCALE (0x00007FFFU) /*!< Bit mask for PXP_HW_PXP_PS_SCALE_XSCALE. */
#define BS_PXP_HW_PXP_PS_SCALE_XSCALE (15U) /*!< Bit field size in bits for PXP_HW_PXP_PS_SCALE_XSCALE. */

/*! @brief Read current value of the PXP_HW_PXP_PS_SCALE_XSCALE field. */
#define BR_PXP_HW_PXP_PS_SCALE_XSCALE(x) (HW_PXP_HW_PXP_PS_SCALE(x).B.XSCALE)

/*! @brief Format value for bitfield PXP_HW_PXP_PS_SCALE_XSCALE. */
#define BF_PXP_HW_PXP_PS_SCALE_XSCALE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_PS_SCALE_XSCALE) & BM_PXP_HW_PXP_PS_SCALE_XSCALE)

/*! @brief Set the XSCALE field to a new value. */
#define BW_PXP_HW_PXP_PS_SCALE_XSCALE(x, v) (HW_PXP_HW_PXP_PS_SCALE_WR(x, (HW_PXP_HW_PXP_PS_SCALE_RD(x) & ~BM_PXP_HW_PXP_PS_SCALE_XSCALE) | BF_PXP_HW_PXP_PS_SCALE_XSCALE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_PS_SCALE, field RSVD1[15] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_SCALE_RSVD1 (15U) /*!< Bit position for PXP_HW_PXP_PS_SCALE_RSVD1. */
#define BM_PXP_HW_PXP_PS_SCALE_RSVD1 (0x00008000U) /*!< Bit mask for PXP_HW_PXP_PS_SCALE_RSVD1. */
#define BS_PXP_HW_PXP_PS_SCALE_RSVD1 (1U)  /*!< Bit field size in bits for PXP_HW_PXP_PS_SCALE_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_PS_SCALE_RSVD1 field. */
#define BR_PXP_HW_PXP_PS_SCALE_RSVD1(x) (HW_PXP_HW_PXP_PS_SCALE(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_PS_SCALE, field YSCALE[30:16] (RW)
 *
 * This is a two bit integer and 12 bit fractional representation
 * (##.####_####_####) of the Y scaling factor for the PS source buffer. The maximum value
 * programmed should be 2 since scaling down by a factor greater than 2 is not
 * supported with the bilinear filter. Decimation and the bilinear filter should be
 * used together to achieve scaling by more than a factor of 2.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_SCALE_YSCALE (16U) /*!< Bit position for PXP_HW_PXP_PS_SCALE_YSCALE. */
#define BM_PXP_HW_PXP_PS_SCALE_YSCALE (0x7FFF0000U) /*!< Bit mask for PXP_HW_PXP_PS_SCALE_YSCALE. */
#define BS_PXP_HW_PXP_PS_SCALE_YSCALE (15U) /*!< Bit field size in bits for PXP_HW_PXP_PS_SCALE_YSCALE. */

/*! @brief Read current value of the PXP_HW_PXP_PS_SCALE_YSCALE field. */
#define BR_PXP_HW_PXP_PS_SCALE_YSCALE(x) (HW_PXP_HW_PXP_PS_SCALE(x).B.YSCALE)

/*! @brief Format value for bitfield PXP_HW_PXP_PS_SCALE_YSCALE. */
#define BF_PXP_HW_PXP_PS_SCALE_YSCALE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_PS_SCALE_YSCALE) & BM_PXP_HW_PXP_PS_SCALE_YSCALE)

/*! @brief Set the YSCALE field to a new value. */
#define BW_PXP_HW_PXP_PS_SCALE_YSCALE(x, v) (HW_PXP_HW_PXP_PS_SCALE_WR(x, (HW_PXP_HW_PXP_PS_SCALE_RD(x) & ~BM_PXP_HW_PXP_PS_SCALE_YSCALE) | BF_PXP_HW_PXP_PS_SCALE_YSCALE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_PS_SCALE, field RSVD2[31] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_SCALE_RSVD2 (31U) /*!< Bit position for PXP_HW_PXP_PS_SCALE_RSVD2. */
#define BM_PXP_HW_PXP_PS_SCALE_RSVD2 (0x80000000U) /*!< Bit mask for PXP_HW_PXP_PS_SCALE_RSVD2. */
#define BS_PXP_HW_PXP_PS_SCALE_RSVD2 (1U)  /*!< Bit field size in bits for PXP_HW_PXP_PS_SCALE_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_PS_SCALE_RSVD2 field. */
#define BR_PXP_HW_PXP_PS_SCALE_RSVD2(x) (HW_PXP_HW_PXP_PS_SCALE(x).B.RSVD2)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_PS_OFFSET - PS Scale Offset Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_PS_OFFSET - PS Scale Offset Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * PS Scale Offset. This register provides the initial scale offset for the PS
 * buffer. The X and Y offset provides the ability to access the source image with
 * a per sub-pixel granularity. This provides the capability to use all source
 * pixels to effect the output PS image. The fixed offset values can be used for
 * sub-pixel adjustments in the bilinear scaling filter. For example, when scaling
 * an image down by a factor of 2, an initial offset of 0x0 would result in
 * sub-sampling every other pixel. If a fixed offset of 0x800 (1/2), all pixels are
 * used in scaling the final output pixel value. In this case, the first output
 * pixel would be the sum of (1/2*P0) + (1/2*P1). This fixed offset is applied
 * after the decimation filter stage, and before the bilinear filter stage. EXAMPLE
 * REG_PS_SCALE_WR(0x2000_2000); // 1/2x scaling (0x2.000)
 * REG_PS_OFFSET_WR(0x0800_0800); // half-pixel offset in both X and Y to ensure averaging versus pixel
 * decimation
 */
typedef union _hw_pxp_hw_pxp_ps_offset
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_ps_offset_bitfields
    {
        uint32_t XOFFSET : 12;         /*!< [11:0]  */
        uint32_t RSVD1 : 4;            /*!< [15:12]  */
        uint32_t YOFFSET : 12;         /*!< [27:16]  */
        uint32_t RSVD2 : 4;            /*!< [31:28]  */
    } B;
} hw_pxp_hw_pxp_ps_offset_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_PS_OFFSET register
 */
/*@{*/
#define HW_PXP_HW_PXP_PS_OFFSET_ADDR(x) ((uintptr_t)(x) + 0x120U)

#define HW_PXP_HW_PXP_PS_OFFSET(x) (*(__IO hw_pxp_hw_pxp_ps_offset_t *) HW_PXP_HW_PXP_PS_OFFSET_ADDR(x))
#define HW_PXP_HW_PXP_PS_OFFSET_RD(x) (HW_PXP_HW_PXP_PS_OFFSET(x).U)
#define HW_PXP_HW_PXP_PS_OFFSET_WR(x, v) (HW_PXP_HW_PXP_PS_OFFSET(x).U = (v))
#define HW_PXP_HW_PXP_PS_OFFSET_SET(x, v) (HW_PXP_HW_PXP_PS_OFFSET_WR(x, HW_PXP_HW_PXP_PS_OFFSET_RD(x) |  (v)))
#define HW_PXP_HW_PXP_PS_OFFSET_CLR(x, v) (HW_PXP_HW_PXP_PS_OFFSET_WR(x, HW_PXP_HW_PXP_PS_OFFSET_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_PS_OFFSET_TOG(x, v) (HW_PXP_HW_PXP_PS_OFFSET_WR(x, HW_PXP_HW_PXP_PS_OFFSET_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_PS_OFFSET bitfields
 */

/*!
 * @name Register PXP_HW_PXP_PS_OFFSET, field XOFFSET[11:0] (RW)
 *
 * This is a 12 bit fractional representation (0.####_####_####) of the X
 * scaling offset. This represents a fixed pixel offset which gets added to the scaled
 * address to determine source data for the scaling engine.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_OFFSET_XOFFSET (0U) /*!< Bit position for PXP_HW_PXP_PS_OFFSET_XOFFSET. */
#define BM_PXP_HW_PXP_PS_OFFSET_XOFFSET (0x00000FFFU) /*!< Bit mask for PXP_HW_PXP_PS_OFFSET_XOFFSET. */
#define BS_PXP_HW_PXP_PS_OFFSET_XOFFSET (12U) /*!< Bit field size in bits for PXP_HW_PXP_PS_OFFSET_XOFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_PS_OFFSET_XOFFSET field. */
#define BR_PXP_HW_PXP_PS_OFFSET_XOFFSET(x) (HW_PXP_HW_PXP_PS_OFFSET(x).B.XOFFSET)

/*! @brief Format value for bitfield PXP_HW_PXP_PS_OFFSET_XOFFSET. */
#define BF_PXP_HW_PXP_PS_OFFSET_XOFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_PS_OFFSET_XOFFSET) & BM_PXP_HW_PXP_PS_OFFSET_XOFFSET)

/*! @brief Set the XOFFSET field to a new value. */
#define BW_PXP_HW_PXP_PS_OFFSET_XOFFSET(x, v) (HW_PXP_HW_PXP_PS_OFFSET_WR(x, (HW_PXP_HW_PXP_PS_OFFSET_RD(x) & ~BM_PXP_HW_PXP_PS_OFFSET_XOFFSET) | BF_PXP_HW_PXP_PS_OFFSET_XOFFSET(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_PS_OFFSET, field RSVD1[15:12] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_OFFSET_RSVD1 (12U) /*!< Bit position for PXP_HW_PXP_PS_OFFSET_RSVD1. */
#define BM_PXP_HW_PXP_PS_OFFSET_RSVD1 (0x0000F000U) /*!< Bit mask for PXP_HW_PXP_PS_OFFSET_RSVD1. */
#define BS_PXP_HW_PXP_PS_OFFSET_RSVD1 (4U) /*!< Bit field size in bits for PXP_HW_PXP_PS_OFFSET_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_PS_OFFSET_RSVD1 field. */
#define BR_PXP_HW_PXP_PS_OFFSET_RSVD1(x) (HW_PXP_HW_PXP_PS_OFFSET(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_PS_OFFSET, field YOFFSET[27:16] (RW)
 *
 * This is a 12 bit fractional representation (0.####_####_####) of the Y
 * scaling offset. This represents a fixed pixel offset which gets added to the scaled
 * address to determine source data for the scaling engine.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_OFFSET_YOFFSET (16U) /*!< Bit position for PXP_HW_PXP_PS_OFFSET_YOFFSET. */
#define BM_PXP_HW_PXP_PS_OFFSET_YOFFSET (0x0FFF0000U) /*!< Bit mask for PXP_HW_PXP_PS_OFFSET_YOFFSET. */
#define BS_PXP_HW_PXP_PS_OFFSET_YOFFSET (12U) /*!< Bit field size in bits for PXP_HW_PXP_PS_OFFSET_YOFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_PS_OFFSET_YOFFSET field. */
#define BR_PXP_HW_PXP_PS_OFFSET_YOFFSET(x) (HW_PXP_HW_PXP_PS_OFFSET(x).B.YOFFSET)

/*! @brief Format value for bitfield PXP_HW_PXP_PS_OFFSET_YOFFSET. */
#define BF_PXP_HW_PXP_PS_OFFSET_YOFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_PS_OFFSET_YOFFSET) & BM_PXP_HW_PXP_PS_OFFSET_YOFFSET)

/*! @brief Set the YOFFSET field to a new value. */
#define BW_PXP_HW_PXP_PS_OFFSET_YOFFSET(x, v) (HW_PXP_HW_PXP_PS_OFFSET_WR(x, (HW_PXP_HW_PXP_PS_OFFSET_RD(x) & ~BM_PXP_HW_PXP_PS_OFFSET_YOFFSET) | BF_PXP_HW_PXP_PS_OFFSET_YOFFSET(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_PS_OFFSET, field RSVD2[31:28] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_OFFSET_RSVD2 (28U) /*!< Bit position for PXP_HW_PXP_PS_OFFSET_RSVD2. */
#define BM_PXP_HW_PXP_PS_OFFSET_RSVD2 (0xF0000000U) /*!< Bit mask for PXP_HW_PXP_PS_OFFSET_RSVD2. */
#define BS_PXP_HW_PXP_PS_OFFSET_RSVD2 (4U) /*!< Bit field size in bits for PXP_HW_PXP_PS_OFFSET_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_PS_OFFSET_RSVD2 field. */
#define BR_PXP_HW_PXP_PS_OFFSET_RSVD2(x) (HW_PXP_HW_PXP_PS_OFFSET(x).B.RSVD2)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_PS_CLRKEYLOW_0 - PS Color Key Low
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_PS_CLRKEYLOW_0 - PS Color Key Low (RW)
 *
 * Reset value: 0x00FFFFFFU
 *
 * This register contains the color key low value for the PS buffer. This value
 * is used by the Alpha A block. When processing an image, if the PXP finds a
 * pixel in the PS buffer with a color that falls in the range between
 * REG_PS_CLRKEYLOW and REG_PS_CLRKEYHIGH, it will insert the pixel from the AS channel. If
 * the current AS pixel is letterboxed or if the AS also matches its colorkey
 * range, the REG_PS_BACKGROUND color is passed down the pixel pipeline. EXAMPLE //
 * colorkey values between REG_PS_CLRKEYLOW_WR (0x008000); // medium green and
 * REG_PS_CLRKEYHIGH_WR(0x00FF00); // light green
 */
typedef union _hw_pxp_hw_pxp_ps_clrkeylow_0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_ps_clrkeylow_0_bitfields
    {
        uint32_t PIXEL : 24;           /*!< [23:0]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_ps_clrkeylow_0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_PS_CLRKEYLOW_0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_PS_CLRKEYLOW_0_ADDR(x) ((uintptr_t)(x) + 0x130U)

#define HW_PXP_HW_PXP_PS_CLRKEYLOW_0(x) (*(__IO hw_pxp_hw_pxp_ps_clrkeylow_0_t *) HW_PXP_HW_PXP_PS_CLRKEYLOW_0_ADDR(x))
#define HW_PXP_HW_PXP_PS_CLRKEYLOW_0_RD(x) (HW_PXP_HW_PXP_PS_CLRKEYLOW_0(x).U)
#define HW_PXP_HW_PXP_PS_CLRKEYLOW_0_WR(x, v) (HW_PXP_HW_PXP_PS_CLRKEYLOW_0(x).U = (v))
#define HW_PXP_HW_PXP_PS_CLRKEYLOW_0_SET(x, v) (HW_PXP_HW_PXP_PS_CLRKEYLOW_0_WR(x, HW_PXP_HW_PXP_PS_CLRKEYLOW_0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_PS_CLRKEYLOW_0_CLR(x, v) (HW_PXP_HW_PXP_PS_CLRKEYLOW_0_WR(x, HW_PXP_HW_PXP_PS_CLRKEYLOW_0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_PS_CLRKEYLOW_0_TOG(x, v) (HW_PXP_HW_PXP_PS_CLRKEYLOW_0_WR(x, HW_PXP_HW_PXP_PS_CLRKEYLOW_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_PS_CLRKEYLOW_0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_PS_CLRKEYLOW_0, field PIXEL[23:0] (RW)
 *
 * Low range of color key applied to PS buffer. To disable PS colorkeying, set
 * the low colorkey to 0xFFFFFF and the high colorkey to 0x000000.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL (0U) /*!< Bit position for PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL. */
#define BM_PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL (0x00FFFFFFU) /*!< Bit mask for PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL. */
#define BS_PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL (24U) /*!< Bit field size in bits for PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL. */

/*! @brief Read current value of the PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL field. */
#define BR_PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL(x) (HW_PXP_HW_PXP_PS_CLRKEYLOW_0(x).B.PIXEL)

/*! @brief Format value for bitfield PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL. */
#define BF_PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL) & BM_PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL)

/*! @brief Set the PIXEL field to a new value. */
#define BW_PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL(x, v) (HW_PXP_HW_PXP_PS_CLRKEYLOW_0_WR(x, (HW_PXP_HW_PXP_PS_CLRKEYLOW_0_RD(x) & ~BM_PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL) | BF_PXP_HW_PXP_PS_CLRKEYLOW_0_PIXEL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_PS_CLRKEYLOW_0, field RSVD1[31:24] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_CLRKEYLOW_0_RSVD1 (24U) /*!< Bit position for PXP_HW_PXP_PS_CLRKEYLOW_0_RSVD1. */
#define BM_PXP_HW_PXP_PS_CLRKEYLOW_0_RSVD1 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_PS_CLRKEYLOW_0_RSVD1. */
#define BS_PXP_HW_PXP_PS_CLRKEYLOW_0_RSVD1 (8U) /*!< Bit field size in bits for PXP_HW_PXP_PS_CLRKEYLOW_0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_PS_CLRKEYLOW_0_RSVD1 field. */
#define BR_PXP_HW_PXP_PS_CLRKEYLOW_0_RSVD1(x) (HW_PXP_HW_PXP_PS_CLRKEYLOW_0(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_PS_CLRKEYHIGH_0 - PS Color Key High
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_PS_CLRKEYHIGH_0 - PS Color Key High (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the color key high value for the PS buffer. This value
 * is used by the Alpha A block. When processing an image, if the PXP finds a
 * pixel in the PS buffer with a color that falls in the range between
 * REG_PS_CLRKEYLOW and REG_PS_CLRKEYHIGH, it will insert the pixel from the AS channel. If
 * the current AS pixel is letterboxed or if the AS also matches its colorkey
 * range, the REG_PS_BACKGROUND color is passed down the pixel pipeline. EXAMPLE //
 * colorkey values between REG_PS_CLRKEYLOW_WR (0x008000); // medium green and
 * REG_PS_CLRKEYHIGH_WR(0x00FF00); // light green
 */
typedef union _hw_pxp_hw_pxp_ps_clrkeyhigh_0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_ps_clrkeyhigh_0_bitfields
    {
        uint32_t PIXEL : 24;           /*!< [23:0]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_ps_clrkeyhigh_0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_PS_CLRKEYHIGH_0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_PS_CLRKEYHIGH_0_ADDR(x) ((uintptr_t)(x) + 0x140U)

#define HW_PXP_HW_PXP_PS_CLRKEYHIGH_0(x) (*(__IO hw_pxp_hw_pxp_ps_clrkeyhigh_0_t *) HW_PXP_HW_PXP_PS_CLRKEYHIGH_0_ADDR(x))
#define HW_PXP_HW_PXP_PS_CLRKEYHIGH_0_RD(x) (HW_PXP_HW_PXP_PS_CLRKEYHIGH_0(x).U)
#define HW_PXP_HW_PXP_PS_CLRKEYHIGH_0_WR(x, v) (HW_PXP_HW_PXP_PS_CLRKEYHIGH_0(x).U = (v))
#define HW_PXP_HW_PXP_PS_CLRKEYHIGH_0_SET(x, v) (HW_PXP_HW_PXP_PS_CLRKEYHIGH_0_WR(x, HW_PXP_HW_PXP_PS_CLRKEYHIGH_0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_PS_CLRKEYHIGH_0_CLR(x, v) (HW_PXP_HW_PXP_PS_CLRKEYHIGH_0_WR(x, HW_PXP_HW_PXP_PS_CLRKEYHIGH_0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_PS_CLRKEYHIGH_0_TOG(x, v) (HW_PXP_HW_PXP_PS_CLRKEYHIGH_0_WR(x, HW_PXP_HW_PXP_PS_CLRKEYHIGH_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_PS_CLRKEYHIGH_0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_PS_CLRKEYHIGH_0, field PIXEL[23:0] (RW)
 *
 * High range of color key applied to PS buffer. To disable PS colorkeying, set
 * the low colorkey to 0xFFFFFF and the high colorkey to 0x000000.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL (0U) /*!< Bit position for PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL. */
#define BM_PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL (0x00FFFFFFU) /*!< Bit mask for PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL. */
#define BS_PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL (24U) /*!< Bit field size in bits for PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL. */

/*! @brief Read current value of the PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL field. */
#define BR_PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL(x) (HW_PXP_HW_PXP_PS_CLRKEYHIGH_0(x).B.PIXEL)

/*! @brief Format value for bitfield PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL. */
#define BF_PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL) & BM_PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL)

/*! @brief Set the PIXEL field to a new value. */
#define BW_PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL(x, v) (HW_PXP_HW_PXP_PS_CLRKEYHIGH_0_WR(x, (HW_PXP_HW_PXP_PS_CLRKEYHIGH_0_RD(x) & ~BM_PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL) | BF_PXP_HW_PXP_PS_CLRKEYHIGH_0_PIXEL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_PS_CLRKEYHIGH_0, field RSVD1[31:24] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_CLRKEYHIGH_0_RSVD1 (24U) /*!< Bit position for PXP_HW_PXP_PS_CLRKEYHIGH_0_RSVD1. */
#define BM_PXP_HW_PXP_PS_CLRKEYHIGH_0_RSVD1 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_PS_CLRKEYHIGH_0_RSVD1. */
#define BS_PXP_HW_PXP_PS_CLRKEYHIGH_0_RSVD1 (8U) /*!< Bit field size in bits for PXP_HW_PXP_PS_CLRKEYHIGH_0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_PS_CLRKEYHIGH_0_RSVD1 field. */
#define BR_PXP_HW_PXP_PS_CLRKEYHIGH_0_RSVD1(x) (HW_PXP_HW_PXP_PS_CLRKEYHIGH_0(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_AS_CTRL - Alpha Surface Control
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_AS_CTRL - Alpha Surface Control (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains buffer control for the Alpha Surface 0 input buffer.
 * Control register to determine AS buffer processing. EXAMPLE u32 asparam;
 * asparam = BF_PXP_ASPARAM_ENABLE (1); asparam |=
 * BF_PXP_ASPARAM_ALPHA_CTRL(BV_PXP_ASPARAM_ALPHA_CTRL__ROPs); asparam |= BF_PXP_ASPARAM_FORMAT
 * (BV_PXP_ASPARAM_FORMAT__ARGB8888); asparam |= BF_PXP_ASPARAM_ROP (BV_PXP_ASPARAM_ROP__XORAS);
 * REG_ASPARAM_WR(0,asparam); // enable alpha surface to perform XOR ROP using RGB8888
 * AS pixel format
 */
typedef union _hw_pxp_hw_pxp_as_ctrl
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_as_ctrl_bitfields
    {
        uint32_t RSVD0 : 1;            /*!< [0]  */
        uint32_t ALPHA_CTRL : 2;       /*!< [2:1]  */
        uint32_t ENABLE_COLORKEY : 1;  /*!< [3]  */
        uint32_t FORMAT : 4;           /*!< [7:4]  */
        uint32_t ALPHA : 8;            /*!< [15:8]  */
        uint32_t ROP : 4;              /*!< [19:16]  */
        uint32_t ALPHA0_INVERT : 1;    /*!< [20]  */
        uint32_t ALPHA1_INVERT : 1;    /*!< [21]  */
        uint32_t RSVD1 : 10;           /*!< [31:22]  */
    } B;
} hw_pxp_hw_pxp_as_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_AS_CTRL register
 */
/*@{*/
#define HW_PXP_HW_PXP_AS_CTRL_ADDR(x) ((uintptr_t)(x) + 0x150U)

#define HW_PXP_HW_PXP_AS_CTRL(x) (*(__IO hw_pxp_hw_pxp_as_ctrl_t *) HW_PXP_HW_PXP_AS_CTRL_ADDR(x))
#define HW_PXP_HW_PXP_AS_CTRL_RD(x) (HW_PXP_HW_PXP_AS_CTRL(x).U)
#define HW_PXP_HW_PXP_AS_CTRL_WR(x, v) (HW_PXP_HW_PXP_AS_CTRL(x).U = (v))
#define HW_PXP_HW_PXP_AS_CTRL_SET(x, v) (HW_PXP_HW_PXP_AS_CTRL_WR(x, HW_PXP_HW_PXP_AS_CTRL_RD(x) |  (v)))
#define HW_PXP_HW_PXP_AS_CTRL_CLR(x, v) (HW_PXP_HW_PXP_AS_CTRL_WR(x, HW_PXP_HW_PXP_AS_CTRL_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_AS_CTRL_TOG(x, v) (HW_PXP_HW_PXP_AS_CTRL_WR(x, HW_PXP_HW_PXP_AS_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_AS_CTRL bitfields
 */

/*!
 * @name Register PXP_HW_PXP_AS_CTRL, field RSVD0[0] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_CTRL_RSVD0 (0U)   /*!< Bit position for PXP_HW_PXP_AS_CTRL_RSVD0. */
#define BM_PXP_HW_PXP_AS_CTRL_RSVD0 (0x00000001U) /*!< Bit mask for PXP_HW_PXP_AS_CTRL_RSVD0. */
#define BS_PXP_HW_PXP_AS_CTRL_RSVD0 (1U)   /*!< Bit field size in bits for PXP_HW_PXP_AS_CTRL_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_AS_CTRL_RSVD0 field. */
#define BR_PXP_HW_PXP_AS_CTRL_RSVD0(x) (HW_PXP_HW_PXP_AS_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_AS_CTRL, field ALPHA_CTRL[2:1] (RW)
 *
 * Determines how the alpha value is constructed for this alpha surface.
 * Indicates that the value in the ALPHA field should be used instead of the alpha
 * values present in the input pixels.
 *
 * Values:
 * - 0 - Indicates that the AS pixel alpha value will be used to blend the AS
 *     with PS. The ALPHA field is ignored.
 * - 1 - Indicates that the value in the ALPHA field should be used instead of
 *     the alpha values present in the input pixels.
 * - 10 - Indicates that the value in the ALPHA field should be used to scale
 *     all pixel alpha values. Each pixel alpha is multiplied by the value in the
 *     ALPHA field.
 * - 11 - Enable ROPs. The ROP field indicates an operation to be performed on
 *     the alpha surface and PS pixels.
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_CTRL_ALPHA_CTRL (1U) /*!< Bit position for PXP_HW_PXP_AS_CTRL_ALPHA_CTRL. */
#define BM_PXP_HW_PXP_AS_CTRL_ALPHA_CTRL (0x00000006U) /*!< Bit mask for PXP_HW_PXP_AS_CTRL_ALPHA_CTRL. */
#define BS_PXP_HW_PXP_AS_CTRL_ALPHA_CTRL (2U) /*!< Bit field size in bits for PXP_HW_PXP_AS_CTRL_ALPHA_CTRL. */

#define BV_PXP_HW_PXP_AS_CTRL_ALPHA_CTRL_Embedded (0U) /*!< Bit field value for PXP_HW_PXP_AS_CTRL_ALPHA_CTRL: Indicates that the AS pixel alpha value will be used to blend the AS with PS. The ALPHA field is ignored. */
#define BV_PXP_HW_PXP_AS_CTRL_ALPHA_CTRL_Override (0x1U) /*!< Bit field value for PXP_HW_PXP_AS_CTRL_ALPHA_CTRL: Indicates that the value in the ALPHA field should be used instead of the alpha values present in the input pixels. */
#define BV_PXP_HW_PXP_AS_CTRL_ALPHA_CTRL_Multiply (0x2U) /*!< Bit field value for PXP_HW_PXP_AS_CTRL_ALPHA_CTRL: Indicates that the value in the ALPHA field should be used to scale all pixel alpha values. Each pixel alpha is multiplied by the value in the ALPHA field. */
#define BV_PXP_HW_PXP_AS_CTRL_ALPHA_CTRL_ROPs (0x3U) /*!< Bit field value for PXP_HW_PXP_AS_CTRL_ALPHA_CTRL: Enable ROPs. The ROP field indicates an operation to be performed on the alpha surface and PS pixels. */

/*! @brief Read current value of the PXP_HW_PXP_AS_CTRL_ALPHA_CTRL field. */
#define BR_PXP_HW_PXP_AS_CTRL_ALPHA_CTRL(x) (HW_PXP_HW_PXP_AS_CTRL(x).B.ALPHA_CTRL)

/*! @brief Format value for bitfield PXP_HW_PXP_AS_CTRL_ALPHA_CTRL. */
#define BF_PXP_HW_PXP_AS_CTRL_ALPHA_CTRL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_AS_CTRL_ALPHA_CTRL) & BM_PXP_HW_PXP_AS_CTRL_ALPHA_CTRL)

/*! @brief Set the ALPHA_CTRL field to a new value. */
#define BW_PXP_HW_PXP_AS_CTRL_ALPHA_CTRL(x, v) (HW_PXP_HW_PXP_AS_CTRL_WR(x, (HW_PXP_HW_PXP_AS_CTRL_RD(x) & ~BM_PXP_HW_PXP_AS_CTRL_ALPHA_CTRL) | BF_PXP_HW_PXP_AS_CTRL_ALPHA_CTRL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_AS_CTRL, field ENABLE_COLORKEY[3] (RW)
 *
 * Indicates that colorkey functionality is enabled for this alpha surface.
 * Pixels found in the alpha surface colorkey range will be displayed as transparent
 * (the PS pixel will be used).
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_CTRL_ENABLE_COLORKEY (3U) /*!< Bit position for PXP_HW_PXP_AS_CTRL_ENABLE_COLORKEY. */
#define BM_PXP_HW_PXP_AS_CTRL_ENABLE_COLORKEY (0x00000008U) /*!< Bit mask for PXP_HW_PXP_AS_CTRL_ENABLE_COLORKEY. */
#define BS_PXP_HW_PXP_AS_CTRL_ENABLE_COLORKEY (1U) /*!< Bit field size in bits for PXP_HW_PXP_AS_CTRL_ENABLE_COLORKEY. */

/*! @brief Read current value of the PXP_HW_PXP_AS_CTRL_ENABLE_COLORKEY field. */
#define BR_PXP_HW_PXP_AS_CTRL_ENABLE_COLORKEY(x) (HW_PXP_HW_PXP_AS_CTRL(x).B.ENABLE_COLORKEY)

/*! @brief Format value for bitfield PXP_HW_PXP_AS_CTRL_ENABLE_COLORKEY. */
#define BF_PXP_HW_PXP_AS_CTRL_ENABLE_COLORKEY(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_AS_CTRL_ENABLE_COLORKEY) & BM_PXP_HW_PXP_AS_CTRL_ENABLE_COLORKEY)

/*! @brief Set the ENABLE_COLORKEY field to a new value. */
#define BW_PXP_HW_PXP_AS_CTRL_ENABLE_COLORKEY(x, v) (HW_PXP_HW_PXP_AS_CTRL_WR(x, (HW_PXP_HW_PXP_AS_CTRL_RD(x) & ~BM_PXP_HW_PXP_AS_CTRL_ENABLE_COLORKEY) | BF_PXP_HW_PXP_AS_CTRL_ENABLE_COLORKEY(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_AS_CTRL, field FORMAT[7:4] (RW)
 *
 * Indicates the input buffer format for AS.
 *
 * Values:
 * - 0 - 32-bit pixels with alpha
 * - 1 - 32-bit pixels with alpha
 * - 100 - 32-bit pixels without alpha (unpacked 24-bit format)
 * - 1000 - 16-bit pixels with alpha
 * - 1001 - 16-bit pixels with alpha
 * - 1100 - 16-bit pixels without alpha
 * - 1101 - 16-bit pixels without alpha
 * - 1110 - 16-bit pixels without alpha
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_CTRL_FORMAT (4U)  /*!< Bit position for PXP_HW_PXP_AS_CTRL_FORMAT. */
#define BM_PXP_HW_PXP_AS_CTRL_FORMAT (0x000000F0U) /*!< Bit mask for PXP_HW_PXP_AS_CTRL_FORMAT. */
#define BS_PXP_HW_PXP_AS_CTRL_FORMAT (4U)  /*!< Bit field size in bits for PXP_HW_PXP_AS_CTRL_FORMAT. */

#define BV_PXP_HW_PXP_AS_CTRL_FORMAT_ARGB8888 (0U)   /*!< Bit field value for PXP_HW_PXP_AS_CTRL_FORMAT: 32-bit pixels with alpha */
#define BV_PXP_HW_PXP_AS_CTRL_FORMAT_RGBA8888 (0x1U) /*!< Bit field value for PXP_HW_PXP_AS_CTRL_FORMAT: 32-bit pixels with alpha */
#define BV_PXP_HW_PXP_AS_CTRL_FORMAT_RGB888 (0x4U)   /*!< Bit field value for PXP_HW_PXP_AS_CTRL_FORMAT: 32-bit pixels without alpha (unpacked 24-bit format) */
#define BV_PXP_HW_PXP_AS_CTRL_FORMAT_ARGB1555 (0x8U) /*!< Bit field value for PXP_HW_PXP_AS_CTRL_FORMAT: 16-bit pixels with alpha */
#define BV_PXP_HW_PXP_AS_CTRL_FORMAT_ARGB4444 (0x9U) /*!< Bit field value for PXP_HW_PXP_AS_CTRL_FORMAT: 16-bit pixels with alpha */
#define BV_PXP_HW_PXP_AS_CTRL_FORMAT_RGB555 (0xCU)   /*!< Bit field value for PXP_HW_PXP_AS_CTRL_FORMAT: 16-bit pixels without alpha */
#define BV_PXP_HW_PXP_AS_CTRL_FORMAT_RGB444 (0xDU)   /*!< Bit field value for PXP_HW_PXP_AS_CTRL_FORMAT: 16-bit pixels without alpha */
#define BV_PXP_HW_PXP_AS_CTRL_FORMAT_RGB565 (0xEU)   /*!< Bit field value for PXP_HW_PXP_AS_CTRL_FORMAT: 16-bit pixels without alpha */

/*! @brief Read current value of the PXP_HW_PXP_AS_CTRL_FORMAT field. */
#define BR_PXP_HW_PXP_AS_CTRL_FORMAT(x) (HW_PXP_HW_PXP_AS_CTRL(x).B.FORMAT)

/*! @brief Format value for bitfield PXP_HW_PXP_AS_CTRL_FORMAT. */
#define BF_PXP_HW_PXP_AS_CTRL_FORMAT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_AS_CTRL_FORMAT) & BM_PXP_HW_PXP_AS_CTRL_FORMAT)

/*! @brief Set the FORMAT field to a new value. */
#define BW_PXP_HW_PXP_AS_CTRL_FORMAT(x, v) (HW_PXP_HW_PXP_AS_CTRL_WR(x, (HW_PXP_HW_PXP_AS_CTRL_RD(x) & ~BM_PXP_HW_PXP_AS_CTRL_FORMAT) | BF_PXP_HW_PXP_AS_CTRL_FORMAT(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_AS_CTRL, field ALPHA[15:8] (RW)
 *
 * Alpha modifier used when the ALPHA_MULTIPLY or ALPHA_OVERRIDE values are
 * programmed in REG_AS_CTRL[ALPHA_CTRL]. The output alpha value will either be
 * replaced (ALPHA_OVERRIDE) or scaled (ALPHA_MULTIPLY) when selected.
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_CTRL_ALPHA (8U)   /*!< Bit position for PXP_HW_PXP_AS_CTRL_ALPHA. */
#define BM_PXP_HW_PXP_AS_CTRL_ALPHA (0x0000FF00U) /*!< Bit mask for PXP_HW_PXP_AS_CTRL_ALPHA. */
#define BS_PXP_HW_PXP_AS_CTRL_ALPHA (8U)   /*!< Bit field size in bits for PXP_HW_PXP_AS_CTRL_ALPHA. */

/*! @brief Read current value of the PXP_HW_PXP_AS_CTRL_ALPHA field. */
#define BR_PXP_HW_PXP_AS_CTRL_ALPHA(x) (HW_PXP_HW_PXP_AS_CTRL(x).B.ALPHA)

/*! @brief Format value for bitfield PXP_HW_PXP_AS_CTRL_ALPHA. */
#define BF_PXP_HW_PXP_AS_CTRL_ALPHA(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_AS_CTRL_ALPHA) & BM_PXP_HW_PXP_AS_CTRL_ALPHA)

/*! @brief Set the ALPHA field to a new value. */
#define BW_PXP_HW_PXP_AS_CTRL_ALPHA(x, v) (HW_PXP_HW_PXP_AS_CTRL_WR(x, (HW_PXP_HW_PXP_AS_CTRL_RD(x) & ~BM_PXP_HW_PXP_AS_CTRL_ALPHA) | BF_PXP_HW_PXP_AS_CTRL_ALPHA(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_AS_CTRL, field ROP[19:16] (RW)
 *
 * Indicates a raster operation to perform when enabled. Raster operations are
 * enabled through the ALPHA_CTRL field.
 *
 * Values:
 * - 0 - AS AND PS
 * - 1 - nAS AND PS
 * - 10 - AS AND nPS
 * - 11 - AS OR PS
 * - 100 - nAS OR PS
 * - 101 - AS OR nPS
 * - 110 - nAS
 * - 111 - nPS
 * - 1000 - AS NAND PS
 * - 1001 - AS NOR PS
 * - 1010 - AS XOR PS
 * - 1011 - AS XNOR PS
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_CTRL_ROP (16U)    /*!< Bit position for PXP_HW_PXP_AS_CTRL_ROP. */
#define BM_PXP_HW_PXP_AS_CTRL_ROP (0x000F0000U) /*!< Bit mask for PXP_HW_PXP_AS_CTRL_ROP. */
#define BS_PXP_HW_PXP_AS_CTRL_ROP (4U)     /*!< Bit field size in bits for PXP_HW_PXP_AS_CTRL_ROP. */

#define BV_PXP_HW_PXP_AS_CTRL_ROP_MASKAS (0U)        /*!< Bit field value for PXP_HW_PXP_AS_CTRL_ROP: AS AND PS */
#define BV_PXP_HW_PXP_AS_CTRL_ROP_MASKNOTAS (0x1U)   /*!< Bit field value for PXP_HW_PXP_AS_CTRL_ROP: nAS AND PS */
#define BV_PXP_HW_PXP_AS_CTRL_ROP_MASKASNOT (0x2U)   /*!< Bit field value for PXP_HW_PXP_AS_CTRL_ROP: AS AND nPS */
#define BV_PXP_HW_PXP_AS_CTRL_ROP_MERGEAS (0x3U)     /*!< Bit field value for PXP_HW_PXP_AS_CTRL_ROP: AS OR PS */
#define BV_PXP_HW_PXP_AS_CTRL_ROP_MERGENOTAS (0x4U)  /*!< Bit field value for PXP_HW_PXP_AS_CTRL_ROP: nAS OR PS */
#define BV_PXP_HW_PXP_AS_CTRL_ROP_MERGEASNOT (0x5U)  /*!< Bit field value for PXP_HW_PXP_AS_CTRL_ROP: AS OR nPS */
#define BV_PXP_HW_PXP_AS_CTRL_ROP_NOTCOPYAS (0x6U)   /*!< Bit field value for PXP_HW_PXP_AS_CTRL_ROP: nAS */
#define BV_PXP_HW_PXP_AS_CTRL_ROP_NOT  (0x7U)        /*!< Bit field value for PXP_HW_PXP_AS_CTRL_ROP: nPS */
#define BV_PXP_HW_PXP_AS_CTRL_ROP_NOTMASKAS (0x8U)   /*!< Bit field value for PXP_HW_PXP_AS_CTRL_ROP: AS NAND PS */
#define BV_PXP_HW_PXP_AS_CTRL_ROP_NOTMERGEAS (0x9U)  /*!< Bit field value for PXP_HW_PXP_AS_CTRL_ROP: AS NOR PS */
#define BV_PXP_HW_PXP_AS_CTRL_ROP_XORAS (0xAU)       /*!< Bit field value for PXP_HW_PXP_AS_CTRL_ROP: AS XOR PS */
#define BV_PXP_HW_PXP_AS_CTRL_ROP_NOTXORAS (0xBU)    /*!< Bit field value for PXP_HW_PXP_AS_CTRL_ROP: AS XNOR PS */

/*! @brief Read current value of the PXP_HW_PXP_AS_CTRL_ROP field. */
#define BR_PXP_HW_PXP_AS_CTRL_ROP(x) (HW_PXP_HW_PXP_AS_CTRL(x).B.ROP)

/*! @brief Format value for bitfield PXP_HW_PXP_AS_CTRL_ROP. */
#define BF_PXP_HW_PXP_AS_CTRL_ROP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_AS_CTRL_ROP) & BM_PXP_HW_PXP_AS_CTRL_ROP)

/*! @brief Set the ROP field to a new value. */
#define BW_PXP_HW_PXP_AS_CTRL_ROP(x, v) (HW_PXP_HW_PXP_AS_CTRL_WR(x, (HW_PXP_HW_PXP_AS_CTRL_RD(x) & ~BM_PXP_HW_PXP_AS_CTRL_ROP) | BF_PXP_HW_PXP_AS_CTRL_ROP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_AS_CTRL, field ALPHA0_INVERT[20] (RW)
 *
 * Setting this bit to logic 0 will not alter the alpha0 value. A logic 1 will
 * invert the alpha0 value and apply (1-alpha) for image composition.
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_CTRL_ALPHA0_INVERT (20U) /*!< Bit position for PXP_HW_PXP_AS_CTRL_ALPHA0_INVERT. */
#define BM_PXP_HW_PXP_AS_CTRL_ALPHA0_INVERT (0x00100000U) /*!< Bit mask for PXP_HW_PXP_AS_CTRL_ALPHA0_INVERT. */
#define BS_PXP_HW_PXP_AS_CTRL_ALPHA0_INVERT (1U) /*!< Bit field size in bits for PXP_HW_PXP_AS_CTRL_ALPHA0_INVERT. */

/*! @brief Read current value of the PXP_HW_PXP_AS_CTRL_ALPHA0_INVERT field. */
#define BR_PXP_HW_PXP_AS_CTRL_ALPHA0_INVERT(x) (HW_PXP_HW_PXP_AS_CTRL(x).B.ALPHA0_INVERT)

/*! @brief Format value for bitfield PXP_HW_PXP_AS_CTRL_ALPHA0_INVERT. */
#define BF_PXP_HW_PXP_AS_CTRL_ALPHA0_INVERT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_AS_CTRL_ALPHA0_INVERT) & BM_PXP_HW_PXP_AS_CTRL_ALPHA0_INVERT)

/*! @brief Set the ALPHA0_INVERT field to a new value. */
#define BW_PXP_HW_PXP_AS_CTRL_ALPHA0_INVERT(x, v) (HW_PXP_HW_PXP_AS_CTRL_WR(x, (HW_PXP_HW_PXP_AS_CTRL_RD(x) & ~BM_PXP_HW_PXP_AS_CTRL_ALPHA0_INVERT) | BF_PXP_HW_PXP_AS_CTRL_ALPHA0_INVERT(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_AS_CTRL, field ALPHA1_INVERT[21] (RW)
 *
 * Setting this bit to logic 0 will not alter the alpha1 value. A logic 1 will
 * invert the alpha1 value and apply (1-alpha) for image composition.
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_CTRL_ALPHA1_INVERT (21U) /*!< Bit position for PXP_HW_PXP_AS_CTRL_ALPHA1_INVERT. */
#define BM_PXP_HW_PXP_AS_CTRL_ALPHA1_INVERT (0x00200000U) /*!< Bit mask for PXP_HW_PXP_AS_CTRL_ALPHA1_INVERT. */
#define BS_PXP_HW_PXP_AS_CTRL_ALPHA1_INVERT (1U) /*!< Bit field size in bits for PXP_HW_PXP_AS_CTRL_ALPHA1_INVERT. */

/*! @brief Read current value of the PXP_HW_PXP_AS_CTRL_ALPHA1_INVERT field. */
#define BR_PXP_HW_PXP_AS_CTRL_ALPHA1_INVERT(x) (HW_PXP_HW_PXP_AS_CTRL(x).B.ALPHA1_INVERT)

/*! @brief Format value for bitfield PXP_HW_PXP_AS_CTRL_ALPHA1_INVERT. */
#define BF_PXP_HW_PXP_AS_CTRL_ALPHA1_INVERT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_AS_CTRL_ALPHA1_INVERT) & BM_PXP_HW_PXP_AS_CTRL_ALPHA1_INVERT)

/*! @brief Set the ALPHA1_INVERT field to a new value. */
#define BW_PXP_HW_PXP_AS_CTRL_ALPHA1_INVERT(x, v) (HW_PXP_HW_PXP_AS_CTRL_WR(x, (HW_PXP_HW_PXP_AS_CTRL_RD(x) & ~BM_PXP_HW_PXP_AS_CTRL_ALPHA1_INVERT) | BF_PXP_HW_PXP_AS_CTRL_ALPHA1_INVERT(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_AS_CTRL, field RSVD1[31:22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_CTRL_RSVD1 (22U)  /*!< Bit position for PXP_HW_PXP_AS_CTRL_RSVD1. */
#define BM_PXP_HW_PXP_AS_CTRL_RSVD1 (0xFFC00000U) /*!< Bit mask for PXP_HW_PXP_AS_CTRL_RSVD1. */
#define BS_PXP_HW_PXP_AS_CTRL_RSVD1 (10U)  /*!< Bit field size in bits for PXP_HW_PXP_AS_CTRL_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_AS_CTRL_RSVD1 field. */
#define BR_PXP_HW_PXP_AS_CTRL_RSVD1(x) (HW_PXP_HW_PXP_AS_CTRL(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_AS_BUF - Alpha Surface Buffer Pointer
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_AS_BUF - Alpha Surface Buffer Pointer (RW)
 *
 * Reset value: 0x00000000U
 *
 * Alpha Surface 0 Buffer Address Pointer. This register points to the beginning
 * of the Alpha Surface 0 input buffer. This register is used to indicate the
 * base address of the AS buffer. EXAMPLE u32* alpha_ptr; REG_ASn_WR(0,alpha_ptr);
 */
typedef union _hw_pxp_hw_pxp_as_buf
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_as_buf_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_as_buf_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_AS_BUF register
 */
/*@{*/
#define HW_PXP_HW_PXP_AS_BUF_ADDR(x) ((uintptr_t)(x) + 0x160U)

#define HW_PXP_HW_PXP_AS_BUF(x)  (*(__IO hw_pxp_hw_pxp_as_buf_t *) HW_PXP_HW_PXP_AS_BUF_ADDR(x))
#define HW_PXP_HW_PXP_AS_BUF_RD(x) (HW_PXP_HW_PXP_AS_BUF(x).U)
#define HW_PXP_HW_PXP_AS_BUF_WR(x, v) (HW_PXP_HW_PXP_AS_BUF(x).U = (v))
#define HW_PXP_HW_PXP_AS_BUF_SET(x, v) (HW_PXP_HW_PXP_AS_BUF_WR(x, HW_PXP_HW_PXP_AS_BUF_RD(x) |  (v)))
#define HW_PXP_HW_PXP_AS_BUF_CLR(x, v) (HW_PXP_HW_PXP_AS_BUF_WR(x, HW_PXP_HW_PXP_AS_BUF_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_AS_BUF_TOG(x, v) (HW_PXP_HW_PXP_AS_BUF_WR(x, HW_PXP_HW_PXP_AS_BUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_AS_BUF bitfields
 */

/*!
 * @name Register PXP_HW_PXP_AS_BUF, field ADDR[31:0] (RW)
 *
 * Address pointer for the alpha surface 0 buffer.
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_BUF_ADDR (0U)     /*!< Bit position for PXP_HW_PXP_AS_BUF_ADDR. */
#define BM_PXP_HW_PXP_AS_BUF_ADDR (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_AS_BUF_ADDR. */
#define BS_PXP_HW_PXP_AS_BUF_ADDR (32U)    /*!< Bit field size in bits for PXP_HW_PXP_AS_BUF_ADDR. */

/*! @brief Read current value of the PXP_HW_PXP_AS_BUF_ADDR field. */
#define BR_PXP_HW_PXP_AS_BUF_ADDR(x) (HW_PXP_HW_PXP_AS_BUF(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_AS_BUF_ADDR. */
#define BF_PXP_HW_PXP_AS_BUF_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_AS_BUF_ADDR) & BM_PXP_HW_PXP_AS_BUF_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_PXP_HW_PXP_AS_BUF_ADDR(x, v) (HW_PXP_HW_PXP_AS_BUF_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_AS_PITCH - Alpha Surface Pitch
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_AS_PITCH - Alpha Surface Pitch (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the alpha surface pitch in bytes. Any byte value will
 * indicate the vertical pitch. This value will be used in AS pixel address
 * calculations. This value has no relation to the UL and LR registers. It specifies
 * how many bytes are between two vertically adjacent pixels in the input AS
 * surface. EXAMPLE REG_AS_PITCH_WR( 1920 * 4 ); // The output buffer pitch is HD
 * resolution at 32 bits per pixel
 */
typedef union _hw_pxp_hw_pxp_as_pitch
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_as_pitch_bitfields
    {
        uint32_t PITCH : 16;           /*!< [15:0]  */
        uint32_t RSVD : 16;            /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_as_pitch_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_AS_PITCH register
 */
/*@{*/
#define HW_PXP_HW_PXP_AS_PITCH_ADDR(x) ((uintptr_t)(x) + 0x170U)

#define HW_PXP_HW_PXP_AS_PITCH(x) (*(__IO hw_pxp_hw_pxp_as_pitch_t *) HW_PXP_HW_PXP_AS_PITCH_ADDR(x))
#define HW_PXP_HW_PXP_AS_PITCH_RD(x) (HW_PXP_HW_PXP_AS_PITCH(x).U)
#define HW_PXP_HW_PXP_AS_PITCH_WR(x, v) (HW_PXP_HW_PXP_AS_PITCH(x).U = (v))
#define HW_PXP_HW_PXP_AS_PITCH_SET(x, v) (HW_PXP_HW_PXP_AS_PITCH_WR(x, HW_PXP_HW_PXP_AS_PITCH_RD(x) |  (v)))
#define HW_PXP_HW_PXP_AS_PITCH_CLR(x, v) (HW_PXP_HW_PXP_AS_PITCH_WR(x, HW_PXP_HW_PXP_AS_PITCH_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_AS_PITCH_TOG(x, v) (HW_PXP_HW_PXP_AS_PITCH_WR(x, HW_PXP_HW_PXP_AS_PITCH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_AS_PITCH bitfields
 */

/*!
 * @name Register PXP_HW_PXP_AS_PITCH, field PITCH[15:0] (RW)
 *
 * Indicates the number of bytes in memory between two vertically adjacent
 * pixels.
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_PITCH_PITCH (0U)  /*!< Bit position for PXP_HW_PXP_AS_PITCH_PITCH. */
#define BM_PXP_HW_PXP_AS_PITCH_PITCH (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_AS_PITCH_PITCH. */
#define BS_PXP_HW_PXP_AS_PITCH_PITCH (16U) /*!< Bit field size in bits for PXP_HW_PXP_AS_PITCH_PITCH. */

/*! @brief Read current value of the PXP_HW_PXP_AS_PITCH_PITCH field. */
#define BR_PXP_HW_PXP_AS_PITCH_PITCH(x) (HW_PXP_HW_PXP_AS_PITCH(x).B.PITCH)

/*! @brief Format value for bitfield PXP_HW_PXP_AS_PITCH_PITCH. */
#define BF_PXP_HW_PXP_AS_PITCH_PITCH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_AS_PITCH_PITCH) & BM_PXP_HW_PXP_AS_PITCH_PITCH)

/*! @brief Set the PITCH field to a new value. */
#define BW_PXP_HW_PXP_AS_PITCH_PITCH(x, v) (HW_PXP_HW_PXP_AS_PITCH_WR(x, (HW_PXP_HW_PXP_AS_PITCH_RD(x) & ~BM_PXP_HW_PXP_AS_PITCH_PITCH) | BF_PXP_HW_PXP_AS_PITCH_PITCH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_AS_PITCH, field RSVD[31:16] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_PITCH_RSVD (16U)  /*!< Bit position for PXP_HW_PXP_AS_PITCH_RSVD. */
#define BM_PXP_HW_PXP_AS_PITCH_RSVD (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_AS_PITCH_RSVD. */
#define BS_PXP_HW_PXP_AS_PITCH_RSVD (16U)  /*!< Bit field size in bits for PXP_HW_PXP_AS_PITCH_RSVD. */

/*! @brief Read current value of the PXP_HW_PXP_AS_PITCH_RSVD field. */
#define BR_PXP_HW_PXP_AS_PITCH_RSVD(x) (HW_PXP_HW_PXP_AS_PITCH(x).B.RSVD)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_AS_CLRKEYLOW_0 - Overlay Color Key Low
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_AS_CLRKEYLOW_0 - Overlay Color Key Low (RW)
 *
 * Reset value: 0x00FFFFFFU
 *
 * This register contains the color key low value for the AS buffer. This value
 * is used by the Alpha A block. When processing an image, the if the PXP finds a
 * pixel in the current overlay image with a color that falls in the range from
 * the ASCOLORKEYLOW to ASCOLORKEYHIGH range, it will use the PS pixel value for
 * that location. If no PS image is present or if the PS image also matches its
 * colorkey range, the PS background color is used. Colorkey operations are higher
 * priority than alpha or ROP operations. EXAMPLE // colorkey values between
 * REG_AS_CLRKEYLOW_WR (0x000000); // black and REG_AS_CLRKEYHIGH_WR(0x800000); //
 * medium red
 */
typedef union _hw_pxp_hw_pxp_as_clrkeylow_0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_as_clrkeylow_0_bitfields
    {
        uint32_t PIXEL : 24;           /*!< [23:0]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_as_clrkeylow_0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_AS_CLRKEYLOW_0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_AS_CLRKEYLOW_0_ADDR(x) ((uintptr_t)(x) + 0x180U)

#define HW_PXP_HW_PXP_AS_CLRKEYLOW_0(x) (*(__IO hw_pxp_hw_pxp_as_clrkeylow_0_t *) HW_PXP_HW_PXP_AS_CLRKEYLOW_0_ADDR(x))
#define HW_PXP_HW_PXP_AS_CLRKEYLOW_0_RD(x) (HW_PXP_HW_PXP_AS_CLRKEYLOW_0(x).U)
#define HW_PXP_HW_PXP_AS_CLRKEYLOW_0_WR(x, v) (HW_PXP_HW_PXP_AS_CLRKEYLOW_0(x).U = (v))
#define HW_PXP_HW_PXP_AS_CLRKEYLOW_0_SET(x, v) (HW_PXP_HW_PXP_AS_CLRKEYLOW_0_WR(x, HW_PXP_HW_PXP_AS_CLRKEYLOW_0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_AS_CLRKEYLOW_0_CLR(x, v) (HW_PXP_HW_PXP_AS_CLRKEYLOW_0_WR(x, HW_PXP_HW_PXP_AS_CLRKEYLOW_0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_AS_CLRKEYLOW_0_TOG(x, v) (HW_PXP_HW_PXP_AS_CLRKEYLOW_0_WR(x, HW_PXP_HW_PXP_AS_CLRKEYLOW_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_AS_CLRKEYLOW_0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_AS_CLRKEYLOW_0, field PIXEL[23:0] (RW)
 *
 * Low range of RGB color key applied to AS buffer. Each overlay has an
 * independent colorkey enable.
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL (0U) /*!< Bit position for PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL. */
#define BM_PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL (0x00FFFFFFU) /*!< Bit mask for PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL. */
#define BS_PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL (24U) /*!< Bit field size in bits for PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL. */

/*! @brief Read current value of the PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL field. */
#define BR_PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL(x) (HW_PXP_HW_PXP_AS_CLRKEYLOW_0(x).B.PIXEL)

/*! @brief Format value for bitfield PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL. */
#define BF_PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL) & BM_PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL)

/*! @brief Set the PIXEL field to a new value. */
#define BW_PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL(x, v) (HW_PXP_HW_PXP_AS_CLRKEYLOW_0_WR(x, (HW_PXP_HW_PXP_AS_CLRKEYLOW_0_RD(x) & ~BM_PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL) | BF_PXP_HW_PXP_AS_CLRKEYLOW_0_PIXEL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_AS_CLRKEYLOW_0, field RSVD1[31:24] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_CLRKEYLOW_0_RSVD1 (24U) /*!< Bit position for PXP_HW_PXP_AS_CLRKEYLOW_0_RSVD1. */
#define BM_PXP_HW_PXP_AS_CLRKEYLOW_0_RSVD1 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_AS_CLRKEYLOW_0_RSVD1. */
#define BS_PXP_HW_PXP_AS_CLRKEYLOW_0_RSVD1 (8U) /*!< Bit field size in bits for PXP_HW_PXP_AS_CLRKEYLOW_0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_AS_CLRKEYLOW_0_RSVD1 field. */
#define BR_PXP_HW_PXP_AS_CLRKEYLOW_0_RSVD1(x) (HW_PXP_HW_PXP_AS_CLRKEYLOW_0(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_AS_CLRKEYHIGH_0 - Overlay Color Key High
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_AS_CLRKEYHIGH_0 - Overlay Color Key High (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the color key high value for the AS buffer. This value
 * is used by the Alpha A block. When processing an image, the if the PXP finds
 * a pixel in the current overlay image with a color that falls in the range from
 * the ASCOLORKEYLOW to ASCOLORKEYHIGH range, it will use the PS pixel value for
 * that location. If no PS image is present or if the PS image also matches its
 * colorkey range, the PS background color is used. Colorkey operations are
 * higher priority than alpha or ROP operations. EXAMPLE // colorkey values between
 * REG_AS_CLRKEYLOW_WR (0x000000); // black and REG_AS_CLRKEYHIGH_WR(0x800000); //
 * medium red
 */
typedef union _hw_pxp_hw_pxp_as_clrkeyhigh_0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_as_clrkeyhigh_0_bitfields
    {
        uint32_t PIXEL : 24;           /*!< [23:0]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_as_clrkeyhigh_0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_AS_CLRKEYHIGH_0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_AS_CLRKEYHIGH_0_ADDR(x) ((uintptr_t)(x) + 0x190U)

#define HW_PXP_HW_PXP_AS_CLRKEYHIGH_0(x) (*(__IO hw_pxp_hw_pxp_as_clrkeyhigh_0_t *) HW_PXP_HW_PXP_AS_CLRKEYHIGH_0_ADDR(x))
#define HW_PXP_HW_PXP_AS_CLRKEYHIGH_0_RD(x) (HW_PXP_HW_PXP_AS_CLRKEYHIGH_0(x).U)
#define HW_PXP_HW_PXP_AS_CLRKEYHIGH_0_WR(x, v) (HW_PXP_HW_PXP_AS_CLRKEYHIGH_0(x).U = (v))
#define HW_PXP_HW_PXP_AS_CLRKEYHIGH_0_SET(x, v) (HW_PXP_HW_PXP_AS_CLRKEYHIGH_0_WR(x, HW_PXP_HW_PXP_AS_CLRKEYHIGH_0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_AS_CLRKEYHIGH_0_CLR(x, v) (HW_PXP_HW_PXP_AS_CLRKEYHIGH_0_WR(x, HW_PXP_HW_PXP_AS_CLRKEYHIGH_0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_AS_CLRKEYHIGH_0_TOG(x, v) (HW_PXP_HW_PXP_AS_CLRKEYHIGH_0_WR(x, HW_PXP_HW_PXP_AS_CLRKEYHIGH_0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_AS_CLRKEYHIGH_0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_AS_CLRKEYHIGH_0, field PIXEL[23:0] (RW)
 *
 * High range of RGB color key applied to AS buffer. Each overlay has an
 * independent colorkey enable.
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL (0U) /*!< Bit position for PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL. */
#define BM_PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL (0x00FFFFFFU) /*!< Bit mask for PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL. */
#define BS_PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL (24U) /*!< Bit field size in bits for PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL. */

/*! @brief Read current value of the PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL field. */
#define BR_PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL(x) (HW_PXP_HW_PXP_AS_CLRKEYHIGH_0(x).B.PIXEL)

/*! @brief Format value for bitfield PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL. */
#define BF_PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL) & BM_PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL)

/*! @brief Set the PIXEL field to a new value. */
#define BW_PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL(x, v) (HW_PXP_HW_PXP_AS_CLRKEYHIGH_0_WR(x, (HW_PXP_HW_PXP_AS_CLRKEYHIGH_0_RD(x) & ~BM_PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL) | BF_PXP_HW_PXP_AS_CLRKEYHIGH_0_PIXEL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_AS_CLRKEYHIGH_0, field RSVD1[31:24] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_CLRKEYHIGH_0_RSVD1 (24U) /*!< Bit position for PXP_HW_PXP_AS_CLRKEYHIGH_0_RSVD1. */
#define BM_PXP_HW_PXP_AS_CLRKEYHIGH_0_RSVD1 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_AS_CLRKEYHIGH_0_RSVD1. */
#define BS_PXP_HW_PXP_AS_CLRKEYHIGH_0_RSVD1 (8U) /*!< Bit field size in bits for PXP_HW_PXP_AS_CLRKEYHIGH_0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_AS_CLRKEYHIGH_0_RSVD1 field. */
#define BR_PXP_HW_PXP_AS_CLRKEYHIGH_0_RSVD1(x) (HW_PXP_HW_PXP_AS_CLRKEYHIGH_0(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_CSC1_COEF0 - Color Space Conversion Coefficient Register 0
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_CSC1_COEF0 - Color Space Conversion Coefficient Register 0 (RW)
 *
 * Reset value: 0x04000000U
 *
 * This register contains color space conversion coefficients in two's
 * compliment notation. The Coefficient 0 register contains coefficients used in the color
 * space conversion algorithm. The Y and UV offsets are added to the source
 * buffer to normalize them before the conversion. C0 is the coefficient that is used
 * to multiply the luma component of the data for all three RGB components.
 * EXAMPLE // The equations used for Colorspace conversion are: // R = C0*(Y+YOFFSET)
 * + C1(V+UV_OFFSET) // G = C0*(Y+YOFFSET) + C3(U+UV_OFFSET) + C2(V+UV_OFFSET)
 * // R = C0*(Y+YOFFSET) + C4(U+UV_OFFSET) REG_CSCCOEF0_WR(0x04030000); // YUV
 * coefficients: C0, Yoffset, UVoffset REG_CSCCOEF1_WR(0x01230208); // YUV
 * coefficients: C1, C4 REG_CSCCOEF2_WR(0x076B079b); // YUV coefficients: C2, C3
 */
typedef union _hw_pxp_hw_pxp_csc1_coef0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_csc1_coef0_bitfields
    {
        uint32_t Y_OFFSET : 9;         /*!< [8:0]  */
        uint32_t UV_OFFSET : 9;        /*!< [17:9]  */
        uint32_t C0 : 11;              /*!< [28:18]  */
        uint32_t RSVD1 : 1;            /*!< [29]  */
        uint32_t BYPASS : 1;           /*!< [30]  */
        uint32_t YCBCR_MODE : 1;       /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_csc1_coef0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_CSC1_COEF0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_CSC1_COEF0_ADDR(x) ((uintptr_t)(x) + 0x1A0U)

#define HW_PXP_HW_PXP_CSC1_COEF0(x) (*(__IO hw_pxp_hw_pxp_csc1_coef0_t *) HW_PXP_HW_PXP_CSC1_COEF0_ADDR(x))
#define HW_PXP_HW_PXP_CSC1_COEF0_RD(x) (HW_PXP_HW_PXP_CSC1_COEF0(x).U)
#define HW_PXP_HW_PXP_CSC1_COEF0_WR(x, v) (HW_PXP_HW_PXP_CSC1_COEF0(x).U = (v))
#define HW_PXP_HW_PXP_CSC1_COEF0_SET(x, v) (HW_PXP_HW_PXP_CSC1_COEF0_WR(x, HW_PXP_HW_PXP_CSC1_COEF0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_CSC1_COEF0_CLR(x, v) (HW_PXP_HW_PXP_CSC1_COEF0_WR(x, HW_PXP_HW_PXP_CSC1_COEF0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_CSC1_COEF0_TOG(x, v) (HW_PXP_HW_PXP_CSC1_COEF0_WR(x, HW_PXP_HW_PXP_CSC1_COEF0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_CSC1_COEF0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_CSC1_COEF0, field Y_OFFSET[8:0] (RW)
 *
 * Two's compliment amplitude offset implicit in the Y data. For YUV, this is
 * typically 0 and for YCbCr, this is typically -16 (0x1F0)
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC1_COEF0_Y_OFFSET (0U) /*!< Bit position for PXP_HW_PXP_CSC1_COEF0_Y_OFFSET. */
#define BM_PXP_HW_PXP_CSC1_COEF0_Y_OFFSET (0x000001FFU) /*!< Bit mask for PXP_HW_PXP_CSC1_COEF0_Y_OFFSET. */
#define BS_PXP_HW_PXP_CSC1_COEF0_Y_OFFSET (9U) /*!< Bit field size in bits for PXP_HW_PXP_CSC1_COEF0_Y_OFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_CSC1_COEF0_Y_OFFSET field. */
#define BR_PXP_HW_PXP_CSC1_COEF0_Y_OFFSET(x) (HW_PXP_HW_PXP_CSC1_COEF0(x).B.Y_OFFSET)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC1_COEF0_Y_OFFSET. */
#define BF_PXP_HW_PXP_CSC1_COEF0_Y_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC1_COEF0_Y_OFFSET) & BM_PXP_HW_PXP_CSC1_COEF0_Y_OFFSET)

/*! @brief Set the Y_OFFSET field to a new value. */
#define BW_PXP_HW_PXP_CSC1_COEF0_Y_OFFSET(x, v) (HW_PXP_HW_PXP_CSC1_COEF0_WR(x, (HW_PXP_HW_PXP_CSC1_COEF0_RD(x) & ~BM_PXP_HW_PXP_CSC1_COEF0_Y_OFFSET) | BF_PXP_HW_PXP_CSC1_COEF0_Y_OFFSET(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC1_COEF0, field UV_OFFSET[17:9] (RW)
 *
 * Two's compliment phase offset implicit for CbCr data. Generally used for
 * YCbCr to RGB conversion. YCbCr=0x180, YUV=0x000 (typically -128 or 0x180 to
 * indicate normalized -0.5 to 0.5 range)
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC1_COEF0_UV_OFFSET (9U) /*!< Bit position for PXP_HW_PXP_CSC1_COEF0_UV_OFFSET. */
#define BM_PXP_HW_PXP_CSC1_COEF0_UV_OFFSET (0x0003FE00U) /*!< Bit mask for PXP_HW_PXP_CSC1_COEF0_UV_OFFSET. */
#define BS_PXP_HW_PXP_CSC1_COEF0_UV_OFFSET (9U) /*!< Bit field size in bits for PXP_HW_PXP_CSC1_COEF0_UV_OFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_CSC1_COEF0_UV_OFFSET field. */
#define BR_PXP_HW_PXP_CSC1_COEF0_UV_OFFSET(x) (HW_PXP_HW_PXP_CSC1_COEF0(x).B.UV_OFFSET)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC1_COEF0_UV_OFFSET. */
#define BF_PXP_HW_PXP_CSC1_COEF0_UV_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC1_COEF0_UV_OFFSET) & BM_PXP_HW_PXP_CSC1_COEF0_UV_OFFSET)

/*! @brief Set the UV_OFFSET field to a new value. */
#define BW_PXP_HW_PXP_CSC1_COEF0_UV_OFFSET(x, v) (HW_PXP_HW_PXP_CSC1_COEF0_WR(x, (HW_PXP_HW_PXP_CSC1_COEF0_RD(x) & ~BM_PXP_HW_PXP_CSC1_COEF0_UV_OFFSET) | BF_PXP_HW_PXP_CSC1_COEF0_UV_OFFSET(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC1_COEF0, field C0[28:18] (RW)
 *
 * Two's compliment Y multiplier coefficient. YUV=0x100 (1.000) YCbCr=0x12A
 * (1.164)
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC1_COEF0_C0 (18U)  /*!< Bit position for PXP_HW_PXP_CSC1_COEF0_C0. */
#define BM_PXP_HW_PXP_CSC1_COEF0_C0 (0x1FFC0000U) /*!< Bit mask for PXP_HW_PXP_CSC1_COEF0_C0. */
#define BS_PXP_HW_PXP_CSC1_COEF0_C0 (11U)  /*!< Bit field size in bits for PXP_HW_PXP_CSC1_COEF0_C0. */

/*! @brief Read current value of the PXP_HW_PXP_CSC1_COEF0_C0 field. */
#define BR_PXP_HW_PXP_CSC1_COEF0_C0(x) (HW_PXP_HW_PXP_CSC1_COEF0(x).B.C0)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC1_COEF0_C0. */
#define BF_PXP_HW_PXP_CSC1_COEF0_C0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC1_COEF0_C0) & BM_PXP_HW_PXP_CSC1_COEF0_C0)

/*! @brief Set the C0 field to a new value. */
#define BW_PXP_HW_PXP_CSC1_COEF0_C0(x, v) (HW_PXP_HW_PXP_CSC1_COEF0_WR(x, (HW_PXP_HW_PXP_CSC1_COEF0_RD(x) & ~BM_PXP_HW_PXP_CSC1_COEF0_C0) | BF_PXP_HW_PXP_CSC1_COEF0_C0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC1_COEF0, field RSVD1[29] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC1_COEF0_RSVD1 (29U) /*!< Bit position for PXP_HW_PXP_CSC1_COEF0_RSVD1. */
#define BM_PXP_HW_PXP_CSC1_COEF0_RSVD1 (0x20000000U) /*!< Bit mask for PXP_HW_PXP_CSC1_COEF0_RSVD1. */
#define BS_PXP_HW_PXP_CSC1_COEF0_RSVD1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_CSC1_COEF0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_CSC1_COEF0_RSVD1 field. */
#define BR_PXP_HW_PXP_CSC1_COEF0_RSVD1(x) (HW_PXP_HW_PXP_CSC1_COEF0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC1_COEF0, field BYPASS[30] (RW)
 *
 * Bypass the CSC unit in the scaling engine. When set to logic 1, bypass is
 * enabled and the output pixels will be in the YUV/YCbCr color space. When set to
 * logic 0, the CSC unit is enabled and the pixels will be converted based on the
 * programmed coefficients.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC1_COEF0_BYPASS (30U) /*!< Bit position for PXP_HW_PXP_CSC1_COEF0_BYPASS. */
#define BM_PXP_HW_PXP_CSC1_COEF0_BYPASS (0x40000000U) /*!< Bit mask for PXP_HW_PXP_CSC1_COEF0_BYPASS. */
#define BS_PXP_HW_PXP_CSC1_COEF0_BYPASS (1U) /*!< Bit field size in bits for PXP_HW_PXP_CSC1_COEF0_BYPASS. */

/*! @brief Read current value of the PXP_HW_PXP_CSC1_COEF0_BYPASS field. */
#define BR_PXP_HW_PXP_CSC1_COEF0_BYPASS(x) (HW_PXP_HW_PXP_CSC1_COEF0(x).B.BYPASS)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC1_COEF0_BYPASS. */
#define BF_PXP_HW_PXP_CSC1_COEF0_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC1_COEF0_BYPASS) & BM_PXP_HW_PXP_CSC1_COEF0_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_PXP_HW_PXP_CSC1_COEF0_BYPASS(x, v) (HW_PXP_HW_PXP_CSC1_COEF0_WR(x, (HW_PXP_HW_PXP_CSC1_COEF0_RD(x) & ~BM_PXP_HW_PXP_CSC1_COEF0_BYPASS) | BF_PXP_HW_PXP_CSC1_COEF0_BYPASS(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC1_COEF0, field YCBCR_MODE[31] (RW)
 *
 * Set to 1 when performing YCbCr conversion to RGB. Set to 0 when converting
 * YUV to RGB data. This bit changes the behavior of the scaler when performing U/V
 * scaling.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC1_COEF0_YCBCR_MODE (31U) /*!< Bit position for PXP_HW_PXP_CSC1_COEF0_YCBCR_MODE. */
#define BM_PXP_HW_PXP_CSC1_COEF0_YCBCR_MODE (0x80000000U) /*!< Bit mask for PXP_HW_PXP_CSC1_COEF0_YCBCR_MODE. */
#define BS_PXP_HW_PXP_CSC1_COEF0_YCBCR_MODE (1U) /*!< Bit field size in bits for PXP_HW_PXP_CSC1_COEF0_YCBCR_MODE. */

/*! @brief Read current value of the PXP_HW_PXP_CSC1_COEF0_YCBCR_MODE field. */
#define BR_PXP_HW_PXP_CSC1_COEF0_YCBCR_MODE(x) (HW_PXP_HW_PXP_CSC1_COEF0(x).B.YCBCR_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC1_COEF0_YCBCR_MODE. */
#define BF_PXP_HW_PXP_CSC1_COEF0_YCBCR_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC1_COEF0_YCBCR_MODE) & BM_PXP_HW_PXP_CSC1_COEF0_YCBCR_MODE)

/*! @brief Set the YCBCR_MODE field to a new value. */
#define BW_PXP_HW_PXP_CSC1_COEF0_YCBCR_MODE(x, v) (HW_PXP_HW_PXP_CSC1_COEF0_WR(x, (HW_PXP_HW_PXP_CSC1_COEF0_RD(x) & ~BM_PXP_HW_PXP_CSC1_COEF0_YCBCR_MODE) | BF_PXP_HW_PXP_CSC1_COEF0_YCBCR_MODE(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_CSC1_COEF1 - Color Space Conversion Coefficient Register 1
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_CSC1_COEF1 - Color Space Conversion Coefficient Register 1 (RW)
 *
 * Reset value: 0x01230208U
 *
 * This register contains color space conversion coefficients in two's
 * compliment notation. The Coefficient 1 register contains coefficients used in the color
 * space conversion algorithm. C1 is the coefficient that is used to multiply
 * the chroma (Cr/V) component of the data for the red component. C4 is the
 * coefficient that is used to multiply the chroma (Cb/U) component of the data for the
 * blue component. Both values should be coded as a two's compliment fixed point
 * number with 8 bits right of the decimal. EXAMPLE REG_CSCCOEF0_WR(0x04030000);
 * // YUV coefficients: C0, Yoffset, UVoffset REG_CSCCOEF1_WR(0x01230208); // YUV
 * coefficients: C1, C4 REG_CSCCOEF2_WR(0x076B079b); // YUV coefficients: C2, C3
 */
typedef union _hw_pxp_hw_pxp_csc1_coef1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_csc1_coef1_bitfields
    {
        uint32_t C4 : 11;              /*!< [10:0]  */
        uint32_t RSVD0 : 5;            /*!< [15:11]  */
        uint32_t C1 : 11;              /*!< [26:16]  */
        uint32_t RSVD1 : 5;            /*!< [31:27]  */
    } B;
} hw_pxp_hw_pxp_csc1_coef1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_CSC1_COEF1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_CSC1_COEF1_ADDR(x) ((uintptr_t)(x) + 0x1B0U)

#define HW_PXP_HW_PXP_CSC1_COEF1(x) (*(__IO hw_pxp_hw_pxp_csc1_coef1_t *) HW_PXP_HW_PXP_CSC1_COEF1_ADDR(x))
#define HW_PXP_HW_PXP_CSC1_COEF1_RD(x) (HW_PXP_HW_PXP_CSC1_COEF1(x).U)
#define HW_PXP_HW_PXP_CSC1_COEF1_WR(x, v) (HW_PXP_HW_PXP_CSC1_COEF1(x).U = (v))
#define HW_PXP_HW_PXP_CSC1_COEF1_SET(x, v) (HW_PXP_HW_PXP_CSC1_COEF1_WR(x, HW_PXP_HW_PXP_CSC1_COEF1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_CSC1_COEF1_CLR(x, v) (HW_PXP_HW_PXP_CSC1_COEF1_WR(x, HW_PXP_HW_PXP_CSC1_COEF1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_CSC1_COEF1_TOG(x, v) (HW_PXP_HW_PXP_CSC1_COEF1_WR(x, HW_PXP_HW_PXP_CSC1_COEF1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_CSC1_COEF1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_CSC1_COEF1, field C4[10:0] (RW)
 *
 * Two's compliment Blue U/Cb multiplier coefficient. YUV=0x208 (2.032)
 * YCbCr=0x204 (2.017)
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC1_COEF1_C4 (0U)   /*!< Bit position for PXP_HW_PXP_CSC1_COEF1_C4. */
#define BM_PXP_HW_PXP_CSC1_COEF1_C4 (0x000007FFU) /*!< Bit mask for PXP_HW_PXP_CSC1_COEF1_C4. */
#define BS_PXP_HW_PXP_CSC1_COEF1_C4 (11U)  /*!< Bit field size in bits for PXP_HW_PXP_CSC1_COEF1_C4. */

/*! @brief Read current value of the PXP_HW_PXP_CSC1_COEF1_C4 field. */
#define BR_PXP_HW_PXP_CSC1_COEF1_C4(x) (HW_PXP_HW_PXP_CSC1_COEF1(x).B.C4)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC1_COEF1_C4. */
#define BF_PXP_HW_PXP_CSC1_COEF1_C4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC1_COEF1_C4) & BM_PXP_HW_PXP_CSC1_COEF1_C4)

/*! @brief Set the C4 field to a new value. */
#define BW_PXP_HW_PXP_CSC1_COEF1_C4(x, v) (HW_PXP_HW_PXP_CSC1_COEF1_WR(x, (HW_PXP_HW_PXP_CSC1_COEF1_RD(x) & ~BM_PXP_HW_PXP_CSC1_COEF1_C4) | BF_PXP_HW_PXP_CSC1_COEF1_C4(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC1_COEF1, field RSVD0[15:11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC1_COEF1_RSVD0 (11U) /*!< Bit position for PXP_HW_PXP_CSC1_COEF1_RSVD0. */
#define BM_PXP_HW_PXP_CSC1_COEF1_RSVD0 (0x0000F800U) /*!< Bit mask for PXP_HW_PXP_CSC1_COEF1_RSVD0. */
#define BS_PXP_HW_PXP_CSC1_COEF1_RSVD0 (5U) /*!< Bit field size in bits for PXP_HW_PXP_CSC1_COEF1_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_CSC1_COEF1_RSVD0 field. */
#define BR_PXP_HW_PXP_CSC1_COEF1_RSVD0(x) (HW_PXP_HW_PXP_CSC1_COEF1(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC1_COEF1, field C1[26:16] (RW)
 *
 * Two's compliment Red V/Cr multiplier coefficient. YUV=0x123 (1.140)
 * YCbCr=0x198 (1.596)
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC1_COEF1_C1 (16U)  /*!< Bit position for PXP_HW_PXP_CSC1_COEF1_C1. */
#define BM_PXP_HW_PXP_CSC1_COEF1_C1 (0x07FF0000U) /*!< Bit mask for PXP_HW_PXP_CSC1_COEF1_C1. */
#define BS_PXP_HW_PXP_CSC1_COEF1_C1 (11U)  /*!< Bit field size in bits for PXP_HW_PXP_CSC1_COEF1_C1. */

/*! @brief Read current value of the PXP_HW_PXP_CSC1_COEF1_C1 field. */
#define BR_PXP_HW_PXP_CSC1_COEF1_C1(x) (HW_PXP_HW_PXP_CSC1_COEF1(x).B.C1)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC1_COEF1_C1. */
#define BF_PXP_HW_PXP_CSC1_COEF1_C1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC1_COEF1_C1) & BM_PXP_HW_PXP_CSC1_COEF1_C1)

/*! @brief Set the C1 field to a new value. */
#define BW_PXP_HW_PXP_CSC1_COEF1_C1(x, v) (HW_PXP_HW_PXP_CSC1_COEF1_WR(x, (HW_PXP_HW_PXP_CSC1_COEF1_RD(x) & ~BM_PXP_HW_PXP_CSC1_COEF1_C1) | BF_PXP_HW_PXP_CSC1_COEF1_C1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC1_COEF1, field RSVD1[31:27] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC1_COEF1_RSVD1 (27U) /*!< Bit position for PXP_HW_PXP_CSC1_COEF1_RSVD1. */
#define BM_PXP_HW_PXP_CSC1_COEF1_RSVD1 (0xF8000000U) /*!< Bit mask for PXP_HW_PXP_CSC1_COEF1_RSVD1. */
#define BS_PXP_HW_PXP_CSC1_COEF1_RSVD1 (5U) /*!< Bit field size in bits for PXP_HW_PXP_CSC1_COEF1_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_CSC1_COEF1_RSVD1 field. */
#define BR_PXP_HW_PXP_CSC1_COEF1_RSVD1(x) (HW_PXP_HW_PXP_CSC1_COEF1(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_CSC1_COEF2 - Color Space Conversion Coefficient Register 2
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_CSC1_COEF2 - Color Space Conversion Coefficient Register 2 (RW)
 *
 * Reset value: 0x079B076CU
 *
 * This register contains color space conversion coefficients in two's
 * compliment notation. The Coefficient 2 register contains coefficients used in the color
 * space conversion algorithm. C2 is the coefficient that is used to multiply
 * the chroma (Cr/V) component of the data for the green component. C3 is the
 * coefficient that is used to multiply the chroma (Cb/U) component of the data for
 * the green component. Both values should be coded as a two's compliment fixed
 * point number with 8 bits right of the decimal. EXAMPLE // NOTE: The default
 * values for the CSCCOEF2 register are incorrect. C2 should be 0x76B and C3 should be
 * 0x79C for proper operation. REG_CSCCOEF0_WR(0x04030000); // YUV coefficients:
 * C0, Yoffset, UVoffset REG_CSCCOEF1_WR(0x01230208); // YUV coefficients: C1,
 * C4 REG_CSCCOEF2_WR(0x076B079b); // YUV coefficients: C2, C3
 */
typedef union _hw_pxp_hw_pxp_csc1_coef2
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_csc1_coef2_bitfields
    {
        uint32_t C3 : 11;              /*!< [10:0]  */
        uint32_t RSVD0 : 5;            /*!< [15:11]  */
        uint32_t C2 : 11;              /*!< [26:16]  */
        uint32_t RSVD1 : 5;            /*!< [31:27]  */
    } B;
} hw_pxp_hw_pxp_csc1_coef2_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_CSC1_COEF2 register
 */
/*@{*/
#define HW_PXP_HW_PXP_CSC1_COEF2_ADDR(x) ((uintptr_t)(x) + 0x1C0U)

#define HW_PXP_HW_PXP_CSC1_COEF2(x) (*(__IO hw_pxp_hw_pxp_csc1_coef2_t *) HW_PXP_HW_PXP_CSC1_COEF2_ADDR(x))
#define HW_PXP_HW_PXP_CSC1_COEF2_RD(x) (HW_PXP_HW_PXP_CSC1_COEF2(x).U)
#define HW_PXP_HW_PXP_CSC1_COEF2_WR(x, v) (HW_PXP_HW_PXP_CSC1_COEF2(x).U = (v))
#define HW_PXP_HW_PXP_CSC1_COEF2_SET(x, v) (HW_PXP_HW_PXP_CSC1_COEF2_WR(x, HW_PXP_HW_PXP_CSC1_COEF2_RD(x) |  (v)))
#define HW_PXP_HW_PXP_CSC1_COEF2_CLR(x, v) (HW_PXP_HW_PXP_CSC1_COEF2_WR(x, HW_PXP_HW_PXP_CSC1_COEF2_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_CSC1_COEF2_TOG(x, v) (HW_PXP_HW_PXP_CSC1_COEF2_WR(x, HW_PXP_HW_PXP_CSC1_COEF2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_CSC1_COEF2 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_CSC1_COEF2, field C3[10:0] (RW)
 *
 * Two's compliment Green U/Cb multiplier coefficient. YUV=0x79C (-0.394)
 * YCbCr=0x79C (-0.392)
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC1_COEF2_C3 (0U)   /*!< Bit position for PXP_HW_PXP_CSC1_COEF2_C3. */
#define BM_PXP_HW_PXP_CSC1_COEF2_C3 (0x000007FFU) /*!< Bit mask for PXP_HW_PXP_CSC1_COEF2_C3. */
#define BS_PXP_HW_PXP_CSC1_COEF2_C3 (11U)  /*!< Bit field size in bits for PXP_HW_PXP_CSC1_COEF2_C3. */

/*! @brief Read current value of the PXP_HW_PXP_CSC1_COEF2_C3 field. */
#define BR_PXP_HW_PXP_CSC1_COEF2_C3(x) (HW_PXP_HW_PXP_CSC1_COEF2(x).B.C3)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC1_COEF2_C3. */
#define BF_PXP_HW_PXP_CSC1_COEF2_C3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC1_COEF2_C3) & BM_PXP_HW_PXP_CSC1_COEF2_C3)

/*! @brief Set the C3 field to a new value. */
#define BW_PXP_HW_PXP_CSC1_COEF2_C3(x, v) (HW_PXP_HW_PXP_CSC1_COEF2_WR(x, (HW_PXP_HW_PXP_CSC1_COEF2_RD(x) & ~BM_PXP_HW_PXP_CSC1_COEF2_C3) | BF_PXP_HW_PXP_CSC1_COEF2_C3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC1_COEF2, field RSVD0[15:11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC1_COEF2_RSVD0 (11U) /*!< Bit position for PXP_HW_PXP_CSC1_COEF2_RSVD0. */
#define BM_PXP_HW_PXP_CSC1_COEF2_RSVD0 (0x0000F800U) /*!< Bit mask for PXP_HW_PXP_CSC1_COEF2_RSVD0. */
#define BS_PXP_HW_PXP_CSC1_COEF2_RSVD0 (5U) /*!< Bit field size in bits for PXP_HW_PXP_CSC1_COEF2_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_CSC1_COEF2_RSVD0 field. */
#define BR_PXP_HW_PXP_CSC1_COEF2_RSVD0(x) (HW_PXP_HW_PXP_CSC1_COEF2(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC1_COEF2, field C2[26:16] (RW)
 *
 * Two's compliment Green V/Cr multiplier coefficient. YUV=0x76B (-0.581)
 * YCbCr=0x730 (-0.813)
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC1_COEF2_C2 (16U)  /*!< Bit position for PXP_HW_PXP_CSC1_COEF2_C2. */
#define BM_PXP_HW_PXP_CSC1_COEF2_C2 (0x07FF0000U) /*!< Bit mask for PXP_HW_PXP_CSC1_COEF2_C2. */
#define BS_PXP_HW_PXP_CSC1_COEF2_C2 (11U)  /*!< Bit field size in bits for PXP_HW_PXP_CSC1_COEF2_C2. */

/*! @brief Read current value of the PXP_HW_PXP_CSC1_COEF2_C2 field. */
#define BR_PXP_HW_PXP_CSC1_COEF2_C2(x) (HW_PXP_HW_PXP_CSC1_COEF2(x).B.C2)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC1_COEF2_C2. */
#define BF_PXP_HW_PXP_CSC1_COEF2_C2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC1_COEF2_C2) & BM_PXP_HW_PXP_CSC1_COEF2_C2)

/*! @brief Set the C2 field to a new value. */
#define BW_PXP_HW_PXP_CSC1_COEF2_C2(x, v) (HW_PXP_HW_PXP_CSC1_COEF2_WR(x, (HW_PXP_HW_PXP_CSC1_COEF2_RD(x) & ~BM_PXP_HW_PXP_CSC1_COEF2_C2) | BF_PXP_HW_PXP_CSC1_COEF2_C2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC1_COEF2, field RSVD1[31:27] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC1_COEF2_RSVD1 (27U) /*!< Bit position for PXP_HW_PXP_CSC1_COEF2_RSVD1. */
#define BM_PXP_HW_PXP_CSC1_COEF2_RSVD1 (0xF8000000U) /*!< Bit mask for PXP_HW_PXP_CSC1_COEF2_RSVD1. */
#define BS_PXP_HW_PXP_CSC1_COEF2_RSVD1 (5U) /*!< Bit field size in bits for PXP_HW_PXP_CSC1_COEF2_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_CSC1_COEF2_RSVD1 field. */
#define BR_PXP_HW_PXP_CSC1_COEF2_RSVD1(x) (HW_PXP_HW_PXP_CSC1_COEF2(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_CSC2_CTRL - Color Space Conversion Control Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_CSC2_CTRL - Color Space Conversion Control Register. (RW)
 *
 * Reset value: 0x00000001U
 *
 * This register contains the control registers to configure the CSC module. The
 * CSC control register will configure the CSC module to perform color space
 * conversion between the RGB/YUV/YCbCr color spaces. EXAMPLE //Converting from
 * YUV/YCbCr color spaces to the RGB color space uses the //following equation
 * structure: // // R = A1(Y-D1) + A2(U-D2) + A3(V-D3) // G = B1(Y-D1) + B2(U-D2) +
 * B3(V-D3) // B = C1(Y-D1) + C2(U-D2) + C3(V-D3) // //Converting from the RGB color
 * space to YUV/YCbCr color spaces uses the //following equation structure: //
 * // Y = A1*R + A2*G + A3*B + D1 // U = B1*R + B2*G + B3*B + D2 // V = C1*R +
 * C2*G + C3*B + D3 // //All math is signed, so all coefficients come in as two's
 * comp numbers //
 */
typedef union _hw_pxp_hw_pxp_csc2_ctrl
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_csc2_ctrl_bitfields
    {
        uint32_t BYPASS : 1;           /*!< [0]  */
        uint32_t CSC_MODE : 2;         /*!< [2:1]  */
        uint32_t RSVD : 29;            /*!< [31:3]  */
    } B;
} hw_pxp_hw_pxp_csc2_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_CSC2_CTRL register
 */
/*@{*/
#define HW_PXP_HW_PXP_CSC2_CTRL_ADDR(x) ((uintptr_t)(x) + 0x1D0U)

#define HW_PXP_HW_PXP_CSC2_CTRL(x) (*(__IO hw_pxp_hw_pxp_csc2_ctrl_t *) HW_PXP_HW_PXP_CSC2_CTRL_ADDR(x))
#define HW_PXP_HW_PXP_CSC2_CTRL_RD(x) (HW_PXP_HW_PXP_CSC2_CTRL(x).U)
#define HW_PXP_HW_PXP_CSC2_CTRL_WR(x, v) (HW_PXP_HW_PXP_CSC2_CTRL(x).U = (v))
#define HW_PXP_HW_PXP_CSC2_CTRL_SET(x, v) (HW_PXP_HW_PXP_CSC2_CTRL_WR(x, HW_PXP_HW_PXP_CSC2_CTRL_RD(x) |  (v)))
#define HW_PXP_HW_PXP_CSC2_CTRL_CLR(x, v) (HW_PXP_HW_PXP_CSC2_CTRL_WR(x, HW_PXP_HW_PXP_CSC2_CTRL_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_CSC2_CTRL_TOG(x, v) (HW_PXP_HW_PXP_CSC2_CTRL_WR(x, HW_PXP_HW_PXP_CSC2_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_CSC2_CTRL bitfields
 */

/*!
 * @name Register PXP_HW_PXP_CSC2_CTRL, field BYPASS[0] (RW)
 *
 * This bit controls whether the pixels entering the CSC2 unit get converted or
 * not. When BYPASS is set, no operations occur on the pixels. When BYPASS is
 * cleared, the selected CSC operation takes place.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_CTRL_BYPASS (0U) /*!< Bit position for PXP_HW_PXP_CSC2_CTRL_BYPASS. */
#define BM_PXP_HW_PXP_CSC2_CTRL_BYPASS (0x00000001U) /*!< Bit mask for PXP_HW_PXP_CSC2_CTRL_BYPASS. */
#define BS_PXP_HW_PXP_CSC2_CTRL_BYPASS (1U) /*!< Bit field size in bits for PXP_HW_PXP_CSC2_CTRL_BYPASS. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_CTRL_BYPASS field. */
#define BR_PXP_HW_PXP_CSC2_CTRL_BYPASS(x) (HW_PXP_HW_PXP_CSC2_CTRL(x).B.BYPASS)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC2_CTRL_BYPASS. */
#define BF_PXP_HW_PXP_CSC2_CTRL_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC2_CTRL_BYPASS) & BM_PXP_HW_PXP_CSC2_CTRL_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_PXP_HW_PXP_CSC2_CTRL_BYPASS(x, v) (HW_PXP_HW_PXP_CSC2_CTRL_WR(x, (HW_PXP_HW_PXP_CSC2_CTRL_RD(x) & ~BM_PXP_HW_PXP_CSC2_CTRL_BYPASS) | BF_PXP_HW_PXP_CSC2_CTRL_BYPASS(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_CTRL, field CSC_MODE[2:1] (RW)
 *
 * This field controls how the CSC unit operates on pixels when the CSC is not
 * bypassed.
 *
 * Values:
 * - 0 - Convert from YUV to RGB.
 * - 1 - Convert from YCbCr to RGB.
 * - 10 - Convert from RGB to YUV.
 * - 11 - Convert from RGB to YCbCr.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_CTRL_CSC_MODE (1U) /*!< Bit position for PXP_HW_PXP_CSC2_CTRL_CSC_MODE. */
#define BM_PXP_HW_PXP_CSC2_CTRL_CSC_MODE (0x00000006U) /*!< Bit mask for PXP_HW_PXP_CSC2_CTRL_CSC_MODE. */
#define BS_PXP_HW_PXP_CSC2_CTRL_CSC_MODE (2U) /*!< Bit field size in bits for PXP_HW_PXP_CSC2_CTRL_CSC_MODE. */

#define BV_PXP_HW_PXP_CSC2_CTRL_CSC_MODE_YUV2RGB (0U) /*!< Bit field value for PXP_HW_PXP_CSC2_CTRL_CSC_MODE: Convert from YUV to RGB. */
#define BV_PXP_HW_PXP_CSC2_CTRL_CSC_MODE_YCbCr2RGB (0x1U) /*!< Bit field value for PXP_HW_PXP_CSC2_CTRL_CSC_MODE: Convert from YCbCr to RGB. */
#define BV_PXP_HW_PXP_CSC2_CTRL_CSC_MODE_RGB2YUV (0x2U) /*!< Bit field value for PXP_HW_PXP_CSC2_CTRL_CSC_MODE: Convert from RGB to YUV. */
#define BV_PXP_HW_PXP_CSC2_CTRL_CSC_MODE_RGB2YCbCr (0x3U) /*!< Bit field value for PXP_HW_PXP_CSC2_CTRL_CSC_MODE: Convert from RGB to YCbCr. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_CTRL_CSC_MODE field. */
#define BR_PXP_HW_PXP_CSC2_CTRL_CSC_MODE(x) (HW_PXP_HW_PXP_CSC2_CTRL(x).B.CSC_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC2_CTRL_CSC_MODE. */
#define BF_PXP_HW_PXP_CSC2_CTRL_CSC_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC2_CTRL_CSC_MODE) & BM_PXP_HW_PXP_CSC2_CTRL_CSC_MODE)

/*! @brief Set the CSC_MODE field to a new value. */
#define BW_PXP_HW_PXP_CSC2_CTRL_CSC_MODE(x, v) (HW_PXP_HW_PXP_CSC2_CTRL_WR(x, (HW_PXP_HW_PXP_CSC2_CTRL_RD(x) & ~BM_PXP_HW_PXP_CSC2_CTRL_CSC_MODE) | BF_PXP_HW_PXP_CSC2_CTRL_CSC_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_CTRL, field RSVD[31:3] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_CTRL_RSVD (3U)  /*!< Bit position for PXP_HW_PXP_CSC2_CTRL_RSVD. */
#define BM_PXP_HW_PXP_CSC2_CTRL_RSVD (0xFFFFFFF8U) /*!< Bit mask for PXP_HW_PXP_CSC2_CTRL_RSVD. */
#define BS_PXP_HW_PXP_CSC2_CTRL_RSVD (29U) /*!< Bit field size in bits for PXP_HW_PXP_CSC2_CTRL_RSVD. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_CTRL_RSVD field. */
#define BR_PXP_HW_PXP_CSC2_CTRL_RSVD(x) (HW_PXP_HW_PXP_CSC2_CTRL(x).B.RSVD)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_CSC2_COEF0 - Color Space Conversion Coefficient Register 0
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_CSC2_COEF0 - Color Space Conversion Coefficient Register 0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains color space conversion coefficients in two's
 * compliment notation.
 */
typedef union _hw_pxp_hw_pxp_csc2_coef0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_csc2_coef0_bitfields
    {
        uint32_t A1 : 11;              /*!< [10:0]  */
        uint32_t RSVD0 : 5;            /*!< [15:11]  */
        uint32_t A2 : 11;              /*!< [26:16]  */
        uint32_t RSVD1 : 5;            /*!< [31:27]  */
    } B;
} hw_pxp_hw_pxp_csc2_coef0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_CSC2_COEF0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_CSC2_COEF0_ADDR(x) ((uintptr_t)(x) + 0x1E0U)

#define HW_PXP_HW_PXP_CSC2_COEF0(x) (*(__IO hw_pxp_hw_pxp_csc2_coef0_t *) HW_PXP_HW_PXP_CSC2_COEF0_ADDR(x))
#define HW_PXP_HW_PXP_CSC2_COEF0_RD(x) (HW_PXP_HW_PXP_CSC2_COEF0(x).U)
#define HW_PXP_HW_PXP_CSC2_COEF0_WR(x, v) (HW_PXP_HW_PXP_CSC2_COEF0(x).U = (v))
#define HW_PXP_HW_PXP_CSC2_COEF0_SET(x, v) (HW_PXP_HW_PXP_CSC2_COEF0_WR(x, HW_PXP_HW_PXP_CSC2_COEF0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_CSC2_COEF0_CLR(x, v) (HW_PXP_HW_PXP_CSC2_COEF0_WR(x, HW_PXP_HW_PXP_CSC2_COEF0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_CSC2_COEF0_TOG(x, v) (HW_PXP_HW_PXP_CSC2_COEF0_WR(x, HW_PXP_HW_PXP_CSC2_COEF0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_CSC2_COEF0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF0, field A1[10:0] (RW)
 *
 * Two's compliment coefficient offset. This coefficient has a sign bit, 2 bits
 * integer, and 8 bits of fraction as ###.####_####.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF0_A1 (0U)   /*!< Bit position for PXP_HW_PXP_CSC2_COEF0_A1. */
#define BM_PXP_HW_PXP_CSC2_COEF0_A1 (0x000007FFU) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF0_A1. */
#define BS_PXP_HW_PXP_CSC2_COEF0_A1 (11U)  /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF0_A1. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF0_A1 field. */
#define BR_PXP_HW_PXP_CSC2_COEF0_A1(x) (HW_PXP_HW_PXP_CSC2_COEF0(x).B.A1)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC2_COEF0_A1. */
#define BF_PXP_HW_PXP_CSC2_COEF0_A1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC2_COEF0_A1) & BM_PXP_HW_PXP_CSC2_COEF0_A1)

/*! @brief Set the A1 field to a new value. */
#define BW_PXP_HW_PXP_CSC2_COEF0_A1(x, v) (HW_PXP_HW_PXP_CSC2_COEF0_WR(x, (HW_PXP_HW_PXP_CSC2_COEF0_RD(x) & ~BM_PXP_HW_PXP_CSC2_COEF0_A1) | BF_PXP_HW_PXP_CSC2_COEF0_A1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF0, field RSVD0[15:11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF0_RSVD0 (11U) /*!< Bit position for PXP_HW_PXP_CSC2_COEF0_RSVD0. */
#define BM_PXP_HW_PXP_CSC2_COEF0_RSVD0 (0x0000F800U) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF0_RSVD0. */
#define BS_PXP_HW_PXP_CSC2_COEF0_RSVD0 (5U) /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF0_RSVD0 field. */
#define BR_PXP_HW_PXP_CSC2_COEF0_RSVD0(x) (HW_PXP_HW_PXP_CSC2_COEF0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF0, field A2[26:16] (RW)
 *
 * Two's compliment coefficient offset. This coefficient has a sign bit, 2 bits
 * integer, and 8 bits of fraction as ###.####_####.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF0_A2 (16U)  /*!< Bit position for PXP_HW_PXP_CSC2_COEF0_A2. */
#define BM_PXP_HW_PXP_CSC2_COEF0_A2 (0x07FF0000U) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF0_A2. */
#define BS_PXP_HW_PXP_CSC2_COEF0_A2 (11U)  /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF0_A2. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF0_A2 field. */
#define BR_PXP_HW_PXP_CSC2_COEF0_A2(x) (HW_PXP_HW_PXP_CSC2_COEF0(x).B.A2)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC2_COEF0_A2. */
#define BF_PXP_HW_PXP_CSC2_COEF0_A2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC2_COEF0_A2) & BM_PXP_HW_PXP_CSC2_COEF0_A2)

/*! @brief Set the A2 field to a new value. */
#define BW_PXP_HW_PXP_CSC2_COEF0_A2(x, v) (HW_PXP_HW_PXP_CSC2_COEF0_WR(x, (HW_PXP_HW_PXP_CSC2_COEF0_RD(x) & ~BM_PXP_HW_PXP_CSC2_COEF0_A2) | BF_PXP_HW_PXP_CSC2_COEF0_A2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF0, field RSVD1[31:27] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF0_RSVD1 (27U) /*!< Bit position for PXP_HW_PXP_CSC2_COEF0_RSVD1. */
#define BM_PXP_HW_PXP_CSC2_COEF0_RSVD1 (0xF8000000U) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF0_RSVD1. */
#define BS_PXP_HW_PXP_CSC2_COEF0_RSVD1 (5U) /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF0_RSVD1 field. */
#define BR_PXP_HW_PXP_CSC2_COEF0_RSVD1(x) (HW_PXP_HW_PXP_CSC2_COEF0(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_CSC2_COEF1 - Color Space Conversion Coefficient Register 1
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_CSC2_COEF1 - Color Space Conversion Coefficient Register 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains color space conversion coefficients in two's
 * compliment notation.
 */
typedef union _hw_pxp_hw_pxp_csc2_coef1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_csc2_coef1_bitfields
    {
        uint32_t A3 : 11;              /*!< [10:0]  */
        uint32_t RSVD0 : 5;            /*!< [15:11]  */
        uint32_t B1 : 11;              /*!< [26:16]  */
        uint32_t RSVD1 : 5;            /*!< [31:27]  */
    } B;
} hw_pxp_hw_pxp_csc2_coef1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_CSC2_COEF1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_CSC2_COEF1_ADDR(x) ((uintptr_t)(x) + 0x1F0U)

#define HW_PXP_HW_PXP_CSC2_COEF1(x) (*(__IO hw_pxp_hw_pxp_csc2_coef1_t *) HW_PXP_HW_PXP_CSC2_COEF1_ADDR(x))
#define HW_PXP_HW_PXP_CSC2_COEF1_RD(x) (HW_PXP_HW_PXP_CSC2_COEF1(x).U)
#define HW_PXP_HW_PXP_CSC2_COEF1_WR(x, v) (HW_PXP_HW_PXP_CSC2_COEF1(x).U = (v))
#define HW_PXP_HW_PXP_CSC2_COEF1_SET(x, v) (HW_PXP_HW_PXP_CSC2_COEF1_WR(x, HW_PXP_HW_PXP_CSC2_COEF1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_CSC2_COEF1_CLR(x, v) (HW_PXP_HW_PXP_CSC2_COEF1_WR(x, HW_PXP_HW_PXP_CSC2_COEF1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_CSC2_COEF1_TOG(x, v) (HW_PXP_HW_PXP_CSC2_COEF1_WR(x, HW_PXP_HW_PXP_CSC2_COEF1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_CSC2_COEF1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF1, field A3[10:0] (RW)
 *
 * Two's compliment coefficient offset. This coefficient has a sign bit, 2 bits
 * integer, and 8 bits of fraction as ###.####_####.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF1_A3 (0U)   /*!< Bit position for PXP_HW_PXP_CSC2_COEF1_A3. */
#define BM_PXP_HW_PXP_CSC2_COEF1_A3 (0x000007FFU) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF1_A3. */
#define BS_PXP_HW_PXP_CSC2_COEF1_A3 (11U)  /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF1_A3. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF1_A3 field. */
#define BR_PXP_HW_PXP_CSC2_COEF1_A3(x) (HW_PXP_HW_PXP_CSC2_COEF1(x).B.A3)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC2_COEF1_A3. */
#define BF_PXP_HW_PXP_CSC2_COEF1_A3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC2_COEF1_A3) & BM_PXP_HW_PXP_CSC2_COEF1_A3)

/*! @brief Set the A3 field to a new value. */
#define BW_PXP_HW_PXP_CSC2_COEF1_A3(x, v) (HW_PXP_HW_PXP_CSC2_COEF1_WR(x, (HW_PXP_HW_PXP_CSC2_COEF1_RD(x) & ~BM_PXP_HW_PXP_CSC2_COEF1_A3) | BF_PXP_HW_PXP_CSC2_COEF1_A3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF1, field RSVD0[15:11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF1_RSVD0 (11U) /*!< Bit position for PXP_HW_PXP_CSC2_COEF1_RSVD0. */
#define BM_PXP_HW_PXP_CSC2_COEF1_RSVD0 (0x0000F800U) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF1_RSVD0. */
#define BS_PXP_HW_PXP_CSC2_COEF1_RSVD0 (5U) /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF1_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF1_RSVD0 field. */
#define BR_PXP_HW_PXP_CSC2_COEF1_RSVD0(x) (HW_PXP_HW_PXP_CSC2_COEF1(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF1, field B1[26:16] (RW)
 *
 * Two's compliment coefficient offset. This coefficient has a sign bit, 2 bits
 * integer, and 8 bits of fraction as ###.####_####.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF1_B1 (16U)  /*!< Bit position for PXP_HW_PXP_CSC2_COEF1_B1. */
#define BM_PXP_HW_PXP_CSC2_COEF1_B1 (0x07FF0000U) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF1_B1. */
#define BS_PXP_HW_PXP_CSC2_COEF1_B1 (11U)  /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF1_B1. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF1_B1 field. */
#define BR_PXP_HW_PXP_CSC2_COEF1_B1(x) (HW_PXP_HW_PXP_CSC2_COEF1(x).B.B1)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC2_COEF1_B1. */
#define BF_PXP_HW_PXP_CSC2_COEF1_B1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC2_COEF1_B1) & BM_PXP_HW_PXP_CSC2_COEF1_B1)

/*! @brief Set the B1 field to a new value. */
#define BW_PXP_HW_PXP_CSC2_COEF1_B1(x, v) (HW_PXP_HW_PXP_CSC2_COEF1_WR(x, (HW_PXP_HW_PXP_CSC2_COEF1_RD(x) & ~BM_PXP_HW_PXP_CSC2_COEF1_B1) | BF_PXP_HW_PXP_CSC2_COEF1_B1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF1, field RSVD1[31:27] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF1_RSVD1 (27U) /*!< Bit position for PXP_HW_PXP_CSC2_COEF1_RSVD1. */
#define BM_PXP_HW_PXP_CSC2_COEF1_RSVD1 (0xF8000000U) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF1_RSVD1. */
#define BS_PXP_HW_PXP_CSC2_COEF1_RSVD1 (5U) /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF1_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF1_RSVD1 field. */
#define BR_PXP_HW_PXP_CSC2_COEF1_RSVD1(x) (HW_PXP_HW_PXP_CSC2_COEF1(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_CSC2_COEF2 - Color Space Conversion Coefficient Register 2
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_CSC2_COEF2 - Color Space Conversion Coefficient Register 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains color space conversion coefficients in two's
 * compliment notation.
 */
typedef union _hw_pxp_hw_pxp_csc2_coef2
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_csc2_coef2_bitfields
    {
        uint32_t B2 : 11;              /*!< [10:0]  */
        uint32_t RSVD0 : 5;            /*!< [15:11]  */
        uint32_t B3 : 11;              /*!< [26:16]  */
        uint32_t RSVD1 : 5;            /*!< [31:27]  */
    } B;
} hw_pxp_hw_pxp_csc2_coef2_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_CSC2_COEF2 register
 */
/*@{*/
#define HW_PXP_HW_PXP_CSC2_COEF2_ADDR(x) ((uintptr_t)(x) + 0x200U)

#define HW_PXP_HW_PXP_CSC2_COEF2(x) (*(__IO hw_pxp_hw_pxp_csc2_coef2_t *) HW_PXP_HW_PXP_CSC2_COEF2_ADDR(x))
#define HW_PXP_HW_PXP_CSC2_COEF2_RD(x) (HW_PXP_HW_PXP_CSC2_COEF2(x).U)
#define HW_PXP_HW_PXP_CSC2_COEF2_WR(x, v) (HW_PXP_HW_PXP_CSC2_COEF2(x).U = (v))
#define HW_PXP_HW_PXP_CSC2_COEF2_SET(x, v) (HW_PXP_HW_PXP_CSC2_COEF2_WR(x, HW_PXP_HW_PXP_CSC2_COEF2_RD(x) |  (v)))
#define HW_PXP_HW_PXP_CSC2_COEF2_CLR(x, v) (HW_PXP_HW_PXP_CSC2_COEF2_WR(x, HW_PXP_HW_PXP_CSC2_COEF2_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_CSC2_COEF2_TOG(x, v) (HW_PXP_HW_PXP_CSC2_COEF2_WR(x, HW_PXP_HW_PXP_CSC2_COEF2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_CSC2_COEF2 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF2, field B2[10:0] (RW)
 *
 * Two's compliment coefficient offset. This coefficient has a sign bit, 2 bits
 * integer, and 8 bits of fraction as ###.####_####.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF2_B2 (0U)   /*!< Bit position for PXP_HW_PXP_CSC2_COEF2_B2. */
#define BM_PXP_HW_PXP_CSC2_COEF2_B2 (0x000007FFU) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF2_B2. */
#define BS_PXP_HW_PXP_CSC2_COEF2_B2 (11U)  /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF2_B2. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF2_B2 field. */
#define BR_PXP_HW_PXP_CSC2_COEF2_B2(x) (HW_PXP_HW_PXP_CSC2_COEF2(x).B.B2)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC2_COEF2_B2. */
#define BF_PXP_HW_PXP_CSC2_COEF2_B2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC2_COEF2_B2) & BM_PXP_HW_PXP_CSC2_COEF2_B2)

/*! @brief Set the B2 field to a new value. */
#define BW_PXP_HW_PXP_CSC2_COEF2_B2(x, v) (HW_PXP_HW_PXP_CSC2_COEF2_WR(x, (HW_PXP_HW_PXP_CSC2_COEF2_RD(x) & ~BM_PXP_HW_PXP_CSC2_COEF2_B2) | BF_PXP_HW_PXP_CSC2_COEF2_B2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF2, field RSVD0[15:11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF2_RSVD0 (11U) /*!< Bit position for PXP_HW_PXP_CSC2_COEF2_RSVD0. */
#define BM_PXP_HW_PXP_CSC2_COEF2_RSVD0 (0x0000F800U) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF2_RSVD0. */
#define BS_PXP_HW_PXP_CSC2_COEF2_RSVD0 (5U) /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF2_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF2_RSVD0 field. */
#define BR_PXP_HW_PXP_CSC2_COEF2_RSVD0(x) (HW_PXP_HW_PXP_CSC2_COEF2(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF2, field B3[26:16] (RW)
 *
 * Two's compliment coefficient offset. This coefficient has a sign bit, 2 bits
 * integer, and 8 bits of fraction as ###.####_####.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF2_B3 (16U)  /*!< Bit position for PXP_HW_PXP_CSC2_COEF2_B3. */
#define BM_PXP_HW_PXP_CSC2_COEF2_B3 (0x07FF0000U) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF2_B3. */
#define BS_PXP_HW_PXP_CSC2_COEF2_B3 (11U)  /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF2_B3. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF2_B3 field. */
#define BR_PXP_HW_PXP_CSC2_COEF2_B3(x) (HW_PXP_HW_PXP_CSC2_COEF2(x).B.B3)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC2_COEF2_B3. */
#define BF_PXP_HW_PXP_CSC2_COEF2_B3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC2_COEF2_B3) & BM_PXP_HW_PXP_CSC2_COEF2_B3)

/*! @brief Set the B3 field to a new value. */
#define BW_PXP_HW_PXP_CSC2_COEF2_B3(x, v) (HW_PXP_HW_PXP_CSC2_COEF2_WR(x, (HW_PXP_HW_PXP_CSC2_COEF2_RD(x) & ~BM_PXP_HW_PXP_CSC2_COEF2_B3) | BF_PXP_HW_PXP_CSC2_COEF2_B3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF2, field RSVD1[31:27] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF2_RSVD1 (27U) /*!< Bit position for PXP_HW_PXP_CSC2_COEF2_RSVD1. */
#define BM_PXP_HW_PXP_CSC2_COEF2_RSVD1 (0xF8000000U) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF2_RSVD1. */
#define BS_PXP_HW_PXP_CSC2_COEF2_RSVD1 (5U) /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF2_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF2_RSVD1 field. */
#define BR_PXP_HW_PXP_CSC2_COEF2_RSVD1(x) (HW_PXP_HW_PXP_CSC2_COEF2(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_CSC2_COEF3 - Color Space Conversion Coefficient Register 3
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_CSC2_COEF3 - Color Space Conversion Coefficient Register 3 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains color space conversion coefficients in two's
 * compliment notation.
 */
typedef union _hw_pxp_hw_pxp_csc2_coef3
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_csc2_coef3_bitfields
    {
        uint32_t C1 : 11;              /*!< [10:0]  */
        uint32_t RSVD0 : 5;            /*!< [15:11]  */
        uint32_t C2 : 11;              /*!< [26:16]  */
        uint32_t RSVD1 : 5;            /*!< [31:27]  */
    } B;
} hw_pxp_hw_pxp_csc2_coef3_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_CSC2_COEF3 register
 */
/*@{*/
#define HW_PXP_HW_PXP_CSC2_COEF3_ADDR(x) ((uintptr_t)(x) + 0x210U)

#define HW_PXP_HW_PXP_CSC2_COEF3(x) (*(__IO hw_pxp_hw_pxp_csc2_coef3_t *) HW_PXP_HW_PXP_CSC2_COEF3_ADDR(x))
#define HW_PXP_HW_PXP_CSC2_COEF3_RD(x) (HW_PXP_HW_PXP_CSC2_COEF3(x).U)
#define HW_PXP_HW_PXP_CSC2_COEF3_WR(x, v) (HW_PXP_HW_PXP_CSC2_COEF3(x).U = (v))
#define HW_PXP_HW_PXP_CSC2_COEF3_SET(x, v) (HW_PXP_HW_PXP_CSC2_COEF3_WR(x, HW_PXP_HW_PXP_CSC2_COEF3_RD(x) |  (v)))
#define HW_PXP_HW_PXP_CSC2_COEF3_CLR(x, v) (HW_PXP_HW_PXP_CSC2_COEF3_WR(x, HW_PXP_HW_PXP_CSC2_COEF3_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_CSC2_COEF3_TOG(x, v) (HW_PXP_HW_PXP_CSC2_COEF3_WR(x, HW_PXP_HW_PXP_CSC2_COEF3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_CSC2_COEF3 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF3, field C1[10:0] (RW)
 *
 * Two's compliment coefficient offset. This coefficient has a sign bit, 2 bits
 * integer, and 8 bits of fraction as ###.####_####.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF3_C1 (0U)   /*!< Bit position for PXP_HW_PXP_CSC2_COEF3_C1. */
#define BM_PXP_HW_PXP_CSC2_COEF3_C1 (0x000007FFU) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF3_C1. */
#define BS_PXP_HW_PXP_CSC2_COEF3_C1 (11U)  /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF3_C1. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF3_C1 field. */
#define BR_PXP_HW_PXP_CSC2_COEF3_C1(x) (HW_PXP_HW_PXP_CSC2_COEF3(x).B.C1)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC2_COEF3_C1. */
#define BF_PXP_HW_PXP_CSC2_COEF3_C1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC2_COEF3_C1) & BM_PXP_HW_PXP_CSC2_COEF3_C1)

/*! @brief Set the C1 field to a new value. */
#define BW_PXP_HW_PXP_CSC2_COEF3_C1(x, v) (HW_PXP_HW_PXP_CSC2_COEF3_WR(x, (HW_PXP_HW_PXP_CSC2_COEF3_RD(x) & ~BM_PXP_HW_PXP_CSC2_COEF3_C1) | BF_PXP_HW_PXP_CSC2_COEF3_C1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF3, field RSVD0[15:11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF3_RSVD0 (11U) /*!< Bit position for PXP_HW_PXP_CSC2_COEF3_RSVD0. */
#define BM_PXP_HW_PXP_CSC2_COEF3_RSVD0 (0x0000F800U) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF3_RSVD0. */
#define BS_PXP_HW_PXP_CSC2_COEF3_RSVD0 (5U) /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF3_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF3_RSVD0 field. */
#define BR_PXP_HW_PXP_CSC2_COEF3_RSVD0(x) (HW_PXP_HW_PXP_CSC2_COEF3(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF3, field C2[26:16] (RW)
 *
 * Two's compliment coefficient offset. This coefficient has a sign bit, 2 bits
 * integer, and 8 bits of fraction as ###.####_####.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF3_C2 (16U)  /*!< Bit position for PXP_HW_PXP_CSC2_COEF3_C2. */
#define BM_PXP_HW_PXP_CSC2_COEF3_C2 (0x07FF0000U) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF3_C2. */
#define BS_PXP_HW_PXP_CSC2_COEF3_C2 (11U)  /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF3_C2. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF3_C2 field. */
#define BR_PXP_HW_PXP_CSC2_COEF3_C2(x) (HW_PXP_HW_PXP_CSC2_COEF3(x).B.C2)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC2_COEF3_C2. */
#define BF_PXP_HW_PXP_CSC2_COEF3_C2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC2_COEF3_C2) & BM_PXP_HW_PXP_CSC2_COEF3_C2)

/*! @brief Set the C2 field to a new value. */
#define BW_PXP_HW_PXP_CSC2_COEF3_C2(x, v) (HW_PXP_HW_PXP_CSC2_COEF3_WR(x, (HW_PXP_HW_PXP_CSC2_COEF3_RD(x) & ~BM_PXP_HW_PXP_CSC2_COEF3_C2) | BF_PXP_HW_PXP_CSC2_COEF3_C2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF3, field RSVD1[31:27] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF3_RSVD1 (27U) /*!< Bit position for PXP_HW_PXP_CSC2_COEF3_RSVD1. */
#define BM_PXP_HW_PXP_CSC2_COEF3_RSVD1 (0xF8000000U) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF3_RSVD1. */
#define BS_PXP_HW_PXP_CSC2_COEF3_RSVD1 (5U) /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF3_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF3_RSVD1 field. */
#define BR_PXP_HW_PXP_CSC2_COEF3_RSVD1(x) (HW_PXP_HW_PXP_CSC2_COEF3(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_CSC2_COEF4 - Color Space Conversion Coefficient Register 4
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_CSC2_COEF4 - Color Space Conversion Coefficient Register 4 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains color space conversion coefficients in two's
 * compliment notation.
 */
typedef union _hw_pxp_hw_pxp_csc2_coef4
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_csc2_coef4_bitfields
    {
        uint32_t C3 : 11;              /*!< [10:0]  */
        uint32_t RSVD0 : 5;            /*!< [15:11]  */
        uint32_t D1 : 9;               /*!< [24:16]  */
        uint32_t RSVD1 : 7;            /*!< [31:25]  */
    } B;
} hw_pxp_hw_pxp_csc2_coef4_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_CSC2_COEF4 register
 */
/*@{*/
#define HW_PXP_HW_PXP_CSC2_COEF4_ADDR(x) ((uintptr_t)(x) + 0x220U)

#define HW_PXP_HW_PXP_CSC2_COEF4(x) (*(__IO hw_pxp_hw_pxp_csc2_coef4_t *) HW_PXP_HW_PXP_CSC2_COEF4_ADDR(x))
#define HW_PXP_HW_PXP_CSC2_COEF4_RD(x) (HW_PXP_HW_PXP_CSC2_COEF4(x).U)
#define HW_PXP_HW_PXP_CSC2_COEF4_WR(x, v) (HW_PXP_HW_PXP_CSC2_COEF4(x).U = (v))
#define HW_PXP_HW_PXP_CSC2_COEF4_SET(x, v) (HW_PXP_HW_PXP_CSC2_COEF4_WR(x, HW_PXP_HW_PXP_CSC2_COEF4_RD(x) |  (v)))
#define HW_PXP_HW_PXP_CSC2_COEF4_CLR(x, v) (HW_PXP_HW_PXP_CSC2_COEF4_WR(x, HW_PXP_HW_PXP_CSC2_COEF4_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_CSC2_COEF4_TOG(x, v) (HW_PXP_HW_PXP_CSC2_COEF4_WR(x, HW_PXP_HW_PXP_CSC2_COEF4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_CSC2_COEF4 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF4, field C3[10:0] (RW)
 *
 * Two's compliment coefficient offset. This coefficient has a sign bit, 2 bits
 * integer, and 8 bits of fraction as ###.####_####.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF4_C3 (0U)   /*!< Bit position for PXP_HW_PXP_CSC2_COEF4_C3. */
#define BM_PXP_HW_PXP_CSC2_COEF4_C3 (0x000007FFU) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF4_C3. */
#define BS_PXP_HW_PXP_CSC2_COEF4_C3 (11U)  /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF4_C3. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF4_C3 field. */
#define BR_PXP_HW_PXP_CSC2_COEF4_C3(x) (HW_PXP_HW_PXP_CSC2_COEF4(x).B.C3)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC2_COEF4_C3. */
#define BF_PXP_HW_PXP_CSC2_COEF4_C3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC2_COEF4_C3) & BM_PXP_HW_PXP_CSC2_COEF4_C3)

/*! @brief Set the C3 field to a new value. */
#define BW_PXP_HW_PXP_CSC2_COEF4_C3(x, v) (HW_PXP_HW_PXP_CSC2_COEF4_WR(x, (HW_PXP_HW_PXP_CSC2_COEF4_RD(x) & ~BM_PXP_HW_PXP_CSC2_COEF4_C3) | BF_PXP_HW_PXP_CSC2_COEF4_C3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF4, field RSVD0[15:11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF4_RSVD0 (11U) /*!< Bit position for PXP_HW_PXP_CSC2_COEF4_RSVD0. */
#define BM_PXP_HW_PXP_CSC2_COEF4_RSVD0 (0x0000F800U) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF4_RSVD0. */
#define BS_PXP_HW_PXP_CSC2_COEF4_RSVD0 (5U) /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF4_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF4_RSVD0 field. */
#define BR_PXP_HW_PXP_CSC2_COEF4_RSVD0(x) (HW_PXP_HW_PXP_CSC2_COEF4(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF4, field D1[24:16] (RW)
 *
 * Two's compliment coefficient integer offset to be added.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF4_D1 (16U)  /*!< Bit position for PXP_HW_PXP_CSC2_COEF4_D1. */
#define BM_PXP_HW_PXP_CSC2_COEF4_D1 (0x01FF0000U) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF4_D1. */
#define BS_PXP_HW_PXP_CSC2_COEF4_D1 (9U)   /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF4_D1. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF4_D1 field. */
#define BR_PXP_HW_PXP_CSC2_COEF4_D1(x) (HW_PXP_HW_PXP_CSC2_COEF4(x).B.D1)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC2_COEF4_D1. */
#define BF_PXP_HW_PXP_CSC2_COEF4_D1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC2_COEF4_D1) & BM_PXP_HW_PXP_CSC2_COEF4_D1)

/*! @brief Set the D1 field to a new value. */
#define BW_PXP_HW_PXP_CSC2_COEF4_D1(x, v) (HW_PXP_HW_PXP_CSC2_COEF4_WR(x, (HW_PXP_HW_PXP_CSC2_COEF4_RD(x) & ~BM_PXP_HW_PXP_CSC2_COEF4_D1) | BF_PXP_HW_PXP_CSC2_COEF4_D1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF4, field RSVD1[31:25] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF4_RSVD1 (25U) /*!< Bit position for PXP_HW_PXP_CSC2_COEF4_RSVD1. */
#define BM_PXP_HW_PXP_CSC2_COEF4_RSVD1 (0xFE000000U) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF4_RSVD1. */
#define BS_PXP_HW_PXP_CSC2_COEF4_RSVD1 (7U) /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF4_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF4_RSVD1 field. */
#define BR_PXP_HW_PXP_CSC2_COEF4_RSVD1(x) (HW_PXP_HW_PXP_CSC2_COEF4(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_CSC2_COEF5 - Color Space Conversion Coefficient Register 5
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_CSC2_COEF5 - Color Space Conversion Coefficient Register 5 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains color space conversion coefficients in two's
 * compliment notation.
 */
typedef union _hw_pxp_hw_pxp_csc2_coef5
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_csc2_coef5_bitfields
    {
        uint32_t D2 : 9;               /*!< [8:0]  */
        uint32_t RSVD0 : 7;            /*!< [15:9]  */
        uint32_t D3 : 9;               /*!< [24:16]  */
        uint32_t RSVD1 : 7;            /*!< [31:25]  */
    } B;
} hw_pxp_hw_pxp_csc2_coef5_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_CSC2_COEF5 register
 */
/*@{*/
#define HW_PXP_HW_PXP_CSC2_COEF5_ADDR(x) ((uintptr_t)(x) + 0x230U)

#define HW_PXP_HW_PXP_CSC2_COEF5(x) (*(__IO hw_pxp_hw_pxp_csc2_coef5_t *) HW_PXP_HW_PXP_CSC2_COEF5_ADDR(x))
#define HW_PXP_HW_PXP_CSC2_COEF5_RD(x) (HW_PXP_HW_PXP_CSC2_COEF5(x).U)
#define HW_PXP_HW_PXP_CSC2_COEF5_WR(x, v) (HW_PXP_HW_PXP_CSC2_COEF5(x).U = (v))
#define HW_PXP_HW_PXP_CSC2_COEF5_SET(x, v) (HW_PXP_HW_PXP_CSC2_COEF5_WR(x, HW_PXP_HW_PXP_CSC2_COEF5_RD(x) |  (v)))
#define HW_PXP_HW_PXP_CSC2_COEF5_CLR(x, v) (HW_PXP_HW_PXP_CSC2_COEF5_WR(x, HW_PXP_HW_PXP_CSC2_COEF5_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_CSC2_COEF5_TOG(x, v) (HW_PXP_HW_PXP_CSC2_COEF5_WR(x, HW_PXP_HW_PXP_CSC2_COEF5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_CSC2_COEF5 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF5, field D2[8:0] (RW)
 *
 * Two's compliment D1 coefficient integer offset to be added.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF5_D2 (0U)   /*!< Bit position for PXP_HW_PXP_CSC2_COEF5_D2. */
#define BM_PXP_HW_PXP_CSC2_COEF5_D2 (0x000001FFU) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF5_D2. */
#define BS_PXP_HW_PXP_CSC2_COEF5_D2 (9U)   /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF5_D2. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF5_D2 field. */
#define BR_PXP_HW_PXP_CSC2_COEF5_D2(x) (HW_PXP_HW_PXP_CSC2_COEF5(x).B.D2)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC2_COEF5_D2. */
#define BF_PXP_HW_PXP_CSC2_COEF5_D2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC2_COEF5_D2) & BM_PXP_HW_PXP_CSC2_COEF5_D2)

/*! @brief Set the D2 field to a new value. */
#define BW_PXP_HW_PXP_CSC2_COEF5_D2(x, v) (HW_PXP_HW_PXP_CSC2_COEF5_WR(x, (HW_PXP_HW_PXP_CSC2_COEF5_RD(x) & ~BM_PXP_HW_PXP_CSC2_COEF5_D2) | BF_PXP_HW_PXP_CSC2_COEF5_D2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF5, field RSVD0[15:9] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF5_RSVD0 (9U) /*!< Bit position for PXP_HW_PXP_CSC2_COEF5_RSVD0. */
#define BM_PXP_HW_PXP_CSC2_COEF5_RSVD0 (0x0000FE00U) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF5_RSVD0. */
#define BS_PXP_HW_PXP_CSC2_COEF5_RSVD0 (7U) /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF5_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF5_RSVD0 field. */
#define BR_PXP_HW_PXP_CSC2_COEF5_RSVD0(x) (HW_PXP_HW_PXP_CSC2_COEF5(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF5, field D3[24:16] (RW)
 *
 * Two's compliment coefficient integer offset to be added.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF5_D3 (16U)  /*!< Bit position for PXP_HW_PXP_CSC2_COEF5_D3. */
#define BM_PXP_HW_PXP_CSC2_COEF5_D3 (0x01FF0000U) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF5_D3. */
#define BS_PXP_HW_PXP_CSC2_COEF5_D3 (9U)   /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF5_D3. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF5_D3 field. */
#define BR_PXP_HW_PXP_CSC2_COEF5_D3(x) (HW_PXP_HW_PXP_CSC2_COEF5(x).B.D3)

/*! @brief Format value for bitfield PXP_HW_PXP_CSC2_COEF5_D3. */
#define BF_PXP_HW_PXP_CSC2_COEF5_D3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CSC2_COEF5_D3) & BM_PXP_HW_PXP_CSC2_COEF5_D3)

/*! @brief Set the D3 field to a new value. */
#define BW_PXP_HW_PXP_CSC2_COEF5_D3(x, v) (HW_PXP_HW_PXP_CSC2_COEF5_WR(x, (HW_PXP_HW_PXP_CSC2_COEF5_RD(x) & ~BM_PXP_HW_PXP_CSC2_COEF5_D3) | BF_PXP_HW_PXP_CSC2_COEF5_D3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CSC2_COEF5, field RSVD1[31:25] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CSC2_COEF5_RSVD1 (25U) /*!< Bit position for PXP_HW_PXP_CSC2_COEF5_RSVD1. */
#define BM_PXP_HW_PXP_CSC2_COEF5_RSVD1 (0xFE000000U) /*!< Bit mask for PXP_HW_PXP_CSC2_COEF5_RSVD1. */
#define BS_PXP_HW_PXP_CSC2_COEF5_RSVD1 (7U) /*!< Bit field size in bits for PXP_HW_PXP_CSC2_COEF5_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_CSC2_COEF5_RSVD1 field. */
#define BR_PXP_HW_PXP_CSC2_COEF5_RSVD1(x) (HW_PXP_HW_PXP_CSC2_COEF5(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_LUT_CTRL - Lookup Table Control Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_LUT_CTRL - Lookup Table Control Register. (RW)
 *
 * Reset value: 0x80010000U
 *
 * This register is used to access/control the Monochrome Lookup table. The Y8
 * LUT input mode will take the high order data path byte and transform it using
 * the LUT memory. This is an 8-bit to 8-bit transformation. The two low order
 * bytes bypass the LUT and are not transformed, but bypassed without modification.
 * This option can be used for monochrome gamma correction. The Direct Lookup
 * mode will use the high nibble of each data byte and truncate the low nibble to
 * generate the lookup address, i.e. R[7:0]G[7:0]B[7:0] -> R[7:4]G[7:4]B[7:4]. 4K
 * pixels (12-bit address) with 2 bytes per pixel is supported in this mode.
 * Cached Lookup mode will use the high order bits, R[7:3],G[7:2],B[7:3] or RGB565, to
 * address the cached LUT memory. 64KB LUT tables, using 16KB of internal LUT
 * memory, can be indirectly transformed to 16-bit output pixels (as in
 * RGBW4444/RGB565). This is used for 16bpp gamma correction or EPD color panel support.
 * Cache misses are internally managed by the PXP LUT Cache controller.
 */
typedef union _hw_pxp_hw_pxp_lut_ctrl
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_lut_ctrl_bitfields
    {
        uint32_t DMA_START : 1;        /*!< [0]  */
        uint32_t RSVD0 : 7;            /*!< [7:1]  */
        uint32_t INVALID : 1;          /*!< [8]  */
        uint32_t LRU_UPD : 1;          /*!< [9]  */
        uint32_t SEL_8KB : 1;          /*!< [10]  */
        uint32_t RSVD1 : 5;            /*!< [15:11]  */
        uint32_t OUT_MODE : 2;         /*!< [17:16]  */
        uint32_t RSVD2 : 6;            /*!< [23:18]  */
        uint32_t LOOKUP_MODE : 2;      /*!< [25:24]  */
        uint32_t RSVD3 : 5;            /*!< [30:26]  */
        uint32_t BYPASS : 1;           /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_lut_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_LUT_CTRL register
 */
/*@{*/
#define HW_PXP_HW_PXP_LUT_CTRL_ADDR(x) ((uintptr_t)(x) + 0x240U)

#define HW_PXP_HW_PXP_LUT_CTRL(x) (*(__IO hw_pxp_hw_pxp_lut_ctrl_t *) HW_PXP_HW_PXP_LUT_CTRL_ADDR(x))
#define HW_PXP_HW_PXP_LUT_CTRL_RD(x) (HW_PXP_HW_PXP_LUT_CTRL(x).U)
#define HW_PXP_HW_PXP_LUT_CTRL_WR(x, v) (HW_PXP_HW_PXP_LUT_CTRL(x).U = (v))
#define HW_PXP_HW_PXP_LUT_CTRL_SET(x, v) (HW_PXP_HW_PXP_LUT_CTRL_WR(x, HW_PXP_HW_PXP_LUT_CTRL_RD(x) |  (v)))
#define HW_PXP_HW_PXP_LUT_CTRL_CLR(x, v) (HW_PXP_HW_PXP_LUT_CTRL_WR(x, HW_PXP_HW_PXP_LUT_CTRL_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_LUT_CTRL_TOG(x, v) (HW_PXP_HW_PXP_LUT_CTRL_WR(x, HW_PXP_HW_PXP_LUT_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_LUT_CTRL bitfields
 */

/*!
 * @name Register PXP_HW_PXP_LUT_CTRL, field DMA_START[0] (RW)
 *
 * Setting this bit will result in the DMA operation to load the PXP LUT memory
 * based on REG_LUT_ADDR_NUM_BYTES, REG_LUT_ADDR_ADDR, and REG_LUT_MEM_ADDR. This
 * bit will automatically reset when set to a logic 1. Note: The LOOKUP_MODE
 * must not be set to CACHE_RGB565 when starting and performing DMA transfers.
 */
/*@{*/
#define BP_PXP_HW_PXP_LUT_CTRL_DMA_START (0U) /*!< Bit position for PXP_HW_PXP_LUT_CTRL_DMA_START. */
#define BM_PXP_HW_PXP_LUT_CTRL_DMA_START (0x00000001U) /*!< Bit mask for PXP_HW_PXP_LUT_CTRL_DMA_START. */
#define BS_PXP_HW_PXP_LUT_CTRL_DMA_START (1U) /*!< Bit field size in bits for PXP_HW_PXP_LUT_CTRL_DMA_START. */

/*! @brief Read current value of the PXP_HW_PXP_LUT_CTRL_DMA_START field. */
#define BR_PXP_HW_PXP_LUT_CTRL_DMA_START(x) (HW_PXP_HW_PXP_LUT_CTRL(x).B.DMA_START)

/*! @brief Format value for bitfield PXP_HW_PXP_LUT_CTRL_DMA_START. */
#define BF_PXP_HW_PXP_LUT_CTRL_DMA_START(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_LUT_CTRL_DMA_START) & BM_PXP_HW_PXP_LUT_CTRL_DMA_START)

/*! @brief Set the DMA_START field to a new value. */
#define BW_PXP_HW_PXP_LUT_CTRL_DMA_START(x, v) (HW_PXP_HW_PXP_LUT_CTRL_WR(x, (HW_PXP_HW_PXP_LUT_CTRL_RD(x) & ~BM_PXP_HW_PXP_LUT_CTRL_DMA_START) | BF_PXP_HW_PXP_LUT_CTRL_DMA_START(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_LUT_CTRL, field RSVD0[7:1] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_LUT_CTRL_RSVD0 (1U)  /*!< Bit position for PXP_HW_PXP_LUT_CTRL_RSVD0. */
#define BM_PXP_HW_PXP_LUT_CTRL_RSVD0 (0x000000FEU) /*!< Bit mask for PXP_HW_PXP_LUT_CTRL_RSVD0. */
#define BS_PXP_HW_PXP_LUT_CTRL_RSVD0 (7U)  /*!< Bit field size in bits for PXP_HW_PXP_LUT_CTRL_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_LUT_CTRL_RSVD0 field. */
#define BR_PXP_HW_PXP_LUT_CTRL_RSVD0(x) (HW_PXP_HW_PXP_LUT_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_LUT_CTRL, field INVALID[8] (RW)
 *
 * Invalidate the cache LRU and valid bits. This bit will automatically reset
 * when set to a logic 1.
 */
/*@{*/
#define BP_PXP_HW_PXP_LUT_CTRL_INVALID (8U) /*!< Bit position for PXP_HW_PXP_LUT_CTRL_INVALID. */
#define BM_PXP_HW_PXP_LUT_CTRL_INVALID (0x00000100U) /*!< Bit mask for PXP_HW_PXP_LUT_CTRL_INVALID. */
#define BS_PXP_HW_PXP_LUT_CTRL_INVALID (1U) /*!< Bit field size in bits for PXP_HW_PXP_LUT_CTRL_INVALID. */

/*! @brief Read current value of the PXP_HW_PXP_LUT_CTRL_INVALID field. */
#define BR_PXP_HW_PXP_LUT_CTRL_INVALID(x) (HW_PXP_HW_PXP_LUT_CTRL(x).B.INVALID)

/*! @brief Format value for bitfield PXP_HW_PXP_LUT_CTRL_INVALID. */
#define BF_PXP_HW_PXP_LUT_CTRL_INVALID(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_LUT_CTRL_INVALID) & BM_PXP_HW_PXP_LUT_CTRL_INVALID)

/*! @brief Set the INVALID field to a new value. */
#define BW_PXP_HW_PXP_LUT_CTRL_INVALID(x, v) (HW_PXP_HW_PXP_LUT_CTRL_WR(x, (HW_PXP_HW_PXP_LUT_CTRL_RD(x) & ~BM_PXP_HW_PXP_LUT_CTRL_INVALID) | BF_PXP_HW_PXP_LUT_CTRL_INVALID(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_LUT_CTRL, field LRU_UPD[9] (RW)
 *
 * Least Recently Used Policy Update Control: 1=> block LRU update for hit after
 * miss. 0=> update LRU for all hits including hit after miss.
 */
/*@{*/
#define BP_PXP_HW_PXP_LUT_CTRL_LRU_UPD (9U) /*!< Bit position for PXP_HW_PXP_LUT_CTRL_LRU_UPD. */
#define BM_PXP_HW_PXP_LUT_CTRL_LRU_UPD (0x00000200U) /*!< Bit mask for PXP_HW_PXP_LUT_CTRL_LRU_UPD. */
#define BS_PXP_HW_PXP_LUT_CTRL_LRU_UPD (1U) /*!< Bit field size in bits for PXP_HW_PXP_LUT_CTRL_LRU_UPD. */

/*! @brief Read current value of the PXP_HW_PXP_LUT_CTRL_LRU_UPD field. */
#define BR_PXP_HW_PXP_LUT_CTRL_LRU_UPD(x) (HW_PXP_HW_PXP_LUT_CTRL(x).B.LRU_UPD)

/*! @brief Format value for bitfield PXP_HW_PXP_LUT_CTRL_LRU_UPD. */
#define BF_PXP_HW_PXP_LUT_CTRL_LRU_UPD(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_LUT_CTRL_LRU_UPD) & BM_PXP_HW_PXP_LUT_CTRL_LRU_UPD)

/*! @brief Set the LRU_UPD field to a new value. */
#define BW_PXP_HW_PXP_LUT_CTRL_LRU_UPD(x, v) (HW_PXP_HW_PXP_LUT_CTRL_WR(x, (HW_PXP_HW_PXP_LUT_CTRL_RD(x) & ~BM_PXP_HW_PXP_LUT_CTRL_LRU_UPD) | BF_PXP_HW_PXP_LUT_CTRL_LRU_UPD(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_LUT_CTRL, field SEL_8KB[10] (RW)
 *
 * Selects which 8KB bank of memory to use for direct 12bpp lookup modes. Logic
 * 0 indicates first 8KB, logic 1 indicates second 8KB. Two direct LUT arrays can
 * be stored and one can be selected for a given PXP operation.
 */
/*@{*/
#define BP_PXP_HW_PXP_LUT_CTRL_SEL_8KB (10U) /*!< Bit position for PXP_HW_PXP_LUT_CTRL_SEL_8KB. */
#define BM_PXP_HW_PXP_LUT_CTRL_SEL_8KB (0x00000400U) /*!< Bit mask for PXP_HW_PXP_LUT_CTRL_SEL_8KB. */
#define BS_PXP_HW_PXP_LUT_CTRL_SEL_8KB (1U) /*!< Bit field size in bits for PXP_HW_PXP_LUT_CTRL_SEL_8KB. */

/*! @brief Read current value of the PXP_HW_PXP_LUT_CTRL_SEL_8KB field. */
#define BR_PXP_HW_PXP_LUT_CTRL_SEL_8KB(x) (HW_PXP_HW_PXP_LUT_CTRL(x).B.SEL_8KB)

/*! @brief Format value for bitfield PXP_HW_PXP_LUT_CTRL_SEL_8KB. */
#define BF_PXP_HW_PXP_LUT_CTRL_SEL_8KB(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_LUT_CTRL_SEL_8KB) & BM_PXP_HW_PXP_LUT_CTRL_SEL_8KB)

/*! @brief Set the SEL_8KB field to a new value. */
#define BW_PXP_HW_PXP_LUT_CTRL_SEL_8KB(x, v) (HW_PXP_HW_PXP_LUT_CTRL_WR(x, (HW_PXP_HW_PXP_LUT_CTRL_RD(x) & ~BM_PXP_HW_PXP_LUT_CTRL_SEL_8KB) | BF_PXP_HW_PXP_LUT_CTRL_SEL_8KB(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_LUT_CTRL, field RSVD1[15:11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_LUT_CTRL_RSVD1 (11U) /*!< Bit position for PXP_HW_PXP_LUT_CTRL_RSVD1. */
#define BM_PXP_HW_PXP_LUT_CTRL_RSVD1 (0x0000F800U) /*!< Bit mask for PXP_HW_PXP_LUT_CTRL_RSVD1. */
#define BS_PXP_HW_PXP_LUT_CTRL_RSVD1 (5U)  /*!< Bit field size in bits for PXP_HW_PXP_LUT_CTRL_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_LUT_CTRL_RSVD1 field. */
#define BR_PXP_HW_PXP_LUT_CTRL_RSVD1(x) (HW_PXP_HW_PXP_LUT_CTRL(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_LUT_CTRL, field OUT_MODE[17:16] (RW)
 *
 * Select the output mode of operation for the LUT resource. There are four
 * bytes [3-0] in the data path at the output of the LUT resource. Byte lane 3 is
 * always bypassed and usually contains an alpha value. The LUT can be programmed to
 * transform bytes 2,1,0 according to the options available in this field.
 *
 * Values:
 * - 0 - Reserved, not valid when using the LUT to transform pixels.
 * - 1 - R/Y byte lane 2 lookup, bytes 1,0 bypassed.
 * - 10 - Byte lane 2 = CFA_Y8, byte lane 1,0 = RGBW4444.
 * - 11 - RGB565->RGB888 conversion for Gamma correction.
 */
/*@{*/
#define BP_PXP_HW_PXP_LUT_CTRL_OUT_MODE (16U) /*!< Bit position for PXP_HW_PXP_LUT_CTRL_OUT_MODE. */
#define BM_PXP_HW_PXP_LUT_CTRL_OUT_MODE (0x00030000U) /*!< Bit mask for PXP_HW_PXP_LUT_CTRL_OUT_MODE. */
#define BS_PXP_HW_PXP_LUT_CTRL_OUT_MODE (2U) /*!< Bit field size in bits for PXP_HW_PXP_LUT_CTRL_OUT_MODE. */

#define BV_PXP_HW_PXP_LUT_CTRL_OUT_MODE_RESERVED (0U) /*!< Bit field value for PXP_HW_PXP_LUT_CTRL_OUT_MODE: Reserved, not valid when using the LUT to transform pixels. */
#define BV_PXP_HW_PXP_LUT_CTRL_OUT_MODE_Y8 (0x1U)    /*!< Bit field value for PXP_HW_PXP_LUT_CTRL_OUT_MODE: R/Y byte lane 2 lookup, bytes 1,0 bypassed. */
#define BV_PXP_HW_PXP_LUT_CTRL_OUT_MODE_RGBW4444CFA (0x2U) /*!< Bit field value for PXP_HW_PXP_LUT_CTRL_OUT_MODE: Byte lane 2 = CFA_Y8, byte lane 1,0 = RGBW4444. */
#define BV_PXP_HW_PXP_LUT_CTRL_OUT_MODE_RGB888 (0x3U) /*!< Bit field value for PXP_HW_PXP_LUT_CTRL_OUT_MODE: RGB565->RGB888 conversion for Gamma correction. */

/*! @brief Read current value of the PXP_HW_PXP_LUT_CTRL_OUT_MODE field. */
#define BR_PXP_HW_PXP_LUT_CTRL_OUT_MODE(x) (HW_PXP_HW_PXP_LUT_CTRL(x).B.OUT_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_LUT_CTRL_OUT_MODE. */
#define BF_PXP_HW_PXP_LUT_CTRL_OUT_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_LUT_CTRL_OUT_MODE) & BM_PXP_HW_PXP_LUT_CTRL_OUT_MODE)

/*! @brief Set the OUT_MODE field to a new value. */
#define BW_PXP_HW_PXP_LUT_CTRL_OUT_MODE(x, v) (HW_PXP_HW_PXP_LUT_CTRL_WR(x, (HW_PXP_HW_PXP_LUT_CTRL_RD(x) & ~BM_PXP_HW_PXP_LUT_CTRL_OUT_MODE) | BF_PXP_HW_PXP_LUT_CTRL_OUT_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_LUT_CTRL, field RSVD2[23:18] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_LUT_CTRL_RSVD2 (18U) /*!< Bit position for PXP_HW_PXP_LUT_CTRL_RSVD2. */
#define BM_PXP_HW_PXP_LUT_CTRL_RSVD2 (0x00FC0000U) /*!< Bit mask for PXP_HW_PXP_LUT_CTRL_RSVD2. */
#define BS_PXP_HW_PXP_LUT_CTRL_RSVD2 (6U)  /*!< Bit field size in bits for PXP_HW_PXP_LUT_CTRL_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_LUT_CTRL_RSVD2 field. */
#define BR_PXP_HW_PXP_LUT_CTRL_RSVD2(x) (HW_PXP_HW_PXP_LUT_CTRL(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_LUT_CTRL, field LOOKUP_MODE[25:24] (RW)
 *
 * Configure the input address for the 16KB LUT memory. The address into the LUT
 * uses different parts of the pixel data path bytes. The data path is defined
 * as three bytes, conceptually as RGB/YUV/YCbCr[23:0]. Also referred to as
 * R/Y[7:0],G/U[7:0],B/V[7:0]
 *
 * Values:
 * - 0 - LUT ADDR = R[7:3],G[7:2],B[7:3]. Use all 16KB of LUT for indirect
 *     cached 128KB lookup.
 * - 1 - LUT ADDR = 16'b0,Y[7:0]. Use only the first 256 bytes of LUT. Only the
 *     Y, or third data path byte, is tranformed.
 * - 10 - LUT ADDR = R[7:4],G[7:4],B[7:4]. Use one 8KB bank of LUT selected by
 *     SEL_8KB.
 * - 11 - LUT ADDR = R[7:4],G[7:3],B[7:4]. Use all 16KB of LUT.
 */
/*@{*/
#define BP_PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE (24U) /*!< Bit position for PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE. */
#define BM_PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE (0x03000000U) /*!< Bit mask for PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE. */
#define BS_PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE (2U) /*!< Bit field size in bits for PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE. */

#define BV_PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE_CACHE_RGB565 (0U) /*!< Bit field value for PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE: LUT ADDR = R[7:3],G[7:2],B[7:3]. Use all 16KB of LUT for indirect cached 128KB lookup. */
#define BV_PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE_DIRECT_Y8 (0x1U) /*!< Bit field value for PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE: LUT ADDR = 16'b0,Y[7:0]. Use only the first 256 bytes of LUT. Only the Y, or third data path byte, is tranformed. */
#define BV_PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE_DIRECT_RGB444 (0x2U) /*!< Bit field value for PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE: LUT ADDR = R[7:4],G[7:4],B[7:4]. Use one 8KB bank of LUT selected by SEL_8KB. */
#define BV_PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE_DIRECT_RGB454 (0x3U) /*!< Bit field value for PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE: LUT ADDR = R[7:4],G[7:3],B[7:4]. Use all 16KB of LUT. */

/*! @brief Read current value of the PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE field. */
#define BR_PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE(x) (HW_PXP_HW_PXP_LUT_CTRL(x).B.LOOKUP_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE. */
#define BF_PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE) & BM_PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE)

/*! @brief Set the LOOKUP_MODE field to a new value. */
#define BW_PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE(x, v) (HW_PXP_HW_PXP_LUT_CTRL_WR(x, (HW_PXP_HW_PXP_LUT_CTRL_RD(x) & ~BM_PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE) | BF_PXP_HW_PXP_LUT_CTRL_LOOKUP_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_LUT_CTRL, field RSVD3[30:26] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_LUT_CTRL_RSVD3 (26U) /*!< Bit position for PXP_HW_PXP_LUT_CTRL_RSVD3. */
#define BM_PXP_HW_PXP_LUT_CTRL_RSVD3 (0x7C000000U) /*!< Bit mask for PXP_HW_PXP_LUT_CTRL_RSVD3. */
#define BS_PXP_HW_PXP_LUT_CTRL_RSVD3 (5U)  /*!< Bit field size in bits for PXP_HW_PXP_LUT_CTRL_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_LUT_CTRL_RSVD3 field. */
#define BR_PXP_HW_PXP_LUT_CTRL_RSVD3(x) (HW_PXP_HW_PXP_LUT_CTRL(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_LUT_CTRL, field BYPASS[31] (RW)
 *
 * Setting this bit will bypass the LUT memory resource completely. No pixel
 * transfermations will occur at this stage of the PXP pixel rpocessing pipeline.
 */
/*@{*/
#define BP_PXP_HW_PXP_LUT_CTRL_BYPASS (31U) /*!< Bit position for PXP_HW_PXP_LUT_CTRL_BYPASS. */
#define BM_PXP_HW_PXP_LUT_CTRL_BYPASS (0x80000000U) /*!< Bit mask for PXP_HW_PXP_LUT_CTRL_BYPASS. */
#define BS_PXP_HW_PXP_LUT_CTRL_BYPASS (1U) /*!< Bit field size in bits for PXP_HW_PXP_LUT_CTRL_BYPASS. */

/*! @brief Read current value of the PXP_HW_PXP_LUT_CTRL_BYPASS field. */
#define BR_PXP_HW_PXP_LUT_CTRL_BYPASS(x) (HW_PXP_HW_PXP_LUT_CTRL(x).B.BYPASS)

/*! @brief Format value for bitfield PXP_HW_PXP_LUT_CTRL_BYPASS. */
#define BF_PXP_HW_PXP_LUT_CTRL_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_LUT_CTRL_BYPASS) & BM_PXP_HW_PXP_LUT_CTRL_BYPASS)

/*! @brief Set the BYPASS field to a new value. */
#define BW_PXP_HW_PXP_LUT_CTRL_BYPASS(x, v) (HW_PXP_HW_PXP_LUT_CTRL_WR(x, (HW_PXP_HW_PXP_LUT_CTRL_RD(x) & ~BM_PXP_HW_PXP_LUT_CTRL_BYPASS) | BF_PXP_HW_PXP_LUT_CTRL_BYPASS(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_LUT_ADDR - Lookup Table Control Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_LUT_ADDR - Lookup Table Control Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to access/control the Monochrome Lookup table. The Y8
 * LUT input mode will take the high order data path byte and transform it using
 * the LUT memory. This is an 8-bit to 8-bit transformation. The two low order
 * bytes bypass the LUT and are not transformed, but bypassed without modification.
 * This option can be used for monochrome gamma correction. The Direct Lookup
 * mode will use the high nibble of each data byte and truncate the low nibble to
 * generate the lookup address, i.e. R[7:0]G[7:0]B[7:0] -> R[7:4]G[7:4]B[7:4]. 4K
 * pixels (12-bit address) with 2 bytes per pixel is supported in this mode.
 * Cached Lookup mode will use the high order bits, R[7:3],G[7:2],B[7:3] or RGB565, to
 * address the cached LUT memory. 64KB LUT tables, using 16KB of internal LUT
 * memory, can be indirectly transformed to 16-bit output pixels (as in
 * RGBW4444/RGB565). This is used for 16bpp gamma correction or EPD color panel support.
 * Cache misses are internally managed by the PXP LUT Cache controller.
 */
typedef union _hw_pxp_hw_pxp_lut_addr
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_lut_addr_bitfields
    {
        uint32_t ADDR : 14;            /*!< [13:0]  */
        uint32_t RSVD1 : 2;            /*!< [15:14]  */
        uint32_t NUM_BYTES : 15;       /*!< [30:16]  */
        uint32_t RSVD2 : 1;            /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_lut_addr_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_LUT_ADDR register
 */
/*@{*/
#define HW_PXP_HW_PXP_LUT_ADDR_ADDR(x) ((uintptr_t)(x) + 0x250U)

#define HW_PXP_HW_PXP_LUT_ADDR(x) (*(__IO hw_pxp_hw_pxp_lut_addr_t *) HW_PXP_HW_PXP_LUT_ADDR_ADDR(x))
#define HW_PXP_HW_PXP_LUT_ADDR_RD(x) (HW_PXP_HW_PXP_LUT_ADDR(x).U)
#define HW_PXP_HW_PXP_LUT_ADDR_WR(x, v) (HW_PXP_HW_PXP_LUT_ADDR(x).U = (v))
#define HW_PXP_HW_PXP_LUT_ADDR_SET(x, v) (HW_PXP_HW_PXP_LUT_ADDR_WR(x, HW_PXP_HW_PXP_LUT_ADDR_RD(x) |  (v)))
#define HW_PXP_HW_PXP_LUT_ADDR_CLR(x, v) (HW_PXP_HW_PXP_LUT_ADDR_WR(x, HW_PXP_HW_PXP_LUT_ADDR_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_LUT_ADDR_TOG(x, v) (HW_PXP_HW_PXP_LUT_ADDR_WR(x, HW_PXP_HW_PXP_LUT_ADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_LUT_ADDR bitfields
 */

/*!
 * @name Register PXP_HW_PXP_LUT_ADDR, field ADDR[13:0] (RW)
 *
 * LUT indexed address pointer. This address into the LUT memory is always four
 * byte aligned for PIO access, and eight byte aligned for DMA access. The least
 * two significant bits are not used to drive the LUT memory array. For PIO LUT
 * access, when the LUT data register is written, the contents of the LUT at the
 * address specified by this address field will be loaded with a 32-bit DWORD.
 * This address pointer will be incremented after the LUT data is written. This will
 * provide recursive writes to the LUT data register to initialize the entire
 * LUT array with recursive writes to the LUT data register. For DMA access, this
 * register indicates the LUT memory address of the 8 byte QWORD to be loaded.
 * When using the NUM_BYTES field to load more than 8 bytes, the register should be
 * programmed with the first LUT memory location to be filled and each load of
 * the LUT memory will increment this address field until NUM_BYTES has been loaded.
 */
/*@{*/
#define BP_PXP_HW_PXP_LUT_ADDR_ADDR (0U)   /*!< Bit position for PXP_HW_PXP_LUT_ADDR_ADDR. */
#define BM_PXP_HW_PXP_LUT_ADDR_ADDR (0x00003FFFU) /*!< Bit mask for PXP_HW_PXP_LUT_ADDR_ADDR. */
#define BS_PXP_HW_PXP_LUT_ADDR_ADDR (14U)  /*!< Bit field size in bits for PXP_HW_PXP_LUT_ADDR_ADDR. */

/*! @brief Read current value of the PXP_HW_PXP_LUT_ADDR_ADDR field. */
#define BR_PXP_HW_PXP_LUT_ADDR_ADDR(x) (HW_PXP_HW_PXP_LUT_ADDR(x).B.ADDR)

/*! @brief Format value for bitfield PXP_HW_PXP_LUT_ADDR_ADDR. */
#define BF_PXP_HW_PXP_LUT_ADDR_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_LUT_ADDR_ADDR) & BM_PXP_HW_PXP_LUT_ADDR_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_PXP_HW_PXP_LUT_ADDR_ADDR(x, v) (HW_PXP_HW_PXP_LUT_ADDR_WR(x, (HW_PXP_HW_PXP_LUT_ADDR_RD(x) & ~BM_PXP_HW_PXP_LUT_ADDR_ADDR) | BF_PXP_HW_PXP_LUT_ADDR_ADDR(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_LUT_ADDR, field RSVD1[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_LUT_ADDR_RSVD1 (14U) /*!< Bit position for PXP_HW_PXP_LUT_ADDR_RSVD1. */
#define BM_PXP_HW_PXP_LUT_ADDR_RSVD1 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_LUT_ADDR_RSVD1. */
#define BS_PXP_HW_PXP_LUT_ADDR_RSVD1 (2U)  /*!< Bit field size in bits for PXP_HW_PXP_LUT_ADDR_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_LUT_ADDR_RSVD1 field. */
#define BR_PXP_HW_PXP_LUT_ADDR_RSVD1(x) (HW_PXP_HW_PXP_LUT_ADDR(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_LUT_ADDR, field NUM_BYTES[30:16] (RW)
 *
 * Indicates the number of bytes to load via a DMA operation. This field must be
 * divisable by 8 and the least significant 3 bits must be 0. The value 8
 * indicates load 8 bytes from the external address indicated by REG_LUT_MEM_ADDR to
 * the LUT memory location indicated by REG_LUT_CTRL_ADDR.
 */
/*@{*/
#define BP_PXP_HW_PXP_LUT_ADDR_NUM_BYTES (16U) /*!< Bit position for PXP_HW_PXP_LUT_ADDR_NUM_BYTES. */
#define BM_PXP_HW_PXP_LUT_ADDR_NUM_BYTES (0x7FFF0000U) /*!< Bit mask for PXP_HW_PXP_LUT_ADDR_NUM_BYTES. */
#define BS_PXP_HW_PXP_LUT_ADDR_NUM_BYTES (15U) /*!< Bit field size in bits for PXP_HW_PXP_LUT_ADDR_NUM_BYTES. */

/*! @brief Read current value of the PXP_HW_PXP_LUT_ADDR_NUM_BYTES field. */
#define BR_PXP_HW_PXP_LUT_ADDR_NUM_BYTES(x) (HW_PXP_HW_PXP_LUT_ADDR(x).B.NUM_BYTES)

/*! @brief Format value for bitfield PXP_HW_PXP_LUT_ADDR_NUM_BYTES. */
#define BF_PXP_HW_PXP_LUT_ADDR_NUM_BYTES(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_LUT_ADDR_NUM_BYTES) & BM_PXP_HW_PXP_LUT_ADDR_NUM_BYTES)

/*! @brief Set the NUM_BYTES field to a new value. */
#define BW_PXP_HW_PXP_LUT_ADDR_NUM_BYTES(x, v) (HW_PXP_HW_PXP_LUT_ADDR_WR(x, (HW_PXP_HW_PXP_LUT_ADDR_RD(x) & ~BM_PXP_HW_PXP_LUT_ADDR_NUM_BYTES) | BF_PXP_HW_PXP_LUT_ADDR_NUM_BYTES(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_LUT_ADDR, field RSVD2[31] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_LUT_ADDR_RSVD2 (31U) /*!< Bit position for PXP_HW_PXP_LUT_ADDR_RSVD2. */
#define BM_PXP_HW_PXP_LUT_ADDR_RSVD2 (0x80000000U) /*!< Bit mask for PXP_HW_PXP_LUT_ADDR_RSVD2. */
#define BS_PXP_HW_PXP_LUT_ADDR_RSVD2 (1U)  /*!< Bit field size in bits for PXP_HW_PXP_LUT_ADDR_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_LUT_ADDR_RSVD2 field. */
#define BR_PXP_HW_PXP_LUT_ADDR_RSVD2(x) (HW_PXP_HW_PXP_LUT_ADDR(x).B.RSVD2)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_LUT_DATA - Lookup Table Data Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_LUT_DATA - Lookup Table Data Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to load data into the lookup table.
 */
typedef union _hw_pxp_hw_pxp_lut_data
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_lut_data_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_lut_data_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_LUT_DATA register
 */
/*@{*/
#define HW_PXP_HW_PXP_LUT_DATA_ADDR(x) ((uintptr_t)(x) + 0x260U)

#define HW_PXP_HW_PXP_LUT_DATA(x) (*(__IO hw_pxp_hw_pxp_lut_data_t *) HW_PXP_HW_PXP_LUT_DATA_ADDR(x))
#define HW_PXP_HW_PXP_LUT_DATA_RD(x) (HW_PXP_HW_PXP_LUT_DATA(x).U)
#define HW_PXP_HW_PXP_LUT_DATA_WR(x, v) (HW_PXP_HW_PXP_LUT_DATA(x).U = (v))
#define HW_PXP_HW_PXP_LUT_DATA_SET(x, v) (HW_PXP_HW_PXP_LUT_DATA_WR(x, HW_PXP_HW_PXP_LUT_DATA_RD(x) |  (v)))
#define HW_PXP_HW_PXP_LUT_DATA_CLR(x, v) (HW_PXP_HW_PXP_LUT_DATA_WR(x, HW_PXP_HW_PXP_LUT_DATA_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_LUT_DATA_TOG(x, v) (HW_PXP_HW_PXP_LUT_DATA_WR(x, HW_PXP_HW_PXP_LUT_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_LUT_DATA bitfields
 */

/*!
 * @name Register PXP_HW_PXP_LUT_DATA, field DATA[31:0] (RW)
 *
 * Writing this field will load 4 bytes, aligned to four byte boundaries, of
 * data indexed by the ADDR field of the REG_LUT_CTRL register.
 */
/*@{*/
#define BP_PXP_HW_PXP_LUT_DATA_DATA (0U)   /*!< Bit position for PXP_HW_PXP_LUT_DATA_DATA. */
#define BM_PXP_HW_PXP_LUT_DATA_DATA (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_LUT_DATA_DATA. */
#define BS_PXP_HW_PXP_LUT_DATA_DATA (32U)  /*!< Bit field size in bits for PXP_HW_PXP_LUT_DATA_DATA. */

/*! @brief Read current value of the PXP_HW_PXP_LUT_DATA_DATA field. */
#define BR_PXP_HW_PXP_LUT_DATA_DATA(x) (HW_PXP_HW_PXP_LUT_DATA(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_LUT_DATA_DATA. */
#define BF_PXP_HW_PXP_LUT_DATA_DATA(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_LUT_DATA_DATA) & BM_PXP_HW_PXP_LUT_DATA_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_PXP_HW_PXP_LUT_DATA_DATA(x, v) (HW_PXP_HW_PXP_LUT_DATA_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_LUT_EXTMEM - Lookup Table External Memory Address Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_LUT_EXTMEM - Lookup Table External Memory Address Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used as the external memory base address for LUT data
 * transfers. For DMA LUT memory loads, this is the base address from which data will
 * be sourced to store into the LUT memory array. For Cached LUT memory pixel
 * transformations, this register will store the base address of the full 64K pixel
 * LUT translation table.
 */
typedef union _hw_pxp_hw_pxp_lut_extmem
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_lut_extmem_bitfields
    {
        uint32_t ADDR : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_lut_extmem_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_LUT_EXTMEM register
 */
/*@{*/
#define HW_PXP_HW_PXP_LUT_EXTMEM_ADDR(x) ((uintptr_t)(x) + 0x270U)

#define HW_PXP_HW_PXP_LUT_EXTMEM(x) (*(__IO hw_pxp_hw_pxp_lut_extmem_t *) HW_PXP_HW_PXP_LUT_EXTMEM_ADDR(x))
#define HW_PXP_HW_PXP_LUT_EXTMEM_RD(x) (HW_PXP_HW_PXP_LUT_EXTMEM(x).U)
#define HW_PXP_HW_PXP_LUT_EXTMEM_WR(x, v) (HW_PXP_HW_PXP_LUT_EXTMEM(x).U = (v))
#define HW_PXP_HW_PXP_LUT_EXTMEM_SET(x, v) (HW_PXP_HW_PXP_LUT_EXTMEM_WR(x, HW_PXP_HW_PXP_LUT_EXTMEM_RD(x) |  (v)))
#define HW_PXP_HW_PXP_LUT_EXTMEM_CLR(x, v) (HW_PXP_HW_PXP_LUT_EXTMEM_WR(x, HW_PXP_HW_PXP_LUT_EXTMEM_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_LUT_EXTMEM_TOG(x, v) (HW_PXP_HW_PXP_LUT_EXTMEM_WR(x, HW_PXP_HW_PXP_LUT_EXTMEM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_LUT_EXTMEM bitfields
 */

/*!
 * @name Register PXP_HW_PXP_LUT_EXTMEM, field ADDR[31:0] (RW)
 *
 * This register contains the external memory address used for LUT memory
 * operation.
 */
/*@{*/
#define BP_PXP_HW_PXP_LUT_EXTMEM_ADDR (0U) /*!< Bit position for PXP_HW_PXP_LUT_EXTMEM_ADDR. */
#define BM_PXP_HW_PXP_LUT_EXTMEM_ADDR (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_LUT_EXTMEM_ADDR. */
#define BS_PXP_HW_PXP_LUT_EXTMEM_ADDR (32U) /*!< Bit field size in bits for PXP_HW_PXP_LUT_EXTMEM_ADDR. */

/*! @brief Read current value of the PXP_HW_PXP_LUT_EXTMEM_ADDR field. */
#define BR_PXP_HW_PXP_LUT_EXTMEM_ADDR(x) (HW_PXP_HW_PXP_LUT_EXTMEM(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_LUT_EXTMEM_ADDR. */
#define BF_PXP_HW_PXP_LUT_EXTMEM_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_LUT_EXTMEM_ADDR) & BM_PXP_HW_PXP_LUT_EXTMEM_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_PXP_HW_PXP_LUT_EXTMEM_ADDR(x, v) (HW_PXP_HW_PXP_LUT_EXTMEM_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_CFA - Color Filter Array Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_CFA - Color Filter Array Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the pattern of the CFA mapping within PXP macro
 * blocks. There are sixteen 2 bit values in this register each mapping a selected
 * component to the output pixel. The two bit values are defined as 0=>R, 1=>G, 2=>B,
 * and 3=>W. The first byte represents the repetitive pattern of RGBW pixels in
 * the CFA for the first line segment of each processed PXP block. The second
 * byte represents the pattern in the second line segment of the block, and so on.
 * The first byte repeats two times for 8x8 macro block mode, and repeats four
 * times for 16x16 block mode.
 */
typedef union _hw_pxp_hw_pxp_cfa
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_cfa_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_cfa_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_CFA register
 */
/*@{*/
#define HW_PXP_HW_PXP_CFA_ADDR(x) ((uintptr_t)(x) + 0x280U)

#define HW_PXP_HW_PXP_CFA(x)     (*(__IO hw_pxp_hw_pxp_cfa_t *) HW_PXP_HW_PXP_CFA_ADDR(x))
#define HW_PXP_HW_PXP_CFA_RD(x)  (HW_PXP_HW_PXP_CFA(x).U)
#define HW_PXP_HW_PXP_CFA_WR(x, v) (HW_PXP_HW_PXP_CFA(x).U = (v))
#define HW_PXP_HW_PXP_CFA_SET(x, v) (HW_PXP_HW_PXP_CFA_WR(x, HW_PXP_HW_PXP_CFA_RD(x) |  (v)))
#define HW_PXP_HW_PXP_CFA_CLR(x, v) (HW_PXP_HW_PXP_CFA_WR(x, HW_PXP_HW_PXP_CFA_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_CFA_TOG(x, v) (HW_PXP_HW_PXP_CFA_WR(x, HW_PXP_HW_PXP_CFA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_CFA bitfields
 */

/*!
 * @name Register PXP_HW_PXP_CFA, field DATA[31:0] (RW)
 *
 * This register contains the Color Filter Array pattern for decimation of
 * RGBW4444 16 bit pixels to individual R, G, B, W values. The pattern represents a
 * replicated 4x4 color filter array for the entire output frame buffer.
 */
/*@{*/
#define BP_PXP_HW_PXP_CFA_DATA (0U)        /*!< Bit position for PXP_HW_PXP_CFA_DATA. */
#define BM_PXP_HW_PXP_CFA_DATA (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_CFA_DATA. */
#define BS_PXP_HW_PXP_CFA_DATA (32U)       /*!< Bit field size in bits for PXP_HW_PXP_CFA_DATA. */

/*! @brief Read current value of the PXP_HW_PXP_CFA_DATA field. */
#define BR_PXP_HW_PXP_CFA_DATA(x) (HW_PXP_HW_PXP_CFA(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_CFA_DATA. */
#define BF_PXP_HW_PXP_CFA_DATA(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CFA_DATA) & BM_PXP_HW_PXP_CFA_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_PXP_HW_PXP_CFA_DATA(x, v) (HW_PXP_HW_PXP_CFA_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_ALPHA_A_CTRL - PXP Alpha Engine A Control Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_ALPHA_A_CTRL - PXP Alpha Engine A Control Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register controls alpha blending function in PXP.
 */
typedef union _hw_pxp_hw_pxp_alpha_a_ctrl
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_alpha_a_ctrl_bitfields
    {
        uint32_t POTER_DUFF_ENABLE : 1; /*!< [0]  */
        uint32_t S0_S1_FACTOR_MODE : 2; /*!< [2:1]  */
        uint32_t S0_GLOBAL_ALPHA_MODE : 2; /*!< [4:3]  */
        uint32_t S0_ALPHA_MODE : 1;    /*!< [5]  */
        uint32_t S0_COLOR_MODE : 1;    /*!< [6]  */
        uint32_t RSVD1 : 1;            /*!< [7]  */
        uint32_t S1_S0_FACTOR_MODE : 2; /*!< [9:8]  */
        uint32_t S1_GLOBAL_ALPHA_MODE : 2; /*!< [11:10]  */
        uint32_t S1_ALPHA_MODE : 1;    /*!< [12]  */
        uint32_t S1_COLOR_MODE : 1;    /*!< [13]  */
        uint32_t RSVD0 : 2;            /*!< [15:14]  */
        uint32_t S0_GLOBAL_ALPHA : 8;  /*!< [23:16]  */
        uint32_t S1_GLOBAL_ALPHA : 8;  /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_alpha_a_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_ALPHA_A_CTRL register
 */
/*@{*/
#define HW_PXP_HW_PXP_ALPHA_A_CTRL_ADDR(x) ((uintptr_t)(x) + 0x290U)

#define HW_PXP_HW_PXP_ALPHA_A_CTRL(x) (*(__IO hw_pxp_hw_pxp_alpha_a_ctrl_t *) HW_PXP_HW_PXP_ALPHA_A_CTRL_ADDR(x))
#define HW_PXP_HW_PXP_ALPHA_A_CTRL_RD(x) (HW_PXP_HW_PXP_ALPHA_A_CTRL(x).U)
#define HW_PXP_HW_PXP_ALPHA_A_CTRL_WR(x, v) (HW_PXP_HW_PXP_ALPHA_A_CTRL(x).U = (v))
#define HW_PXP_HW_PXP_ALPHA_A_CTRL_SET(x, v) (HW_PXP_HW_PXP_ALPHA_A_CTRL_WR(x, HW_PXP_HW_PXP_ALPHA_A_CTRL_RD(x) |  (v)))
#define HW_PXP_HW_PXP_ALPHA_A_CTRL_CLR(x, v) (HW_PXP_HW_PXP_ALPHA_A_CTRL_WR(x, HW_PXP_HW_PXP_ALPHA_A_CTRL_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_ALPHA_A_CTRL_TOG(x, v) (HW_PXP_HW_PXP_ALPHA_A_CTRL_WR(x, HW_PXP_HW_PXP_ALPHA_A_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_ALPHA_A_CTRL bitfields
 */

/*!
 * @name Register PXP_HW_PXP_ALPHA_A_CTRL, field POTER_DUFF_ENABLE[0] (RW)
 *
 * poter_duff enable
 *
 * Values:
 * - 0 - porter duff disable.
 * - 1 - porter duff enable.
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE (0U) /*!< Bit position for PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE. */
#define BM_PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE (0x00000001U) /*!< Bit mask for PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE. */
#define BS_PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE (1U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE. */

#define BV_PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE_0 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE: porter duff disable. */
#define BV_PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE: porter duff enable. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE field. */
#define BR_PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE(x) (HW_PXP_HW_PXP_ALPHA_A_CTRL(x).B.POTER_DUFF_ENABLE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE. */
#define BF_PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE) & BM_PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE)

/*! @brief Set the POTER_DUFF_ENABLE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE(x, v) (HW_PXP_HW_PXP_ALPHA_A_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_A_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE) | BF_PXP_HW_PXP_ALPHA_A_CTRL_POTER_DUFF_ENABLE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_A_CTRL, field S0_S1_FACTOR_MODE[2:1] (RW)
 *
 * s0 to s1 factor mode
 *
 * Values:
 * - 0 - using 1.
 * - 1 - using 0.
 * - 10 - using straight alpha.
 * - 11 - using inverse alpha.
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE (1U) /*!< Bit position for PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE. */
#define BM_PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE (0x00000006U) /*!< Bit mask for PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE. */
#define BS_PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE (2U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE. */

#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE_0 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE: using 1. */
#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE: using 0. */
#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE: using straight alpha. */
#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE: using inverse alpha. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE field. */
#define BR_PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE(x) (HW_PXP_HW_PXP_ALPHA_A_CTRL(x).B.S0_S1_FACTOR_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE. */
#define BF_PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE) & BM_PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE)

/*! @brief Set the S0_S1_FACTOR_MODE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE(x, v) (HW_PXP_HW_PXP_ALPHA_A_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_A_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE) | BF_PXP_HW_PXP_ALPHA_A_CTRL_S0_S1_FACTOR_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_A_CTRL, field S0_GLOBAL_ALPHA_MODE[4:3] (RW)
 *
 * s0 global alpha mode
 *
 * Values:
 * - 0 - using global alpha.
 * - 1 - using local alpha.
 * - 10 - using scaled alpha.
 * - 11 - using scaled alpha.
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE (3U) /*!< Bit position for PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE. */
#define BM_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE (0x00000018U) /*!< Bit mask for PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE. */
#define BS_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE (2U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE. */

#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE_0 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE: using global alpha. */
#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE: using local alpha. */
#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE: using scaled alpha. */
#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE: using scaled alpha. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE field. */
#define BR_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE(x) (HW_PXP_HW_PXP_ALPHA_A_CTRL(x).B.S0_GLOBAL_ALPHA_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE. */
#define BF_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE) & BM_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE)

/*! @brief Set the S0_GLOBAL_ALPHA_MODE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE(x, v) (HW_PXP_HW_PXP_ALPHA_A_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_A_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE) | BF_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_A_CTRL, field S0_ALPHA_MODE[5] (RW)
 *
 * s0 alpha mode
 *
 * Values:
 * - 0 - straight mode for s0 alpha
 * - 1 - inversed mode for s0 alpha
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE (5U) /*!< Bit position for PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE. */
#define BM_PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE (0x00000020U) /*!< Bit mask for PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE. */
#define BS_PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE (1U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE. */

#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE_0 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE: straight mode for s0 alpha */
#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE: inversed mode for s0 alpha */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE field. */
#define BR_PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE(x) (HW_PXP_HW_PXP_ALPHA_A_CTRL(x).B.S0_ALPHA_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE. */
#define BF_PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE) & BM_PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE)

/*! @brief Set the S0_ALPHA_MODE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE(x, v) (HW_PXP_HW_PXP_ALPHA_A_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_A_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE) | BF_PXP_HW_PXP_ALPHA_A_CTRL_S0_ALPHA_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_A_CTRL, field S0_COLOR_MODE[6] (RW)
 *
 * s0 color mode
 *
 * Values:
 * - 0 - straight mode for s0 color
 * - 1 - multiply mode for s0 color
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE (6U) /*!< Bit position for PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE. */
#define BM_PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE (0x00000040U) /*!< Bit mask for PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE. */
#define BS_PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE (1U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE. */

#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE_0 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE: straight mode for s0 color */
#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE: multiply mode for s0 color */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE field. */
#define BR_PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE(x) (HW_PXP_HW_PXP_ALPHA_A_CTRL(x).B.S0_COLOR_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE. */
#define BF_PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE) & BM_PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE)

/*! @brief Set the S0_COLOR_MODE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE(x, v) (HW_PXP_HW_PXP_ALPHA_A_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_A_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE) | BF_PXP_HW_PXP_ALPHA_A_CTRL_S0_COLOR_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_A_CTRL, field RSVD1[7] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_A_CTRL_RSVD1 (7U) /*!< Bit position for PXP_HW_PXP_ALPHA_A_CTRL_RSVD1. */
#define BM_PXP_HW_PXP_ALPHA_A_CTRL_RSVD1 (0x00000080U) /*!< Bit mask for PXP_HW_PXP_ALPHA_A_CTRL_RSVD1. */
#define BS_PXP_HW_PXP_ALPHA_A_CTRL_RSVD1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_A_CTRL_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_A_CTRL_RSVD1 field. */
#define BR_PXP_HW_PXP_ALPHA_A_CTRL_RSVD1(x) (HW_PXP_HW_PXP_ALPHA_A_CTRL(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_A_CTRL, field S1_S0_FACTOR_MODE[9:8] (RW)
 *
 * s1 to s0 factor mode
 *
 * Values:
 * - 0 - using 1.
 * - 1 - using 0.
 * - 10 - using straight alpha.
 * - 11 - using inverse alpha.
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE (8U) /*!< Bit position for PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE. */
#define BM_PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE (0x00000300U) /*!< Bit mask for PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE. */
#define BS_PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE (2U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE. */

#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE_0 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE: using 1. */
#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE: using 0. */
#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE: using straight alpha. */
#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE: using inverse alpha. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE field. */
#define BR_PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE(x) (HW_PXP_HW_PXP_ALPHA_A_CTRL(x).B.S1_S0_FACTOR_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE. */
#define BF_PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE) & BM_PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE)

/*! @brief Set the S1_S0_FACTOR_MODE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE(x, v) (HW_PXP_HW_PXP_ALPHA_A_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_A_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE) | BF_PXP_HW_PXP_ALPHA_A_CTRL_S1_S0_FACTOR_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_A_CTRL, field S1_GLOBAL_ALPHA_MODE[11:10] (RW)
 *
 * s1 global alpha mode
 *
 * Values:
 * - 0 - using global alpha.
 * - 0 - using local alpha.
 * - 0 - using scaled alpha.
 * - 0 - using scaled alpha.
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE (10U) /*!< Bit position for PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE. */
#define BM_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE (0x00000C00U) /*!< Bit mask for PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE. */
#define BS_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE (2U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE. */

#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE_0 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE: using global alpha. */
#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE_1 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE: using local alpha. */
#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE_2 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE: using scaled alpha. */
#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE_3 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE: using scaled alpha. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE field. */
#define BR_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE(x) (HW_PXP_HW_PXP_ALPHA_A_CTRL(x).B.S1_GLOBAL_ALPHA_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE. */
#define BF_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE) & BM_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE)

/*! @brief Set the S1_GLOBAL_ALPHA_MODE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE(x, v) (HW_PXP_HW_PXP_ALPHA_A_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_A_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE) | BF_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_A_CTRL, field S1_ALPHA_MODE[12] (RW)
 *
 * s1 alpha mode
 *
 * Values:
 * - 0 - straight mode for s1 alpha
 * - 1 - inversed mode for s1 alpha
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE (12U) /*!< Bit position for PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE. */
#define BM_PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE (0x00001000U) /*!< Bit mask for PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE. */
#define BS_PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE (1U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE. */

#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE_0 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE: straight mode for s1 alpha */
#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE: inversed mode for s1 alpha */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE field. */
#define BR_PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE(x) (HW_PXP_HW_PXP_ALPHA_A_CTRL(x).B.S1_ALPHA_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE. */
#define BF_PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE) & BM_PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE)

/*! @brief Set the S1_ALPHA_MODE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE(x, v) (HW_PXP_HW_PXP_ALPHA_A_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_A_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE) | BF_PXP_HW_PXP_ALPHA_A_CTRL_S1_ALPHA_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_A_CTRL, field S1_COLOR_MODE[13] (RW)
 *
 * s1 color mode
 *
 * Values:
 * - 0 - straight mode for s1 color
 * - 1 - multiply mode for s1 color
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE (13U) /*!< Bit position for PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE. */
#define BM_PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE (0x00002000U) /*!< Bit mask for PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE. */
#define BS_PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE (1U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE. */

#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE_0 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE: straight mode for s1 color */
#define BV_PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE: multiply mode for s1 color */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE field. */
#define BR_PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE(x) (HW_PXP_HW_PXP_ALPHA_A_CTRL(x).B.S1_COLOR_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE. */
#define BF_PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE) & BM_PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE)

/*! @brief Set the S1_COLOR_MODE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE(x, v) (HW_PXP_HW_PXP_ALPHA_A_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_A_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE) | BF_PXP_HW_PXP_ALPHA_A_CTRL_S1_COLOR_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_A_CTRL, field RSVD0[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_A_CTRL_RSVD0 (14U) /*!< Bit position for PXP_HW_PXP_ALPHA_A_CTRL_RSVD0. */
#define BM_PXP_HW_PXP_ALPHA_A_CTRL_RSVD0 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_ALPHA_A_CTRL_RSVD0. */
#define BS_PXP_HW_PXP_ALPHA_A_CTRL_RSVD0 (2U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_A_CTRL_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_A_CTRL_RSVD0 field. */
#define BR_PXP_HW_PXP_ALPHA_A_CTRL_RSVD0(x) (HW_PXP_HW_PXP_ALPHA_A_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_A_CTRL, field S0_GLOBAL_ALPHA[23:16] (RW)
 *
 * s0 global alpha
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA (16U) /*!< Bit position for PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA. */
#define BM_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA (0x00FF0000U) /*!< Bit mask for PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA. */
#define BS_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA (8U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA field. */
#define BR_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA(x) (HW_PXP_HW_PXP_ALPHA_A_CTRL(x).B.S0_GLOBAL_ALPHA)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA. */
#define BF_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA) & BM_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA)

/*! @brief Set the S0_GLOBAL_ALPHA field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA(x, v) (HW_PXP_HW_PXP_ALPHA_A_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_A_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA) | BF_PXP_HW_PXP_ALPHA_A_CTRL_S0_GLOBAL_ALPHA(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_A_CTRL, field S1_GLOBAL_ALPHA[31:24] (RW)
 *
 * s1 global alpha
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA (24U) /*!< Bit position for PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA. */
#define BM_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA. */
#define BS_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA (8U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA field. */
#define BR_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA(x) (HW_PXP_HW_PXP_ALPHA_A_CTRL(x).B.S1_GLOBAL_ALPHA)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA. */
#define BF_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA) & BM_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA)

/*! @brief Set the S1_GLOBAL_ALPHA field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA(x, v) (HW_PXP_HW_PXP_ALPHA_A_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_A_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA) | BF_PXP_HW_PXP_ALPHA_A_CTRL_S1_GLOBAL_ALPHA(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_ALPHA_B_CTRL - PXP Alpha Engine B Control Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_ALPHA_B_CTRL - PXP Alpha Engine B Control Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register controls alpha blending function in PXP.
 */
typedef union _hw_pxp_hw_pxp_alpha_b_ctrl
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_alpha_b_ctrl_bitfields
    {
        uint32_t POTER_DUFF_ENABLE : 1; /*!< [0]  */
        uint32_t S0_S1_FACTOR_MODE : 2; /*!< [2:1]  */
        uint32_t S0_GLOBAL_ALPHA_MODE : 2; /*!< [4:3]  */
        uint32_t S0_ALPHA_MODE : 1;    /*!< [5]  */
        uint32_t S0_COLOR_MODE : 1;    /*!< [6]  */
        uint32_t RSVD1 : 1;            /*!< [7]  */
        uint32_t S1_S0_FACTOR_MODE : 2; /*!< [9:8]  */
        uint32_t S1_GLOBAL_ALPHA_MODE : 2; /*!< [11:10]  */
        uint32_t S1_ALPHA_MODE : 1;    /*!< [12]  */
        uint32_t S1_COLOR_MODE : 1;    /*!< [13]  */
        uint32_t RSVD0 : 2;            /*!< [15:14]  */
        uint32_t S0_GLOBAL_ALPHA : 8;  /*!< [23:16]  */
        uint32_t S1_GLOBAL_ALPHA : 8;  /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_alpha_b_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_ALPHA_B_CTRL register
 */
/*@{*/
#define HW_PXP_HW_PXP_ALPHA_B_CTRL_ADDR(x) ((uintptr_t)(x) + 0x2A0U)

#define HW_PXP_HW_PXP_ALPHA_B_CTRL(x) (*(__IO hw_pxp_hw_pxp_alpha_b_ctrl_t *) HW_PXP_HW_PXP_ALPHA_B_CTRL_ADDR(x))
#define HW_PXP_HW_PXP_ALPHA_B_CTRL_RD(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL(x).U)
#define HW_PXP_HW_PXP_ALPHA_B_CTRL_WR(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL(x).U = (v))
#define HW_PXP_HW_PXP_ALPHA_B_CTRL_SET(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_WR(x, HW_PXP_HW_PXP_ALPHA_B_CTRL_RD(x) |  (v)))
#define HW_PXP_HW_PXP_ALPHA_B_CTRL_CLR(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_WR(x, HW_PXP_HW_PXP_ALPHA_B_CTRL_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_ALPHA_B_CTRL_TOG(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_WR(x, HW_PXP_HW_PXP_ALPHA_B_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_ALPHA_B_CTRL bitfields
 */

/*!
 * @name Register PXP_HW_PXP_ALPHA_B_CTRL, field POTER_DUFF_ENABLE[0] (RW)
 *
 * poter_duff enable
 *
 * Values:
 * - 0 - porter duff disable.
 * - 1 - porter duff enable.
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE (0U) /*!< Bit position for PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE. */
#define BM_PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE (0x00000001U) /*!< Bit mask for PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE. */
#define BS_PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE (1U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE. */

#define BV_PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE_0 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE: porter duff disable. */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE: porter duff enable. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE field. */
#define BR_PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL(x).B.POTER_DUFF_ENABLE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE. */
#define BF_PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE) & BM_PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE)

/*! @brief Set the POTER_DUFF_ENABLE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_B_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE) | BF_PXP_HW_PXP_ALPHA_B_CTRL_POTER_DUFF_ENABLE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_B_CTRL, field S0_S1_FACTOR_MODE[2:1] (RW)
 *
 * s0 to s1 factor mode
 *
 * Values:
 * - 0 - using 1.
 * - 1 - using 0.
 * - 10 - using straight alpha.
 * - 11 - using inverse alpha.
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE (1U) /*!< Bit position for PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE. */
#define BM_PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE (0x00000006U) /*!< Bit mask for PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE. */
#define BS_PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE (2U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE. */

#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE_0 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE: using 1. */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE: using 0. */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE: using straight alpha. */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE: using inverse alpha. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE field. */
#define BR_PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL(x).B.S0_S1_FACTOR_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE. */
#define BF_PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE) & BM_PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE)

/*! @brief Set the S0_S1_FACTOR_MODE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_B_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE) | BF_PXP_HW_PXP_ALPHA_B_CTRL_S0_S1_FACTOR_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_B_CTRL, field S0_GLOBAL_ALPHA_MODE[4:3] (RW)
 *
 * s0 global alpha mode
 *
 * Values:
 * - 0 - using global alpha.
 * - 1 - using local alpha.
 * - 10 - using scaled alpha.
 * - 11 - using scaled alpha.
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE (3U) /*!< Bit position for PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE. */
#define BM_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE (0x00000018U) /*!< Bit mask for PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE. */
#define BS_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE (2U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE. */

#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE_0 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE: using global alpha. */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE: using local alpha. */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE: using scaled alpha. */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE: using scaled alpha. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE field. */
#define BR_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL(x).B.S0_GLOBAL_ALPHA_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE. */
#define BF_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE) & BM_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE)

/*! @brief Set the S0_GLOBAL_ALPHA_MODE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_B_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE) | BF_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_B_CTRL, field S0_ALPHA_MODE[5] (RW)
 *
 * s0 alpha mode
 *
 * Values:
 * - 0 - straight mode for s0 alpha
 * - 1 - inversed mode for s0 alpha
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE (5U) /*!< Bit position for PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE. */
#define BM_PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE (0x00000020U) /*!< Bit mask for PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE. */
#define BS_PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE (1U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE. */

#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE_0 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE: straight mode for s0 alpha */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE: inversed mode for s0 alpha */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE field. */
#define BR_PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL(x).B.S0_ALPHA_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE. */
#define BF_PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE) & BM_PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE)

/*! @brief Set the S0_ALPHA_MODE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_B_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE) | BF_PXP_HW_PXP_ALPHA_B_CTRL_S0_ALPHA_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_B_CTRL, field S0_COLOR_MODE[6] (RW)
 *
 * s0 color mode
 *
 * Values:
 * - 0 - straight mode for s0 color
 * - 1 - multiply mode for s0 color
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE (6U) /*!< Bit position for PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE. */
#define BM_PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE (0x00000040U) /*!< Bit mask for PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE. */
#define BS_PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE (1U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE. */

#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE_0 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE: straight mode for s0 color */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE: multiply mode for s0 color */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE field. */
#define BR_PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL(x).B.S0_COLOR_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE. */
#define BF_PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE) & BM_PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE)

/*! @brief Set the S0_COLOR_MODE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_B_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE) | BF_PXP_HW_PXP_ALPHA_B_CTRL_S0_COLOR_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_B_CTRL, field RSVD1[7] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_B_CTRL_RSVD1 (7U) /*!< Bit position for PXP_HW_PXP_ALPHA_B_CTRL_RSVD1. */
#define BM_PXP_HW_PXP_ALPHA_B_CTRL_RSVD1 (0x00000080U) /*!< Bit mask for PXP_HW_PXP_ALPHA_B_CTRL_RSVD1. */
#define BS_PXP_HW_PXP_ALPHA_B_CTRL_RSVD1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_B_CTRL_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_B_CTRL_RSVD1 field. */
#define BR_PXP_HW_PXP_ALPHA_B_CTRL_RSVD1(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_B_CTRL, field S1_S0_FACTOR_MODE[9:8] (RW)
 *
 * s1 to s0 factor mode
 *
 * Values:
 * - 0 - using 1.
 * - 1 - using 0.
 * - 10 - using straight alpha.
 * - 11 - using inverse alpha.
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE (8U) /*!< Bit position for PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE. */
#define BM_PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE (0x00000300U) /*!< Bit mask for PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE. */
#define BS_PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE (2U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE. */

#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE_0 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE: using 1. */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE: using 0. */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE: using straight alpha. */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE: using inverse alpha. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE field. */
#define BR_PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL(x).B.S1_S0_FACTOR_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE. */
#define BF_PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE) & BM_PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE)

/*! @brief Set the S1_S0_FACTOR_MODE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_B_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE) | BF_PXP_HW_PXP_ALPHA_B_CTRL_S1_S0_FACTOR_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_B_CTRL, field S1_GLOBAL_ALPHA_MODE[11:10] (RW)
 *
 * s1 global alpha mode
 *
 * Values:
 * - 0 - using global alpha.
 * - 1 - using local alpha.
 * - 10 - using scaled alpha.
 * - 11 - using scaled alpha.
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE (10U) /*!< Bit position for PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE. */
#define BM_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE (0x00000C00U) /*!< Bit mask for PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE. */
#define BS_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE (2U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE. */

#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE_0 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE: using global alpha. */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE: using local alpha. */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE: using scaled alpha. */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE: using scaled alpha. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE field. */
#define BR_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL(x).B.S1_GLOBAL_ALPHA_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE. */
#define BF_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE) & BM_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE)

/*! @brief Set the S1_GLOBAL_ALPHA_MODE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_B_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE) | BF_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_B_CTRL, field S1_ALPHA_MODE[12] (RW)
 *
 * s1 alpha mode
 *
 * Values:
 * - 0 - straight mode for s1 alpha
 * - 1 - inversed mode for s1 alpha
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE (12U) /*!< Bit position for PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE. */
#define BM_PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE (0x00001000U) /*!< Bit mask for PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE. */
#define BS_PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE (1U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE. */

#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE_0 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE: straight mode for s1 alpha */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE: inversed mode for s1 alpha */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE field. */
#define BR_PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL(x).B.S1_ALPHA_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE. */
#define BF_PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE) & BM_PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE)

/*! @brief Set the S1_ALPHA_MODE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_B_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE) | BF_PXP_HW_PXP_ALPHA_B_CTRL_S1_ALPHA_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_B_CTRL, field S1_COLOR_MODE[13] (RW)
 *
 * s1 color mode
 *
 * Values:
 * - 0 - straight mode for s1 color
 * - 1 - multiply mode for s1 color
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE (13U) /*!< Bit position for PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE. */
#define BM_PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE (0x00002000U) /*!< Bit mask for PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE. */
#define BS_PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE (1U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE. */

#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE_0 (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE: straight mode for s1 color */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE: multiply mode for s1 color */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE field. */
#define BR_PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL(x).B.S1_COLOR_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE. */
#define BF_PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE) & BM_PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE)

/*! @brief Set the S1_COLOR_MODE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_B_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE) | BF_PXP_HW_PXP_ALPHA_B_CTRL_S1_COLOR_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_B_CTRL, field RSVD0[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_B_CTRL_RSVD0 (14U) /*!< Bit position for PXP_HW_PXP_ALPHA_B_CTRL_RSVD0. */
#define BM_PXP_HW_PXP_ALPHA_B_CTRL_RSVD0 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_ALPHA_B_CTRL_RSVD0. */
#define BS_PXP_HW_PXP_ALPHA_B_CTRL_RSVD0 (2U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_B_CTRL_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_B_CTRL_RSVD0 field. */
#define BR_PXP_HW_PXP_ALPHA_B_CTRL_RSVD0(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_B_CTRL, field S0_GLOBAL_ALPHA[23:16] (RW)
 *
 * s0 global alpha
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA (16U) /*!< Bit position for PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA. */
#define BM_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA (0x00FF0000U) /*!< Bit mask for PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA. */
#define BS_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA (8U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA field. */
#define BR_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL(x).B.S0_GLOBAL_ALPHA)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA. */
#define BF_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA) & BM_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA)

/*! @brief Set the S0_GLOBAL_ALPHA field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_B_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA) | BF_PXP_HW_PXP_ALPHA_B_CTRL_S0_GLOBAL_ALPHA(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_B_CTRL, field S1_GLOBAL_ALPHA[31:24] (RW)
 *
 * s1 global alpha
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA (24U) /*!< Bit position for PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA. */
#define BM_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA. */
#define BS_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA (8U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA field. */
#define BR_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL(x).B.S1_GLOBAL_ALPHA)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA. */
#define BF_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA) & BM_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA)

/*! @brief Set the S1_GLOBAL_ALPHA field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_WR(x, (HW_PXP_HW_PXP_ALPHA_B_CTRL_RD(x) & ~BM_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA) | BF_PXP_HW_PXP_ALPHA_B_CTRL_S1_GLOBAL_ALPHA(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_ALPHA_B_CTRL_1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_ALPHA_B_CTRL_1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines software define pixels for alpha blending. This
 * register defines alpha1 legacy blending parameters. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_alpha_b_ctrl_1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_alpha_b_ctrl_1_bitfields
    {
        uint32_t ROP_ENABLE : 1;       /*!< [0]  */
        uint32_t OL_CLRKEY_ENABLE : 1; /*!< [1]  */
        uint32_t RSVD1 : 2;            /*!< [3:2]  */
        uint32_t ROP : 4;              /*!< [7:4]  */
        uint32_t RSVD0 : 24;           /*!< [31:8]  */
    } B;
} hw_pxp_hw_pxp_alpha_b_ctrl_1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_ALPHA_B_CTRL_1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_ALPHA_B_CTRL_1_ADDR(x) ((uintptr_t)(x) + 0x2B0U)

#define HW_PXP_HW_PXP_ALPHA_B_CTRL_1(x) (*(__IO hw_pxp_hw_pxp_alpha_b_ctrl_1_t *) HW_PXP_HW_PXP_ALPHA_B_CTRL_1_ADDR(x))
#define HW_PXP_HW_PXP_ALPHA_B_CTRL_1_RD(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL_1(x).U)
#define HW_PXP_HW_PXP_ALPHA_B_CTRL_1_WR(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_1(x).U = (v))
#define HW_PXP_HW_PXP_ALPHA_B_CTRL_1_SET(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_1_WR(x, HW_PXP_HW_PXP_ALPHA_B_CTRL_1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_ALPHA_B_CTRL_1_CLR(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_1_WR(x, HW_PXP_HW_PXP_ALPHA_B_CTRL_1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_ALPHA_B_CTRL_1_TOG(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_1_WR(x, HW_PXP_HW_PXP_ALPHA_B_CTRL_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_ALPHA_B_CTRL_1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_ALPHA_B_CTRL_1, field ROP_ENABLE[0] (RW)
 *
 * ROP ENABLE
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_ENABLE (0U) /*!< Bit position for PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_ENABLE. */
#define BM_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_ENABLE (0x00000001U) /*!< Bit mask for PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_ENABLE. */
#define BS_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_ENABLE (1U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_ENABLE. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_ENABLE field. */
#define BR_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_ENABLE(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL_1(x).B.ROP_ENABLE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_ENABLE. */
#define BF_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_ENABLE) & BM_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_ENABLE)

/*! @brief Set the ROP_ENABLE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_ENABLE(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_1_WR(x, (HW_PXP_HW_PXP_ALPHA_B_CTRL_1_RD(x) & ~BM_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_ENABLE) | BF_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_ENABLE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_B_CTRL_1, field OL_CLRKEY_ENABLE[1] (RW)
 *
 * Indicates that colorkey functionality is enabled for this alpha surface.
 * Pixels found in the alpha surface colorkey range will be displayed as transparent
 * (the PS pixel will be used).
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_B_CTRL_1_OL_CLRKEY_ENABLE (1U) /*!< Bit position for PXP_HW_PXP_ALPHA_B_CTRL_1_OL_CLRKEY_ENABLE. */
#define BM_PXP_HW_PXP_ALPHA_B_CTRL_1_OL_CLRKEY_ENABLE (0x00000002U) /*!< Bit mask for PXP_HW_PXP_ALPHA_B_CTRL_1_OL_CLRKEY_ENABLE. */
#define BS_PXP_HW_PXP_ALPHA_B_CTRL_1_OL_CLRKEY_ENABLE (1U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_B_CTRL_1_OL_CLRKEY_ENABLE. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_B_CTRL_1_OL_CLRKEY_ENABLE field. */
#define BR_PXP_HW_PXP_ALPHA_B_CTRL_1_OL_CLRKEY_ENABLE(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL_1(x).B.OL_CLRKEY_ENABLE)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_B_CTRL_1_OL_CLRKEY_ENABLE. */
#define BF_PXP_HW_PXP_ALPHA_B_CTRL_1_OL_CLRKEY_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_B_CTRL_1_OL_CLRKEY_ENABLE) & BM_PXP_HW_PXP_ALPHA_B_CTRL_1_OL_CLRKEY_ENABLE)

/*! @brief Set the OL_CLRKEY_ENABLE field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_B_CTRL_1_OL_CLRKEY_ENABLE(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_1_WR(x, (HW_PXP_HW_PXP_ALPHA_B_CTRL_1_RD(x) & ~BM_PXP_HW_PXP_ALPHA_B_CTRL_1_OL_CLRKEY_ENABLE) | BF_PXP_HW_PXP_ALPHA_B_CTRL_1_OL_CLRKEY_ENABLE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_B_CTRL_1, field RSVD1[3:2] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD1 (2U) /*!< Bit position for PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD1. */
#define BM_PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD1 (0x0000000CU) /*!< Bit mask for PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD1. */
#define BS_PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD1 (2U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD1 field. */
#define BR_PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD1(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL_1(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_B_CTRL_1, field ROP[7:4] (RW)
 *
 * Indicates a raster operation to perform when enabled.
 *
 * Values:
 * - 0 - AS AND PS
 * - 1 - nAS AND PS
 * - 10 - AS AND nPS
 * - 11 - AS OR PS
 * - 100 - nAS OR PS
 * - 101 - AS OR nPS
 * - 110 - nAS
 * - 111 - nPS
 * - 1000 - AS NAND PS
 * - 1001 - AS NOR PS
 * - 1010 - AS XOR PS
 * - 1011 - AS XNOR PS
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP (4U) /*!< Bit position for PXP_HW_PXP_ALPHA_B_CTRL_1_ROP. */
#define BM_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP (0x000000F0U) /*!< Bit mask for PXP_HW_PXP_ALPHA_B_CTRL_1_ROP. */
#define BS_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP (4U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_B_CTRL_1_ROP. */

#define BV_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_MASKAS (0U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_1_ROP: AS AND PS */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_MASKNOTAS (0x1U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_1_ROP: nAS AND PS */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_MASKASNOT (0x2U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_1_ROP: AS AND nPS */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_MERGEAS (0x3U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_1_ROP: AS OR PS */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_MERGENOTAS (0x4U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_1_ROP: nAS OR PS */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_MERGEASNOT (0x5U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_1_ROP: AS OR nPS */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_NOTCOPYAS (0x6U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_1_ROP: nAS */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_NOT (0x7U)  /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_1_ROP: nPS */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_NOTMASKAS (0x8U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_1_ROP: AS NAND PS */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_NOTMERGEAS (0x9U) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_1_ROP: AS NOR PS */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_XORAS (0xAU) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_1_ROP: AS XOR PS */
#define BV_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP_NOTXORAS (0xBU) /*!< Bit field value for PXP_HW_PXP_ALPHA_B_CTRL_1_ROP: AS XNOR PS */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_B_CTRL_1_ROP field. */
#define BR_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL_1(x).B.ROP)

/*! @brief Format value for bitfield PXP_HW_PXP_ALPHA_B_CTRL_1_ROP. */
#define BF_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP) & BM_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP)

/*! @brief Set the ROP field to a new value. */
#define BW_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP(x, v) (HW_PXP_HW_PXP_ALPHA_B_CTRL_1_WR(x, (HW_PXP_HW_PXP_ALPHA_B_CTRL_1_RD(x) & ~BM_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP) | BF_PXP_HW_PXP_ALPHA_B_CTRL_1_ROP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_ALPHA_B_CTRL_1, field RSVD0[31:8] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD0 (8U) /*!< Bit position for PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD0. */
#define BM_PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD0 (0xFFFFFF00U) /*!< Bit mask for PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD0. */
#define BS_PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD0 (24U) /*!< Bit field size in bits for PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD0 field. */
#define BR_PXP_HW_PXP_ALPHA_B_CTRL_1_RSVD0(x) (HW_PXP_HW_PXP_ALPHA_B_CTRL_1(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_PS_BACKGROUND_1 - PS Background Color 1
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_PS_BACKGROUND_1 - PS Background Color 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * PS Background Pixel Color. This register provides a pixel value used when
 * processing pixels outside of the region specified by the PS Coordinate registers.
 * This value can effectively be used to set the color of the letterboxing
 * region around the PS image. This value is used by the Alpha B block. This register
 * contains a pixel value to be used for any PS pixels that fall outside the PS
 * extents. This is effectively a background or letterbox color. The CSC1 control
 * and datapath pixel format should be considered when selecting the background
 * color. EXAMPLE REG_PS_BACKGROUND_WR(0x00000000); // letterbox is black
 * REG_PS_BACKGROUND_WR(0x00800000); // letterbox is dark red
 * REG_PS_BACKGROUND_WR(0x00008000); // letterbox is dark green REG_PS_BACKGROUND_WR(0x00000080); //
 * letterbox is dark blue
 */
typedef union _hw_pxp_hw_pxp_ps_background_1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_ps_background_1_bitfields
    {
        uint32_t COLOR : 24;           /*!< [23:0]  */
        uint32_t RSVD : 8;             /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_ps_background_1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_PS_BACKGROUND_1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_PS_BACKGROUND_1_ADDR(x) ((uintptr_t)(x) + 0x2C0U)

#define HW_PXP_HW_PXP_PS_BACKGROUND_1(x) (*(__IO hw_pxp_hw_pxp_ps_background_1_t *) HW_PXP_HW_PXP_PS_BACKGROUND_1_ADDR(x))
#define HW_PXP_HW_PXP_PS_BACKGROUND_1_RD(x) (HW_PXP_HW_PXP_PS_BACKGROUND_1(x).U)
#define HW_PXP_HW_PXP_PS_BACKGROUND_1_WR(x, v) (HW_PXP_HW_PXP_PS_BACKGROUND_1(x).U = (v))
#define HW_PXP_HW_PXP_PS_BACKGROUND_1_SET(x, v) (HW_PXP_HW_PXP_PS_BACKGROUND_1_WR(x, HW_PXP_HW_PXP_PS_BACKGROUND_1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_PS_BACKGROUND_1_CLR(x, v) (HW_PXP_HW_PXP_PS_BACKGROUND_1_WR(x, HW_PXP_HW_PXP_PS_BACKGROUND_1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_PS_BACKGROUND_1_TOG(x, v) (HW_PXP_HW_PXP_PS_BACKGROUND_1_WR(x, HW_PXP_HW_PXP_PS_BACKGROUND_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_PS_BACKGROUND_1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_PS_BACKGROUND_1, field COLOR[23:0] (RW)
 *
 * Background color (in 24bpp format) for any pixels not within the buffer range
 * specified by the PS ULC/LRC.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_BACKGROUND_1_COLOR (0U) /*!< Bit position for PXP_HW_PXP_PS_BACKGROUND_1_COLOR. */
#define BM_PXP_HW_PXP_PS_BACKGROUND_1_COLOR (0x00FFFFFFU) /*!< Bit mask for PXP_HW_PXP_PS_BACKGROUND_1_COLOR. */
#define BS_PXP_HW_PXP_PS_BACKGROUND_1_COLOR (24U) /*!< Bit field size in bits for PXP_HW_PXP_PS_BACKGROUND_1_COLOR. */

/*! @brief Read current value of the PXP_HW_PXP_PS_BACKGROUND_1_COLOR field. */
#define BR_PXP_HW_PXP_PS_BACKGROUND_1_COLOR(x) (HW_PXP_HW_PXP_PS_BACKGROUND_1(x).B.COLOR)

/*! @brief Format value for bitfield PXP_HW_PXP_PS_BACKGROUND_1_COLOR. */
#define BF_PXP_HW_PXP_PS_BACKGROUND_1_COLOR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_PS_BACKGROUND_1_COLOR) & BM_PXP_HW_PXP_PS_BACKGROUND_1_COLOR)

/*! @brief Set the COLOR field to a new value. */
#define BW_PXP_HW_PXP_PS_BACKGROUND_1_COLOR(x, v) (HW_PXP_HW_PXP_PS_BACKGROUND_1_WR(x, (HW_PXP_HW_PXP_PS_BACKGROUND_1_RD(x) & ~BM_PXP_HW_PXP_PS_BACKGROUND_1_COLOR) | BF_PXP_HW_PXP_PS_BACKGROUND_1_COLOR(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_PS_BACKGROUND_1, field RSVD[31:24] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_BACKGROUND_1_RSVD (24U) /*!< Bit position for PXP_HW_PXP_PS_BACKGROUND_1_RSVD. */
#define BM_PXP_HW_PXP_PS_BACKGROUND_1_RSVD (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_PS_BACKGROUND_1_RSVD. */
#define BS_PXP_HW_PXP_PS_BACKGROUND_1_RSVD (8U) /*!< Bit field size in bits for PXP_HW_PXP_PS_BACKGROUND_1_RSVD. */

/*! @brief Read current value of the PXP_HW_PXP_PS_BACKGROUND_1_RSVD field. */
#define BR_PXP_HW_PXP_PS_BACKGROUND_1_RSVD(x) (HW_PXP_HW_PXP_PS_BACKGROUND_1(x).B.RSVD)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_PS_CLRKEYLOW_1 - PS Color Key Low 1
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_PS_CLRKEYLOW_1 - PS Color Key Low 1 (RW)
 *
 * Reset value: 0x00FFFFFFU
 *
 * This register contains the color key low value for the PS buffer 1. This
 * value is used by the Alpha B block. When processing an image, if the PXP finds a
 * pixel in the PS buffer with a color that falls in the range between
 * REG_PS_CLRKEYLOW and REG_PS_CLRKEYHIGH, it will insert the pixel from the AS channel. If
 * the current AS pixel is letterboxed or if the AS also matches its colorkey
 * range, the REG_PS_BACKGROUND color is passed down the pixel pipeline. EXAMPLE //
 * colorkey values between REG_PS_CLRKEYLOW_WR (0x008000); // medium green and
 * REG_PS_CLRKEYHIGH_WR(0x00FF00); // light green
 */
typedef union _hw_pxp_hw_pxp_ps_clrkeylow_1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_ps_clrkeylow_1_bitfields
    {
        uint32_t PIXEL : 24;           /*!< [23:0]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_ps_clrkeylow_1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_PS_CLRKEYLOW_1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_PS_CLRKEYLOW_1_ADDR(x) ((uintptr_t)(x) + 0x2D0U)

#define HW_PXP_HW_PXP_PS_CLRKEYLOW_1(x) (*(__IO hw_pxp_hw_pxp_ps_clrkeylow_1_t *) HW_PXP_HW_PXP_PS_CLRKEYLOW_1_ADDR(x))
#define HW_PXP_HW_PXP_PS_CLRKEYLOW_1_RD(x) (HW_PXP_HW_PXP_PS_CLRKEYLOW_1(x).U)
#define HW_PXP_HW_PXP_PS_CLRKEYLOW_1_WR(x, v) (HW_PXP_HW_PXP_PS_CLRKEYLOW_1(x).U = (v))
#define HW_PXP_HW_PXP_PS_CLRKEYLOW_1_SET(x, v) (HW_PXP_HW_PXP_PS_CLRKEYLOW_1_WR(x, HW_PXP_HW_PXP_PS_CLRKEYLOW_1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_PS_CLRKEYLOW_1_CLR(x, v) (HW_PXP_HW_PXP_PS_CLRKEYLOW_1_WR(x, HW_PXP_HW_PXP_PS_CLRKEYLOW_1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_PS_CLRKEYLOW_1_TOG(x, v) (HW_PXP_HW_PXP_PS_CLRKEYLOW_1_WR(x, HW_PXP_HW_PXP_PS_CLRKEYLOW_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_PS_CLRKEYLOW_1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_PS_CLRKEYLOW_1, field PIXEL[23:0] (RW)
 *
 * Low range of color key applied to PS buffer. To disable PS colorkeying, set
 * the low colorkey to 0xFFFFFF and the high colorkey to 0x000000.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL (0U) /*!< Bit position for PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL. */
#define BM_PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL (0x00FFFFFFU) /*!< Bit mask for PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL. */
#define BS_PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL (24U) /*!< Bit field size in bits for PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL. */

/*! @brief Read current value of the PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL field. */
#define BR_PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL(x) (HW_PXP_HW_PXP_PS_CLRKEYLOW_1(x).B.PIXEL)

/*! @brief Format value for bitfield PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL. */
#define BF_PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL) & BM_PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL)

/*! @brief Set the PIXEL field to a new value. */
#define BW_PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL(x, v) (HW_PXP_HW_PXP_PS_CLRKEYLOW_1_WR(x, (HW_PXP_HW_PXP_PS_CLRKEYLOW_1_RD(x) & ~BM_PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL) | BF_PXP_HW_PXP_PS_CLRKEYLOW_1_PIXEL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_PS_CLRKEYLOW_1, field RSVD1[31:24] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_CLRKEYLOW_1_RSVD1 (24U) /*!< Bit position for PXP_HW_PXP_PS_CLRKEYLOW_1_RSVD1. */
#define BM_PXP_HW_PXP_PS_CLRKEYLOW_1_RSVD1 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_PS_CLRKEYLOW_1_RSVD1. */
#define BS_PXP_HW_PXP_PS_CLRKEYLOW_1_RSVD1 (8U) /*!< Bit field size in bits for PXP_HW_PXP_PS_CLRKEYLOW_1_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_PS_CLRKEYLOW_1_RSVD1 field. */
#define BR_PXP_HW_PXP_PS_CLRKEYLOW_1_RSVD1(x) (HW_PXP_HW_PXP_PS_CLRKEYLOW_1(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_PS_CLRKEYHIGH_1 - PS Color Key High 1
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_PS_CLRKEYHIGH_1 - PS Color Key High 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the color key high value for the PS buffer. This value
 * is used by the Alpha B block. When processing an image, if the PXP finds a
 * pixel in the PS buffer with a color that falls in the range between
 * REG_PS_CLRKEYLOW and REG_PS_CLRKEYHIGH, it will insert the pixel from the AS channel. If
 * the current AS pixel is letterboxed or if the AS also matches its colorkey
 * range, the REG_PS_BACKGROUND color is passed down the pixel pipeline. EXAMPLE //
 * colorkey values between REG_PS_CLRKEYLOW_WR (0x008000); // medium green and
 * REG_PS_CLRKEYHIGH_WR(0x00FF00); // light green
 */
typedef union _hw_pxp_hw_pxp_ps_clrkeyhigh_1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_ps_clrkeyhigh_1_bitfields
    {
        uint32_t PIXEL : 24;           /*!< [23:0]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_ps_clrkeyhigh_1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_PS_CLRKEYHIGH_1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_PS_CLRKEYHIGH_1_ADDR(x) ((uintptr_t)(x) + 0x2E0U)

#define HW_PXP_HW_PXP_PS_CLRKEYHIGH_1(x) (*(__IO hw_pxp_hw_pxp_ps_clrkeyhigh_1_t *) HW_PXP_HW_PXP_PS_CLRKEYHIGH_1_ADDR(x))
#define HW_PXP_HW_PXP_PS_CLRKEYHIGH_1_RD(x) (HW_PXP_HW_PXP_PS_CLRKEYHIGH_1(x).U)
#define HW_PXP_HW_PXP_PS_CLRKEYHIGH_1_WR(x, v) (HW_PXP_HW_PXP_PS_CLRKEYHIGH_1(x).U = (v))
#define HW_PXP_HW_PXP_PS_CLRKEYHIGH_1_SET(x, v) (HW_PXP_HW_PXP_PS_CLRKEYHIGH_1_WR(x, HW_PXP_HW_PXP_PS_CLRKEYHIGH_1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_PS_CLRKEYHIGH_1_CLR(x, v) (HW_PXP_HW_PXP_PS_CLRKEYHIGH_1_WR(x, HW_PXP_HW_PXP_PS_CLRKEYHIGH_1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_PS_CLRKEYHIGH_1_TOG(x, v) (HW_PXP_HW_PXP_PS_CLRKEYHIGH_1_WR(x, HW_PXP_HW_PXP_PS_CLRKEYHIGH_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_PS_CLRKEYHIGH_1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_PS_CLRKEYHIGH_1, field PIXEL[23:0] (RW)
 *
 * High range of color key applied to PS buffer. To disable PS colorkeying, set
 * the low colorkey to 0xFFFFFF and the high colorkey to 0x000000.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL (0U) /*!< Bit position for PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL. */
#define BM_PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL (0x00FFFFFFU) /*!< Bit mask for PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL. */
#define BS_PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL (24U) /*!< Bit field size in bits for PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL. */

/*! @brief Read current value of the PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL field. */
#define BR_PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL(x) (HW_PXP_HW_PXP_PS_CLRKEYHIGH_1(x).B.PIXEL)

/*! @brief Format value for bitfield PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL. */
#define BF_PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL) & BM_PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL)

/*! @brief Set the PIXEL field to a new value. */
#define BW_PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL(x, v) (HW_PXP_HW_PXP_PS_CLRKEYHIGH_1_WR(x, (HW_PXP_HW_PXP_PS_CLRKEYHIGH_1_RD(x) & ~BM_PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL) | BF_PXP_HW_PXP_PS_CLRKEYHIGH_1_PIXEL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_PS_CLRKEYHIGH_1, field RSVD1[31:24] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_PS_CLRKEYHIGH_1_RSVD1 (24U) /*!< Bit position for PXP_HW_PXP_PS_CLRKEYHIGH_1_RSVD1. */
#define BM_PXP_HW_PXP_PS_CLRKEYHIGH_1_RSVD1 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_PS_CLRKEYHIGH_1_RSVD1. */
#define BS_PXP_HW_PXP_PS_CLRKEYHIGH_1_RSVD1 (8U) /*!< Bit field size in bits for PXP_HW_PXP_PS_CLRKEYHIGH_1_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_PS_CLRKEYHIGH_1_RSVD1 field. */
#define BR_PXP_HW_PXP_PS_CLRKEYHIGH_1_RSVD1(x) (HW_PXP_HW_PXP_PS_CLRKEYHIGH_1(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_AS_CLRKEYLOW_1 - Overlay Color Key Low
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_AS_CLRKEYLOW_1 - Overlay Color Key Low (RW)
 *
 * Reset value: 0x00FFFFFFU
 *
 * This register contains the color key low value for the AS buffer. This value
 * is used by the Alpha B block. When processing an image, the if the PXP finds a
 * pixel in the current overlay image with a color that falls in the range from
 * the ASCOLORKEYLOW to ASCOLORKEYHIGH range, it will use the PS pixel value for
 * that location. If no PS image is present or if the PS image also matches its
 * colorkey range, the PS background color is used. Colorkey operations are higher
 * priority than alpha or ROP operations. EXAMPLE // colorkey values between
 * REG_AS_CLRKEYLOW_WR (0x000000); // black and REG_AS_CLRKEYHIGH_WR(0x800000); //
 * medium red
 */
typedef union _hw_pxp_hw_pxp_as_clrkeylow_1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_as_clrkeylow_1_bitfields
    {
        uint32_t PIXEL : 24;           /*!< [23:0]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_as_clrkeylow_1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_AS_CLRKEYLOW_1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_AS_CLRKEYLOW_1_ADDR(x) ((uintptr_t)(x) + 0x2F0U)

#define HW_PXP_HW_PXP_AS_CLRKEYLOW_1(x) (*(__IO hw_pxp_hw_pxp_as_clrkeylow_1_t *) HW_PXP_HW_PXP_AS_CLRKEYLOW_1_ADDR(x))
#define HW_PXP_HW_PXP_AS_CLRKEYLOW_1_RD(x) (HW_PXP_HW_PXP_AS_CLRKEYLOW_1(x).U)
#define HW_PXP_HW_PXP_AS_CLRKEYLOW_1_WR(x, v) (HW_PXP_HW_PXP_AS_CLRKEYLOW_1(x).U = (v))
#define HW_PXP_HW_PXP_AS_CLRKEYLOW_1_SET(x, v) (HW_PXP_HW_PXP_AS_CLRKEYLOW_1_WR(x, HW_PXP_HW_PXP_AS_CLRKEYLOW_1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_AS_CLRKEYLOW_1_CLR(x, v) (HW_PXP_HW_PXP_AS_CLRKEYLOW_1_WR(x, HW_PXP_HW_PXP_AS_CLRKEYLOW_1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_AS_CLRKEYLOW_1_TOG(x, v) (HW_PXP_HW_PXP_AS_CLRKEYLOW_1_WR(x, HW_PXP_HW_PXP_AS_CLRKEYLOW_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_AS_CLRKEYLOW_1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_AS_CLRKEYLOW_1, field PIXEL[23:0] (RW)
 *
 * Low range of RGB color key applied to AS buffer. Each overlay has an
 * independent colorkey enable.
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL (0U) /*!< Bit position for PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL. */
#define BM_PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL (0x00FFFFFFU) /*!< Bit mask for PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL. */
#define BS_PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL (24U) /*!< Bit field size in bits for PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL. */

/*! @brief Read current value of the PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL field. */
#define BR_PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL(x) (HW_PXP_HW_PXP_AS_CLRKEYLOW_1(x).B.PIXEL)

/*! @brief Format value for bitfield PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL. */
#define BF_PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL) & BM_PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL)

/*! @brief Set the PIXEL field to a new value. */
#define BW_PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL(x, v) (HW_PXP_HW_PXP_AS_CLRKEYLOW_1_WR(x, (HW_PXP_HW_PXP_AS_CLRKEYLOW_1_RD(x) & ~BM_PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL) | BF_PXP_HW_PXP_AS_CLRKEYLOW_1_PIXEL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_AS_CLRKEYLOW_1, field RSVD1[31:24] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_CLRKEYLOW_1_RSVD1 (24U) /*!< Bit position for PXP_HW_PXP_AS_CLRKEYLOW_1_RSVD1. */
#define BM_PXP_HW_PXP_AS_CLRKEYLOW_1_RSVD1 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_AS_CLRKEYLOW_1_RSVD1. */
#define BS_PXP_HW_PXP_AS_CLRKEYLOW_1_RSVD1 (8U) /*!< Bit field size in bits for PXP_HW_PXP_AS_CLRKEYLOW_1_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_AS_CLRKEYLOW_1_RSVD1 field. */
#define BR_PXP_HW_PXP_AS_CLRKEYLOW_1_RSVD1(x) (HW_PXP_HW_PXP_AS_CLRKEYLOW_1(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_AS_CLRKEYHIGH_1 - Overlay Color Key High
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_AS_CLRKEYHIGH_1 - Overlay Color Key High (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the color key high value for the AS buffer. This value
 * is used by the Alpha B block. When processing an image, the if the PXP finds
 * a pixel in the current overlay image with a color that falls in the range from
 * the ASCOLORKEYLOW to ASCOLORKEYHIGH range, it will use the PS pixel value for
 * that location. If no PS image is present or if the PS image also matches its
 * colorkey range, the PS background color is used. Colorkey operations are
 * higher priority than alpha or ROP operations. EXAMPLE // colorkey values between
 * REG_AS_CLRKEYLOW_WR (0x000000); // black and REG_AS_CLRKEYHIGH_WR(0x800000); //
 * medium red
 */
typedef union _hw_pxp_hw_pxp_as_clrkeyhigh_1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_as_clrkeyhigh_1_bitfields
    {
        uint32_t PIXEL : 24;           /*!< [23:0]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_as_clrkeyhigh_1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_AS_CLRKEYHIGH_1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_AS_CLRKEYHIGH_1_ADDR(x) ((uintptr_t)(x) + 0x300U)

#define HW_PXP_HW_PXP_AS_CLRKEYHIGH_1(x) (*(__IO hw_pxp_hw_pxp_as_clrkeyhigh_1_t *) HW_PXP_HW_PXP_AS_CLRKEYHIGH_1_ADDR(x))
#define HW_PXP_HW_PXP_AS_CLRKEYHIGH_1_RD(x) (HW_PXP_HW_PXP_AS_CLRKEYHIGH_1(x).U)
#define HW_PXP_HW_PXP_AS_CLRKEYHIGH_1_WR(x, v) (HW_PXP_HW_PXP_AS_CLRKEYHIGH_1(x).U = (v))
#define HW_PXP_HW_PXP_AS_CLRKEYHIGH_1_SET(x, v) (HW_PXP_HW_PXP_AS_CLRKEYHIGH_1_WR(x, HW_PXP_HW_PXP_AS_CLRKEYHIGH_1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_AS_CLRKEYHIGH_1_CLR(x, v) (HW_PXP_HW_PXP_AS_CLRKEYHIGH_1_WR(x, HW_PXP_HW_PXP_AS_CLRKEYHIGH_1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_AS_CLRKEYHIGH_1_TOG(x, v) (HW_PXP_HW_PXP_AS_CLRKEYHIGH_1_WR(x, HW_PXP_HW_PXP_AS_CLRKEYHIGH_1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_AS_CLRKEYHIGH_1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_AS_CLRKEYHIGH_1, field PIXEL[23:0] (RW)
 *
 * High range of RGB color key applied to AS buffer. Each overlay has an
 * independent colorkey enable.
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL (0U) /*!< Bit position for PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL. */
#define BM_PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL (0x00FFFFFFU) /*!< Bit mask for PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL. */
#define BS_PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL (24U) /*!< Bit field size in bits for PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL. */

/*! @brief Read current value of the PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL field. */
#define BR_PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL(x) (HW_PXP_HW_PXP_AS_CLRKEYHIGH_1(x).B.PIXEL)

/*! @brief Format value for bitfield PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL. */
#define BF_PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL) & BM_PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL)

/*! @brief Set the PIXEL field to a new value. */
#define BW_PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL(x, v) (HW_PXP_HW_PXP_AS_CLRKEYHIGH_1_WR(x, (HW_PXP_HW_PXP_AS_CLRKEYHIGH_1_RD(x) & ~BM_PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL) | BF_PXP_HW_PXP_AS_CLRKEYHIGH_1_PIXEL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_AS_CLRKEYHIGH_1, field RSVD1[31:24] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_AS_CLRKEYHIGH_1_RSVD1 (24U) /*!< Bit position for PXP_HW_PXP_AS_CLRKEYHIGH_1_RSVD1. */
#define BM_PXP_HW_PXP_AS_CLRKEYHIGH_1_RSVD1 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_AS_CLRKEYHIGH_1_RSVD1. */
#define BS_PXP_HW_PXP_AS_CLRKEYHIGH_1_RSVD1 (8U) /*!< Bit field size in bits for PXP_HW_PXP_AS_CLRKEYHIGH_1_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_AS_CLRKEYHIGH_1_RSVD1 field. */
#define BR_PXP_HW_PXP_AS_CLRKEYHIGH_1_RSVD1(x) (HW_PXP_HW_PXP_AS_CLRKEYHIGH_1(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_CTRL2 - Control Register 2
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_CTRL2 - Control Register 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The CTRL register contains controls for the secondary processing flow in PXP
 * module. HW_PXP_CTRL2: 0x310 HW_PXP_CTRL2_SET: 0x314 HW_PXP_CTRL2_CLR: 0x318
 * HW_PXP_CTRL2_TOG: 0x31C The Control register contains the controls for the
 * secondary data flow in PXP block. EXAMPLE REG_CTRL_SET(BM_PXP_CTRL_SFTRST);
 * REG_CTRL_CLR(BM_PXP_CTRL_SFTRST | BM_PXP_CTRL_CLKGATE);
 */
typedef union _hw_pxp_hw_pxp_ctrl2
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_ctrl2_bitfields
    {
        uint32_t ENABLE : 1;           /*!< [0]  */
        uint32_t RSVD0 : 7;            /*!< [7:1]  */
        uint32_t ROTATE0 : 2;          /*!< [9:8]  */
        uint32_t HFLIP0 : 1;           /*!< [10]  */
        uint32_t VFLIP0 : 1;           /*!< [11]  */
        uint32_t ROTATE1 : 2;          /*!< [13:12]  */
        uint32_t HFLIP1 : 1;           /*!< [14]  */
        uint32_t VFLIP1 : 1;           /*!< [15]  */
        uint32_t RSVD1 : 1;            /*!< [16]  */
        uint32_t ENABLE_DITHER : 1;    /*!< [17]  */
        uint32_t ENABLE_WFE_A : 1;     /*!< [18]  */
        uint32_t ENABLE_WFE_B : 1;     /*!< [19]  */
        uint32_t ENABLE_INPUT_FETCH_STORE : 1; /*!< [20]  */
        uint32_t ENABLE_ALPHA_B : 1;   /*!< [21]  */
        uint32_t RSVD2 : 1;            /*!< [22]  */
        uint32_t BLOCK_SIZE : 1;       /*!< [23]  */
        uint32_t ENABLE_CSC2 : 1;      /*!< [24]  */
        uint32_t ENABLE_LUT : 1;       /*!< [25]  */
        uint32_t ENABLE_ROTATE0 : 1;   /*!< [26]  */
        uint32_t ENABLE_ROTATE1 : 1;   /*!< [27]  */
        uint32_t RSVD3 : 4;            /*!< [31:28]  */
    } B;
} hw_pxp_hw_pxp_ctrl2_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_CTRL2 register
 */
/*@{*/
#define HW_PXP_HW_PXP_CTRL2_ADDR(x) ((uintptr_t)(x) + 0x310U)

#define HW_PXP_HW_PXP_CTRL2(x)   (*(__IO hw_pxp_hw_pxp_ctrl2_t *) HW_PXP_HW_PXP_CTRL2_ADDR(x))
#define HW_PXP_HW_PXP_CTRL2_RD(x) (HW_PXP_HW_PXP_CTRL2(x).U)
#define HW_PXP_HW_PXP_CTRL2_WR(x, v) (HW_PXP_HW_PXP_CTRL2(x).U = (v))
#define HW_PXP_HW_PXP_CTRL2_SET(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, HW_PXP_HW_PXP_CTRL2_RD(x) |  (v)))
#define HW_PXP_HW_PXP_CTRL2_CLR(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, HW_PXP_HW_PXP_CTRL2_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_CTRL2_TOG(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, HW_PXP_HW_PXP_CTRL2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_CTRL2 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_CTRL2, field ENABLE[0] (RW)
 *
 * Enables PXP secondary data processing flow with specified parameters. The
 * ENABLE bit will remain set while the PXP is active and will be cleared once the
 * current operation completes. Software should use the IRQ bit in the HW_PXP_STAT
 * when polling for PXP completion.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_ENABLE (0U)    /*!< Bit position for PXP_HW_PXP_CTRL2_ENABLE. */
#define BM_PXP_HW_PXP_CTRL2_ENABLE (0x00000001U) /*!< Bit mask for PXP_HW_PXP_CTRL2_ENABLE. */
#define BS_PXP_HW_PXP_CTRL2_ENABLE (1U)    /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_ENABLE. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_ENABLE field. */
#define BR_PXP_HW_PXP_CTRL2_ENABLE(x) (HW_PXP_HW_PXP_CTRL2(x).B.ENABLE)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL2_ENABLE. */
#define BF_PXP_HW_PXP_CTRL2_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL2_ENABLE) & BM_PXP_HW_PXP_CTRL2_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_PXP_HW_PXP_CTRL2_ENABLE(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, (HW_PXP_HW_PXP_CTRL2_RD(x) & ~BM_PXP_HW_PXP_CTRL2_ENABLE) | BF_PXP_HW_PXP_CTRL2_ENABLE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field RSVD0[7:1] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_RSVD0 (1U)     /*!< Bit position for PXP_HW_PXP_CTRL2_RSVD0. */
#define BM_PXP_HW_PXP_CTRL2_RSVD0 (0x000000FEU) /*!< Bit mask for PXP_HW_PXP_CTRL2_RSVD0. */
#define BS_PXP_HW_PXP_CTRL2_RSVD0 (7U)     /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_RSVD0 field. */
#define BR_PXP_HW_PXP_CTRL2_RSVD0(x) (HW_PXP_HW_PXP_CTRL2(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field ROTATE0[9:8] (RW)
 *
 * Indicates the clockwise rotation to be applied at the output buffer. The
 * rotation effect is defined as occurring after the FLIP_X and FLIP_Y permutation.
 *
 * Values:
 * - 0 -
 * - 1 -
 * - 10 -
 * - 11 -
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_ROTATE0 (8U)   /*!< Bit position for PXP_HW_PXP_CTRL2_ROTATE0. */
#define BM_PXP_HW_PXP_CTRL2_ROTATE0 (0x00000300U) /*!< Bit mask for PXP_HW_PXP_CTRL2_ROTATE0. */
#define BS_PXP_HW_PXP_CTRL2_ROTATE0 (2U)   /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_ROTATE0. */

#define BV_PXP_HW_PXP_CTRL2_ROTATE0_ROT_0 (0U)       /*!< Bit field value for PXP_HW_PXP_CTRL2_ROTATE0:  */
#define BV_PXP_HW_PXP_CTRL2_ROTATE0_ROT_90 (0x1U)    /*!< Bit field value for PXP_HW_PXP_CTRL2_ROTATE0:  */
#define BV_PXP_HW_PXP_CTRL2_ROTATE0_ROT_180 (0x2U)   /*!< Bit field value for PXP_HW_PXP_CTRL2_ROTATE0:  */
#define BV_PXP_HW_PXP_CTRL2_ROTATE0_ROT_270 (0x3U)   /*!< Bit field value for PXP_HW_PXP_CTRL2_ROTATE0:  */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_ROTATE0 field. */
#define BR_PXP_HW_PXP_CTRL2_ROTATE0(x) (HW_PXP_HW_PXP_CTRL2(x).B.ROTATE0)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL2_ROTATE0. */
#define BF_PXP_HW_PXP_CTRL2_ROTATE0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL2_ROTATE0) & BM_PXP_HW_PXP_CTRL2_ROTATE0)

/*! @brief Set the ROTATE0 field to a new value. */
#define BW_PXP_HW_PXP_CTRL2_ROTATE0(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, (HW_PXP_HW_PXP_CTRL2_RD(x) & ~BM_PXP_HW_PXP_CTRL2_ROTATE0) | BF_PXP_HW_PXP_CTRL2_ROTATE0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field HFLIP0[10] (RW)
 *
 * Indicates that the output buffer should be flipped horizontally (effect
 * applied before rotation).
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_HFLIP0 (10U)   /*!< Bit position for PXP_HW_PXP_CTRL2_HFLIP0. */
#define BM_PXP_HW_PXP_CTRL2_HFLIP0 (0x00000400U) /*!< Bit mask for PXP_HW_PXP_CTRL2_HFLIP0. */
#define BS_PXP_HW_PXP_CTRL2_HFLIP0 (1U)    /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_HFLIP0. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_HFLIP0 field. */
#define BR_PXP_HW_PXP_CTRL2_HFLIP0(x) (HW_PXP_HW_PXP_CTRL2(x).B.HFLIP0)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL2_HFLIP0. */
#define BF_PXP_HW_PXP_CTRL2_HFLIP0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL2_HFLIP0) & BM_PXP_HW_PXP_CTRL2_HFLIP0)

/*! @brief Set the HFLIP0 field to a new value. */
#define BW_PXP_HW_PXP_CTRL2_HFLIP0(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, (HW_PXP_HW_PXP_CTRL2_RD(x) & ~BM_PXP_HW_PXP_CTRL2_HFLIP0) | BF_PXP_HW_PXP_CTRL2_HFLIP0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field VFLIP0[11] (RW)
 *
 * Indicates that the output buffer should be flipped vertically (effect applied
 * before rotation).
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_VFLIP0 (11U)   /*!< Bit position for PXP_HW_PXP_CTRL2_VFLIP0. */
#define BM_PXP_HW_PXP_CTRL2_VFLIP0 (0x00000800U) /*!< Bit mask for PXP_HW_PXP_CTRL2_VFLIP0. */
#define BS_PXP_HW_PXP_CTRL2_VFLIP0 (1U)    /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_VFLIP0. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_VFLIP0 field. */
#define BR_PXP_HW_PXP_CTRL2_VFLIP0(x) (HW_PXP_HW_PXP_CTRL2(x).B.VFLIP0)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL2_VFLIP0. */
#define BF_PXP_HW_PXP_CTRL2_VFLIP0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL2_VFLIP0) & BM_PXP_HW_PXP_CTRL2_VFLIP0)

/*! @brief Set the VFLIP0 field to a new value. */
#define BW_PXP_HW_PXP_CTRL2_VFLIP0(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, (HW_PXP_HW_PXP_CTRL2_RD(x) & ~BM_PXP_HW_PXP_CTRL2_VFLIP0) | BF_PXP_HW_PXP_CTRL2_VFLIP0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field ROTATE1[13:12] (RW)
 *
 * Indicates the clockwise rotation to be applied at the input buffer. The
 * rotation effect is defined as occurring after the FLIP_X and FLIP_Y permutation.
 *
 * Values:
 * - 0 -
 * - 1 -
 * - 10 -
 * - 11 -
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_ROTATE1 (12U)  /*!< Bit position for PXP_HW_PXP_CTRL2_ROTATE1. */
#define BM_PXP_HW_PXP_CTRL2_ROTATE1 (0x00003000U) /*!< Bit mask for PXP_HW_PXP_CTRL2_ROTATE1. */
#define BS_PXP_HW_PXP_CTRL2_ROTATE1 (2U)   /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_ROTATE1. */

#define BV_PXP_HW_PXP_CTRL2_ROTATE1_ROT_0 (0U)       /*!< Bit field value for PXP_HW_PXP_CTRL2_ROTATE1:  */
#define BV_PXP_HW_PXP_CTRL2_ROTATE1_ROT_90 (0x1U)    /*!< Bit field value for PXP_HW_PXP_CTRL2_ROTATE1:  */
#define BV_PXP_HW_PXP_CTRL2_ROTATE1_ROT_180 (0x2U)   /*!< Bit field value for PXP_HW_PXP_CTRL2_ROTATE1:  */
#define BV_PXP_HW_PXP_CTRL2_ROTATE1_ROT_270 (0x3U)   /*!< Bit field value for PXP_HW_PXP_CTRL2_ROTATE1:  */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_ROTATE1 field. */
#define BR_PXP_HW_PXP_CTRL2_ROTATE1(x) (HW_PXP_HW_PXP_CTRL2(x).B.ROTATE1)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL2_ROTATE1. */
#define BF_PXP_HW_PXP_CTRL2_ROTATE1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL2_ROTATE1) & BM_PXP_HW_PXP_CTRL2_ROTATE1)

/*! @brief Set the ROTATE1 field to a new value. */
#define BW_PXP_HW_PXP_CTRL2_ROTATE1(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, (HW_PXP_HW_PXP_CTRL2_RD(x) & ~BM_PXP_HW_PXP_CTRL2_ROTATE1) | BF_PXP_HW_PXP_CTRL2_ROTATE1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field HFLIP1[14] (RW)
 *
 * Indicates that the input should be flipped horizontally (effect applied
 * before rotation).
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_HFLIP1 (14U)   /*!< Bit position for PXP_HW_PXP_CTRL2_HFLIP1. */
#define BM_PXP_HW_PXP_CTRL2_HFLIP1 (0x00004000U) /*!< Bit mask for PXP_HW_PXP_CTRL2_HFLIP1. */
#define BS_PXP_HW_PXP_CTRL2_HFLIP1 (1U)    /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_HFLIP1. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_HFLIP1 field. */
#define BR_PXP_HW_PXP_CTRL2_HFLIP1(x) (HW_PXP_HW_PXP_CTRL2(x).B.HFLIP1)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL2_HFLIP1. */
#define BF_PXP_HW_PXP_CTRL2_HFLIP1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL2_HFLIP1) & BM_PXP_HW_PXP_CTRL2_HFLIP1)

/*! @brief Set the HFLIP1 field to a new value. */
#define BW_PXP_HW_PXP_CTRL2_HFLIP1(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, (HW_PXP_HW_PXP_CTRL2_RD(x) & ~BM_PXP_HW_PXP_CTRL2_HFLIP1) | BF_PXP_HW_PXP_CTRL2_HFLIP1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field VFLIP1[15] (RW)
 *
 * Indicates that the input should be flipped vertically (effect applied before
 * rotation).
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_VFLIP1 (15U)   /*!< Bit position for PXP_HW_PXP_CTRL2_VFLIP1. */
#define BM_PXP_HW_PXP_CTRL2_VFLIP1 (0x00008000U) /*!< Bit mask for PXP_HW_PXP_CTRL2_VFLIP1. */
#define BS_PXP_HW_PXP_CTRL2_VFLIP1 (1U)    /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_VFLIP1. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_VFLIP1 field. */
#define BR_PXP_HW_PXP_CTRL2_VFLIP1(x) (HW_PXP_HW_PXP_CTRL2(x).B.VFLIP1)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL2_VFLIP1. */
#define BF_PXP_HW_PXP_CTRL2_VFLIP1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL2_VFLIP1) & BM_PXP_HW_PXP_CTRL2_VFLIP1)

/*! @brief Set the VFLIP1 field to a new value. */
#define BW_PXP_HW_PXP_CTRL2_VFLIP1(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, (HW_PXP_HW_PXP_CTRL2_RD(x) & ~BM_PXP_HW_PXP_CTRL2_VFLIP1) | BF_PXP_HW_PXP_CTRL2_VFLIP1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field RSVD1[16] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_RSVD1 (16U)    /*!< Bit position for PXP_HW_PXP_CTRL2_RSVD1. */
#define BM_PXP_HW_PXP_CTRL2_RSVD1 (0x00010000U) /*!< Bit mask for PXP_HW_PXP_CTRL2_RSVD1. */
#define BS_PXP_HW_PXP_CTRL2_RSVD1 (1U)     /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_RSVD1 field. */
#define BR_PXP_HW_PXP_CTRL2_RSVD1(x) (HW_PXP_HW_PXP_CTRL2(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field ENABLE_DITHER[17] (RW)
 *
 * Enable the Dithering engine in the PXP secondary processing flow.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_ENABLE_DITHER (17U) /*!< Bit position for PXP_HW_PXP_CTRL2_ENABLE_DITHER. */
#define BM_PXP_HW_PXP_CTRL2_ENABLE_DITHER (0x00020000U) /*!< Bit mask for PXP_HW_PXP_CTRL2_ENABLE_DITHER. */
#define BS_PXP_HW_PXP_CTRL2_ENABLE_DITHER (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_ENABLE_DITHER. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_ENABLE_DITHER field. */
#define BR_PXP_HW_PXP_CTRL2_ENABLE_DITHER(x) (HW_PXP_HW_PXP_CTRL2(x).B.ENABLE_DITHER)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL2_ENABLE_DITHER. */
#define BF_PXP_HW_PXP_CTRL2_ENABLE_DITHER(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL2_ENABLE_DITHER) & BM_PXP_HW_PXP_CTRL2_ENABLE_DITHER)

/*! @brief Set the ENABLE_DITHER field to a new value. */
#define BW_PXP_HW_PXP_CTRL2_ENABLE_DITHER(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, (HW_PXP_HW_PXP_CTRL2_RD(x) & ~BM_PXP_HW_PXP_CTRL2_ENABLE_DITHER) | BF_PXP_HW_PXP_CTRL2_ENABLE_DITHER(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field ENABLE_WFE_A[18] (RW)
 *
 * Enable the WFE-A engine in the PXP secondary processing flow.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_ENABLE_WFE_A (18U) /*!< Bit position for PXP_HW_PXP_CTRL2_ENABLE_WFE_A. */
#define BM_PXP_HW_PXP_CTRL2_ENABLE_WFE_A (0x00040000U) /*!< Bit mask for PXP_HW_PXP_CTRL2_ENABLE_WFE_A. */
#define BS_PXP_HW_PXP_CTRL2_ENABLE_WFE_A (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_ENABLE_WFE_A. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_ENABLE_WFE_A field. */
#define BR_PXP_HW_PXP_CTRL2_ENABLE_WFE_A(x) (HW_PXP_HW_PXP_CTRL2(x).B.ENABLE_WFE_A)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL2_ENABLE_WFE_A. */
#define BF_PXP_HW_PXP_CTRL2_ENABLE_WFE_A(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL2_ENABLE_WFE_A) & BM_PXP_HW_PXP_CTRL2_ENABLE_WFE_A)

/*! @brief Set the ENABLE_WFE_A field to a new value. */
#define BW_PXP_HW_PXP_CTRL2_ENABLE_WFE_A(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, (HW_PXP_HW_PXP_CTRL2_RD(x) & ~BM_PXP_HW_PXP_CTRL2_ENABLE_WFE_A) | BF_PXP_HW_PXP_CTRL2_ENABLE_WFE_A(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field ENABLE_WFE_B[19] (RW)
 *
 * Enable the WFE-B engine in the PXP secondary processing flow.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_ENABLE_WFE_B (19U) /*!< Bit position for PXP_HW_PXP_CTRL2_ENABLE_WFE_B. */
#define BM_PXP_HW_PXP_CTRL2_ENABLE_WFE_B (0x00080000U) /*!< Bit mask for PXP_HW_PXP_CTRL2_ENABLE_WFE_B. */
#define BS_PXP_HW_PXP_CTRL2_ENABLE_WFE_B (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_ENABLE_WFE_B. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_ENABLE_WFE_B field. */
#define BR_PXP_HW_PXP_CTRL2_ENABLE_WFE_B(x) (HW_PXP_HW_PXP_CTRL2(x).B.ENABLE_WFE_B)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL2_ENABLE_WFE_B. */
#define BF_PXP_HW_PXP_CTRL2_ENABLE_WFE_B(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL2_ENABLE_WFE_B) & BM_PXP_HW_PXP_CTRL2_ENABLE_WFE_B)

/*! @brief Set the ENABLE_WFE_B field to a new value. */
#define BW_PXP_HW_PXP_CTRL2_ENABLE_WFE_B(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, (HW_PXP_HW_PXP_CTRL2_RD(x) & ~BM_PXP_HW_PXP_CTRL2_ENABLE_WFE_B) | BF_PXP_HW_PXP_CTRL2_ENABLE_WFE_B(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field ENABLE_INPUT_FETCH_STORE[20] (RW)
 *
 * Enable the Input Fetch and Store engine in the PXP secondary processing flow.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_ENABLE_INPUT_FETCH_STORE (20U) /*!< Bit position for PXP_HW_PXP_CTRL2_ENABLE_INPUT_FETCH_STORE. */
#define BM_PXP_HW_PXP_CTRL2_ENABLE_INPUT_FETCH_STORE (0x00100000U) /*!< Bit mask for PXP_HW_PXP_CTRL2_ENABLE_INPUT_FETCH_STORE. */
#define BS_PXP_HW_PXP_CTRL2_ENABLE_INPUT_FETCH_STORE (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_ENABLE_INPUT_FETCH_STORE. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_ENABLE_INPUT_FETCH_STORE field. */
#define BR_PXP_HW_PXP_CTRL2_ENABLE_INPUT_FETCH_STORE(x) (HW_PXP_HW_PXP_CTRL2(x).B.ENABLE_INPUT_FETCH_STORE)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL2_ENABLE_INPUT_FETCH_STORE. */
#define BF_PXP_HW_PXP_CTRL2_ENABLE_INPUT_FETCH_STORE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL2_ENABLE_INPUT_FETCH_STORE) & BM_PXP_HW_PXP_CTRL2_ENABLE_INPUT_FETCH_STORE)

/*! @brief Set the ENABLE_INPUT_FETCH_STORE field to a new value. */
#define BW_PXP_HW_PXP_CTRL2_ENABLE_INPUT_FETCH_STORE(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, (HW_PXP_HW_PXP_CTRL2_RD(x) & ~BM_PXP_HW_PXP_CTRL2_ENABLE_INPUT_FETCH_STORE) | BF_PXP_HW_PXP_CTRL2_ENABLE_INPUT_FETCH_STORE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field ENABLE_ALPHA_B[21] (RW)
 *
 * Enable the Alpha-B engine in the PXP secondary processing flow.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_ENABLE_ALPHA_B (21U) /*!< Bit position for PXP_HW_PXP_CTRL2_ENABLE_ALPHA_B. */
#define BM_PXP_HW_PXP_CTRL2_ENABLE_ALPHA_B (0x00200000U) /*!< Bit mask for PXP_HW_PXP_CTRL2_ENABLE_ALPHA_B. */
#define BS_PXP_HW_PXP_CTRL2_ENABLE_ALPHA_B (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_ENABLE_ALPHA_B. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_ENABLE_ALPHA_B field. */
#define BR_PXP_HW_PXP_CTRL2_ENABLE_ALPHA_B(x) (HW_PXP_HW_PXP_CTRL2(x).B.ENABLE_ALPHA_B)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL2_ENABLE_ALPHA_B. */
#define BF_PXP_HW_PXP_CTRL2_ENABLE_ALPHA_B(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL2_ENABLE_ALPHA_B) & BM_PXP_HW_PXP_CTRL2_ENABLE_ALPHA_B)

/*! @brief Set the ENABLE_ALPHA_B field to a new value. */
#define BW_PXP_HW_PXP_CTRL2_ENABLE_ALPHA_B(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, (HW_PXP_HW_PXP_CTRL2_RD(x) & ~BM_PXP_HW_PXP_CTRL2_ENABLE_ALPHA_B) | BF_PXP_HW_PXP_CTRL2_ENABLE_ALPHA_B(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field RSVD2[22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_RSVD2 (22U)    /*!< Bit position for PXP_HW_PXP_CTRL2_RSVD2. */
#define BM_PXP_HW_PXP_CTRL2_RSVD2 (0x00400000U) /*!< Bit mask for PXP_HW_PXP_CTRL2_RSVD2. */
#define BS_PXP_HW_PXP_CTRL2_RSVD2 (1U)     /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_RSVD2 field. */
#define BR_PXP_HW_PXP_CTRL2_RSVD2(x) (HW_PXP_HW_PXP_CTRL2(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field BLOCK_SIZE[23] (RW)
 *
 * Select the block size to process through the Rotate block.
 *
 * Values:
 * - 0 - Process 8x8 pixel blocks.
 * - 1 - Process 16x16 pixel blocks.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_BLOCK_SIZE (23U) /*!< Bit position for PXP_HW_PXP_CTRL2_BLOCK_SIZE. */
#define BM_PXP_HW_PXP_CTRL2_BLOCK_SIZE (0x00800000U) /*!< Bit mask for PXP_HW_PXP_CTRL2_BLOCK_SIZE. */
#define BS_PXP_HW_PXP_CTRL2_BLOCK_SIZE (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_BLOCK_SIZE. */

#define BV_PXP_HW_PXP_CTRL2_BLOCK_SIZE_8X8 (0U)      /*!< Bit field value for PXP_HW_PXP_CTRL2_BLOCK_SIZE: Process 8x8 pixel blocks. */
#define BV_PXP_HW_PXP_CTRL2_BLOCK_SIZE_16X16 (0x1U)  /*!< Bit field value for PXP_HW_PXP_CTRL2_BLOCK_SIZE: Process 16x16 pixel blocks. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_BLOCK_SIZE field. */
#define BR_PXP_HW_PXP_CTRL2_BLOCK_SIZE(x) (HW_PXP_HW_PXP_CTRL2(x).B.BLOCK_SIZE)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL2_BLOCK_SIZE. */
#define BF_PXP_HW_PXP_CTRL2_BLOCK_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL2_BLOCK_SIZE) & BM_PXP_HW_PXP_CTRL2_BLOCK_SIZE)

/*! @brief Set the BLOCK_SIZE field to a new value. */
#define BW_PXP_HW_PXP_CTRL2_BLOCK_SIZE(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, (HW_PXP_HW_PXP_CTRL2_RD(x) & ~BM_PXP_HW_PXP_CTRL2_BLOCK_SIZE) | BF_PXP_HW_PXP_CTRL2_BLOCK_SIZE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field ENABLE_CSC2[24] (RW)
 *
 * Enable the CSC2 engine in the PXP secondary processing flow.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_ENABLE_CSC2 (24U) /*!< Bit position for PXP_HW_PXP_CTRL2_ENABLE_CSC2. */
#define BM_PXP_HW_PXP_CTRL2_ENABLE_CSC2 (0x01000000U) /*!< Bit mask for PXP_HW_PXP_CTRL2_ENABLE_CSC2. */
#define BS_PXP_HW_PXP_CTRL2_ENABLE_CSC2 (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_ENABLE_CSC2. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_ENABLE_CSC2 field. */
#define BR_PXP_HW_PXP_CTRL2_ENABLE_CSC2(x) (HW_PXP_HW_PXP_CTRL2(x).B.ENABLE_CSC2)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL2_ENABLE_CSC2. */
#define BF_PXP_HW_PXP_CTRL2_ENABLE_CSC2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL2_ENABLE_CSC2) & BM_PXP_HW_PXP_CTRL2_ENABLE_CSC2)

/*! @brief Set the ENABLE_CSC2 field to a new value. */
#define BW_PXP_HW_PXP_CTRL2_ENABLE_CSC2(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, (HW_PXP_HW_PXP_CTRL2_RD(x) & ~BM_PXP_HW_PXP_CTRL2_ENABLE_CSC2) | BF_PXP_HW_PXP_CTRL2_ENABLE_CSC2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field ENABLE_LUT[25] (RW)
 *
 * Enable the LUT engine in the PXP secondary processing flow.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_ENABLE_LUT (25U) /*!< Bit position for PXP_HW_PXP_CTRL2_ENABLE_LUT. */
#define BM_PXP_HW_PXP_CTRL2_ENABLE_LUT (0x02000000U) /*!< Bit mask for PXP_HW_PXP_CTRL2_ENABLE_LUT. */
#define BS_PXP_HW_PXP_CTRL2_ENABLE_LUT (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_ENABLE_LUT. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_ENABLE_LUT field. */
#define BR_PXP_HW_PXP_CTRL2_ENABLE_LUT(x) (HW_PXP_HW_PXP_CTRL2(x).B.ENABLE_LUT)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL2_ENABLE_LUT. */
#define BF_PXP_HW_PXP_CTRL2_ENABLE_LUT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL2_ENABLE_LUT) & BM_PXP_HW_PXP_CTRL2_ENABLE_LUT)

/*! @brief Set the ENABLE_LUT field to a new value. */
#define BW_PXP_HW_PXP_CTRL2_ENABLE_LUT(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, (HW_PXP_HW_PXP_CTRL2_RD(x) & ~BM_PXP_HW_PXP_CTRL2_ENABLE_LUT) | BF_PXP_HW_PXP_CTRL2_ENABLE_LUT(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field ENABLE_ROTATE0[26] (RW)
 *
 * Enable the ROTATE0 engine in the PXP secondary processing flow.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_ENABLE_ROTATE0 (26U) /*!< Bit position for PXP_HW_PXP_CTRL2_ENABLE_ROTATE0. */
#define BM_PXP_HW_PXP_CTRL2_ENABLE_ROTATE0 (0x04000000U) /*!< Bit mask for PXP_HW_PXP_CTRL2_ENABLE_ROTATE0. */
#define BS_PXP_HW_PXP_CTRL2_ENABLE_ROTATE0 (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_ENABLE_ROTATE0. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_ENABLE_ROTATE0 field. */
#define BR_PXP_HW_PXP_CTRL2_ENABLE_ROTATE0(x) (HW_PXP_HW_PXP_CTRL2(x).B.ENABLE_ROTATE0)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL2_ENABLE_ROTATE0. */
#define BF_PXP_HW_PXP_CTRL2_ENABLE_ROTATE0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL2_ENABLE_ROTATE0) & BM_PXP_HW_PXP_CTRL2_ENABLE_ROTATE0)

/*! @brief Set the ENABLE_ROTATE0 field to a new value. */
#define BW_PXP_HW_PXP_CTRL2_ENABLE_ROTATE0(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, (HW_PXP_HW_PXP_CTRL2_RD(x) & ~BM_PXP_HW_PXP_CTRL2_ENABLE_ROTATE0) | BF_PXP_HW_PXP_CTRL2_ENABLE_ROTATE0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field ENABLE_ROTATE1[27] (RW)
 *
 * Enable the ROTATE1 engine in the PXP secondary processing flow.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_ENABLE_ROTATE1 (27U) /*!< Bit position for PXP_HW_PXP_CTRL2_ENABLE_ROTATE1. */
#define BM_PXP_HW_PXP_CTRL2_ENABLE_ROTATE1 (0x08000000U) /*!< Bit mask for PXP_HW_PXP_CTRL2_ENABLE_ROTATE1. */
#define BS_PXP_HW_PXP_CTRL2_ENABLE_ROTATE1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_ENABLE_ROTATE1. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_ENABLE_ROTATE1 field. */
#define BR_PXP_HW_PXP_CTRL2_ENABLE_ROTATE1(x) (HW_PXP_HW_PXP_CTRL2(x).B.ENABLE_ROTATE1)

/*! @brief Format value for bitfield PXP_HW_PXP_CTRL2_ENABLE_ROTATE1. */
#define BF_PXP_HW_PXP_CTRL2_ENABLE_ROTATE1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_CTRL2_ENABLE_ROTATE1) & BM_PXP_HW_PXP_CTRL2_ENABLE_ROTATE1)

/*! @brief Set the ENABLE_ROTATE1 field to a new value. */
#define BW_PXP_HW_PXP_CTRL2_ENABLE_ROTATE1(x, v) (HW_PXP_HW_PXP_CTRL2_WR(x, (HW_PXP_HW_PXP_CTRL2_RD(x) & ~BM_PXP_HW_PXP_CTRL2_ENABLE_ROTATE1) | BF_PXP_HW_PXP_CTRL2_ENABLE_ROTATE1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_CTRL2, field RSVD3[31:28] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_CTRL2_RSVD3 (28U)    /*!< Bit position for PXP_HW_PXP_CTRL2_RSVD3. */
#define BM_PXP_HW_PXP_CTRL2_RSVD3 (0xF0000000U) /*!< Bit mask for PXP_HW_PXP_CTRL2_RSVD3. */
#define BS_PXP_HW_PXP_CTRL2_RSVD3 (4U)     /*!< Bit field size in bits for PXP_HW_PXP_CTRL2_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_CTRL2_RSVD3 field. */
#define BR_PXP_HW_PXP_CTRL2_RSVD3(x) (HW_PXP_HW_PXP_CTRL2(x).B.RSVD3)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_POWER_REG0 - PXP Power Control Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_POWER_REG0 - PXP Power Control Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register controls power states for PXP memories.
 */
typedef union _hw_pxp_hw_pxp_power_reg0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_power_reg0_bitfields
    {
        uint32_t LUT_LP_STATE_WAY0_BANK0 : 3; /*!< [2:0]  */
        uint32_t LUT_LP_STATE_WAY0_BANKN : 3; /*!< [5:3]  */
        uint32_t LUT_LP_STATE_WAY1_BANKN : 3; /*!< [8:6]  */
        uint32_t ROT0_MEM_LP_STATE : 3; /*!< [11:9]  */
        uint32_t CTRL : 20;            /*!< [31:12]  */
    } B;
} hw_pxp_hw_pxp_power_reg0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_POWER_REG0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_POWER_REG0_ADDR(x) ((uintptr_t)(x) + 0x320U)

#define HW_PXP_HW_PXP_POWER_REG0(x) (*(__IO hw_pxp_hw_pxp_power_reg0_t *) HW_PXP_HW_PXP_POWER_REG0_ADDR(x))
#define HW_PXP_HW_PXP_POWER_REG0_RD(x) (HW_PXP_HW_PXP_POWER_REG0(x).U)
#define HW_PXP_HW_PXP_POWER_REG0_WR(x, v) (HW_PXP_HW_PXP_POWER_REG0(x).U = (v))
#define HW_PXP_HW_PXP_POWER_REG0_SET(x, v) (HW_PXP_HW_PXP_POWER_REG0_WR(x, HW_PXP_HW_PXP_POWER_REG0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_POWER_REG0_CLR(x, v) (HW_PXP_HW_PXP_POWER_REG0_WR(x, HW_PXP_HW_PXP_POWER_REG0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_POWER_REG0_TOG(x, v) (HW_PXP_HW_PXP_POWER_REG0_WR(x, HW_PXP_HW_PXP_POWER_REG0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_POWER_REG0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_POWER_REG0, field LUT_LP_STATE_WAY0_BANK0[2:0] (RW)
 *
 * Select the low power state of the LUT's WAY0-BANK0 memory.
 *
 * Values:
 * - 0 - Memory is not in low power state.
 * - 1 - Light Sleep Mode. Low leakage mode, maintain memory contents.
 * - 10 - Deep Sleep Mode. Low leakage mode, maintain memory contents.
 * - 100 - Shut Down Mode. Shut Down periphery and core, no memory retention.
 */
/*@{*/
#define BP_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0 (0U) /*!< Bit position for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0. */
#define BM_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0 (0x00000007U) /*!< Bit mask for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0. */
#define BS_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0 (3U) /*!< Bit field size in bits for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0. */

#define BV_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0_NONE (0U) /*!< Bit field value for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0: Memory is not in low power state. */
#define BV_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0_LS (0x1U) /*!< Bit field value for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0: Light Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0_DS (0x2U) /*!< Bit field value for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0: Deep Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0_SD (0x4U) /*!< Bit field value for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0: Shut Down Mode. Shut Down periphery and core, no memory retention. */

/*! @brief Read current value of the PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0 field. */
#define BR_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0(x) (HW_PXP_HW_PXP_POWER_REG0(x).B.LUT_LP_STATE_WAY0_BANK0)

/*! @brief Format value for bitfield PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0. */
#define BF_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0) & BM_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0)

/*! @brief Set the LUT_LP_STATE_WAY0_BANK0 field to a new value. */
#define BW_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0(x, v) (HW_PXP_HW_PXP_POWER_REG0_WR(x, (HW_PXP_HW_PXP_POWER_REG0_RD(x) & ~BM_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0) | BF_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANK0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_POWER_REG0, field LUT_LP_STATE_WAY0_BANKN[5:3] (RW)
 *
 * Select the low power state of the LUT's WAY0-BANK1,2,3 memory.
 *
 * Values:
 * - 0 - Memory is not in low power state.
 * - 1 - Light Sleep Mode. Low leakage mode, maintain memory contents.
 * - 10 - Deep Sleep Mode. Low leakage mode, maintain memory contents.
 * - 100 - Shut Down Mode. Shut Down periphery and core, no memory retention.
 */
/*@{*/
#define BP_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN (3U) /*!< Bit position for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN. */
#define BM_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN (0x00000038U) /*!< Bit mask for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN. */
#define BS_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN (3U) /*!< Bit field size in bits for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN. */

#define BV_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN_NONE (0U) /*!< Bit field value for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN: Memory is not in low power state. */
#define BV_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN_LS (0x1U) /*!< Bit field value for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN: Light Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN_DS (0x2U) /*!< Bit field value for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN: Deep Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN_SD (0x4U) /*!< Bit field value for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN: Shut Down Mode. Shut Down periphery and core, no memory retention. */

/*! @brief Read current value of the PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN field. */
#define BR_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN(x) (HW_PXP_HW_PXP_POWER_REG0(x).B.LUT_LP_STATE_WAY0_BANKN)

/*! @brief Format value for bitfield PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN. */
#define BF_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN) & BM_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN)

/*! @brief Set the LUT_LP_STATE_WAY0_BANKN field to a new value. */
#define BW_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN(x, v) (HW_PXP_HW_PXP_POWER_REG0_WR(x, (HW_PXP_HW_PXP_POWER_REG0_RD(x) & ~BM_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN) | BF_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY0_BANKN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_POWER_REG0, field LUT_LP_STATE_WAY1_BANKN[8:6] (RW)
 *
 * Select the low power state of the LUT's WAY0-BANK0,1,2,3 memory.
 *
 * Values:
 * - 0 - Memory is not in low power state.
 * - 1 - Light Sleep Mode. Low leakage mode, maintain memory contents.
 * - 10 - Deep Sleep Mode. Low leakage mode, maintain memory contents.
 * - 100 - Shut Down Mode. Shut Down periphery and core, no memory retention.
 */
/*@{*/
#define BP_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN (6U) /*!< Bit position for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN. */
#define BM_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN (0x000001C0U) /*!< Bit mask for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN. */
#define BS_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN (3U) /*!< Bit field size in bits for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN. */

#define BV_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN_NONE (0U) /*!< Bit field value for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN: Memory is not in low power state. */
#define BV_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN_LS (0x1U) /*!< Bit field value for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN: Light Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN_DS (0x2U) /*!< Bit field value for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN: Deep Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN_SD (0x4U) /*!< Bit field value for PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN: Shut Down Mode. Shut Down periphery and core, no memory retention. */

/*! @brief Read current value of the PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN field. */
#define BR_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN(x) (HW_PXP_HW_PXP_POWER_REG0(x).B.LUT_LP_STATE_WAY1_BANKN)

/*! @brief Format value for bitfield PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN. */
#define BF_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN) & BM_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN)

/*! @brief Set the LUT_LP_STATE_WAY1_BANKN field to a new value. */
#define BW_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN(x, v) (HW_PXP_HW_PXP_POWER_REG0_WR(x, (HW_PXP_HW_PXP_POWER_REG0_RD(x) & ~BM_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN) | BF_PXP_HW_PXP_POWER_REG0_LUT_LP_STATE_WAY1_BANKN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_POWER_REG0, field ROT0_MEM_LP_STATE[11:9] (RW)
 *
 * Select the low power state of the ROT 0 memory.
 *
 * Values:
 * - 0 - Memory is not in low power state.
 * - 1 - Light Sleep Mode. Low leakage mode, maintain memory contents.
 * - 10 - Deep Sleep Mode. Low leakage mode, maintain memory contents.
 * - 100 - Shut Down Mode. Shut Down periphery and core, no memory retention.
 */
/*@{*/
#define BP_PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE (9U) /*!< Bit position for PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE. */
#define BM_PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE (0x00000E00U) /*!< Bit mask for PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE. */
#define BS_PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE (3U) /*!< Bit field size in bits for PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE. */

#define BV_PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE_NONE (0U) /*!< Bit field value for PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE: Memory is not in low power state. */
#define BV_PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE_LS (0x1U) /*!< Bit field value for PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE: Light Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE_DS (0x2U) /*!< Bit field value for PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE: Deep Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE_SD (0x4U) /*!< Bit field value for PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE: Shut Down Mode. Shut Down periphery and core, no memory retention. */

/*! @brief Read current value of the PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE field. */
#define BR_PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE(x) (HW_PXP_HW_PXP_POWER_REG0(x).B.ROT0_MEM_LP_STATE)

/*! @brief Format value for bitfield PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE. */
#define BF_PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE) & BM_PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE)

/*! @brief Set the ROT0_MEM_LP_STATE field to a new value. */
#define BW_PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE(x, v) (HW_PXP_HW_PXP_POWER_REG0_WR(x, (HW_PXP_HW_PXP_POWER_REG0_RD(x) & ~BM_PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE) | BF_PXP_HW_PXP_POWER_REG0_ROT0_MEM_LP_STATE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_POWER_REG0, field CTRL[31:12] (RW)
 *
 * This register contains power control for the PXP.
 */
/*@{*/
#define BP_PXP_HW_PXP_POWER_REG0_CTRL (12U) /*!< Bit position for PXP_HW_PXP_POWER_REG0_CTRL. */
#define BM_PXP_HW_PXP_POWER_REG0_CTRL (0xFFFFF000U) /*!< Bit mask for PXP_HW_PXP_POWER_REG0_CTRL. */
#define BS_PXP_HW_PXP_POWER_REG0_CTRL (20U) /*!< Bit field size in bits for PXP_HW_PXP_POWER_REG0_CTRL. */

/*! @brief Read current value of the PXP_HW_PXP_POWER_REG0_CTRL field. */
#define BR_PXP_HW_PXP_POWER_REG0_CTRL(x) (HW_PXP_HW_PXP_POWER_REG0(x).B.CTRL)

/*! @brief Format value for bitfield PXP_HW_PXP_POWER_REG0_CTRL. */
#define BF_PXP_HW_PXP_POWER_REG0_CTRL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_POWER_REG0_CTRL) & BM_PXP_HW_PXP_POWER_REG0_CTRL)

/*! @brief Set the CTRL field to a new value. */
#define BW_PXP_HW_PXP_POWER_REG0_CTRL(x, v) (HW_PXP_HW_PXP_POWER_REG0_WR(x, (HW_PXP_HW_PXP_POWER_REG0_RD(x) & ~BM_PXP_HW_PXP_POWER_REG0_CTRL) | BF_PXP_HW_PXP_POWER_REG0_CTRL(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_POWER_REG1 - PXP Power Control Register 1.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_POWER_REG1 - PXP Power Control Register 1. (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register controls power states for PXP memories.
 */
typedef union _hw_pxp_hw_pxp_power_reg1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_power_reg1_bitfields
    {
        uint32_t ROT1_MEM_LP_STATE : 3; /*!< [2:0]  */
        uint32_t DITH0_LUT_MEM_LP_STATE : 3; /*!< [5:3]  */
        uint32_t DITH0_ERR0_MEM_LP_STATE : 3; /*!< [8:6]  */
        uint32_t DITH0_ERR1_MEM_LP_STATE : 3; /*!< [11:9]  */
        uint32_t DITH1_LUT_MEM_LP_STATE : 3; /*!< [14:12]  */
        uint32_t DITH2_LUT_MEM_LP_STATE : 3; /*!< [17:15]  */
        uint32_t ALU_A_MEM_LP_STATE : 3; /*!< [20:18]  */
        uint32_t ALU_B_MEM_LP_STATE : 3; /*!< [23:21]  */
        uint32_t RSVD0 : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_power_reg1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_POWER_REG1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_POWER_REG1_ADDR(x) ((uintptr_t)(x) + 0x330U)

#define HW_PXP_HW_PXP_POWER_REG1(x) (*(__IO hw_pxp_hw_pxp_power_reg1_t *) HW_PXP_HW_PXP_POWER_REG1_ADDR(x))
#define HW_PXP_HW_PXP_POWER_REG1_RD(x) (HW_PXP_HW_PXP_POWER_REG1(x).U)
#define HW_PXP_HW_PXP_POWER_REG1_WR(x, v) (HW_PXP_HW_PXP_POWER_REG1(x).U = (v))
#define HW_PXP_HW_PXP_POWER_REG1_SET(x, v) (HW_PXP_HW_PXP_POWER_REG1_WR(x, HW_PXP_HW_PXP_POWER_REG1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_POWER_REG1_CLR(x, v) (HW_PXP_HW_PXP_POWER_REG1_WR(x, HW_PXP_HW_PXP_POWER_REG1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_POWER_REG1_TOG(x, v) (HW_PXP_HW_PXP_POWER_REG1_WR(x, HW_PXP_HW_PXP_POWER_REG1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_POWER_REG1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_POWER_REG1, field ROT1_MEM_LP_STATE[2:0] (RW)
 *
 * Select the low power state of the ROT 1 memory.
 *
 * Values:
 * - 0 - Memory is not in low power state.
 * - 1 - Light Sleep Mode. Low leakage mode, maintain memory contents.
 * - 10 - Deep Sleep Mode. Low leakage mode, maintain memory contents.
 * - 100 - Shut Down Mode. Shut Down periphery and core, no memory retention.
 */
/*@{*/
#define BP_PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE (0U) /*!< Bit position for PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE. */
#define BM_PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE (0x00000007U) /*!< Bit mask for PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE. */
#define BS_PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE (3U) /*!< Bit field size in bits for PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE. */

#define BV_PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE_NONE (0U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE: Memory is not in low power state. */
#define BV_PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE_LS (0x1U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE: Light Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE_DS (0x2U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE: Deep Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE_SD (0x4U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE: Shut Down Mode. Shut Down periphery and core, no memory retention. */

/*! @brief Read current value of the PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE field. */
#define BR_PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE(x) (HW_PXP_HW_PXP_POWER_REG1(x).B.ROT1_MEM_LP_STATE)

/*! @brief Format value for bitfield PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE. */
#define BF_PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE) & BM_PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE)

/*! @brief Set the ROT1_MEM_LP_STATE field to a new value. */
#define BW_PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE(x, v) (HW_PXP_HW_PXP_POWER_REG1_WR(x, (HW_PXP_HW_PXP_POWER_REG1_RD(x) & ~BM_PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE) | BF_PXP_HW_PXP_POWER_REG1_ROT1_MEM_LP_STATE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_POWER_REG1, field DITH0_LUT_MEM_LP_STATE[5:3] (RW)
 *
 * Select the low power state of the dither0 LUT memory.
 *
 * Values:
 * - 0 - Memory is not in low power state.
 * - 1 - Light Sleep Mode. Low leakage mode, maintain memory contents.
 * - 10 - Deep Sleep Mode. Low leakage mode, maintain memory contents.
 * - 100 - Shut Down Mode. Shut Down periphery and core, no memory retention.
 */
/*@{*/
#define BP_PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE (3U) /*!< Bit position for PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE. */
#define BM_PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE (0x00000038U) /*!< Bit mask for PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE. */
#define BS_PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE (3U) /*!< Bit field size in bits for PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE. */

#define BV_PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE_NONE (0U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE: Memory is not in low power state. */
#define BV_PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE_LS (0x1U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE: Light Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE_DS (0x2U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE: Deep Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE_SD (0x4U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE: Shut Down Mode. Shut Down periphery and core, no memory retention. */

/*! @brief Read current value of the PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE field. */
#define BR_PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE(x) (HW_PXP_HW_PXP_POWER_REG1(x).B.DITH0_LUT_MEM_LP_STATE)

/*! @brief Format value for bitfield PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE. */
#define BF_PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE) & BM_PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE)

/*! @brief Set the DITH0_LUT_MEM_LP_STATE field to a new value. */
#define BW_PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE(x, v) (HW_PXP_HW_PXP_POWER_REG1_WR(x, (HW_PXP_HW_PXP_POWER_REG1_RD(x) & ~BM_PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE) | BF_PXP_HW_PXP_POWER_REG1_DITH0_LUT_MEM_LP_STATE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_POWER_REG1, field DITH0_ERR0_MEM_LP_STATE[8:6] (RW)
 *
 * Select the low power state of the dither0 ERR0 memory.
 *
 * Values:
 * - 0 - Memory is not in low power state.
 * - 1 - Light Sleep Mode. Low leakage mode, maintain memory contents.
 * - 10 - Deep Sleep Mode. Low leakage mode, maintain memory contents.
 * - 100 - Shut Down Mode. Shut Down periphery and core, no memory retention.
 */
/*@{*/
#define BP_PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE (6U) /*!< Bit position for PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE. */
#define BM_PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE (0x000001C0U) /*!< Bit mask for PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE. */
#define BS_PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE (3U) /*!< Bit field size in bits for PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE. */

#define BV_PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE_NONE (0U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE: Memory is not in low power state. */
#define BV_PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE_LS (0x1U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE: Light Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE_DS (0x2U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE: Deep Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE_SD (0x4U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE: Shut Down Mode. Shut Down periphery and core, no memory retention. */

/*! @brief Read current value of the PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE field. */
#define BR_PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE(x) (HW_PXP_HW_PXP_POWER_REG1(x).B.DITH0_ERR0_MEM_LP_STATE)

/*! @brief Format value for bitfield PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE. */
#define BF_PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE) & BM_PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE)

/*! @brief Set the DITH0_ERR0_MEM_LP_STATE field to a new value. */
#define BW_PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE(x, v) (HW_PXP_HW_PXP_POWER_REG1_WR(x, (HW_PXP_HW_PXP_POWER_REG1_RD(x) & ~BM_PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE) | BF_PXP_HW_PXP_POWER_REG1_DITH0_ERR0_MEM_LP_STATE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_POWER_REG1, field DITH0_ERR1_MEM_LP_STATE[11:9] (RW)
 *
 * Select the low power state of the dither0 ERR1 memory.
 *
 * Values:
 * - 0 - Memory is not in low power state.
 * - 1 - Light Sleep Mode. Low leakage mode, maintain memory contents.
 * - 10 - Deep Sleep Mode. Low leakage mode, maintain memory contents.
 * - 100 - Shut Down Mode. Shut Down periphery and core, no memory retention.
 */
/*@{*/
#define BP_PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE (9U) /*!< Bit position for PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE. */
#define BM_PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE (0x00000E00U) /*!< Bit mask for PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE. */
#define BS_PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE (3U) /*!< Bit field size in bits for PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE. */

#define BV_PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE_NONE (0U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE: Memory is not in low power state. */
#define BV_PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE_LS (0x1U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE: Light Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE_DS (0x2U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE: Deep Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE_SD (0x4U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE: Shut Down Mode. Shut Down periphery and core, no memory retention. */

/*! @brief Read current value of the PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE field. */
#define BR_PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE(x) (HW_PXP_HW_PXP_POWER_REG1(x).B.DITH0_ERR1_MEM_LP_STATE)

/*! @brief Format value for bitfield PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE. */
#define BF_PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE) & BM_PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE)

/*! @brief Set the DITH0_ERR1_MEM_LP_STATE field to a new value. */
#define BW_PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE(x, v) (HW_PXP_HW_PXP_POWER_REG1_WR(x, (HW_PXP_HW_PXP_POWER_REG1_RD(x) & ~BM_PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE) | BF_PXP_HW_PXP_POWER_REG1_DITH0_ERR1_MEM_LP_STATE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_POWER_REG1, field DITH1_LUT_MEM_LP_STATE[14:12] (RW)
 *
 * Select the low power state of the dither1 LUT memory.
 *
 * Values:
 * - 0 - Memory is not in low power state.
 * - 1 - Light Sleep Mode. Low leakage mode, maintain memory contents.
 * - 10 - Deep Sleep Mode. Low leakage mode, maintain memory contents.
 * - 100 - Shut Down Mode. Shut Down periphery and core, no memory retention.
 */
/*@{*/
#define BP_PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE (12U) /*!< Bit position for PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE. */
#define BM_PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE (0x00007000U) /*!< Bit mask for PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE. */
#define BS_PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE (3U) /*!< Bit field size in bits for PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE. */

#define BV_PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE_NONE (0U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE: Memory is not in low power state. */
#define BV_PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE_LS (0x1U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE: Light Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE_DS (0x2U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE: Deep Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE_SD (0x4U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE: Shut Down Mode. Shut Down periphery and core, no memory retention. */

/*! @brief Read current value of the PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE field. */
#define BR_PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE(x) (HW_PXP_HW_PXP_POWER_REG1(x).B.DITH1_LUT_MEM_LP_STATE)

/*! @brief Format value for bitfield PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE. */
#define BF_PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE) & BM_PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE)

/*! @brief Set the DITH1_LUT_MEM_LP_STATE field to a new value. */
#define BW_PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE(x, v) (HW_PXP_HW_PXP_POWER_REG1_WR(x, (HW_PXP_HW_PXP_POWER_REG1_RD(x) & ~BM_PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE) | BF_PXP_HW_PXP_POWER_REG1_DITH1_LUT_MEM_LP_STATE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_POWER_REG1, field DITH2_LUT_MEM_LP_STATE[17:15] (RW)
 *
 * Select the low power state of the dither2 LUT memory.
 *
 * Values:
 * - 0 - Memory is not in low power state.
 * - 1 - Light Sleep Mode. Low leakage mode, maintain memory contents.
 * - 10 - Deep Sleep Mode. Low leakage mode, maintain memory contents.
 * - 100 - Shut Down Mode. Shut Down periphery and core, no memory retention.
 */
/*@{*/
#define BP_PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE (15U) /*!< Bit position for PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE. */
#define BM_PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE (0x00038000U) /*!< Bit mask for PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE. */
#define BS_PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE (3U) /*!< Bit field size in bits for PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE. */

#define BV_PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE_NONE (0U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE: Memory is not in low power state. */
#define BV_PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE_LS (0x1U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE: Light Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE_DS (0x2U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE: Deep Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE_SD (0x4U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE: Shut Down Mode. Shut Down periphery and core, no memory retention. */

/*! @brief Read current value of the PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE field. */
#define BR_PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE(x) (HW_PXP_HW_PXP_POWER_REG1(x).B.DITH2_LUT_MEM_LP_STATE)

/*! @brief Format value for bitfield PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE. */
#define BF_PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE) & BM_PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE)

/*! @brief Set the DITH2_LUT_MEM_LP_STATE field to a new value. */
#define BW_PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE(x, v) (HW_PXP_HW_PXP_POWER_REG1_WR(x, (HW_PXP_HW_PXP_POWER_REG1_RD(x) & ~BM_PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE) | BF_PXP_HW_PXP_POWER_REG1_DITH2_LUT_MEM_LP_STATE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_POWER_REG1, field ALU_A_MEM_LP_STATE[20:18] (RW)
 *
 * Select the low power state of the ALU A memory.
 *
 * Values:
 * - 0 - Memory is not in low power state.
 * - 1 - Light Sleep Mode. Low leakage mode, maintain memory contents.
 * - 10 - Deep Sleep Mode. Low leakage mode, maintain memory contents.
 * - 100 - Shut Down Mode. Shut Down periphery and core, no memory retention.
 */
/*@{*/
#define BP_PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE (18U) /*!< Bit position for PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE. */
#define BM_PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE (0x001C0000U) /*!< Bit mask for PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE. */
#define BS_PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE (3U) /*!< Bit field size in bits for PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE. */

#define BV_PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE_NONE (0U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE: Memory is not in low power state. */
#define BV_PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE_LS (0x1U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE: Light Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE_DS (0x2U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE: Deep Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE_SD (0x4U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE: Shut Down Mode. Shut Down periphery and core, no memory retention. */

/*! @brief Read current value of the PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE field. */
#define BR_PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE(x) (HW_PXP_HW_PXP_POWER_REG1(x).B.ALU_A_MEM_LP_STATE)

/*! @brief Format value for bitfield PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE. */
#define BF_PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE) & BM_PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE)

/*! @brief Set the ALU_A_MEM_LP_STATE field to a new value. */
#define BW_PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE(x, v) (HW_PXP_HW_PXP_POWER_REG1_WR(x, (HW_PXP_HW_PXP_POWER_REG1_RD(x) & ~BM_PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE) | BF_PXP_HW_PXP_POWER_REG1_ALU_A_MEM_LP_STATE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_POWER_REG1, field ALU_B_MEM_LP_STATE[23:21] (RW)
 *
 * Select the low power state of the ALU B memory.
 *
 * Values:
 * - 0 - Memory is not in low power state.
 * - 1 - Light Sleep Mode. Low leakage mode, maintain memory contents.
 * - 10 - Deep Sleep Mode. Low leakage mode, maintain memory contents.
 * - 100 - Shut Down Mode. Shut Down periphery and core, no memory retention.
 */
/*@{*/
#define BP_PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE (21U) /*!< Bit position for PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE. */
#define BM_PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE (0x00E00000U) /*!< Bit mask for PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE. */
#define BS_PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE (3U) /*!< Bit field size in bits for PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE. */

#define BV_PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE_NONE (0U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE: Memory is not in low power state. */
#define BV_PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE_LS (0x1U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE: Light Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE_DS (0x2U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE: Deep Sleep Mode. Low leakage mode, maintain memory contents. */
#define BV_PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE_SD (0x4U) /*!< Bit field value for PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE: Shut Down Mode. Shut Down periphery and core, no memory retention. */

/*! @brief Read current value of the PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE field. */
#define BR_PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE(x) (HW_PXP_HW_PXP_POWER_REG1(x).B.ALU_B_MEM_LP_STATE)

/*! @brief Format value for bitfield PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE. */
#define BF_PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE) & BM_PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE)

/*! @brief Set the ALU_B_MEM_LP_STATE field to a new value. */
#define BW_PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE(x, v) (HW_PXP_HW_PXP_POWER_REG1_WR(x, (HW_PXP_HW_PXP_POWER_REG1_RD(x) & ~BM_PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE) | BF_PXP_HW_PXP_POWER_REG1_ALU_B_MEM_LP_STATE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_POWER_REG1, field RSVD0[31:24] (RO)
 *
 * This register contains power control for the PXP.
 */
/*@{*/
#define BP_PXP_HW_PXP_POWER_REG1_RSVD0 (24U) /*!< Bit position for PXP_HW_PXP_POWER_REG1_RSVD0. */
#define BM_PXP_HW_PXP_POWER_REG1_RSVD0 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_POWER_REG1_RSVD0. */
#define BS_PXP_HW_PXP_POWER_REG1_RSVD0 (8U) /*!< Bit field size in bits for PXP_HW_PXP_POWER_REG1_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_POWER_REG1_RSVD0 field. */
#define BR_PXP_HW_PXP_POWER_REG1_RSVD0(x) (HW_PXP_HW_PXP_POWER_REG1(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DATA_PATH_CTRL1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DATA_PATH_CTRL1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register helps decide the data path gthrough the PXP.
 * HW_PXP_DATA_PATH_CTRL1: 0x350 HW_PXP_DATA_PATH_CTRL1_SET: 0x354 HW_PXP_DATA_PATH_CTRL1_CLR:
 * 0x358 HW_PXP_DATA_PATH_CTRL1_TOG: 0x35C The Control register contains the control
 * bits for the data path through the PXP. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_data_path_ctrl1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_data_path_ctrl1_bitfields
    {
        uint32_t MUX16_SEL : 2;        /*!< [1:0]  */
        uint32_t MUX17_SEL : 2;        /*!< [3:2]  */
        uint32_t RSVD0 : 28;           /*!< [31:4]  */
    } B;
} hw_pxp_hw_pxp_data_path_ctrl1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DATA_PATH_CTRL1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DATA_PATH_CTRL1_ADDR(x) ((uintptr_t)(x) + 0x350U)

#define HW_PXP_HW_PXP_DATA_PATH_CTRL1(x) (*(__IO hw_pxp_hw_pxp_data_path_ctrl1_t *) HW_PXP_HW_PXP_DATA_PATH_CTRL1_ADDR(x))
#define HW_PXP_HW_PXP_DATA_PATH_CTRL1_RD(x) (HW_PXP_HW_PXP_DATA_PATH_CTRL1(x).U)
#define HW_PXP_HW_PXP_DATA_PATH_CTRL1_WR(x, v) (HW_PXP_HW_PXP_DATA_PATH_CTRL1(x).U = (v))
#define HW_PXP_HW_PXP_DATA_PATH_CTRL1_SET(x, v) (HW_PXP_HW_PXP_DATA_PATH_CTRL1_WR(x, HW_PXP_HW_PXP_DATA_PATH_CTRL1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DATA_PATH_CTRL1_CLR(x, v) (HW_PXP_HW_PXP_DATA_PATH_CTRL1_WR(x, HW_PXP_HW_PXP_DATA_PATH_CTRL1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DATA_PATH_CTRL1_TOG(x, v) (HW_PXP_HW_PXP_DATA_PATH_CTRL1_WR(x, HW_PXP_HW_PXP_DATA_PATH_CTRL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DATA_PATH_CTRL1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DATA_PATH_CTRL1, field MUX16_SEL[1:0] (RW)
 *
 * This mux chooses the data path through MUX 16.
 *
 * Values:
 * - 0 - Output of ALU A Engine
 * - 1 - histogram_pixel output from output
 * - 10 - Output of ALU B Engine
 * - 11 - No output
 */
/*@{*/
#define BP_PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL (0U) /*!< Bit position for PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL. */
#define BM_PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL (0x00000003U) /*!< Bit mask for PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL. */
#define BS_PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL (2U) /*!< Bit field size in bits for PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL. */

#define BV_PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL_0 (0U) /*!< Bit field value for PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL: Output of ALU A Engine */
#define BV_PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL: histogram_pixel output from output */
#define BV_PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL: Output of ALU B Engine */
#define BV_PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL: No output */

/*! @brief Read current value of the PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL field. */
#define BR_PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL(x) (HW_PXP_HW_PXP_DATA_PATH_CTRL1(x).B.MUX16_SEL)

/*! @brief Format value for bitfield PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL. */
#define BF_PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL) & BM_PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL)

/*! @brief Set the MUX16_SEL field to a new value. */
#define BW_PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL(x, v) (HW_PXP_HW_PXP_DATA_PATH_CTRL1_WR(x, (HW_PXP_HW_PXP_DATA_PATH_CTRL1_RD(x) & ~BM_PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL) | BF_PXP_HW_PXP_DATA_PATH_CTRL1_MUX16_SEL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DATA_PATH_CTRL1, field MUX17_SEL[3:2] (RW)
 *
 * This field chooses the data path through MUX 17.
 *
 * Values:
 * - 0 - Output of ALU A
 * - 1 - Output of ALU B
 * - 10 - No output
 * - 11 - No Output
 */
/*@{*/
#define BP_PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL (2U) /*!< Bit position for PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL. */
#define BM_PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL (0x0000000CU) /*!< Bit mask for PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL. */
#define BS_PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL (2U) /*!< Bit field size in bits for PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL. */

#define BV_PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL_0 (0U) /*!< Bit field value for PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL: Output of ALU A */
#define BV_PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL: Output of ALU B */
#define BV_PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL: No output */
#define BV_PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL: No Output */

/*! @brief Read current value of the PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL field. */
#define BR_PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL(x) (HW_PXP_HW_PXP_DATA_PATH_CTRL1(x).B.MUX17_SEL)

/*! @brief Format value for bitfield PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL. */
#define BF_PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL) & BM_PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL)

/*! @brief Set the MUX17_SEL field to a new value. */
#define BW_PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL(x, v) (HW_PXP_HW_PXP_DATA_PATH_CTRL1_WR(x, (HW_PXP_HW_PXP_DATA_PATH_CTRL1_RD(x) & ~BM_PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL) | BF_PXP_HW_PXP_DATA_PATH_CTRL1_MUX17_SEL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DATA_PATH_CTRL1, field RSVD0[31:4] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_DATA_PATH_CTRL1_RSVD0 (4U) /*!< Bit position for PXP_HW_PXP_DATA_PATH_CTRL1_RSVD0. */
#define BM_PXP_HW_PXP_DATA_PATH_CTRL1_RSVD0 (0xFFFFFFF0U) /*!< Bit mask for PXP_HW_PXP_DATA_PATH_CTRL1_RSVD0. */
#define BS_PXP_HW_PXP_DATA_PATH_CTRL1_RSVD0 (28U) /*!< Bit field size in bits for PXP_HW_PXP_DATA_PATH_CTRL1_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_DATA_PATH_CTRL1_RSVD0 field. */
#define BR_PXP_HW_PXP_DATA_PATH_CTRL1_RSVD0(x) (HW_PXP_HW_PXP_DATA_PATH_CTRL1(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INIT_MEM_CTRL - Initialize memory buffer control Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INIT_MEM_CTRL - Initialize memory buffer control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Controls initializing/writing to dither and ALU memory buffers.
 * HW_PXP_INIT_MEM_CTRL: 0x360 HW_PXP_INIT_MEM_CTRL_SET: 0x364 HW_PXP_INIT_MEM_CTRL_CLR: 0x368
 * HW_PXP_INIT_MEM_CTRL_TOG: 0x36C This register controls IRQ the intializing of
 * internal pxp rams. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_init_mem_ctrl
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_init_mem_ctrl_bitfields
    {
        uint32_t ADDR : 16;            /*!< [15:0]  */
        uint32_t RSVD0 : 11;           /*!< [26:16]  */
        uint32_t SELECT : 4;           /*!< [30:27]  */
        uint32_t START : 1;            /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_init_mem_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INIT_MEM_CTRL register
 */
/*@{*/
#define HW_PXP_HW_PXP_INIT_MEM_CTRL_ADDR(x) ((uintptr_t)(x) + 0x360U)

#define HW_PXP_HW_PXP_INIT_MEM_CTRL(x) (*(__IO hw_pxp_hw_pxp_init_mem_ctrl_t *) HW_PXP_HW_PXP_INIT_MEM_CTRL_ADDR(x))
#define HW_PXP_HW_PXP_INIT_MEM_CTRL_RD(x) (HW_PXP_HW_PXP_INIT_MEM_CTRL(x).U)
#define HW_PXP_HW_PXP_INIT_MEM_CTRL_WR(x, v) (HW_PXP_HW_PXP_INIT_MEM_CTRL(x).U = (v))
#define HW_PXP_HW_PXP_INIT_MEM_CTRL_SET(x, v) (HW_PXP_HW_PXP_INIT_MEM_CTRL_WR(x, HW_PXP_HW_PXP_INIT_MEM_CTRL_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INIT_MEM_CTRL_CLR(x, v) (HW_PXP_HW_PXP_INIT_MEM_CTRL_WR(x, HW_PXP_HW_PXP_INIT_MEM_CTRL_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INIT_MEM_CTRL_TOG(x, v) (HW_PXP_HW_PXP_INIT_MEM_CTRL_WR(x, HW_PXP_HW_PXP_INIT_MEM_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INIT_MEM_CTRL bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INIT_MEM_CTRL, field ADDR[15:0] (RW)
 *
 * Base address to start writing. The control logic will increment the address
 * value internally each time the data register is written.
 */
/*@{*/
#define BP_PXP_HW_PXP_INIT_MEM_CTRL_ADDR (0U) /*!< Bit position for PXP_HW_PXP_INIT_MEM_CTRL_ADDR. */
#define BM_PXP_HW_PXP_INIT_MEM_CTRL_ADDR (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_INIT_MEM_CTRL_ADDR. */
#define BS_PXP_HW_PXP_INIT_MEM_CTRL_ADDR (16U) /*!< Bit field size in bits for PXP_HW_PXP_INIT_MEM_CTRL_ADDR. */

/*! @brief Read current value of the PXP_HW_PXP_INIT_MEM_CTRL_ADDR field. */
#define BR_PXP_HW_PXP_INIT_MEM_CTRL_ADDR(x) (HW_PXP_HW_PXP_INIT_MEM_CTRL(x).B.ADDR)

/*! @brief Format value for bitfield PXP_HW_PXP_INIT_MEM_CTRL_ADDR. */
#define BF_PXP_HW_PXP_INIT_MEM_CTRL_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INIT_MEM_CTRL_ADDR) & BM_PXP_HW_PXP_INIT_MEM_CTRL_ADDR)

/*! @brief Set the ADDR field to a new value. */
#define BW_PXP_HW_PXP_INIT_MEM_CTRL_ADDR(x, v) (HW_PXP_HW_PXP_INIT_MEM_CTRL_WR(x, (HW_PXP_HW_PXP_INIT_MEM_CTRL_RD(x) & ~BM_PXP_HW_PXP_INIT_MEM_CTRL_ADDR) | BF_PXP_HW_PXP_INIT_MEM_CTRL_ADDR(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INIT_MEM_CTRL, field RSVD0[26:16] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_PXP_HW_PXP_INIT_MEM_CTRL_RSVD0 (16U) /*!< Bit position for PXP_HW_PXP_INIT_MEM_CTRL_RSVD0. */
#define BM_PXP_HW_PXP_INIT_MEM_CTRL_RSVD0 (0x07FF0000U) /*!< Bit mask for PXP_HW_PXP_INIT_MEM_CTRL_RSVD0. */
#define BS_PXP_HW_PXP_INIT_MEM_CTRL_RSVD0 (11U) /*!< Bit field size in bits for PXP_HW_PXP_INIT_MEM_CTRL_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_INIT_MEM_CTRL_RSVD0 field. */
#define BR_PXP_HW_PXP_INIT_MEM_CTRL_RSVD0(x) (HW_PXP_HW_PXP_INIT_MEM_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INIT_MEM_CTRL, field SELECT[30:27] (RW)
 *
 * Select which memory to write.
 *
 * Values:
 * - 0 - Select the LUT memory for access
 * - 1 - Select the ERR0 memory for access
 * - 10 - Select the ERR1 memory for access
 * - 11 - Select the LUT memory for access
 * - 100 - Select the LUT memory for access
 * - 101 - Select the ALU instr memory for access
 * - 110 - Select the ALU instr memory for access
 * - 111 - Select the WFE-A fetch memory for access
 * - 1000 - Select the WFE-B fetch memory for access
 */
/*@{*/
#define BP_PXP_HW_PXP_INIT_MEM_CTRL_SELECT (27U) /*!< Bit position for PXP_HW_PXP_INIT_MEM_CTRL_SELECT. */
#define BM_PXP_HW_PXP_INIT_MEM_CTRL_SELECT (0x78000000U) /*!< Bit mask for PXP_HW_PXP_INIT_MEM_CTRL_SELECT. */
#define BS_PXP_HW_PXP_INIT_MEM_CTRL_SELECT (4U) /*!< Bit field size in bits for PXP_HW_PXP_INIT_MEM_CTRL_SELECT. */

#define BV_PXP_HW_PXP_INIT_MEM_CTRL_SELECT_DITHER0_LUT (0U) /*!< Bit field value for PXP_HW_PXP_INIT_MEM_CTRL_SELECT: Select the LUT memory for access */
#define BV_PXP_HW_PXP_INIT_MEM_CTRL_SELECT_DITHER0_ERR0 (0x1U) /*!< Bit field value for PXP_HW_PXP_INIT_MEM_CTRL_SELECT: Select the ERR0 memory for access */
#define BV_PXP_HW_PXP_INIT_MEM_CTRL_SELECT_DITHER0_ERR1 (0x2U) /*!< Bit field value for PXP_HW_PXP_INIT_MEM_CTRL_SELECT: Select the ERR1 memory for access */
#define BV_PXP_HW_PXP_INIT_MEM_CTRL_SELECT_DITHER1_LUT (0x3U) /*!< Bit field value for PXP_HW_PXP_INIT_MEM_CTRL_SELECT: Select the LUT memory for access */
#define BV_PXP_HW_PXP_INIT_MEM_CTRL_SELECT_DITHER2_LUT (0x4U) /*!< Bit field value for PXP_HW_PXP_INIT_MEM_CTRL_SELECT: Select the LUT memory for access */
#define BV_PXP_HW_PXP_INIT_MEM_CTRL_SELECT_ALU_A (0x5U) /*!< Bit field value for PXP_HW_PXP_INIT_MEM_CTRL_SELECT: Select the ALU instr memory for access */
#define BV_PXP_HW_PXP_INIT_MEM_CTRL_SELECT_ALU_B (0x6U) /*!< Bit field value for PXP_HW_PXP_INIT_MEM_CTRL_SELECT: Select the ALU instr memory for access */
#define BV_PXP_HW_PXP_INIT_MEM_CTRL_SELECT_WFE_A_FETCH (0x7U) /*!< Bit field value for PXP_HW_PXP_INIT_MEM_CTRL_SELECT: Select the WFE-A fetch memory for access */
#define BV_PXP_HW_PXP_INIT_MEM_CTRL_SELECT_WFE_B_FETCH (0x8U) /*!< Bit field value for PXP_HW_PXP_INIT_MEM_CTRL_SELECT: Select the WFE-B fetch memory for access */

/*! @brief Read current value of the PXP_HW_PXP_INIT_MEM_CTRL_SELECT field. */
#define BR_PXP_HW_PXP_INIT_MEM_CTRL_SELECT(x) (HW_PXP_HW_PXP_INIT_MEM_CTRL(x).B.SELECT)

/*! @brief Format value for bitfield PXP_HW_PXP_INIT_MEM_CTRL_SELECT. */
#define BF_PXP_HW_PXP_INIT_MEM_CTRL_SELECT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INIT_MEM_CTRL_SELECT) & BM_PXP_HW_PXP_INIT_MEM_CTRL_SELECT)

/*! @brief Set the SELECT field to a new value. */
#define BW_PXP_HW_PXP_INIT_MEM_CTRL_SELECT(x, v) (HW_PXP_HW_PXP_INIT_MEM_CTRL_WR(x, (HW_PXP_HW_PXP_INIT_MEM_CTRL_RD(x) & ~BM_PXP_HW_PXP_INIT_MEM_CTRL_SELECT) | BF_PXP_HW_PXP_INIT_MEM_CTRL_SELECT(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INIT_MEM_CTRL, field START[31] (RW)
 *
 * Enable writing to the memory.
 */
/*@{*/
#define BP_PXP_HW_PXP_INIT_MEM_CTRL_START (31U) /*!< Bit position for PXP_HW_PXP_INIT_MEM_CTRL_START. */
#define BM_PXP_HW_PXP_INIT_MEM_CTRL_START (0x80000000U) /*!< Bit mask for PXP_HW_PXP_INIT_MEM_CTRL_START. */
#define BS_PXP_HW_PXP_INIT_MEM_CTRL_START (1U) /*!< Bit field size in bits for PXP_HW_PXP_INIT_MEM_CTRL_START. */

/*! @brief Read current value of the PXP_HW_PXP_INIT_MEM_CTRL_START field. */
#define BR_PXP_HW_PXP_INIT_MEM_CTRL_START(x) (HW_PXP_HW_PXP_INIT_MEM_CTRL(x).B.START)

/*! @brief Format value for bitfield PXP_HW_PXP_INIT_MEM_CTRL_START. */
#define BF_PXP_HW_PXP_INIT_MEM_CTRL_START(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INIT_MEM_CTRL_START) & BM_PXP_HW_PXP_INIT_MEM_CTRL_START)

/*! @brief Set the START field to a new value. */
#define BW_PXP_HW_PXP_INIT_MEM_CTRL_START(x, v) (HW_PXP_HW_PXP_INIT_MEM_CTRL_WR(x, (HW_PXP_HW_PXP_INIT_MEM_CTRL_RD(x) & ~BM_PXP_HW_PXP_INIT_MEM_CTRL_START) | BF_PXP_HW_PXP_INIT_MEM_CTRL_START(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INIT_MEM_DATA - Write data Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INIT_MEM_DATA - Write data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Write data for initializing/writing to dither, ALU and fetch memory buffers.
 * This register holds the data word to intialize internal pxp rams. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_init_mem_data
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_init_mem_data_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_init_mem_data_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INIT_MEM_DATA register
 */
/*@{*/
#define HW_PXP_HW_PXP_INIT_MEM_DATA_ADDR(x) ((uintptr_t)(x) + 0x370U)

#define HW_PXP_HW_PXP_INIT_MEM_DATA(x) (*(__IO hw_pxp_hw_pxp_init_mem_data_t *) HW_PXP_HW_PXP_INIT_MEM_DATA_ADDR(x))
#define HW_PXP_HW_PXP_INIT_MEM_DATA_RD(x) (HW_PXP_HW_PXP_INIT_MEM_DATA(x).U)
#define HW_PXP_HW_PXP_INIT_MEM_DATA_WR(x, v) (HW_PXP_HW_PXP_INIT_MEM_DATA(x).U = (v))
#define HW_PXP_HW_PXP_INIT_MEM_DATA_SET(x, v) (HW_PXP_HW_PXP_INIT_MEM_DATA_WR(x, HW_PXP_HW_PXP_INIT_MEM_DATA_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INIT_MEM_DATA_CLR(x, v) (HW_PXP_HW_PXP_INIT_MEM_DATA_WR(x, HW_PXP_HW_PXP_INIT_MEM_DATA_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INIT_MEM_DATA_TOG(x, v) (HW_PXP_HW_PXP_INIT_MEM_DATA_WR(x, HW_PXP_HW_PXP_INIT_MEM_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INIT_MEM_DATA bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INIT_MEM_DATA, field DATA[31:0] (RW)
 *
 * Data value to be written to the memory. A write to this register kicks off a
 * write cycle to the memory selected.
 */
/*@{*/
#define BP_PXP_HW_PXP_INIT_MEM_DATA_DATA (0U) /*!< Bit position for PXP_HW_PXP_INIT_MEM_DATA_DATA. */
#define BM_PXP_HW_PXP_INIT_MEM_DATA_DATA (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INIT_MEM_DATA_DATA. */
#define BS_PXP_HW_PXP_INIT_MEM_DATA_DATA (32U) /*!< Bit field size in bits for PXP_HW_PXP_INIT_MEM_DATA_DATA. */

/*! @brief Read current value of the PXP_HW_PXP_INIT_MEM_DATA_DATA field. */
#define BR_PXP_HW_PXP_INIT_MEM_DATA_DATA(x) (HW_PXP_HW_PXP_INIT_MEM_DATA(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INIT_MEM_DATA_DATA. */
#define BF_PXP_HW_PXP_INIT_MEM_DATA_DATA(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INIT_MEM_DATA_DATA) & BM_PXP_HW_PXP_INIT_MEM_DATA_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_PXP_HW_PXP_INIT_MEM_DATA_DATA(x, v) (HW_PXP_HW_PXP_INIT_MEM_DATA_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH - Write data Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH - Write data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Write data for initializing/writing to the most significant 32 bits of the
 * fetch memory buffers. This register holds the upper data word to intialize
 * internal pxp fetch rams. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_init_mem_data_high
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_init_mem_data_high_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_init_mem_data_high_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INIT_MEM_DATA_HIGH register
 */
/*@{*/
#define HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH_ADDR(x) ((uintptr_t)(x) + 0x380U)

#define HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH(x) (*(__IO hw_pxp_hw_pxp_init_mem_data_high_t *) HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH_ADDR(x))
#define HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH_RD(x) (HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH(x).U)
#define HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH_WR(x, v) (HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH(x).U = (v))
#define HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH_SET(x, v) (HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH_WR(x, HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH_CLR(x, v) (HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH_WR(x, HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH_TOG(x, v) (HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH_WR(x, HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INIT_MEM_DATA_HIGH bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INIT_MEM_DATA_HIGH, field DATA[31:0] (RW)
 *
 * Data value to be written to the most significant 32 bits of the fetch
 * memories. this register must be written before the HW_PXP_INIT_MEM_DATA as that
 * register triggers the write cycle to memory.
 */
/*@{*/
#define BP_PXP_HW_PXP_INIT_MEM_DATA_HIGH_DATA (0U) /*!< Bit position for PXP_HW_PXP_INIT_MEM_DATA_HIGH_DATA. */
#define BM_PXP_HW_PXP_INIT_MEM_DATA_HIGH_DATA (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INIT_MEM_DATA_HIGH_DATA. */
#define BS_PXP_HW_PXP_INIT_MEM_DATA_HIGH_DATA (32U) /*!< Bit field size in bits for PXP_HW_PXP_INIT_MEM_DATA_HIGH_DATA. */

/*! @brief Read current value of the PXP_HW_PXP_INIT_MEM_DATA_HIGH_DATA field. */
#define BR_PXP_HW_PXP_INIT_MEM_DATA_HIGH_DATA(x) (HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INIT_MEM_DATA_HIGH_DATA. */
#define BF_PXP_HW_PXP_INIT_MEM_DATA_HIGH_DATA(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INIT_MEM_DATA_HIGH_DATA) & BM_PXP_HW_PXP_INIT_MEM_DATA_HIGH_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_PXP_HW_PXP_INIT_MEM_DATA_HIGH_DATA(x, v) (HW_PXP_HW_PXP_INIT_MEM_DATA_HIGH_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_IRQ_MASK - PXP IRQ Mask Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_IRQ_MASK - PXP IRQ Mask Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * Controls masking for all PXP interrupts HW_PXP_IRQ_MASK: 0x390
 * HW_PXP_IRQ_MASK_SET: 0x394 HW_PXP_IRQ_MASK_CLR: 0x398 HW_PXP_IRQ_MASK_TOG: 0x39C This
 * register controls IRQ masks for all PXP interrupts EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_irq_mask
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_irq_mask_bitfields
    {
        uint32_t FIRST_CH0_PREFETCH_IRQ_EN : 1; /*!< [0]  */
        uint32_t FIRST_CH1_PREFETCH_IRQ_EN : 1; /*!< [1]  */
        uint32_t FIRST_CH0_STORE_IRQ_EN : 1; /*!< [2]  */
        uint32_t FIRST_CH1_STORE_IRQ_EN : 1; /*!< [3]  */
        uint32_t DITHER_CH0_PREFETCH_IRQ_EN : 1; /*!< [4]  */
        uint32_t DITHER_CH1_PREFETCH_IRQ_EN : 1; /*!< [5]  */
        uint32_t DITHER_CH0_STORE_IRQ_EN : 1; /*!< [6]  */
        uint32_t DITHER_CH1_STORE_IRQ_EN : 1; /*!< [7]  */
        uint32_t WFE_A_CH0_STORE_IRQ_EN : 1; /*!< [8]  */
        uint32_t WFE_A_CH1_STORE_IRQ_EN : 1; /*!< [9]  */
        uint32_t WFE_B_CH0_STORE_IRQ_EN : 1; /*!< [10]  */
        uint32_t WFE_B_CH1_STORE_IRQ_EN : 1; /*!< [11]  */
        uint32_t FIRST_STORE_IRQ_EN : 1; /*!< [12]  */
        uint32_t DITHER_STORE_IRQ_EN : 1; /*!< [13]  */
        uint32_t WFE_A_STORE_IRQ_EN : 1; /*!< [14]  */
        uint32_t WFE_B_STORE_IRQ_EN : 1; /*!< [15]  */
        uint32_t RSVD1 : 15;           /*!< [30:16]  */
        uint32_t COMPRESS_DONE_IRQ_EN : 1; /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_irq_mask_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_IRQ_MASK register
 */
/*@{*/
#define HW_PXP_HW_PXP_IRQ_MASK_ADDR(x) ((uintptr_t)(x) + 0x390U)

#define HW_PXP_HW_PXP_IRQ_MASK(x) (*(__IO hw_pxp_hw_pxp_irq_mask_t *) HW_PXP_HW_PXP_IRQ_MASK_ADDR(x))
#define HW_PXP_HW_PXP_IRQ_MASK_RD(x) (HW_PXP_HW_PXP_IRQ_MASK(x).U)
#define HW_PXP_HW_PXP_IRQ_MASK_WR(x, v) (HW_PXP_HW_PXP_IRQ_MASK(x).U = (v))
#define HW_PXP_HW_PXP_IRQ_MASK_SET(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, HW_PXP_HW_PXP_IRQ_MASK_RD(x) |  (v)))
#define HW_PXP_HW_PXP_IRQ_MASK_CLR(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, HW_PXP_HW_PXP_IRQ_MASK_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_IRQ_MASK_TOG(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, HW_PXP_HW_PXP_IRQ_MASK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_IRQ_MASK bitfields
 */

/*!
 * @name Register PXP_HW_PXP_IRQ_MASK, field FIRST_CH0_PREFETCH_IRQ_EN[0] (RW)
 *
 * Enable First ch0 prefetch engine interrupt detection
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_PREFETCH_IRQ_EN (0U) /*!< Bit position for PXP_HW_PXP_IRQ_MASK_FIRST_CH0_PREFETCH_IRQ_EN. */
#define BM_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_PREFETCH_IRQ_EN (0x00000001U) /*!< Bit mask for PXP_HW_PXP_IRQ_MASK_FIRST_CH0_PREFETCH_IRQ_EN. */
#define BS_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_PREFETCH_IRQ_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_MASK_FIRST_CH0_PREFETCH_IRQ_EN. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_MASK_FIRST_CH0_PREFETCH_IRQ_EN field. */
#define BR_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_PREFETCH_IRQ_EN(x) (HW_PXP_HW_PXP_IRQ_MASK(x).B.FIRST_CH0_PREFETCH_IRQ_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_MASK_FIRST_CH0_PREFETCH_IRQ_EN. */
#define BF_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_PREFETCH_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_PREFETCH_IRQ_EN) & BM_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_PREFETCH_IRQ_EN)

/*! @brief Set the FIRST_CH0_PREFETCH_IRQ_EN field to a new value. */
#define BW_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_PREFETCH_IRQ_EN(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, (HW_PXP_HW_PXP_IRQ_MASK_RD(x) & ~BM_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_PREFETCH_IRQ_EN) | BF_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_PREFETCH_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ_MASK, field FIRST_CH1_PREFETCH_IRQ_EN[1] (RW)
 *
 * Enable First ch1 prefetch engine interrupt detection
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_PREFETCH_IRQ_EN (1U) /*!< Bit position for PXP_HW_PXP_IRQ_MASK_FIRST_CH1_PREFETCH_IRQ_EN. */
#define BM_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_PREFETCH_IRQ_EN (0x00000002U) /*!< Bit mask for PXP_HW_PXP_IRQ_MASK_FIRST_CH1_PREFETCH_IRQ_EN. */
#define BS_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_PREFETCH_IRQ_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_MASK_FIRST_CH1_PREFETCH_IRQ_EN. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_MASK_FIRST_CH1_PREFETCH_IRQ_EN field. */
#define BR_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_PREFETCH_IRQ_EN(x) (HW_PXP_HW_PXP_IRQ_MASK(x).B.FIRST_CH1_PREFETCH_IRQ_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_MASK_FIRST_CH1_PREFETCH_IRQ_EN. */
#define BF_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_PREFETCH_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_PREFETCH_IRQ_EN) & BM_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_PREFETCH_IRQ_EN)

/*! @brief Set the FIRST_CH1_PREFETCH_IRQ_EN field to a new value. */
#define BW_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_PREFETCH_IRQ_EN(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, (HW_PXP_HW_PXP_IRQ_MASK_RD(x) & ~BM_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_PREFETCH_IRQ_EN) | BF_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_PREFETCH_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ_MASK, field FIRST_CH0_STORE_IRQ_EN[2] (RW)
 *
 * Enable First ch0 store engine interrupt detection
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_STORE_IRQ_EN (2U) /*!< Bit position for PXP_HW_PXP_IRQ_MASK_FIRST_CH0_STORE_IRQ_EN. */
#define BM_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_STORE_IRQ_EN (0x00000004U) /*!< Bit mask for PXP_HW_PXP_IRQ_MASK_FIRST_CH0_STORE_IRQ_EN. */
#define BS_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_STORE_IRQ_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_MASK_FIRST_CH0_STORE_IRQ_EN. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_MASK_FIRST_CH0_STORE_IRQ_EN field. */
#define BR_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_STORE_IRQ_EN(x) (HW_PXP_HW_PXP_IRQ_MASK(x).B.FIRST_CH0_STORE_IRQ_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_MASK_FIRST_CH0_STORE_IRQ_EN. */
#define BF_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_STORE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_STORE_IRQ_EN) & BM_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_STORE_IRQ_EN)

/*! @brief Set the FIRST_CH0_STORE_IRQ_EN field to a new value. */
#define BW_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_STORE_IRQ_EN(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, (HW_PXP_HW_PXP_IRQ_MASK_RD(x) & ~BM_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_STORE_IRQ_EN) | BF_PXP_HW_PXP_IRQ_MASK_FIRST_CH0_STORE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ_MASK, field FIRST_CH1_STORE_IRQ_EN[3] (RW)
 *
 * Enable First ch1 store engine interrupt detection
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_STORE_IRQ_EN (3U) /*!< Bit position for PXP_HW_PXP_IRQ_MASK_FIRST_CH1_STORE_IRQ_EN. */
#define BM_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_STORE_IRQ_EN (0x00000008U) /*!< Bit mask for PXP_HW_PXP_IRQ_MASK_FIRST_CH1_STORE_IRQ_EN. */
#define BS_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_STORE_IRQ_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_MASK_FIRST_CH1_STORE_IRQ_EN. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_MASK_FIRST_CH1_STORE_IRQ_EN field. */
#define BR_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_STORE_IRQ_EN(x) (HW_PXP_HW_PXP_IRQ_MASK(x).B.FIRST_CH1_STORE_IRQ_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_MASK_FIRST_CH1_STORE_IRQ_EN. */
#define BF_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_STORE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_STORE_IRQ_EN) & BM_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_STORE_IRQ_EN)

/*! @brief Set the FIRST_CH1_STORE_IRQ_EN field to a new value. */
#define BW_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_STORE_IRQ_EN(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, (HW_PXP_HW_PXP_IRQ_MASK_RD(x) & ~BM_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_STORE_IRQ_EN) | BF_PXP_HW_PXP_IRQ_MASK_FIRST_CH1_STORE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ_MASK, field DITHER_CH0_PREFETCH_IRQ_EN[4] (RW)
 *
 * Enable Dither ch0 prefetch engine interrupt detection
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_PREFETCH_IRQ_EN (4U) /*!< Bit position for PXP_HW_PXP_IRQ_MASK_DITHER_CH0_PREFETCH_IRQ_EN. */
#define BM_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_PREFETCH_IRQ_EN (0x00000010U) /*!< Bit mask for PXP_HW_PXP_IRQ_MASK_DITHER_CH0_PREFETCH_IRQ_EN. */
#define BS_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_PREFETCH_IRQ_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_MASK_DITHER_CH0_PREFETCH_IRQ_EN. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_MASK_DITHER_CH0_PREFETCH_IRQ_EN field. */
#define BR_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_PREFETCH_IRQ_EN(x) (HW_PXP_HW_PXP_IRQ_MASK(x).B.DITHER_CH0_PREFETCH_IRQ_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_MASK_DITHER_CH0_PREFETCH_IRQ_EN. */
#define BF_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_PREFETCH_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_PREFETCH_IRQ_EN) & BM_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_PREFETCH_IRQ_EN)

/*! @brief Set the DITHER_CH0_PREFETCH_IRQ_EN field to a new value. */
#define BW_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_PREFETCH_IRQ_EN(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, (HW_PXP_HW_PXP_IRQ_MASK_RD(x) & ~BM_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_PREFETCH_IRQ_EN) | BF_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_PREFETCH_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ_MASK, field DITHER_CH1_PREFETCH_IRQ_EN[5] (RW)
 *
 * Enable Dither ch1 prefetch engine interrupt detection
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_PREFETCH_IRQ_EN (5U) /*!< Bit position for PXP_HW_PXP_IRQ_MASK_DITHER_CH1_PREFETCH_IRQ_EN. */
#define BM_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_PREFETCH_IRQ_EN (0x00000020U) /*!< Bit mask for PXP_HW_PXP_IRQ_MASK_DITHER_CH1_PREFETCH_IRQ_EN. */
#define BS_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_PREFETCH_IRQ_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_MASK_DITHER_CH1_PREFETCH_IRQ_EN. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_MASK_DITHER_CH1_PREFETCH_IRQ_EN field. */
#define BR_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_PREFETCH_IRQ_EN(x) (HW_PXP_HW_PXP_IRQ_MASK(x).B.DITHER_CH1_PREFETCH_IRQ_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_MASK_DITHER_CH1_PREFETCH_IRQ_EN. */
#define BF_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_PREFETCH_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_PREFETCH_IRQ_EN) & BM_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_PREFETCH_IRQ_EN)

/*! @brief Set the DITHER_CH1_PREFETCH_IRQ_EN field to a new value. */
#define BW_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_PREFETCH_IRQ_EN(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, (HW_PXP_HW_PXP_IRQ_MASK_RD(x) & ~BM_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_PREFETCH_IRQ_EN) | BF_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_PREFETCH_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ_MASK, field DITHER_CH0_STORE_IRQ_EN[6] (RW)
 *
 * Enable dither ch0 store engine interrupt detection.
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_STORE_IRQ_EN (6U) /*!< Bit position for PXP_HW_PXP_IRQ_MASK_DITHER_CH0_STORE_IRQ_EN. */
#define BM_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_STORE_IRQ_EN (0x00000040U) /*!< Bit mask for PXP_HW_PXP_IRQ_MASK_DITHER_CH0_STORE_IRQ_EN. */
#define BS_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_STORE_IRQ_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_MASK_DITHER_CH0_STORE_IRQ_EN. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_MASK_DITHER_CH0_STORE_IRQ_EN field. */
#define BR_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_STORE_IRQ_EN(x) (HW_PXP_HW_PXP_IRQ_MASK(x).B.DITHER_CH0_STORE_IRQ_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_MASK_DITHER_CH0_STORE_IRQ_EN. */
#define BF_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_STORE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_STORE_IRQ_EN) & BM_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_STORE_IRQ_EN)

/*! @brief Set the DITHER_CH0_STORE_IRQ_EN field to a new value. */
#define BW_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_STORE_IRQ_EN(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, (HW_PXP_HW_PXP_IRQ_MASK_RD(x) & ~BM_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_STORE_IRQ_EN) | BF_PXP_HW_PXP_IRQ_MASK_DITHER_CH0_STORE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ_MASK, field DITHER_CH1_STORE_IRQ_EN[7] (RW)
 *
 * Enable dither ch1 store engine interrupt detection.
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_STORE_IRQ_EN (7U) /*!< Bit position for PXP_HW_PXP_IRQ_MASK_DITHER_CH1_STORE_IRQ_EN. */
#define BM_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_STORE_IRQ_EN (0x00000080U) /*!< Bit mask for PXP_HW_PXP_IRQ_MASK_DITHER_CH1_STORE_IRQ_EN. */
#define BS_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_STORE_IRQ_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_MASK_DITHER_CH1_STORE_IRQ_EN. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_MASK_DITHER_CH1_STORE_IRQ_EN field. */
#define BR_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_STORE_IRQ_EN(x) (HW_PXP_HW_PXP_IRQ_MASK(x).B.DITHER_CH1_STORE_IRQ_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_MASK_DITHER_CH1_STORE_IRQ_EN. */
#define BF_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_STORE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_STORE_IRQ_EN) & BM_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_STORE_IRQ_EN)

/*! @brief Set the DITHER_CH1_STORE_IRQ_EN field to a new value. */
#define BW_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_STORE_IRQ_EN(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, (HW_PXP_HW_PXP_IRQ_MASK_RD(x) & ~BM_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_STORE_IRQ_EN) | BF_PXP_HW_PXP_IRQ_MASK_DITHER_CH1_STORE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ_MASK, field WFE_A_CH0_STORE_IRQ_EN[8] (RW)
 *
 * Enable WFE A ch0 store engine interrupt detection.
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_MASK_WFE_A_CH0_STORE_IRQ_EN (8U) /*!< Bit position for PXP_HW_PXP_IRQ_MASK_WFE_A_CH0_STORE_IRQ_EN. */
#define BM_PXP_HW_PXP_IRQ_MASK_WFE_A_CH0_STORE_IRQ_EN (0x00000100U) /*!< Bit mask for PXP_HW_PXP_IRQ_MASK_WFE_A_CH0_STORE_IRQ_EN. */
#define BS_PXP_HW_PXP_IRQ_MASK_WFE_A_CH0_STORE_IRQ_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_MASK_WFE_A_CH0_STORE_IRQ_EN. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_MASK_WFE_A_CH0_STORE_IRQ_EN field. */
#define BR_PXP_HW_PXP_IRQ_MASK_WFE_A_CH0_STORE_IRQ_EN(x) (HW_PXP_HW_PXP_IRQ_MASK(x).B.WFE_A_CH0_STORE_IRQ_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_MASK_WFE_A_CH0_STORE_IRQ_EN. */
#define BF_PXP_HW_PXP_IRQ_MASK_WFE_A_CH0_STORE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_MASK_WFE_A_CH0_STORE_IRQ_EN) & BM_PXP_HW_PXP_IRQ_MASK_WFE_A_CH0_STORE_IRQ_EN)

/*! @brief Set the WFE_A_CH0_STORE_IRQ_EN field to a new value. */
#define BW_PXP_HW_PXP_IRQ_MASK_WFE_A_CH0_STORE_IRQ_EN(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, (HW_PXP_HW_PXP_IRQ_MASK_RD(x) & ~BM_PXP_HW_PXP_IRQ_MASK_WFE_A_CH0_STORE_IRQ_EN) | BF_PXP_HW_PXP_IRQ_MASK_WFE_A_CH0_STORE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ_MASK, field WFE_A_CH1_STORE_IRQ_EN[9] (RW)
 *
 * Enable WFE A ch1 store engine interrupt detection.
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_MASK_WFE_A_CH1_STORE_IRQ_EN (9U) /*!< Bit position for PXP_HW_PXP_IRQ_MASK_WFE_A_CH1_STORE_IRQ_EN. */
#define BM_PXP_HW_PXP_IRQ_MASK_WFE_A_CH1_STORE_IRQ_EN (0x00000200U) /*!< Bit mask for PXP_HW_PXP_IRQ_MASK_WFE_A_CH1_STORE_IRQ_EN. */
#define BS_PXP_HW_PXP_IRQ_MASK_WFE_A_CH1_STORE_IRQ_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_MASK_WFE_A_CH1_STORE_IRQ_EN. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_MASK_WFE_A_CH1_STORE_IRQ_EN field. */
#define BR_PXP_HW_PXP_IRQ_MASK_WFE_A_CH1_STORE_IRQ_EN(x) (HW_PXP_HW_PXP_IRQ_MASK(x).B.WFE_A_CH1_STORE_IRQ_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_MASK_WFE_A_CH1_STORE_IRQ_EN. */
#define BF_PXP_HW_PXP_IRQ_MASK_WFE_A_CH1_STORE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_MASK_WFE_A_CH1_STORE_IRQ_EN) & BM_PXP_HW_PXP_IRQ_MASK_WFE_A_CH1_STORE_IRQ_EN)

/*! @brief Set the WFE_A_CH1_STORE_IRQ_EN field to a new value. */
#define BW_PXP_HW_PXP_IRQ_MASK_WFE_A_CH1_STORE_IRQ_EN(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, (HW_PXP_HW_PXP_IRQ_MASK_RD(x) & ~BM_PXP_HW_PXP_IRQ_MASK_WFE_A_CH1_STORE_IRQ_EN) | BF_PXP_HW_PXP_IRQ_MASK_WFE_A_CH1_STORE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ_MASK, field WFE_B_CH0_STORE_IRQ_EN[10] (RW)
 *
 * Enable WFE B ch0 store engine interrupt detection.
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_MASK_WFE_B_CH0_STORE_IRQ_EN (10U) /*!< Bit position for PXP_HW_PXP_IRQ_MASK_WFE_B_CH0_STORE_IRQ_EN. */
#define BM_PXP_HW_PXP_IRQ_MASK_WFE_B_CH0_STORE_IRQ_EN (0x00000400U) /*!< Bit mask for PXP_HW_PXP_IRQ_MASK_WFE_B_CH0_STORE_IRQ_EN. */
#define BS_PXP_HW_PXP_IRQ_MASK_WFE_B_CH0_STORE_IRQ_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_MASK_WFE_B_CH0_STORE_IRQ_EN. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_MASK_WFE_B_CH0_STORE_IRQ_EN field. */
#define BR_PXP_HW_PXP_IRQ_MASK_WFE_B_CH0_STORE_IRQ_EN(x) (HW_PXP_HW_PXP_IRQ_MASK(x).B.WFE_B_CH0_STORE_IRQ_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_MASK_WFE_B_CH0_STORE_IRQ_EN. */
#define BF_PXP_HW_PXP_IRQ_MASK_WFE_B_CH0_STORE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_MASK_WFE_B_CH0_STORE_IRQ_EN) & BM_PXP_HW_PXP_IRQ_MASK_WFE_B_CH0_STORE_IRQ_EN)

/*! @brief Set the WFE_B_CH0_STORE_IRQ_EN field to a new value. */
#define BW_PXP_HW_PXP_IRQ_MASK_WFE_B_CH0_STORE_IRQ_EN(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, (HW_PXP_HW_PXP_IRQ_MASK_RD(x) & ~BM_PXP_HW_PXP_IRQ_MASK_WFE_B_CH0_STORE_IRQ_EN) | BF_PXP_HW_PXP_IRQ_MASK_WFE_B_CH0_STORE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ_MASK, field WFE_B_CH1_STORE_IRQ_EN[11] (RW)
 *
 * Enable WFE B ch1 store engine interrupt detection.
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_MASK_WFE_B_CH1_STORE_IRQ_EN (11U) /*!< Bit position for PXP_HW_PXP_IRQ_MASK_WFE_B_CH1_STORE_IRQ_EN. */
#define BM_PXP_HW_PXP_IRQ_MASK_WFE_B_CH1_STORE_IRQ_EN (0x00000800U) /*!< Bit mask for PXP_HW_PXP_IRQ_MASK_WFE_B_CH1_STORE_IRQ_EN. */
#define BS_PXP_HW_PXP_IRQ_MASK_WFE_B_CH1_STORE_IRQ_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_MASK_WFE_B_CH1_STORE_IRQ_EN. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_MASK_WFE_B_CH1_STORE_IRQ_EN field. */
#define BR_PXP_HW_PXP_IRQ_MASK_WFE_B_CH1_STORE_IRQ_EN(x) (HW_PXP_HW_PXP_IRQ_MASK(x).B.WFE_B_CH1_STORE_IRQ_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_MASK_WFE_B_CH1_STORE_IRQ_EN. */
#define BF_PXP_HW_PXP_IRQ_MASK_WFE_B_CH1_STORE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_MASK_WFE_B_CH1_STORE_IRQ_EN) & BM_PXP_HW_PXP_IRQ_MASK_WFE_B_CH1_STORE_IRQ_EN)

/*! @brief Set the WFE_B_CH1_STORE_IRQ_EN field to a new value. */
#define BW_PXP_HW_PXP_IRQ_MASK_WFE_B_CH1_STORE_IRQ_EN(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, (HW_PXP_HW_PXP_IRQ_MASK_RD(x) & ~BM_PXP_HW_PXP_IRQ_MASK_WFE_B_CH1_STORE_IRQ_EN) | BF_PXP_HW_PXP_IRQ_MASK_WFE_B_CH1_STORE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ_MASK, field FIRST_STORE_IRQ_EN[12] (RW)
 *
 * Enable First store engine interrupt detection
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_MASK_FIRST_STORE_IRQ_EN (12U) /*!< Bit position for PXP_HW_PXP_IRQ_MASK_FIRST_STORE_IRQ_EN. */
#define BM_PXP_HW_PXP_IRQ_MASK_FIRST_STORE_IRQ_EN (0x00001000U) /*!< Bit mask for PXP_HW_PXP_IRQ_MASK_FIRST_STORE_IRQ_EN. */
#define BS_PXP_HW_PXP_IRQ_MASK_FIRST_STORE_IRQ_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_MASK_FIRST_STORE_IRQ_EN. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_MASK_FIRST_STORE_IRQ_EN field. */
#define BR_PXP_HW_PXP_IRQ_MASK_FIRST_STORE_IRQ_EN(x) (HW_PXP_HW_PXP_IRQ_MASK(x).B.FIRST_STORE_IRQ_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_MASK_FIRST_STORE_IRQ_EN. */
#define BF_PXP_HW_PXP_IRQ_MASK_FIRST_STORE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_MASK_FIRST_STORE_IRQ_EN) & BM_PXP_HW_PXP_IRQ_MASK_FIRST_STORE_IRQ_EN)

/*! @brief Set the FIRST_STORE_IRQ_EN field to a new value. */
#define BW_PXP_HW_PXP_IRQ_MASK_FIRST_STORE_IRQ_EN(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, (HW_PXP_HW_PXP_IRQ_MASK_RD(x) & ~BM_PXP_HW_PXP_IRQ_MASK_FIRST_STORE_IRQ_EN) | BF_PXP_HW_PXP_IRQ_MASK_FIRST_STORE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ_MASK, field DITHER_STORE_IRQ_EN[13] (RW)
 *
 * Enable dither store engine interrupt detection.
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_MASK_DITHER_STORE_IRQ_EN (13U) /*!< Bit position for PXP_HW_PXP_IRQ_MASK_DITHER_STORE_IRQ_EN. */
#define BM_PXP_HW_PXP_IRQ_MASK_DITHER_STORE_IRQ_EN (0x00002000U) /*!< Bit mask for PXP_HW_PXP_IRQ_MASK_DITHER_STORE_IRQ_EN. */
#define BS_PXP_HW_PXP_IRQ_MASK_DITHER_STORE_IRQ_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_MASK_DITHER_STORE_IRQ_EN. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_MASK_DITHER_STORE_IRQ_EN field. */
#define BR_PXP_HW_PXP_IRQ_MASK_DITHER_STORE_IRQ_EN(x) (HW_PXP_HW_PXP_IRQ_MASK(x).B.DITHER_STORE_IRQ_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_MASK_DITHER_STORE_IRQ_EN. */
#define BF_PXP_HW_PXP_IRQ_MASK_DITHER_STORE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_MASK_DITHER_STORE_IRQ_EN) & BM_PXP_HW_PXP_IRQ_MASK_DITHER_STORE_IRQ_EN)

/*! @brief Set the DITHER_STORE_IRQ_EN field to a new value. */
#define BW_PXP_HW_PXP_IRQ_MASK_DITHER_STORE_IRQ_EN(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, (HW_PXP_HW_PXP_IRQ_MASK_RD(x) & ~BM_PXP_HW_PXP_IRQ_MASK_DITHER_STORE_IRQ_EN) | BF_PXP_HW_PXP_IRQ_MASK_DITHER_STORE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ_MASK, field WFE_A_STORE_IRQ_EN[14] (RW)
 *
 * Enable WFE A store engine interrupt detection.
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_MASK_WFE_A_STORE_IRQ_EN (14U) /*!< Bit position for PXP_HW_PXP_IRQ_MASK_WFE_A_STORE_IRQ_EN. */
#define BM_PXP_HW_PXP_IRQ_MASK_WFE_A_STORE_IRQ_EN (0x00004000U) /*!< Bit mask for PXP_HW_PXP_IRQ_MASK_WFE_A_STORE_IRQ_EN. */
#define BS_PXP_HW_PXP_IRQ_MASK_WFE_A_STORE_IRQ_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_MASK_WFE_A_STORE_IRQ_EN. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_MASK_WFE_A_STORE_IRQ_EN field. */
#define BR_PXP_HW_PXP_IRQ_MASK_WFE_A_STORE_IRQ_EN(x) (HW_PXP_HW_PXP_IRQ_MASK(x).B.WFE_A_STORE_IRQ_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_MASK_WFE_A_STORE_IRQ_EN. */
#define BF_PXP_HW_PXP_IRQ_MASK_WFE_A_STORE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_MASK_WFE_A_STORE_IRQ_EN) & BM_PXP_HW_PXP_IRQ_MASK_WFE_A_STORE_IRQ_EN)

/*! @brief Set the WFE_A_STORE_IRQ_EN field to a new value. */
#define BW_PXP_HW_PXP_IRQ_MASK_WFE_A_STORE_IRQ_EN(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, (HW_PXP_HW_PXP_IRQ_MASK_RD(x) & ~BM_PXP_HW_PXP_IRQ_MASK_WFE_A_STORE_IRQ_EN) | BF_PXP_HW_PXP_IRQ_MASK_WFE_A_STORE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ_MASK, field WFE_B_STORE_IRQ_EN[15] (RW)
 *
 * Enable WFE B store engine interrupt detection.
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_MASK_WFE_B_STORE_IRQ_EN (15U) /*!< Bit position for PXP_HW_PXP_IRQ_MASK_WFE_B_STORE_IRQ_EN. */
#define BM_PXP_HW_PXP_IRQ_MASK_WFE_B_STORE_IRQ_EN (0x00008000U) /*!< Bit mask for PXP_HW_PXP_IRQ_MASK_WFE_B_STORE_IRQ_EN. */
#define BS_PXP_HW_PXP_IRQ_MASK_WFE_B_STORE_IRQ_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_MASK_WFE_B_STORE_IRQ_EN. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_MASK_WFE_B_STORE_IRQ_EN field. */
#define BR_PXP_HW_PXP_IRQ_MASK_WFE_B_STORE_IRQ_EN(x) (HW_PXP_HW_PXP_IRQ_MASK(x).B.WFE_B_STORE_IRQ_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_MASK_WFE_B_STORE_IRQ_EN. */
#define BF_PXP_HW_PXP_IRQ_MASK_WFE_B_STORE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_MASK_WFE_B_STORE_IRQ_EN) & BM_PXP_HW_PXP_IRQ_MASK_WFE_B_STORE_IRQ_EN)

/*! @brief Set the WFE_B_STORE_IRQ_EN field to a new value. */
#define BW_PXP_HW_PXP_IRQ_MASK_WFE_B_STORE_IRQ_EN(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, (HW_PXP_HW_PXP_IRQ_MASK_RD(x) & ~BM_PXP_HW_PXP_IRQ_MASK_WFE_B_STORE_IRQ_EN) | BF_PXP_HW_PXP_IRQ_MASK_WFE_B_STORE_IRQ_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ_MASK, field RSVD1[30:16] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_MASK_RSVD1 (16U) /*!< Bit position for PXP_HW_PXP_IRQ_MASK_RSVD1. */
#define BM_PXP_HW_PXP_IRQ_MASK_RSVD1 (0x7FFF0000U) /*!< Bit mask for PXP_HW_PXP_IRQ_MASK_RSVD1. */
#define BS_PXP_HW_PXP_IRQ_MASK_RSVD1 (15U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_MASK_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_MASK_RSVD1 field. */
#define BR_PXP_HW_PXP_IRQ_MASK_RSVD1(x) (HW_PXP_HW_PXP_IRQ_MASK(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ_MASK, field COMPRESS_DONE_IRQ_EN[31] (RW)
 *
 * Enable compression done interrupt detection.
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_MASK_COMPRESS_DONE_IRQ_EN (31U) /*!< Bit position for PXP_HW_PXP_IRQ_MASK_COMPRESS_DONE_IRQ_EN. */
#define BM_PXP_HW_PXP_IRQ_MASK_COMPRESS_DONE_IRQ_EN (0x80000000U) /*!< Bit mask for PXP_HW_PXP_IRQ_MASK_COMPRESS_DONE_IRQ_EN. */
#define BS_PXP_HW_PXP_IRQ_MASK_COMPRESS_DONE_IRQ_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_MASK_COMPRESS_DONE_IRQ_EN. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_MASK_COMPRESS_DONE_IRQ_EN field. */
#define BR_PXP_HW_PXP_IRQ_MASK_COMPRESS_DONE_IRQ_EN(x) (HW_PXP_HW_PXP_IRQ_MASK(x).B.COMPRESS_DONE_IRQ_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_MASK_COMPRESS_DONE_IRQ_EN. */
#define BF_PXP_HW_PXP_IRQ_MASK_COMPRESS_DONE_IRQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_MASK_COMPRESS_DONE_IRQ_EN) & BM_PXP_HW_PXP_IRQ_MASK_COMPRESS_DONE_IRQ_EN)

/*! @brief Set the COMPRESS_DONE_IRQ_EN field to a new value. */
#define BW_PXP_HW_PXP_IRQ_MASK_COMPRESS_DONE_IRQ_EN(x, v) (HW_PXP_HW_PXP_IRQ_MASK_WR(x, (HW_PXP_HW_PXP_IRQ_MASK_RD(x) & ~BM_PXP_HW_PXP_IRQ_MASK_COMPRESS_DONE_IRQ_EN) | BF_PXP_HW_PXP_IRQ_MASK_COMPRESS_DONE_IRQ_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_IRQ - PXP Interrupt Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_IRQ - PXP Interrupt Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * PXP Fetch and Store engine IRQs. Each interrupt has a corresponding mask
 * register in HW_EPDC_IRQ_MASK HW_PXP_IRQ: 0x3A0 HW_PXP_IRQ_SET: 0x3A4
 * HW_PXP_IRQ_CLR: 0x3a8 HW_PXP_IRQ_TOG: 0x3AC This register houses the interrupt bits for the
 * Prefetch and Store Engines EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_irq
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_irq_bitfields
    {
        uint32_t FIRST_CH0_PREFETCH_IRQ : 1; /*!< [0]  */
        uint32_t FIRST_CH1_PREFETCH_IRQ : 1; /*!< [1]  */
        uint32_t FIRST_CH0_STORE_IRQ : 1; /*!< [2]  */
        uint32_t FIRST_CH1_STORE_IRQ : 1; /*!< [3]  */
        uint32_t DITHER_CH0_PREFETCH_IRQ : 1; /*!< [4]  */
        uint32_t DITHER_CH1_PREFETCH_IRQ : 1; /*!< [5]  */
        uint32_t DITHER_CH0_STORE_IRQ : 1; /*!< [6]  */
        uint32_t DITHER_CH1_STORE_IRQ : 1; /*!< [7]  */
        uint32_t WFE_A_CH0_STORE_IRQ : 1; /*!< [8]  */
        uint32_t WFE_A_CH1_STORE_IRQ : 1; /*!< [9]  */
        uint32_t WFE_B_CH0_STORE_IRQ : 1; /*!< [10]  */
        uint32_t WFE_B_CH1_STORE_IRQ : 1; /*!< [11]  */
        uint32_t FIRST_STORE_IRQ : 1;  /*!< [12]  */
        uint32_t DITHER_STORE_IRQ : 1; /*!< [13]  */
        uint32_t WFE_A_STORE_IRQ : 1;  /*!< [14]  */
        uint32_t WFE_B_STORE_IRQ : 1;  /*!< [15]  */
        uint32_t RSVD1 : 15;           /*!< [30:16]  */
        uint32_t COMPRESS_DONE_IRQ : 1; /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_irq_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_IRQ register
 */
/*@{*/
#define HW_PXP_HW_PXP_IRQ_ADDR(x) ((uintptr_t)(x) + 0x3A0U)

#define HW_PXP_HW_PXP_IRQ(x)     (*(__IO hw_pxp_hw_pxp_irq_t *) HW_PXP_HW_PXP_IRQ_ADDR(x))
#define HW_PXP_HW_PXP_IRQ_RD(x)  (HW_PXP_HW_PXP_IRQ(x).U)
#define HW_PXP_HW_PXP_IRQ_WR(x, v) (HW_PXP_HW_PXP_IRQ(x).U = (v))
#define HW_PXP_HW_PXP_IRQ_SET(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, HW_PXP_HW_PXP_IRQ_RD(x) |  (v)))
#define HW_PXP_HW_PXP_IRQ_CLR(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, HW_PXP_HW_PXP_IRQ_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_IRQ_TOG(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, HW_PXP_HW_PXP_IRQ_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_IRQ bitfields
 */

/*!
 * @name Register PXP_HW_PXP_IRQ, field FIRST_CH0_PREFETCH_IRQ[0] (RW)
 *
 * Initial ch0 prefetch engine interrupt
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_FIRST_CH0_PREFETCH_IRQ (0U) /*!< Bit position for PXP_HW_PXP_IRQ_FIRST_CH0_PREFETCH_IRQ. */
#define BM_PXP_HW_PXP_IRQ_FIRST_CH0_PREFETCH_IRQ (0x00000001U) /*!< Bit mask for PXP_HW_PXP_IRQ_FIRST_CH0_PREFETCH_IRQ. */
#define BS_PXP_HW_PXP_IRQ_FIRST_CH0_PREFETCH_IRQ (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_FIRST_CH0_PREFETCH_IRQ. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_FIRST_CH0_PREFETCH_IRQ field. */
#define BR_PXP_HW_PXP_IRQ_FIRST_CH0_PREFETCH_IRQ(x) (HW_PXP_HW_PXP_IRQ(x).B.FIRST_CH0_PREFETCH_IRQ)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_FIRST_CH0_PREFETCH_IRQ. */
#define BF_PXP_HW_PXP_IRQ_FIRST_CH0_PREFETCH_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_FIRST_CH0_PREFETCH_IRQ) & BM_PXP_HW_PXP_IRQ_FIRST_CH0_PREFETCH_IRQ)

/*! @brief Set the FIRST_CH0_PREFETCH_IRQ field to a new value. */
#define BW_PXP_HW_PXP_IRQ_FIRST_CH0_PREFETCH_IRQ(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, (HW_PXP_HW_PXP_IRQ_RD(x) & ~BM_PXP_HW_PXP_IRQ_FIRST_CH0_PREFETCH_IRQ) | BF_PXP_HW_PXP_IRQ_FIRST_CH0_PREFETCH_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ, field FIRST_CH1_PREFETCH_IRQ[1] (RW)
 *
 * Initial ch1 prefetch engine interrupt
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_FIRST_CH1_PREFETCH_IRQ (1U) /*!< Bit position for PXP_HW_PXP_IRQ_FIRST_CH1_PREFETCH_IRQ. */
#define BM_PXP_HW_PXP_IRQ_FIRST_CH1_PREFETCH_IRQ (0x00000002U) /*!< Bit mask for PXP_HW_PXP_IRQ_FIRST_CH1_PREFETCH_IRQ. */
#define BS_PXP_HW_PXP_IRQ_FIRST_CH1_PREFETCH_IRQ (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_FIRST_CH1_PREFETCH_IRQ. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_FIRST_CH1_PREFETCH_IRQ field. */
#define BR_PXP_HW_PXP_IRQ_FIRST_CH1_PREFETCH_IRQ(x) (HW_PXP_HW_PXP_IRQ(x).B.FIRST_CH1_PREFETCH_IRQ)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_FIRST_CH1_PREFETCH_IRQ. */
#define BF_PXP_HW_PXP_IRQ_FIRST_CH1_PREFETCH_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_FIRST_CH1_PREFETCH_IRQ) & BM_PXP_HW_PXP_IRQ_FIRST_CH1_PREFETCH_IRQ)

/*! @brief Set the FIRST_CH1_PREFETCH_IRQ field to a new value. */
#define BW_PXP_HW_PXP_IRQ_FIRST_CH1_PREFETCH_IRQ(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, (HW_PXP_HW_PXP_IRQ_RD(x) & ~BM_PXP_HW_PXP_IRQ_FIRST_CH1_PREFETCH_IRQ) | BF_PXP_HW_PXP_IRQ_FIRST_CH1_PREFETCH_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ, field FIRST_CH0_STORE_IRQ[2] (RW)
 *
 * Initial ch0 store engine interrupt
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_FIRST_CH0_STORE_IRQ (2U) /*!< Bit position for PXP_HW_PXP_IRQ_FIRST_CH0_STORE_IRQ. */
#define BM_PXP_HW_PXP_IRQ_FIRST_CH0_STORE_IRQ (0x00000004U) /*!< Bit mask for PXP_HW_PXP_IRQ_FIRST_CH0_STORE_IRQ. */
#define BS_PXP_HW_PXP_IRQ_FIRST_CH0_STORE_IRQ (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_FIRST_CH0_STORE_IRQ. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_FIRST_CH0_STORE_IRQ field. */
#define BR_PXP_HW_PXP_IRQ_FIRST_CH0_STORE_IRQ(x) (HW_PXP_HW_PXP_IRQ(x).B.FIRST_CH0_STORE_IRQ)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_FIRST_CH0_STORE_IRQ. */
#define BF_PXP_HW_PXP_IRQ_FIRST_CH0_STORE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_FIRST_CH0_STORE_IRQ) & BM_PXP_HW_PXP_IRQ_FIRST_CH0_STORE_IRQ)

/*! @brief Set the FIRST_CH0_STORE_IRQ field to a new value. */
#define BW_PXP_HW_PXP_IRQ_FIRST_CH0_STORE_IRQ(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, (HW_PXP_HW_PXP_IRQ_RD(x) & ~BM_PXP_HW_PXP_IRQ_FIRST_CH0_STORE_IRQ) | BF_PXP_HW_PXP_IRQ_FIRST_CH0_STORE_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ, field FIRST_CH1_STORE_IRQ[3] (RW)
 *
 * Initial ch1 store engine interrupt
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_FIRST_CH1_STORE_IRQ (3U) /*!< Bit position for PXP_HW_PXP_IRQ_FIRST_CH1_STORE_IRQ. */
#define BM_PXP_HW_PXP_IRQ_FIRST_CH1_STORE_IRQ (0x00000008U) /*!< Bit mask for PXP_HW_PXP_IRQ_FIRST_CH1_STORE_IRQ. */
#define BS_PXP_HW_PXP_IRQ_FIRST_CH1_STORE_IRQ (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_FIRST_CH1_STORE_IRQ. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_FIRST_CH1_STORE_IRQ field. */
#define BR_PXP_HW_PXP_IRQ_FIRST_CH1_STORE_IRQ(x) (HW_PXP_HW_PXP_IRQ(x).B.FIRST_CH1_STORE_IRQ)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_FIRST_CH1_STORE_IRQ. */
#define BF_PXP_HW_PXP_IRQ_FIRST_CH1_STORE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_FIRST_CH1_STORE_IRQ) & BM_PXP_HW_PXP_IRQ_FIRST_CH1_STORE_IRQ)

/*! @brief Set the FIRST_CH1_STORE_IRQ field to a new value. */
#define BW_PXP_HW_PXP_IRQ_FIRST_CH1_STORE_IRQ(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, (HW_PXP_HW_PXP_IRQ_RD(x) & ~BM_PXP_HW_PXP_IRQ_FIRST_CH1_STORE_IRQ) | BF_PXP_HW_PXP_IRQ_FIRST_CH1_STORE_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ, field DITHER_CH0_PREFETCH_IRQ[4] (RW)
 *
 * Dither ch0 prefetch engine interrupt
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_DITHER_CH0_PREFETCH_IRQ (4U) /*!< Bit position for PXP_HW_PXP_IRQ_DITHER_CH0_PREFETCH_IRQ. */
#define BM_PXP_HW_PXP_IRQ_DITHER_CH0_PREFETCH_IRQ (0x00000010U) /*!< Bit mask for PXP_HW_PXP_IRQ_DITHER_CH0_PREFETCH_IRQ. */
#define BS_PXP_HW_PXP_IRQ_DITHER_CH0_PREFETCH_IRQ (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_DITHER_CH0_PREFETCH_IRQ. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_DITHER_CH0_PREFETCH_IRQ field. */
#define BR_PXP_HW_PXP_IRQ_DITHER_CH0_PREFETCH_IRQ(x) (HW_PXP_HW_PXP_IRQ(x).B.DITHER_CH0_PREFETCH_IRQ)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_DITHER_CH0_PREFETCH_IRQ. */
#define BF_PXP_HW_PXP_IRQ_DITHER_CH0_PREFETCH_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_DITHER_CH0_PREFETCH_IRQ) & BM_PXP_HW_PXP_IRQ_DITHER_CH0_PREFETCH_IRQ)

/*! @brief Set the DITHER_CH0_PREFETCH_IRQ field to a new value. */
#define BW_PXP_HW_PXP_IRQ_DITHER_CH0_PREFETCH_IRQ(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, (HW_PXP_HW_PXP_IRQ_RD(x) & ~BM_PXP_HW_PXP_IRQ_DITHER_CH0_PREFETCH_IRQ) | BF_PXP_HW_PXP_IRQ_DITHER_CH0_PREFETCH_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ, field DITHER_CH1_PREFETCH_IRQ[5] (RW)
 *
 * Dither ch1 prefetch engine interrupt
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_DITHER_CH1_PREFETCH_IRQ (5U) /*!< Bit position for PXP_HW_PXP_IRQ_DITHER_CH1_PREFETCH_IRQ. */
#define BM_PXP_HW_PXP_IRQ_DITHER_CH1_PREFETCH_IRQ (0x00000020U) /*!< Bit mask for PXP_HW_PXP_IRQ_DITHER_CH1_PREFETCH_IRQ. */
#define BS_PXP_HW_PXP_IRQ_DITHER_CH1_PREFETCH_IRQ (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_DITHER_CH1_PREFETCH_IRQ. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_DITHER_CH1_PREFETCH_IRQ field. */
#define BR_PXP_HW_PXP_IRQ_DITHER_CH1_PREFETCH_IRQ(x) (HW_PXP_HW_PXP_IRQ(x).B.DITHER_CH1_PREFETCH_IRQ)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_DITHER_CH1_PREFETCH_IRQ. */
#define BF_PXP_HW_PXP_IRQ_DITHER_CH1_PREFETCH_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_DITHER_CH1_PREFETCH_IRQ) & BM_PXP_HW_PXP_IRQ_DITHER_CH1_PREFETCH_IRQ)

/*! @brief Set the DITHER_CH1_PREFETCH_IRQ field to a new value. */
#define BW_PXP_HW_PXP_IRQ_DITHER_CH1_PREFETCH_IRQ(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, (HW_PXP_HW_PXP_IRQ_RD(x) & ~BM_PXP_HW_PXP_IRQ_DITHER_CH1_PREFETCH_IRQ) | BF_PXP_HW_PXP_IRQ_DITHER_CH1_PREFETCH_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ, field DITHER_CH0_STORE_IRQ[6] (RW)
 *
 * Dither ch0 store engine Interrupt
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_DITHER_CH0_STORE_IRQ (6U) /*!< Bit position for PXP_HW_PXP_IRQ_DITHER_CH0_STORE_IRQ. */
#define BM_PXP_HW_PXP_IRQ_DITHER_CH0_STORE_IRQ (0x00000040U) /*!< Bit mask for PXP_HW_PXP_IRQ_DITHER_CH0_STORE_IRQ. */
#define BS_PXP_HW_PXP_IRQ_DITHER_CH0_STORE_IRQ (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_DITHER_CH0_STORE_IRQ. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_DITHER_CH0_STORE_IRQ field. */
#define BR_PXP_HW_PXP_IRQ_DITHER_CH0_STORE_IRQ(x) (HW_PXP_HW_PXP_IRQ(x).B.DITHER_CH0_STORE_IRQ)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_DITHER_CH0_STORE_IRQ. */
#define BF_PXP_HW_PXP_IRQ_DITHER_CH0_STORE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_DITHER_CH0_STORE_IRQ) & BM_PXP_HW_PXP_IRQ_DITHER_CH0_STORE_IRQ)

/*! @brief Set the DITHER_CH0_STORE_IRQ field to a new value. */
#define BW_PXP_HW_PXP_IRQ_DITHER_CH0_STORE_IRQ(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, (HW_PXP_HW_PXP_IRQ_RD(x) & ~BM_PXP_HW_PXP_IRQ_DITHER_CH0_STORE_IRQ) | BF_PXP_HW_PXP_IRQ_DITHER_CH0_STORE_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ, field DITHER_CH1_STORE_IRQ[7] (RW)
 *
 * Dither ch1 store engine Interrupt
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_DITHER_CH1_STORE_IRQ (7U) /*!< Bit position for PXP_HW_PXP_IRQ_DITHER_CH1_STORE_IRQ. */
#define BM_PXP_HW_PXP_IRQ_DITHER_CH1_STORE_IRQ (0x00000080U) /*!< Bit mask for PXP_HW_PXP_IRQ_DITHER_CH1_STORE_IRQ. */
#define BS_PXP_HW_PXP_IRQ_DITHER_CH1_STORE_IRQ (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_DITHER_CH1_STORE_IRQ. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_DITHER_CH1_STORE_IRQ field. */
#define BR_PXP_HW_PXP_IRQ_DITHER_CH1_STORE_IRQ(x) (HW_PXP_HW_PXP_IRQ(x).B.DITHER_CH1_STORE_IRQ)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_DITHER_CH1_STORE_IRQ. */
#define BF_PXP_HW_PXP_IRQ_DITHER_CH1_STORE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_DITHER_CH1_STORE_IRQ) & BM_PXP_HW_PXP_IRQ_DITHER_CH1_STORE_IRQ)

/*! @brief Set the DITHER_CH1_STORE_IRQ field to a new value. */
#define BW_PXP_HW_PXP_IRQ_DITHER_CH1_STORE_IRQ(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, (HW_PXP_HW_PXP_IRQ_RD(x) & ~BM_PXP_HW_PXP_IRQ_DITHER_CH1_STORE_IRQ) | BF_PXP_HW_PXP_IRQ_DITHER_CH1_STORE_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ, field WFE_A_CH0_STORE_IRQ[8] (RW)
 *
 * WFE A ch0 store engine Interrupt.
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_WFE_A_CH0_STORE_IRQ (8U) /*!< Bit position for PXP_HW_PXP_IRQ_WFE_A_CH0_STORE_IRQ. */
#define BM_PXP_HW_PXP_IRQ_WFE_A_CH0_STORE_IRQ (0x00000100U) /*!< Bit mask for PXP_HW_PXP_IRQ_WFE_A_CH0_STORE_IRQ. */
#define BS_PXP_HW_PXP_IRQ_WFE_A_CH0_STORE_IRQ (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_WFE_A_CH0_STORE_IRQ. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_WFE_A_CH0_STORE_IRQ field. */
#define BR_PXP_HW_PXP_IRQ_WFE_A_CH0_STORE_IRQ(x) (HW_PXP_HW_PXP_IRQ(x).B.WFE_A_CH0_STORE_IRQ)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_WFE_A_CH0_STORE_IRQ. */
#define BF_PXP_HW_PXP_IRQ_WFE_A_CH0_STORE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_WFE_A_CH0_STORE_IRQ) & BM_PXP_HW_PXP_IRQ_WFE_A_CH0_STORE_IRQ)

/*! @brief Set the WFE_A_CH0_STORE_IRQ field to a new value. */
#define BW_PXP_HW_PXP_IRQ_WFE_A_CH0_STORE_IRQ(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, (HW_PXP_HW_PXP_IRQ_RD(x) & ~BM_PXP_HW_PXP_IRQ_WFE_A_CH0_STORE_IRQ) | BF_PXP_HW_PXP_IRQ_WFE_A_CH0_STORE_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ, field WFE_A_CH1_STORE_IRQ[9] (RW)
 *
 * WFE A ch1 store engine Interrupt.
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_WFE_A_CH1_STORE_IRQ (9U) /*!< Bit position for PXP_HW_PXP_IRQ_WFE_A_CH1_STORE_IRQ. */
#define BM_PXP_HW_PXP_IRQ_WFE_A_CH1_STORE_IRQ (0x00000200U) /*!< Bit mask for PXP_HW_PXP_IRQ_WFE_A_CH1_STORE_IRQ. */
#define BS_PXP_HW_PXP_IRQ_WFE_A_CH1_STORE_IRQ (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_WFE_A_CH1_STORE_IRQ. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_WFE_A_CH1_STORE_IRQ field. */
#define BR_PXP_HW_PXP_IRQ_WFE_A_CH1_STORE_IRQ(x) (HW_PXP_HW_PXP_IRQ(x).B.WFE_A_CH1_STORE_IRQ)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_WFE_A_CH1_STORE_IRQ. */
#define BF_PXP_HW_PXP_IRQ_WFE_A_CH1_STORE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_WFE_A_CH1_STORE_IRQ) & BM_PXP_HW_PXP_IRQ_WFE_A_CH1_STORE_IRQ)

/*! @brief Set the WFE_A_CH1_STORE_IRQ field to a new value. */
#define BW_PXP_HW_PXP_IRQ_WFE_A_CH1_STORE_IRQ(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, (HW_PXP_HW_PXP_IRQ_RD(x) & ~BM_PXP_HW_PXP_IRQ_WFE_A_CH1_STORE_IRQ) | BF_PXP_HW_PXP_IRQ_WFE_A_CH1_STORE_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ, field WFE_B_CH0_STORE_IRQ[10] (RW)
 *
 * WFE B ch0 store engine Interrupt
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_WFE_B_CH0_STORE_IRQ (10U) /*!< Bit position for PXP_HW_PXP_IRQ_WFE_B_CH0_STORE_IRQ. */
#define BM_PXP_HW_PXP_IRQ_WFE_B_CH0_STORE_IRQ (0x00000400U) /*!< Bit mask for PXP_HW_PXP_IRQ_WFE_B_CH0_STORE_IRQ. */
#define BS_PXP_HW_PXP_IRQ_WFE_B_CH0_STORE_IRQ (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_WFE_B_CH0_STORE_IRQ. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_WFE_B_CH0_STORE_IRQ field. */
#define BR_PXP_HW_PXP_IRQ_WFE_B_CH0_STORE_IRQ(x) (HW_PXP_HW_PXP_IRQ(x).B.WFE_B_CH0_STORE_IRQ)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_WFE_B_CH0_STORE_IRQ. */
#define BF_PXP_HW_PXP_IRQ_WFE_B_CH0_STORE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_WFE_B_CH0_STORE_IRQ) & BM_PXP_HW_PXP_IRQ_WFE_B_CH0_STORE_IRQ)

/*! @brief Set the WFE_B_CH0_STORE_IRQ field to a new value. */
#define BW_PXP_HW_PXP_IRQ_WFE_B_CH0_STORE_IRQ(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, (HW_PXP_HW_PXP_IRQ_RD(x) & ~BM_PXP_HW_PXP_IRQ_WFE_B_CH0_STORE_IRQ) | BF_PXP_HW_PXP_IRQ_WFE_B_CH0_STORE_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ, field WFE_B_CH1_STORE_IRQ[11] (RW)
 *
 * WFE B ch1 store engine Interrupt
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_WFE_B_CH1_STORE_IRQ (11U) /*!< Bit position for PXP_HW_PXP_IRQ_WFE_B_CH1_STORE_IRQ. */
#define BM_PXP_HW_PXP_IRQ_WFE_B_CH1_STORE_IRQ (0x00000800U) /*!< Bit mask for PXP_HW_PXP_IRQ_WFE_B_CH1_STORE_IRQ. */
#define BS_PXP_HW_PXP_IRQ_WFE_B_CH1_STORE_IRQ (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_WFE_B_CH1_STORE_IRQ. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_WFE_B_CH1_STORE_IRQ field. */
#define BR_PXP_HW_PXP_IRQ_WFE_B_CH1_STORE_IRQ(x) (HW_PXP_HW_PXP_IRQ(x).B.WFE_B_CH1_STORE_IRQ)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_WFE_B_CH1_STORE_IRQ. */
#define BF_PXP_HW_PXP_IRQ_WFE_B_CH1_STORE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_WFE_B_CH1_STORE_IRQ) & BM_PXP_HW_PXP_IRQ_WFE_B_CH1_STORE_IRQ)

/*! @brief Set the WFE_B_CH1_STORE_IRQ field to a new value. */
#define BW_PXP_HW_PXP_IRQ_WFE_B_CH1_STORE_IRQ(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, (HW_PXP_HW_PXP_IRQ_RD(x) & ~BM_PXP_HW_PXP_IRQ_WFE_B_CH1_STORE_IRQ) | BF_PXP_HW_PXP_IRQ_WFE_B_CH1_STORE_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ, field FIRST_STORE_IRQ[12] (RW)
 *
 * Initial store engine interrupt
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_FIRST_STORE_IRQ (12U) /*!< Bit position for PXP_HW_PXP_IRQ_FIRST_STORE_IRQ. */
#define BM_PXP_HW_PXP_IRQ_FIRST_STORE_IRQ (0x00001000U) /*!< Bit mask for PXP_HW_PXP_IRQ_FIRST_STORE_IRQ. */
#define BS_PXP_HW_PXP_IRQ_FIRST_STORE_IRQ (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_FIRST_STORE_IRQ. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_FIRST_STORE_IRQ field. */
#define BR_PXP_HW_PXP_IRQ_FIRST_STORE_IRQ(x) (HW_PXP_HW_PXP_IRQ(x).B.FIRST_STORE_IRQ)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_FIRST_STORE_IRQ. */
#define BF_PXP_HW_PXP_IRQ_FIRST_STORE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_FIRST_STORE_IRQ) & BM_PXP_HW_PXP_IRQ_FIRST_STORE_IRQ)

/*! @brief Set the FIRST_STORE_IRQ field to a new value. */
#define BW_PXP_HW_PXP_IRQ_FIRST_STORE_IRQ(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, (HW_PXP_HW_PXP_IRQ_RD(x) & ~BM_PXP_HW_PXP_IRQ_FIRST_STORE_IRQ) | BF_PXP_HW_PXP_IRQ_FIRST_STORE_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ, field DITHER_STORE_IRQ[13] (RW)
 *
 * Dither store engine Interrupt
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_DITHER_STORE_IRQ (13U) /*!< Bit position for PXP_HW_PXP_IRQ_DITHER_STORE_IRQ. */
#define BM_PXP_HW_PXP_IRQ_DITHER_STORE_IRQ (0x00002000U) /*!< Bit mask for PXP_HW_PXP_IRQ_DITHER_STORE_IRQ. */
#define BS_PXP_HW_PXP_IRQ_DITHER_STORE_IRQ (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_DITHER_STORE_IRQ. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_DITHER_STORE_IRQ field. */
#define BR_PXP_HW_PXP_IRQ_DITHER_STORE_IRQ(x) (HW_PXP_HW_PXP_IRQ(x).B.DITHER_STORE_IRQ)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_DITHER_STORE_IRQ. */
#define BF_PXP_HW_PXP_IRQ_DITHER_STORE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_DITHER_STORE_IRQ) & BM_PXP_HW_PXP_IRQ_DITHER_STORE_IRQ)

/*! @brief Set the DITHER_STORE_IRQ field to a new value. */
#define BW_PXP_HW_PXP_IRQ_DITHER_STORE_IRQ(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, (HW_PXP_HW_PXP_IRQ_RD(x) & ~BM_PXP_HW_PXP_IRQ_DITHER_STORE_IRQ) | BF_PXP_HW_PXP_IRQ_DITHER_STORE_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ, field WFE_A_STORE_IRQ[14] (RW)
 *
 * WFE A store engine Interrupt.
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_WFE_A_STORE_IRQ (14U) /*!< Bit position for PXP_HW_PXP_IRQ_WFE_A_STORE_IRQ. */
#define BM_PXP_HW_PXP_IRQ_WFE_A_STORE_IRQ (0x00004000U) /*!< Bit mask for PXP_HW_PXP_IRQ_WFE_A_STORE_IRQ. */
#define BS_PXP_HW_PXP_IRQ_WFE_A_STORE_IRQ (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_WFE_A_STORE_IRQ. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_WFE_A_STORE_IRQ field. */
#define BR_PXP_HW_PXP_IRQ_WFE_A_STORE_IRQ(x) (HW_PXP_HW_PXP_IRQ(x).B.WFE_A_STORE_IRQ)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_WFE_A_STORE_IRQ. */
#define BF_PXP_HW_PXP_IRQ_WFE_A_STORE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_WFE_A_STORE_IRQ) & BM_PXP_HW_PXP_IRQ_WFE_A_STORE_IRQ)

/*! @brief Set the WFE_A_STORE_IRQ field to a new value. */
#define BW_PXP_HW_PXP_IRQ_WFE_A_STORE_IRQ(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, (HW_PXP_HW_PXP_IRQ_RD(x) & ~BM_PXP_HW_PXP_IRQ_WFE_A_STORE_IRQ) | BF_PXP_HW_PXP_IRQ_WFE_A_STORE_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ, field WFE_B_STORE_IRQ[15] (RW)
 *
 * WFE B store engine Interrupt
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_WFE_B_STORE_IRQ (15U) /*!< Bit position for PXP_HW_PXP_IRQ_WFE_B_STORE_IRQ. */
#define BM_PXP_HW_PXP_IRQ_WFE_B_STORE_IRQ (0x00008000U) /*!< Bit mask for PXP_HW_PXP_IRQ_WFE_B_STORE_IRQ. */
#define BS_PXP_HW_PXP_IRQ_WFE_B_STORE_IRQ (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_WFE_B_STORE_IRQ. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_WFE_B_STORE_IRQ field. */
#define BR_PXP_HW_PXP_IRQ_WFE_B_STORE_IRQ(x) (HW_PXP_HW_PXP_IRQ(x).B.WFE_B_STORE_IRQ)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_WFE_B_STORE_IRQ. */
#define BF_PXP_HW_PXP_IRQ_WFE_B_STORE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_WFE_B_STORE_IRQ) & BM_PXP_HW_PXP_IRQ_WFE_B_STORE_IRQ)

/*! @brief Set the WFE_B_STORE_IRQ field to a new value. */
#define BW_PXP_HW_PXP_IRQ_WFE_B_STORE_IRQ(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, (HW_PXP_HW_PXP_IRQ_RD(x) & ~BM_PXP_HW_PXP_IRQ_WFE_B_STORE_IRQ) | BF_PXP_HW_PXP_IRQ_WFE_B_STORE_IRQ(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ, field RSVD1[30:16] (RO)
 *
 * Reserved.
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_RSVD1 (16U)      /*!< Bit position for PXP_HW_PXP_IRQ_RSVD1. */
#define BM_PXP_HW_PXP_IRQ_RSVD1 (0x7FFF0000U) /*!< Bit mask for PXP_HW_PXP_IRQ_RSVD1. */
#define BS_PXP_HW_PXP_IRQ_RSVD1 (15U)      /*!< Bit field size in bits for PXP_HW_PXP_IRQ_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_RSVD1 field. */
#define BR_PXP_HW_PXP_IRQ_RSVD1(x) (HW_PXP_HW_PXP_IRQ(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_IRQ, field COMPRESS_DONE_IRQ[31] (RW)
 *
 * compression done Interrupt
 */
/*@{*/
#define BP_PXP_HW_PXP_IRQ_COMPRESS_DONE_IRQ (31U) /*!< Bit position for PXP_HW_PXP_IRQ_COMPRESS_DONE_IRQ. */
#define BM_PXP_HW_PXP_IRQ_COMPRESS_DONE_IRQ (0x80000000U) /*!< Bit mask for PXP_HW_PXP_IRQ_COMPRESS_DONE_IRQ. */
#define BS_PXP_HW_PXP_IRQ_COMPRESS_DONE_IRQ (1U) /*!< Bit field size in bits for PXP_HW_PXP_IRQ_COMPRESS_DONE_IRQ. */

/*! @brief Read current value of the PXP_HW_PXP_IRQ_COMPRESS_DONE_IRQ field. */
#define BR_PXP_HW_PXP_IRQ_COMPRESS_DONE_IRQ(x) (HW_PXP_HW_PXP_IRQ(x).B.COMPRESS_DONE_IRQ)

/*! @brief Format value for bitfield PXP_HW_PXP_IRQ_COMPRESS_DONE_IRQ. */
#define BF_PXP_HW_PXP_IRQ_COMPRESS_DONE_IRQ(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_IRQ_COMPRESS_DONE_IRQ) & BM_PXP_HW_PXP_IRQ_COMPRESS_DONE_IRQ)

/*! @brief Set the COMPRESS_DONE_IRQ field to a new value. */
#define BW_PXP_HW_PXP_IRQ_COMPRESS_DONE_IRQ(x, v) (HW_PXP_HW_PXP_IRQ_WR(x, (HW_PXP_HW_PXP_IRQ_RD(x) & ~BM_PXP_HW_PXP_IRQ_COMPRESS_DONE_IRQ) | BF_PXP_HW_PXP_IRQ_COMPRESS_DONE_IRQ(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_NEXT - Next Frame Pointer
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_NEXT - Next Frame Pointer (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains a pointer to a data structure used to reload the PXP
 * registers at the end of the current frame. To enable this functionality,
 * software must write this register while the PXP is processing the current data frame
 * (if the PXP is currently idle, this will also initiate an immediate load of
 * registers from the pointer). The process of writing this register (WRITE
 * operation) will set a semaphore in hardware to notify the control logic that a
 * register reload operation must be performed when the current frame processing is
 * complete. At the end of a frame, the PXP will fetch the register settings from
 * this location, signal an interrupt to software, then proceed with rendering the
 * next frame of data. Software may cancel the reload operation by issuing a
 * CLEAR operation to this register. SET and TOGGLE operations should not be used
 * when addressing this register. All registers will be reloaded with the exception
 * of the following: STAT, CSCCOEFn, NEXT, VERSION. All other registers will be
 * loaded in the order they appear in the register map. Once the pointer's
 * contents have been loaded into the PXP's registers, the NEXT_IRQ interrupt will be
 * issued (see the PXP_STATUS register). EXAMPLE // create register command
 * structure in memory u32* pxp_commands0[48], pxp_commands1; u32 rc; // initialize
 * control structure for frame 0 pxp_commands0[0] = ...; // CTRL pxp_commands0[1] =
 * ...; // OUT Buffer ... pxp_commands0[47] = ..; // Overlay7 param2 //
 * initialize control structure for frame 1 pxp_commands1[0] = ...; // CTRL
 * pxp_commands1[1] = ...; // OUT Buffer ... pxp_commands1[47] = ..; // Overlay7 param2 // poll
 * until a command isn't queued while (rc=REG_NEXT_RD() & BM_PXP_NEXT_ENABLED );
 * REG_NEXT_WR(pxp_commands0); // enable PXP operation 0 via command pointer //
 * poll until first command clears while (rc=REG_NEXT_RD() & BM_PXP_NEXT_ENABLED
 * ); REG_NEXT_WR(pxp_commands1); // enable PXP operation 1 via command pointer
 */
typedef union _hw_pxp_hw_pxp_next
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_next_bitfields
    {
        uint32_t ENABLED : 1;          /*!< [0]  */
        uint32_t RSVD : 1;             /*!< [1]  */
        uint32_t POINTER : 30;         /*!< [31:2]  */
    } B;
} hw_pxp_hw_pxp_next_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_NEXT register
 */
/*@{*/
#define HW_PXP_HW_PXP_NEXT_ADDR(x) ((uintptr_t)(x) + 0x400U)

#define HW_PXP_HW_PXP_NEXT(x)    (*(__IO hw_pxp_hw_pxp_next_t *) HW_PXP_HW_PXP_NEXT_ADDR(x))
#define HW_PXP_HW_PXP_NEXT_RD(x) (HW_PXP_HW_PXP_NEXT(x).U)
#define HW_PXP_HW_PXP_NEXT_WR(x, v) (HW_PXP_HW_PXP_NEXT(x).U = (v))
#define HW_PXP_HW_PXP_NEXT_SET(x, v) (HW_PXP_HW_PXP_NEXT_WR(x, HW_PXP_HW_PXP_NEXT_RD(x) |  (v)))
#define HW_PXP_HW_PXP_NEXT_CLR(x, v) (HW_PXP_HW_PXP_NEXT_WR(x, HW_PXP_HW_PXP_NEXT_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_NEXT_TOG(x, v) (HW_PXP_HW_PXP_NEXT_WR(x, HW_PXP_HW_PXP_NEXT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_NEXT bitfields
 */

/*!
 * @name Register PXP_HW_PXP_NEXT, field ENABLED[0] (RO)
 *
 * Indicates that the "next frame" functionality has been enabled. This bit
 * reflects the status of the hardware semaphore indicating that a reload operation
 * is pending at the end of the current frame.
 */
/*@{*/
#define BP_PXP_HW_PXP_NEXT_ENABLED (0U)    /*!< Bit position for PXP_HW_PXP_NEXT_ENABLED. */
#define BM_PXP_HW_PXP_NEXT_ENABLED (0x00000001U) /*!< Bit mask for PXP_HW_PXP_NEXT_ENABLED. */
#define BS_PXP_HW_PXP_NEXT_ENABLED (1U)    /*!< Bit field size in bits for PXP_HW_PXP_NEXT_ENABLED. */

/*! @brief Read current value of the PXP_HW_PXP_NEXT_ENABLED field. */
#define BR_PXP_HW_PXP_NEXT_ENABLED(x) (HW_PXP_HW_PXP_NEXT(x).B.ENABLED)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_NEXT, field RSVD[1] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_NEXT_RSVD (1U)       /*!< Bit position for PXP_HW_PXP_NEXT_RSVD. */
#define BM_PXP_HW_PXP_NEXT_RSVD (0x00000002U) /*!< Bit mask for PXP_HW_PXP_NEXT_RSVD. */
#define BS_PXP_HW_PXP_NEXT_RSVD (1U)       /*!< Bit field size in bits for PXP_HW_PXP_NEXT_RSVD. */

/*! @brief Read current value of the PXP_HW_PXP_NEXT_RSVD field. */
#define BR_PXP_HW_PXP_NEXT_RSVD(x) (HW_PXP_HW_PXP_NEXT(x).B.RSVD)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_NEXT, field POINTER[31:2] (RW)
 *
 * A pointer to a data structure containing register values to be used when
 * processing the next frame. The pointer must be 32-bit aligned and should reside in
 * on-chip or off-chip memory.
 */
/*@{*/
#define BP_PXP_HW_PXP_NEXT_POINTER (2U)    /*!< Bit position for PXP_HW_PXP_NEXT_POINTER. */
#define BM_PXP_HW_PXP_NEXT_POINTER (0xFFFFFFFCU) /*!< Bit mask for PXP_HW_PXP_NEXT_POINTER. */
#define BS_PXP_HW_PXP_NEXT_POINTER (30U)   /*!< Bit field size in bits for PXP_HW_PXP_NEXT_POINTER. */

/*! @brief Read current value of the PXP_HW_PXP_NEXT_POINTER field. */
#define BR_PXP_HW_PXP_NEXT_POINTER(x) (HW_PXP_HW_PXP_NEXT(x).B.POINTER)

/*! @brief Format value for bitfield PXP_HW_PXP_NEXT_POINTER. */
#define BF_PXP_HW_PXP_NEXT_POINTER(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_NEXT_POINTER) & BM_PXP_HW_PXP_NEXT_POINTER)

/*! @brief Set the POINTER field to a new value. */
#define BW_PXP_HW_PXP_NEXT_POINTER(x, v) (HW_PXP_HW_PXP_NEXT_WR(x, (HW_PXP_HW_PXP_NEXT_RD(x) & ~BM_PXP_HW_PXP_NEXT_POINTER) | BF_PXP_HW_PXP_NEXT_POINTER(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0 - Pre-fetch engine Control Channel 0 Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0 - Pre-fetch engine Control Channel 0 Register (RW)
 *
 * Reset value: 0x00020000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * HW_PXP_INPUT_FETCH_CTRL_CH0: 0x450 HW_PXP_INPUT_FETCH_CTRL_CH0_SET: 0x454
 * HW_PXP_INPUT_FETCH_CTRL_CH0_CLR: 0x458 HW_PXP_INPUT_FETCH_CTRL_CH0_TOG: 0x45C The
 * Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_ctrl_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_ctrl_ch0_bitfields
    {
        uint32_t CH_EN : 1;            /*!< [0]  */
        uint32_t BLOCK_EN : 1;         /*!< [1]  */
        uint32_t BLOCK_16 : 1;         /*!< [2]  */
        uint32_t HANDSHAKE_EN : 1;     /*!< [3]  */
        uint32_t BYPASS_PIXEL_EN : 1;  /*!< [4]  */
        uint32_t HIGH_BYTE : 1;        /*!< [5]  */
        uint32_t RSVD4 : 3;            /*!< [8:6]  */
        uint32_t HFLIP : 1;            /*!< [9]  */
        uint32_t VFLIP : 1;            /*!< [10]  */
        uint32_t RSVD3 : 1;            /*!< [11]  */
        uint32_t ROTATION_ANGLE : 2;   /*!< [13:12]  */
        uint32_t RSVD2 : 2;            /*!< [15:14]  */
        uint32_t RD_NUM_BYTES : 2;     /*!< [17:16]  */
        uint32_t RSVD1 : 6;            /*!< [23:18]  */
        uint32_t HANDSHAKE_SCAN_LINE_NUM : 2; /*!< [25:24]  */
        uint32_t RSVD0 : 5;            /*!< [30:26]  */
        uint32_t ARBIT_EN : 1;         /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_ctrl_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_CTRL_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ADDR(x) ((uintptr_t)(x) + 0x450U)

#define HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x) (*(__IO hw_pxp_hw_pxp_input_fetch_ctrl_ch0_t *) HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_CTRL_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH0, field CH_EN[0] (RW)
 *
 * Channel enable.
 *
 * Values:
 * - 0 - Prefetch function is disable
 * - 1 - Prefetch function is enable
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN (0x00000001U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN: Prefetch function is disable */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN: Prefetch function is enable */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x).B.CH_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN)

/*! @brief Set the CH_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_CH_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH0, field BLOCK_EN[1] (RW)
 *
 * Choses the prefetch mode.
 *
 * Values:
 * - 0 - Prefetch in scan mode
 * - 1 - Prefetch in block mode
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN (1U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN (0x00000002U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN: Prefetch in scan mode */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN: Prefetch in block mode */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x).B.BLOCK_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN)

/*! @brief Set the BLOCK_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH0, field BLOCK_16[2] (RW)
 *
 * Determines the block sixe.
 *
 * Values:
 * - 0 - Block size is 8x8
 * - 1 - Block size is 16x16
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16 (2U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16 (0x00000004U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16_8x8 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16: Block size is 8x8 */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16_16x16 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16: Block size is 16x16 */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x).B.BLOCK_16)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16)

/*! @brief Set the BLOCK_16 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BLOCK_16(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH0, field HANDSHAKE_EN[3] (RW)
 *
 * Enable bit for handshake with the store engine.
 *
 * Values:
 * - 0 - Handshake with the store engine is disabled
 * - 1 - Handshake with the store engine is enabled
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN (3U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN (0x00000008U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN: Handshake with the store engine is disabled */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN: Handshake with the store engine is enabled */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x).B.HANDSHAKE_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN)

/*! @brief Set the HANDSHAKE_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH0, field BYPASS_PIXEL_EN[4] (RW)
 *
 * Selects Channel 0 pixel source
 *
 * Values:
 * - 0 - Channel 0 is from memory
 * - 1 - Channel 0 is from previous process engine
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN (4U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN (0x00000010U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN: Channel 0 is from memory */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN: Channel 0 is from previous process engine */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x).B.BYPASS_PIXEL_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN)

/*! @brief Set the BYPASS_PIXEL_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_BYPASS_PIXEL_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH0, field HIGH_BYTE[5] (RW)
 *
 * channel 0 high byte selection
 *
 * Values:
 * - 0 - In 64 bit mode, the output high byte will use channel1.
 * - 1 - In 64 bit mode, the output high byte will use channel0
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE (5U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE (0x00000020U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE: In 64 bit mode, the output high byte will use channel1. */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE: In 64 bit mode, the output high byte will use channel0 */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x).B.HIGH_BYTE)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE)

/*! @brief Set the HIGH_BYTE field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HIGH_BYTE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH0, field RSVD4[8:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD4 (6U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD4. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD4 (0x000001C0U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD4. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD4 (3U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD4. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD4 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD4(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x).B.RSVD4)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH0, field HFLIP[9] (RW)
 *
 * Enables HFLIP.
 *
 * Values:
 * - 0 - HFLIP disable
 * - 1 - VFLIP enable
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP (9U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP (0x00000200U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP: HFLIP disable */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP: VFLIP enable */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x).B.HFLIP)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP)

/*! @brief Set the HFLIP field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HFLIP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH0, field VFLIP[10] (RW)
 *
 * Enables VFLIP
 *
 * Values:
 * - 0 - VFLIP disable
 * - 1 - VFLIP enable
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP (10U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP (0x00000400U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP: VFLIP disable */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP: VFLIP enable */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x).B.VFLIP)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP)

/*! @brief Set the VFLIP field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_VFLIP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH0, field RSVD3[11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD3 (11U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD3. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD3 (0x00000800U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD3. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD3 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD3(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH0, field ROTATION_ANGLE[13:12] (RW)
 *
 * Values:
 * - 0 - Rotate image by 0 degrees.
 * - 1 - Rotate image by 90 degrees.
 * - 10 - Rotate image by 180 degrees.
 * - 11 - Rotate image by 270 degrees.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE (12U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE (0x00003000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE (2U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE_ROT_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE: Rotate image by 0 degrees. */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE_ROT_90 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE: Rotate image by 90 degrees. */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE_ROT_180 (0x2U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE: Rotate image by 180 degrees. */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE_ROT_270 (0x3U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE: Rotate image by 270 degrees. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x).B.ROTATION_ANGLE)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE)

/*! @brief Set the ROTATION_ANGLE field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ROTATION_ANGLE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH0, field RSVD2[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD2 (14U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD2. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD2 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD2. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD2 (2U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD2 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD2(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH0, field RD_NUM_BYTES[17:16] (RW)
 *
 * Bytes in a read burst
 *
 * Values:
 * - 0 - 8 bytes.
 * - 1 - 16 bytes.
 * - 10 - 32 bytes.
 * - 11 - 64 bytes.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES (16U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES (0x00030000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES (2U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES_8_bytes (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES: 8 bytes. */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES_16_bytes (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES: 16 bytes. */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES_32_bytes (0x2U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES: 32 bytes. */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES_64_bytes (0x3U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES: 64 bytes. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x).B.RD_NUM_BYTES)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES)

/*! @brief Set the RD_NUM_BYTES field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD_NUM_BYTES(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH0, field RSVD1[23:18] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD1 (18U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD1. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD1 (0x00FC0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD1. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD1 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD1(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH0, field HANDSHAKE_SCAN_LINE_NUM[25:24] (RW)
 *
 * scan handshake line number
 *
 * Values:
 * - 0 - 1 line.
 * - 1 - 8 lines
 * - 10 - 16 lines
 * - 11 - 16 lines
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM (24U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM (0x03000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM (2U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM: 1 line. */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM: 8 lines */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM: 16 lines */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM: 16 lines */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x).B.HANDSHAKE_SCAN_LINE_NUM)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM)

/*! @brief Set the HANDSHAKE_SCAN_LINE_NUM field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH0, field RSVD0[30:26] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD0 (26U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD0. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD0 (0x7C000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD0. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD0 (5U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RSVD0(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH0, field ARBIT_EN[31] (RW)
 *
 * Enables Arbitration
 *
 * Values:
 * - 0 - Arbitration disable. If using 2 channels, will output 2 axi bus sets.
 * - 1 - Arbitration enable. If using 2 channel, will only output 1 axi bus sets
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN (31U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN (0x80000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN: Arbitration disable. If using 2 channels, will output 2 axi bus sets. */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN: Arbitration enable. If using 2 channel, will only output 1 axi bus sets */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0(x).B.ARBIT_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN)

/*! @brief Set the ARBIT_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH0_ARBIT_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1 - Pre-fetch engine Control Channel 1 Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1 - Pre-fetch engine Control Channel 1 Register (RW)
 *
 * Reset value: 0x00020000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * HW_PXP_INPUT_FETCH_CTRL_CH1: 0x460 HW_PXP_INPUT_FETCH_CTRL_CH1_SET: 0x464
 * HW_PXP_INPUT_FETCH_CTRL_CH1_CLR: 0x468 HW_PXP_INPUT_FETCH_CTRL_CH1_TOG: 0x46C The
 * Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_ctrl_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_ctrl_ch1_bitfields
    {
        uint32_t CH_EN : 1;            /*!< [0]  */
        uint32_t BLOCK_EN : 1;         /*!< [1]  */
        uint32_t BLOCK_16 : 1;         /*!< [2]  */
        uint32_t HANDSHAKE_EN : 1;     /*!< [3]  */
        uint32_t BYPASS_PIXEL_EN : 1;  /*!< [4]  */
        uint32_t RSVD4 : 4;            /*!< [8:5]  */
        uint32_t HFLIP : 1;            /*!< [9]  */
        uint32_t VFLIP : 1;            /*!< [10]  */
        uint32_t RSVD3 : 1;            /*!< [11]  */
        uint32_t ROTATION_ANGLE : 2;   /*!< [13:12]  */
        uint32_t RSVD2 : 2;            /*!< [15:14]  */
        uint32_t RD_NUM_BYTES : 2;     /*!< [17:16]  */
        uint32_t RSVD1 : 6;            /*!< [23:18]  */
        uint32_t HANDSHAKE_SCAN_LINE_NUM : 2; /*!< [25:24]  */
        uint32_t RSVD0 : 6;            /*!< [31:26]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_ctrl_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_CTRL_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ADDR(x) ((uintptr_t)(x) + 0x460U)

#define HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1(x) (*(__IO hw_pxp_hw_pxp_input_fetch_ctrl_ch1_t *) HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_CTRL_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH1, field CH_EN[0] (RW)
 *
 * Channel enable.
 *
 * Values:
 * - 0 - prefetch function is disable
 * - 1 - prefetch function is enable
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN (0x00000001U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN: prefetch function is disable */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN: prefetch function is enable */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1(x).B.CH_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN)

/*! @brief Set the CH_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_CH_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH1, field BLOCK_EN[1] (RW)
 *
 * Choses the prefetch mode.
 *
 * Values:
 * - 0 - Prefetch in scan mode
 * - 1 - Prefetch in block mode
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN (1U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN (0x00000002U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN: Prefetch in scan mode */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN: Prefetch in block mode */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1(x).B.BLOCK_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN)

/*! @brief Set the BLOCK_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH1, field BLOCK_16[2] (RW)
 *
 * Determines the block sixe.
 *
 * Values:
 * - 0 - Block size is 8x8
 * - 1 - Block size is 16x16
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16 (2U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16 (0x00000004U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16_8x8 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16: Block size is 8x8 */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16_16x16 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16: Block size is 16x16 */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1(x).B.BLOCK_16)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16)

/*! @brief Set the BLOCK_16 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BLOCK_16(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH1, field HANDSHAKE_EN[3] (RW)
 *
 * Enable bit for handshake with the store engine.
 *
 * Values:
 * - 0 - Handshake with the store engine is disabled
 * - 1 - Handshake with the store engine is enabled
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN (3U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN (0x00000008U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN: Handshake with the store engine is disabled */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN: Handshake with the store engine is enabled */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1(x).B.HANDSHAKE_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN)

/*! @brief Set the HANDSHAKE_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH1, field BYPASS_PIXEL_EN[4] (RW)
 *
 * Selects Channel 1 pixel source
 *
 * Values:
 * - 0 - Channel 1 is from memory
 * - 1 - Channel 1 is from previous process engine
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN (4U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN (0x00000010U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN: Channel 1 is from memory */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN: Channel 1 is from previous process engine */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1(x).B.BYPASS_PIXEL_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN)

/*! @brief Set the BYPASS_PIXEL_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_BYPASS_PIXEL_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH1, field RSVD4[8:5] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD4 (5U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD4. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD4 (0x000001E0U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD4. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD4 (4U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD4. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD4 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD4(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1(x).B.RSVD4)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH1, field HFLIP[9] (RW)
 *
 * Enables HFLIP.
 *
 * Values:
 * - 0 - HFLIP disable
 * - 1 - VFLIP enable
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP (9U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP (0x00000200U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP: HFLIP disable */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP: VFLIP enable */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1(x).B.HFLIP)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP)

/*! @brief Set the HFLIP field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HFLIP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH1, field VFLIP[10] (RW)
 *
 * Enables VFLIP
 *
 * Values:
 * - 0 - VFLIP disable
 * - 1 - VFLIP enable
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP (10U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP (0x00000400U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP: VFLIP disable */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP: VFLIP enable */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1(x).B.VFLIP)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP)

/*! @brief Set the VFLIP field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_VFLIP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH1, field RSVD3[11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD3 (11U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD3. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD3 (0x00000800U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD3. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD3 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD3(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH1, field ROTATION_ANGLE[13:12] (RW)
 *
 * Values:
 * - 0 - Rotate image by 0 degrees.
 * - 1 - Rotate image by 90 degrees.
 * - 10 - Rotate image by 180 degrees.
 * - 11 - Rotate image by 270 degrees.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE (12U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE (0x00003000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE (2U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE_ROT_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE: Rotate image by 0 degrees. */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE_ROT_90 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE: Rotate image by 90 degrees. */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE_ROT_180 (0x2U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE: Rotate image by 180 degrees. */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE_ROT_270 (0x3U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE: Rotate image by 270 degrees. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1(x).B.ROTATION_ANGLE)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE)

/*! @brief Set the ROTATION_ANGLE field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_ROTATION_ANGLE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH1, field RSVD2[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD2 (14U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD2. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD2 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD2. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD2 (2U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD2 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD2(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH1, field RD_NUM_BYTES[17:16] (RW)
 *
 * Bytes in a read burst
 *
 * Values:
 * - 0 - 8 bytes.
 * - 1 - 16 bytes.
 * - 10 - 32 bytes.
 * - 11 - 64 bytes.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES (16U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES (0x00030000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES (2U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES_8_bytes (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES: 8 bytes. */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES_16_bytes (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES: 16 bytes. */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES_32_bytes (0x2U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES: 32 bytes. */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES_64_bytes (0x3U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES: 64 bytes. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1(x).B.RD_NUM_BYTES)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES)

/*! @brief Set the RD_NUM_BYTES field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD_NUM_BYTES(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH1, field RSVD1[23:18] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD1 (18U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD1. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD1 (0x00FC0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD1. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD1 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD1(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH1, field HANDSHAKE_SCAN_LINE_NUM[25:24] (RW)
 *
 * scan handshake line number
 *
 * Values:
 * - 0 - 1 line.
 * - 1 - 8 lines
 * - 10 - 16 lines
 * - 11 - 16 lines
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM (24U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM (0x03000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM (2U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM. */

#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM: 1 line. */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM: 8 lines */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM: 16 lines */
#define BV_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM: 16 lines */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1(x).B.HANDSHAKE_SCAN_LINE_NUM)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM. */
#define BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM) & BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM)

/*! @brief Set the HANDSHAKE_SCAN_LINE_NUM field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM) | BF_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_CTRL_CH1, field RSVD0[31:26] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD0 (26U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD0. */
#define BM_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD0 (0xFC000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD0. */
#define BS_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD0 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD0 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1_RSVD0(x) (HW_PXP_HW_PXP_INPUT_FETCH_CTRL_CH1(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH0 - Pre-fetch engine status Channel 0 Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH0 - Pre-fetch engine status Channel 0 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the status bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_status_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_status_ch0_bitfields
    {
        uint32_t PREFETCH_BLOCK_X : 16; /*!< [15:0]  */
        uint32_t PREFETCH_BLOCK_Y : 16; /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_status_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_STATUS_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_ADDR(x) ((uintptr_t)(x) + 0x470U)

#define HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH0(x) (*(__I hw_pxp_hw_pxp_input_fetch_status_ch0_t *) HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH0(x).U)
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_STATUS_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_STATUS_CH0, field PREFETCH_BLOCK_X[15:0] (RO)
 *
 * When in scan mode, this field is always 0. In block mode, it indicates the X
 * coordinate of the block currently being rendered.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_X (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_X. */
#define BM_PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_X (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_X. */
#define BS_PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_X (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_X. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_X field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_X(x) (HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH0(x).B.PREFETCH_BLOCK_X)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_STATUS_CH0, field PREFETCH_BLOCK_Y[31:16] (RO)
 *
 * When in scan mode, this field indicates the current Y coordinate of the
 * frame. In block mode, it indicates the Y coordinate of the block currently being
 * rendered.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y (16U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y. */
#define BM_PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y. */
#define BS_PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y(x) (HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH0(x).B.PREFETCH_BLOCK_Y)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH1 - Store engine status Channel 1 Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH1 - Store engine status Channel 1 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the status bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_status_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_status_ch1_bitfields
    {
        uint32_t PREFETCH_BLOCK_X : 16; /*!< [15:0]  */
        uint32_t PREFETCH_BLOCK_Y : 16; /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_status_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_STATUS_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_ADDR(x) ((uintptr_t)(x) + 0x480U)

#define HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH1(x) (*(__I hw_pxp_hw_pxp_input_fetch_status_ch1_t *) HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH1(x).U)
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_STATUS_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_STATUS_CH1, field PREFETCH_BLOCK_X[15:0] (RO)
 *
 * When in scan mode, this field is always 0. In block mode, it indicates the X
 * coordinate of the block currently being rendered.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_X (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_X. */
#define BM_PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_X (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_X. */
#define BS_PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_X (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_X. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_X field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_X(x) (HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH1(x).B.PREFETCH_BLOCK_X)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_STATUS_CH1, field PREFETCH_BLOCK_Y[31:16] (RO)
 *
 * When in scan mode, this field indicates the current Y coordinate of the
 * frame. In block mode, it indicates the Y coordinate of the block currently being
 * rendered.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y (16U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y. */
#define BM_PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y. */
#define BS_PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y(x) (HW_PXP_HW_PXP_INPUT_FETCH_STATUS_CH1(x).B.PREFETCH_BLOCK_Y)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_active_size_ulc_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_active_size_ulc_ch0_bitfields
    {
        uint32_t ACTIVE_SIZE_ULC_X : 16; /*!< [15:0]  */
        uint32_t ACTIVE_SIZE_ULC_Y : 16; /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_active_size_ulc_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ADDR(x) ((uintptr_t)(x) + 0x490U)

#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0(x) (*(__IO hw_pxp_hw_pxp_input_fetch_active_size_ulc_ch0_t *) HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0, field ACTIVE_SIZE_ULC_X[15:0] (RW)
 *
 * This field indicates the upper left X-coordinate(in pixels) of the active
 * surface of the total input memory
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X. */
#define BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X. */
#define BS_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X(x) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0(x).B.ACTIVE_SIZE_ULC_X)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X. */
#define BF_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X) & BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X)

/*! @brief Set the ACTIVE_SIZE_ULC_X field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X) | BF_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0, field ACTIVE_SIZE_ULC_Y[31:16] (RW)
 *
 * This field indicates the upper left Y-coordinate(in pixels) of the active
 * surface of the total input memory
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y (16U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y. */
#define BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y. */
#define BS_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y(x) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0(x).B.ACTIVE_SIZE_ULC_Y)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y. */
#define BF_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y) & BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y)

/*! @brief Set the ACTIVE_SIZE_ULC_Y field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y) | BF_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_active_size_lrc_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_active_size_lrc_ch0_bitfields
    {
        uint32_t ACTIVE_SIZE_LRC_X : 16; /*!< [15:0]  */
        uint32_t ACTIVE_SIZE_LRC_Y : 16; /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_active_size_lrc_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ADDR(x) ((uintptr_t)(x) + 0x4A0U)

#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0(x) (*(__IO hw_pxp_hw_pxp_input_fetch_active_size_lrc_ch0_t *) HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0, field ACTIVE_SIZE_LRC_X[15:0] (RW)
 *
 * This field indicates the upper left X-coordinate(in pixels) of the active
 * surface of the total input memory
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X. */
#define BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X. */
#define BS_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X(x) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0(x).B.ACTIVE_SIZE_LRC_X)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X. */
#define BF_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X) & BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X)

/*! @brief Set the ACTIVE_SIZE_LRC_X field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X) | BF_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0, field ACTIVE_SIZE_LRC_Y[31:16] (RW)
 *
 * This field indicates the upper left Y-coordinate(in pixels) of the active
 * surface of the total input memory
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y (16U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y. */
#define BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y. */
#define BS_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y(x) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0(x).B.ACTIVE_SIZE_LRC_Y)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y. */
#define BF_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y) & BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y)

/*! @brief Set the ACTIVE_SIZE_LRC_Y field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y) | BF_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_active_size_ulc_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_active_size_ulc_ch1_bitfields
    {
        uint32_t ACTIVE_SIZE_ULC_X : 16; /*!< [15:0]  */
        uint32_t ACTIVE_SIZE_ULC_Y : 16; /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_active_size_ulc_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ADDR(x) ((uintptr_t)(x) + 0x4B0U)

#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1(x) (*(__IO hw_pxp_hw_pxp_input_fetch_active_size_ulc_ch1_t *) HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1, field ACTIVE_SIZE_ULC_X[15:0] (RW)
 *
 * This field indicates the upper left X-coordinate(in pixels) of the active
 * surface of the total input memory
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X. */
#define BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X. */
#define BS_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X(x) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1(x).B.ACTIVE_SIZE_ULC_X)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X. */
#define BF_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X) & BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X)

/*! @brief Set the ACTIVE_SIZE_ULC_X field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X) | BF_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1, field ACTIVE_SIZE_ULC_Y[31:16] (RW)
 *
 * This field indicates the upper left Y-coordinate(in pixels) of the active
 * surface of the total input memory
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y (16U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y. */
#define BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y. */
#define BS_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y(x) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1(x).B.ACTIVE_SIZE_ULC_Y)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y. */
#define BF_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y) & BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y)

/*! @brief Set the ACTIVE_SIZE_ULC_Y field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y) | BF_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_active_size_lrc_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_active_size_lrc_ch1_bitfields
    {
        uint32_t ACTIVE_SIZE_LRC_X : 16; /*!< [15:0]  */
        uint32_t ACTIVE_SIZE_LRC_Y : 16; /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_active_size_lrc_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ADDR(x) ((uintptr_t)(x) + 0x4C0U)

#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1(x) (*(__IO hw_pxp_hw_pxp_input_fetch_active_size_lrc_ch1_t *) HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1, field ACTIVE_SIZE_LRC_X[15:0] (RW)
 *
 * This field indicates the upper left X-coordinate(in pixels) of the active
 * surface of the total input memory
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X. */
#define BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X. */
#define BS_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X(x) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1(x).B.ACTIVE_SIZE_LRC_X)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X. */
#define BF_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X) & BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X)

/*! @brief Set the ACTIVE_SIZE_LRC_X field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X) | BF_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1, field ACTIVE_SIZE_LRC_Y[31:16] (RW)
 *
 * This field indicates the upper left Y-coordinate(in pixels) of the active
 * surface of the total input memory
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y (16U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y. */
#define BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y. */
#define BS_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y(x) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1(x).B.ACTIVE_SIZE_LRC_Y)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y. */
#define BF_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y) & BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y)

/*! @brief Set the ACTIVE_SIZE_LRC_Y field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y) | BF_PXP_HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_size_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_size_ch0_bitfields
    {
        uint32_t INPUT_TOTAL_WIDTH : 16; /*!< [15:0]  */
        uint32_t INPUT_TOTAL_HEIGHT : 16; /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_size_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_SIZE_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_ADDR(x) ((uintptr_t)(x) + 0x4D0U)

#define HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0(x) (*(__IO hw_pxp_hw_pxp_input_fetch_size_ch0_t *) HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_SIZE_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SIZE_CH0, field INPUT_TOTAL_WIDTH[15:0] (RW)
 *
 * actual total width -1
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH(x) (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0(x).B.INPUT_TOTAL_WIDTH)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH) & BM_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH)

/*! @brief Set the INPUT_TOTAL_WIDTH field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH) | BF_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SIZE_CH0, field INPUT_TOTAL_HEIGHT[31:16] (RW)
 *
 * actual total height - 1
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT (16U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT(x) (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0(x).B.INPUT_TOTAL_HEIGHT)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT) & BM_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT)

/*! @brief Set the INPUT_TOTAL_HEIGHT field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT) | BF_PXP_HW_PXP_INPUT_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_size_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_size_ch1_bitfields
    {
        uint32_t INPUT_TOTAL_WIDTH : 16; /*!< [15:0]  */
        uint32_t INPUT_TOTAL_HEIGHT : 16; /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_size_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_SIZE_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_ADDR(x) ((uintptr_t)(x) + 0x4E0U)

#define HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1(x) (*(__IO hw_pxp_hw_pxp_input_fetch_size_ch1_t *) HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_SIZE_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SIZE_CH1, field INPUT_TOTAL_WIDTH[15:0] (RW)
 *
 * actual total width -1
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH(x) (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1(x).B.INPUT_TOTAL_WIDTH)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH) & BM_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH)

/*! @brief Set the INPUT_TOTAL_WIDTH field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH) | BF_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SIZE_CH1, field INPUT_TOTAL_HEIGHT[31:16] (RW)
 *
 * actual total height -1
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT (16U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT(x) (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1(x).B.INPUT_TOTAL_HEIGHT)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT) & BM_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT)

/*! @brief Set the INPUT_TOTAL_HEIGHT field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT) | BF_PXP_HW_PXP_INPUT_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_background_color_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_background_color_ch0_bitfields
    {
        uint32_t BACKGROUND_COLOR : 32; /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_background_color_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_ADDR(x) ((uintptr_t)(x) + 0x4F0U)

#define HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0(x) (*(__IO hw_pxp_hw_pxp_input_fetch_background_color_ch0_t *) HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0, field BACKGROUND_COLOR[31:0] (RW)
 *
 * background color(in 32bpp format) for any pixels not within the bufffer range
 * specified by the ULC/LRC
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR. */
#define BM_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR. */
#define BS_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR(x) (HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR. */
#define BF_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR) & BM_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR)

/*! @brief Set the BACKGROUND_COLOR field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_background_color_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_background_color_ch1_bitfields
    {
        uint32_t BACKGROUND_COLOR : 32; /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_background_color_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_ADDR(x) ((uintptr_t)(x) + 0x500U)

#define HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1(x) (*(__IO hw_pxp_hw_pxp_input_fetch_background_color_ch1_t *) HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1, field BACKGROUND_COLOR[31:0] (RW)
 *
 * background color(in 32bpp format) for any pixels not within the bufffer range
 * specified by the ULC/LRC
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR. */
#define BM_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR. */
#define BS_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR(x) (HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR. */
#define BF_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR) & BM_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR)

/*! @brief Set the BACKGROUND_COLOR field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_PITCH -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_PITCH -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_pitch
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_pitch_bitfields
    {
        uint32_t CH0_INPUT_PITCH : 16; /*!< [15:0]  */
        uint32_t CH1_INPUT_PITCH : 16; /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_pitch_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_PITCH register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_PITCH_ADDR(x) ((uintptr_t)(x) + 0x510U)

#define HW_PXP_HW_PXP_INPUT_FETCH_PITCH(x) (*(__IO hw_pxp_hw_pxp_input_fetch_pitch_t *) HW_PXP_HW_PXP_INPUT_FETCH_PITCH_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_PITCH_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_PITCH(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_PITCH_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_PITCH(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_PITCH_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_PITCH_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_PITCH_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_PITCH_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_PITCH_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_PITCH_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_PITCH_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_PITCH_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_PITCH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_PITCH bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_PITCH, field CH0_INPUT_PITCH[15:0] (RW)
 *
 * This field indicates the channel 0 input pitch
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH. */
#define BM_PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH. */
#define BS_PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH(x) (HW_PXP_HW_PXP_INPUT_FETCH_PITCH(x).B.CH0_INPUT_PITCH)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH. */
#define BF_PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH) & BM_PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH)

/*! @brief Set the CH0_INPUT_PITCH field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_PITCH_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_PITCH_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH) | BF_PXP_HW_PXP_INPUT_FETCH_PITCH_CH0_INPUT_PITCH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_PITCH, field CH1_INPUT_PITCH[31:16] (RW)
 *
 * This field indicates the channel 1 input pitch
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH (16U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH. */
#define BM_PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH. */
#define BS_PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH(x) (HW_PXP_HW_PXP_INPUT_FETCH_PITCH(x).B.CH1_INPUT_PITCH)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH. */
#define BF_PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH) & BM_PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH)

/*! @brief Set the CH1_INPUT_PITCH field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_PITCH_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_PITCH_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH) | BF_PXP_HW_PXP_INPUT_FETCH_PITCH_CH1_INPUT_PITCH(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0 -  (RW)
 *
 * Reset value: 0x00001000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0: 0x520
 * HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SET: 0x524 HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_CLR: 0x528
 * HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_TOG: 0x52C The Control register contains the control bits for the
 * pxp prefetch_engine sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_shift_ctrl_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_shift_ctrl_ch0_bitfields
    {
        uint32_t INPUT_ACTIVE_BPP : 2; /*!< [1:0]  */
        uint32_t RSVD1 : 6;            /*!< [7:2]  */
        uint32_t EXPAND_FORMAT : 3;    /*!< [10:8]  */
        uint32_t EXPAND_EN : 1;        /*!< [11]  */
        uint32_t SHIFT_BYPASS : 1;     /*!< [12]  */
        uint32_t RSVD0 : 19;           /*!< [31:13]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_shift_ctrl_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_ADDR(x) ((uintptr_t)(x) + 0x520U)

#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0(x) (*(__IO hw_pxp_hw_pxp_input_fetch_shift_ctrl_ch0_t *) HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0, field INPUT_ACTIVE_BPP[1:0] (RW)
 *
 * Values:
 * - 0 - 8 bits
 * - 1 - 16 bits
 * - 10 - 32 bits
 * - 11 - 32 bits
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP (0x00000003U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP (2U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP. */

#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP: 8 bits */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP: 16 bits */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP: 32 bits */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP: 32 bits */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0(x).B.INPUT_ACTIVE_BPP)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP)

/*! @brief Set the INPUT_ACTIVE_BPP field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0, field RSVD1[7:2] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD1 (2U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD1. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD1 (0x000000FCU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD1. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD1 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD1(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0, field EXPAND_FORMAT[10:8] (RW)
 *
 * Select Pixel format
 *
 * Values:
 * - 0 - RGB 565
 * - 1 - RGB 555
 * - 10 - ARGB 1555
 * - 11 - RGB 444
 * - 100 - ARGB 4444
 * - 101 - YUYV/YVYU
 * - 110 - UYVY/VYUY
 * - 111 - YUV422_2P
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT (8U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT (0x00000700U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT (3U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT. */

#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT: RGB 565 */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT: RGB 555 */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT: ARGB 1555 */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT: RGB 444 */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_4 (0x4U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT: ARGB 4444 */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_5 (0x5U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT: YUYV/YVYU */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_6 (0x6U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT: UYVY/VYUY */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_7 (0x7U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT: YUV422_2P */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0(x).B.EXPAND_FORMAT)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT)

/*! @brief Set the EXPAND_FORMAT field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0, field EXPAND_EN[11] (RW)
 *
 * Values:
 * - 0 - channel0 format expanding disable
 * - 1 - channel0 format expanding enable
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN (11U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN (0x00000800U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN. */

#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN: channel0 format expanding disable */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN: channel0 format expanding enable */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0(x).B.EXPAND_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN)

/*! @brief Set the EXPAND_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_EXPAND_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0, field SHIFT_BYPASS[12] (RW)
 *
 * Values:
 * - 0 - channel0 data will do shift function
 * - 1 - channel0 will bypass shift function
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS (12U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS (0x00001000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS. */

#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS: channel0 data will do shift function */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS: channel0 will bypass shift function */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0(x).B.SHIFT_BYPASS)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS)

/*! @brief Set the SHIFT_BYPASS field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0, field RSVD0[31:13] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD0 (13U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD0. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD0 (0xFFFFE000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD0. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD0 (19U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0_RSVD0(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1 -  (RW)
 *
 * Reset value: 0x00001000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1: 0x530
 * HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SET: 0x534 HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_CLR: 0x538
 * HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_TOG: 0x53C The Control register contains the control bits for the
 * pxp prefetch_engine sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_shift_ctrl_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_shift_ctrl_ch1_bitfields
    {
        uint32_t INPUT_ACTIVE_BPP : 2; /*!< [1:0]  */
        uint32_t RSVD1 : 6;            /*!< [7:2]  */
        uint32_t EXPAND_FORMAT : 3;    /*!< [10:8]  */
        uint32_t EXPAND_EN : 1;        /*!< [11]  */
        uint32_t SHIFT_BYPASS : 1;     /*!< [12]  */
        uint32_t RSVD0 : 19;           /*!< [31:13]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_shift_ctrl_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_ADDR(x) ((uintptr_t)(x) + 0x530U)

#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1(x) (*(__IO hw_pxp_hw_pxp_input_fetch_shift_ctrl_ch1_t *) HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1, field INPUT_ACTIVE_BPP[1:0] (RW)
 *
 * Values:
 * - 0 - 8 bits
 * - 1 - 16 bits
 * - 10 - 32 bits
 * - 11 - 32 bits
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP (0x00000003U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP (2U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP. */

#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP: 8 bits */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP: 16 bits */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP: 32 bits */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP: 32 bits */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1(x).B.INPUT_ACTIVE_BPP)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP)

/*! @brief Set the INPUT_ACTIVE_BPP field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1, field RSVD1[7:2] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD1 (2U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD1. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD1 (0x000000FCU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD1. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD1 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD1(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1, field EXPAND_FORMAT[10:8] (RW)
 *
 * Select Pixel format
 *
 * Values:
 * - 0 - RGB 565
 * - 1 - RGB 555
 * - 10 - ARGB 1555
 * - 11 - RGB 444
 * - 100 - ARGB 4444
 * - 101 - YUYV/YVYU
 * - 110 - UYVY/VYUY
 * - 111 - YUV422_2P
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT (8U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT (0x00000700U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT (3U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT. */

#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT: RGB 565 */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT: RGB 555 */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT: ARGB 1555 */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT: RGB 444 */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_4 (0x4U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT: ARGB 4444 */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_5 (0x5U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT: YUYV/YVYU */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_6 (0x6U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT: UYVY/VYUY */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_7 (0x7U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT: YUV422_2P */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1(x).B.EXPAND_FORMAT)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT)

/*! @brief Set the EXPAND_FORMAT field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1, field EXPAND_EN[11] (RW)
 *
 * Values:
 * - 0 - channel1 format expanding disable
 * - 1 - channel1 format expanding enable
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN (11U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN (0x00000800U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN. */

#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN: channel1 format expanding disable */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN: channel1 format expanding enable */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1(x).B.EXPAND_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN)

/*! @brief Set the EXPAND_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_EXPAND_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1, field SHIFT_BYPASS[12] (RW)
 *
 * Values:
 * - 0 - channel1 data will do shift function
 * - 1 - channel1 will bypass shift function
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS (12U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS (0x00001000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS. */

#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS: channel1 data will do shift function */
#define BV_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS: channel1 will bypass shift function */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1(x).B.SHIFT_BYPASS)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS)

/*! @brief Set the SHIFT_BYPASS field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1, field RSVD0[31:13] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD0 (13U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD0. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD0 (0xFFFFE000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD0. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD0 (19U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD0 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1_RSVD0(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0: 0x540
 * HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_SET: 0x544 HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_CLR: 0x548
 * HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_TOG: 0x54C The Control register contains the control bits
 * for the pxp prefetch_engine sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_shift_offset_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_shift_offset_ch0_bitfields
    {
        uint32_t OFFSET0 : 5;          /*!< [4:0]  */
        uint32_t RSVD3 : 3;            /*!< [7:5]  */
        uint32_t OFFSET1 : 5;          /*!< [12:8]  */
        uint32_t RSVD2 : 3;            /*!< [15:13]  */
        uint32_t OFFSET2 : 5;          /*!< [20:16]  */
        uint32_t RSVD1 : 3;            /*!< [23:21]  */
        uint32_t OFFSET3 : 5;          /*!< [28:24]  */
        uint32_t RSVD0 : 3;            /*!< [31:29]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_shift_offset_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_ADDR(x) ((uintptr_t)(x) + 0x540U)

#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0(x) (*(__IO hw_pxp_hw_pxp_input_fetch_shift_offset_ch0_t *) HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0, field OFFSET0[4:0] (RW)
 *
 * Shift Offset for channel 0 componnent 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0 (0x0000001FU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0 (5U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0(x).B.OFFSET0)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0)

/*! @brief Set the OFFSET0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0, field RSVD3[7:5] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD3 (5U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD3. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD3 (0x000000E0U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD3. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD3 (3U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD3 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD3(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0, field OFFSET1[12:8] (RW)
 *
 * Shift Offset for channel 0 componnent 1.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1 (8U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1 (0x00001F00U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1 (5U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0(x).B.OFFSET1)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1)

/*! @brief Set the OFFSET1 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0, field RSVD2[15:13] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD2 (13U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD2. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD2 (0x0000E000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD2. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD2 (3U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD2 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD2(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0, field OFFSET2[20:16] (RW)
 *
 * Shift Offset for channel 0 componnent 2.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2 (16U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2 (0x001F0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2 (5U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0(x).B.OFFSET2)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2)

/*! @brief Set the OFFSET2 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0, field RSVD1[23:21] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD1 (21U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD1. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD1 (0x00E00000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD1. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD1 (3U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD1 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD1(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0, field OFFSET3[28:24] (RW)
 *
 * Shift Offset for channel 0 componnent 3.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3 (24U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3 (0x1F000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3 (5U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0(x).B.OFFSET3)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3)

/*! @brief Set the OFFSET3 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_OFFSET3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0, field RSVD0[31:29] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD0 (29U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD0. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD0 (0xE0000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD0. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD0 (3U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0_RSVD0(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1: 0x550
 * HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_SET: 0x554 HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_CLR: 0x558
 * HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_TOG: 0x55C The Control register contains the control bits
 * for the pxp prefetch_engine sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_shift_offset_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_shift_offset_ch1_bitfields
    {
        uint32_t OFFSET0 : 5;          /*!< [4:0]  */
        uint32_t RSVD3 : 3;            /*!< [7:5]  */
        uint32_t OFFSET1 : 5;          /*!< [12:8]  */
        uint32_t RSVD2 : 3;            /*!< [15:13]  */
        uint32_t OFFSET2 : 5;          /*!< [20:16]  */
        uint32_t RSVD1 : 3;            /*!< [23:21]  */
        uint32_t OFFSET3 : 5;          /*!< [28:24]  */
        uint32_t RSVD0 : 3;            /*!< [31:29]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_shift_offset_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_ADDR(x) ((uintptr_t)(x) + 0x550U)

#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1(x) (*(__IO hw_pxp_hw_pxp_input_fetch_shift_offset_ch1_t *) HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1, field OFFSET0[4:0] (RW)
 *
 * Shift Offset for channel 1 componnent 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0 (0x0000001FU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0 (5U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1(x).B.OFFSET0)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0)

/*! @brief Set the OFFSET0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1, field RSVD3[7:5] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD3 (5U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD3. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD3 (0x000000E0U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD3. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD3 (3U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD3 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD3(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1, field OFFSET1[12:8] (RW)
 *
 * Shift Offset for channel 1 componnent 1.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1 (8U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1 (0x00001F00U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1 (5U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1(x).B.OFFSET1)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1)

/*! @brief Set the OFFSET1 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1, field RSVD2[15:13] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD2 (13U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD2. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD2 (0x0000E000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD2. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD2 (3U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD2 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD2(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1, field OFFSET2[20:16] (RW)
 *
 * Shift Offset for channel 1 componnent 2.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2 (16U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2 (0x001F0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2 (5U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1(x).B.OFFSET2)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2)

/*! @brief Set the OFFSET2 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1, field RSVD1[23:21] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD1 (21U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD1. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD1 (0x00E00000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD1. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD1 (3U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD1 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD1(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1, field OFFSET3[28:24] (RW)
 *
 * Shift Offset for channel 1 componnent 3.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3 (24U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3 (0x1F000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3 (5U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1(x).B.OFFSET3)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3)

/*! @brief Set the OFFSET3 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_OFFSET3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1, field RSVD0[31:29] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD0 (29U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD0. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD0 (0xE0000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD0. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD0 (3U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD0 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1_RSVD0(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0 -  (RW)
 *
 * Reset value: 0x00008888U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0: 0x560
 * HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_SET: 0x564 HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_CLR: 0x568
 * HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_TOG: 0x56C The Control register contains the control bits for
 * the pxp prefetch_engine sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_shift_width_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_shift_width_ch0_bitfields
    {
        uint32_t WIDTH0 : 4;           /*!< [3:0]  */
        uint32_t WIDTH1 : 4;           /*!< [7:4]  */
        uint32_t WIDTH2 : 4;           /*!< [11:8]  */
        uint32_t WIDTH3 : 4;           /*!< [15:12]  */
        uint32_t RSVD0 : 16;           /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_shift_width_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_ADDR(x) ((uintptr_t)(x) + 0x560U)

#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0(x) (*(__IO hw_pxp_hw_pxp_input_fetch_shift_width_ch0_t *) HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0, field WIDTH0[3:0] (RW)
 *
 * Shift Width for channel 0 componnent 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0 (0x0000000FU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0 (4U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0(x).B.WIDTH0)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0)

/*! @brief Set the WIDTH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0, field WIDTH1[7:4] (RW)
 *
 * Shift Width for channel 0 componnent 1.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1 (4U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1 (0x000000F0U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1 (4U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0(x).B.WIDTH1)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1)

/*! @brief Set the WIDTH1 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0, field WIDTH2[11:8] (RW)
 *
 * Shift Width for channel 0 componnent 2.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2 (8U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2 (0x00000F00U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2 (4U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0(x).B.WIDTH2)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2)

/*! @brief Set the WIDTH2 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0, field WIDTH3[15:12] (RW)
 *
 * Shift Width for channel 0 componnent 3.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3 (12U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3 (0x0000F000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3 (4U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0(x).B.WIDTH3)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3)

/*! @brief Set the WIDTH3 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_WIDTH3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0, field RSVD0[31:16] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RSVD0 (16U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RSVD0. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RSVD0 (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RSVD0. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RSVD0 (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0_RSVD0(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1 -  (RW)
 *
 * Reset value: 0x00008888U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1: 0x570
 * HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_SET: 0x574 HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_CLR: 0x578
 * HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_TOG: 0x57C The Control register contains the control bits for
 * the pxp prefetch_engine sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_shift_width_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_shift_width_ch1_bitfields
    {
        uint32_t WIDTH0 : 4;           /*!< [3:0]  */
        uint32_t WIDTH1 : 4;           /*!< [7:4]  */
        uint32_t WIDTH2 : 4;           /*!< [11:8]  */
        uint32_t WIDTH3 : 4;           /*!< [15:12]  */
        uint32_t RSVD0 : 16;           /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_shift_width_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_ADDR(x) ((uintptr_t)(x) + 0x570U)

#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1(x) (*(__IO hw_pxp_hw_pxp_input_fetch_shift_width_ch1_t *) HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1, field WIDTH0[3:0] (RW)
 *
 * Shift Width for channel 1 componnent 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0 (0x0000000FU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0 (4U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1(x).B.WIDTH0)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0)

/*! @brief Set the WIDTH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1, field WIDTH1[7:4] (RW)
 *
 * Shift Width for channel 1 componnent 1.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1 (4U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1 (0x000000F0U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1 (4U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1(x).B.WIDTH1)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1)

/*! @brief Set the WIDTH1 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1, field WIDTH2[11:8] (RW)
 *
 * Shift Width for channel 1 componnent 2.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2 (8U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2 (0x00000F00U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2 (4U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1(x).B.WIDTH2)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2)

/*! @brief Set the WIDTH2 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1, field WIDTH3[15:12] (RW)
 *
 * Shift Width for channel 1 componnent 3.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3 (12U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3 (0x0000F000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3 (4U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1(x).B.WIDTH3)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3. */
#define BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3) & BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3)

/*! @brief Set the WIDTH3 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3) | BF_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_WIDTH3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1, field RSVD0[31:16] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RSVD0 (16U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RSVD0. */
#define BM_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RSVD0 (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RSVD0. */
#define BS_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RSVD0 (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RSVD0 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1_RSVD0(x) (HW_PXP_HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_addr_0_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_addr_0_ch0_bitfields
    {
        uint32_t INPUT_BASE_ADDR0 : 32; /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_addr_0_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_ADDR(x) ((uintptr_t)(x) + 0x580U)

#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0(x) (*(__IO hw_pxp_hw_pxp_input_fetch_addr_0_ch0_t *) HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0, field INPUT_BASE_ADDR0[31:0] (RW)
 *
 * input base address0. For 2 channel, indicated the channel0 base address. For
 * 1 channel and YUV422 2 plane, indicate the Y base address
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0. */
#define BM_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0. */
#define BS_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0(x) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0. */
#define BF_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0) & BM_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0)

/*! @brief Set the INPUT_BASE_ADDR0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_addr_1_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_addr_1_ch0_bitfields
    {
        uint32_t INPUT_BASE_ADDR1 : 32; /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_addr_1_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_ADDR(x) ((uintptr_t)(x) + 0x590U)

#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0(x) (*(__IO hw_pxp_hw_pxp_input_fetch_addr_1_ch0_t *) HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0, field INPUT_BASE_ADDR1[31:0] (RW)
 *
 * input base address1. For 2 channel, indicated the channel1 base address. For
 * 1 channel and YUV422 2 plane, indicate the UV base address
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1. */
#define BM_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1. */
#define BS_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1(x) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1. */
#define BF_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1) & BM_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1)

/*! @brief Set the INPUT_BASE_ADDR1 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_addr_0_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_addr_0_ch1_bitfields
    {
        uint32_t INPUT_BASE_ADDR0 : 32; /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_addr_0_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_ADDR(x) ((uintptr_t)(x) + 0x5A0U)

#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1(x) (*(__IO hw_pxp_hw_pxp_input_fetch_addr_0_ch1_t *) HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1, field INPUT_BASE_ADDR0[31:0] (RW)
 *
 * input base address0. For 2 channel, indicated the channel0 base address. For
 * 1 channel and YUV422 2 plane, indicate the Y base address
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0. */
#define BM_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0. */
#define BS_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0(x) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0. */
#define BF_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0) & BM_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0)

/*! @brief Set the INPUT_BASE_ADDR0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_0_CH1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_fetch_addr_1_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_fetch_addr_1_ch1_bitfields
    {
        uint32_t INPUT_BASE_ADDR1 : 32; /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_fetch_addr_1_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_ADDR(x) ((uintptr_t)(x) + 0x5B0U)

#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1(x) (*(__IO hw_pxp_hw_pxp_input_fetch_addr_1_ch1_t *) HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_RD(x) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1(x).U)
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_WR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_SET(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_CLR(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_TOG(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_WR(x, HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1, field INPUT_BASE_ADDR1[31:0] (RW)
 *
 * input base address1. For 2 channel, indicated the channel1 base address. For
 * 1 channel and YUV422 2 plane, indicate the UV base address
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1. */
#define BM_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1. */
#define BS_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1 field. */
#define BR_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1(x) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1. */
#define BF_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1) & BM_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1)

/*! @brief Set the INPUT_BASE_ADDR1 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1(x, v) (HW_PXP_HW_PXP_INPUT_FETCH_ADDR_1_CH1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0 - Store engine Control Channel 0 Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0 - Store engine Control Channel 0 Register (RW)
 *
 * Reset value: 0x00020200U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * HW_PXP_INPUT_STORE_CTRL_CH0: 0x5C0 HW_PXP_INPUT_STORE_CTRL_CH0_SET: 0x5C4
 * HW_PXP_INPUT_STORE_CTRL_CH0_CLR: 0x5C8 HW_PXP_INPUT_STORE_CTRL_CH0_TOG: 0x5CC The
 * Control register contains the control bits for the pxp store_engine sub-block.
 * EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_ctrl_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_ctrl_ch0_bitfields
    {
        uint32_t CH_EN : 1;            /*!< [0]  */
        uint32_t BLOCK_EN : 1;         /*!< [1]  */
        uint32_t BLOCK_16 : 1;         /*!< [2]  */
        uint32_t HANDSHAKE_EN : 1;     /*!< [3]  */
        uint32_t ARRAY_EN : 1;         /*!< [4]  */
        uint32_t ARRAY_LINE_NUM : 2;   /*!< [6:5]  */
        uint32_t RSVD3 : 1;            /*!< [7]  */
        uint32_t STORE_BYPASS_EN : 1;  /*!< [8]  */
        uint32_t STORE_MEMORY_EN : 1;  /*!< [9]  */
        uint32_t PACK_IN_SEL : 1;      /*!< [10]  */
        uint32_t FILL_DATA_EN : 1;     /*!< [11]  */
        uint32_t RSVD2 : 4;            /*!< [15:12]  */
        uint32_t WR_NUM_BYTES : 2;     /*!< [17:16]  */
        uint32_t RSVD1 : 6;            /*!< [23:18]  */
        uint32_t COMBINE_2CHANNEL : 1; /*!< [24]  */
        uint32_t RSVD0 : 6;            /*!< [30:25]  */
        uint32_t ARBIT_EN : 1;         /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_input_store_ctrl_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_CTRL_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ADDR(x) ((uintptr_t)(x) + 0x5C0U)

#define HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_ctrl_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_CTRL_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH0, field CH_EN[0] (RW)
 *
 * Channel enable.
 *
 * Values:
 * - 0 - Store function is disable
 * - 1 - Store function is enable
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN (0x00000001U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN: Store function is disable */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN: Store function is enable */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x).B.CH_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN)

/*! @brief Set the CH_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_CH_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH0, field BLOCK_EN[1] (RW)
 *
 * Choses the store mode.
 *
 * Values:
 * - 0 - Store in scan mode
 * - 1 - Store in block mode
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN (1U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN (0x00000002U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN: Store in scan mode */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN: Store in block mode */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x).B.BLOCK_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN)

/*! @brief Set the BLOCK_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH0, field BLOCK_16[2] (RW)
 *
 * Determines the block sixe.
 *
 * Values:
 * - 0 - Block size is 8x8
 * - 1 - Block size is 16x16
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16 (2U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16 (0x00000004U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16_8x8 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16: Block size is 8x8 */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16_16x16 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16: Block size is 16x16 */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x).B.BLOCK_16)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16)

/*! @brief Set the BLOCK_16 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_BLOCK_16(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH0, field HANDSHAKE_EN[3] (RW)
 *
 * Enable bit for handshake with the store engine.
 *
 * Values:
 * - 0 - Handshake with the prefetch engine is disabled
 * - 1 - Handshake with the prefetch engine is enabled
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN (3U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN (0x00000008U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN: Handshake with the prefetch engine is disabled */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN: Handshake with the prefetch engine is enabled */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x).B.HANDSHAKE_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN)

/*! @brief Set the HANDSHAKE_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_HANDSHAKE_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH0, field ARRAY_EN[4] (RW)
 *
 * Values:
 * - 0 - Array Handshake Disabled
 * - 1 - Array Handshake Enabled
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN (4U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN (0x00000010U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN: Array Handshake Disabled */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN: Array Handshake Enabled */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x).B.ARRAY_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN)

/*! @brief Set the ARRAY_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH0, field ARRAY_LINE_NUM[6:5] (RW)
 *
 * Selects Array Size
 *
 * Values:
 * - 0 - Using 1x1 Array
 * - 1 - Using 3x3 Array
 * - 10 - Using 5x5 Array
 * - 11 - Using 5x5 Array
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM (5U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM (0x00000060U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM (2U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM: Using 1x1 Array */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM: Using 3x3 Array */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM: Using 5x5 Array */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM: Using 5x5 Array */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x).B.ARRAY_LINE_NUM)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM)

/*! @brief Set the ARRAY_LINE_NUM field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARRAY_LINE_NUM(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH0, field RSVD3[7] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD3 (7U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD3. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD3 (0x00000080U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD3. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD3 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD3(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH0, field STORE_BYPASS_EN[8] (RW)
 *
 * store bypass enable
 *
 * Values:
 * - 0 - store bypass mode disable.
 * - 1 - store bypass mode enable. Data will bypass to store output.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN (8U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN (0x00000100U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN: store bypass mode disable. */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN: store bypass mode enable. Data will bypass to store output. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x).B.STORE_BYPASS_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN)

/*! @brief Set the STORE_BYPASS_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_BYPASS_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH0, field STORE_MEMORY_EN[9] (RW)
 *
 * store memory enable
 *
 * Values:
 * - 0 - store memory mode disable.
 * - 1 - store memory mode enable. Data will store to memory
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN (9U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN (0x00000200U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN: store memory mode disable. */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN: store memory mode enable. Data will store to memory */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x).B.STORE_MEMORY_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN)

/*! @brief Set the STORE_MEMORY_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_STORE_MEMORY_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH0, field PACK_IN_SEL[10] (RW)
 *
 * pack_in_sel
 *
 * Values:
 * - 0 - select 64 shift out data to pack
 * - 1 - select low 32 bit shift out data to pack
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL (10U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL (0x00000400U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL: select 64 shift out data to pack */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL: select low 32 bit shift out data to pack */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x).B.PACK_IN_SEL)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL)

/*! @brief Set the PACK_IN_SEL field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_PACK_IN_SEL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH0, field FILL_DATA_EN[11] (RW)
 *
 * fill data enable
 *
 * Values:
 * - 0 - Fill data mode disable.
 * - 1 - Fill data mode enable. When using fill_data mode, store_engine will
 *     store fixed data defined in fill_data register
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN (11U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN (0x00000800U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN: Fill data mode disable. */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN: Fill data mode enable. When using fill_data mode, store_engine will store fixed data defined in fill_data register */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x).B.FILL_DATA_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN)

/*! @brief Set the FILL_DATA_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_FILL_DATA_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH0, field RSVD2[15:12] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD2 (12U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD2. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD2 (0x0000F000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD2. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD2 (4U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD2 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD2(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH0, field WR_NUM_BYTES[17:16] (RW)
 *
 * Bytes in a write burst
 *
 * Values:
 * - 0 - 8 bytes
 * - 1 - 16 bytes
 * - 10 - 32 bytes
 * - 11 - 64 bytes
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES (16U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES (0x00030000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES (2U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES_8_bytes (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES: 8 bytes */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES_16_bytes (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES: 16 bytes */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES_32_bytes (0x2U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES: 32 bytes */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES_64_bytes (0x3U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES: 64 bytes */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x).B.WR_NUM_BYTES)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES)

/*! @brief Set the WR_NUM_BYTES field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR_NUM_BYTES(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH0, field RSVD1[23:18] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD1 (18U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD1. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD1 (0x00FC0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD1. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD1 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD1(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH0, field COMBINE_2CHANNEL[24] (RW)
 *
 * Combine 2 channel Enable
 *
 * Values:
 * - 0 - combine 2 channel disable
 * - 1 - combine 2 channel enable
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL (24U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL (0x01000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL: combine 2 channel disable */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL: combine 2 channel enable */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x).B.COMBINE_2CHANNEL)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL)

/*! @brief Set the COMBINE_2CHANNEL field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_COMBINE_2CHANNEL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH0, field RSVD0[30:25] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD0 (25U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD0. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD0 (0x7E000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD0. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD0 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RSVD0(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH0, field ARBIT_EN[31] (RW)
 *
 * Arbitration Enable
 *
 * Values:
 * - 0 - Arbitration disable. If using 2 channels, will output 2 axi bus sets
 * - 1 - Arbitration enable. If using 2 channel, will only output 1 axi bus sets
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN (31U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN (0x80000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN: Arbitration disable. If using 2 channels, will output 2 axi bus sets */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN: Arbitration enable. If using 2 channel, will only output 1 axi bus sets */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0(x).B.ARBIT_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN)

/*! @brief Set the ARBIT_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH0_ARBIT_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1 - Store engine Control Channel 1 Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1 - Store engine Control Channel 1 Register (RW)
 *
 * Reset value: 0x00020200U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * HW_PXP_INPUT_STORE_CTRL_CH1: 0x5D0 HW_PXP_INPUT_STORE_CTRL_CH1_SET: 0x5D4
 * HW_PXP_INPUT_STORE_CTRL_CH1_CLR: 0x5D8 HW_PXP_INPUT_STORE_CTRL_CH1_TOG: 0x5DC The
 * Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_ctrl_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_ctrl_ch1_bitfields
    {
        uint32_t CH_EN : 1;            /*!< [0]  */
        uint32_t BLOCK_EN : 1;         /*!< [1]  */
        uint32_t BLOCK_16 : 1;         /*!< [2]  */
        uint32_t HANDSHAKE_EN : 1;     /*!< [3]  */
        uint32_t ARRAY_EN : 1;         /*!< [4]  */
        uint32_t ARRAY_LINE_NUM : 2;   /*!< [6:5]  */
        uint32_t RSVD3 : 1;            /*!< [7]  */
        uint32_t STORE_BYPASS_EN : 1;  /*!< [8]  */
        uint32_t STORE_MEMORY_EN : 1;  /*!< [9]  */
        uint32_t PACK_IN_SEL : 1;      /*!< [10]  */
        uint32_t RSVD1 : 5;            /*!< [15:11]  */
        uint32_t WR_NUM_BYTES : 2;     /*!< [17:16]  */
        uint32_t RSVD0 : 14;           /*!< [31:18]  */
    } B;
} hw_pxp_hw_pxp_input_store_ctrl_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_CTRL_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ADDR(x) ((uintptr_t)(x) + 0x5D0U)

#define HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1(x) (*(__IO hw_pxp_hw_pxp_input_store_ctrl_ch1_t *) HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR(x, HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR(x, HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR(x, HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_CTRL_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH1, field CH_EN[0] (RW)
 *
 * Channel enable.
 *
 * Values:
 * - 0 - Store function is disable
 * - 1 - Store function is enable
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN (0x00000001U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN: Store function is disable */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN: Store function is enable */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1(x).B.CH_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN)

/*! @brief Set the CH_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_CH_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH1, field BLOCK_EN[1] (RW)
 *
 * Choses the store mode.
 *
 * Values:
 * - 0 - Store in scan mode
 * - 1 - Store in block mode
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN (1U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN (0x00000002U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN: Store in scan mode */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN: Store in block mode */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1(x).B.BLOCK_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN)

/*! @brief Set the BLOCK_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH1, field BLOCK_16[2] (RW)
 *
 * Determines the block sixe.
 *
 * Values:
 * - 0 - Block size is 8x8
 * - 1 - Block size is 16x16
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16 (2U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16 (0x00000004U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16_8x8 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16: Block size is 8x8 */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16_16x16 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16: Block size is 16x16 */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1(x).B.BLOCK_16)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16)

/*! @brief Set the BLOCK_16 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_BLOCK_16(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH1, field HANDSHAKE_EN[3] (RW)
 *
 * Enable bit for handshake with the fetch engine.
 *
 * Values:
 * - 0 - Handshake with the fetch engine is disabled
 * - 1 - Handshake with the fetch engine is enabled
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN (3U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN (0x00000008U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN: Handshake with the fetch engine is disabled */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN: Handshake with the fetch engine is enabled */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1(x).B.HANDSHAKE_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN)

/*! @brief Set the HANDSHAKE_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_HANDSHAKE_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH1, field ARRAY_EN[4] (RW)
 *
 * Values:
 * - 0 - Array Handshake Disabled
 * - 1 - Array Handshake Enabled
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN (4U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN (0x00000010U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN: Array Handshake Disabled */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN: Array Handshake Enabled */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1(x).B.ARRAY_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN)

/*! @brief Set the ARRAY_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH1, field ARRAY_LINE_NUM[6:5] (RW)
 *
 * Selects Array Size
 *
 * Values:
 * - 0 - Using 1x1 Array
 * - 1 - Using 3x3 Array
 * - 10 - Using 5x5 Array
 * - 11 - Using 5x5 Array
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM (5U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM (0x00000060U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM (2U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM: Using 1x1 Array */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM: Using 3x3 Array */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM: Using 5x5 Array */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM: Using 5x5 Array */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1(x).B.ARRAY_LINE_NUM)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM)

/*! @brief Set the ARRAY_LINE_NUM field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_ARRAY_LINE_NUM(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH1, field RSVD3[7] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD3 (7U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD3. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD3 (0x00000080U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD3. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD3 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD3(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH1, field STORE_BYPASS_EN[8] (RW)
 *
 * enable bit for store bypass
 *
 * Values:
 * - 0 - store bypass mode disable.
 * - 1 - store bypass mode enable. Data will bypass to store output.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN (8U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN (0x00000100U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN: store bypass mode disable. */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN: store bypass mode enable. Data will bypass to store output. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1(x).B.STORE_BYPASS_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN)

/*! @brief Set the STORE_BYPASS_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_BYPASS_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH1, field STORE_MEMORY_EN[9] (RW)
 *
 * store memory enable
 *
 * Values:
 * - 0 - store memory mode disable.
 * - 1 - store memory mode enable. Data will store to memory.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN (9U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN (0x00000200U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN: store memory mode disable. */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN: store memory mode enable. Data will store to memory. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1(x).B.STORE_MEMORY_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN)

/*! @brief Set the STORE_MEMORY_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_STORE_MEMORY_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH1, field PACK_IN_SEL[10] (RW)
 *
 * pack_in_sel
 *
 * Values:
 * - 0 - select 64 shift out data to pack
 * - 1 - select channel 0 high 32 bit shift out data to pack
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL (10U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL (0x00000400U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL: select 64 shift out data to pack */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL: select channel 0 high 32 bit shift out data to pack */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1(x).B.PACK_IN_SEL)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL)

/*! @brief Set the PACK_IN_SEL field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_PACK_IN_SEL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH1, field RSVD1[15:11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD1 (11U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD1. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD1 (0x0000F800U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD1. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD1 (5U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD1 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD1(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH1, field WR_NUM_BYTES[17:16] (RW)
 *
 * Bytes in a write burst
 *
 * Values:
 * - 0 - 8 bytes
 * - 1 - 16 bytes
 * - 10 - 32 bytes
 * - 11 - 64 bytes
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES (16U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES (0x00030000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES (2U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES. */

#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES_8_bytes (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES: 8 bytes */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES_16_bytes (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES: 16 bytes */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES_32_bytes (0x2U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES: 32 bytes */
#define BV_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES_64_bytes (0x3U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES: 64 bytes */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1(x).B.WR_NUM_BYTES)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES. */
#define BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES) & BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES)

/*! @brief Set the WR_NUM_BYTES field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES(x, v) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES) | BF_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_WR_NUM_BYTES(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_CTRL_CH1, field RSVD0[31:18] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD0 (18U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD0. */
#define BM_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD0 (0xFFFC0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD0. */
#define BS_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD0 (14U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_CTRL_CH1_RSVD0(x) (HW_PXP_HW_PXP_INPUT_STORE_CTRL_CH1(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH0 - Store engine status Channel 0 Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH0 - Store engine status Channel 0 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the status bits for the pxp store_engine sub-block. The
 * Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_status_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_status_ch0_bitfields
    {
        uint32_t STORE_BLOCK_X : 16;   /*!< [15:0]  */
        uint32_t STORE_BLOCK_Y : 16;   /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_input_store_status_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_STATUS_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH0_ADDR(x) ((uintptr_t)(x) + 0x5E0U)

#define HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH0(x) (*(__I hw_pxp_hw_pxp_input_store_status_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH0(x).U)
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_STATUS_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_STATUS_CH0, field STORE_BLOCK_X[15:0] (RO)
 *
 * When in scan mode, this field is always 0. In block mode, it indicates the X
 * coordinate of the block currently being rendered.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_X (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_X. */
#define BM_PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_X (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_X. */
#define BS_PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_X (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_X. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_X field. */
#define BR_PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_X(x) (HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH0(x).B.STORE_BLOCK_X)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_STATUS_CH0, field STORE_BLOCK_Y[31:16] (RO)
 *
 * When in scan mode, this field indicates the current Y coordinate of the
 * frame. In block mode, it indicates the Y coordinate of the block currently being
 * rendered.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_Y (16U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_Y. */
#define BM_PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_Y (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_Y. */
#define BS_PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_Y (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_Y. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_Y field. */
#define BR_PXP_HW_PXP_INPUT_STORE_STATUS_CH0_STORE_BLOCK_Y(x) (HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH0(x).B.STORE_BLOCK_Y)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH1 - Store engine status Channel 1 Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH1 - Store engine status Channel 1 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the status bits for the pxp store_engine sub-block. The
 * Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_status_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_status_ch1_bitfields
    {
        uint32_t STORE_BLOCK_X : 16;   /*!< [15:0]  */
        uint32_t STORE_BLOCK_Y : 16;   /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_input_store_status_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_STATUS_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH1_ADDR(x) ((uintptr_t)(x) + 0x5F0U)

#define HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH1(x) (*(__I hw_pxp_hw_pxp_input_store_status_ch1_t *) HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH1_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH1_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH1(x).U)
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_STATUS_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_STATUS_CH1, field STORE_BLOCK_X[15:0] (RO)
 *
 * When in scan mode, this field is always 0. In block mode, it indicates the X
 * coordinate of the block currently being rendered.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_X (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_X. */
#define BM_PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_X (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_X. */
#define BS_PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_X (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_X. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_X field. */
#define BR_PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_X(x) (HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH1(x).B.STORE_BLOCK_X)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_STATUS_CH1, field STORE_BLOCK_Y[31:16] (RO)
 *
 * When in scan mode, this field indicates the current Y coordinate of the
 * frame. In block mode, it indicates the Y coordinate of the block currently being
 * rendered.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_Y (16U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_Y. */
#define BM_PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_Y (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_Y. */
#define BS_PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_Y (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_Y. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_Y field. */
#define BR_PXP_HW_PXP_INPUT_STORE_STATUS_CH1_STORE_BLOCK_Y(x) (HW_PXP_HW_PXP_INPUT_STORE_STATUS_CH1(x).B.STORE_BLOCK_Y)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_size_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_size_ch0_bitfields
    {
        uint32_t OUT_WIDTH : 16;       /*!< [15:0]  */
        uint32_t OUT_HEIGHT : 16;      /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_input_store_size_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_SIZE_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_ADDR(x) ((uintptr_t)(x) + 0x600U)

#define HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_size_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_SIZE_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_SIZE_CH0, field OUT_WIDTH[15:0] (RW)
 *
 * actual output width -1
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH. */
#define BM_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH. */
#define BS_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH field. */
#define BR_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH(x) (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0(x).B.OUT_WIDTH)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH. */
#define BF_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH) & BM_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH)

/*! @brief Set the OUT_WIDTH field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH) | BF_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_WIDTH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_SIZE_CH0, field OUT_HEIGHT[31:16] (RW)
 *
 * actual output height -1
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT (16U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT. */
#define BM_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT. */
#define BS_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT field. */
#define BR_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT(x) (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0(x).B.OUT_HEIGHT)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT. */
#define BF_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT) & BM_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT)

/*! @brief Set the OUT_HEIGHT field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT) | BF_PXP_HW_PXP_INPUT_STORE_SIZE_CH0_OUT_HEIGHT(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_size_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_size_ch1_bitfields
    {
        uint32_t OUT_WIDTH : 16;       /*!< [15:0]  */
        uint32_t OUT_HEIGHT : 16;      /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_input_store_size_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_SIZE_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_ADDR(x) ((uintptr_t)(x) + 0x610U)

#define HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1(x) (*(__IO hw_pxp_hw_pxp_input_store_size_ch1_t *) HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_WR(x, HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_WR(x, HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_WR(x, HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_SIZE_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_SIZE_CH1, field OUT_WIDTH[15:0] (RW)
 *
 * actual output width -1
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH. */
#define BM_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH. */
#define BS_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH field. */
#define BR_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH(x) (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1(x).B.OUT_WIDTH)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH. */
#define BF_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH) & BM_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH)

/*! @brief Set the OUT_WIDTH field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH) | BF_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_WIDTH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_SIZE_CH1, field OUT_HEIGHT[31:16] (RW)
 *
 * actual output height -1
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT (16U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT. */
#define BM_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT. */
#define BS_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT field. */
#define BR_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT(x) (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1(x).B.OUT_HEIGHT)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT. */
#define BF_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT) & BM_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT)

/*! @brief Set the OUT_HEIGHT field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT) | BF_PXP_HW_PXP_INPUT_STORE_SIZE_CH1_OUT_HEIGHT(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_PITCH -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_PITCH -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_pitch
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_pitch_bitfields
    {
        uint32_t CH0_OUT_PITCH : 16;   /*!< [15:0]  */
        uint32_t CH1_OUT_PITCH : 16;   /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_input_store_pitch_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_PITCH register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_PITCH_ADDR(x) ((uintptr_t)(x) + 0x620U)

#define HW_PXP_HW_PXP_INPUT_STORE_PITCH(x) (*(__IO hw_pxp_hw_pxp_input_store_pitch_t *) HW_PXP_HW_PXP_INPUT_STORE_PITCH_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_PITCH_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_PITCH(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_PITCH_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_PITCH(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_PITCH_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_PITCH_WR(x, HW_PXP_HW_PXP_INPUT_STORE_PITCH_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_PITCH_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_PITCH_WR(x, HW_PXP_HW_PXP_INPUT_STORE_PITCH_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_PITCH_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_PITCH_WR(x, HW_PXP_HW_PXP_INPUT_STORE_PITCH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_PITCH bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_PITCH, field CH0_OUT_PITCH[15:0] (RW)
 *
 * This field indicates the channel 0 input pitch
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH. */
#define BM_PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH. */
#define BS_PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH field. */
#define BR_PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH(x) (HW_PXP_HW_PXP_INPUT_STORE_PITCH(x).B.CH0_OUT_PITCH)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH. */
#define BF_PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH) & BM_PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH)

/*! @brief Set the CH0_OUT_PITCH field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH(x, v) (HW_PXP_HW_PXP_INPUT_STORE_PITCH_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_PITCH_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH) | BF_PXP_HW_PXP_INPUT_STORE_PITCH_CH0_OUT_PITCH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_PITCH, field CH1_OUT_PITCH[31:16] (RW)
 *
 * This field indicates the channel 1 input pitch
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH (16U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH. */
#define BM_PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH. */
#define BS_PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH (16U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH field. */
#define BR_PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH(x) (HW_PXP_HW_PXP_INPUT_STORE_PITCH(x).B.CH1_OUT_PITCH)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH. */
#define BF_PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH) & BM_PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH)

/*! @brief Set the CH1_OUT_PITCH field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH(x, v) (HW_PXP_HW_PXP_INPUT_STORE_PITCH_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_PITCH_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH) | BF_PXP_HW_PXP_INPUT_STORE_PITCH_CH1_OUT_PITCH(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0: 0x630 HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SET:
 * 0x634 HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_CLR: 0x638
 * HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_TOG: 0x63C The Control register contains the control bits for the pxp
 * store_engine sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_shift_ctrl_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_shift_ctrl_ch0_bitfields
    {
        uint32_t RSVD2 : 2;            /*!< [1:0]  */
        uint32_t OUTPUT_ACTIVE_BPP : 2; /*!< [3:2]  */
        uint32_t OUT_YUV422_1P_EN : 1; /*!< [4]  */
        uint32_t OUT_YUV422_2P_EN : 1; /*!< [5]  */
        uint32_t RSVD1 : 1;            /*!< [6]  */
        uint32_t SHIFT_BYPASS : 1;     /*!< [7]  */
        uint32_t RSVD0 : 24;           /*!< [31:8]  */
    } B;
} hw_pxp_hw_pxp_input_store_shift_ctrl_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_ADDR(x) ((uintptr_t)(x) + 0x630U)

#define HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_shift_ctrl_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0, field RSVD2[1:0] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD2 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD2. */
#define BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD2 (0x00000003U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD2. */
#define BS_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD2 (2U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD2 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD2(x) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0, field OUTPUT_ACTIVE_BPP[3:2] (RW)
 *
 * Values:
 * - 0 - 8 bits
 * - 1 - 16 bits
 * - 10 - 32 bits
 * - 11 - 32 bits
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP (2U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP. */
#define BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP (0x0000000CU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP. */
#define BS_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP (2U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP. */

#define BV_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP: 8 bits */
#define BV_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP: 16 bits */
#define BV_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP: 32 bits */
#define BV_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP: 32 bits */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP field. */
#define BR_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP(x) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0(x).B.OUTPUT_ACTIVE_BPP)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP. */
#define BF_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP) & BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP)

/*! @brief Set the OUTPUT_ACTIVE_BPP field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP) | BF_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0, field OUT_YUV422_1P_EN[4] (RW)
 *
 * Enable for YUV422 1 plane
 *
 * Values:
 * - 0 - YUYV422 2 plane disabled.
 * - 1 - YUYV422 2 plane enabled.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN (4U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN. */
#define BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN (0x00000010U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN. */
#define BS_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN. */

#define BV_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN: YUYV422 2 plane disabled. */
#define BV_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN: YUYV422 2 plane enabled. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN field. */
#define BR_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN(x) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0(x).B.OUT_YUV422_1P_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN. */
#define BF_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN) & BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN)

/*! @brief Set the OUT_YUV422_1P_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN) | BF_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0, field OUT_YUV422_2P_EN[5] (RW)
 *
 * Enable for YUV422 2 plane
 *
 * Values:
 * - 0 - YUYV422 2 plane disabled.
 * - 1 - YUYV422 2 plane enabled.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN (5U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN. */
#define BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN (0x00000020U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN. */
#define BS_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN. */

#define BV_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN: YUYV422 2 plane disabled. */
#define BV_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN: YUYV422 2 plane enabled. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN field. */
#define BR_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN(x) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0(x).B.OUT_YUV422_2P_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN. */
#define BF_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN) & BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN)

/*! @brief Set the OUT_YUV422_2P_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN) | BF_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0, field RSVD1[6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD1 (6U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD1. */
#define BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD1 (0x00000040U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD1. */
#define BS_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD1 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD1(x) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0, field SHIFT_BYPASS[7] (RW)
 *
 * CH0 shift bypass
 *
 * Values:
 * - 0 - data will do shift processing.
 * - 1 - data will bypass shift module.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS (7U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS. */
#define BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS (0x00000080U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS. */
#define BS_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS. */

#define BV_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS: data will do shift processing. */
#define BV_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS: data will bypass shift module. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS field. */
#define BR_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS(x) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0(x).B.SHIFT_BYPASS)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS. */
#define BF_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS) & BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS)

/*! @brief Set the SHIFT_BYPASS field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS) | BF_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0, field RSVD0[31:8] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD0 (8U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD0. */
#define BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD0 (0xFFFFFF00U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD0. */
#define BS_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD0 (24U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0_RSVD0(x) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1: 0x640 HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_SET:
 * 0x644 HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_CLR: 0x648
 * HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_TOG: 0x64C The Control register contains the control bits for the pxp
 * prefetch_engine sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_shift_ctrl_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_shift_ctrl_ch1_bitfields
    {
        uint32_t RSVD2 : 2;            /*!< [1:0]  */
        uint32_t OUTPUT_ACTIVE_BPP : 2; /*!< [3:2]  */
        uint32_t OUT_YUV422_1P_EN : 1; /*!< [4]  */
        uint32_t OUT_YUV422_2P_EN : 1; /*!< [5]  */
        uint32_t RSVD0 : 26;           /*!< [31:6]  */
    } B;
} hw_pxp_hw_pxp_input_store_shift_ctrl_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_ADDR(x) ((uintptr_t)(x) + 0x640U)

#define HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1(x) (*(__IO hw_pxp_hw_pxp_input_store_shift_ctrl_ch1_t *) HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_WR(x, HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_WR(x, HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_WR(x, HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1, field RSVD2[1:0] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD2 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD2. */
#define BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD2 (0x00000003U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD2. */
#define BS_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD2 (2U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD2 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD2(x) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1, field OUTPUT_ACTIVE_BPP[3:2] (RW)
 *
 * Values:
 * - 0 - 8 bits
 * - 1 - 16 bits
 * - 10 - 32 bits
 * - 11 - 32 bits
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP (2U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP. */
#define BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP (0x0000000CU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP. */
#define BS_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP (2U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP. */

#define BV_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP: 8 bits */
#define BV_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP: 16 bits */
#define BV_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP: 32 bits */
#define BV_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP: 32 bits */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP field. */
#define BR_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP(x) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1(x).B.OUTPUT_ACTIVE_BPP)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP. */
#define BF_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP) & BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP)

/*! @brief Set the OUTPUT_ACTIVE_BPP field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP) | BF_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1, field OUT_YUV422_1P_EN[4] (RW)
 *
 * Enable for YUV422 1 plane
 *
 * Values:
 * - 0 - YUYV422 2 plane disabled.
 * - 1 - YUYV422 2 plane enabled.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN (4U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN. */
#define BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN (0x00000010U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN. */
#define BS_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN. */

#define BV_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN: YUYV422 2 plane disabled. */
#define BV_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN: YUYV422 2 plane enabled. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN field. */
#define BR_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN(x) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1(x).B.OUT_YUV422_1P_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN. */
#define BF_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN) & BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN)

/*! @brief Set the OUT_YUV422_1P_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN) | BF_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1, field OUT_YUV422_2P_EN[5] (RW)
 *
 * Enable for YUV422 2 plane
 *
 * Values:
 * - 0 - YUYV422 2 plane disabled.
 * - 1 - YUYV422 2 plane enabled.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN (5U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN. */
#define BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN (0x00000020U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN. */
#define BS_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN. */

#define BV_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN: YUYV422 2 plane disabled. */
#define BV_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN: YUYV422 2 plane enabled. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN field. */
#define BR_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN(x) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1(x).B.OUT_YUV422_2P_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN. */
#define BF_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN) & BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN)

/*! @brief Set the OUT_YUV422_2P_EN field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN(x, v) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN) | BF_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1, field RSVD0[31:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD0 (6U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD0. */
#define BM_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD0 (0xFFFFFFC0U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD0. */
#define BS_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD0 (26U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1_RSVD0(x) (HW_PXP_HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_addr_0_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_addr_0_ch0_bitfields
    {
        uint32_t OUT_BASE_ADDR0 : 32;  /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_addr_0_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_ADDR(x) ((uintptr_t)(x) + 0x690U)

#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_addr_0_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0, field OUT_BASE_ADDR0[31:0] (RW)
 *
 * input base address0. For 2 channel, indicated the channel0 base address. For
 * 1 channel and YUV422 2 plane, indicate the Y base address
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_OUT_BASE_ADDR0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_OUT_BASE_ADDR0. */
#define BM_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_OUT_BASE_ADDR0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_OUT_BASE_ADDR0. */
#define BS_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_OUT_BASE_ADDR0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_OUT_BASE_ADDR0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_OUT_BASE_ADDR0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_OUT_BASE_ADDR0(x) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_OUT_BASE_ADDR0. */
#define BF_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_OUT_BASE_ADDR0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_OUT_BASE_ADDR0) & BM_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_OUT_BASE_ADDR0)

/*! @brief Set the OUT_BASE_ADDR0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_OUT_BASE_ADDR0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_addr_1_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_addr_1_ch0_bitfields
    {
        uint32_t OUT_BASE_ADDR1 : 32;  /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_addr_1_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_ADDR(x) ((uintptr_t)(x) + 0x6A0U)

#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_addr_1_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0, field OUT_BASE_ADDR1[31:0] (RW)
 *
 * input base address1. For 2 channel, indicated the channel 1 base address. For
 * 1 channel and YUV422 2 plane, indicate the UV base address
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_OUT_BASE_ADDR1 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_OUT_BASE_ADDR1. */
#define BM_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_OUT_BASE_ADDR1 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_OUT_BASE_ADDR1. */
#define BS_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_OUT_BASE_ADDR1 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_OUT_BASE_ADDR1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_OUT_BASE_ADDR1 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_OUT_BASE_ADDR1(x) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_OUT_BASE_ADDR1. */
#define BF_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_OUT_BASE_ADDR1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_OUT_BASE_ADDR1) & BM_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_OUT_BASE_ADDR1)

/*! @brief Set the OUT_BASE_ADDR1 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_OUT_BASE_ADDR1(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_fill_data_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_fill_data_ch0_bitfields
    {
        uint32_t FILL_DATA_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_fill_data_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_ADDR(x) ((uintptr_t)(x) + 0x6B0U)

#define HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_fill_data_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0, field FILL_DATA_CH0[31:0] (RW)
 *
 * when using fill_data mode,store engine channel0 will store the fill_data
 * value defined here.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_FILL_DATA_CH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_FILL_DATA_CH0. */
#define BM_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_FILL_DATA_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_FILL_DATA_CH0. */
#define BS_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_FILL_DATA_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_FILL_DATA_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_FILL_DATA_CH0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_FILL_DATA_CH0(x) (HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_FILL_DATA_CH0. */
#define BF_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_FILL_DATA_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_FILL_DATA_CH0) & BM_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_FILL_DATA_CH0)

/*! @brief Set the FILL_DATA_CH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_FILL_DATA_CH0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_FILL_DATA_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_addr_0_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_addr_0_ch1_bitfields
    {
        uint32_t OUT_BASE_ADDR0 : 32;  /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_addr_0_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_ADDR(x) ((uintptr_t)(x) + 0x6C0U)

#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1(x) (*(__IO hw_pxp_hw_pxp_input_store_addr_0_ch1_t *) HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_WR(x, HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_WR(x, HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_WR(x, HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1, field OUT_BASE_ADDR0[31:0] (RW)
 *
 * input base address0. For 2 channel, indicated the channel0 base address. For
 * 1 channel and YUV422 2 plane, indicate the Y base address
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_OUT_BASE_ADDR0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_OUT_BASE_ADDR0. */
#define BM_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_OUT_BASE_ADDR0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_OUT_BASE_ADDR0. */
#define BS_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_OUT_BASE_ADDR0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_OUT_BASE_ADDR0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_OUT_BASE_ADDR0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_OUT_BASE_ADDR0(x) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_OUT_BASE_ADDR0. */
#define BF_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_OUT_BASE_ADDR0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_OUT_BASE_ADDR0) & BM_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_OUT_BASE_ADDR0)

/*! @brief Set the OUT_BASE_ADDR0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_OUT_BASE_ADDR0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_0_CH1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_addr_1_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_addr_1_ch1_bitfields
    {
        uint32_t OUT_BASE_ADDR1 : 32;  /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_addr_1_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_ADDR(x) ((uintptr_t)(x) + 0x6D0U)

#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1(x) (*(__IO hw_pxp_hw_pxp_input_store_addr_1_ch1_t *) HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_WR(x, HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_WR(x, HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_WR(x, HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1, field OUT_BASE_ADDR1[31:0] (RW)
 *
 * input base address1. For 2 channel, indicated the channel 1 base address. For
 * 1 channel and YUV422 2 plane, indicate the UV base address
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_OUT_BASE_ADDR1 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_OUT_BASE_ADDR1. */
#define BM_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_OUT_BASE_ADDR1 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_OUT_BASE_ADDR1. */
#define BS_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_OUT_BASE_ADDR1 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_OUT_BASE_ADDR1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_OUT_BASE_ADDR1 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_OUT_BASE_ADDR1(x) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_OUT_BASE_ADDR1. */
#define BF_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_OUT_BASE_ADDR1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_OUT_BASE_ADDR1) & BM_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_OUT_BASE_ADDR1)

/*! @brief Set the OUT_BASE_ADDR1 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_OUT_BASE_ADDR1(x, v) (HW_PXP_HW_PXP_INPUT_STORE_ADDR_1_CH1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_d_mask0_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_d_mask0_h_ch0_bitfields
    {
        uint32_t D_MASK0_H_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_d_mask0_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_ADDR(x) ((uintptr_t)(x) + 0x6E0U)

#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_d_mask0_h_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0, field D_MASK0_H_CH0[31:0] (RW)
 *
 * data mask0 high byte
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0) & BM_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0)

/*! @brief Set the D_MASK0_H_CH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_H_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_d_mask0_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_d_mask0_l_ch0_bitfields
    {
        uint32_t D_MASK0_L_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_d_mask0_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_ADDR(x) ((uintptr_t)(x) + 0x6F0U)

#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_d_mask0_l_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0, field D_MASK0_L_CH0[31:0] (RW)
 *
 * data mask0 low byte
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0) & BM_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0)

/*! @brief Set the D_MASK0_L_CH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK0_L_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_d_mask1_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_d_mask1_h_ch0_bitfields
    {
        uint32_t D_MASK1_H_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_d_mask1_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_ADDR(x) ((uintptr_t)(x) + 0x700U)

#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_d_mask1_h_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0, field D_MASK1_H_CH0[31:0] (RW)
 *
 * data mask1 high byte
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0) & BM_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0)

/*! @brief Set the D_MASK1_H_CH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_H_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_d_mask1_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_d_mask1_l_ch0_bitfields
    {
        uint32_t D_MASK1_L_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_d_mask1_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_ADDR(x) ((uintptr_t)(x) + 0x710U)

#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_d_mask1_l_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0, field D_MASK1_L_CH0[31:0] (RW)
 *
 * data mask1 low byte
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0) & BM_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0)

/*! @brief Set the D_MASK1_L_CH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK1_L_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_d_mask2_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_d_mask2_h_ch0_bitfields
    {
        uint32_t D_MASK2_H_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_d_mask2_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_ADDR(x) ((uintptr_t)(x) + 0x720U)

#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_d_mask2_h_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0, field D_MASK2_H_CH0[31:0] (RW)
 *
 * data mask2 high byte
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0) & BM_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0)

/*! @brief Set the D_MASK2_H_CH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_H_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_d_mask2_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_d_mask2_l_ch0_bitfields
    {
        uint32_t D_MASK2_L_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_d_mask2_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_ADDR(x) ((uintptr_t)(x) + 0x730U)

#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_d_mask2_l_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0, field D_MASK2_L_CH0[31:0] (RW)
 *
 * data mask2 low byte
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0) & BM_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0)

/*! @brief Set the D_MASK2_L_CH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK2_L_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_d_mask3_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_d_mask3_h_ch0_bitfields
    {
        uint32_t D_MASK3_H_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_d_mask3_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_ADDR(x) ((uintptr_t)(x) + 0x740U)

#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_d_mask3_h_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0, field D_MASK3_H_CH0[31:0] (RW)
 *
 * data mask3 high byte
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0) & BM_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0)

/*! @brief Set the D_MASK3_H_CH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_H_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_d_mask3_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_d_mask3_l_ch0_bitfields
    {
        uint32_t D_MASK3_L_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_d_mask3_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_ADDR(x) ((uintptr_t)(x) + 0x750U)

#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_d_mask3_l_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0, field D_MASK3_L_CH0[31:0] (RW)
 *
 * data mask3 low byte
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0) & BM_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0)

/*! @brief Set the D_MASK3_L_CH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK3_L_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_d_mask4_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_d_mask4_h_ch0_bitfields
    {
        uint32_t D_MASK4_H_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_d_mask4_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_ADDR(x) ((uintptr_t)(x) + 0x760U)

#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_d_mask4_h_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0, field D_MASK4_H_CH0[31:0] (RW)
 *
 * data mask4 high byte
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0) & BM_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0)

/*! @brief Set the D_MASK4_H_CH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_H_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_d_mask4_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_d_mask4_l_ch0_bitfields
    {
        uint32_t D_MASK4_L_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_d_mask4_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_ADDR(x) ((uintptr_t)(x) + 0x770U)

#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_d_mask4_l_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0, field D_MASK4_L_CH0[31:0] (RW)
 *
 * data mask4 low byte
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0) & BM_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0)

/*! @brief Set the D_MASK4_L_CH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK4_L_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_d_mask5_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_d_mask5_h_ch0_bitfields
    {
        uint32_t D_MASK5_H_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_d_mask5_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_ADDR(x) ((uintptr_t)(x) + 0x780U)

#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_d_mask5_h_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0, field D_MASK5_H_CH0[31:0] (RW)
 *
 * data mask5 high byte
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0) & BM_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0)

/*! @brief Set the D_MASK5_H_CH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_H_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_d_mask5_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_d_mask5_l_ch0_bitfields
    {
        uint32_t D_MASK5_L_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_d_mask5_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_ADDR(x) ((uintptr_t)(x) + 0x790U)

#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_d_mask5_l_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0, field D_MASK5_L_CH0[31:0] (RW)
 *
 * data mask5 low byte
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0) & BM_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0)

/*! @brief Set the D_MASK5_L_CH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK5_L_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_d_mask6_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_d_mask6_h_ch0_bitfields
    {
        uint32_t D_MASK6_H_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_d_mask6_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_ADDR(x) ((uintptr_t)(x) + 0x7A0U)

#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_d_mask6_h_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0, field D_MASK6_H_CH0[31:0] (RW)
 *
 * data mask6 high byte
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0) & BM_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0)

/*! @brief Set the D_MASK6_H_CH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_H_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_d_mask6_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_d_mask6_l_ch0_bitfields
    {
        uint32_t D_MASK6_L_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_d_mask6_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_ADDR(x) ((uintptr_t)(x) + 0x7B0U)

#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_d_mask6_l_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0, field D_MASK6_L_CH0[31:0] (RW)
 *
 * data mask6 low byte
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0) & BM_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0)

/*! @brief Set the D_MASK6_L_CH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK6_L_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_d_mask7_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_d_mask7_h_ch0_bitfields
    {
        uint32_t D_MASK7_H_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_d_mask7_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_ADDR(x) ((uintptr_t)(x) + 0x7C0U)

#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_d_mask7_h_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0, field D_MASK7_H_CH0[31:0] (RW)
 *
 * data mask7 high byte
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0) & BM_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0)

/*! @brief Set the D_MASK7_H_CH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_H_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_d_mask7_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_d_mask7_l_ch0_bitfields
    {
        uint32_t D_MASK7_L_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_input_store_d_mask7_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_ADDR(x) ((uintptr_t)(x) + 0x7E0U)

#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_d_mask7_l_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0, field D_MASK7_L_CH0[31:0] (RW)
 *
 * data mask7 low byte
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0) & BM_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0)

/*! @brief Set the D_MASK7_L_CH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_MASK7_L_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_d_shift_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_d_shift_l_ch0_bitfields
    {
        uint32_t D_SHIFT_WIDTH0 : 6;   /*!< [5:0]  */
        uint32_t RSVD3 : 1;            /*!< [6]  */
        uint32_t D_SHIFT_FLAG0 : 1;    /*!< [7]  */
        uint32_t D_SHIFT_WIDTH1 : 6;   /*!< [13:8]  */
        uint32_t RSVD2 : 1;            /*!< [14]  */
        uint32_t D_SHIFT_FLAG1 : 1;    /*!< [15]  */
        uint32_t D_SHIFT_WIDTH2 : 6;   /*!< [21:16]  */
        uint32_t RSVD1 : 1;            /*!< [22]  */
        uint32_t D_SHIFT_FLAG2 : 1;    /*!< [23]  */
        uint32_t D_SHIFT_WIDTH3 : 6;   /*!< [29:24]  */
        uint32_t RSVD0 : 1;            /*!< [30]  */
        uint32_t D_SHIFT_FLAG3 : 1;    /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_input_store_d_shift_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_ADDR(x) ((uintptr_t)(x) + 0x7F0U)

#define HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_d_shift_l_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0, field D_SHIFT_WIDTH0[5:0] (RW)
 *
 * data shift width 0
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0(x).B.D_SHIFT_WIDTH0)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0) & BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0)

/*! @brief Set the D_SHIFT_WIDTH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0) | BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0, field RSVD3[6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD3 (6U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD3. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD3 (0x00000040U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD3. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD3 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD3(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0, field D_SHIFT_FLAG0[7] (RW)
 *
 * data shift flag 0
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0 (7U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0 (0x00000080U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0(x).B.D_SHIFT_FLAG0)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0) & BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0)

/*! @brief Set the D_SHIFT_FLAG0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0) | BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0, field D_SHIFT_WIDTH1[13:8] (RW)
 *
 * data shift width 1
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1 (8U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0(x).B.D_SHIFT_WIDTH1)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1) & BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1)

/*! @brief Set the D_SHIFT_WIDTH1 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1) | BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0, field RSVD2[14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD2 (14U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD2. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD2 (0x00004000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD2. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD2 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD2 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD2(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0, field D_SHIFT_FLAG1[15] (RW)
 *
 * data shift flag 1
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1 (15U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1 (0x00008000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0(x).B.D_SHIFT_FLAG1)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1) & BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1)

/*! @brief Set the D_SHIFT_FLAG1 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1) | BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0, field D_SHIFT_WIDTH2[21:16] (RW)
 *
 * data shift width 2
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2 (16U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0(x).B.D_SHIFT_WIDTH2)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2) & BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2)

/*! @brief Set the D_SHIFT_WIDTH2 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2) | BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0, field RSVD1[22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD1 (22U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD1. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD1 (0x00400000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD1. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD1 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD1(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0, field D_SHIFT_FLAG2[23] (RW)
 *
 * data shift flag 2
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2 (23U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2 (0x00800000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0(x).B.D_SHIFT_FLAG2)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2) & BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2)

/*! @brief Set the D_SHIFT_FLAG2 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2) | BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0, field D_SHIFT_WIDTH3[29:24] (RW)
 *
 * data shift width 3
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3 (24U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0(x).B.D_SHIFT_WIDTH3)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3) & BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3)

/*! @brief Set the D_SHIFT_WIDTH3 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3) | BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0, field RSVD0[30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD0 (30U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD0 (0x40000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD0 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RSVD0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0, field D_SHIFT_FLAG3[31] (RW)
 *
 * data shift flag 3
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3 (31U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3 (0x80000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0(x).B.D_SHIFT_FLAG3)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3) & BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3)

/*! @brief Set the D_SHIFT_FLAG3 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3) | BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_d_shift_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_d_shift_h_ch0_bitfields
    {
        uint32_t D_SHIFT_WIDTH4 : 6;   /*!< [5:0]  */
        uint32_t RSVD3 : 1;            /*!< [6]  */
        uint32_t D_SHIFT_FLAG4 : 1;    /*!< [7]  */
        uint32_t D_SHIFT_WIDTH5 : 6;   /*!< [13:8]  */
        uint32_t RSVD2 : 1;            /*!< [14]  */
        uint32_t D_SHIFT_FLAG5 : 1;    /*!< [15]  */
        uint32_t D_SHIFT_WIDTH6 : 6;   /*!< [21:16]  */
        uint32_t RSVD1 : 1;            /*!< [22]  */
        uint32_t D_SHIFT_FLAG6 : 1;    /*!< [23]  */
        uint32_t D_SHIFT_WIDTH7 : 6;   /*!< [29:24]  */
        uint32_t RSVD0 : 1;            /*!< [30]  */
        uint32_t D_SHIFT_FLAG7 : 1;    /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_input_store_d_shift_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_ADDR(x) ((uintptr_t)(x) + 0x800U)

#define HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_d_shift_h_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0, field D_SHIFT_WIDTH4[5:0] (RW)
 *
 * data shift width 4
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0(x).B.D_SHIFT_WIDTH4)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4) & BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4)

/*! @brief Set the D_SHIFT_WIDTH4 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4) | BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0, field RSVD3[6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD3 (6U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD3. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD3 (0x00000040U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD3. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD3 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD3(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0, field D_SHIFT_FLAG4[7] (RW)
 *
 * data shift flag 4
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4 (7U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4 (0x00000080U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0(x).B.D_SHIFT_FLAG4)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4) & BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4)

/*! @brief Set the D_SHIFT_FLAG4 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4) | BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0, field D_SHIFT_WIDTH5[13:8] (RW)
 *
 * data shift width 5
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5 (8U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0(x).B.D_SHIFT_WIDTH5)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5) & BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5)

/*! @brief Set the D_SHIFT_WIDTH5 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5) | BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0, field RSVD2[14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD2 (14U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD2. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD2 (0x00004000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD2. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD2 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD2 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD2(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0, field D_SHIFT_FLAG5[15] (RW)
 *
 * data shift flag 5
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5 (15U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5 (0x00008000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0(x).B.D_SHIFT_FLAG5)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5) & BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5)

/*! @brief Set the D_SHIFT_FLAG5 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5) | BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0, field D_SHIFT_WIDTH6[21:16] (RW)
 *
 * data shift width 6
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6 (16U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0(x).B.D_SHIFT_WIDTH6)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6) & BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6)

/*! @brief Set the D_SHIFT_WIDTH6 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6) | BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0, field RSVD1[22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD1 (22U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD1. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD1 (0x00400000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD1. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD1 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD1(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0, field D_SHIFT_FLAG6[23] (RW)
 *
 * data shift flag 6
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6 (23U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6 (0x00800000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0(x).B.D_SHIFT_FLAG6)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6) & BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6)

/*! @brief Set the D_SHIFT_FLAG6 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6) | BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0, field D_SHIFT_WIDTH7[29:24] (RW)
 *
 * data shift width 3
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7 (24U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0(x).B.D_SHIFT_WIDTH7)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7) & BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7)

/*! @brief Set the D_SHIFT_WIDTH7 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7) | BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0, field RSVD0[30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD0 (30U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD0. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD0 (0x40000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD0. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD0 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RSVD0(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0, field D_SHIFT_FLAG7[31] (RW)
 *
 * data shift flag 7
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7 (31U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7. */
#define BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7 (0x80000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7. */
#define BS_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7(x) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0(x).B.D_SHIFT_FLAG7)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7. */
#define BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7) & BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7)

/*! @brief Set the D_SHIFT_FLAG7 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7(x, v) (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7) | BF_PXP_HW_PXP_INPUT_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_f_shift_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_f_shift_l_ch0_bitfields
    {
        uint32_t F_SHIFT_WIDTH0 : 6;   /*!< [5:0]  */
        uint32_t F_SHIFT_FLAG0 : 1;    /*!< [6]  */
        uint32_t RSVD3 : 1;            /*!< [7]  */
        uint32_t F_SHIFT_WIDTH1 : 6;   /*!< [13:8]  */
        uint32_t F_SHIFT_FLAG1 : 1;    /*!< [14]  */
        uint32_t RSVD2 : 1;            /*!< [15]  */
        uint32_t F_SHIFT_WIDTH2 : 6;   /*!< [21:16]  */
        uint32_t F_SHIFT_FLAG2 : 1;    /*!< [22]  */
        uint32_t RSVD1 : 1;            /*!< [23]  */
        uint32_t F_SHIFT_WIDTH3 : 6;   /*!< [29:24]  */
        uint32_t F_SHIFT_FLAG3 : 1;    /*!< [30]  */
        uint32_t RSVD0 : 1;            /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_input_store_f_shift_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_ADDR(x) ((uintptr_t)(x) + 0x810U)

#define HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_f_shift_l_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0, field F_SHIFT_WIDTH0[5:0] (RW)
 *
 * flag shift width 0
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0(x).B.F_SHIFT_WIDTH0)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0) & BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0)

/*! @brief Set the F_SHIFT_WIDTH0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0) | BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0, field F_SHIFT_FLAG0[6] (RW)
 *
 * flag shift flag0
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0 (6U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0 (0x00000040U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0(x).B.F_SHIFT_FLAG0)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0) & BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0)

/*! @brief Set the F_SHIFT_FLAG0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0) | BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0, field RSVD3[7] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD3 (7U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD3. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD3 (0x00000080U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD3. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD3 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD3(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0, field F_SHIFT_WIDTH1[13:8] (RW)
 *
 * flag shift width 1
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1 (8U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0(x).B.F_SHIFT_WIDTH1)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1) & BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1)

/*! @brief Set the F_SHIFT_WIDTH1 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1) | BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0, field F_SHIFT_FLAG1[14] (RW)
 *
 * flag shift flag1
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1 (14U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1 (0x00004000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0(x).B.F_SHIFT_FLAG1)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1) & BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1)

/*! @brief Set the F_SHIFT_FLAG1 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1) | BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0, field RSVD2[15] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD2 (15U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD2. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD2 (0x00008000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD2. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD2 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD2 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD2(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0, field F_SHIFT_WIDTH2[21:16] (RW)
 *
 * flag shift width 2
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2 (16U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0(x).B.F_SHIFT_WIDTH2)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2) & BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2)

/*! @brief Set the F_SHIFT_WIDTH2 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2) | BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0, field F_SHIFT_FLAG2[22] (RW)
 *
 * flag shift flag2
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2 (22U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2 (0x00400000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0(x).B.F_SHIFT_FLAG2)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2) & BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2)

/*! @brief Set the F_SHIFT_FLAG2 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2) | BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0, field RSVD1[23] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD1 (23U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD1. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD1 (0x00800000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD1. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD1 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD1(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0, field F_SHIFT_WIDTH3[29:24] (RW)
 *
 * flag shift width 3
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3 (24U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0(x).B.F_SHIFT_WIDTH3)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3) & BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3)

/*! @brief Set the F_SHIFT_WIDTH3 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3) | BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0, field F_SHIFT_FLAG3[30] (RW)
 *
 * flag shift flag3
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3 (30U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3 (0x40000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0(x).B.F_SHIFT_FLAG3)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3) & BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3)

/*! @brief Set the F_SHIFT_FLAG3 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3) | BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0, field RSVD0[31] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD0 (31U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD0. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD0 (0x80000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD0. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD0 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0_RSVD0(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_L_CH0(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_f_shift_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_f_shift_h_ch0_bitfields
    {
        uint32_t F_SHIFT_WIDTH4 : 6;   /*!< [5:0]  */
        uint32_t F_SHIFT_FLAG4 : 1;    /*!< [6]  */
        uint32_t RSVD3 : 1;            /*!< [7]  */
        uint32_t F_SHIFT_WIDTH5 : 6;   /*!< [13:8]  */
        uint32_t F_SHIFT_FLAG5 : 1;    /*!< [14]  */
        uint32_t RSVD2 : 1;            /*!< [15]  */
        uint32_t F_SHIFT_WIDTH6 : 6;   /*!< [21:16]  */
        uint32_t F_SHIFT_FLAG6 : 1;    /*!< [22]  */
        uint32_t RSVD1 : 1;            /*!< [23]  */
        uint32_t F_SHIFT_WIDTH7 : 6;   /*!< [29:24]  */
        uint32_t F_SHIFT_FLAG7 : 1;    /*!< [30]  */
        uint32_t RSVD0 : 1;            /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_input_store_f_shift_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_ADDR(x) ((uintptr_t)(x) + 0x820U)

#define HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_f_shift_h_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0, field F_SHIFT_WIDTH4[5:0] (RW)
 *
 * flag shift width 4
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0(x).B.F_SHIFT_WIDTH4)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4) & BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4)

/*! @brief Set the F_SHIFT_WIDTH4 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4) | BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0, field F_SHIFT_FLAG4[6] (RW)
 *
 * flag shift flag4
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4 (6U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4 (0x00000040U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0(x).B.F_SHIFT_FLAG4)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4) & BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4)

/*! @brief Set the F_SHIFT_FLAG4 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4) | BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0, field RSVD3[7] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD3 (7U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD3. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD3 (0x00000080U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD3. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD3 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD3(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0, field F_SHIFT_WIDTH5[13:8] (RW)
 *
 * flag shift width 5
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5 (8U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0(x).B.F_SHIFT_WIDTH5)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5) & BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5)

/*! @brief Set the F_SHIFT_WIDTH5 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5) | BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0, field F_SHIFT_FLAG5[14] (RW)
 *
 * flag shift flag5
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5 (14U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5 (0x00004000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0(x).B.F_SHIFT_FLAG5)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5) & BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5)

/*! @brief Set the F_SHIFT_FLAG5 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5) | BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0, field RSVD2[15] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD2 (15U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD2. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD2 (0x00008000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD2. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD2 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD2 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD2(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0, field F_SHIFT_WIDTH6[21:16] (RW)
 *
 * flag shift width 5
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6 (16U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0(x).B.F_SHIFT_WIDTH6)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6) & BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6)

/*! @brief Set the F_SHIFT_WIDTH6 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6) | BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0, field F_SHIFT_FLAG6[22] (RW)
 *
 * flag shift flag6
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6 (22U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6 (0x00400000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0(x).B.F_SHIFT_FLAG6)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6) & BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6)

/*! @brief Set the F_SHIFT_FLAG6 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6) | BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0, field RSVD1[23] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD1 (23U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD1. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD1 (0x00800000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD1. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD1 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD1(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0, field F_SHIFT_WIDTH7[29:24] (RW)
 *
 * flag shift width 7
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7 (24U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7 (6U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0(x).B.F_SHIFT_WIDTH7)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7) & BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7)

/*! @brief Set the F_SHIFT_WIDTH7 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7) | BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0, field F_SHIFT_FLAG7[30] (RW)
 *
 * flag shift flag7
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7 (30U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7 (0x40000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0(x).B.F_SHIFT_FLAG7)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7) & BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7)

/*! @brief Set the F_SHIFT_FLAG7 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7) | BF_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0, field RSVD0[31] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD0 (31U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD0. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD0 (0x80000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD0. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD0 (1U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0_RSVD0(x) (HW_PXP_HW_PXP_INPUT_STORE_F_SHIFT_H_CH0(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_f_mask_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_f_mask_l_ch0_bitfields
    {
        uint32_t F_MASK0 : 8;          /*!< [7:0]  */
        uint32_t F_MASK1 : 8;          /*!< [15:8]  */
        uint32_t F_MASK2 : 8;          /*!< [23:16]  */
        uint32_t F_MASK3 : 8;          /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_input_store_f_mask_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_ADDR(x) ((uintptr_t)(x) + 0x830U)

#define HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_f_mask_l_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0, field F_MASK0[7:0] (RW)
 *
 * flag mask0
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0 (0x000000FFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0 (8U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0(x) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0(x).B.F_MASK0)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0) & BM_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0)

/*! @brief Set the F_MASK0 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0) | BF_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0, field F_MASK1[15:8] (RW)
 *
 * flag mask1
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1 (8U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1 (0x0000FF00U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1 (8U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1(x) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0(x).B.F_MASK1)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1) & BM_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1)

/*! @brief Set the F_MASK1 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1) | BF_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0, field F_MASK2[23:16] (RW)
 *
 * flag mask2
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2 (16U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2 (0x00FF0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2 (8U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2(x) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0(x).B.F_MASK2)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2) & BM_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2)

/*! @brief Set the F_MASK2 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2) | BF_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0, field F_MASK3[31:24] (RW)
 *
 * flag mask3
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3 (24U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3 (8U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3(x) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0(x).B.F_MASK3)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3) & BM_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3)

/*! @brief Set the F_MASK3 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3) | BF_PXP_HW_PXP_INPUT_STORE_F_MASK_L_CH0_F_MASK3(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_input_store_f_mask_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_input_store_f_mask_h_ch0_bitfields
    {
        uint32_t F_MASK4 : 8;          /*!< [7:0]  */
        uint32_t F_MASK5 : 8;          /*!< [15:8]  */
        uint32_t F_MASK6 : 8;          /*!< [23:16]  */
        uint32_t F_MASK7 : 8;          /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_input_store_f_mask_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_ADDR(x) ((uintptr_t)(x) + 0x840U)

#define HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0(x) (*(__IO hw_pxp_hw_pxp_input_store_f_mask_h_ch0_t *) HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_RD(x) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0(x).U)
#define HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_WR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_SET(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_WR(x, HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0, field F_MASK4[7:0] (RW)
 *
 * flag mask4
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4 (0U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4 (0x000000FFU) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4 (8U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4(x) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0(x).B.F_MASK4)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4) & BM_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4)

/*! @brief Set the F_MASK4 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4) | BF_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK4(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0, field F_MASK5[15:8] (RW)
 *
 * flag mask5
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5 (8U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5 (0x0000FF00U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5 (8U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5(x) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0(x).B.F_MASK5)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5) & BM_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5)

/*! @brief Set the F_MASK5 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5) | BF_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK5(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0, field F_MASK6[23:16] (RW)
 *
 * flag mask6
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6 (16U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6 (0x00FF0000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6 (8U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6(x) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0(x).B.F_MASK6)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6) & BM_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6)

/*! @brief Set the F_MASK6 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6) | BF_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK6(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0, field F_MASK7[31:24] (RW)
 *
 * flag mask7
 */
/*@{*/
#define BP_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7 (24U) /*!< Bit position for PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7. */
#define BM_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7. */
#define BS_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7 (8U) /*!< Bit field size in bits for PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7. */

/*! @brief Read current value of the PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7 field. */
#define BR_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7(x) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0(x).B.F_MASK7)

/*! @brief Format value for bitfield PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7. */
#define BF_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7) & BM_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7)

/*! @brief Set the F_MASK7 field to a new value. */
#define BW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7(x, v) (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_WR(x, (HW_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_RD(x) & ~BM_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7) | BF_PXP_HW_PXP_INPUT_STORE_F_MASK_H_CH0_F_MASK7(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0 - Pre-fetch engine Control Channel 0 Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0 - Pre-fetch engine Control Channel 0 Register (RW)
 *
 * Reset value: 0x00020000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * HW_PXP_DITHER_FETCH_CTRL_CH0: 0x850 HW_PXP_DITHER_FETCH_CTRL_CH0_SET: 0x854
 * HW_PXP_DITHER_FETCH_CTRL_CH0_CLR: 0x858 HW_PXP_DITHER_FETCH_CTRL_CH0_TOG: 0x85C
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_ctrl_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_ctrl_ch0_bitfields
    {
        uint32_t CH_EN : 1;            /*!< [0]  */
        uint32_t BLOCK_EN : 1;         /*!< [1]  */
        uint32_t BLOCK_16 : 1;         /*!< [2]  */
        uint32_t HANDSHAKE_EN : 1;     /*!< [3]  */
        uint32_t BYPASS_PIXEL_EN : 1;  /*!< [4]  */
        uint32_t HIGH_BYTE : 1;        /*!< [5]  */
        uint32_t RSVD4 : 3;            /*!< [8:6]  */
        uint32_t HFLIP : 1;            /*!< [9]  */
        uint32_t VFLIP : 1;            /*!< [10]  */
        uint32_t RSVD3 : 1;            /*!< [11]  */
        uint32_t ROTATION_ANGLE : 2;   /*!< [13:12]  */
        uint32_t RSVD2 : 2;            /*!< [15:14]  */
        uint32_t RD_NUM_BYTES : 2;     /*!< [17:16]  */
        uint32_t RSVD1 : 6;            /*!< [23:18]  */
        uint32_t HANDSHAKE_SCAN_LINE_NUM : 2; /*!< [25:24]  */
        uint32_t RSVD0 : 5;            /*!< [30:26]  */
        uint32_t ARBIT_EN : 1;         /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_ctrl_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_CTRL_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ADDR(x) ((uintptr_t)(x) + 0x850U)

#define HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_ctrl_ch0_t *) HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_CTRL_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH0, field CH_EN[0] (RW)
 *
 * Channel enable.
 *
 * Values:
 * - 0 - Prefetch function is disable
 * - 1 - Prefetch function is enable
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN (0x00000001U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN: Prefetch function is disable */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN: Prefetch function is enable */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x).B.CH_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN)

/*! @brief Set the CH_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_CH_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH0, field BLOCK_EN[1] (RW)
 *
 * Choses the prefetch mode.
 *
 * Values:
 * - 0 - Prefetch in scan mode
 * - 1 - Prefetch in block mode
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN (1U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN (0x00000002U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN: Prefetch in scan mode */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN: Prefetch in block mode */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x).B.BLOCK_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN)

/*! @brief Set the BLOCK_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH0, field BLOCK_16[2] (RW)
 *
 * Determines the block sixe.
 *
 * Values:
 * - 0 - Block size is 8x8
 * - 1 - Block size is 16x16
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16 (2U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16 (0x00000004U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16_8x8 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16: Block size is 8x8 */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16_16x16 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16: Block size is 16x16 */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x).B.BLOCK_16)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16)

/*! @brief Set the BLOCK_16 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BLOCK_16(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH0, field HANDSHAKE_EN[3] (RW)
 *
 * Enable bit for handshake with the store engine.
 *
 * Values:
 * - 0 - Handshake with the store engine is disabled
 * - 1 - Handshake with the store engine is enabled
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN (3U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN (0x00000008U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN: Handshake with the store engine is disabled */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN: Handshake with the store engine is enabled */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x).B.HANDSHAKE_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN)

/*! @brief Set the HANDSHAKE_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH0, field BYPASS_PIXEL_EN[4] (RW)
 *
 * Selects Channel 0 pixel source
 *
 * Values:
 * - 0 - Channel 0 is from memory
 * - 1 - Channel 0 is from previous process engine
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN (4U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN (0x00000010U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN: Channel 0 is from memory */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN: Channel 0 is from previous process engine */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x).B.BYPASS_PIXEL_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN)

/*! @brief Set the BYPASS_PIXEL_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_BYPASS_PIXEL_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH0, field HIGH_BYTE[5] (RW)
 *
 * channel 0 high byte selection
 *
 * Values:
 * - 0 - In 64 bit mode, the output high byte will use channel1.
 * - 1 - In 64 bit mode, the output high byte will use channel0
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE (5U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE (0x00000020U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE: In 64 bit mode, the output high byte will use channel1. */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE: In 64 bit mode, the output high byte will use channel0 */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x).B.HIGH_BYTE)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE)

/*! @brief Set the HIGH_BYTE field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HIGH_BYTE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH0, field RSVD4[8:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD4 (6U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD4. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD4 (0x000001C0U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD4. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD4 (3U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD4. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD4 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD4(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x).B.RSVD4)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH0, field HFLIP[9] (RW)
 *
 * Enables HFLIP.
 *
 * Values:
 * - 0 - HFLIP disable
 * - 1 - VFLIP enable
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP (9U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP (0x00000200U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP: HFLIP disable */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP: VFLIP enable */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x).B.HFLIP)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP)

/*! @brief Set the HFLIP field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HFLIP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH0, field VFLIP[10] (RW)
 *
 * Enables VFLIP
 *
 * Values:
 * - 0 - VFLIP disable
 * - 1 - VFLIP enable
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP (10U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP (0x00000400U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP: VFLIP disable */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP: VFLIP enable */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x).B.VFLIP)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP)

/*! @brief Set the VFLIP field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_VFLIP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH0, field RSVD3[11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD3 (11U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD3. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD3 (0x00000800U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD3. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD3 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD3(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH0, field ROTATION_ANGLE[13:12] (RW)
 *
 * Values:
 * - 0 - Rotate image by 0 degrees.
 * - 1 - Rotate image by 90 degrees.
 * - 10 - Rotate image by 180 degrees.
 * - 11 - Rotate image by 270 degrees.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE (12U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE (0x00003000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE_ROT_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE: Rotate image by 0 degrees. */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE_ROT_90 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE: Rotate image by 90 degrees. */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE_ROT_180 (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE: Rotate image by 180 degrees. */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE_ROT_270 (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE: Rotate image by 270 degrees. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x).B.ROTATION_ANGLE)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE)

/*! @brief Set the ROTATION_ANGLE field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ROTATION_ANGLE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH0, field RSVD2[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD2 (14U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD2. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD2 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD2. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD2 (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD2 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD2(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH0, field RD_NUM_BYTES[17:16] (RW)
 *
 * Bytes in a read burst
 *
 * Values:
 * - 0 - 8 bytes.
 * - 1 - 16 bytes.
 * - 10 - 32 bytes.
 * - 11 - 64 bytes.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES (16U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES (0x00030000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES_8_bytes (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES: 8 bytes. */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES_16_bytes (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES: 16 bytes. */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES_32_bytes (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES: 32 bytes. */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES_64_bytes (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES: 64 bytes. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x).B.RD_NUM_BYTES)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES)

/*! @brief Set the RD_NUM_BYTES field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD_NUM_BYTES(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH0, field RSVD1[23:18] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD1 (18U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD1. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD1 (0x00FC0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD1. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD1 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD1(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH0, field HANDSHAKE_SCAN_LINE_NUM[25:24] (RW)
 *
 * scan handshake line number
 *
 * Values:
 * - 0 - 1 line.
 * - 1 - 8 lines
 * - 10 - 16 lines
 * - 11 - 16 lines
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM (24U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM (0x03000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM: 1 line. */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM: 8 lines */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM: 16 lines */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM: 16 lines */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x).B.HANDSHAKE_SCAN_LINE_NUM)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM)

/*! @brief Set the HANDSHAKE_SCAN_LINE_NUM field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_HANDSHAKE_SCAN_LINE_NUM(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH0, field RSVD0[30:26] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD0 (26U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD0. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD0 (0x7C000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD0. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD0 (5U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RSVD0(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH0, field ARBIT_EN[31] (RW)
 *
 * Enables Arbitration
 *
 * Values:
 * - 0 - Arbitration disable. If using 2 channels, will output 2 axi bus sets.
 * - 1 - Arbitration enable. If using 2 channel, will only output 1 axi bus sets
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN (31U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN (0x80000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN: Arbitration disable. If using 2 channels, will output 2 axi bus sets. */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN: Arbitration enable. If using 2 channel, will only output 1 axi bus sets */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0(x).B.ARBIT_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN)

/*! @brief Set the ARBIT_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH0_ARBIT_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1 - Pre-fetch engine Control Channel 1 Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1 - Pre-fetch engine Control Channel 1 Register (RW)
 *
 * Reset value: 0x00020000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * HW_PXP_DITHER_FETCH_CTRL_CH1: 0x860 HW_PXP_DITHER_FETCH_CTRL_CH1_SET: 0x864
 * HW_PXP_DITHER_FETCH_CTRL_CH1_CLR: 0x868 HW_PXP_DITHER_FETCH_CTRL_CH1_TOG: 0x86C
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_ctrl_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_ctrl_ch1_bitfields
    {
        uint32_t CH_EN : 1;            /*!< [0]  */
        uint32_t BLOCK_EN : 1;         /*!< [1]  */
        uint32_t BLOCK_16 : 1;         /*!< [2]  */
        uint32_t HANDSHAKE_EN : 1;     /*!< [3]  */
        uint32_t BYPASS_PIXEL_EN : 1;  /*!< [4]  */
        uint32_t RSVD4 : 4;            /*!< [8:5]  */
        uint32_t HFLIP : 1;            /*!< [9]  */
        uint32_t VFLIP : 1;            /*!< [10]  */
        uint32_t RSVD3 : 1;            /*!< [11]  */
        uint32_t ROTATION_ANGLE : 2;   /*!< [13:12]  */
        uint32_t RSVD2 : 2;            /*!< [15:14]  */
        uint32_t RD_NUM_BYTES : 2;     /*!< [17:16]  */
        uint32_t RSVD1 : 6;            /*!< [23:18]  */
        uint32_t HANDSHAKE_SCAN_LINE_NUM : 2; /*!< [25:24]  */
        uint32_t RSVD0 : 6;            /*!< [31:26]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_ctrl_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_CTRL_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ADDR(x) ((uintptr_t)(x) + 0x860U)

#define HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_ctrl_ch1_t *) HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_CTRL_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH1, field CH_EN[0] (RW)
 *
 * Channel enable.
 *
 * Values:
 * - 0 - Prefetch function is disable
 * - 1 - Prefetch function is enable
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN (0x00000001U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN: Prefetch function is disable */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN: Prefetch function is enable */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1(x).B.CH_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN)

/*! @brief Set the CH_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_CH_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH1, field BLOCK_EN[1] (RW)
 *
 * Choses the prefetch mode.
 *
 * Values:
 * - 0 - Prefetch in scan mode
 * - 1 - Prefetch in block mode
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN (1U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN (0x00000002U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN: Prefetch in scan mode */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN: Prefetch in block mode */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1(x).B.BLOCK_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN)

/*! @brief Set the BLOCK_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH1, field BLOCK_16[2] (RW)
 *
 * Determines the block sixe.
 *
 * Values:
 * - 0 - Block size is 8x8
 * - 1 - Block size is 16x16
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16 (2U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16 (0x00000004U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16_8x8 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16: Block size is 8x8 */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16_16x16 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16: Block size is 16x16 */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1(x).B.BLOCK_16)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16)

/*! @brief Set the BLOCK_16 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BLOCK_16(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH1, field HANDSHAKE_EN[3] (RW)
 *
 * Enable bit for handshake with the store engine.
 *
 * Values:
 * - 0 - Handshake with the store engine is disabled
 * - 1 - Handshake with the store engine is enabled
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN (3U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN (0x00000008U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN: Handshake with the store engine is disabled */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN: Handshake with the store engine is enabled */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1(x).B.HANDSHAKE_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN)

/*! @brief Set the HANDSHAKE_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH1, field BYPASS_PIXEL_EN[4] (RW)
 *
 * Selects Channel 1 pixel source
 *
 * Values:
 * - 0 - Channel 1 is from memory
 * - 1 - Channel 1 is from previous process engine
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN (4U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN (0x00000010U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN: Channel 1 is from memory */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN: Channel 1 is from previous process engine */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1(x).B.BYPASS_PIXEL_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN)

/*! @brief Set the BYPASS_PIXEL_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_BYPASS_PIXEL_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH1, field RSVD4[8:5] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD4 (5U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD4. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD4 (0x000001E0U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD4. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD4 (4U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD4. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD4 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD4(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1(x).B.RSVD4)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH1, field HFLIP[9] (RW)
 *
 * Enables HFLIP.
 *
 * Values:
 * - 0 - HFLIP disable
 * - 1 - VFLIP enable
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP (9U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP (0x00000200U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP: HFLIP disable */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP: VFLIP enable */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1(x).B.HFLIP)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP)

/*! @brief Set the HFLIP field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HFLIP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH1, field VFLIP[10] (RW)
 *
 * Enables VFLIP
 *
 * Values:
 * - 0 - VFLIP disable
 * - 1 - VFLIP enable
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP (10U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP (0x00000400U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP: VFLIP disable */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP: VFLIP enable */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1(x).B.VFLIP)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP)

/*! @brief Set the VFLIP field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_VFLIP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH1, field RSVD3[11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD3 (11U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD3. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD3 (0x00000800U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD3. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD3 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD3(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH1, field ROTATION_ANGLE[13:12] (RW)
 *
 * Values:
 * - 0 - Rotate image by 0 degrees.
 * - 1 - Rotate image by 90 degrees.
 * - 10 - Rotate image by 180 degrees.
 * - 11 - Rotate image by 270 degrees.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE (12U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE (0x00003000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE_ROT_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE: Rotate image by 0 degrees. */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE_ROT_90 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE: Rotate image by 90 degrees. */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE_ROT_180 (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE: Rotate image by 180 degrees. */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE_ROT_270 (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE: Rotate image by 270 degrees. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1(x).B.ROTATION_ANGLE)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE)

/*! @brief Set the ROTATION_ANGLE field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_ROTATION_ANGLE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH1, field RSVD2[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD2 (14U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD2. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD2 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD2. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD2 (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD2 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD2(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH1, field RD_NUM_BYTES[17:16] (RW)
 *
 * Bytes in a read burst
 *
 * Values:
 * - 0 - 8 bytes.
 * - 1 - 16 bytes.
 * - 10 - 32 bytes.
 * - 11 - 64 bytes.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES (16U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES (0x00030000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES_8_bytes (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES: 8 bytes. */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES_16_bytes (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES: 16 bytes. */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES_32_bytes (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES: 32 bytes. */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES_64_bytes (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES: 64 bytes. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1(x).B.RD_NUM_BYTES)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES)

/*! @brief Set the RD_NUM_BYTES field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD_NUM_BYTES(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH1, field RSVD1[23:18] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD1 (18U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD1. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD1 (0x00FC0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD1. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD1 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD1(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH1, field HANDSHAKE_SCAN_LINE_NUM[25:24] (RW)
 *
 * scan handshake line number
 *
 * Values:
 * - 0 - 1 line.
 * - 1 - 8 lines
 * - 10 - 16 lines
 * - 11 - 16 lines
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM (24U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM (0x03000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM. */

#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM: 1 line. */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM: 8 lines */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM: 16 lines */
#define BV_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM: 16 lines */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1(x).B.HANDSHAKE_SCAN_LINE_NUM)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM. */
#define BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM) & BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM)

/*! @brief Set the HANDSHAKE_SCAN_LINE_NUM field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM) | BF_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_HANDSHAKE_SCAN_LINE_NUM(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_CTRL_CH1, field RSVD0[31:26] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD0 (26U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD0. */
#define BM_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD0 (0xFC000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD0. */
#define BS_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD0 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD0 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1_RSVD0(x) (HW_PXP_HW_PXP_DITHER_FETCH_CTRL_CH1(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH0 - Pre-fetch engine status Channel 0 Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH0 - Pre-fetch engine status Channel 0 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the status bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_status_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_status_ch0_bitfields
    {
        uint32_t PREFETCH_BLOCK_X : 16; /*!< [15:0]  */
        uint32_t PREFETCH_BLOCK_Y : 16; /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_status_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_STATUS_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_ADDR(x) ((uintptr_t)(x) + 0x870U)

#define HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH0(x) (*(__I hw_pxp_hw_pxp_dither_fetch_status_ch0_t *) HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH0(x).U)
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_STATUS_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_STATUS_CH0, field PREFETCH_BLOCK_X[15:0] (RO)
 *
 * When in scan mode, this field is always 0. In block mode, it indicates the X
 * coordinate of the block currently being rendered.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_X (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_X. */
#define BM_PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_X (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_X. */
#define BS_PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_X (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_X. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_X field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_X(x) (HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH0(x).B.PREFETCH_BLOCK_X)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_STATUS_CH0, field PREFETCH_BLOCK_Y[31:16] (RO)
 *
 * When in scan mode, this field indicates the current Y coordinate of the
 * frame. In block mode, it indicates the Y coordinate of the block currently being
 * rendered.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y (16U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y. */
#define BM_PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y. */
#define BS_PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_STATUS_CH0_PREFETCH_BLOCK_Y(x) (HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH0(x).B.PREFETCH_BLOCK_Y)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH1 - Store engine status Channel 1 Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH1 - Store engine status Channel 1 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the status bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_status_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_status_ch1_bitfields
    {
        uint32_t PREFETCH_BLOCK_X : 16; /*!< [15:0]  */
        uint32_t PREFETCH_BLOCK_Y : 16; /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_status_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_STATUS_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_ADDR(x) ((uintptr_t)(x) + 0x880U)

#define HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH1(x) (*(__I hw_pxp_hw_pxp_dither_fetch_status_ch1_t *) HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH1(x).U)
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_STATUS_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_STATUS_CH1, field PREFETCH_BLOCK_X[15:0] (RO)
 *
 * When in scan mode, this field is always 0. In block mode, it indicates the X
 * coordinate of the block currently being rendered.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_X (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_X. */
#define BM_PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_X (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_X. */
#define BS_PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_X (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_X. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_X field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_X(x) (HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH1(x).B.PREFETCH_BLOCK_X)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_STATUS_CH1, field PREFETCH_BLOCK_Y[31:16] (RO)
 *
 * When in scan mode, this field indicates the current Y coordinate of the
 * frame. In block mode, it indicates the Y coordinate of the block currently being
 * rendered.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y (16U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y. */
#define BM_PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y. */
#define BS_PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_STATUS_CH1_PREFETCH_BLOCK_Y(x) (HW_PXP_HW_PXP_DITHER_FETCH_STATUS_CH1(x).B.PREFETCH_BLOCK_Y)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_active_size_ulc_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_active_size_ulc_ch0_bitfields
    {
        uint32_t ACTIVE_SIZE_ULC_X : 16; /*!< [15:0]  */
        uint32_t ACTIVE_SIZE_ULC_Y : 16; /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_active_size_ulc_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ADDR(x) ((uintptr_t)(x) + 0x890U)

#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_active_size_ulc_ch0_t *) HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0, field ACTIVE_SIZE_ULC_X[15:0] (RW)
 *
 * This field indicates the upper left X-coordinate(in pixels) of the active
 * surface of the total input memory
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X. */
#define BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X. */
#define BS_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X(x) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0(x).B.ACTIVE_SIZE_ULC_X)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X. */
#define BF_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X) & BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X)

/*! @brief Set the ACTIVE_SIZE_ULC_X field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X) | BF_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_X(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0, field ACTIVE_SIZE_ULC_Y[31:16] (RW)
 *
 * This field indicates the upper left Y-coordinate(in pixels) of the active
 * surface of the total input memory
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y (16U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y. */
#define BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y. */
#define BS_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y(x) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0(x).B.ACTIVE_SIZE_ULC_Y)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y. */
#define BF_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y) & BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y)

/*! @brief Set the ACTIVE_SIZE_ULC_Y field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y) | BF_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0_ACTIVE_SIZE_ULC_Y(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_active_size_lrc_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_active_size_lrc_ch0_bitfields
    {
        uint32_t ACTIVE_SIZE_LRC_X : 16; /*!< [15:0]  */
        uint32_t ACTIVE_SIZE_LRC_Y : 16; /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_active_size_lrc_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ADDR(x) ((uintptr_t)(x) + 0x8A0U)

#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_active_size_lrc_ch0_t *) HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0, field ACTIVE_SIZE_LRC_X[15:0] (RW)
 *
 * This field indicates the upper left X-coordinate(in pixels) of the active
 * surface of the total input memory
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X. */
#define BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X. */
#define BS_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X(x) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0(x).B.ACTIVE_SIZE_LRC_X)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X. */
#define BF_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X) & BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X)

/*! @brief Set the ACTIVE_SIZE_LRC_X field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X) | BF_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_X(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0, field ACTIVE_SIZE_LRC_Y[31:16] (RW)
 *
 * This field indicates the upper left Y-coordinate(in pixels) of the active
 * surface of the total input memory
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y (16U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y. */
#define BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y. */
#define BS_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y(x) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0(x).B.ACTIVE_SIZE_LRC_Y)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y. */
#define BF_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y) & BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y)

/*! @brief Set the ACTIVE_SIZE_LRC_Y field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y) | BF_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0_ACTIVE_SIZE_LRC_Y(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_active_size_ulc_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_active_size_ulc_ch1_bitfields
    {
        uint32_t ACTIVE_SIZE_ULC_X : 16; /*!< [15:0]  */
        uint32_t ACTIVE_SIZE_ULC_Y : 16; /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_active_size_ulc_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ADDR(x) ((uintptr_t)(x) + 0x8B0U)

#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_active_size_ulc_ch1_t *) HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1, field ACTIVE_SIZE_ULC_X[15:0] (RW)
 *
 * This field indicates the upper left X-coordinate(in pixels) of the active
 * surface of the total input memory
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X. */
#define BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X. */
#define BS_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X(x) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1(x).B.ACTIVE_SIZE_ULC_X)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X. */
#define BF_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X) & BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X)

/*! @brief Set the ACTIVE_SIZE_ULC_X field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X) | BF_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_X(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1, field ACTIVE_SIZE_ULC_Y[31:16] (RW)
 *
 * This field indicates the upper left Y-coordinate(in pixels) of the active
 * surface of the total input memory
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y (16U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y. */
#define BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y. */
#define BS_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y(x) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1(x).B.ACTIVE_SIZE_ULC_Y)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y. */
#define BF_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y) & BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y)

/*! @brief Set the ACTIVE_SIZE_ULC_Y field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y) | BF_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1_ACTIVE_SIZE_ULC_Y(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_active_size_lrc_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_active_size_lrc_ch1_bitfields
    {
        uint32_t ACTIVE_SIZE_LRC_X : 16; /*!< [15:0]  */
        uint32_t ACTIVE_SIZE_LRC_Y : 16; /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_active_size_lrc_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ADDR(x) ((uintptr_t)(x) + 0x8C0U)

#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_active_size_lrc_ch1_t *) HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1, field ACTIVE_SIZE_LRC_X[15:0] (RW)
 *
 * This field indicates the upper left X-coordinate(in pixels) of the active
 * surface of the total input memory
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X. */
#define BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X. */
#define BS_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X(x) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1(x).B.ACTIVE_SIZE_LRC_X)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X. */
#define BF_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X) & BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X)

/*! @brief Set the ACTIVE_SIZE_LRC_X field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X) | BF_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_X(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1, field ACTIVE_SIZE_LRC_Y[31:16] (RW)
 *
 * This field indicates the upper left Y-coordinate(in pixels) of the active
 * surface of the total input memory
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y (16U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y. */
#define BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y. */
#define BS_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y(x) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1(x).B.ACTIVE_SIZE_LRC_Y)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y. */
#define BF_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y) & BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y)

/*! @brief Set the ACTIVE_SIZE_LRC_Y field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y) | BF_PXP_HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1_ACTIVE_SIZE_LRC_Y(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_size_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_size_ch0_bitfields
    {
        uint32_t INPUT_TOTAL_WIDTH : 16; /*!< [15:0]  */
        uint32_t INPUT_TOTAL_HEIGHT : 16; /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_size_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_SIZE_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_ADDR(x) ((uintptr_t)(x) + 0x8D0U)

#define HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_size_ch0_t *) HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_SIZE_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SIZE_CH0, field INPUT_TOTAL_WIDTH[15:0] (RW)
 *
 * actual total widht -1
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH(x) (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0(x).B.INPUT_TOTAL_WIDTH)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH) & BM_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH)

/*! @brief Set the INPUT_TOTAL_WIDTH field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH) | BF_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_WIDTH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SIZE_CH0, field INPUT_TOTAL_HEIGHT[31:16] (RW)
 *
 * actual total height -1
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT (16U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT(x) (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0(x).B.INPUT_TOTAL_HEIGHT)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT) & BM_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT)

/*! @brief Set the INPUT_TOTAL_HEIGHT field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT) | BF_PXP_HW_PXP_DITHER_FETCH_SIZE_CH0_INPUT_TOTAL_HEIGHT(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_size_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_size_ch1_bitfields
    {
        uint32_t INPUT_TOTAL_WIDTH : 16; /*!< [15:0]  */
        uint32_t INPUT_TOTAL_HEIGHT : 16; /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_size_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_SIZE_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_ADDR(x) ((uintptr_t)(x) + 0x8E0U)

#define HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_size_ch1_t *) HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_SIZE_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SIZE_CH1, field INPUT_TOTAL_WIDTH[15:0] (RW)
 *
 * actual_total_width -1
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH(x) (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1(x).B.INPUT_TOTAL_WIDTH)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH) & BM_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH)

/*! @brief Set the INPUT_TOTAL_WIDTH field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH) | BF_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_WIDTH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SIZE_CH1, field INPUT_TOTAL_HEIGHT[31:16] (RW)
 *
 * acutal total height -1
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT (16U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT(x) (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1(x).B.INPUT_TOTAL_HEIGHT)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT) & BM_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT)

/*! @brief Set the INPUT_TOTAL_HEIGHT field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT) | BF_PXP_HW_PXP_DITHER_FETCH_SIZE_CH1_INPUT_TOTAL_HEIGHT(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_background_color_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_background_color_ch0_bitfields
    {
        uint32_t BACKGROUND_COLOR : 32; /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_background_color_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_ADDR(x) ((uintptr_t)(x) + 0x8F0U)

#define HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_background_color_ch0_t *) HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0, field BACKGROUND_COLOR[31:0] (RW)
 *
 * background color(in 32bpp format) for any pixels not within the bufffer range
 * specified by the ULC/LRC
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR. */
#define BM_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR. */
#define BS_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR(x) (HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR. */
#define BF_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR) & BM_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR)

/*! @brief Set the BACKGROUND_COLOR field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_BACKGROUND_COLOR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_background_color_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_background_color_ch1_bitfields
    {
        uint32_t BACKGROUND_COLOR : 32; /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_background_color_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_ADDR(x) ((uintptr_t)(x) + 0x900U)

#define HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_background_color_ch1_t *) HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1, field BACKGROUND_COLOR[31:0] (RW)
 *
 * background color(in 32bpp format) for any pixels not within the bufffer range
 * specified by the ULC/LRC
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR. */
#define BM_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR. */
#define BS_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR(x) (HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR. */
#define BF_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR) & BM_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR)

/*! @brief Set the BACKGROUND_COLOR field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_BACKGROUND_COLOR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_PITCH -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_PITCH -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_pitch
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_pitch_bitfields
    {
        uint32_t CH0_INPUT_PITCH : 16; /*!< [15:0]  */
        uint32_t CH1_INPUT_PITCH : 16; /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_pitch_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_PITCH register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_PITCH_ADDR(x) ((uintptr_t)(x) + 0x910U)

#define HW_PXP_HW_PXP_DITHER_FETCH_PITCH(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_pitch_t *) HW_PXP_HW_PXP_DITHER_FETCH_PITCH_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_PITCH_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_PITCH(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_PITCH_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_PITCH(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_PITCH_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_PITCH_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_PITCH_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_PITCH_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_PITCH_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_PITCH_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_PITCH_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_PITCH_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_PITCH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_PITCH bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_PITCH, field CH0_INPUT_PITCH[15:0] (RW)
 *
 * This field indicates the channel 0 input pitch
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH. */
#define BM_PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH. */
#define BS_PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH(x) (HW_PXP_HW_PXP_DITHER_FETCH_PITCH(x).B.CH0_INPUT_PITCH)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH. */
#define BF_PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH) & BM_PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH)

/*! @brief Set the CH0_INPUT_PITCH field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_PITCH_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_PITCH_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH) | BF_PXP_HW_PXP_DITHER_FETCH_PITCH_CH0_INPUT_PITCH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_PITCH, field CH1_INPUT_PITCH[31:16] (RW)
 *
 * This field indicates the channel 1 input pitch
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH (16U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH. */
#define BM_PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH. */
#define BS_PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH(x) (HW_PXP_HW_PXP_DITHER_FETCH_PITCH(x).B.CH1_INPUT_PITCH)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH. */
#define BF_PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH) & BM_PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH)

/*! @brief Set the CH1_INPUT_PITCH field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_PITCH_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_PITCH_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH) | BF_PXP_HW_PXP_DITHER_FETCH_PITCH_CH1_INPUT_PITCH(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0 -  (RW)
 *
 * Reset value: 0x00001000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0: 0x920
 * HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SET: 0x924 HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_CLR: 0x928
 * HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_TOG: 0x92C The Control register contains the control bits for
 * the pxp prefetch_engine sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_shift_ctrl_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_shift_ctrl_ch0_bitfields
    {
        uint32_t INPUT_ACTIVE_BPP : 2; /*!< [1:0]  */
        uint32_t RSVD1 : 6;            /*!< [7:2]  */
        uint32_t EXPAND_FORMAT : 3;    /*!< [10:8]  */
        uint32_t EXPAND_EN : 1;        /*!< [11]  */
        uint32_t SHIFT_BYPASS : 1;     /*!< [12]  */
        uint32_t RSVD0 : 19;           /*!< [31:13]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_shift_ctrl_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_ADDR(x) ((uintptr_t)(x) + 0x920U)

#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_shift_ctrl_ch0_t *) HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0, field INPUT_ACTIVE_BPP[1:0] (RW)
 *
 * Values:
 * - 0 - 8 bits
 * - 1 - 16 bits
 * - 10 - 32 bits
 * - 11 - 32 bits
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP (0x00000003U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP. */

#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP: 8 bits */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP: 16 bits */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP: 32 bits */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP: 32 bits */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0(x).B.INPUT_ACTIVE_BPP)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP)

/*! @brief Set the INPUT_ACTIVE_BPP field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_INPUT_ACTIVE_BPP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0, field RSVD1[7:2] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD1 (2U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD1. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD1 (0x000000FCU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD1. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD1 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD1(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0, field EXPAND_FORMAT[10:8] (RW)
 *
 * Select Pixel format
 *
 * Values:
 * - 0 - RGB 565
 * - 1 - RGB 555
 * - 10 - ARGB 1555
 * - 11 - RGB 444
 * - 100 - ARGB 4444
 * - 101 - YUYV/YVYU
 * - 110 - UYVY/VYUY
 * - 111 - YUV422_2P
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT (8U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT (0x00000700U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT (3U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT. */

#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT: RGB 565 */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT: RGB 555 */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT: ARGB 1555 */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT: RGB 444 */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_4 (0x4U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT: ARGB 4444 */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_5 (0x5U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT: YUYV/YVYU */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_6 (0x6U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT: UYVY/VYUY */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT_7 (0x7U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT: YUV422_2P */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0(x).B.EXPAND_FORMAT)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT)

/*! @brief Set the EXPAND_FORMAT field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_FORMAT(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0, field EXPAND_EN[11] (RW)
 *
 * Values:
 * - 0 - channel0 format expanding disable
 * - 1 - channel0 format expanding enable
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN (11U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN (0x00000800U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN. */

#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN: channel0 format expanding disable */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN: channel0 format expanding enable */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0(x).B.EXPAND_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN)

/*! @brief Set the EXPAND_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_EXPAND_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0, field SHIFT_BYPASS[12] (RW)
 *
 * Values:
 * - 0 - channel0 data will do shift function
 * - 1 - channel0 will bypass shift function
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS (12U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS (0x00001000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS. */

#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS: channel0 data will do shift function */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS: channel0 will bypass shift function */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0(x).B.SHIFT_BYPASS)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS)

/*! @brief Set the SHIFT_BYPASS field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_SHIFT_BYPASS(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0, field RSVD0[31:13] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD0 (13U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD0. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD0 (0xFFFFE000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD0. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD0 (19U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0_RSVD0(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1 -  (RW)
 *
 * Reset value: 0x00001000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1: 0x930
 * HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SET: 0x934 HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_CLR: 0x938
 * HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_TOG: 0x93C The Control register contains the control bits for
 * the pxp prefetch_engine sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_shift_ctrl_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_shift_ctrl_ch1_bitfields
    {
        uint32_t INPUT_ACTIVE_BPP : 2; /*!< [1:0]  */
        uint32_t RSVD1 : 6;            /*!< [7:2]  */
        uint32_t EXPAND_FORMAT : 3;    /*!< [10:8]  */
        uint32_t EXPAND_EN : 1;        /*!< [11]  */
        uint32_t SHIFT_BYPASS : 1;     /*!< [12]  */
        uint32_t RSVD0 : 19;           /*!< [31:13]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_shift_ctrl_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_ADDR(x) ((uintptr_t)(x) + 0x930U)

#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_shift_ctrl_ch1_t *) HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1, field INPUT_ACTIVE_BPP[1:0] (RW)
 *
 * Values:
 * - 0 - 8 bits
 * - 1 - 16 bits
 * - 10 - 32 bits
 * - 11 - 32 bits
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP (0x00000003U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP. */

#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP: 8 bits */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP: 16 bits */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP: 32 bits */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP: 32 bits */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1(x).B.INPUT_ACTIVE_BPP)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP)

/*! @brief Set the INPUT_ACTIVE_BPP field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_INPUT_ACTIVE_BPP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1, field RSVD1[7:2] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD1 (2U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD1. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD1 (0x000000FCU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD1. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD1 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD1(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1, field EXPAND_FORMAT[10:8] (RW)
 *
 * Select Pixel format
 *
 * Values:
 * - 0 - RGB 565
 * - 1 - RGB 555
 * - 10 - ARGB 1555
 * - 11 - RGB 444
 * - 100 - ARGB 4444
 * - 101 - YUYV/YVYU
 * - 110 - UYVY/VYUY
 * - 111 - YUV422_2P
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT (8U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT (0x00000700U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT (3U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT. */

#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT: RGB 565 */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT: RGB 555 */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT: ARGB 1555 */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT: RGB 444 */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_4 (0x4U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT: ARGB 4444 */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_5 (0x5U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT: YUYV/YVYU */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_6 (0x6U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT: UYVY/VYUY */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT_7 (0x7U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT: YUV422_2P */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1(x).B.EXPAND_FORMAT)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT)

/*! @brief Set the EXPAND_FORMAT field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_FORMAT(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1, field EXPAND_EN[11] (RW)
 *
 * Values:
 * - 0 - channel1 format expanding disable
 * - 1 - channel1 format expanding enable
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN (11U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN (0x00000800U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN. */

#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN: channel1 format expanding disable */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN: channel1 format expanding enable */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1(x).B.EXPAND_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN)

/*! @brief Set the EXPAND_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_EXPAND_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1, field SHIFT_BYPASS[12] (RW)
 *
 * Values:
 * - 0 - channel1 data will do shift function
 * - 1 - channel1 will bypass shift function
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS (12U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS (0x00001000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS. */

#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS: channel1 data will do shift function */
#define BV_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS: channel1 will bypass shift function */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1(x).B.SHIFT_BYPASS)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS)

/*! @brief Set the SHIFT_BYPASS field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_SHIFT_BYPASS(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1, field RSVD0[31:13] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD0 (13U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD0. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD0 (0xFFFFE000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD0. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD0 (19U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD0 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1_RSVD0(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0: 0x940
 * HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_SET: 0x944 HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_CLR: 0x948
 * HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_TOG: 0x94C The Control register contains the control
 * bits for the pxp prefetch_engine sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_shift_offset_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_shift_offset_ch0_bitfields
    {
        uint32_t OFFSET0 : 5;          /*!< [4:0]  */
        uint32_t RSVD3 : 3;            /*!< [7:5]  */
        uint32_t OFFSET1 : 5;          /*!< [12:8]  */
        uint32_t RSVD2 : 3;            /*!< [15:13]  */
        uint32_t OFFSET2 : 5;          /*!< [20:16]  */
        uint32_t RSVD1 : 3;            /*!< [23:21]  */
        uint32_t OFFSET3 : 5;          /*!< [28:24]  */
        uint32_t RSVD0 : 3;            /*!< [31:29]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_shift_offset_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_ADDR(x) ((uintptr_t)(x) + 0x940U)

#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_shift_offset_ch0_t *) HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0, field OFFSET0[4:0] (RW)
 *
 * Shift Offset for channel 0 componnent 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0 (0x0000001FU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0 (5U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0(x).B.OFFSET0)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0)

/*! @brief Set the OFFSET0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0, field RSVD3[7:5] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD3 (5U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD3. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD3 (0x000000E0U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD3. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD3 (3U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD3 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD3(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0, field OFFSET1[12:8] (RW)
 *
 * Shift Offset for channel 0 componnent 1.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1 (8U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1 (0x00001F00U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1 (5U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0(x).B.OFFSET1)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1)

/*! @brief Set the OFFSET1 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0, field RSVD2[15:13] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD2 (13U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD2. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD2 (0x0000E000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD2. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD2 (3U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD2 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD2(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0, field OFFSET2[20:16] (RW)
 *
 * Shift Offset for channel 0 componnent 2.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2 (16U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2 (0x001F0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2 (5U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0(x).B.OFFSET2)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2)

/*! @brief Set the OFFSET2 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0, field RSVD1[23:21] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD1 (21U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD1. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD1 (0x00E00000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD1. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD1 (3U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD1 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD1(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0, field OFFSET3[28:24] (RW)
 *
 * Shift Offset for channel 0 componnent 3.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3 (24U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3 (0x1F000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3 (5U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0(x).B.OFFSET3)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3)

/*! @brief Set the OFFSET3 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_OFFSET3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0, field RSVD0[31:29] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD0 (29U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD0. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD0 (0xE0000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD0. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD0 (3U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0_RSVD0(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1: 0x950
 * HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_SET: 0x954 HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_CLR: 0x958
 * HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_TOG: 0x95C The Control register contains the control
 * bits for the pxp prefetch_engine sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_shift_offset_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_shift_offset_ch1_bitfields
    {
        uint32_t OFFSET0 : 5;          /*!< [4:0]  */
        uint32_t RSVD3 : 3;            /*!< [7:5]  */
        uint32_t OFFSET1 : 5;          /*!< [12:8]  */
        uint32_t RSVD2 : 3;            /*!< [15:13]  */
        uint32_t OFFSET2 : 5;          /*!< [20:16]  */
        uint32_t RSVD1 : 3;            /*!< [23:21]  */
        uint32_t OFFSET3 : 5;          /*!< [28:24]  */
        uint32_t RSVD0 : 3;            /*!< [31:29]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_shift_offset_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_ADDR(x) ((uintptr_t)(x) + 0x950U)

#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_shift_offset_ch1_t *) HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1, field OFFSET0[4:0] (RW)
 *
 * Shift Offset for channel 1 componnent 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0 (0x0000001FU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0 (5U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1(x).B.OFFSET0)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0)

/*! @brief Set the OFFSET0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1, field RSVD3[7:5] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD3 (5U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD3. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD3 (0x000000E0U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD3. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD3 (3U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD3 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD3(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1, field OFFSET1[12:8] (RW)
 *
 * Shift Offset for channel 1 componnent 1.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1 (8U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1 (0x00001F00U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1 (5U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1(x).B.OFFSET1)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1)

/*! @brief Set the OFFSET1 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1, field RSVD2[15:13] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD2 (13U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD2. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD2 (0x0000E000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD2. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD2 (3U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD2 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD2(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1, field OFFSET2[20:16] (RW)
 *
 * Shift Offset for channel 1 componnent 2.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2 (16U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2 (0x001F0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2 (5U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1(x).B.OFFSET2)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2)

/*! @brief Set the OFFSET2 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1, field RSVD1[23:21] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD1 (21U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD1. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD1 (0x00E00000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD1. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD1 (3U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD1 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD1(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1, field OFFSET3[28:24] (RW)
 *
 * Shift Offset for channel 1 componnent 3.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3 (24U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3 (0x1F000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3 (5U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1(x).B.OFFSET3)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3)

/*! @brief Set the OFFSET3 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_OFFSET3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1, field RSVD0[31:29] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD0 (29U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD0. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD0 (0xE0000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD0. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD0 (3U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD0 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1_RSVD0(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0 -  (RW)
 *
 * Reset value: 0x00008888U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0: 0x960
 * HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_SET: 0x964 HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_CLR: 0x968
 * HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_TOG: 0x96C The Control register contains the control bits
 * for the pxp prefetch_engine sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_shift_width_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_shift_width_ch0_bitfields
    {
        uint32_t WIDTH0 : 4;           /*!< [3:0]  */
        uint32_t WIDTH1 : 4;           /*!< [7:4]  */
        uint32_t WIDTH2 : 4;           /*!< [11:8]  */
        uint32_t WIDTH3 : 4;           /*!< [15:12]  */
        uint32_t RSVD0 : 16;           /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_shift_width_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_ADDR(x) ((uintptr_t)(x) + 0x960U)

#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_shift_width_ch0_t *) HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0, field WIDTH0[3:0] (RW)
 *
 * Shift Width for channel 0 componnent 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0 (0x0000000FU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0 (4U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0(x).B.WIDTH0)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0)

/*! @brief Set the WIDTH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0, field WIDTH1[7:4] (RW)
 *
 * Shift Width for channel 0 componnent 1.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1 (4U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1 (0x000000F0U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1 (4U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0(x).B.WIDTH1)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1)

/*! @brief Set the WIDTH1 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0, field WIDTH2[11:8] (RW)
 *
 * Shift Width for channel 0 componnent 2.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2 (8U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2 (0x00000F00U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2 (4U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0(x).B.WIDTH2)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2)

/*! @brief Set the WIDTH2 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0, field WIDTH3[15:12] (RW)
 *
 * Shift Width for channel 0 componnent 3.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3 (12U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3 (0x0000F000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3 (4U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0(x).B.WIDTH3)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3)

/*! @brief Set the WIDTH3 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_WIDTH3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0, field RSVD0[31:16] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RSVD0 (16U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RSVD0. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RSVD0 (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RSVD0. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RSVD0 (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0_RSVD0(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1 -  (RW)
 *
 * Reset value: 0x00008888U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1: 0x970
 * HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_SET: 0x974 HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_CLR: 0x978
 * HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_TOG: 0x97C The Control register contains the control bits
 * for the pxp prefetch_engine sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_shift_width_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_shift_width_ch1_bitfields
    {
        uint32_t WIDTH0 : 4;           /*!< [3:0]  */
        uint32_t WIDTH1 : 4;           /*!< [7:4]  */
        uint32_t WIDTH2 : 4;           /*!< [11:8]  */
        uint32_t WIDTH3 : 4;           /*!< [15:12]  */
        uint32_t RSVD0 : 16;           /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_shift_width_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_ADDR(x) ((uintptr_t)(x) + 0x970U)

#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_shift_width_ch1_t *) HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1, field WIDTH0[3:0] (RW)
 *
 * Shift Width for channel 1 componnent 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0 (0x0000000FU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0 (4U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1(x).B.WIDTH0)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0)

/*! @brief Set the WIDTH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1, field WIDTH1[7:4] (RW)
 *
 * Shift Width for channel 1 componnent 1.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1 (4U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1 (0x000000F0U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1 (4U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1(x).B.WIDTH1)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1)

/*! @brief Set the WIDTH1 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1, field WIDTH2[11:8] (RW)
 *
 * Shift Width for channel 1 componnent 2.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2 (8U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2 (0x00000F00U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2 (4U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1(x).B.WIDTH2)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2)

/*! @brief Set the WIDTH2 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1, field WIDTH3[15:12] (RW)
 *
 * Shift Width for channel 1 componnent 3.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3 (12U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3 (0x0000F000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3 (4U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1(x).B.WIDTH3)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3. */
#define BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3) & BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3)

/*! @brief Set the WIDTH3 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3) | BF_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_WIDTH3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1, field RSVD0[31:16] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RSVD0 (16U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RSVD0. */
#define BM_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RSVD0 (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RSVD0. */
#define BS_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RSVD0 (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RSVD0 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1_RSVD0(x) (HW_PXP_HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_addr_0_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_addr_0_ch0_bitfields
    {
        uint32_t INPUT_BASE_ADDR0 : 32; /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_addr_0_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_ADDR(x) ((uintptr_t)(x) + 0x980U)

#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_addr_0_ch0_t *) HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0, field INPUT_BASE_ADDR0[31:0] (RW)
 *
 * input base address0. For 2 channel, indicated the channel0 base address. For
 * 1 channel and YUV422 2 plane, indicate the Y base address
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0. */
#define BM_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0. */
#define BS_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0(x) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0. */
#define BF_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0) & BM_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0)

/*! @brief Set the INPUT_BASE_ADDR0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_INPUT_BASE_ADDR0(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_addr_1_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_addr_1_ch0_bitfields
    {
        uint32_t INPUT_BASE_ADDR1 : 32; /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_addr_1_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_ADDR(x) ((uintptr_t)(x) + 0x990U)

#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_addr_1_ch0_t *) HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0, field INPUT_BASE_ADDR1[31:0] (RW)
 *
 * input base address1. For 2 channel, indicated the channel1 base address. For
 * 1 channel and YUV422 2 plane, indicate the UV base address
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1. */
#define BM_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1. */
#define BS_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1(x) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1. */
#define BF_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1) & BM_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1)

/*! @brief Set the INPUT_BASE_ADDR1 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_INPUT_BASE_ADDR1(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_addr_0_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_addr_0_ch1_bitfields
    {
        uint32_t INPUT_BASE_ADDR0 : 32; /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_addr_0_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_ADDR(x) ((uintptr_t)(x) + 0x9A0U)

#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_addr_0_ch1_t *) HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1, field INPUT_BASE_ADDR0[31:0] (RW)
 *
 * input base address0. For 2 channel, indicated the channel0 base address. For
 * 1 channel and YUV422 2 plane, indicate the Y base address
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0. */
#define BM_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0. */
#define BS_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0(x) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0. */
#define BF_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0) & BM_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0)

/*! @brief Set the INPUT_BASE_ADDR0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_INPUT_BASE_ADDR0(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_0_CH1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_fetch_addr_1_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_fetch_addr_1_ch1_bitfields
    {
        uint32_t INPUT_BASE_ADDR1 : 32; /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_fetch_addr_1_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_ADDR(x) ((uintptr_t)(x) + 0x9B0U)

#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1(x) (*(__IO hw_pxp_hw_pxp_dither_fetch_addr_1_ch1_t *) HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_RD(x) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1(x).U)
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_WR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_SET(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_WR(x, HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1, field INPUT_BASE_ADDR1[31:0] (RW)
 *
 * input base address1. For 2 channel, indicated the channel1 base address. For
 * 1 channel and YUV422 2 plane, indicate the UV base address
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1. */
#define BM_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1. */
#define BS_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1 field. */
#define BR_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1(x) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1. */
#define BF_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1) & BM_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1)

/*! @brief Set the INPUT_BASE_ADDR1 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_INPUT_BASE_ADDR1(x, v) (HW_PXP_HW_PXP_DITHER_FETCH_ADDR_1_CH1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0 - Store engine Control Channel 0 Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0 - Store engine Control Channel 0 Register (RW)
 *
 * Reset value: 0x00020200U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * HW_PXP_DITHER_STORE_CTRL_CH0: 0x9C0 HW_PXP_DITHER_STORE_CTRL_CH0_SET: 0x9C4
 * HW_PXP_DITHER_STORE_CTRL_CH0_CLR: 0x9C8 HW_PXP_DITHER_STORE_CTRL_CH0_TOG: 0x9CC
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_ctrl_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_ctrl_ch0_bitfields
    {
        uint32_t CH_EN : 1;            /*!< [0]  */
        uint32_t BLOCK_EN : 1;         /*!< [1]  */
        uint32_t BLOCK_16 : 1;         /*!< [2]  */
        uint32_t HANDSHAKE_EN : 1;     /*!< [3]  */
        uint32_t ARRAY_EN : 1;         /*!< [4]  */
        uint32_t ARRAY_LINE_NUM : 2;   /*!< [6:5]  */
        uint32_t RSVD3 : 1;            /*!< [7]  */
        uint32_t STORE_BYPASS_EN : 1;  /*!< [8]  */
        uint32_t STORE_MEMORY_EN : 1;  /*!< [9]  */
        uint32_t PACK_IN_SEL : 1;      /*!< [10]  */
        uint32_t FILL_DATA_EN : 1;     /*!< [11]  */
        uint32_t RSVD2 : 4;            /*!< [15:12]  */
        uint32_t WR_NUM_BYTES : 2;     /*!< [17:16]  */
        uint32_t RSVD1 : 6;            /*!< [23:18]  */
        uint32_t COMBINE_2CHANNEL : 1; /*!< [24]  */
        uint32_t RSVD0 : 6;            /*!< [30:25]  */
        uint32_t ARBIT_EN : 1;         /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_dither_store_ctrl_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_CTRL_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ADDR(x) ((uintptr_t)(x) + 0x9C0U)

#define HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_ctrl_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_CTRL_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH0, field CH_EN[0] (RW)
 *
 * Channel enable.
 *
 * Values:
 * - 0 - Store function is disable
 * - 1 - Store function is enable
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN (0x00000001U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN: Store function is disable */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN: Store function is enable */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x).B.CH_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN)

/*! @brief Set the CH_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_CH_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH0, field BLOCK_EN[1] (RW)
 *
 * Choses the store mode.
 *
 * Values:
 * - 0 - Store in scan mode
 * - 1 - Store in block mode
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN (1U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN (0x00000002U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN: Store in scan mode */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN: Store in block mode */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x).B.BLOCK_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN)

/*! @brief Set the BLOCK_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH0, field BLOCK_16[2] (RW)
 *
 * Determines the block sixe.
 *
 * Values:
 * - 0 - Block size is 8x8
 * - 1 - Block size is 16x16
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16 (2U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16 (0x00000004U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16_8x8 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16: Block size is 8x8 */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16_16x16 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16: Block size is 16x16 */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x).B.BLOCK_16)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16)

/*! @brief Set the BLOCK_16 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_BLOCK_16(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH0, field HANDSHAKE_EN[3] (RW)
 *
 * Enable bit for handshake with the store engine.
 *
 * Values:
 * - 0 - Handshake with the prefetch engine is disabled
 * - 1 - Handshake with the prefetch engine is enabled
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN (3U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN (0x00000008U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN: Handshake with the prefetch engine is disabled */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN: Handshake with the prefetch engine is enabled */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x).B.HANDSHAKE_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN)

/*! @brief Set the HANDSHAKE_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_HANDSHAKE_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH0, field ARRAY_EN[4] (RW)
 *
 * Values:
 * - 0 - Array Handshake Disabled
 * - 1 - Array Handshake Enabled
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN (4U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN (0x00000010U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN: Array Handshake Disabled */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN: Array Handshake Enabled */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x).B.ARRAY_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN)

/*! @brief Set the ARRAY_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH0, field ARRAY_LINE_NUM[6:5] (RW)
 *
 * Selects Array Size
 *
 * Values:
 * - 0 - Using 1x1 Array
 * - 1 - Using 3x3 Array
 * - 10 - Using 5x5 Array
 * - 11 - Using 5x5 Array
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM (5U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM (0x00000060U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM: Using 1x1 Array */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM: Using 3x3 Array */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM: Using 5x5 Array */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM: Using 5x5 Array */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x).B.ARRAY_LINE_NUM)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM)

/*! @brief Set the ARRAY_LINE_NUM field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARRAY_LINE_NUM(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH0, field RSVD3[7] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD3 (7U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD3. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD3 (0x00000080U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD3. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD3 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD3(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH0, field STORE_BYPASS_EN[8] (RW)
 *
 * enable bit for store bypass
 *
 * Values:
 * - 0 - store bypass mode disable.
 * - 1 - store bypass mode enable. Data will bypass to store output.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN (8U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN (0x00000100U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN: store bypass mode disable. */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN: store bypass mode enable. Data will bypass to store output. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x).B.STORE_BYPASS_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN)

/*! @brief Set the STORE_BYPASS_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_BYPASS_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH0, field STORE_MEMORY_EN[9] (RW)
 *
 * store memory enable
 *
 * Values:
 * - 0 - store memory mode disable.
 * - 1 - store memory mode enable. Data will store to memory
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN (9U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN (0x00000200U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN: store memory mode disable. */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN: store memory mode enable. Data will store to memory */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x).B.STORE_MEMORY_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN)

/*! @brief Set the STORE_MEMORY_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_STORE_MEMORY_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH0, field PACK_IN_SEL[10] (RW)
 *
 * pack_in_sel
 *
 * Values:
 * - 0 - select 64 shift out data to pack
 * - 1 - select low 32 bit shift out data to pack
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL (10U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL (0x00000400U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL: select 64 shift out data to pack */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL: select low 32 bit shift out data to pack */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x).B.PACK_IN_SEL)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL)

/*! @brief Set the PACK_IN_SEL field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_PACK_IN_SEL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH0, field FILL_DATA_EN[11] (RW)
 *
 * enable bit for fill data
 *
 * Values:
 * - 0 - Fill data mode disable.
 * - 1 - Fill data mode enable. When using fill_data mode, store_engine will
 *     store fixed data defined in fill_data register
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN (11U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN (0x00000800U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN: Fill data mode disable. */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN: Fill data mode enable. When using fill_data mode, store_engine will store fixed data defined in fill_data register */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x).B.FILL_DATA_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN)

/*! @brief Set the FILL_DATA_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_FILL_DATA_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH0, field RSVD2[15:12] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD2 (12U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD2. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD2 (0x0000F000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD2. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD2 (4U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD2 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD2(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH0, field WR_NUM_BYTES[17:16] (RW)
 *
 * Bytes in a write burst
 *
 * Values:
 * - 0 - 8 bytes
 * - 1 - 16 bytes
 * - 10 - 32 bytes
 * - 11 - 64 bytes
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES (16U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES (0x00030000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES_8_bytes (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES: 8 bytes */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES_16_bytes (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES: 16 bytes */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES_32_bytes (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES: 32 bytes */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES_64_bytes (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES: 64 bytes */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x).B.WR_NUM_BYTES)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES)

/*! @brief Set the WR_NUM_BYTES field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR_NUM_BYTES(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH0, field RSVD1[23:18] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD1 (18U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD1. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD1 (0x00FC0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD1. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD1 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD1(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH0, field COMBINE_2CHANNEL[24] (RW)
 *
 * Combine 2 channel Enable
 *
 * Values:
 * - 0 - combine 2 channel disable
 * - 1 - combine 2 channel enable
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL (24U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL (0x01000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL: combine 2 channel disable */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL: combine 2 channel enable */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x).B.COMBINE_2CHANNEL)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL)

/*! @brief Set the COMBINE_2CHANNEL field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_COMBINE_2CHANNEL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH0, field RSVD0[30:25] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD0 (25U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD0. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD0 (0x7E000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD0. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD0 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RSVD0(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH0, field ARBIT_EN[31] (RW)
 *
 * Arbitration Enable
 *
 * Values:
 * - 0 - Arbitration disable. If using 2 channels, will output 2 axi bus sets
 * - 1 - Arbitration enable. If using 2 channel, will only output 1 axi bus sets
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN (31U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN (0x80000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN: Arbitration disable. If using 2 channels, will output 2 axi bus sets */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN: Arbitration enable. If using 2 channel, will only output 1 axi bus sets */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0(x).B.ARBIT_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN)

/*! @brief Set the ARBIT_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH0_ARBIT_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1 - Store engine Control Channel 1 Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1 - Store engine Control Channel 1 Register (RW)
 *
 * Reset value: 0x00020200U
 *
 * This register defines the control bits for the pxp prefetch_engine sub-block.
 * HW_PXP_DITHER_STORE_CTRL_CH1: 0x9D0 HW_PXP_DITHER_STORE_CTRL_CH1_SET: 0x9D4
 * HW_PXP_DITHER_STORE_CTRL_CH1_CLR: 0x9D8 HW_PXP_DITHER_STORE_CTRL_CH1_TOG: 0x9DC
 * The Control register contains the control bits for the pxp prefetch_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_ctrl_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_ctrl_ch1_bitfields
    {
        uint32_t CH_EN : 1;            /*!< [0]  */
        uint32_t BLOCK_EN : 1;         /*!< [1]  */
        uint32_t BLOCK_16 : 1;         /*!< [2]  */
        uint32_t HANDSHAKE_EN : 1;     /*!< [3]  */
        uint32_t ARRAY_EN : 1;         /*!< [4]  */
        uint32_t ARRAY_LINE_NUM : 2;   /*!< [6:5]  */
        uint32_t RSVD3 : 1;            /*!< [7]  */
        uint32_t STORE_BYPASS_EN : 1;  /*!< [8]  */
        uint32_t STORE_MEMORY_EN : 1;  /*!< [9]  */
        uint32_t PACK_IN_SEL : 1;      /*!< [10]  */
        uint32_t RSVD1 : 5;            /*!< [15:11]  */
        uint32_t WR_NUM_BYTES : 2;     /*!< [17:16]  */
        uint32_t RSVD0 : 14;           /*!< [31:18]  */
    } B;
} hw_pxp_hw_pxp_dither_store_ctrl_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_CTRL_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ADDR(x) ((uintptr_t)(x) + 0x9D0U)

#define HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1(x) (*(__IO hw_pxp_hw_pxp_dither_store_ctrl_ch1_t *) HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR(x, HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR(x, HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR(x, HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_CTRL_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH1, field CH_EN[0] (RW)
 *
 * Channel enable.
 *
 * Values:
 * - 0 - Store function is disable
 * - 1 - Store function is enable
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN (0x00000001U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN: Store function is disable */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN: Store function is enable */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1(x).B.CH_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN)

/*! @brief Set the CH_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_CH_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH1, field BLOCK_EN[1] (RW)
 *
 * Choses the store mode.
 *
 * Values:
 * - 0 - Store in scan mode
 * - 1 - Store in block mode
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN (1U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN (0x00000002U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN: Store in scan mode */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN: Store in block mode */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1(x).B.BLOCK_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN)

/*! @brief Set the BLOCK_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH1, field BLOCK_16[2] (RW)
 *
 * Determines the block sixe.
 *
 * Values:
 * - 0 - Block size is 8x8
 * - 1 - Block size is 16x16
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16 (2U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16 (0x00000004U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16_8x8 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16: Block size is 8x8 */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16_16x16 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16: Block size is 16x16 */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1(x).B.BLOCK_16)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16)

/*! @brief Set the BLOCK_16 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_BLOCK_16(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH1, field HANDSHAKE_EN[3] (RW)
 *
 * Enable bit for handshake with the fetch engine.
 *
 * Values:
 * - 0 - Handshake with the fetch engine is disabled
 * - 1 - Handshake with the fetch engine is enabled
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN (3U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN (0x00000008U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN: Handshake with the fetch engine is disabled */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN: Handshake with the fetch engine is enabled */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1(x).B.HANDSHAKE_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN)

/*! @brief Set the HANDSHAKE_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_HANDSHAKE_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH1, field ARRAY_EN[4] (RW)
 *
 * Values:
 * - 0 - Array Handshake Disabled
 * - 1 - Array Handshake Enabled
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN (4U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN (0x00000010U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN: Array Handshake Disabled */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN: Array Handshake Enabled */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1(x).B.ARRAY_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN)

/*! @brief Set the ARRAY_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH1, field ARRAY_LINE_NUM[6:5] (RW)
 *
 * Selects Array Size
 *
 * Values:
 * - 0 - Using 1x1 Array
 * - 1 - Using 3x3 Array
 * - 10 - Using 5x5 Array
 * - 11 - Using 5x5 Array
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM (5U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM (0x00000060U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM: Using 1x1 Array */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM: Using 3x3 Array */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM: Using 5x5 Array */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM: Using 5x5 Array */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1(x).B.ARRAY_LINE_NUM)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM)

/*! @brief Set the ARRAY_LINE_NUM field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_ARRAY_LINE_NUM(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH1, field RSVD3[7] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD3 (7U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD3. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD3 (0x00000080U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD3. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD3 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD3(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH1, field STORE_BYPASS_EN[8] (RW)
 *
 * enable bit for store bypass
 *
 * Values:
 * - 0 - store bypass mode disable.
 * - 1 - store bypass mode enable. Data will bypass to store output.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN (8U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN (0x00000100U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN: store bypass mode disable. */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN: store bypass mode enable. Data will bypass to store output. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1(x).B.STORE_BYPASS_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN)

/*! @brief Set the STORE_BYPASS_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_BYPASS_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH1, field STORE_MEMORY_EN[9] (RW)
 *
 * store memory enable
 *
 * Values:
 * - 0 - store memory mode disable.
 * - 1 - store memory mode enable. Data will store to memory
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN (9U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN (0x00000200U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN: store memory mode disable. */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN: store memory mode enable. Data will store to memory */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1(x).B.STORE_MEMORY_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN)

/*! @brief Set the STORE_MEMORY_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_STORE_MEMORY_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH1, field PACK_IN_SEL[10] (RW)
 *
 * pack_in_sel
 *
 * Values:
 * - 0 - select 64 shift out data to pack
 * - 1 - select channel 0 high 32 bit shift out data to pack
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL (10U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL (0x00000400U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL: select 64 shift out data to pack */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL: select channel 0 high 32 bit shift out data to pack */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1(x).B.PACK_IN_SEL)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL)

/*! @brief Set the PACK_IN_SEL field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_PACK_IN_SEL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH1, field RSVD1[15:11] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD1 (11U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD1. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD1 (0x0000F800U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD1. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD1 (5U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD1 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD1(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH1, field WR_NUM_BYTES[17:16] (RW)
 *
 * Bytes in a write burst
 *
 * Values:
 * - 0 - 8 bytes
 * - 1 - 16 bytes
 * - 10 - 32 bytes
 * - 11 - 64 bytes
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES (16U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES (0x00030000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES. */

#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES_8_bytes (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES: 8 bytes */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES_16_bytes (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES: 16 bytes */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES_32_bytes (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES: 32 bytes */
#define BV_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES_64_bytes (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES: 64 bytes */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1(x).B.WR_NUM_BYTES)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES. */
#define BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES) & BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES)

/*! @brief Set the WR_NUM_BYTES field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES(x, v) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES) | BF_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_WR_NUM_BYTES(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_CTRL_CH1, field RSVD0[31:18] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD0 (18U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD0. */
#define BM_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD0 (0xFFFC0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD0. */
#define BS_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD0 (14U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_CTRL_CH1_RSVD0(x) (HW_PXP_HW_PXP_DITHER_STORE_CTRL_CH1(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH0 - Store engine status Channel 0 Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH0 - Store engine status Channel 0 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the status bits for the pxp store_engine sub-block. The
 * Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_status_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_status_ch0_bitfields
    {
        uint32_t STORE_BLOCK_X : 16;   /*!< [15:0]  */
        uint32_t STORE_BLOCK_Y : 16;   /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_dither_store_status_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_STATUS_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH0_ADDR(x) ((uintptr_t)(x) + 0x9E0U)

#define HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH0(x) (*(__I hw_pxp_hw_pxp_dither_store_status_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH0(x).U)
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_STATUS_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_STATUS_CH0, field STORE_BLOCK_X[15:0] (RO)
 *
 * When in scan mode, this field is always 0. In block mode, it indicates the X
 * coordinate of the block currently being rendered.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_X (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_X. */
#define BM_PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_X (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_X. */
#define BS_PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_X (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_X. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_X field. */
#define BR_PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_X(x) (HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH0(x).B.STORE_BLOCK_X)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_STATUS_CH0, field STORE_BLOCK_Y[31:16] (RO)
 *
 * When in scan mode, this field indicates the current Y coordinate of the
 * frame. In block mode, it indicates the Y coordinate of the block currently being
 * rendered.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_Y (16U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_Y. */
#define BM_PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_Y (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_Y. */
#define BS_PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_Y (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_Y. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_Y field. */
#define BR_PXP_HW_PXP_DITHER_STORE_STATUS_CH0_STORE_BLOCK_Y(x) (HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH0(x).B.STORE_BLOCK_Y)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH1 - Store engine status Channel 1 Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH1 - Store engine status Channel 1 Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the status bits for the pxp store_engine sub-block. The
 * Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_status_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_status_ch1_bitfields
    {
        uint32_t STORE_BLOCK_X : 16;   /*!< [15:0]  */
        uint32_t STORE_BLOCK_Y : 16;   /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_dither_store_status_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_STATUS_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH1_ADDR(x) ((uintptr_t)(x) + 0x9F0U)

#define HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH1(x) (*(__I hw_pxp_hw_pxp_dither_store_status_ch1_t *) HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH1_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH1_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH1(x).U)
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_STATUS_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_STATUS_CH1, field STORE_BLOCK_X[15:0] (RO)
 *
 * When in scan mode, this field is always 0. In block mode, it indicates the X
 * coordinate of the block currently being rendered.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_X (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_X. */
#define BM_PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_X (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_X. */
#define BS_PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_X (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_X. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_X field. */
#define BR_PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_X(x) (HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH1(x).B.STORE_BLOCK_X)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_STATUS_CH1, field STORE_BLOCK_Y[31:16] (RO)
 *
 * When in scan mode, this field indicates the current Y coordinate of the
 * frame. In block mode, it indicates the Y coordinate of the block currently being
 * rendered.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_Y (16U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_Y. */
#define BM_PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_Y (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_Y. */
#define BS_PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_Y (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_Y. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_Y field. */
#define BR_PXP_HW_PXP_DITHER_STORE_STATUS_CH1_STORE_BLOCK_Y(x) (HW_PXP_HW_PXP_DITHER_STORE_STATUS_CH1(x).B.STORE_BLOCK_Y)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_size_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_size_ch0_bitfields
    {
        uint32_t OUT_WIDTH : 16;       /*!< [15:0]  */
        uint32_t OUT_HEIGHT : 16;      /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_dither_store_size_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_SIZE_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_ADDR(x) ((uintptr_t)(x) + 0xA00U)

#define HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_size_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_SIZE_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_SIZE_CH0, field OUT_WIDTH[15:0] (RW)
 *
 * actual output width -1
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH. */
#define BM_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH. */
#define BS_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH field. */
#define BR_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH(x) (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0(x).B.OUT_WIDTH)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH. */
#define BF_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH) & BM_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH)

/*! @brief Set the OUT_WIDTH field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH) | BF_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_WIDTH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_SIZE_CH0, field OUT_HEIGHT[31:16] (RW)
 *
 * actual output height -1
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT (16U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT. */
#define BM_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT. */
#define BS_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT field. */
#define BR_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT(x) (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0(x).B.OUT_HEIGHT)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT. */
#define BF_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT) & BM_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT)

/*! @brief Set the OUT_HEIGHT field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT) | BF_PXP_HW_PXP_DITHER_STORE_SIZE_CH0_OUT_HEIGHT(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_size_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_size_ch1_bitfields
    {
        uint32_t OUT_WIDTH : 16;       /*!< [15:0]  */
        uint32_t OUT_HEIGHT : 16;      /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_dither_store_size_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_SIZE_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_ADDR(x) ((uintptr_t)(x) + 0xA10U)

#define HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1(x) (*(__IO hw_pxp_hw_pxp_dither_store_size_ch1_t *) HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_WR(x, HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_WR(x, HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_WR(x, HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_SIZE_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_SIZE_CH1, field OUT_WIDTH[15:0] (RW)
 *
 * actual output width -1
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH. */
#define BM_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH. */
#define BS_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH field. */
#define BR_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH(x) (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1(x).B.OUT_WIDTH)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH. */
#define BF_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH) & BM_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH)

/*! @brief Set the OUT_WIDTH field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH) | BF_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_WIDTH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_SIZE_CH1, field OUT_HEIGHT[31:16] (RW)
 *
 * actual output height -1
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT (16U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT. */
#define BM_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT. */
#define BS_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT field. */
#define BR_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT(x) (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1(x).B.OUT_HEIGHT)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT. */
#define BF_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT) & BM_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT)

/*! @brief Set the OUT_HEIGHT field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT) | BF_PXP_HW_PXP_DITHER_STORE_SIZE_CH1_OUT_HEIGHT(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_PITCH -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_PITCH -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_pitch
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_pitch_bitfields
    {
        uint32_t CH0_OUT_PITCH : 16;   /*!< [15:0]  */
        uint32_t CH1_OUT_PITCH : 16;   /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_dither_store_pitch_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_PITCH register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_PITCH_ADDR(x) ((uintptr_t)(x) + 0xA20U)

#define HW_PXP_HW_PXP_DITHER_STORE_PITCH(x) (*(__IO hw_pxp_hw_pxp_dither_store_pitch_t *) HW_PXP_HW_PXP_DITHER_STORE_PITCH_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_PITCH_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_PITCH(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_PITCH_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_PITCH(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_PITCH_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_PITCH_WR(x, HW_PXP_HW_PXP_DITHER_STORE_PITCH_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_PITCH_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_PITCH_WR(x, HW_PXP_HW_PXP_DITHER_STORE_PITCH_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_PITCH_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_PITCH_WR(x, HW_PXP_HW_PXP_DITHER_STORE_PITCH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_PITCH bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_PITCH, field CH0_OUT_PITCH[15:0] (RW)
 *
 * This field indicates the channel 0 input pitch
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH. */
#define BM_PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH (0x0000FFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH. */
#define BS_PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH field. */
#define BR_PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH(x) (HW_PXP_HW_PXP_DITHER_STORE_PITCH(x).B.CH0_OUT_PITCH)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH. */
#define BF_PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH) & BM_PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH)

/*! @brief Set the CH0_OUT_PITCH field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH(x, v) (HW_PXP_HW_PXP_DITHER_STORE_PITCH_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_PITCH_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH) | BF_PXP_HW_PXP_DITHER_STORE_PITCH_CH0_OUT_PITCH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_PITCH, field CH1_OUT_PITCH[31:16] (RW)
 *
 * This field indicates the channel 1 input pitch
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH (16U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH. */
#define BM_PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH. */
#define BS_PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH (16U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH field. */
#define BR_PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH(x) (HW_PXP_HW_PXP_DITHER_STORE_PITCH(x).B.CH1_OUT_PITCH)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH. */
#define BF_PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH) & BM_PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH)

/*! @brief Set the CH1_OUT_PITCH field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH(x, v) (HW_PXP_HW_PXP_DITHER_STORE_PITCH_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_PITCH_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH) | BF_PXP_HW_PXP_DITHER_STORE_PITCH_CH1_OUT_PITCH(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0: 0xA30
 * HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SET: 0xA34 HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_CLR: 0xA38
 * HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_TOG: 0xA3C The Control register contains the control bits for the
 * pxp store_engine sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_shift_ctrl_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_shift_ctrl_ch0_bitfields
    {
        uint32_t RSVD2 : 2;            /*!< [1:0]  */
        uint32_t OUTPUT_ACTIVE_BPP : 2; /*!< [3:2]  */
        uint32_t OUT_YUV422_1P_EN : 1; /*!< [4]  */
        uint32_t OUT_YUV422_2P_EN : 1; /*!< [5]  */
        uint32_t RSVD1 : 1;            /*!< [6]  */
        uint32_t SHIFT_BYPASS : 1;     /*!< [7]  */
        uint32_t RSVD0 : 24;           /*!< [31:8]  */
    } B;
} hw_pxp_hw_pxp_dither_store_shift_ctrl_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_ADDR(x) ((uintptr_t)(x) + 0xA30U)

#define HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_shift_ctrl_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0, field RSVD2[1:0] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD2 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD2. */
#define BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD2 (0x00000003U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD2. */
#define BS_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD2 (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD2 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD2(x) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0, field OUTPUT_ACTIVE_BPP[3:2] (RW)
 *
 * Values:
 * - 0 - 8 bits
 * - 1 - 16 bits
 * - 10 - 32 bits
 * - 11 - 32 bits
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP (2U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP. */
#define BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP (0x0000000CU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP. */
#define BS_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP. */

#define BV_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP: 8 bits */
#define BV_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP: 16 bits */
#define BV_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP: 32 bits */
#define BV_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP: 32 bits */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP field. */
#define BR_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP(x) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0(x).B.OUTPUT_ACTIVE_BPP)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP. */
#define BF_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP) & BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP)

/*! @brief Set the OUTPUT_ACTIVE_BPP field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP) | BF_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUTPUT_ACTIVE_BPP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0, field OUT_YUV422_1P_EN[4] (RW)
 *
 * Enable for YUV422 1 plane
 *
 * Values:
 * - 0 - YUYV422 2 plane disabled.
 * - 1 - YUYV422 2 plane enabled.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN (4U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN. */
#define BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN (0x00000010U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN. */
#define BS_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN. */

#define BV_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN: YUYV422 2 plane disabled. */
#define BV_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN: YUYV422 2 plane enabled. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN field. */
#define BR_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN(x) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0(x).B.OUT_YUV422_1P_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN. */
#define BF_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN) & BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN)

/*! @brief Set the OUT_YUV422_1P_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN) | BF_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_1P_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0, field OUT_YUV422_2P_EN[5] (RW)
 *
 * Enable for YUV422 2 plane
 *
 * Values:
 * - 0 - YUYV422 2 plane disabled.
 * - 1 - YUYV422 2 plane enabled.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN (5U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN. */
#define BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN (0x00000020U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN. */
#define BS_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN. */

#define BV_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN: YUYV422 2 plane disabled. */
#define BV_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN: YUYV422 2 plane enabled. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN field. */
#define BR_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN(x) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0(x).B.OUT_YUV422_2P_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN. */
#define BF_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN) & BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN)

/*! @brief Set the OUT_YUV422_2P_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN) | BF_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_OUT_YUV422_2P_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0, field RSVD1[6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD1 (6U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD1. */
#define BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD1 (0x00000040U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD1. */
#define BS_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD1 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD1(x) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0, field SHIFT_BYPASS[7] (RW)
 *
 * CH0 shift bypass
 *
 * Values:
 * - 0 - data will do shift processing.
 * - 1 - data will bypass shift module.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS (7U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS. */
#define BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS (0x00000080U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS. */
#define BS_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS. */

#define BV_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS: data will do shift processing. */
#define BV_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS: data will bypass shift module. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS field. */
#define BR_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS(x) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0(x).B.SHIFT_BYPASS)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS. */
#define BF_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS) & BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS)

/*! @brief Set the SHIFT_BYPASS field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS) | BF_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_SHIFT_BYPASS(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0, field RSVD0[31:8] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD0 (8U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD0. */
#define BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD0 (0xFFFFFF00U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD0. */
#define BS_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD0 (24U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0_RSVD0(x) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1: 0xA40
 * HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_SET: 0xA44 HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_CLR: 0xA48
 * HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_TOG: 0xA4C The Control register contains the control bits for the
 * pxp prefetch_engine sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_shift_ctrl_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_shift_ctrl_ch1_bitfields
    {
        uint32_t RSVD2 : 2;            /*!< [1:0]  */
        uint32_t OUTPUT_ACTIVE_BPP : 2; /*!< [3:2]  */
        uint32_t OUT_YUV422_1P_EN : 1; /*!< [4]  */
        uint32_t OUT_YUV422_2P_EN : 1; /*!< [5]  */
        uint32_t RSVD0 : 26;           /*!< [31:6]  */
    } B;
} hw_pxp_hw_pxp_dither_store_shift_ctrl_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_ADDR(x) ((uintptr_t)(x) + 0xA40U)

#define HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1(x) (*(__IO hw_pxp_hw_pxp_dither_store_shift_ctrl_ch1_t *) HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_WR(x, HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_WR(x, HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_WR(x, HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1, field RSVD2[1:0] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD2 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD2. */
#define BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD2 (0x00000003U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD2. */
#define BS_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD2 (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD2 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD2(x) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1, field OUTPUT_ACTIVE_BPP[3:2] (RW)
 *
 * Values:
 * - 0 - 8 bits
 * - 1 - 16 bits
 * - 10 - 32 bits
 * - 11 - 32 bits
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP (2U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP. */
#define BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP (0x0000000CU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP. */
#define BS_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP. */

#define BV_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP: 8 bits */
#define BV_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP: 16 bits */
#define BV_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP: 32 bits */
#define BV_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP: 32 bits */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP field. */
#define BR_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP(x) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1(x).B.OUTPUT_ACTIVE_BPP)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP. */
#define BF_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP) & BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP)

/*! @brief Set the OUTPUT_ACTIVE_BPP field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP) | BF_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUTPUT_ACTIVE_BPP(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1, field OUT_YUV422_1P_EN[4] (RW)
 *
 * Enable for YUV422 1 plane
 *
 * Values:
 * - 0 - YUYV422 2 plane disabled.
 * - 1 - YUYV422 2 plane enabled.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN (4U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN. */
#define BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN (0x00000010U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN. */
#define BS_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN. */

#define BV_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN: YUYV422 2 plane disabled. */
#define BV_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN: YUYV422 2 plane enabled. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN field. */
#define BR_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN(x) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1(x).B.OUT_YUV422_1P_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN. */
#define BF_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN) & BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN)

/*! @brief Set the OUT_YUV422_1P_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN) | BF_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_1P_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1, field OUT_YUV422_2P_EN[5] (RW)
 *
 * Enable for YUV422 2 plane
 *
 * Values:
 * - 0 - YUYV422 2 plane disabled.
 * - 1 - YUYV422 2 plane enabled.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN (5U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN. */
#define BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN (0x00000020U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN. */
#define BS_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN. */

#define BV_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN: YUYV422 2 plane disabled. */
#define BV_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN: YUYV422 2 plane enabled. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN field. */
#define BR_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN(x) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1(x).B.OUT_YUV422_2P_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN. */
#define BF_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN) & BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN)

/*! @brief Set the OUT_YUV422_2P_EN field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN(x, v) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN) | BF_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_OUT_YUV422_2P_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1, field RSVD0[31:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD0 (6U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD0. */
#define BM_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD0 (0xFFFFFFC0U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD0. */
#define BS_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD0 (26U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1_RSVD0(x) (HW_PXP_HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_addr_0_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_addr_0_ch0_bitfields
    {
        uint32_t OUT_BASE_ADDR0 : 32;  /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_addr_0_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_ADDR(x) ((uintptr_t)(x) + 0xA90U)

#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_addr_0_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0, field OUT_BASE_ADDR0[31:0] (RW)
 *
 * input base address0. For 2 channel, indicated the channel0 base address. For
 * 1 channel and YUV422 2 plane, indicate the Y base address
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_OUT_BASE_ADDR0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_OUT_BASE_ADDR0. */
#define BM_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_OUT_BASE_ADDR0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_OUT_BASE_ADDR0. */
#define BS_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_OUT_BASE_ADDR0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_OUT_BASE_ADDR0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_OUT_BASE_ADDR0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_OUT_BASE_ADDR0(x) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_OUT_BASE_ADDR0. */
#define BF_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_OUT_BASE_ADDR0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_OUT_BASE_ADDR0) & BM_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_OUT_BASE_ADDR0)

/*! @brief Set the OUT_BASE_ADDR0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_OUT_BASE_ADDR0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_addr_1_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_addr_1_ch0_bitfields
    {
        uint32_t OUT_BASE_ADDR1 : 32;  /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_addr_1_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_ADDR(x) ((uintptr_t)(x) + 0xAA0U)

#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_addr_1_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0, field OUT_BASE_ADDR1[31:0] (RW)
 *
 * input base address1. For 2 channel, indicated the channel 1 base address. For
 * 1 channel and YUV422 2 plane, indicate the UV base address
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_OUT_BASE_ADDR1 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_OUT_BASE_ADDR1. */
#define BM_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_OUT_BASE_ADDR1 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_OUT_BASE_ADDR1. */
#define BS_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_OUT_BASE_ADDR1 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_OUT_BASE_ADDR1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_OUT_BASE_ADDR1 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_OUT_BASE_ADDR1(x) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_OUT_BASE_ADDR1. */
#define BF_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_OUT_BASE_ADDR1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_OUT_BASE_ADDR1) & BM_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_OUT_BASE_ADDR1)

/*! @brief Set the OUT_BASE_ADDR1 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_OUT_BASE_ADDR1(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_fill_data_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_fill_data_ch0_bitfields
    {
        uint32_t FILL_DATA_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_fill_data_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_ADDR(x) ((uintptr_t)(x) + 0xAB0U)

#define HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_fill_data_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0, field FILL_DATA_CH0[31:0] (RW)
 *
 * when using fill_data mode,store engine channel0 will store the fill_data
 * value defined here.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_FILL_DATA_CH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_FILL_DATA_CH0. */
#define BM_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_FILL_DATA_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_FILL_DATA_CH0. */
#define BS_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_FILL_DATA_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_FILL_DATA_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_FILL_DATA_CH0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_FILL_DATA_CH0(x) (HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_FILL_DATA_CH0. */
#define BF_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_FILL_DATA_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_FILL_DATA_CH0) & BM_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_FILL_DATA_CH0)

/*! @brief Set the FILL_DATA_CH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_FILL_DATA_CH0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_FILL_DATA_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_addr_0_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_addr_0_ch1_bitfields
    {
        uint32_t OUT_BASE_ADDR0 : 32;  /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_addr_0_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_ADDR(x) ((uintptr_t)(x) + 0xAC0U)

#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1(x) (*(__IO hw_pxp_hw_pxp_dither_store_addr_0_ch1_t *) HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_WR(x, HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_WR(x, HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_WR(x, HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1, field OUT_BASE_ADDR0[31:0] (RW)
 *
 * input base address0. For 2 channel, indicated the channel0 base address. For
 * 1 channel and YUV422 2 plane, indicate the Y base address
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_OUT_BASE_ADDR0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_OUT_BASE_ADDR0. */
#define BM_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_OUT_BASE_ADDR0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_OUT_BASE_ADDR0. */
#define BS_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_OUT_BASE_ADDR0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_OUT_BASE_ADDR0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_OUT_BASE_ADDR0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_OUT_BASE_ADDR0(x) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_OUT_BASE_ADDR0. */
#define BF_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_OUT_BASE_ADDR0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_OUT_BASE_ADDR0) & BM_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_OUT_BASE_ADDR0)

/*! @brief Set the OUT_BASE_ADDR0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_OUT_BASE_ADDR0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_0_CH1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_addr_1_ch1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_addr_1_ch1_bitfields
    {
        uint32_t OUT_BASE_ADDR1 : 32;  /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_addr_1_ch1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_ADDR(x) ((uintptr_t)(x) + 0xAD0U)

#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1(x) (*(__IO hw_pxp_hw_pxp_dither_store_addr_1_ch1_t *) HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_WR(x, HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_WR(x, HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_WR(x, HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1, field OUT_BASE_ADDR1[31:0] (RW)
 *
 * input base address1. For 2 channel, indicated the channel 1 base address. For
 * 1 channel and YUV422 2 plane, indicate the UV base address
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_OUT_BASE_ADDR1 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_OUT_BASE_ADDR1. */
#define BM_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_OUT_BASE_ADDR1 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_OUT_BASE_ADDR1. */
#define BS_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_OUT_BASE_ADDR1 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_OUT_BASE_ADDR1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_OUT_BASE_ADDR1 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_OUT_BASE_ADDR1(x) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_OUT_BASE_ADDR1. */
#define BF_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_OUT_BASE_ADDR1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_OUT_BASE_ADDR1) & BM_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_OUT_BASE_ADDR1)

/*! @brief Set the OUT_BASE_ADDR1 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_OUT_BASE_ADDR1(x, v) (HW_PXP_HW_PXP_DITHER_STORE_ADDR_1_CH1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_d_mask0_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_d_mask0_h_ch0_bitfields
    {
        uint32_t D_MASK0_H_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_d_mask0_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_ADDR(x) ((uintptr_t)(x) + 0xAE0U)

#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_d_mask0_h_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0, field D_MASK0_H_CH0[31:0] (RW)
 *
 * data mask0 high byte
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0) & BM_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0)

/*! @brief Set the D_MASK0_H_CH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_D_MASK0_H_CH0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_H_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_d_mask0_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_d_mask0_l_ch0_bitfields
    {
        uint32_t D_MASK0_L_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_d_mask0_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_ADDR(x) ((uintptr_t)(x) + 0xAF0U)

#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_d_mask0_l_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0, field D_MASK0_L_CH0[31:0] (RW)
 *
 * data mask0 low byte
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0) & BM_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0)

/*! @brief Set the D_MASK0_L_CH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_D_MASK0_L_CH0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK0_L_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_d_mask1_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_d_mask1_h_ch0_bitfields
    {
        uint32_t D_MASK1_H_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_d_mask1_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_ADDR(x) ((uintptr_t)(x) + 0xB00U)

#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_d_mask1_h_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0, field D_MASK1_H_CH0[31:0] (RW)
 *
 * data mask1 high byte
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0) & BM_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0)

/*! @brief Set the D_MASK1_H_CH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_D_MASK1_H_CH0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_H_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_d_mask1_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_d_mask1_l_ch0_bitfields
    {
        uint32_t D_MASK1_L_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_d_mask1_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_ADDR(x) ((uintptr_t)(x) + 0xB10U)

#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_d_mask1_l_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0, field D_MASK1_L_CH0[31:0] (RW)
 *
 * data mask1 low byte
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0) & BM_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0)

/*! @brief Set the D_MASK1_L_CH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_D_MASK1_L_CH0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK1_L_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_d_mask2_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_d_mask2_h_ch0_bitfields
    {
        uint32_t D_MASK2_H_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_d_mask2_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_ADDR(x) ((uintptr_t)(x) + 0xB20U)

#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_d_mask2_h_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0, field D_MASK2_H_CH0[31:0] (RW)
 *
 * data mask2 high byte
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0) & BM_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0)

/*! @brief Set the D_MASK2_H_CH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_D_MASK2_H_CH0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_H_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_d_mask2_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_d_mask2_l_ch0_bitfields
    {
        uint32_t D_MASK2_L_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_d_mask2_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_ADDR(x) ((uintptr_t)(x) + 0xB30U)

#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_d_mask2_l_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0, field D_MASK2_L_CH0[31:0] (RW)
 *
 * data mask2 low byte
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0) & BM_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0)

/*! @brief Set the D_MASK2_L_CH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_D_MASK2_L_CH0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK2_L_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_d_mask3_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_d_mask3_h_ch0_bitfields
    {
        uint32_t D_MASK3_H_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_d_mask3_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_ADDR(x) ((uintptr_t)(x) + 0xB40U)

#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_d_mask3_h_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0, field D_MASK3_H_CH0[31:0] (RW)
 *
 * data mask3 high byte
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0) & BM_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0)

/*! @brief Set the D_MASK3_H_CH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_D_MASK3_H_CH0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_H_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_d_mask3_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_d_mask3_l_ch0_bitfields
    {
        uint32_t D_MASK3_L_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_d_mask3_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_ADDR(x) ((uintptr_t)(x) + 0xB50U)

#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_d_mask3_l_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0, field D_MASK3_L_CH0[31:0] (RW)
 *
 * data mask3 low byte
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0) & BM_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0)

/*! @brief Set the D_MASK3_L_CH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_D_MASK3_L_CH0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK3_L_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_d_mask4_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_d_mask4_h_ch0_bitfields
    {
        uint32_t D_MASK4_H_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_d_mask4_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_ADDR(x) ((uintptr_t)(x) + 0xB60U)

#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_d_mask4_h_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0, field D_MASK4_H_CH0[31:0] (RW)
 *
 * data mask4 high byte
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0) & BM_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0)

/*! @brief Set the D_MASK4_H_CH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_D_MASK4_H_CH0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_H_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_d_mask4_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_d_mask4_l_ch0_bitfields
    {
        uint32_t D_MASK4_L_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_d_mask4_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_ADDR(x) ((uintptr_t)(x) + 0xB70U)

#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_d_mask4_l_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0, field D_MASK4_L_CH0[31:0] (RW)
 *
 * data mask4 low byte
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0) & BM_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0)

/*! @brief Set the D_MASK4_L_CH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_D_MASK4_L_CH0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK4_L_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_d_mask5_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_d_mask5_h_ch0_bitfields
    {
        uint32_t D_MASK5_H_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_d_mask5_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_ADDR(x) ((uintptr_t)(x) + 0xB80U)

#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_d_mask5_h_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0, field D_MASK5_H_CH0[31:0] (RW)
 *
 * data mask5 high byte
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0) & BM_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0)

/*! @brief Set the D_MASK5_H_CH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_D_MASK5_H_CH0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_H_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_d_mask5_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_d_mask5_l_ch0_bitfields
    {
        uint32_t D_MASK5_L_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_d_mask5_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_ADDR(x) ((uintptr_t)(x) + 0xB90U)

#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_d_mask5_l_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0, field D_MASK5_L_CH0[31:0] (RW)
 *
 * data mask5 low byte
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0) & BM_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0)

/*! @brief Set the D_MASK5_L_CH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_D_MASK5_L_CH0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK5_L_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_d_mask6_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_d_mask6_h_ch0_bitfields
    {
        uint32_t D_MASK6_H_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_d_mask6_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_ADDR(x) ((uintptr_t)(x) + 0xBA0U)

#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_d_mask6_h_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0, field D_MASK6_H_CH0[31:0] (RW)
 *
 * data mask6 high byte
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0) & BM_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0)

/*! @brief Set the D_MASK6_H_CH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_D_MASK6_H_CH0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_H_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_d_mask6_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_d_mask6_l_ch0_bitfields
    {
        uint32_t D_MASK6_L_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_d_mask6_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_ADDR(x) ((uintptr_t)(x) + 0xBB0U)

#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_d_mask6_l_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0, field D_MASK6_L_CH0[31:0] (RW)
 *
 * data mask6 low byte
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0) & BM_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0)

/*! @brief Set the D_MASK6_L_CH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_D_MASK6_L_CH0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK6_L_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_d_mask7_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_d_mask7_h_ch0_bitfields
    {
        uint32_t D_MASK7_H_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_d_mask7_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_ADDR(x) ((uintptr_t)(x) + 0xBC0U)

#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_d_mask7_h_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0, field D_MASK7_H_CH0[31:0] (RW)
 *
 * data mask7 high byte
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0) & BM_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0)

/*! @brief Set the D_MASK7_H_CH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_D_MASK7_H_CH0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_H_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_d_mask7_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_d_mask7_l_ch0_bitfields
    {
        uint32_t D_MASK7_L_CH0 : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_dither_store_d_mask7_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_ADDR(x) ((uintptr_t)(x) + 0xBD0U)

#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_d_mask7_l_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0, field D_MASK7_L_CH0[31:0] (RW)
 *
 * data mask7 low byte
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0) & BM_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0)

/*! @brief Set the D_MASK7_L_CH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_D_MASK7_L_CH0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_MASK7_L_CH0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_d_shift_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_d_shift_l_ch0_bitfields
    {
        uint32_t D_SHIFT_WIDTH0 : 6;   /*!< [5:0]  */
        uint32_t RSVD3 : 1;            /*!< [6]  */
        uint32_t D_SHIFT_FLAG0 : 1;    /*!< [7]  */
        uint32_t D_SHIFT_WIDTH1 : 6;   /*!< [13:8]  */
        uint32_t RSVD2 : 1;            /*!< [14]  */
        uint32_t D_SHIFT_FLAG1 : 1;    /*!< [15]  */
        uint32_t D_SHIFT_WIDTH2 : 6;   /*!< [21:16]  */
        uint32_t RSVD1 : 1;            /*!< [22]  */
        uint32_t D_SHIFT_FLAG2 : 1;    /*!< [23]  */
        uint32_t D_SHIFT_WIDTH3 : 6;   /*!< [29:24]  */
        uint32_t RSVD0 : 1;            /*!< [30]  */
        uint32_t D_SHIFT_FLAG3 : 1;    /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_dither_store_d_shift_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_ADDR(x) ((uintptr_t)(x) + 0xBE0U)

#define HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_d_shift_l_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0, field D_SHIFT_WIDTH0[5:0] (RW)
 *
 * data shift width 0
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0(x).B.D_SHIFT_WIDTH0)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0) & BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0)

/*! @brief Set the D_SHIFT_WIDTH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0) | BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0, field RSVD3[6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD3 (6U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD3. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD3 (0x00000040U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD3. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD3 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD3(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0, field D_SHIFT_FLAG0[7] (RW)
 *
 * data shift flag 0
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0 (7U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0 (0x00000080U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0(x).B.D_SHIFT_FLAG0)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0) & BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0)

/*! @brief Set the D_SHIFT_FLAG0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0) | BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0, field D_SHIFT_WIDTH1[13:8] (RW)
 *
 * data shift width 1
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1 (8U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0(x).B.D_SHIFT_WIDTH1)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1) & BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1)

/*! @brief Set the D_SHIFT_WIDTH1 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1) | BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0, field RSVD2[14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD2 (14U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD2. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD2 (0x00004000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD2. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD2 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD2 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD2(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0, field D_SHIFT_FLAG1[15] (RW)
 *
 * data shift flag 1
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1 (15U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1 (0x00008000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0(x).B.D_SHIFT_FLAG1)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1) & BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1)

/*! @brief Set the D_SHIFT_FLAG1 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1) | BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0, field D_SHIFT_WIDTH2[21:16] (RW)
 *
 * data shift width 2
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2 (16U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0(x).B.D_SHIFT_WIDTH2)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2) & BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2)

/*! @brief Set the D_SHIFT_WIDTH2 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2) | BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0, field RSVD1[22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD1 (22U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD1. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD1 (0x00400000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD1. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD1 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD1(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0, field D_SHIFT_FLAG2[23] (RW)
 *
 * data shift flag 2
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2 (23U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2 (0x00800000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0(x).B.D_SHIFT_FLAG2)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2) & BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2)

/*! @brief Set the D_SHIFT_FLAG2 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2) | BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0, field D_SHIFT_WIDTH3[29:24] (RW)
 *
 * data shift width 3
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3 (24U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0(x).B.D_SHIFT_WIDTH3)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3) & BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3)

/*! @brief Set the D_SHIFT_WIDTH3 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3) | BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_WIDTH3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0, field RSVD0[30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD0 (30U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD0 (0x40000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD0 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RSVD0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0, field D_SHIFT_FLAG3[31] (RW)
 *
 * data shift flag 3
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3 (31U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3 (0x80000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0(x).B.D_SHIFT_FLAG3)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3) & BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3)

/*! @brief Set the D_SHIFT_FLAG3 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3) | BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_L_CH0_D_SHIFT_FLAG3(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_d_shift_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_d_shift_h_ch0_bitfields
    {
        uint32_t D_SHIFT_WIDTH4 : 6;   /*!< [5:0]  */
        uint32_t RSVD3 : 1;            /*!< [6]  */
        uint32_t D_SHIFT_FLAG4 : 1;    /*!< [7]  */
        uint32_t D_SHIFT_WIDTH5 : 6;   /*!< [13:8]  */
        uint32_t RSVD2 : 1;            /*!< [14]  */
        uint32_t D_SHIFT_FLAG5 : 1;    /*!< [15]  */
        uint32_t D_SHIFT_WIDTH6 : 6;   /*!< [21:16]  */
        uint32_t RSVD1 : 1;            /*!< [22]  */
        uint32_t D_SHIFT_FLAG6 : 1;    /*!< [23]  */
        uint32_t D_SHIFT_WIDTH7 : 6;   /*!< [29:24]  */
        uint32_t RSVD0 : 1;            /*!< [30]  */
        uint32_t D_SHIFT_FLAG7 : 1;    /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_dither_store_d_shift_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_ADDR(x) ((uintptr_t)(x) + 0xBF0U)

#define HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_d_shift_h_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0, field D_SHIFT_WIDTH4[5:0] (RW)
 *
 * data shift width 4
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0(x).B.D_SHIFT_WIDTH4)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4) & BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4)

/*! @brief Set the D_SHIFT_WIDTH4 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4) | BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH4(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0, field RSVD3[6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD3 (6U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD3. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD3 (0x00000040U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD3. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD3 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD3(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0, field D_SHIFT_FLAG4[7] (RW)
 *
 * data shift flag 4
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4 (7U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4 (0x00000080U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0(x).B.D_SHIFT_FLAG4)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4) & BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4)

/*! @brief Set the D_SHIFT_FLAG4 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4) | BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG4(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0, field D_SHIFT_WIDTH5[13:8] (RW)
 *
 * data shift width 5
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5 (8U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0(x).B.D_SHIFT_WIDTH5)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5) & BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5)

/*! @brief Set the D_SHIFT_WIDTH5 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5) | BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH5(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0, field RSVD2[14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD2 (14U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD2. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD2 (0x00004000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD2. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD2 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD2 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD2(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0, field D_SHIFT_FLAG5[15] (RW)
 *
 * data shift flag 5
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5 (15U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5 (0x00008000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0(x).B.D_SHIFT_FLAG5)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5) & BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5)

/*! @brief Set the D_SHIFT_FLAG5 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5) | BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG5(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0, field D_SHIFT_WIDTH6[21:16] (RW)
 *
 * data shift width 6
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6 (16U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0(x).B.D_SHIFT_WIDTH6)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6) & BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6)

/*! @brief Set the D_SHIFT_WIDTH6 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6) | BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH6(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0, field RSVD1[22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD1 (22U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD1. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD1 (0x00400000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD1. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD1 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD1(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0, field D_SHIFT_FLAG6[23] (RW)
 *
 * data shift flag 6
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6 (23U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6 (0x00800000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0(x).B.D_SHIFT_FLAG6)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6) & BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6)

/*! @brief Set the D_SHIFT_FLAG6 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6) | BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG6(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0, field D_SHIFT_WIDTH7[29:24] (RW)
 *
 * data shift width 3
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7 (24U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0(x).B.D_SHIFT_WIDTH7)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7) & BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7)

/*! @brief Set the D_SHIFT_WIDTH7 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7) | BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_WIDTH7(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0, field RSVD0[30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD0 (30U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD0. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD0 (0x40000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD0. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD0 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RSVD0(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0, field D_SHIFT_FLAG7[31] (RW)
 *
 * data shift flag 7
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7 (31U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7. */
#define BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7 (0x80000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7. */
#define BS_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7(x) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0(x).B.D_SHIFT_FLAG7)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7. */
#define BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7) & BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7)

/*! @brief Set the D_SHIFT_FLAG7 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7(x, v) (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7) | BF_PXP_HW_PXP_DITHER_STORE_D_SHIFT_H_CH0_D_SHIFT_FLAG7(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_f_shift_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_f_shift_l_ch0_bitfields
    {
        uint32_t F_SHIFT_WIDTH0 : 6;   /*!< [5:0]  */
        uint32_t F_SHIFT_FLAG0 : 1;    /*!< [6]  */
        uint32_t RSVD3 : 1;            /*!< [7]  */
        uint32_t F_SHIFT_WIDTH1 : 6;   /*!< [13:8]  */
        uint32_t F_SHIFT_FLAG1 : 1;    /*!< [14]  */
        uint32_t RSVD2 : 1;            /*!< [15]  */
        uint32_t F_SHIFT_WIDTH2 : 6;   /*!< [21:16]  */
        uint32_t F_SHIFT_FLAG2 : 1;    /*!< [22]  */
        uint32_t RSVD1 : 1;            /*!< [23]  */
        uint32_t F_SHIFT_WIDTH3 : 6;   /*!< [29:24]  */
        uint32_t F_SHIFT_FLAG3 : 1;    /*!< [30]  */
        uint32_t RSVD0 : 1;            /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_dither_store_f_shift_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_ADDR(x) ((uintptr_t)(x) + 0xC00U)

#define HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_f_shift_l_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0, field F_SHIFT_WIDTH0[5:0] (RW)
 *
 * flag shift width 0
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0(x).B.F_SHIFT_WIDTH0)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0) & BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0)

/*! @brief Set the F_SHIFT_WIDTH0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0) | BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0, field F_SHIFT_FLAG0[6] (RW)
 *
 * flag shift flag0
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0 (6U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0 (0x00000040U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0(x).B.F_SHIFT_FLAG0)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0) & BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0)

/*! @brief Set the F_SHIFT_FLAG0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0) | BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0, field RSVD3[7] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD3 (7U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD3. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD3 (0x00000080U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD3. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD3 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD3(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0, field F_SHIFT_WIDTH1[13:8] (RW)
 *
 * flag shift width 1
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1 (8U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0(x).B.F_SHIFT_WIDTH1)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1) & BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1)

/*! @brief Set the F_SHIFT_WIDTH1 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1) | BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0, field F_SHIFT_FLAG1[14] (RW)
 *
 * flag shift flag1
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1 (14U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1 (0x00004000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0(x).B.F_SHIFT_FLAG1)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1) & BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1)

/*! @brief Set the F_SHIFT_FLAG1 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1) | BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0, field RSVD2[15] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD2 (15U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD2. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD2 (0x00008000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD2. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD2 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD2 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD2(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0, field F_SHIFT_WIDTH2[21:16] (RW)
 *
 * flag shift width 2
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2 (16U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0(x).B.F_SHIFT_WIDTH2)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2) & BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2)

/*! @brief Set the F_SHIFT_WIDTH2 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2) | BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0, field F_SHIFT_FLAG2[22] (RW)
 *
 * flag shift flag2
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2 (22U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2 (0x00400000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0(x).B.F_SHIFT_FLAG2)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2) & BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2)

/*! @brief Set the F_SHIFT_FLAG2 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2) | BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0, field RSVD1[23] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD1 (23U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD1. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD1 (0x00800000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD1. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD1 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD1(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0, field F_SHIFT_WIDTH3[29:24] (RW)
 *
 * flag shift width 3
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3 (24U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0(x).B.F_SHIFT_WIDTH3)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3) & BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3)

/*! @brief Set the F_SHIFT_WIDTH3 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3) | BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_WIDTH3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0, field F_SHIFT_FLAG3[30] (RW)
 *
 * flag shift flag3
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3 (30U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3 (0x40000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0(x).B.F_SHIFT_FLAG3)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3) & BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3)

/*! @brief Set the F_SHIFT_FLAG3 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3) | BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_F_SHIFT_FLAG3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0, field RSVD0[31] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD0 (31U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD0. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD0 (0x80000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD0. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD0 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0_RSVD0(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_L_CH0(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_f_shift_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_f_shift_h_ch0_bitfields
    {
        uint32_t F_SHIFT_WIDTH4 : 6;   /*!< [5:0]  */
        uint32_t F_SHIFT_FLAG4 : 1;    /*!< [6]  */
        uint32_t RSVD3 : 1;            /*!< [7]  */
        uint32_t F_SHIFT_WIDTH5 : 6;   /*!< [13:8]  */
        uint32_t F_SHIFT_FLAG5 : 1;    /*!< [14]  */
        uint32_t RSVD2 : 1;            /*!< [15]  */
        uint32_t F_SHIFT_WIDTH6 : 6;   /*!< [21:16]  */
        uint32_t F_SHIFT_FLAG6 : 1;    /*!< [22]  */
        uint32_t RSVD1 : 1;            /*!< [23]  */
        uint32_t F_SHIFT_WIDTH7 : 6;   /*!< [29:24]  */
        uint32_t F_SHIFT_FLAG7 : 1;    /*!< [30]  */
        uint32_t RSVD0 : 1;            /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_dither_store_f_shift_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_ADDR(x) ((uintptr_t)(x) + 0xC10U)

#define HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_f_shift_h_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0, field F_SHIFT_WIDTH4[5:0] (RW)
 *
 * flag shift width 4
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0(x).B.F_SHIFT_WIDTH4)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4) & BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4)

/*! @brief Set the F_SHIFT_WIDTH4 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4) | BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH4(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0, field F_SHIFT_FLAG4[6] (RW)
 *
 * flag shift flag4
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4 (6U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4 (0x00000040U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0(x).B.F_SHIFT_FLAG4)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4) & BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4)

/*! @brief Set the F_SHIFT_FLAG4 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4) | BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG4(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0, field RSVD3[7] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD3 (7U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD3. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD3 (0x00000080U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD3. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD3 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD3(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0, field F_SHIFT_WIDTH5[13:8] (RW)
 *
 * flag shift width 5
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5 (8U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0(x).B.F_SHIFT_WIDTH5)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5) & BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5)

/*! @brief Set the F_SHIFT_WIDTH5 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5) | BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH5(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0, field F_SHIFT_FLAG5[14] (RW)
 *
 * flag shift flag5
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5 (14U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5 (0x00004000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0(x).B.F_SHIFT_FLAG5)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5) & BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5)

/*! @brief Set the F_SHIFT_FLAG5 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5) | BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG5(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0, field RSVD2[15] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD2 (15U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD2. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD2 (0x00008000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD2. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD2 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD2 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD2(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0, field F_SHIFT_WIDTH6[21:16] (RW)
 *
 * flag shift width 5
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6 (16U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0(x).B.F_SHIFT_WIDTH6)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6) & BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6)

/*! @brief Set the F_SHIFT_WIDTH6 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6) | BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH6(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0, field F_SHIFT_FLAG6[22] (RW)
 *
 * flag shift flag6
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6 (22U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6 (0x00400000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0(x).B.F_SHIFT_FLAG6)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6) & BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6)

/*! @brief Set the F_SHIFT_FLAG6 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6) | BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG6(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0, field RSVD1[23] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD1 (23U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD1. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD1 (0x00800000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD1. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD1 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD1(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0, field F_SHIFT_WIDTH7[29:24] (RW)
 *
 * flag shift width 7
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7 (24U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7 (6U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0(x).B.F_SHIFT_WIDTH7)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7) & BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7)

/*! @brief Set the F_SHIFT_WIDTH7 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7) | BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_WIDTH7(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0, field F_SHIFT_FLAG7[30] (RW)
 *
 * flag shift flag7
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7 (30U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7 (0x40000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0(x).B.F_SHIFT_FLAG7)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7) & BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7)

/*! @brief Set the F_SHIFT_FLAG7 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7) | BF_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_F_SHIFT_FLAG7(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0, field RSVD0[31] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD0 (31U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD0. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD0 (0x80000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD0. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD0 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0_RSVD0(x) (HW_PXP_HW_PXP_DITHER_STORE_F_SHIFT_H_CH0(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_f_mask_l_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_f_mask_l_ch0_bitfields
    {
        uint32_t F_MASK0 : 8;          /*!< [7:0]  */
        uint32_t F_MASK1 : 8;          /*!< [15:8]  */
        uint32_t F_MASK2 : 8;          /*!< [23:16]  */
        uint32_t F_MASK3 : 8;          /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_dither_store_f_mask_l_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_ADDR(x) ((uintptr_t)(x) + 0xC20U)

#define HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_f_mask_l_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0, field F_MASK0[7:0] (RW)
 *
 * flag mask0
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0 (0x000000FFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0(x) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0(x).B.F_MASK0)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0) & BM_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0)

/*! @brief Set the F_MASK0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0) | BF_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0, field F_MASK1[15:8] (RW)
 *
 * flag mask1
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1 (8U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1 (0x0000FF00U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1(x) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0(x).B.F_MASK1)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1) & BM_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1)

/*! @brief Set the F_MASK1 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1) | BF_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0, field F_MASK2[23:16] (RW)
 *
 * flag mask2
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2 (16U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2 (0x00FF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2(x) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0(x).B.F_MASK2)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2) & BM_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2)

/*! @brief Set the F_MASK2 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2) | BF_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0, field F_MASK3[31:24] (RW)
 *
 * flag mask3
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3 (24U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3(x) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0(x).B.F_MASK3)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3) & BM_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3)

/*! @brief Set the F_MASK3 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3) | BF_PXP_HW_PXP_DITHER_STORE_F_MASK_L_CH0_F_MASK3(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp store_engine sub-block.
 * The Control register contains the control bits for the pxp store_engine
 * sub-block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_store_f_mask_h_ch0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_store_f_mask_h_ch0_bitfields
    {
        uint32_t F_MASK4 : 8;          /*!< [7:0]  */
        uint32_t F_MASK5 : 8;          /*!< [15:8]  */
        uint32_t F_MASK6 : 8;          /*!< [23:16]  */
        uint32_t F_MASK7 : 8;          /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_dither_store_f_mask_h_ch0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_ADDR(x) ((uintptr_t)(x) + 0xC30U)

#define HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0(x) (*(__IO hw_pxp_hw_pxp_dither_store_f_mask_h_ch0_t *) HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_RD(x) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0(x).U)
#define HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_WR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_SET(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_WR(x, HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0, field F_MASK4[7:0] (RW)
 *
 * flag mask4
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4 (0x000000FFU) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4(x) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0(x).B.F_MASK4)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4) & BM_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4)

/*! @brief Set the F_MASK4 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4) | BF_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK4(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0, field F_MASK5[15:8] (RW)
 *
 * flag mask5
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5 (8U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5 (0x0000FF00U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5(x) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0(x).B.F_MASK5)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5) & BM_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5)

/*! @brief Set the F_MASK5 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5) | BF_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK5(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0, field F_MASK6[23:16] (RW)
 *
 * flag mask6
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6 (16U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6 (0x00FF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6(x) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0(x).B.F_MASK6)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6) & BM_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6)

/*! @brief Set the F_MASK6 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6) | BF_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK6(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0, field F_MASK7[31:24] (RW)
 *
 * flag mask7
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7 (24U) /*!< Bit position for PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7. */
#define BM_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7. */
#define BS_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7 field. */
#define BR_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7(x) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0(x).B.F_MASK7)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7. */
#define BF_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7) & BM_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7)

/*! @brief Set the F_MASK7 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7(x, v) (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_WR(x, (HW_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_RD(x) & ~BM_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7) | BF_PXP_HW_PXP_DITHER_STORE_F_MASK_H_CH0_F_MASK7(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_CTRL - Dither Control Register 0
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_CTRL - Dither Control Register 0 (RW)
 *
 * Reset value: 0x00544000U
 *
 * This register defines the control bits for the pxp dither sub-block.
 * HW_PXP_DITHER_CTRL: 0x1670 HW_PXP_DITHER_CTRL_SET: 0x1674 HW_PXP_DITHER_CTRL_CLR:
 * 0x1678 HW_PXP_DITHER_CTRL_TOG: 0x167C The Control register contains the primary
 * controls for the PXP block. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_ctrl
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_ctrl_bitfields
    {
        uint32_t ENABLE0 : 1;          /*!< [0]  */
        uint32_t ENABLE1 : 1;          /*!< [1]  */
        uint32_t ENABLE2 : 1;          /*!< [2]  */
        uint32_t DITHER_MODE0 : 3;     /*!< [5:3]  */
        uint32_t DITHER_MODE1 : 3;     /*!< [8:6]  */
        uint32_t DITHER_MODE2 : 3;     /*!< [11:9]  */
        uint32_t NUM_QUANT_BIT : 3;    /*!< [14:12]  */
        uint32_t LUT_MODE : 2;         /*!< [16:15]  */
        uint32_t IDX_MATRIX0_SIZE : 2; /*!< [18:17]  */
        uint32_t IDX_MATRIX1_SIZE : 2; /*!< [20:19]  */
        uint32_t IDX_MATRIX2_SIZE : 2; /*!< [22:21]  */
        uint32_t FINAL_LUT_ENABLE : 1; /*!< [23]  */
        uint32_t ORDERED_ROUND_MODE : 1; /*!< [24]  */
        uint32_t RSVD0 : 4;            /*!< [28:25]  */
        uint32_t BUSY2 : 1;            /*!< [29]  */
        uint32_t BUSY1 : 1;            /*!< [30]  */
        uint32_t BUSY0 : 1;            /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_dither_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_CTRL register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_CTRL_ADDR(x) ((uintptr_t)(x) + 0x1670U)

#define HW_PXP_HW_PXP_DITHER_CTRL(x) (*(__IO hw_pxp_hw_pxp_dither_ctrl_t *) HW_PXP_HW_PXP_DITHER_CTRL_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_CTRL_RD(x) (HW_PXP_HW_PXP_DITHER_CTRL(x).U)
#define HW_PXP_HW_PXP_DITHER_CTRL_WR(x, v) (HW_PXP_HW_PXP_DITHER_CTRL(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_CTRL_SET(x, v) (HW_PXP_HW_PXP_DITHER_CTRL_WR(x, HW_PXP_HW_PXP_DITHER_CTRL_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_CTRL_CLR(x, v) (HW_PXP_HW_PXP_DITHER_CTRL_WR(x, HW_PXP_HW_PXP_DITHER_CTRL_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_CTRL_TOG(x, v) (HW_PXP_HW_PXP_DITHER_CTRL_WR(x, HW_PXP_HW_PXP_DITHER_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_CTRL bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_CTRL, field ENABLE0[0] (RW)
 *
 * Enables the dither engine 0
 *
 * Values:
 * - 0 - The dither engine 0 will not process any frames.
 * - 1 - The dither engine 0 is on and ready for processing
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_CTRL_ENABLE0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_CTRL_ENABLE0. */
#define BM_PXP_HW_PXP_DITHER_CTRL_ENABLE0 (0x00000001U) /*!< Bit mask for PXP_HW_PXP_DITHER_CTRL_ENABLE0. */
#define BS_PXP_HW_PXP_DITHER_CTRL_ENABLE0 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_CTRL_ENABLE0. */

#define BV_PXP_HW_PXP_DITHER_CTRL_ENABLE0_Disabled (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_ENABLE0: The dither engine 0 will not process any frames. */
#define BV_PXP_HW_PXP_DITHER_CTRL_ENABLE0_Enabled (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_ENABLE0: The dither engine 0 is on and ready for processing */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_CTRL_ENABLE0 field. */
#define BR_PXP_HW_PXP_DITHER_CTRL_ENABLE0(x) (HW_PXP_HW_PXP_DITHER_CTRL(x).B.ENABLE0)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_CTRL_ENABLE0. */
#define BF_PXP_HW_PXP_DITHER_CTRL_ENABLE0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_CTRL_ENABLE0) & BM_PXP_HW_PXP_DITHER_CTRL_ENABLE0)

/*! @brief Set the ENABLE0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_CTRL_ENABLE0(x, v) (HW_PXP_HW_PXP_DITHER_CTRL_WR(x, (HW_PXP_HW_PXP_DITHER_CTRL_RD(x) & ~BM_PXP_HW_PXP_DITHER_CTRL_ENABLE0) | BF_PXP_HW_PXP_DITHER_CTRL_ENABLE0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_CTRL, field ENABLE1[1] (RW)
 *
 * Enables the dither engine 1
 *
 * Values:
 * - 0 - The dither engine 1 will not process any frames.
 * - 1 - The dither engine 1 is on and ready for processing
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_CTRL_ENABLE1 (1U) /*!< Bit position for PXP_HW_PXP_DITHER_CTRL_ENABLE1. */
#define BM_PXP_HW_PXP_DITHER_CTRL_ENABLE1 (0x00000002U) /*!< Bit mask for PXP_HW_PXP_DITHER_CTRL_ENABLE1. */
#define BS_PXP_HW_PXP_DITHER_CTRL_ENABLE1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_CTRL_ENABLE1. */

#define BV_PXP_HW_PXP_DITHER_CTRL_ENABLE1_Disabled (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_ENABLE1: The dither engine 1 will not process any frames. */
#define BV_PXP_HW_PXP_DITHER_CTRL_ENABLE1_Enabled (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_ENABLE1: The dither engine 1 is on and ready for processing */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_CTRL_ENABLE1 field. */
#define BR_PXP_HW_PXP_DITHER_CTRL_ENABLE1(x) (HW_PXP_HW_PXP_DITHER_CTRL(x).B.ENABLE1)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_CTRL_ENABLE1. */
#define BF_PXP_HW_PXP_DITHER_CTRL_ENABLE1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_CTRL_ENABLE1) & BM_PXP_HW_PXP_DITHER_CTRL_ENABLE1)

/*! @brief Set the ENABLE1 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_CTRL_ENABLE1(x, v) (HW_PXP_HW_PXP_DITHER_CTRL_WR(x, (HW_PXP_HW_PXP_DITHER_CTRL_RD(x) & ~BM_PXP_HW_PXP_DITHER_CTRL_ENABLE1) | BF_PXP_HW_PXP_DITHER_CTRL_ENABLE1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_CTRL, field ENABLE2[2] (RW)
 *
 * Enables the dither engine 2
 *
 * Values:
 * - 0 - The dither engine 2 will not process any frames.
 * - 1 - The dither engine 2 is on and ready for processing
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_CTRL_ENABLE2 (2U) /*!< Bit position for PXP_HW_PXP_DITHER_CTRL_ENABLE2. */
#define BM_PXP_HW_PXP_DITHER_CTRL_ENABLE2 (0x00000004U) /*!< Bit mask for PXP_HW_PXP_DITHER_CTRL_ENABLE2. */
#define BS_PXP_HW_PXP_DITHER_CTRL_ENABLE2 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_CTRL_ENABLE2. */

#define BV_PXP_HW_PXP_DITHER_CTRL_ENABLE2_Disabled (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_ENABLE2: The dither engine 2 will not process any frames. */
#define BV_PXP_HW_PXP_DITHER_CTRL_ENABLE2_Enabled (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_ENABLE2: The dither engine 2 is on and ready for processing */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_CTRL_ENABLE2 field. */
#define BR_PXP_HW_PXP_DITHER_CTRL_ENABLE2(x) (HW_PXP_HW_PXP_DITHER_CTRL(x).B.ENABLE2)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_CTRL_ENABLE2. */
#define BF_PXP_HW_PXP_DITHER_CTRL_ENABLE2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_CTRL_ENABLE2) & BM_PXP_HW_PXP_DITHER_CTRL_ENABLE2)

/*! @brief Set the ENABLE2 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_CTRL_ENABLE2(x, v) (HW_PXP_HW_PXP_DITHER_CTRL_WR(x, (HW_PXP_HW_PXP_DITHER_CTRL_RD(x) & ~BM_PXP_HW_PXP_DITHER_CTRL_ENABLE2) | BF_PXP_HW_PXP_DITHER_CTRL_ENABLE2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_CTRL, field DITHER_MODE0[5:3] (RW)
 *
 * Dither mode.
 *
 * Values:
 * - 0 - Pass through.
 * - 1 - Floyd-Steinberg.
 * - 10 - Atkinson.
 * - 11 - Ordered.
 * - 100 - No Dithering, quantization only.
 * - 101 - Reserved.
 * - 110 - Reserved.
 * - 111 - Reserved.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0 (3U) /*!< Bit position for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0. */
#define BM_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0 (0x00000038U) /*!< Bit mask for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0. */
#define BS_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0 (3U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0. */

#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0: Pass through. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0: Floyd-Steinberg. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0: Atkinson. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0: Ordered. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0_4 (0x4U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0: No Dithering, quantization only. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0_5 (0x5U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0: Reserved. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0_6 (0x6U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0: Reserved. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0_7 (0x7U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0: Reserved. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0 field. */
#define BR_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0(x) (HW_PXP_HW_PXP_DITHER_CTRL(x).B.DITHER_MODE0)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0. */
#define BF_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0) & BM_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0)

/*! @brief Set the DITHER_MODE0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0(x, v) (HW_PXP_HW_PXP_DITHER_CTRL_WR(x, (HW_PXP_HW_PXP_DITHER_CTRL_RD(x) & ~BM_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0) | BF_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_CTRL, field DITHER_MODE1[8:6] (RW)
 *
 * Dither mode.
 *
 * Values:
 * - 0 - Pass through.
 * - 1 - Reserved.
 * - 10 - Reserved
 * - 11 - Ordered.
 * - 100 - No Dithering, quantization only.
 * - 101 - Reserved.
 * - 110 - Reserved.
 * - 111 - Reserved.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1 (6U) /*!< Bit position for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1. */
#define BM_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1 (0x000001C0U) /*!< Bit mask for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1. */
#define BS_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1 (3U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1. */

#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1: Pass through. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1: Reserved. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1: Reserved */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1: Ordered. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1_4 (0x4U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1: No Dithering, quantization only. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1_5 (0x5U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1: Reserved. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1_6 (0x6U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1: Reserved. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1_7 (0x7U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1: Reserved. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1 field. */
#define BR_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1(x) (HW_PXP_HW_PXP_DITHER_CTRL(x).B.DITHER_MODE1)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1. */
#define BF_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1) & BM_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1)

/*! @brief Set the DITHER_MODE1 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1(x, v) (HW_PXP_HW_PXP_DITHER_CTRL_WR(x, (HW_PXP_HW_PXP_DITHER_CTRL_RD(x) & ~BM_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1) | BF_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_CTRL, field DITHER_MODE2[11:9] (RW)
 *
 * Dither mode.
 *
 * Values:
 * - 0 - Pass through.
 * - 1 - Reserved.
 * - 10 - Reserved.
 * - 11 - Ordered.
 * - 100 - No Dithering, quantization only.
 * - 101 - Reserved.
 * - 110 - Reserved.
 * - 111 - Reserved.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2 (9U) /*!< Bit position for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2. */
#define BM_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2 (0x00000E00U) /*!< Bit mask for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2. */
#define BS_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2 (3U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2. */

#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2: Pass through. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2: Reserved. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2: Reserved. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2: Ordered. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2_4 (0x4U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2: No Dithering, quantization only. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2_5 (0x5U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2: Reserved. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2_6 (0x6U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2: Reserved. */
#define BV_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2_7 (0x7U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2: Reserved. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2 field. */
#define BR_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2(x) (HW_PXP_HW_PXP_DITHER_CTRL(x).B.DITHER_MODE2)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2. */
#define BF_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2) & BM_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2)

/*! @brief Set the DITHER_MODE2 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2(x, v) (HW_PXP_HW_PXP_DITHER_CTRL_WR(x, (HW_PXP_HW_PXP_DITHER_CTRL_RD(x) & ~BM_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2) | BF_PXP_HW_PXP_DITHER_CTRL_DITHER_MODE2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_CTRL, field NUM_QUANT_BIT[14:12] (RW)
 *
 * Number of bits to quantize down to. From 8 to (0-7).
 *
 * Values:
 * - 0 - Reserved.
 * - 1 - Quantize down to 1 bit.
 * - 10 - Quantize down to 2 bits.
 * - 11 - Quantize down to 3 bits.
 * - 100 - Quantize down to 4 bits.
 * - 101 - Quantize down to 5 bits.
 * - 110 - Quantize down to 6 bits.
 * - 111 - Quantize down to 7 bits.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT (12U) /*!< Bit position for PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT. */
#define BM_PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT (0x00007000U) /*!< Bit mask for PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT. */
#define BS_PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT (3U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT. */

#define BV_PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT: Reserved. */
#define BV_PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT: Quantize down to 1 bit. */
#define BV_PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT: Quantize down to 2 bits. */
#define BV_PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT: Quantize down to 3 bits. */
#define BV_PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT_4 (0x4U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT: Quantize down to 4 bits. */
#define BV_PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT_5 (0x5U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT: Quantize down to 5 bits. */
#define BV_PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT_6 (0x6U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT: Quantize down to 6 bits. */
#define BV_PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT_7 (0x7U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT: Quantize down to 7 bits. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT field. */
#define BR_PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT(x) (HW_PXP_HW_PXP_DITHER_CTRL(x).B.NUM_QUANT_BIT)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT. */
#define BF_PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT) & BM_PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT)

/*! @brief Set the NUM_QUANT_BIT field to a new value. */
#define BW_PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT(x, v) (HW_PXP_HW_PXP_DITHER_CTRL_WR(x, (HW_PXP_HW_PXP_DITHER_CTRL_RD(x) & ~BM_PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT) | BF_PXP_HW_PXP_DITHER_CTRL_NUM_QUANT_BIT(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_CTRL, field LUT_MODE[16:15] (RW)
 *
 * Specify to use memory lut to transform pixel. Lookup pre or post dithering
 * cannot be used with Ordered dithering. This field only has reference to the
 * internal memory based LUT function. There is a final stage LUT that is enabled
 * through the FINAL_LUT_ENABLE field in this register. This final stage LUT can be
 * enabled in any dither mode or LUT mode.
 *
 * Values:
 * - 0 - LUT mode off.
 * - 1 - Use LUT at pre-diter stage.
 * - 10 - Use LUT at post-dither stage.
 * - 11 - Reserved`
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_CTRL_LUT_MODE (15U) /*!< Bit position for PXP_HW_PXP_DITHER_CTRL_LUT_MODE. */
#define BM_PXP_HW_PXP_DITHER_CTRL_LUT_MODE (0x00018000U) /*!< Bit mask for PXP_HW_PXP_DITHER_CTRL_LUT_MODE. */
#define BS_PXP_HW_PXP_DITHER_CTRL_LUT_MODE (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_CTRL_LUT_MODE. */

#define BV_PXP_HW_PXP_DITHER_CTRL_LUT_MODE_0 (0U)    /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_LUT_MODE: LUT mode off. */
#define BV_PXP_HW_PXP_DITHER_CTRL_LUT_MODE_1 (0x1U)  /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_LUT_MODE: Use LUT at pre-diter stage. */
#define BV_PXP_HW_PXP_DITHER_CTRL_LUT_MODE_2 (0x2U)  /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_LUT_MODE: Use LUT at post-dither stage. */
#define BV_PXP_HW_PXP_DITHER_CTRL_LUT_MODE_3 (0x3U)  /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_LUT_MODE: Reserved` */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_CTRL_LUT_MODE field. */
#define BR_PXP_HW_PXP_DITHER_CTRL_LUT_MODE(x) (HW_PXP_HW_PXP_DITHER_CTRL(x).B.LUT_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_CTRL_LUT_MODE. */
#define BF_PXP_HW_PXP_DITHER_CTRL_LUT_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_CTRL_LUT_MODE) & BM_PXP_HW_PXP_DITHER_CTRL_LUT_MODE)

/*! @brief Set the LUT_MODE field to a new value. */
#define BW_PXP_HW_PXP_DITHER_CTRL_LUT_MODE(x, v) (HW_PXP_HW_PXP_DITHER_CTRL_WR(x, (HW_PXP_HW_PXP_DITHER_CTRL_RD(x) & ~BM_PXP_HW_PXP_DITHER_CTRL_LUT_MODE) | BF_PXP_HW_PXP_DITHER_CTRL_LUT_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_CTRL, field IDX_MATRIX0_SIZE[18:17] (RW)
 *
 * For Dither Engine 0. Specify dimension (assumed square) of the index matrix
 * in the LUT memory so proper indexing can occur.
 *
 * Values:
 * - 0 - 4x4
 * - 1 - 8x8
 * - 10 - 16x16
 * - 11 - Input value of index
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE (17U) /*!< Bit position for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE. */
#define BM_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE (0x00060000U) /*!< Bit mask for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE. */
#define BS_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE. */

#define BV_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE: 4x4 */
#define BV_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE: 8x8 */
#define BV_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE: 16x16 */
#define BV_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE: Input value of index */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE field. */
#define BR_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE(x) (HW_PXP_HW_PXP_DITHER_CTRL(x).B.IDX_MATRIX0_SIZE)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE. */
#define BF_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE) & BM_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE)

/*! @brief Set the IDX_MATRIX0_SIZE field to a new value. */
#define BW_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE(x, v) (HW_PXP_HW_PXP_DITHER_CTRL_WR(x, (HW_PXP_HW_PXP_DITHER_CTRL_RD(x) & ~BM_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE) | BF_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX0_SIZE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_CTRL, field IDX_MATRIX1_SIZE[20:19] (RW)
 *
 * For Dither Engine 1. Specify dimension (assumed square) of the index matrix
 * in the LUT memory so proper indexing can occur.
 *
 * Values:
 * - 0 - 4x4
 * - 1 - 8x8
 * - 10 - 16x16
 * - 11 - Input value of index
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE (19U) /*!< Bit position for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE. */
#define BM_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE (0x00180000U) /*!< Bit mask for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE. */
#define BS_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE. */

#define BV_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE: 4x4 */
#define BV_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE: 8x8 */
#define BV_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE: 16x16 */
#define BV_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE: Input value of index */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE field. */
#define BR_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE(x) (HW_PXP_HW_PXP_DITHER_CTRL(x).B.IDX_MATRIX1_SIZE)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE. */
#define BF_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE) & BM_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE)

/*! @brief Set the IDX_MATRIX1_SIZE field to a new value. */
#define BW_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE(x, v) (HW_PXP_HW_PXP_DITHER_CTRL_WR(x, (HW_PXP_HW_PXP_DITHER_CTRL_RD(x) & ~BM_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE) | BF_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX1_SIZE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_CTRL, field IDX_MATRIX2_SIZE[22:21] (RW)
 *
 * For Dither Engine 2. Specify dimension (assumed square) of the index matrix
 * in the LUT memory so proper indexing can occur.
 *
 * Values:
 * - 0 - 4x4
 * - 1 - 8x8
 * - 10 - 16x16
 * - 11 - Input value of index
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE (21U) /*!< Bit position for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE. */
#define BM_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE (0x00600000U) /*!< Bit mask for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE. */
#define BS_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE (2U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE. */

#define BV_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE: 4x4 */
#define BV_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE: 8x8 */
#define BV_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE_2 (0x2U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE: 16x16 */
#define BV_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE_3 (0x3U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE: Input value of index */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE field. */
#define BR_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE(x) (HW_PXP_HW_PXP_DITHER_CTRL(x).B.IDX_MATRIX2_SIZE)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE. */
#define BF_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE) & BM_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE)

/*! @brief Set the IDX_MATRIX2_SIZE field to a new value. */
#define BW_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE(x, v) (HW_PXP_HW_PXP_DITHER_CTRL_WR(x, (HW_PXP_HW_PXP_DITHER_CTRL_RD(x) & ~BM_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE) | BF_PXP_HW_PXP_DITHER_CTRL_IDX_MATRIX2_SIZE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_CTRL, field FINAL_LUT_ENABLE[23] (RW)
 *
 * Enables a final stage register based LUT at the last stage before output. the
 * lookup transform values come from register bits, not internal memory.
 * Therefore they must be setup by the user by writing to the registers before
 * processing.
 *
 * Values:
 * - 0 - The dither engine 2 will not process any frames.
 * - 1 - The dither engine 2 is on and ready for processing
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE (23U) /*!< Bit position for PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE. */
#define BM_PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE (0x00800000U) /*!< Bit mask for PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE. */
#define BS_PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE. */

#define BV_PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE_Disabled (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE: The dither engine 2 will not process any frames. */
#define BV_PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE_Enabled (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE: The dither engine 2 is on and ready for processing */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE field. */
#define BR_PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE(x) (HW_PXP_HW_PXP_DITHER_CTRL(x).B.FINAL_LUT_ENABLE)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE. */
#define BF_PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE) & BM_PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE)

/*! @brief Set the FINAL_LUT_ENABLE field to a new value. */
#define BW_PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE(x, v) (HW_PXP_HW_PXP_DITHER_CTRL_WR(x, (HW_PXP_HW_PXP_DITHER_CTRL_RD(x) & ~BM_PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE) | BF_PXP_HW_PXP_DITHER_CTRL_FINAL_LUT_ENABLE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_CTRL, field ORDERED_ROUND_MODE[24] (RW)
 *
 * For test purposes. In ordered mode only, this field specifies to use rounding
 * or truncation when calculating the ouptput pixel.
 *
 * Values:
 * - 0 - Use truncation method.
 * - 1 - Use rounding method.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE (24U) /*!< Bit position for PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE. */
#define BM_PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE (0x01000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE. */
#define BS_PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE. */

#define BV_PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE_0 (0U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE: Use truncation method. */
#define BV_PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE_1 (0x1U) /*!< Bit field value for PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE: Use rounding method. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE field. */
#define BR_PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE(x) (HW_PXP_HW_PXP_DITHER_CTRL(x).B.ORDERED_ROUND_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE. */
#define BF_PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE) & BM_PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE)

/*! @brief Set the ORDERED_ROUND_MODE field to a new value. */
#define BW_PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE(x, v) (HW_PXP_HW_PXP_DITHER_CTRL_WR(x, (HW_PXP_HW_PXP_DITHER_CTRL_RD(x) & ~BM_PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE) | BF_PXP_HW_PXP_DITHER_CTRL_ORDERED_ROUND_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_CTRL, field RSVD0[28:25] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_CTRL_RSVD0 (25U) /*!< Bit position for PXP_HW_PXP_DITHER_CTRL_RSVD0. */
#define BM_PXP_HW_PXP_DITHER_CTRL_RSVD0 (0x1E000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_CTRL_RSVD0. */
#define BS_PXP_HW_PXP_DITHER_CTRL_RSVD0 (4U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_CTRL_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_CTRL_RSVD0 field. */
#define BR_PXP_HW_PXP_DITHER_CTRL_RSVD0(x) (HW_PXP_HW_PXP_DITHER_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_CTRL, field BUSY2[29] (RO)
 *
 * When set indicates if the dither engine 2 is busy -- started but not finished
 * processing all of the pixels in the current frame.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_CTRL_BUSY2 (29U) /*!< Bit position for PXP_HW_PXP_DITHER_CTRL_BUSY2. */
#define BM_PXP_HW_PXP_DITHER_CTRL_BUSY2 (0x20000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_CTRL_BUSY2. */
#define BS_PXP_HW_PXP_DITHER_CTRL_BUSY2 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_CTRL_BUSY2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_CTRL_BUSY2 field. */
#define BR_PXP_HW_PXP_DITHER_CTRL_BUSY2(x) (HW_PXP_HW_PXP_DITHER_CTRL(x).B.BUSY2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_CTRL, field BUSY1[30] (RO)
 *
 * When set indicates if the dither engine 1 is busy -- started but not finished
 * processing all of the pixels in the current frame.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_CTRL_BUSY1 (30U) /*!< Bit position for PXP_HW_PXP_DITHER_CTRL_BUSY1. */
#define BM_PXP_HW_PXP_DITHER_CTRL_BUSY1 (0x40000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_CTRL_BUSY1. */
#define BS_PXP_HW_PXP_DITHER_CTRL_BUSY1 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_CTRL_BUSY1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_CTRL_BUSY1 field. */
#define BR_PXP_HW_PXP_DITHER_CTRL_BUSY1(x) (HW_PXP_HW_PXP_DITHER_CTRL(x).B.BUSY1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_CTRL, field BUSY0[31] (RO)
 *
 * When set indicates if the dither engine 0 is busy -- started but not finished
 * processing all of the pixels in the current frame.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_CTRL_BUSY0 (31U) /*!< Bit position for PXP_HW_PXP_DITHER_CTRL_BUSY0. */
#define BM_PXP_HW_PXP_DITHER_CTRL_BUSY0 (0x80000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_CTRL_BUSY0. */
#define BS_PXP_HW_PXP_DITHER_CTRL_BUSY0 (1U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_CTRL_BUSY0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_CTRL_BUSY0 field. */
#define BR_PXP_HW_PXP_DITHER_CTRL_BUSY0(x) (HW_PXP_HW_PXP_DITHER_CTRL(x).B.BUSY0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0 - Final stage lookup value Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0 - Final stage lookup value Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * 8 bit data values for the final stage dither LUT.
 * HW_PXP_DITHER_FINAL_LUT_DATA0: 0x1680 HW_PXP_DITHER_FINAL_LUT_DATA0_SET: 0x1684
 * HW_PXP_DITHER_FINAL_LUT_DATA0_CLR: 0x1688 HW_PXP_DITHER_FINAL_LUT_DATA0_TOG: 0x168C This register
 * contains lookup data values for the final stage register based dither LUT. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_final_lut_data0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_final_lut_data0_bitfields
    {
        uint32_t DATA0 : 8;            /*!< [7:0]  */
        uint32_t DATA1 : 8;            /*!< [15:8]  */
        uint32_t DATA2 : 8;            /*!< [23:16]  */
        uint32_t DATA3 : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_dither_final_lut_data0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FINAL_LUT_DATA0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_ADDR(x) ((uintptr_t)(x) + 0x1680U)

#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0(x) (*(__IO hw_pxp_hw_pxp_dither_final_lut_data0_t *) HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_RD(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0(x).U)
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_WR(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_SET(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_WR(x, HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_WR(x, HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_WR(x, HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FINAL_LUT_DATA0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FINAL_LUT_DATA0, field DATA0[7:0] (RW)
 *
 * Final stage LUT data value.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0. */
#define BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0 (0x000000FFU) /*!< Bit mask for PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0. */
#define BS_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0 field. */
#define BR_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0(x).B.DATA0)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0. */
#define BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0) & BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0)

/*! @brief Set the DATA0 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_WR(x, (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0) | BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FINAL_LUT_DATA0, field DATA1[15:8] (RW)
 *
 * Final stage LUT data value.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1 (8U) /*!< Bit position for PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1. */
#define BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1 (0x0000FF00U) /*!< Bit mask for PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1. */
#define BS_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1 field. */
#define BR_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0(x).B.DATA1)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1. */
#define BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1) & BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1)

/*! @brief Set the DATA1 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_WR(x, (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1) | BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FINAL_LUT_DATA0, field DATA2[23:16] (RW)
 *
 * Final stage LUT data value.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2 (16U) /*!< Bit position for PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2. */
#define BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2 (0x00FF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2. */
#define BS_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2 field. */
#define BR_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0(x).B.DATA2)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2. */
#define BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2) & BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2)

/*! @brief Set the DATA2 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_WR(x, (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2) | BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FINAL_LUT_DATA0, field DATA3[31:24] (RW)
 *
 * Final stage LUT data value.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3 (24U) /*!< Bit position for PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3. */
#define BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3. */
#define BS_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3 field. */
#define BR_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0(x).B.DATA3)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3. */
#define BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3) & BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3)

/*! @brief Set the DATA3 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_WR(x, (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_RD(x) & ~BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3) | BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA0_DATA3(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1 - Final stage lookup value Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1 - Final stage lookup value Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * 8 bit data values for the final stage dither LUT.
 * HW_PXP_DITHER_FINAL_LUT_DATA1: 0x1690 HW_PXP_DITHER_FINAL_LUT_DATA1_SET: 0x1694
 * HW_PXP_DITHER_FINAL_LUT_DATA1_CLR: 0x1698 HW_PXP_DITHER_FINAL_LUT_DATA1_TOG: 0x169C This register
 * contains lookup data values for the final stage register based dither LUT. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_final_lut_data1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_final_lut_data1_bitfields
    {
        uint32_t DATA4 : 8;            /*!< [7:0]  */
        uint32_t DATA5 : 8;            /*!< [15:8]  */
        uint32_t DATA6 : 8;            /*!< [23:16]  */
        uint32_t DATA7 : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_dither_final_lut_data1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FINAL_LUT_DATA1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_ADDR(x) ((uintptr_t)(x) + 0x1690U)

#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1(x) (*(__IO hw_pxp_hw_pxp_dither_final_lut_data1_t *) HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_RD(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1(x).U)
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_WR(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_SET(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_WR(x, HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_WR(x, HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_WR(x, HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FINAL_LUT_DATA1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FINAL_LUT_DATA1, field DATA4[7:0] (RW)
 *
 * Final stage LUT data value.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4. */
#define BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4 (0x000000FFU) /*!< Bit mask for PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4. */
#define BS_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4 field. */
#define BR_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1(x).B.DATA4)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4. */
#define BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4) & BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4)

/*! @brief Set the DATA4 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_WR(x, (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4) | BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA4(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FINAL_LUT_DATA1, field DATA5[15:8] (RW)
 *
 * Final stage LUT data value.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5 (8U) /*!< Bit position for PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5. */
#define BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5 (0x0000FF00U) /*!< Bit mask for PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5. */
#define BS_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5 field. */
#define BR_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1(x).B.DATA5)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5. */
#define BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5) & BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5)

/*! @brief Set the DATA5 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_WR(x, (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5) | BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA5(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FINAL_LUT_DATA1, field DATA6[23:16] (RW)
 *
 * Final stage LUT data value.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6 (16U) /*!< Bit position for PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6. */
#define BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6 (0x00FF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6. */
#define BS_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6 field. */
#define BR_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1(x).B.DATA6)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6. */
#define BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6) & BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6)

/*! @brief Set the DATA6 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_WR(x, (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6) | BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA6(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FINAL_LUT_DATA1, field DATA7[31:24] (RW)
 *
 * Final stage LUT data value.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7 (24U) /*!< Bit position for PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7. */
#define BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7. */
#define BS_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7 field. */
#define BR_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1(x).B.DATA7)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7. */
#define BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7) & BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7)

/*! @brief Set the DATA7 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_WR(x, (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_RD(x) & ~BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7) | BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA1_DATA7(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2 - Final stage lookup value Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2 - Final stage lookup value Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * 8 bit data values for the final stage dither LUT.
 * HW_PXP_DITHER_FINAL_LUT_DATA2: 0x16A0 HW_PXP_DITHER_FINAL_LUT_DATA2_SET: 0x16A4
 * HW_PXP_DITHER_FINAL_LUT_DATA2_CLR: 0x16A8 HW_PXP_DITHER_FINAL_LUT_DATA2_TOG: 0x16AC This register
 * contains lookup data values for the final stage register based dither LUT. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_final_lut_data2
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_final_lut_data2_bitfields
    {
        uint32_t DATA8 : 8;            /*!< [7:0]  */
        uint32_t DATA9 : 8;            /*!< [15:8]  */
        uint32_t DATA10 : 8;           /*!< [23:16]  */
        uint32_t DATA11 : 8;           /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_dither_final_lut_data2_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FINAL_LUT_DATA2 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_ADDR(x) ((uintptr_t)(x) + 0x16A0U)

#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2(x) (*(__IO hw_pxp_hw_pxp_dither_final_lut_data2_t *) HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_RD(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2(x).U)
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_WR(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_SET(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_WR(x, HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_WR(x, HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_WR(x, HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FINAL_LUT_DATA2 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FINAL_LUT_DATA2, field DATA8[7:0] (RW)
 *
 * Final stage LUT data value.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8. */
#define BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8 (0x000000FFU) /*!< Bit mask for PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8. */
#define BS_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8 field. */
#define BR_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2(x).B.DATA8)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8. */
#define BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8) & BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8)

/*! @brief Set the DATA8 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_WR(x, (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_RD(x) & ~BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8) | BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA8(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FINAL_LUT_DATA2, field DATA9[15:8] (RW)
 *
 * Final stage LUT data value.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9 (8U) /*!< Bit position for PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9. */
#define BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9 (0x0000FF00U) /*!< Bit mask for PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9. */
#define BS_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9 field. */
#define BR_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2(x).B.DATA9)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9. */
#define BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9) & BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9)

/*! @brief Set the DATA9 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_WR(x, (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_RD(x) & ~BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9) | BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA9(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FINAL_LUT_DATA2, field DATA10[23:16] (RW)
 *
 * Final stage LUT data value.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10 (16U) /*!< Bit position for PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10. */
#define BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10 (0x00FF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10. */
#define BS_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10 field. */
#define BR_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2(x).B.DATA10)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10. */
#define BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10) & BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10)

/*! @brief Set the DATA10 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_WR(x, (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_RD(x) & ~BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10) | BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA10(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FINAL_LUT_DATA2, field DATA11[31:24] (RW)
 *
 * Final stage LUT data value.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11 (24U) /*!< Bit position for PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11. */
#define BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11. */
#define BS_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11 field. */
#define BR_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2(x).B.DATA11)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11. */
#define BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11) & BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11)

/*! @brief Set the DATA11 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_WR(x, (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_RD(x) & ~BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11) | BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA2_DATA11(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3 - Final stage lookup value Register
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3 - Final stage lookup value Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * 8 bit data values for the final stage dither LUT.
 * HW_PXP_DITHER_FINAL_LUT_DATA3: 0x16B0 HW_PXP_DITHER_FINAL_LUT_DATA3_SET: 0x16B4
 * HW_PXP_DITHER_FINAL_LUT_DATA3_CLR: 0x16B8 HW_PXP_DITHER_FINAL_LUT_DATA3_TOG: 0x16BC This register
 * contains lookup data values for the final stage register based dither LUT. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_dither_final_lut_data3
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_dither_final_lut_data3_bitfields
    {
        uint32_t DATA12 : 8;           /*!< [7:0]  */
        uint32_t DATA13 : 8;           /*!< [15:8]  */
        uint32_t DATA14 : 8;           /*!< [23:16]  */
        uint32_t DATA15 : 8;           /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_dither_final_lut_data3_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_DITHER_FINAL_LUT_DATA3 register
 */
/*@{*/
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_ADDR(x) ((uintptr_t)(x) + 0x16B0U)

#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3(x) (*(__IO hw_pxp_hw_pxp_dither_final_lut_data3_t *) HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_ADDR(x))
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_RD(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3(x).U)
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_WR(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3(x).U = (v))
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_SET(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_WR(x, HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_RD(x) |  (v)))
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_CLR(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_WR(x, HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_TOG(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_WR(x, HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_DITHER_FINAL_LUT_DATA3 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_DITHER_FINAL_LUT_DATA3, field DATA12[7:0] (RW)
 *
 * Final stage LUT data value.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12 (0U) /*!< Bit position for PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12. */
#define BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12 (0x000000FFU) /*!< Bit mask for PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12. */
#define BS_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12 field. */
#define BR_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3(x).B.DATA12)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12. */
#define BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12) & BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12)

/*! @brief Set the DATA12 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_WR(x, (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_RD(x) & ~BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12) | BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA12(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FINAL_LUT_DATA3, field DATA13[15:8] (RW)
 *
 * Final stage LUT data value.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13 (8U) /*!< Bit position for PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13. */
#define BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13 (0x0000FF00U) /*!< Bit mask for PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13. */
#define BS_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13 field. */
#define BR_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3(x).B.DATA13)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13. */
#define BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13) & BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13)

/*! @brief Set the DATA13 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_WR(x, (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_RD(x) & ~BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13) | BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA13(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FINAL_LUT_DATA3, field DATA14[23:16] (RW)
 *
 * Final stage LUT data value.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14 (16U) /*!< Bit position for PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14. */
#define BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14 (0x00FF0000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14. */
#define BS_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14 field. */
#define BR_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3(x).B.DATA14)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14. */
#define BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14) & BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14)

/*! @brief Set the DATA14 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_WR(x, (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_RD(x) & ~BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14) | BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA14(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_DITHER_FINAL_LUT_DATA3, field DATA15[31:24] (RW)
 *
 * Final stage LUT data value.
 */
/*@{*/
#define BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15 (24U) /*!< Bit position for PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15. */
#define BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15. */
#define BS_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15 (8U) /*!< Bit field size in bits for PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15. */

/*! @brief Read current value of the PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15 field. */
#define BR_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15(x) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3(x).B.DATA15)

/*! @brief Format value for bitfield PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15. */
#define BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15) & BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15)

/*! @brief Set the DATA15 field to a new value. */
#define BW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15(x, v) (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_WR(x, (HW_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_RD(x) & ~BM_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15) | BF_PXP_HW_PXP_DITHER_FINAL_LUT_DATA3_DATA15(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST_A_CTRL - Histogram Control Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST_A_CTRL - Histogram Control Register. (RW)
 *
 * Reset value: 0x05001F00U
 *
 * Provides control and status registers for the PXP's histogram classification
 * algorithm.
 */
typedef union _hw_pxp_hw_pxp_hist_a_ctrl
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist_a_ctrl_bitfields
    {
        uint32_t ENABLE : 1;           /*!< [0]  */
        uint32_t RSVD0 : 3;            /*!< [3:1]  */
        uint32_t CLEAR : 1;            /*!< [4]  */
        uint32_t RSVD1 : 3;            /*!< [7:5]  */
        uint32_t STATUS : 5;           /*!< [12:8]  */
        uint32_t RSVD2 : 3;            /*!< [15:13]  */
        uint32_t PIXEL_OFFSET : 7;     /*!< [22:16]  */
        uint32_t RSVD3 : 1;            /*!< [23]  */
        uint32_t PIXEL_WIDTH : 3;      /*!< [26:24]  */
        uint32_t RSVD4 : 5;            /*!< [31:27]  */
    } B;
} hw_pxp_hw_pxp_hist_a_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST_A_CTRL register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST_A_CTRL_ADDR(x) ((uintptr_t)(x) + 0x2A00U)

#define HW_PXP_HW_PXP_HIST_A_CTRL(x) (*(__IO hw_pxp_hw_pxp_hist_a_ctrl_t *) HW_PXP_HW_PXP_HIST_A_CTRL_ADDR(x))
#define HW_PXP_HW_PXP_HIST_A_CTRL_RD(x) (HW_PXP_HW_PXP_HIST_A_CTRL(x).U)
#define HW_PXP_HW_PXP_HIST_A_CTRL_WR(x, v) (HW_PXP_HW_PXP_HIST_A_CTRL(x).U = (v))
#define HW_PXP_HW_PXP_HIST_A_CTRL_SET(x, v) (HW_PXP_HW_PXP_HIST_A_CTRL_WR(x, HW_PXP_HW_PXP_HIST_A_CTRL_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST_A_CTRL_CLR(x, v) (HW_PXP_HW_PXP_HIST_A_CTRL_WR(x, HW_PXP_HW_PXP_HIST_A_CTRL_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST_A_CTRL_TOG(x, v) (HW_PXP_HW_PXP_HIST_A_CTRL_WR(x, HW_PXP_HW_PXP_HIST_A_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST_A_CTRL bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST_A_CTRL, field ENABLE[0] (RW)
 *
 * Enable the Histogram Engine
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_CTRL_ENABLE (0U) /*!< Bit position for PXP_HW_PXP_HIST_A_CTRL_ENABLE. */
#define BM_PXP_HW_PXP_HIST_A_CTRL_ENABLE (0x00000001U) /*!< Bit mask for PXP_HW_PXP_HIST_A_CTRL_ENABLE. */
#define BS_PXP_HW_PXP_HIST_A_CTRL_ENABLE (1U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_CTRL_ENABLE. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_CTRL_ENABLE field. */
#define BR_PXP_HW_PXP_HIST_A_CTRL_ENABLE(x) (HW_PXP_HW_PXP_HIST_A_CTRL(x).B.ENABLE)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_A_CTRL_ENABLE. */
#define BF_PXP_HW_PXP_HIST_A_CTRL_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_A_CTRL_ENABLE) & BM_PXP_HW_PXP_HIST_A_CTRL_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_PXP_HW_PXP_HIST_A_CTRL_ENABLE(x, v) (HW_PXP_HW_PXP_HIST_A_CTRL_WR(x, (HW_PXP_HW_PXP_HIST_A_CTRL_RD(x) & ~BM_PXP_HW_PXP_HIST_A_CTRL_ENABLE) | BF_PXP_HW_PXP_HIST_A_CTRL_ENABLE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_CTRL, field RSVD0[3:1] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_CTRL_RSVD0 (1U) /*!< Bit position for PXP_HW_PXP_HIST_A_CTRL_RSVD0. */
#define BM_PXP_HW_PXP_HIST_A_CTRL_RSVD0 (0x0000000EU) /*!< Bit mask for PXP_HW_PXP_HIST_A_CTRL_RSVD0. */
#define BS_PXP_HW_PXP_HIST_A_CTRL_RSVD0 (3U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_CTRL_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_CTRL_RSVD0 field. */
#define BR_PXP_HW_PXP_HIST_A_CTRL_RSVD0(x) (HW_PXP_HW_PXP_HIST_A_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_CTRL, field CLEAR[4] (RW)
 *
 * Write 1 to clear the histogram result and will be self-clear after clear
 * function finished
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_CTRL_CLEAR (4U) /*!< Bit position for PXP_HW_PXP_HIST_A_CTRL_CLEAR. */
#define BM_PXP_HW_PXP_HIST_A_CTRL_CLEAR (0x00000010U) /*!< Bit mask for PXP_HW_PXP_HIST_A_CTRL_CLEAR. */
#define BS_PXP_HW_PXP_HIST_A_CTRL_CLEAR (1U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_CTRL_CLEAR. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_CTRL_CLEAR field. */
#define BR_PXP_HW_PXP_HIST_A_CTRL_CLEAR(x) (HW_PXP_HW_PXP_HIST_A_CTRL(x).B.CLEAR)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_A_CTRL_CLEAR. */
#define BF_PXP_HW_PXP_HIST_A_CTRL_CLEAR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_A_CTRL_CLEAR) & BM_PXP_HW_PXP_HIST_A_CTRL_CLEAR)

/*! @brief Set the CLEAR field to a new value. */
#define BW_PXP_HW_PXP_HIST_A_CTRL_CLEAR(x, v) (HW_PXP_HW_PXP_HIST_A_CTRL_WR(x, (HW_PXP_HW_PXP_HIST_A_CTRL_RD(x) & ~BM_PXP_HW_PXP_HIST_A_CTRL_CLEAR) | BF_PXP_HW_PXP_HIST_A_CTRL_CLEAR(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_CTRL, field RSVD1[7:5] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_CTRL_RSVD1 (5U) /*!< Bit position for PXP_HW_PXP_HIST_A_CTRL_RSVD1. */
#define BM_PXP_HW_PXP_HIST_A_CTRL_RSVD1 (0x000000E0U) /*!< Bit mask for PXP_HW_PXP_HIST_A_CTRL_RSVD1. */
#define BS_PXP_HW_PXP_HIST_A_CTRL_RSVD1 (3U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_CTRL_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_CTRL_RSVD1 field. */
#define BR_PXP_HW_PXP_HIST_A_CTRL_RSVD1(x) (HW_PXP_HW_PXP_HIST_A_CTRL(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_CTRL, field STATUS[12:8] (RO)
 *
 * Indicates which histogram matched the processed bitmap. Bit[0] indicates that
 * the bitmap pixels were fully contained within the HIST2 (black / white)
 * histogram. Bit[1] indicates that the bitmap pixels were fully contained within the
 * HIST4 (2-bit grayscale) histogram. Bit[2] indicates that the bitmap pixels
 * were fully contained within the HIST8 (3-bit grayscale) histogram. Bit[3]
 * indicates that the bitmap pixels were fully contained within the HIST16 (4-bit
 * grayscale) histogram. Bit[4] indicates that the bitmap pixels were fully contained
 * within the HIST32 (5-bit grayscale) histogram.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_CTRL_STATUS (8U) /*!< Bit position for PXP_HW_PXP_HIST_A_CTRL_STATUS. */
#define BM_PXP_HW_PXP_HIST_A_CTRL_STATUS (0x00001F00U) /*!< Bit mask for PXP_HW_PXP_HIST_A_CTRL_STATUS. */
#define BS_PXP_HW_PXP_HIST_A_CTRL_STATUS (5U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_CTRL_STATUS. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_CTRL_STATUS field. */
#define BR_PXP_HW_PXP_HIST_A_CTRL_STATUS(x) (HW_PXP_HW_PXP_HIST_A_CTRL(x).B.STATUS)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_CTRL, field RSVD2[15:13] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_CTRL_RSVD2 (13U) /*!< Bit position for PXP_HW_PXP_HIST_A_CTRL_RSVD2. */
#define BM_PXP_HW_PXP_HIST_A_CTRL_RSVD2 (0x0000E000U) /*!< Bit mask for PXP_HW_PXP_HIST_A_CTRL_RSVD2. */
#define BS_PXP_HW_PXP_HIST_A_CTRL_RSVD2 (3U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_CTRL_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_CTRL_RSVD2 field. */
#define BR_PXP_HW_PXP_HIST_A_CTRL_RSVD2(x) (HW_PXP_HW_PXP_HIST_A_CTRL(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_CTRL, field PIXEL_OFFSET[22:16] (RW)
 *
 * The offset of the pixel to be used for histogram calculation
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET (16U) /*!< Bit position for PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET. */
#define BM_PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET (0x007F0000U) /*!< Bit mask for PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET. */
#define BS_PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET (7U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET field. */
#define BR_PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET(x) (HW_PXP_HW_PXP_HIST_A_CTRL(x).B.PIXEL_OFFSET)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET. */
#define BF_PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET) & BM_PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET)

/*! @brief Set the PIXEL_OFFSET field to a new value. */
#define BW_PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET(x, v) (HW_PXP_HW_PXP_HIST_A_CTRL_WR(x, (HW_PXP_HW_PXP_HIST_A_CTRL_RD(x) & ~BM_PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET) | BF_PXP_HW_PXP_HIST_A_CTRL_PIXEL_OFFSET(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_CTRL, field RSVD3[23] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_CTRL_RSVD3 (23U) /*!< Bit position for PXP_HW_PXP_HIST_A_CTRL_RSVD3. */
#define BM_PXP_HW_PXP_HIST_A_CTRL_RSVD3 (0x00800000U) /*!< Bit mask for PXP_HW_PXP_HIST_A_CTRL_RSVD3. */
#define BS_PXP_HW_PXP_HIST_A_CTRL_RSVD3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_CTRL_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_CTRL_RSVD3 field. */
#define BR_PXP_HW_PXP_HIST_A_CTRL_RSVD3(x) (HW_PXP_HW_PXP_HIST_A_CTRL(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_CTRL, field PIXEL_WIDTH[26:24] (RW)
 *
 * The width of the pixel to be used for histogram calculation
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH (24U) /*!< Bit position for PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH. */
#define BM_PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH (0x07000000U) /*!< Bit mask for PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH. */
#define BS_PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH (3U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH field. */
#define BR_PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH(x) (HW_PXP_HW_PXP_HIST_A_CTRL(x).B.PIXEL_WIDTH)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH. */
#define BF_PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH) & BM_PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH)

/*! @brief Set the PIXEL_WIDTH field to a new value. */
#define BW_PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH(x, v) (HW_PXP_HW_PXP_HIST_A_CTRL_WR(x, (HW_PXP_HW_PXP_HIST_A_CTRL_RD(x) & ~BM_PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH) | BF_PXP_HW_PXP_HIST_A_CTRL_PIXEL_WIDTH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_CTRL, field RSVD4[31:27] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_CTRL_RSVD4 (27U) /*!< Bit position for PXP_HW_PXP_HIST_A_CTRL_RSVD4. */
#define BM_PXP_HW_PXP_HIST_A_CTRL_RSVD4 (0xF8000000U) /*!< Bit mask for PXP_HW_PXP_HIST_A_CTRL_RSVD4. */
#define BS_PXP_HW_PXP_HIST_A_CTRL_RSVD4 (5U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_CTRL_RSVD4. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_CTRL_RSVD4 field. */
#define BR_PXP_HW_PXP_HIST_A_CTRL_RSVD4(x) (HW_PXP_HW_PXP_HIST_A_CTRL(x).B.RSVD4)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST_A_MASK - Histogram Pixel Mask Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST_A_MASK - Histogram Pixel Mask Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Provides control registers for the pixel masking in PXP's histogram.
 */
typedef union _hw_pxp_hw_pxp_hist_a_mask
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist_a_mask_bitfields
    {
        uint32_t MASK_EN : 1;          /*!< [0]  */
        uint32_t RSVD0 : 3;            /*!< [3:1]  */
        uint32_t MASK_MODE : 2;        /*!< [5:4]  */
        uint32_t MASK_OFFSET : 7;      /*!< [12:6]  */
        uint32_t MASK_WIDTH : 3;       /*!< [15:13]  */
        uint32_t MASK_VALUE0 : 8;      /*!< [23:16]  */
        uint32_t MASK_VALUE1 : 8;      /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_hist_a_mask_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST_A_MASK register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST_A_MASK_ADDR(x) ((uintptr_t)(x) + 0x2A10U)

#define HW_PXP_HW_PXP_HIST_A_MASK(x) (*(__IO hw_pxp_hw_pxp_hist_a_mask_t *) HW_PXP_HW_PXP_HIST_A_MASK_ADDR(x))
#define HW_PXP_HW_PXP_HIST_A_MASK_RD(x) (HW_PXP_HW_PXP_HIST_A_MASK(x).U)
#define HW_PXP_HW_PXP_HIST_A_MASK_WR(x, v) (HW_PXP_HW_PXP_HIST_A_MASK(x).U = (v))
#define HW_PXP_HW_PXP_HIST_A_MASK_SET(x, v) (HW_PXP_HW_PXP_HIST_A_MASK_WR(x, HW_PXP_HW_PXP_HIST_A_MASK_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST_A_MASK_CLR(x, v) (HW_PXP_HW_PXP_HIST_A_MASK_WR(x, HW_PXP_HW_PXP_HIST_A_MASK_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST_A_MASK_TOG(x, v) (HW_PXP_HW_PXP_HIST_A_MASK_WR(x, HW_PXP_HW_PXP_HIST_A_MASK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST_A_MASK bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST_A_MASK, field MASK_EN[0] (RW)
 *
 * Enable the Pixel Mask Function in Histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_MASK_MASK_EN (0U) /*!< Bit position for PXP_HW_PXP_HIST_A_MASK_MASK_EN. */
#define BM_PXP_HW_PXP_HIST_A_MASK_MASK_EN (0x00000001U) /*!< Bit mask for PXP_HW_PXP_HIST_A_MASK_MASK_EN. */
#define BS_PXP_HW_PXP_HIST_A_MASK_MASK_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_MASK_MASK_EN. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_MASK_MASK_EN field. */
#define BR_PXP_HW_PXP_HIST_A_MASK_MASK_EN(x) (HW_PXP_HW_PXP_HIST_A_MASK(x).B.MASK_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_A_MASK_MASK_EN. */
#define BF_PXP_HW_PXP_HIST_A_MASK_MASK_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_A_MASK_MASK_EN) & BM_PXP_HW_PXP_HIST_A_MASK_MASK_EN)

/*! @brief Set the MASK_EN field to a new value. */
#define BW_PXP_HW_PXP_HIST_A_MASK_MASK_EN(x, v) (HW_PXP_HW_PXP_HIST_A_MASK_WR(x, (HW_PXP_HW_PXP_HIST_A_MASK_RD(x) & ~BM_PXP_HW_PXP_HIST_A_MASK_MASK_EN) | BF_PXP_HW_PXP_HIST_A_MASK_MASK_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_MASK, field RSVD0[3:1] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_MASK_RSVD0 (1U) /*!< Bit position for PXP_HW_PXP_HIST_A_MASK_RSVD0. */
#define BM_PXP_HW_PXP_HIST_A_MASK_RSVD0 (0x0000000EU) /*!< Bit mask for PXP_HW_PXP_HIST_A_MASK_RSVD0. */
#define BS_PXP_HW_PXP_HIST_A_MASK_RSVD0 (3U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_MASK_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_MASK_RSVD0 field. */
#define BR_PXP_HW_PXP_HIST_A_MASK_RSVD0(x) (HW_PXP_HW_PXP_HIST_A_MASK(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_MASK, field MASK_MODE[5:4] (RW)
 *
 * Operation mode of pixel mask function
 *
 * Values:
 * - 0 - Run histogram for pixels equal to value0
 * - 1 - Run histogram for pixels not equal to value0
 * - 10 - Run histogram for pixels within the range of value0 to value1
 * - 11 - Run histogram for pixels outside of the rang of value0 to value1
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_MASK_MASK_MODE (4U) /*!< Bit position for PXP_HW_PXP_HIST_A_MASK_MASK_MODE. */
#define BM_PXP_HW_PXP_HIST_A_MASK_MASK_MODE (0x00000030U) /*!< Bit mask for PXP_HW_PXP_HIST_A_MASK_MASK_MODE. */
#define BS_PXP_HW_PXP_HIST_A_MASK_MASK_MODE (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_MASK_MASK_MODE. */

#define BV_PXP_HW_PXP_HIST_A_MASK_MASK_MODE_EQUAL (0U) /*!< Bit field value for PXP_HW_PXP_HIST_A_MASK_MASK_MODE: Run histogram for pixels equal to value0 */
#define BV_PXP_HW_PXP_HIST_A_MASK_MASK_MODE_NOT_EQUAL (0x1U) /*!< Bit field value for PXP_HW_PXP_HIST_A_MASK_MASK_MODE: Run histogram for pixels not equal to value0 */
#define BV_PXP_HW_PXP_HIST_A_MASK_MASK_MODE_INSIDE (0x2U) /*!< Bit field value for PXP_HW_PXP_HIST_A_MASK_MASK_MODE: Run histogram for pixels within the range of value0 to value1 */
#define BV_PXP_HW_PXP_HIST_A_MASK_MASK_MODE_OUTSIDE (0x3U) /*!< Bit field value for PXP_HW_PXP_HIST_A_MASK_MASK_MODE: Run histogram for pixels outside of the rang of value0 to value1 */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_MASK_MASK_MODE field. */
#define BR_PXP_HW_PXP_HIST_A_MASK_MASK_MODE(x) (HW_PXP_HW_PXP_HIST_A_MASK(x).B.MASK_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_A_MASK_MASK_MODE. */
#define BF_PXP_HW_PXP_HIST_A_MASK_MASK_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_A_MASK_MASK_MODE) & BM_PXP_HW_PXP_HIST_A_MASK_MASK_MODE)

/*! @brief Set the MASK_MODE field to a new value. */
#define BW_PXP_HW_PXP_HIST_A_MASK_MASK_MODE(x, v) (HW_PXP_HW_PXP_HIST_A_MASK_WR(x, (HW_PXP_HW_PXP_HIST_A_MASK_RD(x) & ~BM_PXP_HW_PXP_HIST_A_MASK_MASK_MODE) | BF_PXP_HW_PXP_HIST_A_MASK_MASK_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_MASK, field MASK_OFFSET[12:6] (RW)
 *
 * The offset of the field to be checked against mask condition
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET (6U) /*!< Bit position for PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET. */
#define BM_PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET (0x00001FC0U) /*!< Bit mask for PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET. */
#define BS_PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET (7U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET field. */
#define BR_PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET(x) (HW_PXP_HW_PXP_HIST_A_MASK(x).B.MASK_OFFSET)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET. */
#define BF_PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET) & BM_PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET)

/*! @brief Set the MASK_OFFSET field to a new value. */
#define BW_PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET(x, v) (HW_PXP_HW_PXP_HIST_A_MASK_WR(x, (HW_PXP_HW_PXP_HIST_A_MASK_RD(x) & ~BM_PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET) | BF_PXP_HW_PXP_HIST_A_MASK_MASK_OFFSET(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_MASK, field MASK_WIDTH[15:13] (RW)
 *
 * The width of the field to be checked against mask condition
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH (13U) /*!< Bit position for PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH. */
#define BM_PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH (0x0000E000U) /*!< Bit mask for PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH. */
#define BS_PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH (3U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH field. */
#define BR_PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH(x) (HW_PXP_HW_PXP_HIST_A_MASK(x).B.MASK_WIDTH)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH. */
#define BF_PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH) & BM_PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH)

/*! @brief Set the MASK_WIDTH field to a new value. */
#define BW_PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH(x, v) (HW_PXP_HW_PXP_HIST_A_MASK_WR(x, (HW_PXP_HW_PXP_HIST_A_MASK_RD(x) & ~BM_PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH) | BF_PXP_HW_PXP_HIST_A_MASK_MASK_WIDTH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_MASK, field MASK_VALUE0[23:16] (RW)
 *
 * The value0 for mask condition checking
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0 (16U) /*!< Bit position for PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0. */
#define BM_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0 (0x00FF0000U) /*!< Bit mask for PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0. */
#define BS_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0 (8U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0 field. */
#define BR_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0(x) (HW_PXP_HW_PXP_HIST_A_MASK(x).B.MASK_VALUE0)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0. */
#define BF_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0) & BM_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0)

/*! @brief Set the MASK_VALUE0 field to a new value. */
#define BW_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0(x, v) (HW_PXP_HW_PXP_HIST_A_MASK_WR(x, (HW_PXP_HW_PXP_HIST_A_MASK_RD(x) & ~BM_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0) | BF_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_MASK, field MASK_VALUE1[31:24] (RW)
 *
 * The value1 for mask condition checking
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1 (24U) /*!< Bit position for PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1. */
#define BM_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1. */
#define BS_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1 (8U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1 field. */
#define BR_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1(x) (HW_PXP_HW_PXP_HIST_A_MASK(x).B.MASK_VALUE1)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1. */
#define BF_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1) & BM_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1)

/*! @brief Set the MASK_VALUE1 field to a new value. */
#define BW_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1(x, v) (HW_PXP_HW_PXP_HIST_A_MASK_WR(x, (HW_PXP_HW_PXP_HIST_A_MASK_RD(x) & ~BM_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1) | BF_PXP_HW_PXP_HIST_A_MASK_MASK_VALUE1(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST_A_BUF_SIZE - Histogram Pixel Buffer Size Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST_A_BUF_SIZE - Histogram Pixel Buffer Size Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the size of the buffer to be processed by the histogram
 * engine.
 */
typedef union _hw_pxp_hw_pxp_hist_a_buf_size
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist_a_buf_size_bitfields
    {
        uint32_t WIDTH : 12;           /*!< [11:0]  */
        uint32_t RSVD1 : 4;            /*!< [15:12]  */
        uint32_t HEIGHT : 12;          /*!< [27:16]  */
        uint32_t RSVD0 : 4;            /*!< [31:28]  */
    } B;
} hw_pxp_hw_pxp_hist_a_buf_size_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST_A_BUF_SIZE register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST_A_BUF_SIZE_ADDR(x) ((uintptr_t)(x) + 0x2A20U)

#define HW_PXP_HW_PXP_HIST_A_BUF_SIZE(x) (*(__IO hw_pxp_hw_pxp_hist_a_buf_size_t *) HW_PXP_HW_PXP_HIST_A_BUF_SIZE_ADDR(x))
#define HW_PXP_HW_PXP_HIST_A_BUF_SIZE_RD(x) (HW_PXP_HW_PXP_HIST_A_BUF_SIZE(x).U)
#define HW_PXP_HW_PXP_HIST_A_BUF_SIZE_WR(x, v) (HW_PXP_HW_PXP_HIST_A_BUF_SIZE(x).U = (v))
#define HW_PXP_HW_PXP_HIST_A_BUF_SIZE_SET(x, v) (HW_PXP_HW_PXP_HIST_A_BUF_SIZE_WR(x, HW_PXP_HW_PXP_HIST_A_BUF_SIZE_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST_A_BUF_SIZE_CLR(x, v) (HW_PXP_HW_PXP_HIST_A_BUF_SIZE_WR(x, HW_PXP_HW_PXP_HIST_A_BUF_SIZE_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST_A_BUF_SIZE_TOG(x, v) (HW_PXP_HW_PXP_HIST_A_BUF_SIZE_WR(x, HW_PXP_HW_PXP_HIST_A_BUF_SIZE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST_A_BUF_SIZE bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST_A_BUF_SIZE, field WIDTH[11:0] (RW)
 *
 * This indicate the buffer width in pixels
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH (0U) /*!< Bit position for PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH. */
#define BM_PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH (0x00000FFFU) /*!< Bit mask for PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH. */
#define BS_PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH (12U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH field. */
#define BR_PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH(x) (HW_PXP_HW_PXP_HIST_A_BUF_SIZE(x).B.WIDTH)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH. */
#define BF_PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH) & BM_PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH)

/*! @brief Set the WIDTH field to a new value. */
#define BW_PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH(x, v) (HW_PXP_HW_PXP_HIST_A_BUF_SIZE_WR(x, (HW_PXP_HW_PXP_HIST_A_BUF_SIZE_RD(x) & ~BM_PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH) | BF_PXP_HW_PXP_HIST_A_BUF_SIZE_WIDTH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_BUF_SIZE, field RSVD1[15:12] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD1 (12U) /*!< Bit position for PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD1. */
#define BM_PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD1 (0x0000F000U) /*!< Bit mask for PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD1. */
#define BS_PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD1 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD1 field. */
#define BR_PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD1(x) (HW_PXP_HW_PXP_HIST_A_BUF_SIZE(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_BUF_SIZE, field HEIGHT[27:16] (RW)
 *
 * This indicate the buffer height in pixels
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT (16U) /*!< Bit position for PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT. */
#define BM_PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT (0x0FFF0000U) /*!< Bit mask for PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT. */
#define BS_PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT (12U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT field. */
#define BR_PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT(x) (HW_PXP_HW_PXP_HIST_A_BUF_SIZE(x).B.HEIGHT)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT. */
#define BF_PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT) & BM_PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT)

/*! @brief Set the HEIGHT field to a new value. */
#define BW_PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT(x, v) (HW_PXP_HW_PXP_HIST_A_BUF_SIZE_WR(x, (HW_PXP_HW_PXP_HIST_A_BUF_SIZE_RD(x) & ~BM_PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT) | BF_PXP_HW_PXP_HIST_A_BUF_SIZE_HEIGHT(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_BUF_SIZE, field RSVD0[31:28] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD0 (28U) /*!< Bit position for PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD0. */
#define BM_PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD0 (0xF0000000U) /*!< Bit mask for PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD0. */
#define BS_PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD0 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD0 field. */
#define BR_PXP_HW_PXP_HIST_A_BUF_SIZE_RSVD0(x) (HW_PXP_HW_PXP_HIST_A_BUF_SIZE(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST_A_TOTAL_PIXEL - Total Number of Pixels Used by Histogram Engine.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST_A_TOTAL_PIXEL - Total Number of Pixels Used by Histogram Engine. (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register shows the total number of pixels used by histogram engine
 */
typedef union _hw_pxp_hw_pxp_hist_a_total_pixel
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist_a_total_pixel_bitfields
    {
        uint32_t TOTAL_PIXEL : 24;     /*!< [23:0]  */
        uint32_t RSVD0 : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_hist_a_total_pixel_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST_A_TOTAL_PIXEL register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST_A_TOTAL_PIXEL_ADDR(x) ((uintptr_t)(x) + 0x2A30U)

#define HW_PXP_HW_PXP_HIST_A_TOTAL_PIXEL(x) (*(__I hw_pxp_hw_pxp_hist_a_total_pixel_t *) HW_PXP_HW_PXP_HIST_A_TOTAL_PIXEL_ADDR(x))
#define HW_PXP_HW_PXP_HIST_A_TOTAL_PIXEL_RD(x) (HW_PXP_HW_PXP_HIST_A_TOTAL_PIXEL(x).U)
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST_A_TOTAL_PIXEL bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST_A_TOTAL_PIXEL, field TOTAL_PIXEL[23:0] (RO)
 *
 * Total number of pixels used by histogram engine, the pixels got masked will
 * be skipped
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_TOTAL_PIXEL_TOTAL_PIXEL (0U) /*!< Bit position for PXP_HW_PXP_HIST_A_TOTAL_PIXEL_TOTAL_PIXEL. */
#define BM_PXP_HW_PXP_HIST_A_TOTAL_PIXEL_TOTAL_PIXEL (0x00FFFFFFU) /*!< Bit mask for PXP_HW_PXP_HIST_A_TOTAL_PIXEL_TOTAL_PIXEL. */
#define BS_PXP_HW_PXP_HIST_A_TOTAL_PIXEL_TOTAL_PIXEL (24U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_TOTAL_PIXEL_TOTAL_PIXEL. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_TOTAL_PIXEL_TOTAL_PIXEL field. */
#define BR_PXP_HW_PXP_HIST_A_TOTAL_PIXEL_TOTAL_PIXEL(x) (HW_PXP_HW_PXP_HIST_A_TOTAL_PIXEL(x).B.TOTAL_PIXEL)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_TOTAL_PIXEL, field RSVD0[31:24] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_TOTAL_PIXEL_RSVD0 (24U) /*!< Bit position for PXP_HW_PXP_HIST_A_TOTAL_PIXEL_RSVD0. */
#define BM_PXP_HW_PXP_HIST_A_TOTAL_PIXEL_RSVD0 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_HIST_A_TOTAL_PIXEL_RSVD0. */
#define BS_PXP_HW_PXP_HIST_A_TOTAL_PIXEL_RSVD0 (8U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_TOTAL_PIXEL_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_TOTAL_PIXEL_RSVD0 field. */
#define BR_PXP_HW_PXP_HIST_A_TOTAL_PIXEL_RSVD0(x) (HW_PXP_HW_PXP_HIST_A_TOTAL_PIXEL(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X - The X Coordinate Offset for Active Area.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X - The X Coordinate Offset for Active Area. (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register shows the minimal and maximum X coordinate offset for the
 * active area in histogram processing
 */
typedef union _hw_pxp_hw_pxp_hist_a_active_area_x
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist_a_active_area_x_bitfields
    {
        uint32_t MIN_X_OFFSET : 12;    /*!< [11:0]  */
        uint32_t RSVD0 : 4;            /*!< [15:12]  */
        uint32_t MAX_X_OFFSET : 12;    /*!< [27:16]  */
        uint32_t RSVD1 : 4;            /*!< [31:28]  */
    } B;
} hw_pxp_hw_pxp_hist_a_active_area_x_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST_A_ACTIVE_AREA_X register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_ADDR(x) ((uintptr_t)(x) + 0x2A40U)

#define HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X(x) (*(__I hw_pxp_hw_pxp_hist_a_active_area_x_t *) HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_ADDR(x))
#define HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RD(x) (HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X(x).U)
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST_A_ACTIVE_AREA_X bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST_A_ACTIVE_AREA_X, field MIN_X_OFFSET[11:0] (RO)
 *
 * Minimul X coordinate offset for the active area in histogram processing
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MIN_X_OFFSET (0U) /*!< Bit position for PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MIN_X_OFFSET. */
#define BM_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MIN_X_OFFSET (0x00000FFFU) /*!< Bit mask for PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MIN_X_OFFSET. */
#define BS_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MIN_X_OFFSET (12U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MIN_X_OFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MIN_X_OFFSET field. */
#define BR_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MIN_X_OFFSET(x) (HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X(x).B.MIN_X_OFFSET)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_ACTIVE_AREA_X, field RSVD0[15:12] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD0 (12U) /*!< Bit position for PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD0. */
#define BM_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD0 (0x0000F000U) /*!< Bit mask for PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD0. */
#define BS_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD0 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD0 field. */
#define BR_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD0(x) (HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_ACTIVE_AREA_X, field MAX_X_OFFSET[27:16] (RO)
 *
 * Maximum X coordinate offset for the active area in histogram processing
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MAX_X_OFFSET (16U) /*!< Bit position for PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MAX_X_OFFSET. */
#define BM_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MAX_X_OFFSET (0x0FFF0000U) /*!< Bit mask for PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MAX_X_OFFSET. */
#define BS_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MAX_X_OFFSET (12U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MAX_X_OFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MAX_X_OFFSET field. */
#define BR_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_MAX_X_OFFSET(x) (HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X(x).B.MAX_X_OFFSET)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_ACTIVE_AREA_X, field RSVD1[31:28] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD1 (28U) /*!< Bit position for PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD1. */
#define BM_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD1 (0xF0000000U) /*!< Bit mask for PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD1. */
#define BS_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD1 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD1 field. */
#define BR_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X_RSVD1(x) (HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_X(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y - The Y Coordinate Offset for Active Area.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y - The Y Coordinate Offset for Active Area. (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register shows the minimal and maximum Y coordinate offset for the
 * active area in histogram processing
 */
typedef union _hw_pxp_hw_pxp_hist_a_active_area_y
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist_a_active_area_y_bitfields
    {
        uint32_t MIN_Y_OFFSET : 12;    /*!< [11:0]  */
        uint32_t RSVD0 : 4;            /*!< [15:12]  */
        uint32_t MAX_Y_OFFSET : 12;    /*!< [27:16]  */
        uint32_t RSVD1 : 4;            /*!< [31:28]  */
    } B;
} hw_pxp_hw_pxp_hist_a_active_area_y_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_ADDR(x) ((uintptr_t)(x) + 0x2A50U)

#define HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y(x) (*(__I hw_pxp_hw_pxp_hist_a_active_area_y_t *) HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_ADDR(x))
#define HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RD(x) (HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y(x).U)
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y, field MIN_Y_OFFSET[11:0] (RO)
 *
 * Minimul Y coordinate offset for the active area in histogram processing
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MIN_Y_OFFSET (0U) /*!< Bit position for PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MIN_Y_OFFSET. */
#define BM_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MIN_Y_OFFSET (0x00000FFFU) /*!< Bit mask for PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MIN_Y_OFFSET. */
#define BS_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MIN_Y_OFFSET (12U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MIN_Y_OFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MIN_Y_OFFSET field. */
#define BR_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MIN_Y_OFFSET(x) (HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y(x).B.MIN_Y_OFFSET)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y, field RSVD0[15:12] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD0 (12U) /*!< Bit position for PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD0. */
#define BM_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD0 (0x0000F000U) /*!< Bit mask for PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD0. */
#define BS_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD0 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD0 field. */
#define BR_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD0(x) (HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y, field MAX_Y_OFFSET[27:16] (RO)
 *
 * Maximum Y coordinate offset for the active area in histogram processing
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MAX_Y_OFFSET (16U) /*!< Bit position for PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MAX_Y_OFFSET. */
#define BM_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MAX_Y_OFFSET (0x0FFF0000U) /*!< Bit mask for PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MAX_Y_OFFSET. */
#define BS_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MAX_Y_OFFSET (12U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MAX_Y_OFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MAX_Y_OFFSET field. */
#define BR_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_MAX_Y_OFFSET(x) (HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y(x).B.MAX_Y_OFFSET)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y, field RSVD1[31:28] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD1 (28U) /*!< Bit position for PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD1. */
#define BM_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD1 (0xF0000000U) /*!< Bit mask for PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD1. */
#define BS_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD1 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD1 field. */
#define BR_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y_RSVD1(x) (HW_PXP_HW_PXP_HIST_A_ACTIVE_AREA_Y(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST_A_RAW_STAT0 - Histogram Result Based on RAW Pixel Value.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST_A_RAW_STAT0 - Histogram Result Based on RAW Pixel Value. (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register shows the lower 32-bit of the histogram result based on raw
 * pixel value
 */
typedef union _hw_pxp_hw_pxp_hist_a_raw_stat0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist_a_raw_stat0_bitfields
    {
        uint32_t STAT0 : 32;           /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_hist_a_raw_stat0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST_A_RAW_STAT0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST_A_RAW_STAT0_ADDR(x) ((uintptr_t)(x) + 0x2A60U)

#define HW_PXP_HW_PXP_HIST_A_RAW_STAT0(x) (*(__I hw_pxp_hw_pxp_hist_a_raw_stat0_t *) HW_PXP_HW_PXP_HIST_A_RAW_STAT0_ADDR(x))
#define HW_PXP_HW_PXP_HIST_A_RAW_STAT0_RD(x) (HW_PXP_HW_PXP_HIST_A_RAW_STAT0(x).U)
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST_A_RAW_STAT0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST_A_RAW_STAT0, field STAT0[31:0] (RO)
 *
 * Lower 32-bit result fo the histogram calculation
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_RAW_STAT0_STAT0 (0U) /*!< Bit position for PXP_HW_PXP_HIST_A_RAW_STAT0_STAT0. */
#define BM_PXP_HW_PXP_HIST_A_RAW_STAT0_STAT0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_HIST_A_RAW_STAT0_STAT0. */
#define BS_PXP_HW_PXP_HIST_A_RAW_STAT0_STAT0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_RAW_STAT0_STAT0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_RAW_STAT0_STAT0 field. */
#define BR_PXP_HW_PXP_HIST_A_RAW_STAT0_STAT0(x) (HW_PXP_HW_PXP_HIST_A_RAW_STAT0(x).U)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST_A_RAW_STAT1 - Histogram Result Based on RAW Pixel Value.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST_A_RAW_STAT1 - Histogram Result Based on RAW Pixel Value. (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register shows the higher 32-bit of the histogram result based on raw
 * pixel value
 */
typedef union _hw_pxp_hw_pxp_hist_a_raw_stat1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist_a_raw_stat1_bitfields
    {
        uint32_t STAT1 : 32;           /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_hist_a_raw_stat1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST_A_RAW_STAT1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST_A_RAW_STAT1_ADDR(x) ((uintptr_t)(x) + 0x2A70U)

#define HW_PXP_HW_PXP_HIST_A_RAW_STAT1(x) (*(__I hw_pxp_hw_pxp_hist_a_raw_stat1_t *) HW_PXP_HW_PXP_HIST_A_RAW_STAT1_ADDR(x))
#define HW_PXP_HW_PXP_HIST_A_RAW_STAT1_RD(x) (HW_PXP_HW_PXP_HIST_A_RAW_STAT1(x).U)
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST_A_RAW_STAT1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST_A_RAW_STAT1, field STAT1[31:0] (RO)
 *
 * Higher 32-bit result fo the histogram calculation
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_A_RAW_STAT1_STAT1 (0U) /*!< Bit position for PXP_HW_PXP_HIST_A_RAW_STAT1_STAT1. */
#define BM_PXP_HW_PXP_HIST_A_RAW_STAT1_STAT1 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_HIST_A_RAW_STAT1_STAT1. */
#define BS_PXP_HW_PXP_HIST_A_RAW_STAT1_STAT1 (32U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_A_RAW_STAT1_STAT1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_A_RAW_STAT1_STAT1 field. */
#define BR_PXP_HW_PXP_HIST_A_RAW_STAT1_STAT1(x) (HW_PXP_HW_PXP_HIST_A_RAW_STAT1(x).U)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST_B_CTRL - Histogram Control Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST_B_CTRL - Histogram Control Register. (RW)
 *
 * Reset value: 0x05001F00U
 *
 * Provides control and status registers for the PXP's histogram classification
 * algorithm.
 */
typedef union _hw_pxp_hw_pxp_hist_b_ctrl
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist_b_ctrl_bitfields
    {
        uint32_t ENABLE : 1;           /*!< [0]  */
        uint32_t RSVD0 : 3;            /*!< [3:1]  */
        uint32_t CLEAR : 1;            /*!< [4]  */
        uint32_t RSVD1 : 3;            /*!< [7:5]  */
        uint32_t STATUS : 5;           /*!< [12:8]  */
        uint32_t RSVD2 : 3;            /*!< [15:13]  */
        uint32_t PIXEL_OFFSET : 7;     /*!< [22:16]  */
        uint32_t RSVD3 : 1;            /*!< [23]  */
        uint32_t PIXEL_WIDTH : 3;      /*!< [26:24]  */
        uint32_t RSVD4 : 5;            /*!< [31:27]  */
    } B;
} hw_pxp_hw_pxp_hist_b_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST_B_CTRL register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST_B_CTRL_ADDR(x) ((uintptr_t)(x) + 0x2A80U)

#define HW_PXP_HW_PXP_HIST_B_CTRL(x) (*(__IO hw_pxp_hw_pxp_hist_b_ctrl_t *) HW_PXP_HW_PXP_HIST_B_CTRL_ADDR(x))
#define HW_PXP_HW_PXP_HIST_B_CTRL_RD(x) (HW_PXP_HW_PXP_HIST_B_CTRL(x).U)
#define HW_PXP_HW_PXP_HIST_B_CTRL_WR(x, v) (HW_PXP_HW_PXP_HIST_B_CTRL(x).U = (v))
#define HW_PXP_HW_PXP_HIST_B_CTRL_SET(x, v) (HW_PXP_HW_PXP_HIST_B_CTRL_WR(x, HW_PXP_HW_PXP_HIST_B_CTRL_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST_B_CTRL_CLR(x, v) (HW_PXP_HW_PXP_HIST_B_CTRL_WR(x, HW_PXP_HW_PXP_HIST_B_CTRL_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST_B_CTRL_TOG(x, v) (HW_PXP_HW_PXP_HIST_B_CTRL_WR(x, HW_PXP_HW_PXP_HIST_B_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST_B_CTRL bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST_B_CTRL, field ENABLE[0] (RW)
 *
 * Enable the Histogram Engine
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_CTRL_ENABLE (0U) /*!< Bit position for PXP_HW_PXP_HIST_B_CTRL_ENABLE. */
#define BM_PXP_HW_PXP_HIST_B_CTRL_ENABLE (0x00000001U) /*!< Bit mask for PXP_HW_PXP_HIST_B_CTRL_ENABLE. */
#define BS_PXP_HW_PXP_HIST_B_CTRL_ENABLE (1U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_CTRL_ENABLE. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_CTRL_ENABLE field. */
#define BR_PXP_HW_PXP_HIST_B_CTRL_ENABLE(x) (HW_PXP_HW_PXP_HIST_B_CTRL(x).B.ENABLE)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_B_CTRL_ENABLE. */
#define BF_PXP_HW_PXP_HIST_B_CTRL_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_B_CTRL_ENABLE) & BM_PXP_HW_PXP_HIST_B_CTRL_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_PXP_HW_PXP_HIST_B_CTRL_ENABLE(x, v) (HW_PXP_HW_PXP_HIST_B_CTRL_WR(x, (HW_PXP_HW_PXP_HIST_B_CTRL_RD(x) & ~BM_PXP_HW_PXP_HIST_B_CTRL_ENABLE) | BF_PXP_HW_PXP_HIST_B_CTRL_ENABLE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_CTRL, field RSVD0[3:1] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_CTRL_RSVD0 (1U) /*!< Bit position for PXP_HW_PXP_HIST_B_CTRL_RSVD0. */
#define BM_PXP_HW_PXP_HIST_B_CTRL_RSVD0 (0x0000000EU) /*!< Bit mask for PXP_HW_PXP_HIST_B_CTRL_RSVD0. */
#define BS_PXP_HW_PXP_HIST_B_CTRL_RSVD0 (3U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_CTRL_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_CTRL_RSVD0 field. */
#define BR_PXP_HW_PXP_HIST_B_CTRL_RSVD0(x) (HW_PXP_HW_PXP_HIST_B_CTRL(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_CTRL, field CLEAR[4] (RW)
 *
 * Write 1 to clear the histogram result and will be self-clear after clear
 * function finished
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_CTRL_CLEAR (4U) /*!< Bit position for PXP_HW_PXP_HIST_B_CTRL_CLEAR. */
#define BM_PXP_HW_PXP_HIST_B_CTRL_CLEAR (0x00000010U) /*!< Bit mask for PXP_HW_PXP_HIST_B_CTRL_CLEAR. */
#define BS_PXP_HW_PXP_HIST_B_CTRL_CLEAR (1U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_CTRL_CLEAR. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_CTRL_CLEAR field. */
#define BR_PXP_HW_PXP_HIST_B_CTRL_CLEAR(x) (HW_PXP_HW_PXP_HIST_B_CTRL(x).B.CLEAR)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_B_CTRL_CLEAR. */
#define BF_PXP_HW_PXP_HIST_B_CTRL_CLEAR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_B_CTRL_CLEAR) & BM_PXP_HW_PXP_HIST_B_CTRL_CLEAR)

/*! @brief Set the CLEAR field to a new value. */
#define BW_PXP_HW_PXP_HIST_B_CTRL_CLEAR(x, v) (HW_PXP_HW_PXP_HIST_B_CTRL_WR(x, (HW_PXP_HW_PXP_HIST_B_CTRL_RD(x) & ~BM_PXP_HW_PXP_HIST_B_CTRL_CLEAR) | BF_PXP_HW_PXP_HIST_B_CTRL_CLEAR(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_CTRL, field RSVD1[7:5] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_CTRL_RSVD1 (5U) /*!< Bit position for PXP_HW_PXP_HIST_B_CTRL_RSVD1. */
#define BM_PXP_HW_PXP_HIST_B_CTRL_RSVD1 (0x000000E0U) /*!< Bit mask for PXP_HW_PXP_HIST_B_CTRL_RSVD1. */
#define BS_PXP_HW_PXP_HIST_B_CTRL_RSVD1 (3U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_CTRL_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_CTRL_RSVD1 field. */
#define BR_PXP_HW_PXP_HIST_B_CTRL_RSVD1(x) (HW_PXP_HW_PXP_HIST_B_CTRL(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_CTRL, field STATUS[12:8] (RO)
 *
 * Indicates which histogram matched the processed bitmap. Bit[0] indicates that
 * the bitmap pixels were fully contained within the HIST2 (black / white)
 * histogram. Bit[1] indicates that the bitmap pixels were fully contained within the
 * HIST4 (2-bit grayscale) histogram. Bit[2] indicates that the bitmap pixels
 * were fully contained within the HIST8 (3-bit grayscale) histogram. Bit[3]
 * indicates that the bitmap pixels were fully contained within the HIST16 (4-bit
 * grayscale) histogram. Bit[4] indicates that the bitmap pixels were fully contained
 * within the HIST32 (5-bit grayscale) histogram.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_CTRL_STATUS (8U) /*!< Bit position for PXP_HW_PXP_HIST_B_CTRL_STATUS. */
#define BM_PXP_HW_PXP_HIST_B_CTRL_STATUS (0x00001F00U) /*!< Bit mask for PXP_HW_PXP_HIST_B_CTRL_STATUS. */
#define BS_PXP_HW_PXP_HIST_B_CTRL_STATUS (5U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_CTRL_STATUS. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_CTRL_STATUS field. */
#define BR_PXP_HW_PXP_HIST_B_CTRL_STATUS(x) (HW_PXP_HW_PXP_HIST_B_CTRL(x).B.STATUS)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_CTRL, field RSVD2[15:13] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_CTRL_RSVD2 (13U) /*!< Bit position for PXP_HW_PXP_HIST_B_CTRL_RSVD2. */
#define BM_PXP_HW_PXP_HIST_B_CTRL_RSVD2 (0x0000E000U) /*!< Bit mask for PXP_HW_PXP_HIST_B_CTRL_RSVD2. */
#define BS_PXP_HW_PXP_HIST_B_CTRL_RSVD2 (3U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_CTRL_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_CTRL_RSVD2 field. */
#define BR_PXP_HW_PXP_HIST_B_CTRL_RSVD2(x) (HW_PXP_HW_PXP_HIST_B_CTRL(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_CTRL, field PIXEL_OFFSET[22:16] (RW)
 *
 * The offset of the pixel to be used for histogram calculation
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET (16U) /*!< Bit position for PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET. */
#define BM_PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET (0x007F0000U) /*!< Bit mask for PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET. */
#define BS_PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET (7U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET field. */
#define BR_PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET(x) (HW_PXP_HW_PXP_HIST_B_CTRL(x).B.PIXEL_OFFSET)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET. */
#define BF_PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET) & BM_PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET)

/*! @brief Set the PIXEL_OFFSET field to a new value. */
#define BW_PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET(x, v) (HW_PXP_HW_PXP_HIST_B_CTRL_WR(x, (HW_PXP_HW_PXP_HIST_B_CTRL_RD(x) & ~BM_PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET) | BF_PXP_HW_PXP_HIST_B_CTRL_PIXEL_OFFSET(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_CTRL, field RSVD3[23] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_CTRL_RSVD3 (23U) /*!< Bit position for PXP_HW_PXP_HIST_B_CTRL_RSVD3. */
#define BM_PXP_HW_PXP_HIST_B_CTRL_RSVD3 (0x00800000U) /*!< Bit mask for PXP_HW_PXP_HIST_B_CTRL_RSVD3. */
#define BS_PXP_HW_PXP_HIST_B_CTRL_RSVD3 (1U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_CTRL_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_CTRL_RSVD3 field. */
#define BR_PXP_HW_PXP_HIST_B_CTRL_RSVD3(x) (HW_PXP_HW_PXP_HIST_B_CTRL(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_CTRL, field PIXEL_WIDTH[26:24] (RW)
 *
 * The width of the pixel to be used for histogram calculation
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH (24U) /*!< Bit position for PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH. */
#define BM_PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH (0x07000000U) /*!< Bit mask for PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH. */
#define BS_PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH (3U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH field. */
#define BR_PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH(x) (HW_PXP_HW_PXP_HIST_B_CTRL(x).B.PIXEL_WIDTH)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH. */
#define BF_PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH) & BM_PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH)

/*! @brief Set the PIXEL_WIDTH field to a new value. */
#define BW_PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH(x, v) (HW_PXP_HW_PXP_HIST_B_CTRL_WR(x, (HW_PXP_HW_PXP_HIST_B_CTRL_RD(x) & ~BM_PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH) | BF_PXP_HW_PXP_HIST_B_CTRL_PIXEL_WIDTH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_CTRL, field RSVD4[31:27] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_CTRL_RSVD4 (27U) /*!< Bit position for PXP_HW_PXP_HIST_B_CTRL_RSVD4. */
#define BM_PXP_HW_PXP_HIST_B_CTRL_RSVD4 (0xF8000000U) /*!< Bit mask for PXP_HW_PXP_HIST_B_CTRL_RSVD4. */
#define BS_PXP_HW_PXP_HIST_B_CTRL_RSVD4 (5U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_CTRL_RSVD4. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_CTRL_RSVD4 field. */
#define BR_PXP_HW_PXP_HIST_B_CTRL_RSVD4(x) (HW_PXP_HW_PXP_HIST_B_CTRL(x).B.RSVD4)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST_B_MASK - Histogram Pixel Mask Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST_B_MASK - Histogram Pixel Mask Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * Provides control registers for the pixel masking in PXP's histogram.
 */
typedef union _hw_pxp_hw_pxp_hist_b_mask
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist_b_mask_bitfields
    {
        uint32_t MASK_EN : 1;          /*!< [0]  */
        uint32_t RSVD0 : 3;            /*!< [3:1]  */
        uint32_t MASK_MODE : 2;        /*!< [5:4]  */
        uint32_t MASK_OFFSET : 7;      /*!< [12:6]  */
        uint32_t MASK_WIDTH : 3;       /*!< [15:13]  */
        uint32_t MASK_VALUE0 : 8;      /*!< [23:16]  */
        uint32_t MASK_VALUE1 : 8;      /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_hist_b_mask_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST_B_MASK register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST_B_MASK_ADDR(x) ((uintptr_t)(x) + 0x2A90U)

#define HW_PXP_HW_PXP_HIST_B_MASK(x) (*(__IO hw_pxp_hw_pxp_hist_b_mask_t *) HW_PXP_HW_PXP_HIST_B_MASK_ADDR(x))
#define HW_PXP_HW_PXP_HIST_B_MASK_RD(x) (HW_PXP_HW_PXP_HIST_B_MASK(x).U)
#define HW_PXP_HW_PXP_HIST_B_MASK_WR(x, v) (HW_PXP_HW_PXP_HIST_B_MASK(x).U = (v))
#define HW_PXP_HW_PXP_HIST_B_MASK_SET(x, v) (HW_PXP_HW_PXP_HIST_B_MASK_WR(x, HW_PXP_HW_PXP_HIST_B_MASK_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST_B_MASK_CLR(x, v) (HW_PXP_HW_PXP_HIST_B_MASK_WR(x, HW_PXP_HW_PXP_HIST_B_MASK_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST_B_MASK_TOG(x, v) (HW_PXP_HW_PXP_HIST_B_MASK_WR(x, HW_PXP_HW_PXP_HIST_B_MASK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST_B_MASK bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST_B_MASK, field MASK_EN[0] (RW)
 *
 * Enable the Pixel Mask Function in Histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_MASK_MASK_EN (0U) /*!< Bit position for PXP_HW_PXP_HIST_B_MASK_MASK_EN. */
#define BM_PXP_HW_PXP_HIST_B_MASK_MASK_EN (0x00000001U) /*!< Bit mask for PXP_HW_PXP_HIST_B_MASK_MASK_EN. */
#define BS_PXP_HW_PXP_HIST_B_MASK_MASK_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_MASK_MASK_EN. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_MASK_MASK_EN field. */
#define BR_PXP_HW_PXP_HIST_B_MASK_MASK_EN(x) (HW_PXP_HW_PXP_HIST_B_MASK(x).B.MASK_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_B_MASK_MASK_EN. */
#define BF_PXP_HW_PXP_HIST_B_MASK_MASK_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_B_MASK_MASK_EN) & BM_PXP_HW_PXP_HIST_B_MASK_MASK_EN)

/*! @brief Set the MASK_EN field to a new value. */
#define BW_PXP_HW_PXP_HIST_B_MASK_MASK_EN(x, v) (HW_PXP_HW_PXP_HIST_B_MASK_WR(x, (HW_PXP_HW_PXP_HIST_B_MASK_RD(x) & ~BM_PXP_HW_PXP_HIST_B_MASK_MASK_EN) | BF_PXP_HW_PXP_HIST_B_MASK_MASK_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_MASK, field RSVD0[3:1] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_MASK_RSVD0 (1U) /*!< Bit position for PXP_HW_PXP_HIST_B_MASK_RSVD0. */
#define BM_PXP_HW_PXP_HIST_B_MASK_RSVD0 (0x0000000EU) /*!< Bit mask for PXP_HW_PXP_HIST_B_MASK_RSVD0. */
#define BS_PXP_HW_PXP_HIST_B_MASK_RSVD0 (3U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_MASK_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_MASK_RSVD0 field. */
#define BR_PXP_HW_PXP_HIST_B_MASK_RSVD0(x) (HW_PXP_HW_PXP_HIST_B_MASK(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_MASK, field MASK_MODE[5:4] (RW)
 *
 * Operation mode of pixel mask function
 *
 * Values:
 * - 0 - Run histogram for pixels equal to value0
 * - 1 - Run histogram for pixels not equal to value0
 * - 10 - Run histogram for pixels within the range of value0 to value1
 * - 11 - Run histogram for pixels outside of the rang of value0 to value1
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_MASK_MASK_MODE (4U) /*!< Bit position for PXP_HW_PXP_HIST_B_MASK_MASK_MODE. */
#define BM_PXP_HW_PXP_HIST_B_MASK_MASK_MODE (0x00000030U) /*!< Bit mask for PXP_HW_PXP_HIST_B_MASK_MASK_MODE. */
#define BS_PXP_HW_PXP_HIST_B_MASK_MASK_MODE (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_MASK_MASK_MODE. */

#define BV_PXP_HW_PXP_HIST_B_MASK_MASK_MODE_EQUAL (0U) /*!< Bit field value for PXP_HW_PXP_HIST_B_MASK_MASK_MODE: Run histogram for pixels equal to value0 */
#define BV_PXP_HW_PXP_HIST_B_MASK_MASK_MODE_NOT_EQUAL (0x1U) /*!< Bit field value for PXP_HW_PXP_HIST_B_MASK_MASK_MODE: Run histogram for pixels not equal to value0 */
#define BV_PXP_HW_PXP_HIST_B_MASK_MASK_MODE_INSIDE (0x2U) /*!< Bit field value for PXP_HW_PXP_HIST_B_MASK_MASK_MODE: Run histogram for pixels within the range of value0 to value1 */
#define BV_PXP_HW_PXP_HIST_B_MASK_MASK_MODE_OUTSIDE (0x3U) /*!< Bit field value for PXP_HW_PXP_HIST_B_MASK_MASK_MODE: Run histogram for pixels outside of the rang of value0 to value1 */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_MASK_MASK_MODE field. */
#define BR_PXP_HW_PXP_HIST_B_MASK_MASK_MODE(x) (HW_PXP_HW_PXP_HIST_B_MASK(x).B.MASK_MODE)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_B_MASK_MASK_MODE. */
#define BF_PXP_HW_PXP_HIST_B_MASK_MASK_MODE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_B_MASK_MASK_MODE) & BM_PXP_HW_PXP_HIST_B_MASK_MASK_MODE)

/*! @brief Set the MASK_MODE field to a new value. */
#define BW_PXP_HW_PXP_HIST_B_MASK_MASK_MODE(x, v) (HW_PXP_HW_PXP_HIST_B_MASK_WR(x, (HW_PXP_HW_PXP_HIST_B_MASK_RD(x) & ~BM_PXP_HW_PXP_HIST_B_MASK_MASK_MODE) | BF_PXP_HW_PXP_HIST_B_MASK_MASK_MODE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_MASK, field MASK_OFFSET[12:6] (RW)
 *
 * The offset of the field to be checked against mask condition
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET (6U) /*!< Bit position for PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET. */
#define BM_PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET (0x00001FC0U) /*!< Bit mask for PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET. */
#define BS_PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET (7U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET field. */
#define BR_PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET(x) (HW_PXP_HW_PXP_HIST_B_MASK(x).B.MASK_OFFSET)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET. */
#define BF_PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET) & BM_PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET)

/*! @brief Set the MASK_OFFSET field to a new value. */
#define BW_PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET(x, v) (HW_PXP_HW_PXP_HIST_B_MASK_WR(x, (HW_PXP_HW_PXP_HIST_B_MASK_RD(x) & ~BM_PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET) | BF_PXP_HW_PXP_HIST_B_MASK_MASK_OFFSET(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_MASK, field MASK_WIDTH[15:13] (RW)
 *
 * The width of the field to be checked against mask condition
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH (13U) /*!< Bit position for PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH. */
#define BM_PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH (0x0000E000U) /*!< Bit mask for PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH. */
#define BS_PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH (3U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH field. */
#define BR_PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH(x) (HW_PXP_HW_PXP_HIST_B_MASK(x).B.MASK_WIDTH)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH. */
#define BF_PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH) & BM_PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH)

/*! @brief Set the MASK_WIDTH field to a new value. */
#define BW_PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH(x, v) (HW_PXP_HW_PXP_HIST_B_MASK_WR(x, (HW_PXP_HW_PXP_HIST_B_MASK_RD(x) & ~BM_PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH) | BF_PXP_HW_PXP_HIST_B_MASK_MASK_WIDTH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_MASK, field MASK_VALUE0[23:16] (RW)
 *
 * The value0 for mask condition checking
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0 (16U) /*!< Bit position for PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0. */
#define BM_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0 (0x00FF0000U) /*!< Bit mask for PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0. */
#define BS_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0 (8U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0 field. */
#define BR_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0(x) (HW_PXP_HW_PXP_HIST_B_MASK(x).B.MASK_VALUE0)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0. */
#define BF_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0) & BM_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0)

/*! @brief Set the MASK_VALUE0 field to a new value. */
#define BW_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0(x, v) (HW_PXP_HW_PXP_HIST_B_MASK_WR(x, (HW_PXP_HW_PXP_HIST_B_MASK_RD(x) & ~BM_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0) | BF_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_MASK, field MASK_VALUE1[31:24] (RW)
 *
 * The value1 for mask condition checking
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1 (24U) /*!< Bit position for PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1. */
#define BM_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1. */
#define BS_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1 (8U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1 field. */
#define BR_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1(x) (HW_PXP_HW_PXP_HIST_B_MASK(x).B.MASK_VALUE1)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1. */
#define BF_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1) & BM_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1)

/*! @brief Set the MASK_VALUE1 field to a new value. */
#define BW_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1(x, v) (HW_PXP_HW_PXP_HIST_B_MASK_WR(x, (HW_PXP_HW_PXP_HIST_B_MASK_RD(x) & ~BM_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1) | BF_PXP_HW_PXP_HIST_B_MASK_MASK_VALUE1(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST_B_BUF_SIZE - Histogram Pixel Buffer Size Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST_B_BUF_SIZE - Histogram Pixel Buffer Size Register. (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the size of the buffer to be processed by the histogram
 * engine.
 */
typedef union _hw_pxp_hw_pxp_hist_b_buf_size
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist_b_buf_size_bitfields
    {
        uint32_t WIDTH : 12;           /*!< [11:0]  */
        uint32_t RSVD1 : 4;            /*!< [15:12]  */
        uint32_t HEIGHT : 12;          /*!< [27:16]  */
        uint32_t RSVD0 : 4;            /*!< [31:28]  */
    } B;
} hw_pxp_hw_pxp_hist_b_buf_size_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST_B_BUF_SIZE register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST_B_BUF_SIZE_ADDR(x) ((uintptr_t)(x) + 0x2AA0U)

#define HW_PXP_HW_PXP_HIST_B_BUF_SIZE(x) (*(__IO hw_pxp_hw_pxp_hist_b_buf_size_t *) HW_PXP_HW_PXP_HIST_B_BUF_SIZE_ADDR(x))
#define HW_PXP_HW_PXP_HIST_B_BUF_SIZE_RD(x) (HW_PXP_HW_PXP_HIST_B_BUF_SIZE(x).U)
#define HW_PXP_HW_PXP_HIST_B_BUF_SIZE_WR(x, v) (HW_PXP_HW_PXP_HIST_B_BUF_SIZE(x).U = (v))
#define HW_PXP_HW_PXP_HIST_B_BUF_SIZE_SET(x, v) (HW_PXP_HW_PXP_HIST_B_BUF_SIZE_WR(x, HW_PXP_HW_PXP_HIST_B_BUF_SIZE_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST_B_BUF_SIZE_CLR(x, v) (HW_PXP_HW_PXP_HIST_B_BUF_SIZE_WR(x, HW_PXP_HW_PXP_HIST_B_BUF_SIZE_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST_B_BUF_SIZE_TOG(x, v) (HW_PXP_HW_PXP_HIST_B_BUF_SIZE_WR(x, HW_PXP_HW_PXP_HIST_B_BUF_SIZE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST_B_BUF_SIZE bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST_B_BUF_SIZE, field WIDTH[11:0] (RW)
 *
 * This indicate the buffer width in pixels
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH (0U) /*!< Bit position for PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH. */
#define BM_PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH (0x00000FFFU) /*!< Bit mask for PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH. */
#define BS_PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH (12U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH field. */
#define BR_PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH(x) (HW_PXP_HW_PXP_HIST_B_BUF_SIZE(x).B.WIDTH)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH. */
#define BF_PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH) & BM_PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH)

/*! @brief Set the WIDTH field to a new value. */
#define BW_PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH(x, v) (HW_PXP_HW_PXP_HIST_B_BUF_SIZE_WR(x, (HW_PXP_HW_PXP_HIST_B_BUF_SIZE_RD(x) & ~BM_PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH) | BF_PXP_HW_PXP_HIST_B_BUF_SIZE_WIDTH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_BUF_SIZE, field RSVD1[15:12] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD1 (12U) /*!< Bit position for PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD1. */
#define BM_PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD1 (0x0000F000U) /*!< Bit mask for PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD1. */
#define BS_PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD1 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD1 field. */
#define BR_PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD1(x) (HW_PXP_HW_PXP_HIST_B_BUF_SIZE(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_BUF_SIZE, field HEIGHT[27:16] (RW)
 *
 * This indicate the buffer height in pixels
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT (16U) /*!< Bit position for PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT. */
#define BM_PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT (0x0FFF0000U) /*!< Bit mask for PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT. */
#define BS_PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT (12U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT field. */
#define BR_PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT(x) (HW_PXP_HW_PXP_HIST_B_BUF_SIZE(x).B.HEIGHT)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT. */
#define BF_PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT) & BM_PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT)

/*! @brief Set the HEIGHT field to a new value. */
#define BW_PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT(x, v) (HW_PXP_HW_PXP_HIST_B_BUF_SIZE_WR(x, (HW_PXP_HW_PXP_HIST_B_BUF_SIZE_RD(x) & ~BM_PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT) | BF_PXP_HW_PXP_HIST_B_BUF_SIZE_HEIGHT(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_BUF_SIZE, field RSVD0[31:28] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD0 (28U) /*!< Bit position for PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD0. */
#define BM_PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD0 (0xF0000000U) /*!< Bit mask for PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD0. */
#define BS_PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD0 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD0 field. */
#define BR_PXP_HW_PXP_HIST_B_BUF_SIZE_RSVD0(x) (HW_PXP_HW_PXP_HIST_B_BUF_SIZE(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST_B_TOTAL_PIXEL - Total Number of Pixels Used by Histogram Engine.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST_B_TOTAL_PIXEL - Total Number of Pixels Used by Histogram Engine. (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register shows the total number of pixels used by histogram engine
 */
typedef union _hw_pxp_hw_pxp_hist_b_total_pixel
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist_b_total_pixel_bitfields
    {
        uint32_t TOTAL_PIXEL : 24;     /*!< [23:0]  */
        uint32_t RSVD0 : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_hist_b_total_pixel_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST_B_TOTAL_PIXEL register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST_B_TOTAL_PIXEL_ADDR(x) ((uintptr_t)(x) + 0x2AB0U)

#define HW_PXP_HW_PXP_HIST_B_TOTAL_PIXEL(x) (*(__I hw_pxp_hw_pxp_hist_b_total_pixel_t *) HW_PXP_HW_PXP_HIST_B_TOTAL_PIXEL_ADDR(x))
#define HW_PXP_HW_PXP_HIST_B_TOTAL_PIXEL_RD(x) (HW_PXP_HW_PXP_HIST_B_TOTAL_PIXEL(x).U)
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST_B_TOTAL_PIXEL bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST_B_TOTAL_PIXEL, field TOTAL_PIXEL[23:0] (RO)
 *
 * Total number of pixels used by histogram engine, the pixels got masked will
 * be skipped
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_TOTAL_PIXEL_TOTAL_PIXEL (0U) /*!< Bit position for PXP_HW_PXP_HIST_B_TOTAL_PIXEL_TOTAL_PIXEL. */
#define BM_PXP_HW_PXP_HIST_B_TOTAL_PIXEL_TOTAL_PIXEL (0x00FFFFFFU) /*!< Bit mask for PXP_HW_PXP_HIST_B_TOTAL_PIXEL_TOTAL_PIXEL. */
#define BS_PXP_HW_PXP_HIST_B_TOTAL_PIXEL_TOTAL_PIXEL (24U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_TOTAL_PIXEL_TOTAL_PIXEL. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_TOTAL_PIXEL_TOTAL_PIXEL field. */
#define BR_PXP_HW_PXP_HIST_B_TOTAL_PIXEL_TOTAL_PIXEL(x) (HW_PXP_HW_PXP_HIST_B_TOTAL_PIXEL(x).B.TOTAL_PIXEL)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_TOTAL_PIXEL, field RSVD0[31:24] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_TOTAL_PIXEL_RSVD0 (24U) /*!< Bit position for PXP_HW_PXP_HIST_B_TOTAL_PIXEL_RSVD0. */
#define BM_PXP_HW_PXP_HIST_B_TOTAL_PIXEL_RSVD0 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_HIST_B_TOTAL_PIXEL_RSVD0. */
#define BS_PXP_HW_PXP_HIST_B_TOTAL_PIXEL_RSVD0 (8U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_TOTAL_PIXEL_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_TOTAL_PIXEL_RSVD0 field. */
#define BR_PXP_HW_PXP_HIST_B_TOTAL_PIXEL_RSVD0(x) (HW_PXP_HW_PXP_HIST_B_TOTAL_PIXEL(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X - The X Coordinate Offset for Active Area.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X - The X Coordinate Offset for Active Area. (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register shows the minimal and maximum X coordinate offset for the
 * active area in histogram processing
 */
typedef union _hw_pxp_hw_pxp_hist_b_active_area_x
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist_b_active_area_x_bitfields
    {
        uint32_t MIN_X_OFFSET : 12;    /*!< [11:0]  */
        uint32_t RSVD0 : 4;            /*!< [15:12]  */
        uint32_t MAX_X_OFFSET : 12;    /*!< [27:16]  */
        uint32_t RSVD1 : 4;            /*!< [31:28]  */
    } B;
} hw_pxp_hw_pxp_hist_b_active_area_x_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST_B_ACTIVE_AREA_X register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_ADDR(x) ((uintptr_t)(x) + 0x2AC0U)

#define HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X(x) (*(__I hw_pxp_hw_pxp_hist_b_active_area_x_t *) HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_ADDR(x))
#define HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RD(x) (HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X(x).U)
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST_B_ACTIVE_AREA_X bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST_B_ACTIVE_AREA_X, field MIN_X_OFFSET[11:0] (RO)
 *
 * Minimul X coordinate offset for the active area in histogram processing
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MIN_X_OFFSET (0U) /*!< Bit position for PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MIN_X_OFFSET. */
#define BM_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MIN_X_OFFSET (0x00000FFFU) /*!< Bit mask for PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MIN_X_OFFSET. */
#define BS_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MIN_X_OFFSET (12U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MIN_X_OFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MIN_X_OFFSET field. */
#define BR_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MIN_X_OFFSET(x) (HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X(x).B.MIN_X_OFFSET)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_ACTIVE_AREA_X, field RSVD0[15:12] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD0 (12U) /*!< Bit position for PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD0. */
#define BM_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD0 (0x0000F000U) /*!< Bit mask for PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD0. */
#define BS_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD0 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD0 field. */
#define BR_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD0(x) (HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_ACTIVE_AREA_X, field MAX_X_OFFSET[27:16] (RO)
 *
 * Maximum X coordinate offset for the active area in histogram processing
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MAX_X_OFFSET (16U) /*!< Bit position for PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MAX_X_OFFSET. */
#define BM_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MAX_X_OFFSET (0x0FFF0000U) /*!< Bit mask for PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MAX_X_OFFSET. */
#define BS_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MAX_X_OFFSET (12U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MAX_X_OFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MAX_X_OFFSET field. */
#define BR_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_MAX_X_OFFSET(x) (HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X(x).B.MAX_X_OFFSET)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_ACTIVE_AREA_X, field RSVD1[31:28] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD1 (28U) /*!< Bit position for PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD1. */
#define BM_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD1 (0xF0000000U) /*!< Bit mask for PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD1. */
#define BS_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD1 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD1 field. */
#define BR_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X_RSVD1(x) (HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_X(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y - The Y Coordinate Offset for Active Area.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y - The Y Coordinate Offset for Active Area. (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register shows the minimal and maximum Y coordinate offset for the
 * active area in histogram processing
 */
typedef union _hw_pxp_hw_pxp_hist_b_active_area_y
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist_b_active_area_y_bitfields
    {
        uint32_t MIN_Y_OFFSET : 12;    /*!< [11:0]  */
        uint32_t RSVD0 : 4;            /*!< [15:12]  */
        uint32_t MAX_Y_OFFSET : 12;    /*!< [27:16]  */
        uint32_t RSVD1 : 4;            /*!< [31:28]  */
    } B;
} hw_pxp_hw_pxp_hist_b_active_area_y_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_ADDR(x) ((uintptr_t)(x) + 0x2AD0U)

#define HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y(x) (*(__I hw_pxp_hw_pxp_hist_b_active_area_y_t *) HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_ADDR(x))
#define HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RD(x) (HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y(x).U)
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y, field MIN_Y_OFFSET[11:0] (RO)
 *
 * Minimul Y coordinate offset for the active area in histogram processing
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MIN_Y_OFFSET (0U) /*!< Bit position for PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MIN_Y_OFFSET. */
#define BM_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MIN_Y_OFFSET (0x00000FFFU) /*!< Bit mask for PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MIN_Y_OFFSET. */
#define BS_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MIN_Y_OFFSET (12U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MIN_Y_OFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MIN_Y_OFFSET field. */
#define BR_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MIN_Y_OFFSET(x) (HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y(x).B.MIN_Y_OFFSET)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y, field RSVD0[15:12] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD0 (12U) /*!< Bit position for PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD0. */
#define BM_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD0 (0x0000F000U) /*!< Bit mask for PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD0. */
#define BS_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD0 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD0 field. */
#define BR_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD0(x) (HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y, field MAX_Y_OFFSET[27:16] (RO)
 *
 * Maximum Y coordinate offset for the active area in histogram processing
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MAX_Y_OFFSET (16U) /*!< Bit position for PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MAX_Y_OFFSET. */
#define BM_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MAX_Y_OFFSET (0x0FFF0000U) /*!< Bit mask for PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MAX_Y_OFFSET. */
#define BS_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MAX_Y_OFFSET (12U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MAX_Y_OFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MAX_Y_OFFSET field. */
#define BR_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_MAX_Y_OFFSET(x) (HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y(x).B.MAX_Y_OFFSET)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y, field RSVD1[31:28] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD1 (28U) /*!< Bit position for PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD1. */
#define BM_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD1 (0xF0000000U) /*!< Bit mask for PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD1. */
#define BS_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD1 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD1 field. */
#define BR_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y_RSVD1(x) (HW_PXP_HW_PXP_HIST_B_ACTIVE_AREA_Y(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST_B_RAW_STAT0 - Histogram Result Based on RAW Pixel Value.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST_B_RAW_STAT0 - Histogram Result Based on RAW Pixel Value. (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register shows the lower 32-bit of the histogram result based on raw
 * pixel value
 */
typedef union _hw_pxp_hw_pxp_hist_b_raw_stat0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist_b_raw_stat0_bitfields
    {
        uint32_t STAT0 : 32;           /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_hist_b_raw_stat0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST_B_RAW_STAT0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST_B_RAW_STAT0_ADDR(x) ((uintptr_t)(x) + 0x2AE0U)

#define HW_PXP_HW_PXP_HIST_B_RAW_STAT0(x) (*(__I hw_pxp_hw_pxp_hist_b_raw_stat0_t *) HW_PXP_HW_PXP_HIST_B_RAW_STAT0_ADDR(x))
#define HW_PXP_HW_PXP_HIST_B_RAW_STAT0_RD(x) (HW_PXP_HW_PXP_HIST_B_RAW_STAT0(x).U)
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST_B_RAW_STAT0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST_B_RAW_STAT0, field STAT0[31:0] (RO)
 *
 * Lower 32-bit result fo the histogram calculation
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_RAW_STAT0_STAT0 (0U) /*!< Bit position for PXP_HW_PXP_HIST_B_RAW_STAT0_STAT0. */
#define BM_PXP_HW_PXP_HIST_B_RAW_STAT0_STAT0 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_HIST_B_RAW_STAT0_STAT0. */
#define BS_PXP_HW_PXP_HIST_B_RAW_STAT0_STAT0 (32U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_RAW_STAT0_STAT0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_RAW_STAT0_STAT0 field. */
#define BR_PXP_HW_PXP_HIST_B_RAW_STAT0_STAT0(x) (HW_PXP_HW_PXP_HIST_B_RAW_STAT0(x).U)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST_B_RAW_STAT1 - Histogram Result Based on RAW Pixel Value.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST_B_RAW_STAT1 - Histogram Result Based on RAW Pixel Value. (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register shows the higher 32-bit of the histogram result based on raw
 * pixel value
 */
typedef union _hw_pxp_hw_pxp_hist_b_raw_stat1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist_b_raw_stat1_bitfields
    {
        uint32_t STAT1 : 32;           /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_hist_b_raw_stat1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST_B_RAW_STAT1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST_B_RAW_STAT1_ADDR(x) ((uintptr_t)(x) + 0x2AF0U)

#define HW_PXP_HW_PXP_HIST_B_RAW_STAT1(x) (*(__I hw_pxp_hw_pxp_hist_b_raw_stat1_t *) HW_PXP_HW_PXP_HIST_B_RAW_STAT1_ADDR(x))
#define HW_PXP_HW_PXP_HIST_B_RAW_STAT1_RD(x) (HW_PXP_HW_PXP_HIST_B_RAW_STAT1(x).U)
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST_B_RAW_STAT1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST_B_RAW_STAT1, field STAT1[31:0] (RO)
 *
 * Higher 32-bit result fo the histogram calculation
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST_B_RAW_STAT1_STAT1 (0U) /*!< Bit position for PXP_HW_PXP_HIST_B_RAW_STAT1_STAT1. */
#define BM_PXP_HW_PXP_HIST_B_RAW_STAT1_STAT1 (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_HIST_B_RAW_STAT1_STAT1. */
#define BS_PXP_HW_PXP_HIST_B_RAW_STAT1_STAT1 (32U) /*!< Bit field size in bits for PXP_HW_PXP_HIST_B_RAW_STAT1_STAT1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST_B_RAW_STAT1_STAT1 field. */
#define BR_PXP_HW_PXP_HIST_B_RAW_STAT1_STAT1(x) (HW_PXP_HW_PXP_HIST_B_RAW_STAT1(x).U)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST2_PARAM - 2-level Histogram Parameter Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST2_PARAM - 2-level Histogram Parameter Register. (RW)
 *
 * Reset value: 0x00000F00U
 *
 * This register specifies the valid values for a 2-level histogram. If all
 * pixels in a bitmap match the 2-level histogram values, STATUS[0] will be set at
 * the end of frame processing. All comparator values should be programmed such
 * that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hw_pxp_hist2_param
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist2_param_bitfields
    {
        uint32_t VALUE0 : 6;           /*!< [5:0]  */
        uint32_t RSVD0 : 2;            /*!< [7:6]  */
        uint32_t VALUE1 : 6;           /*!< [13:8]  */
        uint32_t RSVD1 : 2;            /*!< [15:14]  */
        uint32_t RSVD : 16;            /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_hist2_param_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST2_PARAM register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST2_PARAM_ADDR(x) ((uintptr_t)(x) + 0x2B00U)

#define HW_PXP_HW_PXP_HIST2_PARAM(x) (*(__IO hw_pxp_hw_pxp_hist2_param_t *) HW_PXP_HW_PXP_HIST2_PARAM_ADDR(x))
#define HW_PXP_HW_PXP_HIST2_PARAM_RD(x) (HW_PXP_HW_PXP_HIST2_PARAM(x).U)
#define HW_PXP_HW_PXP_HIST2_PARAM_WR(x, v) (HW_PXP_HW_PXP_HIST2_PARAM(x).U = (v))
#define HW_PXP_HW_PXP_HIST2_PARAM_SET(x, v) (HW_PXP_HW_PXP_HIST2_PARAM_WR(x, HW_PXP_HW_PXP_HIST2_PARAM_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST2_PARAM_CLR(x, v) (HW_PXP_HW_PXP_HIST2_PARAM_WR(x, HW_PXP_HW_PXP_HIST2_PARAM_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST2_PARAM_TOG(x, v) (HW_PXP_HW_PXP_HIST2_PARAM_WR(x, HW_PXP_HW_PXP_HIST2_PARAM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST2_PARAM bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST2_PARAM, field VALUE0[5:0] (RW)
 *
 * Black value for 2-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST2_PARAM_VALUE0 (0U) /*!< Bit position for PXP_HW_PXP_HIST2_PARAM_VALUE0. */
#define BM_PXP_HW_PXP_HIST2_PARAM_VALUE0 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_HIST2_PARAM_VALUE0. */
#define BS_PXP_HW_PXP_HIST2_PARAM_VALUE0 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST2_PARAM_VALUE0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST2_PARAM_VALUE0 field. */
#define BR_PXP_HW_PXP_HIST2_PARAM_VALUE0(x) (HW_PXP_HW_PXP_HIST2_PARAM(x).B.VALUE0)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST2_PARAM_VALUE0. */
#define BF_PXP_HW_PXP_HIST2_PARAM_VALUE0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST2_PARAM_VALUE0) & BM_PXP_HW_PXP_HIST2_PARAM_VALUE0)

/*! @brief Set the VALUE0 field to a new value. */
#define BW_PXP_HW_PXP_HIST2_PARAM_VALUE0(x, v) (HW_PXP_HW_PXP_HIST2_PARAM_WR(x, (HW_PXP_HW_PXP_HIST2_PARAM_RD(x) & ~BM_PXP_HW_PXP_HIST2_PARAM_VALUE0) | BF_PXP_HW_PXP_HIST2_PARAM_VALUE0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST2_PARAM, field RSVD0[7:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST2_PARAM_RSVD0 (6U) /*!< Bit position for PXP_HW_PXP_HIST2_PARAM_RSVD0. */
#define BM_PXP_HW_PXP_HIST2_PARAM_RSVD0 (0x000000C0U) /*!< Bit mask for PXP_HW_PXP_HIST2_PARAM_RSVD0. */
#define BS_PXP_HW_PXP_HIST2_PARAM_RSVD0 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST2_PARAM_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST2_PARAM_RSVD0 field. */
#define BR_PXP_HW_PXP_HIST2_PARAM_RSVD0(x) (HW_PXP_HW_PXP_HIST2_PARAM(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST2_PARAM, field VALUE1[13:8] (RW)
 *
 * White value for 2-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST2_PARAM_VALUE1 (8U) /*!< Bit position for PXP_HW_PXP_HIST2_PARAM_VALUE1. */
#define BM_PXP_HW_PXP_HIST2_PARAM_VALUE1 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_HIST2_PARAM_VALUE1. */
#define BS_PXP_HW_PXP_HIST2_PARAM_VALUE1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST2_PARAM_VALUE1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST2_PARAM_VALUE1 field. */
#define BR_PXP_HW_PXP_HIST2_PARAM_VALUE1(x) (HW_PXP_HW_PXP_HIST2_PARAM(x).B.VALUE1)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST2_PARAM_VALUE1. */
#define BF_PXP_HW_PXP_HIST2_PARAM_VALUE1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST2_PARAM_VALUE1) & BM_PXP_HW_PXP_HIST2_PARAM_VALUE1)

/*! @brief Set the VALUE1 field to a new value. */
#define BW_PXP_HW_PXP_HIST2_PARAM_VALUE1(x, v) (HW_PXP_HW_PXP_HIST2_PARAM_WR(x, (HW_PXP_HW_PXP_HIST2_PARAM_RD(x) & ~BM_PXP_HW_PXP_HIST2_PARAM_VALUE1) | BF_PXP_HW_PXP_HIST2_PARAM_VALUE1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST2_PARAM, field RSVD1[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST2_PARAM_RSVD1 (14U) /*!< Bit position for PXP_HW_PXP_HIST2_PARAM_RSVD1. */
#define BM_PXP_HW_PXP_HIST2_PARAM_RSVD1 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_HIST2_PARAM_RSVD1. */
#define BS_PXP_HW_PXP_HIST2_PARAM_RSVD1 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST2_PARAM_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST2_PARAM_RSVD1 field. */
#define BR_PXP_HW_PXP_HIST2_PARAM_RSVD1(x) (HW_PXP_HW_PXP_HIST2_PARAM(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST2_PARAM, field RSVD[31:16] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST2_PARAM_RSVD (16U) /*!< Bit position for PXP_HW_PXP_HIST2_PARAM_RSVD. */
#define BM_PXP_HW_PXP_HIST2_PARAM_RSVD (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_HIST2_PARAM_RSVD. */
#define BS_PXP_HW_PXP_HIST2_PARAM_RSVD (16U) /*!< Bit field size in bits for PXP_HW_PXP_HIST2_PARAM_RSVD. */

/*! @brief Read current value of the PXP_HW_PXP_HIST2_PARAM_RSVD field. */
#define BR_PXP_HW_PXP_HIST2_PARAM_RSVD(x) (HW_PXP_HW_PXP_HIST2_PARAM(x).B.RSVD)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST4_PARAM - 4-level Histogram Parameter Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST4_PARAM - 4-level Histogram Parameter Register. (RW)
 *
 * Reset value: 0x0F0A0500U
 *
 * This register specifies the valid values for a 4-level histogram. If all
 * pixels in a bitmap match the 4-level histogram values, STATUS[1] will be set at
 * the end of frame processing. All comparator values should be programmed such
 * that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hw_pxp_hist4_param
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist4_param_bitfields
    {
        uint32_t VALUE0 : 6;           /*!< [5:0]  */
        uint32_t RSVD0 : 2;            /*!< [7:6]  */
        uint32_t VALUE1 : 6;           /*!< [13:8]  */
        uint32_t RSVD1 : 2;            /*!< [15:14]  */
        uint32_t VALUE2 : 6;           /*!< [21:16]  */
        uint32_t RSVD2 : 2;            /*!< [23:22]  */
        uint32_t VALUE3 : 6;           /*!< [29:24]  */
        uint32_t RSVD3 : 2;            /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_hist4_param_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST4_PARAM register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST4_PARAM_ADDR(x) ((uintptr_t)(x) + 0x2B10U)

#define HW_PXP_HW_PXP_HIST4_PARAM(x) (*(__IO hw_pxp_hw_pxp_hist4_param_t *) HW_PXP_HW_PXP_HIST4_PARAM_ADDR(x))
#define HW_PXP_HW_PXP_HIST4_PARAM_RD(x) (HW_PXP_HW_PXP_HIST4_PARAM(x).U)
#define HW_PXP_HW_PXP_HIST4_PARAM_WR(x, v) (HW_PXP_HW_PXP_HIST4_PARAM(x).U = (v))
#define HW_PXP_HW_PXP_HIST4_PARAM_SET(x, v) (HW_PXP_HW_PXP_HIST4_PARAM_WR(x, HW_PXP_HW_PXP_HIST4_PARAM_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST4_PARAM_CLR(x, v) (HW_PXP_HW_PXP_HIST4_PARAM_WR(x, HW_PXP_HW_PXP_HIST4_PARAM_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST4_PARAM_TOG(x, v) (HW_PXP_HW_PXP_HIST4_PARAM_WR(x, HW_PXP_HW_PXP_HIST4_PARAM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST4_PARAM bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST4_PARAM, field VALUE0[5:0] (RW)
 *
 * GRAY0 (Black) value for 4-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST4_PARAM_VALUE0 (0U) /*!< Bit position for PXP_HW_PXP_HIST4_PARAM_VALUE0. */
#define BM_PXP_HW_PXP_HIST4_PARAM_VALUE0 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_HIST4_PARAM_VALUE0. */
#define BS_PXP_HW_PXP_HIST4_PARAM_VALUE0 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST4_PARAM_VALUE0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST4_PARAM_VALUE0 field. */
#define BR_PXP_HW_PXP_HIST4_PARAM_VALUE0(x) (HW_PXP_HW_PXP_HIST4_PARAM(x).B.VALUE0)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST4_PARAM_VALUE0. */
#define BF_PXP_HW_PXP_HIST4_PARAM_VALUE0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST4_PARAM_VALUE0) & BM_PXP_HW_PXP_HIST4_PARAM_VALUE0)

/*! @brief Set the VALUE0 field to a new value. */
#define BW_PXP_HW_PXP_HIST4_PARAM_VALUE0(x, v) (HW_PXP_HW_PXP_HIST4_PARAM_WR(x, (HW_PXP_HW_PXP_HIST4_PARAM_RD(x) & ~BM_PXP_HW_PXP_HIST4_PARAM_VALUE0) | BF_PXP_HW_PXP_HIST4_PARAM_VALUE0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST4_PARAM, field RSVD0[7:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST4_PARAM_RSVD0 (6U) /*!< Bit position for PXP_HW_PXP_HIST4_PARAM_RSVD0. */
#define BM_PXP_HW_PXP_HIST4_PARAM_RSVD0 (0x000000C0U) /*!< Bit mask for PXP_HW_PXP_HIST4_PARAM_RSVD0. */
#define BS_PXP_HW_PXP_HIST4_PARAM_RSVD0 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST4_PARAM_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST4_PARAM_RSVD0 field. */
#define BR_PXP_HW_PXP_HIST4_PARAM_RSVD0(x) (HW_PXP_HW_PXP_HIST4_PARAM(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST4_PARAM, field VALUE1[13:8] (RW)
 *
 * GRAY1 value for 4-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST4_PARAM_VALUE1 (8U) /*!< Bit position for PXP_HW_PXP_HIST4_PARAM_VALUE1. */
#define BM_PXP_HW_PXP_HIST4_PARAM_VALUE1 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_HIST4_PARAM_VALUE1. */
#define BS_PXP_HW_PXP_HIST4_PARAM_VALUE1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST4_PARAM_VALUE1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST4_PARAM_VALUE1 field. */
#define BR_PXP_HW_PXP_HIST4_PARAM_VALUE1(x) (HW_PXP_HW_PXP_HIST4_PARAM(x).B.VALUE1)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST4_PARAM_VALUE1. */
#define BF_PXP_HW_PXP_HIST4_PARAM_VALUE1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST4_PARAM_VALUE1) & BM_PXP_HW_PXP_HIST4_PARAM_VALUE1)

/*! @brief Set the VALUE1 field to a new value. */
#define BW_PXP_HW_PXP_HIST4_PARAM_VALUE1(x, v) (HW_PXP_HW_PXP_HIST4_PARAM_WR(x, (HW_PXP_HW_PXP_HIST4_PARAM_RD(x) & ~BM_PXP_HW_PXP_HIST4_PARAM_VALUE1) | BF_PXP_HW_PXP_HIST4_PARAM_VALUE1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST4_PARAM, field RSVD1[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST4_PARAM_RSVD1 (14U) /*!< Bit position for PXP_HW_PXP_HIST4_PARAM_RSVD1. */
#define BM_PXP_HW_PXP_HIST4_PARAM_RSVD1 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_HIST4_PARAM_RSVD1. */
#define BS_PXP_HW_PXP_HIST4_PARAM_RSVD1 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST4_PARAM_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST4_PARAM_RSVD1 field. */
#define BR_PXP_HW_PXP_HIST4_PARAM_RSVD1(x) (HW_PXP_HW_PXP_HIST4_PARAM(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST4_PARAM, field VALUE2[21:16] (RW)
 *
 * GRAY2 value for 4-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST4_PARAM_VALUE2 (16U) /*!< Bit position for PXP_HW_PXP_HIST4_PARAM_VALUE2. */
#define BM_PXP_HW_PXP_HIST4_PARAM_VALUE2 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_HIST4_PARAM_VALUE2. */
#define BS_PXP_HW_PXP_HIST4_PARAM_VALUE2 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST4_PARAM_VALUE2. */

/*! @brief Read current value of the PXP_HW_PXP_HIST4_PARAM_VALUE2 field. */
#define BR_PXP_HW_PXP_HIST4_PARAM_VALUE2(x) (HW_PXP_HW_PXP_HIST4_PARAM(x).B.VALUE2)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST4_PARAM_VALUE2. */
#define BF_PXP_HW_PXP_HIST4_PARAM_VALUE2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST4_PARAM_VALUE2) & BM_PXP_HW_PXP_HIST4_PARAM_VALUE2)

/*! @brief Set the VALUE2 field to a new value. */
#define BW_PXP_HW_PXP_HIST4_PARAM_VALUE2(x, v) (HW_PXP_HW_PXP_HIST4_PARAM_WR(x, (HW_PXP_HW_PXP_HIST4_PARAM_RD(x) & ~BM_PXP_HW_PXP_HIST4_PARAM_VALUE2) | BF_PXP_HW_PXP_HIST4_PARAM_VALUE2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST4_PARAM, field RSVD2[23:22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST4_PARAM_RSVD2 (22U) /*!< Bit position for PXP_HW_PXP_HIST4_PARAM_RSVD2. */
#define BM_PXP_HW_PXP_HIST4_PARAM_RSVD2 (0x00C00000U) /*!< Bit mask for PXP_HW_PXP_HIST4_PARAM_RSVD2. */
#define BS_PXP_HW_PXP_HIST4_PARAM_RSVD2 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST4_PARAM_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_HIST4_PARAM_RSVD2 field. */
#define BR_PXP_HW_PXP_HIST4_PARAM_RSVD2(x) (HW_PXP_HW_PXP_HIST4_PARAM(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST4_PARAM, field VALUE3[29:24] (RW)
 *
 * GRAY3 (White) value for 4-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST4_PARAM_VALUE3 (24U) /*!< Bit position for PXP_HW_PXP_HIST4_PARAM_VALUE3. */
#define BM_PXP_HW_PXP_HIST4_PARAM_VALUE3 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_HIST4_PARAM_VALUE3. */
#define BS_PXP_HW_PXP_HIST4_PARAM_VALUE3 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST4_PARAM_VALUE3. */

/*! @brief Read current value of the PXP_HW_PXP_HIST4_PARAM_VALUE3 field. */
#define BR_PXP_HW_PXP_HIST4_PARAM_VALUE3(x) (HW_PXP_HW_PXP_HIST4_PARAM(x).B.VALUE3)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST4_PARAM_VALUE3. */
#define BF_PXP_HW_PXP_HIST4_PARAM_VALUE3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST4_PARAM_VALUE3) & BM_PXP_HW_PXP_HIST4_PARAM_VALUE3)

/*! @brief Set the VALUE3 field to a new value. */
#define BW_PXP_HW_PXP_HIST4_PARAM_VALUE3(x, v) (HW_PXP_HW_PXP_HIST4_PARAM_WR(x, (HW_PXP_HW_PXP_HIST4_PARAM_RD(x) & ~BM_PXP_HW_PXP_HIST4_PARAM_VALUE3) | BF_PXP_HW_PXP_HIST4_PARAM_VALUE3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST4_PARAM, field RSVD3[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST4_PARAM_RSVD3 (30U) /*!< Bit position for PXP_HW_PXP_HIST4_PARAM_RSVD3. */
#define BM_PXP_HW_PXP_HIST4_PARAM_RSVD3 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_HIST4_PARAM_RSVD3. */
#define BS_PXP_HW_PXP_HIST4_PARAM_RSVD3 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST4_PARAM_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_HIST4_PARAM_RSVD3 field. */
#define BR_PXP_HW_PXP_HIST4_PARAM_RSVD3(x) (HW_PXP_HW_PXP_HIST4_PARAM(x).B.RSVD3)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST8_PARAM0 - 8-level Histogram Parameter 0 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST8_PARAM0 - 8-level Histogram Parameter 0 Register. (RW)
 *
 * Reset value: 0x06040200U
 *
 * This register specifies four of the valid values for an 8-level histogram. If
 * all pixels in a bitmap match the 8-level histogram values, STATUS[2] will be
 * set at the end of frame processing. All comparator values should be programmed
 * such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hw_pxp_hist8_param0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist8_param0_bitfields
    {
        uint32_t VALUE0 : 6;           /*!< [5:0]  */
        uint32_t RSVD0 : 2;            /*!< [7:6]  */
        uint32_t VALUE1 : 6;           /*!< [13:8]  */
        uint32_t RSVD1 : 2;            /*!< [15:14]  */
        uint32_t VALUE2 : 6;           /*!< [21:16]  */
        uint32_t RSVD2 : 2;            /*!< [23:22]  */
        uint32_t VALUE3 : 6;           /*!< [29:24]  */
        uint32_t RSVD3 : 2;            /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_hist8_param0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST8_PARAM0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST8_PARAM0_ADDR(x) ((uintptr_t)(x) + 0x2B20U)

#define HW_PXP_HW_PXP_HIST8_PARAM0(x) (*(__IO hw_pxp_hw_pxp_hist8_param0_t *) HW_PXP_HW_PXP_HIST8_PARAM0_ADDR(x))
#define HW_PXP_HW_PXP_HIST8_PARAM0_RD(x) (HW_PXP_HW_PXP_HIST8_PARAM0(x).U)
#define HW_PXP_HW_PXP_HIST8_PARAM0_WR(x, v) (HW_PXP_HW_PXP_HIST8_PARAM0(x).U = (v))
#define HW_PXP_HW_PXP_HIST8_PARAM0_SET(x, v) (HW_PXP_HW_PXP_HIST8_PARAM0_WR(x, HW_PXP_HW_PXP_HIST8_PARAM0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST8_PARAM0_CLR(x, v) (HW_PXP_HW_PXP_HIST8_PARAM0_WR(x, HW_PXP_HW_PXP_HIST8_PARAM0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST8_PARAM0_TOG(x, v) (HW_PXP_HW_PXP_HIST8_PARAM0_WR(x, HW_PXP_HW_PXP_HIST8_PARAM0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST8_PARAM0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST8_PARAM0, field VALUE0[5:0] (RW)
 *
 * GRAY0 (Black) value for 8-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST8_PARAM0_VALUE0 (0U) /*!< Bit position for PXP_HW_PXP_HIST8_PARAM0_VALUE0. */
#define BM_PXP_HW_PXP_HIST8_PARAM0_VALUE0 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_HIST8_PARAM0_VALUE0. */
#define BS_PXP_HW_PXP_HIST8_PARAM0_VALUE0 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST8_PARAM0_VALUE0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST8_PARAM0_VALUE0 field. */
#define BR_PXP_HW_PXP_HIST8_PARAM0_VALUE0(x) (HW_PXP_HW_PXP_HIST8_PARAM0(x).B.VALUE0)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST8_PARAM0_VALUE0. */
#define BF_PXP_HW_PXP_HIST8_PARAM0_VALUE0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST8_PARAM0_VALUE0) & BM_PXP_HW_PXP_HIST8_PARAM0_VALUE0)

/*! @brief Set the VALUE0 field to a new value. */
#define BW_PXP_HW_PXP_HIST8_PARAM0_VALUE0(x, v) (HW_PXP_HW_PXP_HIST8_PARAM0_WR(x, (HW_PXP_HW_PXP_HIST8_PARAM0_RD(x) & ~BM_PXP_HW_PXP_HIST8_PARAM0_VALUE0) | BF_PXP_HW_PXP_HIST8_PARAM0_VALUE0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST8_PARAM0, field RSVD0[7:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST8_PARAM0_RSVD0 (6U) /*!< Bit position for PXP_HW_PXP_HIST8_PARAM0_RSVD0. */
#define BM_PXP_HW_PXP_HIST8_PARAM0_RSVD0 (0x000000C0U) /*!< Bit mask for PXP_HW_PXP_HIST8_PARAM0_RSVD0. */
#define BS_PXP_HW_PXP_HIST8_PARAM0_RSVD0 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST8_PARAM0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST8_PARAM0_RSVD0 field. */
#define BR_PXP_HW_PXP_HIST8_PARAM0_RSVD0(x) (HW_PXP_HW_PXP_HIST8_PARAM0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST8_PARAM0, field VALUE1[13:8] (RW)
 *
 * GRAY1 value for 8-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST8_PARAM0_VALUE1 (8U) /*!< Bit position for PXP_HW_PXP_HIST8_PARAM0_VALUE1. */
#define BM_PXP_HW_PXP_HIST8_PARAM0_VALUE1 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_HIST8_PARAM0_VALUE1. */
#define BS_PXP_HW_PXP_HIST8_PARAM0_VALUE1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST8_PARAM0_VALUE1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST8_PARAM0_VALUE1 field. */
#define BR_PXP_HW_PXP_HIST8_PARAM0_VALUE1(x) (HW_PXP_HW_PXP_HIST8_PARAM0(x).B.VALUE1)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST8_PARAM0_VALUE1. */
#define BF_PXP_HW_PXP_HIST8_PARAM0_VALUE1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST8_PARAM0_VALUE1) & BM_PXP_HW_PXP_HIST8_PARAM0_VALUE1)

/*! @brief Set the VALUE1 field to a new value. */
#define BW_PXP_HW_PXP_HIST8_PARAM0_VALUE1(x, v) (HW_PXP_HW_PXP_HIST8_PARAM0_WR(x, (HW_PXP_HW_PXP_HIST8_PARAM0_RD(x) & ~BM_PXP_HW_PXP_HIST8_PARAM0_VALUE1) | BF_PXP_HW_PXP_HIST8_PARAM0_VALUE1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST8_PARAM0, field RSVD1[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST8_PARAM0_RSVD1 (14U) /*!< Bit position for PXP_HW_PXP_HIST8_PARAM0_RSVD1. */
#define BM_PXP_HW_PXP_HIST8_PARAM0_RSVD1 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_HIST8_PARAM0_RSVD1. */
#define BS_PXP_HW_PXP_HIST8_PARAM0_RSVD1 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST8_PARAM0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST8_PARAM0_RSVD1 field. */
#define BR_PXP_HW_PXP_HIST8_PARAM0_RSVD1(x) (HW_PXP_HW_PXP_HIST8_PARAM0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST8_PARAM0, field VALUE2[21:16] (RW)
 *
 * GRAY2 value for 8-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST8_PARAM0_VALUE2 (16U) /*!< Bit position for PXP_HW_PXP_HIST8_PARAM0_VALUE2. */
#define BM_PXP_HW_PXP_HIST8_PARAM0_VALUE2 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_HIST8_PARAM0_VALUE2. */
#define BS_PXP_HW_PXP_HIST8_PARAM0_VALUE2 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST8_PARAM0_VALUE2. */

/*! @brief Read current value of the PXP_HW_PXP_HIST8_PARAM0_VALUE2 field. */
#define BR_PXP_HW_PXP_HIST8_PARAM0_VALUE2(x) (HW_PXP_HW_PXP_HIST8_PARAM0(x).B.VALUE2)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST8_PARAM0_VALUE2. */
#define BF_PXP_HW_PXP_HIST8_PARAM0_VALUE2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST8_PARAM0_VALUE2) & BM_PXP_HW_PXP_HIST8_PARAM0_VALUE2)

/*! @brief Set the VALUE2 field to a new value. */
#define BW_PXP_HW_PXP_HIST8_PARAM0_VALUE2(x, v) (HW_PXP_HW_PXP_HIST8_PARAM0_WR(x, (HW_PXP_HW_PXP_HIST8_PARAM0_RD(x) & ~BM_PXP_HW_PXP_HIST8_PARAM0_VALUE2) | BF_PXP_HW_PXP_HIST8_PARAM0_VALUE2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST8_PARAM0, field RSVD2[23:22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST8_PARAM0_RSVD2 (22U) /*!< Bit position for PXP_HW_PXP_HIST8_PARAM0_RSVD2. */
#define BM_PXP_HW_PXP_HIST8_PARAM0_RSVD2 (0x00C00000U) /*!< Bit mask for PXP_HW_PXP_HIST8_PARAM0_RSVD2. */
#define BS_PXP_HW_PXP_HIST8_PARAM0_RSVD2 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST8_PARAM0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_HIST8_PARAM0_RSVD2 field. */
#define BR_PXP_HW_PXP_HIST8_PARAM0_RSVD2(x) (HW_PXP_HW_PXP_HIST8_PARAM0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST8_PARAM0, field VALUE3[29:24] (RW)
 *
 * GRAY3 value for 8-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST8_PARAM0_VALUE3 (24U) /*!< Bit position for PXP_HW_PXP_HIST8_PARAM0_VALUE3. */
#define BM_PXP_HW_PXP_HIST8_PARAM0_VALUE3 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_HIST8_PARAM0_VALUE3. */
#define BS_PXP_HW_PXP_HIST8_PARAM0_VALUE3 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST8_PARAM0_VALUE3. */

/*! @brief Read current value of the PXP_HW_PXP_HIST8_PARAM0_VALUE3 field. */
#define BR_PXP_HW_PXP_HIST8_PARAM0_VALUE3(x) (HW_PXP_HW_PXP_HIST8_PARAM0(x).B.VALUE3)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST8_PARAM0_VALUE3. */
#define BF_PXP_HW_PXP_HIST8_PARAM0_VALUE3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST8_PARAM0_VALUE3) & BM_PXP_HW_PXP_HIST8_PARAM0_VALUE3)

/*! @brief Set the VALUE3 field to a new value. */
#define BW_PXP_HW_PXP_HIST8_PARAM0_VALUE3(x, v) (HW_PXP_HW_PXP_HIST8_PARAM0_WR(x, (HW_PXP_HW_PXP_HIST8_PARAM0_RD(x) & ~BM_PXP_HW_PXP_HIST8_PARAM0_VALUE3) | BF_PXP_HW_PXP_HIST8_PARAM0_VALUE3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST8_PARAM0, field RSVD3[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST8_PARAM0_RSVD3 (30U) /*!< Bit position for PXP_HW_PXP_HIST8_PARAM0_RSVD3. */
#define BM_PXP_HW_PXP_HIST8_PARAM0_RSVD3 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_HIST8_PARAM0_RSVD3. */
#define BS_PXP_HW_PXP_HIST8_PARAM0_RSVD3 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST8_PARAM0_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_HIST8_PARAM0_RSVD3 field. */
#define BR_PXP_HW_PXP_HIST8_PARAM0_RSVD3(x) (HW_PXP_HW_PXP_HIST8_PARAM0(x).B.RSVD3)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST8_PARAM1 - 8-level Histogram Parameter 1 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST8_PARAM1 - 8-level Histogram Parameter 1 Register. (RW)
 *
 * Reset value: 0x0F0D0B09U
 *
 * This register specifies four of the valid values for an 8-level histogram. If
 * all pixels in a bitmap match the 8-level histogram values, STATUS[2] will be
 * set at the end of frame processing. All comparator values should be programmed
 * such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hw_pxp_hist8_param1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist8_param1_bitfields
    {
        uint32_t VALUE4 : 6;           /*!< [5:0]  */
        uint32_t RSVD4 : 2;            /*!< [7:6]  */
        uint32_t VALUE5 : 6;           /*!< [13:8]  */
        uint32_t RSVD5 : 2;            /*!< [15:14]  */
        uint32_t VALUE6 : 6;           /*!< [21:16]  */
        uint32_t RSVD6 : 2;            /*!< [23:22]  */
        uint32_t VALUE7 : 6;           /*!< [29:24]  */
        uint32_t RSVD7 : 2;            /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_hist8_param1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST8_PARAM1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST8_PARAM1_ADDR(x) ((uintptr_t)(x) + 0x2B30U)

#define HW_PXP_HW_PXP_HIST8_PARAM1(x) (*(__IO hw_pxp_hw_pxp_hist8_param1_t *) HW_PXP_HW_PXP_HIST8_PARAM1_ADDR(x))
#define HW_PXP_HW_PXP_HIST8_PARAM1_RD(x) (HW_PXP_HW_PXP_HIST8_PARAM1(x).U)
#define HW_PXP_HW_PXP_HIST8_PARAM1_WR(x, v) (HW_PXP_HW_PXP_HIST8_PARAM1(x).U = (v))
#define HW_PXP_HW_PXP_HIST8_PARAM1_SET(x, v) (HW_PXP_HW_PXP_HIST8_PARAM1_WR(x, HW_PXP_HW_PXP_HIST8_PARAM1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST8_PARAM1_CLR(x, v) (HW_PXP_HW_PXP_HIST8_PARAM1_WR(x, HW_PXP_HW_PXP_HIST8_PARAM1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST8_PARAM1_TOG(x, v) (HW_PXP_HW_PXP_HIST8_PARAM1_WR(x, HW_PXP_HW_PXP_HIST8_PARAM1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST8_PARAM1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST8_PARAM1, field VALUE4[5:0] (RW)
 *
 * GRAY4 value for 8-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST8_PARAM1_VALUE4 (0U) /*!< Bit position for PXP_HW_PXP_HIST8_PARAM1_VALUE4. */
#define BM_PXP_HW_PXP_HIST8_PARAM1_VALUE4 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_HIST8_PARAM1_VALUE4. */
#define BS_PXP_HW_PXP_HIST8_PARAM1_VALUE4 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST8_PARAM1_VALUE4. */

/*! @brief Read current value of the PXP_HW_PXP_HIST8_PARAM1_VALUE4 field. */
#define BR_PXP_HW_PXP_HIST8_PARAM1_VALUE4(x) (HW_PXP_HW_PXP_HIST8_PARAM1(x).B.VALUE4)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST8_PARAM1_VALUE4. */
#define BF_PXP_HW_PXP_HIST8_PARAM1_VALUE4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST8_PARAM1_VALUE4) & BM_PXP_HW_PXP_HIST8_PARAM1_VALUE4)

/*! @brief Set the VALUE4 field to a new value. */
#define BW_PXP_HW_PXP_HIST8_PARAM1_VALUE4(x, v) (HW_PXP_HW_PXP_HIST8_PARAM1_WR(x, (HW_PXP_HW_PXP_HIST8_PARAM1_RD(x) & ~BM_PXP_HW_PXP_HIST8_PARAM1_VALUE4) | BF_PXP_HW_PXP_HIST8_PARAM1_VALUE4(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST8_PARAM1, field RSVD4[7:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST8_PARAM1_RSVD4 (6U) /*!< Bit position for PXP_HW_PXP_HIST8_PARAM1_RSVD4. */
#define BM_PXP_HW_PXP_HIST8_PARAM1_RSVD4 (0x000000C0U) /*!< Bit mask for PXP_HW_PXP_HIST8_PARAM1_RSVD4. */
#define BS_PXP_HW_PXP_HIST8_PARAM1_RSVD4 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST8_PARAM1_RSVD4. */

/*! @brief Read current value of the PXP_HW_PXP_HIST8_PARAM1_RSVD4 field. */
#define BR_PXP_HW_PXP_HIST8_PARAM1_RSVD4(x) (HW_PXP_HW_PXP_HIST8_PARAM1(x).B.RSVD4)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST8_PARAM1, field VALUE5[13:8] (RW)
 *
 * GRAY5 value for 8-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST8_PARAM1_VALUE5 (8U) /*!< Bit position for PXP_HW_PXP_HIST8_PARAM1_VALUE5. */
#define BM_PXP_HW_PXP_HIST8_PARAM1_VALUE5 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_HIST8_PARAM1_VALUE5. */
#define BS_PXP_HW_PXP_HIST8_PARAM1_VALUE5 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST8_PARAM1_VALUE5. */

/*! @brief Read current value of the PXP_HW_PXP_HIST8_PARAM1_VALUE5 field. */
#define BR_PXP_HW_PXP_HIST8_PARAM1_VALUE5(x) (HW_PXP_HW_PXP_HIST8_PARAM1(x).B.VALUE5)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST8_PARAM1_VALUE5. */
#define BF_PXP_HW_PXP_HIST8_PARAM1_VALUE5(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST8_PARAM1_VALUE5) & BM_PXP_HW_PXP_HIST8_PARAM1_VALUE5)

/*! @brief Set the VALUE5 field to a new value. */
#define BW_PXP_HW_PXP_HIST8_PARAM1_VALUE5(x, v) (HW_PXP_HW_PXP_HIST8_PARAM1_WR(x, (HW_PXP_HW_PXP_HIST8_PARAM1_RD(x) & ~BM_PXP_HW_PXP_HIST8_PARAM1_VALUE5) | BF_PXP_HW_PXP_HIST8_PARAM1_VALUE5(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST8_PARAM1, field RSVD5[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST8_PARAM1_RSVD5 (14U) /*!< Bit position for PXP_HW_PXP_HIST8_PARAM1_RSVD5. */
#define BM_PXP_HW_PXP_HIST8_PARAM1_RSVD5 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_HIST8_PARAM1_RSVD5. */
#define BS_PXP_HW_PXP_HIST8_PARAM1_RSVD5 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST8_PARAM1_RSVD5. */

/*! @brief Read current value of the PXP_HW_PXP_HIST8_PARAM1_RSVD5 field. */
#define BR_PXP_HW_PXP_HIST8_PARAM1_RSVD5(x) (HW_PXP_HW_PXP_HIST8_PARAM1(x).B.RSVD5)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST8_PARAM1, field VALUE6[21:16] (RW)
 *
 * GRAY6 value for 8-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST8_PARAM1_VALUE6 (16U) /*!< Bit position for PXP_HW_PXP_HIST8_PARAM1_VALUE6. */
#define BM_PXP_HW_PXP_HIST8_PARAM1_VALUE6 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_HIST8_PARAM1_VALUE6. */
#define BS_PXP_HW_PXP_HIST8_PARAM1_VALUE6 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST8_PARAM1_VALUE6. */

/*! @brief Read current value of the PXP_HW_PXP_HIST8_PARAM1_VALUE6 field. */
#define BR_PXP_HW_PXP_HIST8_PARAM1_VALUE6(x) (HW_PXP_HW_PXP_HIST8_PARAM1(x).B.VALUE6)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST8_PARAM1_VALUE6. */
#define BF_PXP_HW_PXP_HIST8_PARAM1_VALUE6(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST8_PARAM1_VALUE6) & BM_PXP_HW_PXP_HIST8_PARAM1_VALUE6)

/*! @brief Set the VALUE6 field to a new value. */
#define BW_PXP_HW_PXP_HIST8_PARAM1_VALUE6(x, v) (HW_PXP_HW_PXP_HIST8_PARAM1_WR(x, (HW_PXP_HW_PXP_HIST8_PARAM1_RD(x) & ~BM_PXP_HW_PXP_HIST8_PARAM1_VALUE6) | BF_PXP_HW_PXP_HIST8_PARAM1_VALUE6(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST8_PARAM1, field RSVD6[23:22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST8_PARAM1_RSVD6 (22U) /*!< Bit position for PXP_HW_PXP_HIST8_PARAM1_RSVD6. */
#define BM_PXP_HW_PXP_HIST8_PARAM1_RSVD6 (0x00C00000U) /*!< Bit mask for PXP_HW_PXP_HIST8_PARAM1_RSVD6. */
#define BS_PXP_HW_PXP_HIST8_PARAM1_RSVD6 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST8_PARAM1_RSVD6. */

/*! @brief Read current value of the PXP_HW_PXP_HIST8_PARAM1_RSVD6 field. */
#define BR_PXP_HW_PXP_HIST8_PARAM1_RSVD6(x) (HW_PXP_HW_PXP_HIST8_PARAM1(x).B.RSVD6)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST8_PARAM1, field VALUE7[29:24] (RW)
 *
 * GRAY7 (White) value for 8-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST8_PARAM1_VALUE7 (24U) /*!< Bit position for PXP_HW_PXP_HIST8_PARAM1_VALUE7. */
#define BM_PXP_HW_PXP_HIST8_PARAM1_VALUE7 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_HIST8_PARAM1_VALUE7. */
#define BS_PXP_HW_PXP_HIST8_PARAM1_VALUE7 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST8_PARAM1_VALUE7. */

/*! @brief Read current value of the PXP_HW_PXP_HIST8_PARAM1_VALUE7 field. */
#define BR_PXP_HW_PXP_HIST8_PARAM1_VALUE7(x) (HW_PXP_HW_PXP_HIST8_PARAM1(x).B.VALUE7)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST8_PARAM1_VALUE7. */
#define BF_PXP_HW_PXP_HIST8_PARAM1_VALUE7(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST8_PARAM1_VALUE7) & BM_PXP_HW_PXP_HIST8_PARAM1_VALUE7)

/*! @brief Set the VALUE7 field to a new value. */
#define BW_PXP_HW_PXP_HIST8_PARAM1_VALUE7(x, v) (HW_PXP_HW_PXP_HIST8_PARAM1_WR(x, (HW_PXP_HW_PXP_HIST8_PARAM1_RD(x) & ~BM_PXP_HW_PXP_HIST8_PARAM1_VALUE7) | BF_PXP_HW_PXP_HIST8_PARAM1_VALUE7(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST8_PARAM1, field RSVD7[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST8_PARAM1_RSVD7 (30U) /*!< Bit position for PXP_HW_PXP_HIST8_PARAM1_RSVD7. */
#define BM_PXP_HW_PXP_HIST8_PARAM1_RSVD7 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_HIST8_PARAM1_RSVD7. */
#define BS_PXP_HW_PXP_HIST8_PARAM1_RSVD7 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST8_PARAM1_RSVD7. */

/*! @brief Read current value of the PXP_HW_PXP_HIST8_PARAM1_RSVD7 field. */
#define BR_PXP_HW_PXP_HIST8_PARAM1_RSVD7(x) (HW_PXP_HW_PXP_HIST8_PARAM1(x).B.RSVD7)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST16_PARAM0 - 16-level Histogram Parameter 0 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST16_PARAM0 - 16-level Histogram Parameter 0 Register. (RW)
 *
 * Reset value: 0x03020100U
 *
 * This register specifies four of the valid values for a 16-level histogram. If
 * all pixels in a bitmap match the 16-level histogram values, STATUS[3] will be
 * set at the end of frame processing. All comparator values should be
 * programmed such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hw_pxp_hist16_param0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist16_param0_bitfields
    {
        uint32_t VALUE0 : 6;           /*!< [5:0]  */
        uint32_t RSVD0 : 2;            /*!< [7:6]  */
        uint32_t VALUE1 : 6;           /*!< [13:8]  */
        uint32_t RSVD1 : 2;            /*!< [15:14]  */
        uint32_t VALUE2 : 6;           /*!< [21:16]  */
        uint32_t RSVD2 : 2;            /*!< [23:22]  */
        uint32_t VALUE3 : 6;           /*!< [29:24]  */
        uint32_t RSVD3 : 2;            /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_hist16_param0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST16_PARAM0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST16_PARAM0_ADDR(x) ((uintptr_t)(x) + 0x2B40U)

#define HW_PXP_HW_PXP_HIST16_PARAM0(x) (*(__IO hw_pxp_hw_pxp_hist16_param0_t *) HW_PXP_HW_PXP_HIST16_PARAM0_ADDR(x))
#define HW_PXP_HW_PXP_HIST16_PARAM0_RD(x) (HW_PXP_HW_PXP_HIST16_PARAM0(x).U)
#define HW_PXP_HW_PXP_HIST16_PARAM0_WR(x, v) (HW_PXP_HW_PXP_HIST16_PARAM0(x).U = (v))
#define HW_PXP_HW_PXP_HIST16_PARAM0_SET(x, v) (HW_PXP_HW_PXP_HIST16_PARAM0_WR(x, HW_PXP_HW_PXP_HIST16_PARAM0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST16_PARAM0_CLR(x, v) (HW_PXP_HW_PXP_HIST16_PARAM0_WR(x, HW_PXP_HW_PXP_HIST16_PARAM0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST16_PARAM0_TOG(x, v) (HW_PXP_HW_PXP_HIST16_PARAM0_WR(x, HW_PXP_HW_PXP_HIST16_PARAM0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST16_PARAM0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM0, field VALUE0[5:0] (RW)
 *
 * GRAY0 (Black) value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM0_VALUE0 (0U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM0_VALUE0. */
#define BM_PXP_HW_PXP_HIST16_PARAM0_VALUE0 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM0_VALUE0. */
#define BS_PXP_HW_PXP_HIST16_PARAM0_VALUE0 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM0_VALUE0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM0_VALUE0 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM0_VALUE0(x) (HW_PXP_HW_PXP_HIST16_PARAM0(x).B.VALUE0)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST16_PARAM0_VALUE0. */
#define BF_PXP_HW_PXP_HIST16_PARAM0_VALUE0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST16_PARAM0_VALUE0) & BM_PXP_HW_PXP_HIST16_PARAM0_VALUE0)

/*! @brief Set the VALUE0 field to a new value. */
#define BW_PXP_HW_PXP_HIST16_PARAM0_VALUE0(x, v) (HW_PXP_HW_PXP_HIST16_PARAM0_WR(x, (HW_PXP_HW_PXP_HIST16_PARAM0_RD(x) & ~BM_PXP_HW_PXP_HIST16_PARAM0_VALUE0) | BF_PXP_HW_PXP_HIST16_PARAM0_VALUE0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM0, field RSVD0[7:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM0_RSVD0 (6U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM0_RSVD0. */
#define BM_PXP_HW_PXP_HIST16_PARAM0_RSVD0 (0x000000C0U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM0_RSVD0. */
#define BS_PXP_HW_PXP_HIST16_PARAM0_RSVD0 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM0_RSVD0 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM0_RSVD0(x) (HW_PXP_HW_PXP_HIST16_PARAM0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM0, field VALUE1[13:8] (RW)
 *
 * GRAY1 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM0_VALUE1 (8U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM0_VALUE1. */
#define BM_PXP_HW_PXP_HIST16_PARAM0_VALUE1 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM0_VALUE1. */
#define BS_PXP_HW_PXP_HIST16_PARAM0_VALUE1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM0_VALUE1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM0_VALUE1 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM0_VALUE1(x) (HW_PXP_HW_PXP_HIST16_PARAM0(x).B.VALUE1)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST16_PARAM0_VALUE1. */
#define BF_PXP_HW_PXP_HIST16_PARAM0_VALUE1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST16_PARAM0_VALUE1) & BM_PXP_HW_PXP_HIST16_PARAM0_VALUE1)

/*! @brief Set the VALUE1 field to a new value. */
#define BW_PXP_HW_PXP_HIST16_PARAM0_VALUE1(x, v) (HW_PXP_HW_PXP_HIST16_PARAM0_WR(x, (HW_PXP_HW_PXP_HIST16_PARAM0_RD(x) & ~BM_PXP_HW_PXP_HIST16_PARAM0_VALUE1) | BF_PXP_HW_PXP_HIST16_PARAM0_VALUE1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM0, field RSVD1[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM0_RSVD1 (14U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM0_RSVD1. */
#define BM_PXP_HW_PXP_HIST16_PARAM0_RSVD1 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM0_RSVD1. */
#define BS_PXP_HW_PXP_HIST16_PARAM0_RSVD1 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM0_RSVD1 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM0_RSVD1(x) (HW_PXP_HW_PXP_HIST16_PARAM0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM0, field VALUE2[21:16] (RW)
 *
 * GRAY2 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM0_VALUE2 (16U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM0_VALUE2. */
#define BM_PXP_HW_PXP_HIST16_PARAM0_VALUE2 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM0_VALUE2. */
#define BS_PXP_HW_PXP_HIST16_PARAM0_VALUE2 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM0_VALUE2. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM0_VALUE2 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM0_VALUE2(x) (HW_PXP_HW_PXP_HIST16_PARAM0(x).B.VALUE2)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST16_PARAM0_VALUE2. */
#define BF_PXP_HW_PXP_HIST16_PARAM0_VALUE2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST16_PARAM0_VALUE2) & BM_PXP_HW_PXP_HIST16_PARAM0_VALUE2)

/*! @brief Set the VALUE2 field to a new value. */
#define BW_PXP_HW_PXP_HIST16_PARAM0_VALUE2(x, v) (HW_PXP_HW_PXP_HIST16_PARAM0_WR(x, (HW_PXP_HW_PXP_HIST16_PARAM0_RD(x) & ~BM_PXP_HW_PXP_HIST16_PARAM0_VALUE2) | BF_PXP_HW_PXP_HIST16_PARAM0_VALUE2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM0, field RSVD2[23:22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM0_RSVD2 (22U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM0_RSVD2. */
#define BM_PXP_HW_PXP_HIST16_PARAM0_RSVD2 (0x00C00000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM0_RSVD2. */
#define BS_PXP_HW_PXP_HIST16_PARAM0_RSVD2 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM0_RSVD2 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM0_RSVD2(x) (HW_PXP_HW_PXP_HIST16_PARAM0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM0, field VALUE3[29:24] (RW)
 *
 * GRAY3 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM0_VALUE3 (24U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM0_VALUE3. */
#define BM_PXP_HW_PXP_HIST16_PARAM0_VALUE3 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM0_VALUE3. */
#define BS_PXP_HW_PXP_HIST16_PARAM0_VALUE3 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM0_VALUE3. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM0_VALUE3 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM0_VALUE3(x) (HW_PXP_HW_PXP_HIST16_PARAM0(x).B.VALUE3)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST16_PARAM0_VALUE3. */
#define BF_PXP_HW_PXP_HIST16_PARAM0_VALUE3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST16_PARAM0_VALUE3) & BM_PXP_HW_PXP_HIST16_PARAM0_VALUE3)

/*! @brief Set the VALUE3 field to a new value. */
#define BW_PXP_HW_PXP_HIST16_PARAM0_VALUE3(x, v) (HW_PXP_HW_PXP_HIST16_PARAM0_WR(x, (HW_PXP_HW_PXP_HIST16_PARAM0_RD(x) & ~BM_PXP_HW_PXP_HIST16_PARAM0_VALUE3) | BF_PXP_HW_PXP_HIST16_PARAM0_VALUE3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM0, field RSVD3[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM0_RSVD3 (30U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM0_RSVD3. */
#define BM_PXP_HW_PXP_HIST16_PARAM0_RSVD3 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM0_RSVD3. */
#define BS_PXP_HW_PXP_HIST16_PARAM0_RSVD3 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM0_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM0_RSVD3 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM0_RSVD3(x) (HW_PXP_HW_PXP_HIST16_PARAM0(x).B.RSVD3)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST16_PARAM1 - 16-level Histogram Parameter 1 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST16_PARAM1 - 16-level Histogram Parameter 1 Register. (RW)
 *
 * Reset value: 0x07060504U
 *
 * This register specifies four of the valid values for a 16-level histogram. If
 * all pixels in a bitmap match the 16-level histogram values, STATUS[3] will be
 * set at the end of frame processing. All comparator values should be
 * programmed such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hw_pxp_hist16_param1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist16_param1_bitfields
    {
        uint32_t VALUE4 : 6;           /*!< [5:0]  */
        uint32_t RSVD4 : 2;            /*!< [7:6]  */
        uint32_t VALUE5 : 6;           /*!< [13:8]  */
        uint32_t RSVD5 : 2;            /*!< [15:14]  */
        uint32_t VALUE6 : 6;           /*!< [21:16]  */
        uint32_t RSVD6 : 2;            /*!< [23:22]  */
        uint32_t VALUE7 : 6;           /*!< [29:24]  */
        uint32_t RSVD7 : 2;            /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_hist16_param1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST16_PARAM1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST16_PARAM1_ADDR(x) ((uintptr_t)(x) + 0x2B50U)

#define HW_PXP_HW_PXP_HIST16_PARAM1(x) (*(__IO hw_pxp_hw_pxp_hist16_param1_t *) HW_PXP_HW_PXP_HIST16_PARAM1_ADDR(x))
#define HW_PXP_HW_PXP_HIST16_PARAM1_RD(x) (HW_PXP_HW_PXP_HIST16_PARAM1(x).U)
#define HW_PXP_HW_PXP_HIST16_PARAM1_WR(x, v) (HW_PXP_HW_PXP_HIST16_PARAM1(x).U = (v))
#define HW_PXP_HW_PXP_HIST16_PARAM1_SET(x, v) (HW_PXP_HW_PXP_HIST16_PARAM1_WR(x, HW_PXP_HW_PXP_HIST16_PARAM1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST16_PARAM1_CLR(x, v) (HW_PXP_HW_PXP_HIST16_PARAM1_WR(x, HW_PXP_HW_PXP_HIST16_PARAM1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST16_PARAM1_TOG(x, v) (HW_PXP_HW_PXP_HIST16_PARAM1_WR(x, HW_PXP_HW_PXP_HIST16_PARAM1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST16_PARAM1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM1, field VALUE4[5:0] (RW)
 *
 * GRAY4 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM1_VALUE4 (0U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM1_VALUE4. */
#define BM_PXP_HW_PXP_HIST16_PARAM1_VALUE4 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM1_VALUE4. */
#define BS_PXP_HW_PXP_HIST16_PARAM1_VALUE4 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM1_VALUE4. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM1_VALUE4 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM1_VALUE4(x) (HW_PXP_HW_PXP_HIST16_PARAM1(x).B.VALUE4)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST16_PARAM1_VALUE4. */
#define BF_PXP_HW_PXP_HIST16_PARAM1_VALUE4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST16_PARAM1_VALUE4) & BM_PXP_HW_PXP_HIST16_PARAM1_VALUE4)

/*! @brief Set the VALUE4 field to a new value. */
#define BW_PXP_HW_PXP_HIST16_PARAM1_VALUE4(x, v) (HW_PXP_HW_PXP_HIST16_PARAM1_WR(x, (HW_PXP_HW_PXP_HIST16_PARAM1_RD(x) & ~BM_PXP_HW_PXP_HIST16_PARAM1_VALUE4) | BF_PXP_HW_PXP_HIST16_PARAM1_VALUE4(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM1, field RSVD4[7:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM1_RSVD4 (6U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM1_RSVD4. */
#define BM_PXP_HW_PXP_HIST16_PARAM1_RSVD4 (0x000000C0U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM1_RSVD4. */
#define BS_PXP_HW_PXP_HIST16_PARAM1_RSVD4 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM1_RSVD4. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM1_RSVD4 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM1_RSVD4(x) (HW_PXP_HW_PXP_HIST16_PARAM1(x).B.RSVD4)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM1, field VALUE5[13:8] (RW)
 *
 * GRAY5 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM1_VALUE5 (8U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM1_VALUE5. */
#define BM_PXP_HW_PXP_HIST16_PARAM1_VALUE5 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM1_VALUE5. */
#define BS_PXP_HW_PXP_HIST16_PARAM1_VALUE5 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM1_VALUE5. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM1_VALUE5 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM1_VALUE5(x) (HW_PXP_HW_PXP_HIST16_PARAM1(x).B.VALUE5)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST16_PARAM1_VALUE5. */
#define BF_PXP_HW_PXP_HIST16_PARAM1_VALUE5(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST16_PARAM1_VALUE5) & BM_PXP_HW_PXP_HIST16_PARAM1_VALUE5)

/*! @brief Set the VALUE5 field to a new value. */
#define BW_PXP_HW_PXP_HIST16_PARAM1_VALUE5(x, v) (HW_PXP_HW_PXP_HIST16_PARAM1_WR(x, (HW_PXP_HW_PXP_HIST16_PARAM1_RD(x) & ~BM_PXP_HW_PXP_HIST16_PARAM1_VALUE5) | BF_PXP_HW_PXP_HIST16_PARAM1_VALUE5(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM1, field RSVD5[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM1_RSVD5 (14U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM1_RSVD5. */
#define BM_PXP_HW_PXP_HIST16_PARAM1_RSVD5 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM1_RSVD5. */
#define BS_PXP_HW_PXP_HIST16_PARAM1_RSVD5 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM1_RSVD5. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM1_RSVD5 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM1_RSVD5(x) (HW_PXP_HW_PXP_HIST16_PARAM1(x).B.RSVD5)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM1, field VALUE6[21:16] (RW)
 *
 * GRAY6 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM1_VALUE6 (16U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM1_VALUE6. */
#define BM_PXP_HW_PXP_HIST16_PARAM1_VALUE6 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM1_VALUE6. */
#define BS_PXP_HW_PXP_HIST16_PARAM1_VALUE6 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM1_VALUE6. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM1_VALUE6 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM1_VALUE6(x) (HW_PXP_HW_PXP_HIST16_PARAM1(x).B.VALUE6)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST16_PARAM1_VALUE6. */
#define BF_PXP_HW_PXP_HIST16_PARAM1_VALUE6(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST16_PARAM1_VALUE6) & BM_PXP_HW_PXP_HIST16_PARAM1_VALUE6)

/*! @brief Set the VALUE6 field to a new value. */
#define BW_PXP_HW_PXP_HIST16_PARAM1_VALUE6(x, v) (HW_PXP_HW_PXP_HIST16_PARAM1_WR(x, (HW_PXP_HW_PXP_HIST16_PARAM1_RD(x) & ~BM_PXP_HW_PXP_HIST16_PARAM1_VALUE6) | BF_PXP_HW_PXP_HIST16_PARAM1_VALUE6(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM1, field RSVD6[23:22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM1_RSVD6 (22U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM1_RSVD6. */
#define BM_PXP_HW_PXP_HIST16_PARAM1_RSVD6 (0x00C00000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM1_RSVD6. */
#define BS_PXP_HW_PXP_HIST16_PARAM1_RSVD6 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM1_RSVD6. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM1_RSVD6 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM1_RSVD6(x) (HW_PXP_HW_PXP_HIST16_PARAM1(x).B.RSVD6)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM1, field VALUE7[29:24] (RW)
 *
 * GRAY7 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM1_VALUE7 (24U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM1_VALUE7. */
#define BM_PXP_HW_PXP_HIST16_PARAM1_VALUE7 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM1_VALUE7. */
#define BS_PXP_HW_PXP_HIST16_PARAM1_VALUE7 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM1_VALUE7. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM1_VALUE7 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM1_VALUE7(x) (HW_PXP_HW_PXP_HIST16_PARAM1(x).B.VALUE7)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST16_PARAM1_VALUE7. */
#define BF_PXP_HW_PXP_HIST16_PARAM1_VALUE7(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST16_PARAM1_VALUE7) & BM_PXP_HW_PXP_HIST16_PARAM1_VALUE7)

/*! @brief Set the VALUE7 field to a new value. */
#define BW_PXP_HW_PXP_HIST16_PARAM1_VALUE7(x, v) (HW_PXP_HW_PXP_HIST16_PARAM1_WR(x, (HW_PXP_HW_PXP_HIST16_PARAM1_RD(x) & ~BM_PXP_HW_PXP_HIST16_PARAM1_VALUE7) | BF_PXP_HW_PXP_HIST16_PARAM1_VALUE7(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM1, field RSVD7[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM1_RSVD7 (30U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM1_RSVD7. */
#define BM_PXP_HW_PXP_HIST16_PARAM1_RSVD7 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM1_RSVD7. */
#define BS_PXP_HW_PXP_HIST16_PARAM1_RSVD7 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM1_RSVD7. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM1_RSVD7 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM1_RSVD7(x) (HW_PXP_HW_PXP_HIST16_PARAM1(x).B.RSVD7)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST16_PARAM2 - 16-level Histogram Parameter 2 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST16_PARAM2 - 16-level Histogram Parameter 2 Register. (RW)
 *
 * Reset value: 0x0B0A0908U
 *
 * This register specifies four of the valid values for a 16-level histogram. If
 * all pixels in a bitmap match the 16-level histogram values, STATUS[3] will be
 * set at the end of frame processing. All comparator values should be
 * programmed such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hw_pxp_hist16_param2
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist16_param2_bitfields
    {
        uint32_t VALUE8 : 6;           /*!< [5:0]  */
        uint32_t RSVD8 : 2;            /*!< [7:6]  */
        uint32_t VALUE9 : 6;           /*!< [13:8]  */
        uint32_t RSVD9 : 2;            /*!< [15:14]  */
        uint32_t VALUE10 : 6;          /*!< [21:16]  */
        uint32_t RSVD10 : 2;           /*!< [23:22]  */
        uint32_t VALUE11 : 6;          /*!< [29:24]  */
        uint32_t RSVD11 : 2;           /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_hist16_param2_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST16_PARAM2 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST16_PARAM2_ADDR(x) ((uintptr_t)(x) + 0x2B60U)

#define HW_PXP_HW_PXP_HIST16_PARAM2(x) (*(__IO hw_pxp_hw_pxp_hist16_param2_t *) HW_PXP_HW_PXP_HIST16_PARAM2_ADDR(x))
#define HW_PXP_HW_PXP_HIST16_PARAM2_RD(x) (HW_PXP_HW_PXP_HIST16_PARAM2(x).U)
#define HW_PXP_HW_PXP_HIST16_PARAM2_WR(x, v) (HW_PXP_HW_PXP_HIST16_PARAM2(x).U = (v))
#define HW_PXP_HW_PXP_HIST16_PARAM2_SET(x, v) (HW_PXP_HW_PXP_HIST16_PARAM2_WR(x, HW_PXP_HW_PXP_HIST16_PARAM2_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST16_PARAM2_CLR(x, v) (HW_PXP_HW_PXP_HIST16_PARAM2_WR(x, HW_PXP_HW_PXP_HIST16_PARAM2_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST16_PARAM2_TOG(x, v) (HW_PXP_HW_PXP_HIST16_PARAM2_WR(x, HW_PXP_HW_PXP_HIST16_PARAM2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST16_PARAM2 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM2, field VALUE8[5:0] (RW)
 *
 * GRAY8 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM2_VALUE8 (0U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM2_VALUE8. */
#define BM_PXP_HW_PXP_HIST16_PARAM2_VALUE8 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM2_VALUE8. */
#define BS_PXP_HW_PXP_HIST16_PARAM2_VALUE8 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM2_VALUE8. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM2_VALUE8 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM2_VALUE8(x) (HW_PXP_HW_PXP_HIST16_PARAM2(x).B.VALUE8)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST16_PARAM2_VALUE8. */
#define BF_PXP_HW_PXP_HIST16_PARAM2_VALUE8(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST16_PARAM2_VALUE8) & BM_PXP_HW_PXP_HIST16_PARAM2_VALUE8)

/*! @brief Set the VALUE8 field to a new value. */
#define BW_PXP_HW_PXP_HIST16_PARAM2_VALUE8(x, v) (HW_PXP_HW_PXP_HIST16_PARAM2_WR(x, (HW_PXP_HW_PXP_HIST16_PARAM2_RD(x) & ~BM_PXP_HW_PXP_HIST16_PARAM2_VALUE8) | BF_PXP_HW_PXP_HIST16_PARAM2_VALUE8(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM2, field RSVD8[7:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM2_RSVD8 (6U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM2_RSVD8. */
#define BM_PXP_HW_PXP_HIST16_PARAM2_RSVD8 (0x000000C0U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM2_RSVD8. */
#define BS_PXP_HW_PXP_HIST16_PARAM2_RSVD8 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM2_RSVD8. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM2_RSVD8 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM2_RSVD8(x) (HW_PXP_HW_PXP_HIST16_PARAM2(x).B.RSVD8)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM2, field VALUE9[13:8] (RW)
 *
 * GRAY9 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM2_VALUE9 (8U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM2_VALUE9. */
#define BM_PXP_HW_PXP_HIST16_PARAM2_VALUE9 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM2_VALUE9. */
#define BS_PXP_HW_PXP_HIST16_PARAM2_VALUE9 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM2_VALUE9. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM2_VALUE9 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM2_VALUE9(x) (HW_PXP_HW_PXP_HIST16_PARAM2(x).B.VALUE9)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST16_PARAM2_VALUE9. */
#define BF_PXP_HW_PXP_HIST16_PARAM2_VALUE9(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST16_PARAM2_VALUE9) & BM_PXP_HW_PXP_HIST16_PARAM2_VALUE9)

/*! @brief Set the VALUE9 field to a new value. */
#define BW_PXP_HW_PXP_HIST16_PARAM2_VALUE9(x, v) (HW_PXP_HW_PXP_HIST16_PARAM2_WR(x, (HW_PXP_HW_PXP_HIST16_PARAM2_RD(x) & ~BM_PXP_HW_PXP_HIST16_PARAM2_VALUE9) | BF_PXP_HW_PXP_HIST16_PARAM2_VALUE9(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM2, field RSVD9[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM2_RSVD9 (14U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM2_RSVD9. */
#define BM_PXP_HW_PXP_HIST16_PARAM2_RSVD9 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM2_RSVD9. */
#define BS_PXP_HW_PXP_HIST16_PARAM2_RSVD9 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM2_RSVD9. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM2_RSVD9 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM2_RSVD9(x) (HW_PXP_HW_PXP_HIST16_PARAM2(x).B.RSVD9)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM2, field VALUE10[21:16] (RW)
 *
 * GRAY10 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM2_VALUE10 (16U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM2_VALUE10. */
#define BM_PXP_HW_PXP_HIST16_PARAM2_VALUE10 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM2_VALUE10. */
#define BS_PXP_HW_PXP_HIST16_PARAM2_VALUE10 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM2_VALUE10. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM2_VALUE10 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM2_VALUE10(x) (HW_PXP_HW_PXP_HIST16_PARAM2(x).B.VALUE10)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST16_PARAM2_VALUE10. */
#define BF_PXP_HW_PXP_HIST16_PARAM2_VALUE10(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST16_PARAM2_VALUE10) & BM_PXP_HW_PXP_HIST16_PARAM2_VALUE10)

/*! @brief Set the VALUE10 field to a new value. */
#define BW_PXP_HW_PXP_HIST16_PARAM2_VALUE10(x, v) (HW_PXP_HW_PXP_HIST16_PARAM2_WR(x, (HW_PXP_HW_PXP_HIST16_PARAM2_RD(x) & ~BM_PXP_HW_PXP_HIST16_PARAM2_VALUE10) | BF_PXP_HW_PXP_HIST16_PARAM2_VALUE10(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM2, field RSVD10[23:22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM2_RSVD10 (22U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM2_RSVD10. */
#define BM_PXP_HW_PXP_HIST16_PARAM2_RSVD10 (0x00C00000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM2_RSVD10. */
#define BS_PXP_HW_PXP_HIST16_PARAM2_RSVD10 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM2_RSVD10. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM2_RSVD10 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM2_RSVD10(x) (HW_PXP_HW_PXP_HIST16_PARAM2(x).B.RSVD10)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM2, field VALUE11[29:24] (RW)
 *
 * GRAY11 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM2_VALUE11 (24U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM2_VALUE11. */
#define BM_PXP_HW_PXP_HIST16_PARAM2_VALUE11 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM2_VALUE11. */
#define BS_PXP_HW_PXP_HIST16_PARAM2_VALUE11 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM2_VALUE11. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM2_VALUE11 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM2_VALUE11(x) (HW_PXP_HW_PXP_HIST16_PARAM2(x).B.VALUE11)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST16_PARAM2_VALUE11. */
#define BF_PXP_HW_PXP_HIST16_PARAM2_VALUE11(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST16_PARAM2_VALUE11) & BM_PXP_HW_PXP_HIST16_PARAM2_VALUE11)

/*! @brief Set the VALUE11 field to a new value. */
#define BW_PXP_HW_PXP_HIST16_PARAM2_VALUE11(x, v) (HW_PXP_HW_PXP_HIST16_PARAM2_WR(x, (HW_PXP_HW_PXP_HIST16_PARAM2_RD(x) & ~BM_PXP_HW_PXP_HIST16_PARAM2_VALUE11) | BF_PXP_HW_PXP_HIST16_PARAM2_VALUE11(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM2, field RSVD11[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM2_RSVD11 (30U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM2_RSVD11. */
#define BM_PXP_HW_PXP_HIST16_PARAM2_RSVD11 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM2_RSVD11. */
#define BS_PXP_HW_PXP_HIST16_PARAM2_RSVD11 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM2_RSVD11. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM2_RSVD11 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM2_RSVD11(x) (HW_PXP_HW_PXP_HIST16_PARAM2(x).B.RSVD11)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST16_PARAM3 - 16-level Histogram Parameter 3 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST16_PARAM3 - 16-level Histogram Parameter 3 Register. (RW)
 *
 * Reset value: 0x0F0E0D0CU
 *
 * This register specifies four of the valid values for a 16-level histogram. If
 * all pixels in a bitmap match the 16-level histogram values, STATUS[3] will be
 * set at the end of frame processing. All comparator values should be
 * programmed such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hw_pxp_hist16_param3
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist16_param3_bitfields
    {
        uint32_t VALUE12 : 6;          /*!< [5:0]  */
        uint32_t RSVD12 : 2;           /*!< [7:6]  */
        uint32_t VALUE13 : 6;          /*!< [13:8]  */
        uint32_t RSVD13 : 2;           /*!< [15:14]  */
        uint32_t VALUE14 : 6;          /*!< [21:16]  */
        uint32_t RSVD14 : 2;           /*!< [23:22]  */
        uint32_t VALUE15 : 6;          /*!< [29:24]  */
        uint32_t RSVD15 : 2;           /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_hist16_param3_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST16_PARAM3 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST16_PARAM3_ADDR(x) ((uintptr_t)(x) + 0x2B70U)

#define HW_PXP_HW_PXP_HIST16_PARAM3(x) (*(__IO hw_pxp_hw_pxp_hist16_param3_t *) HW_PXP_HW_PXP_HIST16_PARAM3_ADDR(x))
#define HW_PXP_HW_PXP_HIST16_PARAM3_RD(x) (HW_PXP_HW_PXP_HIST16_PARAM3(x).U)
#define HW_PXP_HW_PXP_HIST16_PARAM3_WR(x, v) (HW_PXP_HW_PXP_HIST16_PARAM3(x).U = (v))
#define HW_PXP_HW_PXP_HIST16_PARAM3_SET(x, v) (HW_PXP_HW_PXP_HIST16_PARAM3_WR(x, HW_PXP_HW_PXP_HIST16_PARAM3_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST16_PARAM3_CLR(x, v) (HW_PXP_HW_PXP_HIST16_PARAM3_WR(x, HW_PXP_HW_PXP_HIST16_PARAM3_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST16_PARAM3_TOG(x, v) (HW_PXP_HW_PXP_HIST16_PARAM3_WR(x, HW_PXP_HW_PXP_HIST16_PARAM3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST16_PARAM3 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM3, field VALUE12[5:0] (RW)
 *
 * GRAY12 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM3_VALUE12 (0U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM3_VALUE12. */
#define BM_PXP_HW_PXP_HIST16_PARAM3_VALUE12 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM3_VALUE12. */
#define BS_PXP_HW_PXP_HIST16_PARAM3_VALUE12 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM3_VALUE12. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM3_VALUE12 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM3_VALUE12(x) (HW_PXP_HW_PXP_HIST16_PARAM3(x).B.VALUE12)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST16_PARAM3_VALUE12. */
#define BF_PXP_HW_PXP_HIST16_PARAM3_VALUE12(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST16_PARAM3_VALUE12) & BM_PXP_HW_PXP_HIST16_PARAM3_VALUE12)

/*! @brief Set the VALUE12 field to a new value. */
#define BW_PXP_HW_PXP_HIST16_PARAM3_VALUE12(x, v) (HW_PXP_HW_PXP_HIST16_PARAM3_WR(x, (HW_PXP_HW_PXP_HIST16_PARAM3_RD(x) & ~BM_PXP_HW_PXP_HIST16_PARAM3_VALUE12) | BF_PXP_HW_PXP_HIST16_PARAM3_VALUE12(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM3, field RSVD12[7:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM3_RSVD12 (6U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM3_RSVD12. */
#define BM_PXP_HW_PXP_HIST16_PARAM3_RSVD12 (0x000000C0U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM3_RSVD12. */
#define BS_PXP_HW_PXP_HIST16_PARAM3_RSVD12 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM3_RSVD12. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM3_RSVD12 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM3_RSVD12(x) (HW_PXP_HW_PXP_HIST16_PARAM3(x).B.RSVD12)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM3, field VALUE13[13:8] (RW)
 *
 * GRAY13 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM3_VALUE13 (8U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM3_VALUE13. */
#define BM_PXP_HW_PXP_HIST16_PARAM3_VALUE13 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM3_VALUE13. */
#define BS_PXP_HW_PXP_HIST16_PARAM3_VALUE13 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM3_VALUE13. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM3_VALUE13 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM3_VALUE13(x) (HW_PXP_HW_PXP_HIST16_PARAM3(x).B.VALUE13)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST16_PARAM3_VALUE13. */
#define BF_PXP_HW_PXP_HIST16_PARAM3_VALUE13(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST16_PARAM3_VALUE13) & BM_PXP_HW_PXP_HIST16_PARAM3_VALUE13)

/*! @brief Set the VALUE13 field to a new value. */
#define BW_PXP_HW_PXP_HIST16_PARAM3_VALUE13(x, v) (HW_PXP_HW_PXP_HIST16_PARAM3_WR(x, (HW_PXP_HW_PXP_HIST16_PARAM3_RD(x) & ~BM_PXP_HW_PXP_HIST16_PARAM3_VALUE13) | BF_PXP_HW_PXP_HIST16_PARAM3_VALUE13(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM3, field RSVD13[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM3_RSVD13 (14U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM3_RSVD13. */
#define BM_PXP_HW_PXP_HIST16_PARAM3_RSVD13 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM3_RSVD13. */
#define BS_PXP_HW_PXP_HIST16_PARAM3_RSVD13 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM3_RSVD13. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM3_RSVD13 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM3_RSVD13(x) (HW_PXP_HW_PXP_HIST16_PARAM3(x).B.RSVD13)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM3, field VALUE14[21:16] (RW)
 *
 * GRAY14 value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM3_VALUE14 (16U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM3_VALUE14. */
#define BM_PXP_HW_PXP_HIST16_PARAM3_VALUE14 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM3_VALUE14. */
#define BS_PXP_HW_PXP_HIST16_PARAM3_VALUE14 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM3_VALUE14. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM3_VALUE14 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM3_VALUE14(x) (HW_PXP_HW_PXP_HIST16_PARAM3(x).B.VALUE14)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST16_PARAM3_VALUE14. */
#define BF_PXP_HW_PXP_HIST16_PARAM3_VALUE14(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST16_PARAM3_VALUE14) & BM_PXP_HW_PXP_HIST16_PARAM3_VALUE14)

/*! @brief Set the VALUE14 field to a new value. */
#define BW_PXP_HW_PXP_HIST16_PARAM3_VALUE14(x, v) (HW_PXP_HW_PXP_HIST16_PARAM3_WR(x, (HW_PXP_HW_PXP_HIST16_PARAM3_RD(x) & ~BM_PXP_HW_PXP_HIST16_PARAM3_VALUE14) | BF_PXP_HW_PXP_HIST16_PARAM3_VALUE14(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM3, field RSVD14[23:22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM3_RSVD14 (22U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM3_RSVD14. */
#define BM_PXP_HW_PXP_HIST16_PARAM3_RSVD14 (0x00C00000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM3_RSVD14. */
#define BS_PXP_HW_PXP_HIST16_PARAM3_RSVD14 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM3_RSVD14. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM3_RSVD14 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM3_RSVD14(x) (HW_PXP_HW_PXP_HIST16_PARAM3(x).B.RSVD14)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM3, field VALUE15[29:24] (RW)
 *
 * GRAY15 (White) value for 16-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM3_VALUE15 (24U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM3_VALUE15. */
#define BM_PXP_HW_PXP_HIST16_PARAM3_VALUE15 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM3_VALUE15. */
#define BS_PXP_HW_PXP_HIST16_PARAM3_VALUE15 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM3_VALUE15. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM3_VALUE15 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM3_VALUE15(x) (HW_PXP_HW_PXP_HIST16_PARAM3(x).B.VALUE15)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST16_PARAM3_VALUE15. */
#define BF_PXP_HW_PXP_HIST16_PARAM3_VALUE15(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST16_PARAM3_VALUE15) & BM_PXP_HW_PXP_HIST16_PARAM3_VALUE15)

/*! @brief Set the VALUE15 field to a new value. */
#define BW_PXP_HW_PXP_HIST16_PARAM3_VALUE15(x, v) (HW_PXP_HW_PXP_HIST16_PARAM3_WR(x, (HW_PXP_HW_PXP_HIST16_PARAM3_RD(x) & ~BM_PXP_HW_PXP_HIST16_PARAM3_VALUE15) | BF_PXP_HW_PXP_HIST16_PARAM3_VALUE15(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST16_PARAM3, field RSVD15[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST16_PARAM3_RSVD15 (30U) /*!< Bit position for PXP_HW_PXP_HIST16_PARAM3_RSVD15. */
#define BM_PXP_HW_PXP_HIST16_PARAM3_RSVD15 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_HIST16_PARAM3_RSVD15. */
#define BS_PXP_HW_PXP_HIST16_PARAM3_RSVD15 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST16_PARAM3_RSVD15. */

/*! @brief Read current value of the PXP_HW_PXP_HIST16_PARAM3_RSVD15 field. */
#define BR_PXP_HW_PXP_HIST16_PARAM3_RSVD15(x) (HW_PXP_HW_PXP_HIST16_PARAM3(x).B.RSVD15)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST32_PARAM0 - 32-level Histogram Parameter 0 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST32_PARAM0 - 32-level Histogram Parameter 0 Register. (RW)
 *
 * Reset value: 0x03020100U
 *
 * This register specifies four of the valid values for a 32-level histogram. If
 * all pixels in a bitmap match the 32-level histogram values, STATUS[3] will be
 * set at the end of frame processing. All comparator values should be
 * programmed such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hw_pxp_hist32_param0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist32_param0_bitfields
    {
        uint32_t VALUE0 : 6;           /*!< [5:0]  */
        uint32_t RSVD0 : 2;            /*!< [7:6]  */
        uint32_t VALUE1 : 6;           /*!< [13:8]  */
        uint32_t RSVD1 : 2;            /*!< [15:14]  */
        uint32_t VALUE2 : 6;           /*!< [21:16]  */
        uint32_t RSVD2 : 2;            /*!< [23:22]  */
        uint32_t VALUE3 : 6;           /*!< [29:24]  */
        uint32_t RSVD3 : 2;            /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_hist32_param0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST32_PARAM0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST32_PARAM0_ADDR(x) ((uintptr_t)(x) + 0x2B80U)

#define HW_PXP_HW_PXP_HIST32_PARAM0(x) (*(__IO hw_pxp_hw_pxp_hist32_param0_t *) HW_PXP_HW_PXP_HIST32_PARAM0_ADDR(x))
#define HW_PXP_HW_PXP_HIST32_PARAM0_RD(x) (HW_PXP_HW_PXP_HIST32_PARAM0(x).U)
#define HW_PXP_HW_PXP_HIST32_PARAM0_WR(x, v) (HW_PXP_HW_PXP_HIST32_PARAM0(x).U = (v))
#define HW_PXP_HW_PXP_HIST32_PARAM0_SET(x, v) (HW_PXP_HW_PXP_HIST32_PARAM0_WR(x, HW_PXP_HW_PXP_HIST32_PARAM0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST32_PARAM0_CLR(x, v) (HW_PXP_HW_PXP_HIST32_PARAM0_WR(x, HW_PXP_HW_PXP_HIST32_PARAM0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST32_PARAM0_TOG(x, v) (HW_PXP_HW_PXP_HIST32_PARAM0_WR(x, HW_PXP_HW_PXP_HIST32_PARAM0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST32_PARAM0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM0, field VALUE0[5:0] (RW)
 *
 * GRAY0 (Black) value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM0_VALUE0 (0U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM0_VALUE0. */
#define BM_PXP_HW_PXP_HIST32_PARAM0_VALUE0 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM0_VALUE0. */
#define BS_PXP_HW_PXP_HIST32_PARAM0_VALUE0 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM0_VALUE0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM0_VALUE0 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM0_VALUE0(x) (HW_PXP_HW_PXP_HIST32_PARAM0(x).B.VALUE0)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM0_VALUE0. */
#define BF_PXP_HW_PXP_HIST32_PARAM0_VALUE0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM0_VALUE0) & BM_PXP_HW_PXP_HIST32_PARAM0_VALUE0)

/*! @brief Set the VALUE0 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM0_VALUE0(x, v) (HW_PXP_HW_PXP_HIST32_PARAM0_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM0_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM0_VALUE0) | BF_PXP_HW_PXP_HIST32_PARAM0_VALUE0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM0, field RSVD0[7:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM0_RSVD0 (6U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM0_RSVD0. */
#define BM_PXP_HW_PXP_HIST32_PARAM0_RSVD0 (0x000000C0U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM0_RSVD0. */
#define BS_PXP_HW_PXP_HIST32_PARAM0_RSVD0 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM0_RSVD0 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM0_RSVD0(x) (HW_PXP_HW_PXP_HIST32_PARAM0(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM0, field VALUE1[13:8] (RW)
 *
 * GRAY1 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM0_VALUE1 (8U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM0_VALUE1. */
#define BM_PXP_HW_PXP_HIST32_PARAM0_VALUE1 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM0_VALUE1. */
#define BS_PXP_HW_PXP_HIST32_PARAM0_VALUE1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM0_VALUE1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM0_VALUE1 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM0_VALUE1(x) (HW_PXP_HW_PXP_HIST32_PARAM0(x).B.VALUE1)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM0_VALUE1. */
#define BF_PXP_HW_PXP_HIST32_PARAM0_VALUE1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM0_VALUE1) & BM_PXP_HW_PXP_HIST32_PARAM0_VALUE1)

/*! @brief Set the VALUE1 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM0_VALUE1(x, v) (HW_PXP_HW_PXP_HIST32_PARAM0_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM0_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM0_VALUE1) | BF_PXP_HW_PXP_HIST32_PARAM0_VALUE1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM0, field RSVD1[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM0_RSVD1 (14U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM0_RSVD1. */
#define BM_PXP_HW_PXP_HIST32_PARAM0_RSVD1 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM0_RSVD1. */
#define BS_PXP_HW_PXP_HIST32_PARAM0_RSVD1 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM0_RSVD1 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM0_RSVD1(x) (HW_PXP_HW_PXP_HIST32_PARAM0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM0, field VALUE2[21:16] (RW)
 *
 * GRAY2 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM0_VALUE2 (16U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM0_VALUE2. */
#define BM_PXP_HW_PXP_HIST32_PARAM0_VALUE2 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM0_VALUE2. */
#define BS_PXP_HW_PXP_HIST32_PARAM0_VALUE2 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM0_VALUE2. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM0_VALUE2 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM0_VALUE2(x) (HW_PXP_HW_PXP_HIST32_PARAM0(x).B.VALUE2)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM0_VALUE2. */
#define BF_PXP_HW_PXP_HIST32_PARAM0_VALUE2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM0_VALUE2) & BM_PXP_HW_PXP_HIST32_PARAM0_VALUE2)

/*! @brief Set the VALUE2 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM0_VALUE2(x, v) (HW_PXP_HW_PXP_HIST32_PARAM0_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM0_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM0_VALUE2) | BF_PXP_HW_PXP_HIST32_PARAM0_VALUE2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM0, field RSVD2[23:22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM0_RSVD2 (22U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM0_RSVD2. */
#define BM_PXP_HW_PXP_HIST32_PARAM0_RSVD2 (0x00C00000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM0_RSVD2. */
#define BS_PXP_HW_PXP_HIST32_PARAM0_RSVD2 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM0_RSVD2 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM0_RSVD2(x) (HW_PXP_HW_PXP_HIST32_PARAM0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM0, field VALUE3[29:24] (RW)
 *
 * GRAY3 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM0_VALUE3 (24U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM0_VALUE3. */
#define BM_PXP_HW_PXP_HIST32_PARAM0_VALUE3 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM0_VALUE3. */
#define BS_PXP_HW_PXP_HIST32_PARAM0_VALUE3 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM0_VALUE3. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM0_VALUE3 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM0_VALUE3(x) (HW_PXP_HW_PXP_HIST32_PARAM0(x).B.VALUE3)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM0_VALUE3. */
#define BF_PXP_HW_PXP_HIST32_PARAM0_VALUE3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM0_VALUE3) & BM_PXP_HW_PXP_HIST32_PARAM0_VALUE3)

/*! @brief Set the VALUE3 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM0_VALUE3(x, v) (HW_PXP_HW_PXP_HIST32_PARAM0_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM0_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM0_VALUE3) | BF_PXP_HW_PXP_HIST32_PARAM0_VALUE3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM0, field RSVD3[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM0_RSVD3 (30U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM0_RSVD3. */
#define BM_PXP_HW_PXP_HIST32_PARAM0_RSVD3 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM0_RSVD3. */
#define BS_PXP_HW_PXP_HIST32_PARAM0_RSVD3 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM0_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM0_RSVD3 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM0_RSVD3(x) (HW_PXP_HW_PXP_HIST32_PARAM0(x).B.RSVD3)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST32_PARAM1 - 32-level Histogram Parameter 1 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST32_PARAM1 - 32-level Histogram Parameter 1 Register. (RW)
 *
 * Reset value: 0x07060504U
 *
 * This register specifies four of the valid values for a 32-level histogram. If
 * all pixels in a bitmap match the 32-level histogram values, STATUS[3] will be
 * set at the end of frame processing. All comparator values should be
 * programmed such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hw_pxp_hist32_param1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist32_param1_bitfields
    {
        uint32_t VALUE4 : 6;           /*!< [5:0]  */
        uint32_t RSVD4 : 2;            /*!< [7:6]  */
        uint32_t VALUE5 : 6;           /*!< [13:8]  */
        uint32_t RSVD5 : 2;            /*!< [15:14]  */
        uint32_t VALUE6 : 6;           /*!< [21:16]  */
        uint32_t RSVD6 : 2;            /*!< [23:22]  */
        uint32_t VALUE7 : 6;           /*!< [29:24]  */
        uint32_t RSVD7 : 2;            /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_hist32_param1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST32_PARAM1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST32_PARAM1_ADDR(x) ((uintptr_t)(x) + 0x2B90U)

#define HW_PXP_HW_PXP_HIST32_PARAM1(x) (*(__IO hw_pxp_hw_pxp_hist32_param1_t *) HW_PXP_HW_PXP_HIST32_PARAM1_ADDR(x))
#define HW_PXP_HW_PXP_HIST32_PARAM1_RD(x) (HW_PXP_HW_PXP_HIST32_PARAM1(x).U)
#define HW_PXP_HW_PXP_HIST32_PARAM1_WR(x, v) (HW_PXP_HW_PXP_HIST32_PARAM1(x).U = (v))
#define HW_PXP_HW_PXP_HIST32_PARAM1_SET(x, v) (HW_PXP_HW_PXP_HIST32_PARAM1_WR(x, HW_PXP_HW_PXP_HIST32_PARAM1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST32_PARAM1_CLR(x, v) (HW_PXP_HW_PXP_HIST32_PARAM1_WR(x, HW_PXP_HW_PXP_HIST32_PARAM1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST32_PARAM1_TOG(x, v) (HW_PXP_HW_PXP_HIST32_PARAM1_WR(x, HW_PXP_HW_PXP_HIST32_PARAM1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST32_PARAM1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM1, field VALUE4[5:0] (RW)
 *
 * GRAY4 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM1_VALUE4 (0U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM1_VALUE4. */
#define BM_PXP_HW_PXP_HIST32_PARAM1_VALUE4 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM1_VALUE4. */
#define BS_PXP_HW_PXP_HIST32_PARAM1_VALUE4 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM1_VALUE4. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM1_VALUE4 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM1_VALUE4(x) (HW_PXP_HW_PXP_HIST32_PARAM1(x).B.VALUE4)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM1_VALUE4. */
#define BF_PXP_HW_PXP_HIST32_PARAM1_VALUE4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM1_VALUE4) & BM_PXP_HW_PXP_HIST32_PARAM1_VALUE4)

/*! @brief Set the VALUE4 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM1_VALUE4(x, v) (HW_PXP_HW_PXP_HIST32_PARAM1_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM1_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM1_VALUE4) | BF_PXP_HW_PXP_HIST32_PARAM1_VALUE4(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM1, field RSVD4[7:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM1_RSVD4 (6U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM1_RSVD4. */
#define BM_PXP_HW_PXP_HIST32_PARAM1_RSVD4 (0x000000C0U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM1_RSVD4. */
#define BS_PXP_HW_PXP_HIST32_PARAM1_RSVD4 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM1_RSVD4. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM1_RSVD4 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM1_RSVD4(x) (HW_PXP_HW_PXP_HIST32_PARAM1(x).B.RSVD4)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM1, field VALUE5[13:8] (RW)
 *
 * GRAY5 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM1_VALUE5 (8U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM1_VALUE5. */
#define BM_PXP_HW_PXP_HIST32_PARAM1_VALUE5 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM1_VALUE5. */
#define BS_PXP_HW_PXP_HIST32_PARAM1_VALUE5 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM1_VALUE5. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM1_VALUE5 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM1_VALUE5(x) (HW_PXP_HW_PXP_HIST32_PARAM1(x).B.VALUE5)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM1_VALUE5. */
#define BF_PXP_HW_PXP_HIST32_PARAM1_VALUE5(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM1_VALUE5) & BM_PXP_HW_PXP_HIST32_PARAM1_VALUE5)

/*! @brief Set the VALUE5 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM1_VALUE5(x, v) (HW_PXP_HW_PXP_HIST32_PARAM1_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM1_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM1_VALUE5) | BF_PXP_HW_PXP_HIST32_PARAM1_VALUE5(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM1, field RSVD5[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM1_RSVD5 (14U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM1_RSVD5. */
#define BM_PXP_HW_PXP_HIST32_PARAM1_RSVD5 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM1_RSVD5. */
#define BS_PXP_HW_PXP_HIST32_PARAM1_RSVD5 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM1_RSVD5. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM1_RSVD5 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM1_RSVD5(x) (HW_PXP_HW_PXP_HIST32_PARAM1(x).B.RSVD5)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM1, field VALUE6[21:16] (RW)
 *
 * GRAY6 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM1_VALUE6 (16U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM1_VALUE6. */
#define BM_PXP_HW_PXP_HIST32_PARAM1_VALUE6 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM1_VALUE6. */
#define BS_PXP_HW_PXP_HIST32_PARAM1_VALUE6 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM1_VALUE6. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM1_VALUE6 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM1_VALUE6(x) (HW_PXP_HW_PXP_HIST32_PARAM1(x).B.VALUE6)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM1_VALUE6. */
#define BF_PXP_HW_PXP_HIST32_PARAM1_VALUE6(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM1_VALUE6) & BM_PXP_HW_PXP_HIST32_PARAM1_VALUE6)

/*! @brief Set the VALUE6 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM1_VALUE6(x, v) (HW_PXP_HW_PXP_HIST32_PARAM1_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM1_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM1_VALUE6) | BF_PXP_HW_PXP_HIST32_PARAM1_VALUE6(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM1, field RSVD6[23:22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM1_RSVD6 (22U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM1_RSVD6. */
#define BM_PXP_HW_PXP_HIST32_PARAM1_RSVD6 (0x00C00000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM1_RSVD6. */
#define BS_PXP_HW_PXP_HIST32_PARAM1_RSVD6 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM1_RSVD6. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM1_RSVD6 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM1_RSVD6(x) (HW_PXP_HW_PXP_HIST32_PARAM1(x).B.RSVD6)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM1, field VALUE7[29:24] (RW)
 *
 * GRAY7 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM1_VALUE7 (24U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM1_VALUE7. */
#define BM_PXP_HW_PXP_HIST32_PARAM1_VALUE7 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM1_VALUE7. */
#define BS_PXP_HW_PXP_HIST32_PARAM1_VALUE7 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM1_VALUE7. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM1_VALUE7 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM1_VALUE7(x) (HW_PXP_HW_PXP_HIST32_PARAM1(x).B.VALUE7)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM1_VALUE7. */
#define BF_PXP_HW_PXP_HIST32_PARAM1_VALUE7(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM1_VALUE7) & BM_PXP_HW_PXP_HIST32_PARAM1_VALUE7)

/*! @brief Set the VALUE7 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM1_VALUE7(x, v) (HW_PXP_HW_PXP_HIST32_PARAM1_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM1_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM1_VALUE7) | BF_PXP_HW_PXP_HIST32_PARAM1_VALUE7(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM1, field RSVD7[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM1_RSVD7 (30U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM1_RSVD7. */
#define BM_PXP_HW_PXP_HIST32_PARAM1_RSVD7 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM1_RSVD7. */
#define BS_PXP_HW_PXP_HIST32_PARAM1_RSVD7 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM1_RSVD7. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM1_RSVD7 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM1_RSVD7(x) (HW_PXP_HW_PXP_HIST32_PARAM1(x).B.RSVD7)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST32_PARAM2 - 32-level Histogram Parameter 2 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST32_PARAM2 - 32-level Histogram Parameter 2 Register. (RW)
 *
 * Reset value: 0x0B0A0908U
 *
 * This register specifies four of the valid values for a 32-level histogram. If
 * all pixels in a bitmap match the 32-level histogram values, STATUS[3] will be
 * set at the end of frame processing. All comparator values should be
 * programmed such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hw_pxp_hist32_param2
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist32_param2_bitfields
    {
        uint32_t VALUE8 : 6;           /*!< [5:0]  */
        uint32_t RSVD8 : 2;            /*!< [7:6]  */
        uint32_t VALUE9 : 6;           /*!< [13:8]  */
        uint32_t RSVD9 : 2;            /*!< [15:14]  */
        uint32_t VALUE10 : 6;          /*!< [21:16]  */
        uint32_t RSVD10 : 2;           /*!< [23:22]  */
        uint32_t VALUE11 : 6;          /*!< [29:24]  */
        uint32_t RSVD11 : 2;           /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_hist32_param2_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST32_PARAM2 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST32_PARAM2_ADDR(x) ((uintptr_t)(x) + 0x2BA0U)

#define HW_PXP_HW_PXP_HIST32_PARAM2(x) (*(__IO hw_pxp_hw_pxp_hist32_param2_t *) HW_PXP_HW_PXP_HIST32_PARAM2_ADDR(x))
#define HW_PXP_HW_PXP_HIST32_PARAM2_RD(x) (HW_PXP_HW_PXP_HIST32_PARAM2(x).U)
#define HW_PXP_HW_PXP_HIST32_PARAM2_WR(x, v) (HW_PXP_HW_PXP_HIST32_PARAM2(x).U = (v))
#define HW_PXP_HW_PXP_HIST32_PARAM2_SET(x, v) (HW_PXP_HW_PXP_HIST32_PARAM2_WR(x, HW_PXP_HW_PXP_HIST32_PARAM2_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST32_PARAM2_CLR(x, v) (HW_PXP_HW_PXP_HIST32_PARAM2_WR(x, HW_PXP_HW_PXP_HIST32_PARAM2_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST32_PARAM2_TOG(x, v) (HW_PXP_HW_PXP_HIST32_PARAM2_WR(x, HW_PXP_HW_PXP_HIST32_PARAM2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST32_PARAM2 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM2, field VALUE8[5:0] (RW)
 *
 * GRAY8 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM2_VALUE8 (0U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM2_VALUE8. */
#define BM_PXP_HW_PXP_HIST32_PARAM2_VALUE8 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM2_VALUE8. */
#define BS_PXP_HW_PXP_HIST32_PARAM2_VALUE8 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM2_VALUE8. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM2_VALUE8 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM2_VALUE8(x) (HW_PXP_HW_PXP_HIST32_PARAM2(x).B.VALUE8)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM2_VALUE8. */
#define BF_PXP_HW_PXP_HIST32_PARAM2_VALUE8(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM2_VALUE8) & BM_PXP_HW_PXP_HIST32_PARAM2_VALUE8)

/*! @brief Set the VALUE8 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM2_VALUE8(x, v) (HW_PXP_HW_PXP_HIST32_PARAM2_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM2_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM2_VALUE8) | BF_PXP_HW_PXP_HIST32_PARAM2_VALUE8(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM2, field RSVD8[7:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM2_RSVD8 (6U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM2_RSVD8. */
#define BM_PXP_HW_PXP_HIST32_PARAM2_RSVD8 (0x000000C0U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM2_RSVD8. */
#define BS_PXP_HW_PXP_HIST32_PARAM2_RSVD8 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM2_RSVD8. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM2_RSVD8 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM2_RSVD8(x) (HW_PXP_HW_PXP_HIST32_PARAM2(x).B.RSVD8)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM2, field VALUE9[13:8] (RW)
 *
 * GRAY9 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM2_VALUE9 (8U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM2_VALUE9. */
#define BM_PXP_HW_PXP_HIST32_PARAM2_VALUE9 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM2_VALUE9. */
#define BS_PXP_HW_PXP_HIST32_PARAM2_VALUE9 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM2_VALUE9. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM2_VALUE9 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM2_VALUE9(x) (HW_PXP_HW_PXP_HIST32_PARAM2(x).B.VALUE9)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM2_VALUE9. */
#define BF_PXP_HW_PXP_HIST32_PARAM2_VALUE9(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM2_VALUE9) & BM_PXP_HW_PXP_HIST32_PARAM2_VALUE9)

/*! @brief Set the VALUE9 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM2_VALUE9(x, v) (HW_PXP_HW_PXP_HIST32_PARAM2_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM2_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM2_VALUE9) | BF_PXP_HW_PXP_HIST32_PARAM2_VALUE9(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM2, field RSVD9[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM2_RSVD9 (14U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM2_RSVD9. */
#define BM_PXP_HW_PXP_HIST32_PARAM2_RSVD9 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM2_RSVD9. */
#define BS_PXP_HW_PXP_HIST32_PARAM2_RSVD9 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM2_RSVD9. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM2_RSVD9 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM2_RSVD9(x) (HW_PXP_HW_PXP_HIST32_PARAM2(x).B.RSVD9)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM2, field VALUE10[21:16] (RW)
 *
 * GRAY10 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM2_VALUE10 (16U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM2_VALUE10. */
#define BM_PXP_HW_PXP_HIST32_PARAM2_VALUE10 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM2_VALUE10. */
#define BS_PXP_HW_PXP_HIST32_PARAM2_VALUE10 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM2_VALUE10. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM2_VALUE10 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM2_VALUE10(x) (HW_PXP_HW_PXP_HIST32_PARAM2(x).B.VALUE10)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM2_VALUE10. */
#define BF_PXP_HW_PXP_HIST32_PARAM2_VALUE10(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM2_VALUE10) & BM_PXP_HW_PXP_HIST32_PARAM2_VALUE10)

/*! @brief Set the VALUE10 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM2_VALUE10(x, v) (HW_PXP_HW_PXP_HIST32_PARAM2_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM2_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM2_VALUE10) | BF_PXP_HW_PXP_HIST32_PARAM2_VALUE10(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM2, field RSVD10[23:22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM2_RSVD10 (22U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM2_RSVD10. */
#define BM_PXP_HW_PXP_HIST32_PARAM2_RSVD10 (0x00C00000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM2_RSVD10. */
#define BS_PXP_HW_PXP_HIST32_PARAM2_RSVD10 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM2_RSVD10. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM2_RSVD10 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM2_RSVD10(x) (HW_PXP_HW_PXP_HIST32_PARAM2(x).B.RSVD10)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM2, field VALUE11[29:24] (RW)
 *
 * GRAY11 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM2_VALUE11 (24U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM2_VALUE11. */
#define BM_PXP_HW_PXP_HIST32_PARAM2_VALUE11 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM2_VALUE11. */
#define BS_PXP_HW_PXP_HIST32_PARAM2_VALUE11 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM2_VALUE11. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM2_VALUE11 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM2_VALUE11(x) (HW_PXP_HW_PXP_HIST32_PARAM2(x).B.VALUE11)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM2_VALUE11. */
#define BF_PXP_HW_PXP_HIST32_PARAM2_VALUE11(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM2_VALUE11) & BM_PXP_HW_PXP_HIST32_PARAM2_VALUE11)

/*! @brief Set the VALUE11 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM2_VALUE11(x, v) (HW_PXP_HW_PXP_HIST32_PARAM2_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM2_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM2_VALUE11) | BF_PXP_HW_PXP_HIST32_PARAM2_VALUE11(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM2, field RSVD11[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM2_RSVD11 (30U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM2_RSVD11. */
#define BM_PXP_HW_PXP_HIST32_PARAM2_RSVD11 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM2_RSVD11. */
#define BS_PXP_HW_PXP_HIST32_PARAM2_RSVD11 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM2_RSVD11. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM2_RSVD11 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM2_RSVD11(x) (HW_PXP_HW_PXP_HIST32_PARAM2(x).B.RSVD11)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST32_PARAM3 - 32-level Histogram Parameter 3 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST32_PARAM3 - 32-level Histogram Parameter 3 Register. (RW)
 *
 * Reset value: 0x0F0E0D0CU
 *
 * This register specifies four of the valid values for a 32-level histogram. If
 * all pixels in a bitmap match the 32-level histogram values, STATUS[3] will be
 * set at the end of frame processing. All comparator values should be
 * programmed such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hw_pxp_hist32_param3
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist32_param3_bitfields
    {
        uint32_t VALUE12 : 6;          /*!< [5:0]  */
        uint32_t RSVD12 : 2;           /*!< [7:6]  */
        uint32_t VALUE13 : 6;          /*!< [13:8]  */
        uint32_t RSVD13 : 2;           /*!< [15:14]  */
        uint32_t VALUE14 : 6;          /*!< [21:16]  */
        uint32_t RSVD14 : 2;           /*!< [23:22]  */
        uint32_t VALUE15 : 6;          /*!< [29:24]  */
        uint32_t RSVD15 : 2;           /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_hist32_param3_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST32_PARAM3 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST32_PARAM3_ADDR(x) ((uintptr_t)(x) + 0x2BB0U)

#define HW_PXP_HW_PXP_HIST32_PARAM3(x) (*(__IO hw_pxp_hw_pxp_hist32_param3_t *) HW_PXP_HW_PXP_HIST32_PARAM3_ADDR(x))
#define HW_PXP_HW_PXP_HIST32_PARAM3_RD(x) (HW_PXP_HW_PXP_HIST32_PARAM3(x).U)
#define HW_PXP_HW_PXP_HIST32_PARAM3_WR(x, v) (HW_PXP_HW_PXP_HIST32_PARAM3(x).U = (v))
#define HW_PXP_HW_PXP_HIST32_PARAM3_SET(x, v) (HW_PXP_HW_PXP_HIST32_PARAM3_WR(x, HW_PXP_HW_PXP_HIST32_PARAM3_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST32_PARAM3_CLR(x, v) (HW_PXP_HW_PXP_HIST32_PARAM3_WR(x, HW_PXP_HW_PXP_HIST32_PARAM3_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST32_PARAM3_TOG(x, v) (HW_PXP_HW_PXP_HIST32_PARAM3_WR(x, HW_PXP_HW_PXP_HIST32_PARAM3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST32_PARAM3 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM3, field VALUE12[5:0] (RW)
 *
 * GRAY12 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM3_VALUE12 (0U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM3_VALUE12. */
#define BM_PXP_HW_PXP_HIST32_PARAM3_VALUE12 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM3_VALUE12. */
#define BS_PXP_HW_PXP_HIST32_PARAM3_VALUE12 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM3_VALUE12. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM3_VALUE12 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM3_VALUE12(x) (HW_PXP_HW_PXP_HIST32_PARAM3(x).B.VALUE12)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM3_VALUE12. */
#define BF_PXP_HW_PXP_HIST32_PARAM3_VALUE12(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM3_VALUE12) & BM_PXP_HW_PXP_HIST32_PARAM3_VALUE12)

/*! @brief Set the VALUE12 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM3_VALUE12(x, v) (HW_PXP_HW_PXP_HIST32_PARAM3_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM3_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM3_VALUE12) | BF_PXP_HW_PXP_HIST32_PARAM3_VALUE12(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM3, field RSVD12[7:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM3_RSVD12 (6U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM3_RSVD12. */
#define BM_PXP_HW_PXP_HIST32_PARAM3_RSVD12 (0x000000C0U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM3_RSVD12. */
#define BS_PXP_HW_PXP_HIST32_PARAM3_RSVD12 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM3_RSVD12. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM3_RSVD12 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM3_RSVD12(x) (HW_PXP_HW_PXP_HIST32_PARAM3(x).B.RSVD12)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM3, field VALUE13[13:8] (RW)
 *
 * GRAY13 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM3_VALUE13 (8U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM3_VALUE13. */
#define BM_PXP_HW_PXP_HIST32_PARAM3_VALUE13 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM3_VALUE13. */
#define BS_PXP_HW_PXP_HIST32_PARAM3_VALUE13 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM3_VALUE13. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM3_VALUE13 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM3_VALUE13(x) (HW_PXP_HW_PXP_HIST32_PARAM3(x).B.VALUE13)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM3_VALUE13. */
#define BF_PXP_HW_PXP_HIST32_PARAM3_VALUE13(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM3_VALUE13) & BM_PXP_HW_PXP_HIST32_PARAM3_VALUE13)

/*! @brief Set the VALUE13 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM3_VALUE13(x, v) (HW_PXP_HW_PXP_HIST32_PARAM3_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM3_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM3_VALUE13) | BF_PXP_HW_PXP_HIST32_PARAM3_VALUE13(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM3, field RSVD13[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM3_RSVD13 (14U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM3_RSVD13. */
#define BM_PXP_HW_PXP_HIST32_PARAM3_RSVD13 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM3_RSVD13. */
#define BS_PXP_HW_PXP_HIST32_PARAM3_RSVD13 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM3_RSVD13. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM3_RSVD13 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM3_RSVD13(x) (HW_PXP_HW_PXP_HIST32_PARAM3(x).B.RSVD13)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM3, field VALUE14[21:16] (RW)
 *
 * GRAY14 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM3_VALUE14 (16U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM3_VALUE14. */
#define BM_PXP_HW_PXP_HIST32_PARAM3_VALUE14 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM3_VALUE14. */
#define BS_PXP_HW_PXP_HIST32_PARAM3_VALUE14 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM3_VALUE14. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM3_VALUE14 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM3_VALUE14(x) (HW_PXP_HW_PXP_HIST32_PARAM3(x).B.VALUE14)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM3_VALUE14. */
#define BF_PXP_HW_PXP_HIST32_PARAM3_VALUE14(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM3_VALUE14) & BM_PXP_HW_PXP_HIST32_PARAM3_VALUE14)

/*! @brief Set the VALUE14 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM3_VALUE14(x, v) (HW_PXP_HW_PXP_HIST32_PARAM3_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM3_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM3_VALUE14) | BF_PXP_HW_PXP_HIST32_PARAM3_VALUE14(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM3, field RSVD14[23:22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM3_RSVD14 (22U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM3_RSVD14. */
#define BM_PXP_HW_PXP_HIST32_PARAM3_RSVD14 (0x00C00000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM3_RSVD14. */
#define BS_PXP_HW_PXP_HIST32_PARAM3_RSVD14 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM3_RSVD14. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM3_RSVD14 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM3_RSVD14(x) (HW_PXP_HW_PXP_HIST32_PARAM3(x).B.RSVD14)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM3, field VALUE15[29:24] (RW)
 *
 * GRAY15 (White) value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM3_VALUE15 (24U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM3_VALUE15. */
#define BM_PXP_HW_PXP_HIST32_PARAM3_VALUE15 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM3_VALUE15. */
#define BS_PXP_HW_PXP_HIST32_PARAM3_VALUE15 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM3_VALUE15. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM3_VALUE15 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM3_VALUE15(x) (HW_PXP_HW_PXP_HIST32_PARAM3(x).B.VALUE15)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM3_VALUE15. */
#define BF_PXP_HW_PXP_HIST32_PARAM3_VALUE15(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM3_VALUE15) & BM_PXP_HW_PXP_HIST32_PARAM3_VALUE15)

/*! @brief Set the VALUE15 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM3_VALUE15(x, v) (HW_PXP_HW_PXP_HIST32_PARAM3_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM3_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM3_VALUE15) | BF_PXP_HW_PXP_HIST32_PARAM3_VALUE15(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM3, field RSVD15[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM3_RSVD15 (30U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM3_RSVD15. */
#define BM_PXP_HW_PXP_HIST32_PARAM3_RSVD15 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM3_RSVD15. */
#define BS_PXP_HW_PXP_HIST32_PARAM3_RSVD15 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM3_RSVD15. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM3_RSVD15 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM3_RSVD15(x) (HW_PXP_HW_PXP_HIST32_PARAM3(x).B.RSVD15)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST32_PARAM4 - 32-level Histogram Parameter 0 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST32_PARAM4 - 32-level Histogram Parameter 0 Register. (RW)
 *
 * Reset value: 0x03020100U
 *
 * This register specifies four of the valid values for a 32-level histogram. If
 * all pixels in a bitmap match the 32-level histogram values, STATUS[3] will be
 * set at the end of frame processing. All comparator values should be
 * programmed such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hw_pxp_hist32_param4
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist32_param4_bitfields
    {
        uint32_t VALUE16 : 6;          /*!< [5:0]  */
        uint32_t RSVD0 : 2;            /*!< [7:6]  */
        uint32_t VALUE17 : 6;          /*!< [13:8]  */
        uint32_t RSVD1 : 2;            /*!< [15:14]  */
        uint32_t VALUE18 : 6;          /*!< [21:16]  */
        uint32_t RSVD2 : 2;            /*!< [23:22]  */
        uint32_t VALUE19 : 6;          /*!< [29:24]  */
        uint32_t RSVD3 : 2;            /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_hist32_param4_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST32_PARAM4 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST32_PARAM4_ADDR(x) ((uintptr_t)(x) + 0x2BC0U)

#define HW_PXP_HW_PXP_HIST32_PARAM4(x) (*(__IO hw_pxp_hw_pxp_hist32_param4_t *) HW_PXP_HW_PXP_HIST32_PARAM4_ADDR(x))
#define HW_PXP_HW_PXP_HIST32_PARAM4_RD(x) (HW_PXP_HW_PXP_HIST32_PARAM4(x).U)
#define HW_PXP_HW_PXP_HIST32_PARAM4_WR(x, v) (HW_PXP_HW_PXP_HIST32_PARAM4(x).U = (v))
#define HW_PXP_HW_PXP_HIST32_PARAM4_SET(x, v) (HW_PXP_HW_PXP_HIST32_PARAM4_WR(x, HW_PXP_HW_PXP_HIST32_PARAM4_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST32_PARAM4_CLR(x, v) (HW_PXP_HW_PXP_HIST32_PARAM4_WR(x, HW_PXP_HW_PXP_HIST32_PARAM4_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST32_PARAM4_TOG(x, v) (HW_PXP_HW_PXP_HIST32_PARAM4_WR(x, HW_PXP_HW_PXP_HIST32_PARAM4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST32_PARAM4 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM4, field VALUE16[5:0] (RW)
 *
 * GRAY16 (Black) value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM4_VALUE16 (0U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM4_VALUE16. */
#define BM_PXP_HW_PXP_HIST32_PARAM4_VALUE16 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM4_VALUE16. */
#define BS_PXP_HW_PXP_HIST32_PARAM4_VALUE16 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM4_VALUE16. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM4_VALUE16 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM4_VALUE16(x) (HW_PXP_HW_PXP_HIST32_PARAM4(x).B.VALUE16)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM4_VALUE16. */
#define BF_PXP_HW_PXP_HIST32_PARAM4_VALUE16(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM4_VALUE16) & BM_PXP_HW_PXP_HIST32_PARAM4_VALUE16)

/*! @brief Set the VALUE16 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM4_VALUE16(x, v) (HW_PXP_HW_PXP_HIST32_PARAM4_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM4_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM4_VALUE16) | BF_PXP_HW_PXP_HIST32_PARAM4_VALUE16(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM4, field RSVD0[7:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM4_RSVD0 (6U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM4_RSVD0. */
#define BM_PXP_HW_PXP_HIST32_PARAM4_RSVD0 (0x000000C0U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM4_RSVD0. */
#define BS_PXP_HW_PXP_HIST32_PARAM4_RSVD0 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM4_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM4_RSVD0 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM4_RSVD0(x) (HW_PXP_HW_PXP_HIST32_PARAM4(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM4, field VALUE17[13:8] (RW)
 *
 * GRAY17 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM4_VALUE17 (8U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM4_VALUE17. */
#define BM_PXP_HW_PXP_HIST32_PARAM4_VALUE17 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM4_VALUE17. */
#define BS_PXP_HW_PXP_HIST32_PARAM4_VALUE17 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM4_VALUE17. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM4_VALUE17 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM4_VALUE17(x) (HW_PXP_HW_PXP_HIST32_PARAM4(x).B.VALUE17)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM4_VALUE17. */
#define BF_PXP_HW_PXP_HIST32_PARAM4_VALUE17(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM4_VALUE17) & BM_PXP_HW_PXP_HIST32_PARAM4_VALUE17)

/*! @brief Set the VALUE17 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM4_VALUE17(x, v) (HW_PXP_HW_PXP_HIST32_PARAM4_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM4_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM4_VALUE17) | BF_PXP_HW_PXP_HIST32_PARAM4_VALUE17(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM4, field RSVD1[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM4_RSVD1 (14U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM4_RSVD1. */
#define BM_PXP_HW_PXP_HIST32_PARAM4_RSVD1 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM4_RSVD1. */
#define BS_PXP_HW_PXP_HIST32_PARAM4_RSVD1 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM4_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM4_RSVD1 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM4_RSVD1(x) (HW_PXP_HW_PXP_HIST32_PARAM4(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM4, field VALUE18[21:16] (RW)
 *
 * GRAY18 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM4_VALUE18 (16U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM4_VALUE18. */
#define BM_PXP_HW_PXP_HIST32_PARAM4_VALUE18 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM4_VALUE18. */
#define BS_PXP_HW_PXP_HIST32_PARAM4_VALUE18 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM4_VALUE18. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM4_VALUE18 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM4_VALUE18(x) (HW_PXP_HW_PXP_HIST32_PARAM4(x).B.VALUE18)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM4_VALUE18. */
#define BF_PXP_HW_PXP_HIST32_PARAM4_VALUE18(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM4_VALUE18) & BM_PXP_HW_PXP_HIST32_PARAM4_VALUE18)

/*! @brief Set the VALUE18 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM4_VALUE18(x, v) (HW_PXP_HW_PXP_HIST32_PARAM4_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM4_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM4_VALUE18) | BF_PXP_HW_PXP_HIST32_PARAM4_VALUE18(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM4, field RSVD2[23:22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM4_RSVD2 (22U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM4_RSVD2. */
#define BM_PXP_HW_PXP_HIST32_PARAM4_RSVD2 (0x00C00000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM4_RSVD2. */
#define BS_PXP_HW_PXP_HIST32_PARAM4_RSVD2 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM4_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM4_RSVD2 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM4_RSVD2(x) (HW_PXP_HW_PXP_HIST32_PARAM4(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM4, field VALUE19[29:24] (RW)
 *
 * GRAY19 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM4_VALUE19 (24U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM4_VALUE19. */
#define BM_PXP_HW_PXP_HIST32_PARAM4_VALUE19 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM4_VALUE19. */
#define BS_PXP_HW_PXP_HIST32_PARAM4_VALUE19 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM4_VALUE19. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM4_VALUE19 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM4_VALUE19(x) (HW_PXP_HW_PXP_HIST32_PARAM4(x).B.VALUE19)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM4_VALUE19. */
#define BF_PXP_HW_PXP_HIST32_PARAM4_VALUE19(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM4_VALUE19) & BM_PXP_HW_PXP_HIST32_PARAM4_VALUE19)

/*! @brief Set the VALUE19 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM4_VALUE19(x, v) (HW_PXP_HW_PXP_HIST32_PARAM4_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM4_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM4_VALUE19) | BF_PXP_HW_PXP_HIST32_PARAM4_VALUE19(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM4, field RSVD3[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM4_RSVD3 (30U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM4_RSVD3. */
#define BM_PXP_HW_PXP_HIST32_PARAM4_RSVD3 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM4_RSVD3. */
#define BS_PXP_HW_PXP_HIST32_PARAM4_RSVD3 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM4_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM4_RSVD3 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM4_RSVD3(x) (HW_PXP_HW_PXP_HIST32_PARAM4(x).B.RSVD3)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST32_PARAM5 - 32-level Histogram Parameter 1 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST32_PARAM5 - 32-level Histogram Parameter 1 Register. (RW)
 *
 * Reset value: 0x07060504U
 *
 * This register specifies four of the valid values for a 32-level histogram. If
 * all pixels in a bitmap match the 32-level histogram values, STATUS[3] will be
 * set at the end of frame processing. All comparator values should be
 * programmed such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hw_pxp_hist32_param5
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist32_param5_bitfields
    {
        uint32_t VALUE20 : 6;          /*!< [5:0]  */
        uint32_t RSVD4 : 2;            /*!< [7:6]  */
        uint32_t VALUE21 : 6;          /*!< [13:8]  */
        uint32_t RSVD5 : 2;            /*!< [15:14]  */
        uint32_t VALUE22 : 6;          /*!< [21:16]  */
        uint32_t RSVD6 : 2;            /*!< [23:22]  */
        uint32_t VALUE23 : 6;          /*!< [29:24]  */
        uint32_t RSVD7 : 2;            /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_hist32_param5_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST32_PARAM5 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST32_PARAM5_ADDR(x) ((uintptr_t)(x) + 0x2BD0U)

#define HW_PXP_HW_PXP_HIST32_PARAM5(x) (*(__IO hw_pxp_hw_pxp_hist32_param5_t *) HW_PXP_HW_PXP_HIST32_PARAM5_ADDR(x))
#define HW_PXP_HW_PXP_HIST32_PARAM5_RD(x) (HW_PXP_HW_PXP_HIST32_PARAM5(x).U)
#define HW_PXP_HW_PXP_HIST32_PARAM5_WR(x, v) (HW_PXP_HW_PXP_HIST32_PARAM5(x).U = (v))
#define HW_PXP_HW_PXP_HIST32_PARAM5_SET(x, v) (HW_PXP_HW_PXP_HIST32_PARAM5_WR(x, HW_PXP_HW_PXP_HIST32_PARAM5_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST32_PARAM5_CLR(x, v) (HW_PXP_HW_PXP_HIST32_PARAM5_WR(x, HW_PXP_HW_PXP_HIST32_PARAM5_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST32_PARAM5_TOG(x, v) (HW_PXP_HW_PXP_HIST32_PARAM5_WR(x, HW_PXP_HW_PXP_HIST32_PARAM5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST32_PARAM5 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM5, field VALUE20[5:0] (RW)
 *
 * GRAY20 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM5_VALUE20 (0U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM5_VALUE20. */
#define BM_PXP_HW_PXP_HIST32_PARAM5_VALUE20 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM5_VALUE20. */
#define BS_PXP_HW_PXP_HIST32_PARAM5_VALUE20 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM5_VALUE20. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM5_VALUE20 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM5_VALUE20(x) (HW_PXP_HW_PXP_HIST32_PARAM5(x).B.VALUE20)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM5_VALUE20. */
#define BF_PXP_HW_PXP_HIST32_PARAM5_VALUE20(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM5_VALUE20) & BM_PXP_HW_PXP_HIST32_PARAM5_VALUE20)

/*! @brief Set the VALUE20 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM5_VALUE20(x, v) (HW_PXP_HW_PXP_HIST32_PARAM5_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM5_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM5_VALUE20) | BF_PXP_HW_PXP_HIST32_PARAM5_VALUE20(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM5, field RSVD4[7:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM5_RSVD4 (6U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM5_RSVD4. */
#define BM_PXP_HW_PXP_HIST32_PARAM5_RSVD4 (0x000000C0U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM5_RSVD4. */
#define BS_PXP_HW_PXP_HIST32_PARAM5_RSVD4 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM5_RSVD4. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM5_RSVD4 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM5_RSVD4(x) (HW_PXP_HW_PXP_HIST32_PARAM5(x).B.RSVD4)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM5, field VALUE21[13:8] (RW)
 *
 * GRAY21 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM5_VALUE21 (8U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM5_VALUE21. */
#define BM_PXP_HW_PXP_HIST32_PARAM5_VALUE21 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM5_VALUE21. */
#define BS_PXP_HW_PXP_HIST32_PARAM5_VALUE21 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM5_VALUE21. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM5_VALUE21 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM5_VALUE21(x) (HW_PXP_HW_PXP_HIST32_PARAM5(x).B.VALUE21)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM5_VALUE21. */
#define BF_PXP_HW_PXP_HIST32_PARAM5_VALUE21(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM5_VALUE21) & BM_PXP_HW_PXP_HIST32_PARAM5_VALUE21)

/*! @brief Set the VALUE21 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM5_VALUE21(x, v) (HW_PXP_HW_PXP_HIST32_PARAM5_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM5_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM5_VALUE21) | BF_PXP_HW_PXP_HIST32_PARAM5_VALUE21(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM5, field RSVD5[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM5_RSVD5 (14U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM5_RSVD5. */
#define BM_PXP_HW_PXP_HIST32_PARAM5_RSVD5 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM5_RSVD5. */
#define BS_PXP_HW_PXP_HIST32_PARAM5_RSVD5 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM5_RSVD5. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM5_RSVD5 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM5_RSVD5(x) (HW_PXP_HW_PXP_HIST32_PARAM5(x).B.RSVD5)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM5, field VALUE22[21:16] (RW)
 *
 * GRAY22 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM5_VALUE22 (16U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM5_VALUE22. */
#define BM_PXP_HW_PXP_HIST32_PARAM5_VALUE22 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM5_VALUE22. */
#define BS_PXP_HW_PXP_HIST32_PARAM5_VALUE22 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM5_VALUE22. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM5_VALUE22 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM5_VALUE22(x) (HW_PXP_HW_PXP_HIST32_PARAM5(x).B.VALUE22)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM5_VALUE22. */
#define BF_PXP_HW_PXP_HIST32_PARAM5_VALUE22(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM5_VALUE22) & BM_PXP_HW_PXP_HIST32_PARAM5_VALUE22)

/*! @brief Set the VALUE22 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM5_VALUE22(x, v) (HW_PXP_HW_PXP_HIST32_PARAM5_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM5_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM5_VALUE22) | BF_PXP_HW_PXP_HIST32_PARAM5_VALUE22(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM5, field RSVD6[23:22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM5_RSVD6 (22U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM5_RSVD6. */
#define BM_PXP_HW_PXP_HIST32_PARAM5_RSVD6 (0x00C00000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM5_RSVD6. */
#define BS_PXP_HW_PXP_HIST32_PARAM5_RSVD6 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM5_RSVD6. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM5_RSVD6 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM5_RSVD6(x) (HW_PXP_HW_PXP_HIST32_PARAM5(x).B.RSVD6)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM5, field VALUE23[29:24] (RW)
 *
 * GRAY23 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM5_VALUE23 (24U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM5_VALUE23. */
#define BM_PXP_HW_PXP_HIST32_PARAM5_VALUE23 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM5_VALUE23. */
#define BS_PXP_HW_PXP_HIST32_PARAM5_VALUE23 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM5_VALUE23. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM5_VALUE23 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM5_VALUE23(x) (HW_PXP_HW_PXP_HIST32_PARAM5(x).B.VALUE23)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM5_VALUE23. */
#define BF_PXP_HW_PXP_HIST32_PARAM5_VALUE23(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM5_VALUE23) & BM_PXP_HW_PXP_HIST32_PARAM5_VALUE23)

/*! @brief Set the VALUE23 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM5_VALUE23(x, v) (HW_PXP_HW_PXP_HIST32_PARAM5_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM5_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM5_VALUE23) | BF_PXP_HW_PXP_HIST32_PARAM5_VALUE23(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM5, field RSVD7[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM5_RSVD7 (30U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM5_RSVD7. */
#define BM_PXP_HW_PXP_HIST32_PARAM5_RSVD7 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM5_RSVD7. */
#define BS_PXP_HW_PXP_HIST32_PARAM5_RSVD7 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM5_RSVD7. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM5_RSVD7 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM5_RSVD7(x) (HW_PXP_HW_PXP_HIST32_PARAM5(x).B.RSVD7)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST32_PARAM6 - 32-level Histogram Parameter 2 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST32_PARAM6 - 32-level Histogram Parameter 2 Register. (RW)
 *
 * Reset value: 0x0B0A0908U
 *
 * This register specifies four of the valid values for a 32-level histogram. If
 * all pixels in a bitmap match the 32-level histogram values, STATUS[3] will be
 * set at the end of frame processing. All comparator values should be
 * programmed such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hw_pxp_hist32_param6
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist32_param6_bitfields
    {
        uint32_t VALUE24 : 6;          /*!< [5:0]  */
        uint32_t RSVD8 : 2;            /*!< [7:6]  */
        uint32_t VALUE25 : 6;          /*!< [13:8]  */
        uint32_t RSVD9 : 2;            /*!< [15:14]  */
        uint32_t VALUE26 : 6;          /*!< [21:16]  */
        uint32_t RSVD10 : 2;           /*!< [23:22]  */
        uint32_t VALUE27 : 6;          /*!< [29:24]  */
        uint32_t RSVD11 : 2;           /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_hist32_param6_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST32_PARAM6 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST32_PARAM6_ADDR(x) ((uintptr_t)(x) + 0x2BE0U)

#define HW_PXP_HW_PXP_HIST32_PARAM6(x) (*(__IO hw_pxp_hw_pxp_hist32_param6_t *) HW_PXP_HW_PXP_HIST32_PARAM6_ADDR(x))
#define HW_PXP_HW_PXP_HIST32_PARAM6_RD(x) (HW_PXP_HW_PXP_HIST32_PARAM6(x).U)
#define HW_PXP_HW_PXP_HIST32_PARAM6_WR(x, v) (HW_PXP_HW_PXP_HIST32_PARAM6(x).U = (v))
#define HW_PXP_HW_PXP_HIST32_PARAM6_SET(x, v) (HW_PXP_HW_PXP_HIST32_PARAM6_WR(x, HW_PXP_HW_PXP_HIST32_PARAM6_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST32_PARAM6_CLR(x, v) (HW_PXP_HW_PXP_HIST32_PARAM6_WR(x, HW_PXP_HW_PXP_HIST32_PARAM6_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST32_PARAM6_TOG(x, v) (HW_PXP_HW_PXP_HIST32_PARAM6_WR(x, HW_PXP_HW_PXP_HIST32_PARAM6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST32_PARAM6 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM6, field VALUE24[5:0] (RW)
 *
 * GRAY24 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM6_VALUE24 (0U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM6_VALUE24. */
#define BM_PXP_HW_PXP_HIST32_PARAM6_VALUE24 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM6_VALUE24. */
#define BS_PXP_HW_PXP_HIST32_PARAM6_VALUE24 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM6_VALUE24. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM6_VALUE24 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM6_VALUE24(x) (HW_PXP_HW_PXP_HIST32_PARAM6(x).B.VALUE24)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM6_VALUE24. */
#define BF_PXP_HW_PXP_HIST32_PARAM6_VALUE24(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM6_VALUE24) & BM_PXP_HW_PXP_HIST32_PARAM6_VALUE24)

/*! @brief Set the VALUE24 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM6_VALUE24(x, v) (HW_PXP_HW_PXP_HIST32_PARAM6_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM6_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM6_VALUE24) | BF_PXP_HW_PXP_HIST32_PARAM6_VALUE24(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM6, field RSVD8[7:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM6_RSVD8 (6U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM6_RSVD8. */
#define BM_PXP_HW_PXP_HIST32_PARAM6_RSVD8 (0x000000C0U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM6_RSVD8. */
#define BS_PXP_HW_PXP_HIST32_PARAM6_RSVD8 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM6_RSVD8. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM6_RSVD8 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM6_RSVD8(x) (HW_PXP_HW_PXP_HIST32_PARAM6(x).B.RSVD8)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM6, field VALUE25[13:8] (RW)
 *
 * GRAY25 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM6_VALUE25 (8U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM6_VALUE25. */
#define BM_PXP_HW_PXP_HIST32_PARAM6_VALUE25 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM6_VALUE25. */
#define BS_PXP_HW_PXP_HIST32_PARAM6_VALUE25 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM6_VALUE25. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM6_VALUE25 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM6_VALUE25(x) (HW_PXP_HW_PXP_HIST32_PARAM6(x).B.VALUE25)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM6_VALUE25. */
#define BF_PXP_HW_PXP_HIST32_PARAM6_VALUE25(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM6_VALUE25) & BM_PXP_HW_PXP_HIST32_PARAM6_VALUE25)

/*! @brief Set the VALUE25 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM6_VALUE25(x, v) (HW_PXP_HW_PXP_HIST32_PARAM6_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM6_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM6_VALUE25) | BF_PXP_HW_PXP_HIST32_PARAM6_VALUE25(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM6, field RSVD9[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM6_RSVD9 (14U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM6_RSVD9. */
#define BM_PXP_HW_PXP_HIST32_PARAM6_RSVD9 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM6_RSVD9. */
#define BS_PXP_HW_PXP_HIST32_PARAM6_RSVD9 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM6_RSVD9. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM6_RSVD9 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM6_RSVD9(x) (HW_PXP_HW_PXP_HIST32_PARAM6(x).B.RSVD9)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM6, field VALUE26[21:16] (RW)
 *
 * GRAY26 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM6_VALUE26 (16U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM6_VALUE26. */
#define BM_PXP_HW_PXP_HIST32_PARAM6_VALUE26 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM6_VALUE26. */
#define BS_PXP_HW_PXP_HIST32_PARAM6_VALUE26 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM6_VALUE26. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM6_VALUE26 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM6_VALUE26(x) (HW_PXP_HW_PXP_HIST32_PARAM6(x).B.VALUE26)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM6_VALUE26. */
#define BF_PXP_HW_PXP_HIST32_PARAM6_VALUE26(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM6_VALUE26) & BM_PXP_HW_PXP_HIST32_PARAM6_VALUE26)

/*! @brief Set the VALUE26 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM6_VALUE26(x, v) (HW_PXP_HW_PXP_HIST32_PARAM6_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM6_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM6_VALUE26) | BF_PXP_HW_PXP_HIST32_PARAM6_VALUE26(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM6, field RSVD10[23:22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM6_RSVD10 (22U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM6_RSVD10. */
#define BM_PXP_HW_PXP_HIST32_PARAM6_RSVD10 (0x00C00000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM6_RSVD10. */
#define BS_PXP_HW_PXP_HIST32_PARAM6_RSVD10 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM6_RSVD10. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM6_RSVD10 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM6_RSVD10(x) (HW_PXP_HW_PXP_HIST32_PARAM6(x).B.RSVD10)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM6, field VALUE27[29:24] (RW)
 *
 * GRAY27 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM6_VALUE27 (24U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM6_VALUE27. */
#define BM_PXP_HW_PXP_HIST32_PARAM6_VALUE27 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM6_VALUE27. */
#define BS_PXP_HW_PXP_HIST32_PARAM6_VALUE27 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM6_VALUE27. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM6_VALUE27 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM6_VALUE27(x) (HW_PXP_HW_PXP_HIST32_PARAM6(x).B.VALUE27)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM6_VALUE27. */
#define BF_PXP_HW_PXP_HIST32_PARAM6_VALUE27(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM6_VALUE27) & BM_PXP_HW_PXP_HIST32_PARAM6_VALUE27)

/*! @brief Set the VALUE27 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM6_VALUE27(x, v) (HW_PXP_HW_PXP_HIST32_PARAM6_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM6_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM6_VALUE27) | BF_PXP_HW_PXP_HIST32_PARAM6_VALUE27(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM6, field RSVD11[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM6_RSVD11 (30U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM6_RSVD11. */
#define BM_PXP_HW_PXP_HIST32_PARAM6_RSVD11 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM6_RSVD11. */
#define BS_PXP_HW_PXP_HIST32_PARAM6_RSVD11 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM6_RSVD11. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM6_RSVD11 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM6_RSVD11(x) (HW_PXP_HW_PXP_HIST32_PARAM6(x).B.RSVD11)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HIST32_PARAM7 - 32-level Histogram Parameter 3 Register.
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HIST32_PARAM7 - 32-level Histogram Parameter 3 Register. (RW)
 *
 * Reset value: 0x0F0E0D0CU
 *
 * This register specifies four of the valid values for a 32-level histogram. If
 * all pixels in a bitmap match the 32-level histogram values, STATUS[3] will be
 * set at the end of frame processing. All comparator values should be
 * programmed such that they are consistent with the PANEL_MODE control field.
 */
typedef union _hw_pxp_hw_pxp_hist32_param7
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_hist32_param7_bitfields
    {
        uint32_t VALUE28 : 6;          /*!< [5:0]  */
        uint32_t RSVD2 : 2;            /*!< [7:6]  */
        uint32_t VALUE29 : 6;          /*!< [13:8]  */
        uint32_t RSVD13 : 2;           /*!< [15:14]  */
        uint32_t VALUE30 : 6;          /*!< [21:16]  */
        uint32_t RSVD14 : 2;           /*!< [23:22]  */
        uint32_t VALUE31 : 6;          /*!< [29:24]  */
        uint32_t RSVD15 : 2;           /*!< [31:30]  */
    } B;
} hw_pxp_hw_pxp_hist32_param7_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HIST32_PARAM7 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HIST32_PARAM7_ADDR(x) ((uintptr_t)(x) + 0x2BF0U)

#define HW_PXP_HW_PXP_HIST32_PARAM7(x) (*(__IO hw_pxp_hw_pxp_hist32_param7_t *) HW_PXP_HW_PXP_HIST32_PARAM7_ADDR(x))
#define HW_PXP_HW_PXP_HIST32_PARAM7_RD(x) (HW_PXP_HW_PXP_HIST32_PARAM7(x).U)
#define HW_PXP_HW_PXP_HIST32_PARAM7_WR(x, v) (HW_PXP_HW_PXP_HIST32_PARAM7(x).U = (v))
#define HW_PXP_HW_PXP_HIST32_PARAM7_SET(x, v) (HW_PXP_HW_PXP_HIST32_PARAM7_WR(x, HW_PXP_HW_PXP_HIST32_PARAM7_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HIST32_PARAM7_CLR(x, v) (HW_PXP_HW_PXP_HIST32_PARAM7_WR(x, HW_PXP_HW_PXP_HIST32_PARAM7_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HIST32_PARAM7_TOG(x, v) (HW_PXP_HW_PXP_HIST32_PARAM7_WR(x, HW_PXP_HW_PXP_HIST32_PARAM7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HIST32_PARAM7 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM7, field VALUE28[5:0] (RW)
 *
 * GRAY28 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM7_VALUE28 (0U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM7_VALUE28. */
#define BM_PXP_HW_PXP_HIST32_PARAM7_VALUE28 (0x0000003FU) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM7_VALUE28. */
#define BS_PXP_HW_PXP_HIST32_PARAM7_VALUE28 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM7_VALUE28. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM7_VALUE28 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM7_VALUE28(x) (HW_PXP_HW_PXP_HIST32_PARAM7(x).B.VALUE28)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM7_VALUE28. */
#define BF_PXP_HW_PXP_HIST32_PARAM7_VALUE28(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM7_VALUE28) & BM_PXP_HW_PXP_HIST32_PARAM7_VALUE28)

/*! @brief Set the VALUE28 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM7_VALUE28(x, v) (HW_PXP_HW_PXP_HIST32_PARAM7_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM7_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM7_VALUE28) | BF_PXP_HW_PXP_HIST32_PARAM7_VALUE28(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM7, field RSVD2[7:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM7_RSVD2 (6U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM7_RSVD2. */
#define BM_PXP_HW_PXP_HIST32_PARAM7_RSVD2 (0x000000C0U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM7_RSVD2. */
#define BS_PXP_HW_PXP_HIST32_PARAM7_RSVD2 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM7_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM7_RSVD2 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM7_RSVD2(x) (HW_PXP_HW_PXP_HIST32_PARAM7(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM7, field VALUE29[13:8] (RW)
 *
 * GRAY29 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM7_VALUE29 (8U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM7_VALUE29. */
#define BM_PXP_HW_PXP_HIST32_PARAM7_VALUE29 (0x00003F00U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM7_VALUE29. */
#define BS_PXP_HW_PXP_HIST32_PARAM7_VALUE29 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM7_VALUE29. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM7_VALUE29 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM7_VALUE29(x) (HW_PXP_HW_PXP_HIST32_PARAM7(x).B.VALUE29)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM7_VALUE29. */
#define BF_PXP_HW_PXP_HIST32_PARAM7_VALUE29(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM7_VALUE29) & BM_PXP_HW_PXP_HIST32_PARAM7_VALUE29)

/*! @brief Set the VALUE29 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM7_VALUE29(x, v) (HW_PXP_HW_PXP_HIST32_PARAM7_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM7_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM7_VALUE29) | BF_PXP_HW_PXP_HIST32_PARAM7_VALUE29(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM7, field RSVD13[15:14] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM7_RSVD13 (14U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM7_RSVD13. */
#define BM_PXP_HW_PXP_HIST32_PARAM7_RSVD13 (0x0000C000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM7_RSVD13. */
#define BS_PXP_HW_PXP_HIST32_PARAM7_RSVD13 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM7_RSVD13. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM7_RSVD13 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM7_RSVD13(x) (HW_PXP_HW_PXP_HIST32_PARAM7(x).B.RSVD13)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM7, field VALUE30[21:16] (RW)
 *
 * GRAY30 value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM7_VALUE30 (16U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM7_VALUE30. */
#define BM_PXP_HW_PXP_HIST32_PARAM7_VALUE30 (0x003F0000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM7_VALUE30. */
#define BS_PXP_HW_PXP_HIST32_PARAM7_VALUE30 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM7_VALUE30. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM7_VALUE30 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM7_VALUE30(x) (HW_PXP_HW_PXP_HIST32_PARAM7(x).B.VALUE30)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM7_VALUE30. */
#define BF_PXP_HW_PXP_HIST32_PARAM7_VALUE30(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM7_VALUE30) & BM_PXP_HW_PXP_HIST32_PARAM7_VALUE30)

/*! @brief Set the VALUE30 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM7_VALUE30(x, v) (HW_PXP_HW_PXP_HIST32_PARAM7_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM7_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM7_VALUE30) | BF_PXP_HW_PXP_HIST32_PARAM7_VALUE30(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM7, field RSVD14[23:22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM7_RSVD14 (22U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM7_RSVD14. */
#define BM_PXP_HW_PXP_HIST32_PARAM7_RSVD14 (0x00C00000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM7_RSVD14. */
#define BS_PXP_HW_PXP_HIST32_PARAM7_RSVD14 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM7_RSVD14. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM7_RSVD14 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM7_RSVD14(x) (HW_PXP_HW_PXP_HIST32_PARAM7(x).B.RSVD14)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM7, field VALUE31[29:24] (RW)
 *
 * GRAY31 (White) value for 32-level histogram
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM7_VALUE31 (24U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM7_VALUE31. */
#define BM_PXP_HW_PXP_HIST32_PARAM7_VALUE31 (0x3F000000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM7_VALUE31. */
#define BS_PXP_HW_PXP_HIST32_PARAM7_VALUE31 (6U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM7_VALUE31. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM7_VALUE31 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM7_VALUE31(x) (HW_PXP_HW_PXP_HIST32_PARAM7(x).B.VALUE31)

/*! @brief Format value for bitfield PXP_HW_PXP_HIST32_PARAM7_VALUE31. */
#define BF_PXP_HW_PXP_HIST32_PARAM7_VALUE31(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HIST32_PARAM7_VALUE31) & BM_PXP_HW_PXP_HIST32_PARAM7_VALUE31)

/*! @brief Set the VALUE31 field to a new value. */
#define BW_PXP_HW_PXP_HIST32_PARAM7_VALUE31(x, v) (HW_PXP_HW_PXP_HIST32_PARAM7_WR(x, (HW_PXP_HW_PXP_HIST32_PARAM7_RD(x) & ~BM_PXP_HW_PXP_HIST32_PARAM7_VALUE31) | BF_PXP_HW_PXP_HIST32_PARAM7_VALUE31(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HIST32_PARAM7, field RSVD15[31:30] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HIST32_PARAM7_RSVD15 (30U) /*!< Bit position for PXP_HW_PXP_HIST32_PARAM7_RSVD15. */
#define BM_PXP_HW_PXP_HIST32_PARAM7_RSVD15 (0xC0000000U) /*!< Bit mask for PXP_HW_PXP_HIST32_PARAM7_RSVD15. */
#define BS_PXP_HW_PXP_HIST32_PARAM7_RSVD15 (2U) /*!< Bit field size in bits for PXP_HW_PXP_HIST32_PARAM7_RSVD15. */

/*! @brief Read current value of the PXP_HW_PXP_HIST32_PARAM7_RSVD15 field. */
#define BR_PXP_HW_PXP_HIST32_PARAM7_RSVD15(x) (HW_PXP_HW_PXP_HIST32_PARAM7(x).B.RSVD15)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_COMP_CTRL -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_COMP_CTRL -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the control bits for the pxp compression sub-block.
 * HW_PXP_COMP_CTRL: 0x2C00 HW_PXP_COMP_CTRL_SET: 0x2C04 HW_PXP_COMP_CTRL_CLR:
 * 0x2C08 HW_PXP_COMP_CTRL_TOG: 0x2C0C EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_comp_ctrl
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_comp_ctrl_bitfields
    {
        uint32_t START : 1;            /*!< [0]  */
        uint32_t RSVD1 : 7;            /*!< [7:1]  */
        uint32_t SW_RESET : 1;         /*!< [8]  */
        uint32_t RSVD0 : 23;           /*!< [31:9]  */
    } B;
} hw_pxp_hw_pxp_comp_ctrl_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_COMP_CTRL register
 */
/*@{*/
#define HW_PXP_HW_PXP_COMP_CTRL_ADDR(x) ((uintptr_t)(x) + 0x2C00U)

#define HW_PXP_HW_PXP_COMP_CTRL(x) (*(__IO hw_pxp_hw_pxp_comp_ctrl_t *) HW_PXP_HW_PXP_COMP_CTRL_ADDR(x))
#define HW_PXP_HW_PXP_COMP_CTRL_RD(x) (HW_PXP_HW_PXP_COMP_CTRL(x).U)
#define HW_PXP_HW_PXP_COMP_CTRL_WR(x, v) (HW_PXP_HW_PXP_COMP_CTRL(x).U = (v))
#define HW_PXP_HW_PXP_COMP_CTRL_SET(x, v) (HW_PXP_HW_PXP_COMP_CTRL_WR(x, HW_PXP_HW_PXP_COMP_CTRL_RD(x) |  (v)))
#define HW_PXP_HW_PXP_COMP_CTRL_CLR(x, v) (HW_PXP_HW_PXP_COMP_CTRL_WR(x, HW_PXP_HW_PXP_COMP_CTRL_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_COMP_CTRL_TOG(x, v) (HW_PXP_HW_PXP_COMP_CTRL_WR(x, HW_PXP_HW_PXP_COMP_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_COMP_CTRL bitfields
 */

/*!
 * @name Register PXP_HW_PXP_COMP_CTRL, field START[0] (RW)
 *
 * Write to 1 to start operation, self-clear
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_CTRL_START (0U) /*!< Bit position for PXP_HW_PXP_COMP_CTRL_START. */
#define BM_PXP_HW_PXP_COMP_CTRL_START (0x00000001U) /*!< Bit mask for PXP_HW_PXP_COMP_CTRL_START. */
#define BS_PXP_HW_PXP_COMP_CTRL_START (1U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_CTRL_START. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_CTRL_START field. */
#define BR_PXP_HW_PXP_COMP_CTRL_START(x) (HW_PXP_HW_PXP_COMP_CTRL(x).B.START)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_CTRL_START. */
#define BF_PXP_HW_PXP_COMP_CTRL_START(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_CTRL_START) & BM_PXP_HW_PXP_COMP_CTRL_START)

/*! @brief Set the START field to a new value. */
#define BW_PXP_HW_PXP_COMP_CTRL_START(x, v) (HW_PXP_HW_PXP_COMP_CTRL_WR(x, (HW_PXP_HW_PXP_COMP_CTRL_RD(x) & ~BM_PXP_HW_PXP_COMP_CTRL_START) | BF_PXP_HW_PXP_COMP_CTRL_START(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_CTRL, field RSVD1[7:1] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_CTRL_RSVD1 (1U) /*!< Bit position for PXP_HW_PXP_COMP_CTRL_RSVD1. */
#define BM_PXP_HW_PXP_COMP_CTRL_RSVD1 (0x000000FEU) /*!< Bit mask for PXP_HW_PXP_COMP_CTRL_RSVD1. */
#define BS_PXP_HW_PXP_COMP_CTRL_RSVD1 (7U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_CTRL_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_CTRL_RSVD1 field. */
#define BR_PXP_HW_PXP_COMP_CTRL_RSVD1(x) (HW_PXP_HW_PXP_COMP_CTRL(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_CTRL, field SW_RESET[8] (RW)
 *
 * Write to 1 to do a software reset to the engine, self-clear.
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_CTRL_SW_RESET (8U) /*!< Bit position for PXP_HW_PXP_COMP_CTRL_SW_RESET. */
#define BM_PXP_HW_PXP_COMP_CTRL_SW_RESET (0x00000100U) /*!< Bit mask for PXP_HW_PXP_COMP_CTRL_SW_RESET. */
#define BS_PXP_HW_PXP_COMP_CTRL_SW_RESET (1U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_CTRL_SW_RESET. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_CTRL_SW_RESET field. */
#define BR_PXP_HW_PXP_COMP_CTRL_SW_RESET(x) (HW_PXP_HW_PXP_COMP_CTRL(x).B.SW_RESET)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_CTRL_SW_RESET. */
#define BF_PXP_HW_PXP_COMP_CTRL_SW_RESET(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_CTRL_SW_RESET) & BM_PXP_HW_PXP_COMP_CTRL_SW_RESET)

/*! @brief Set the SW_RESET field to a new value. */
#define BW_PXP_HW_PXP_COMP_CTRL_SW_RESET(x, v) (HW_PXP_HW_PXP_COMP_CTRL_WR(x, (HW_PXP_HW_PXP_COMP_CTRL_RD(x) & ~BM_PXP_HW_PXP_COMP_CTRL_SW_RESET) | BF_PXP_HW_PXP_COMP_CTRL_SW_RESET(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_CTRL, field RSVD0[31:9] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_CTRL_RSVD0 (9U) /*!< Bit position for PXP_HW_PXP_COMP_CTRL_RSVD0. */
#define BM_PXP_HW_PXP_COMP_CTRL_RSVD0 (0xFFFFFE00U) /*!< Bit mask for PXP_HW_PXP_COMP_CTRL_RSVD0. */
#define BS_PXP_HW_PXP_COMP_CTRL_RSVD0 (23U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_CTRL_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_CTRL_RSVD0 field. */
#define BR_PXP_HW_PXP_COMP_CTRL_RSVD0(x) (HW_PXP_HW_PXP_COMP_CTRL(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_COMP_FORMAT0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_COMP_FORMAT0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the format bits for the pxp compression sub-block.
 * HW_PXP_COMP_FORMAT0: 0x2C10 HW_PXP_COMP_FORMAT0_SET: 0x2C14
 * HW_PXP_COMP_FORMAT0_CLR: 0x2C18 HW_PXP_COMP_FORMAT0_TOG: 0x2C1C EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_comp_format0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_comp_format0_bitfields
    {
        uint32_t FLAG_32B : 1;         /*!< [0]  */
        uint32_t RSVD3 : 3;            /*!< [3:1]  */
        uint32_t FIELD_NUM : 2;        /*!< [5:4]  */
        uint32_t RSVD2 : 2;            /*!< [7:6]  */
        uint32_t MASK_INDEX : 2;       /*!< [9:8]  */
        uint32_t RSVD1 : 6;            /*!< [15:10]  */
        uint32_t PIXEL_PITCH_64B : 10; /*!< [25:16]  */
        uint32_t ERR_PRONE : 1;        /*!< [26]  */
        uint32_t FIFOFULL : 1;         /*!< [27]  */
        uint32_t RSVD0 : 4;            /*!< [31:28]  */
    } B;
} hw_pxp_hw_pxp_comp_format0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_COMP_FORMAT0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_COMP_FORMAT0_ADDR(x) ((uintptr_t)(x) + 0x2C10U)

#define HW_PXP_HW_PXP_COMP_FORMAT0(x) (*(__IO hw_pxp_hw_pxp_comp_format0_t *) HW_PXP_HW_PXP_COMP_FORMAT0_ADDR(x))
#define HW_PXP_HW_PXP_COMP_FORMAT0_RD(x) (HW_PXP_HW_PXP_COMP_FORMAT0(x).U)
#define HW_PXP_HW_PXP_COMP_FORMAT0_WR(x, v) (HW_PXP_HW_PXP_COMP_FORMAT0(x).U = (v))
#define HW_PXP_HW_PXP_COMP_FORMAT0_SET(x, v) (HW_PXP_HW_PXP_COMP_FORMAT0_WR(x, HW_PXP_HW_PXP_COMP_FORMAT0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_COMP_FORMAT0_CLR(x, v) (HW_PXP_HW_PXP_COMP_FORMAT0_WR(x, HW_PXP_HW_PXP_COMP_FORMAT0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_COMP_FORMAT0_TOG(x, v) (HW_PXP_HW_PXP_COMP_FORMAT0_WR(x, HW_PXP_HW_PXP_COMP_FORMAT0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_COMP_FORMAT0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT0, field FLAG_32B[0] (RW)
 *
 * 1 indicate 32-bit for one pixel, 0 for 16-bit
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT0_FLAG_32B (0U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT0_FLAG_32B. */
#define BM_PXP_HW_PXP_COMP_FORMAT0_FLAG_32B (0x00000001U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT0_FLAG_32B. */
#define BS_PXP_HW_PXP_COMP_FORMAT0_FLAG_32B (1U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT0_FLAG_32B. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT0_FLAG_32B field. */
#define BR_PXP_HW_PXP_COMP_FORMAT0_FLAG_32B(x) (HW_PXP_HW_PXP_COMP_FORMAT0(x).B.FLAG_32B)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_FORMAT0_FLAG_32B. */
#define BF_PXP_HW_PXP_COMP_FORMAT0_FLAG_32B(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_FORMAT0_FLAG_32B) & BM_PXP_HW_PXP_COMP_FORMAT0_FLAG_32B)

/*! @brief Set the FLAG_32B field to a new value. */
#define BW_PXP_HW_PXP_COMP_FORMAT0_FLAG_32B(x, v) (HW_PXP_HW_PXP_COMP_FORMAT0_WR(x, (HW_PXP_HW_PXP_COMP_FORMAT0_RD(x) & ~BM_PXP_HW_PXP_COMP_FORMAT0_FLAG_32B) | BF_PXP_HW_PXP_COMP_FORMAT0_FLAG_32B(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT0, field RSVD3[3:1] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT0_RSVD3 (1U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT0_RSVD3. */
#define BM_PXP_HW_PXP_COMP_FORMAT0_RSVD3 (0x0000000EU) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT0_RSVD3. */
#define BS_PXP_HW_PXP_COMP_FORMAT0_RSVD3 (3U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT0_RSVD3. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT0_RSVD3 field. */
#define BR_PXP_HW_PXP_COMP_FORMAT0_RSVD3(x) (HW_PXP_HW_PXP_COMP_FORMAT0(x).B.RSVD3)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT0, field FIELD_NUM[5:4] (RW)
 *
 * indicate how many fields in one pixel,0 for only A;3 for ABCD
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM (4U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM. */
#define BM_PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM (0x00000030U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM. */
#define BS_PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM (2U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM field. */
#define BR_PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM(x) (HW_PXP_HW_PXP_COMP_FORMAT0(x).B.FIELD_NUM)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM. */
#define BF_PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM) & BM_PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM)

/*! @brief Set the FIELD_NUM field to a new value. */
#define BW_PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM(x, v) (HW_PXP_HW_PXP_COMP_FORMAT0_WR(x, (HW_PXP_HW_PXP_COMP_FORMAT0_RD(x) & ~BM_PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM) | BF_PXP_HW_PXP_COMP_FORMAT0_FIELD_NUM(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT0, field RSVD2[7:6] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT0_RSVD2 (6U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT0_RSVD2. */
#define BM_PXP_HW_PXP_COMP_FORMAT0_RSVD2 (0x000000C0U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT0_RSVD2. */
#define BS_PXP_HW_PXP_COMP_FORMAT0_RSVD2 (2U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT0_RSVD2. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT0_RSVD2 field. */
#define BR_PXP_HW_PXP_COMP_FORMAT0_RSVD2(x) (HW_PXP_HW_PXP_COMP_FORMAT0(x).B.RSVD2)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT0, field MASK_INDEX[9:8] (RW)
 *
 * which field is the mask,0 for A, 3 for D
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX (8U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX. */
#define BM_PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX (0x00000300U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX. */
#define BS_PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX (2U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX field. */
#define BR_PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX(x) (HW_PXP_HW_PXP_COMP_FORMAT0(x).B.MASK_INDEX)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX. */
#define BF_PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX) & BM_PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX)

/*! @brief Set the MASK_INDEX field to a new value. */
#define BW_PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX(x, v) (HW_PXP_HW_PXP_COMP_FORMAT0_WR(x, (HW_PXP_HW_PXP_COMP_FORMAT0_RD(x) & ~BM_PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX) | BF_PXP_HW_PXP_COMP_FORMAT0_MASK_INDEX(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT0, field RSVD1[15:10] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT0_RSVD1 (10U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT0_RSVD1. */
#define BM_PXP_HW_PXP_COMP_FORMAT0_RSVD1 (0x0000FC00U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT0_RSVD1. */
#define BS_PXP_HW_PXP_COMP_FORMAT0_RSVD1 (6U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT0_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT0_RSVD1 field. */
#define BR_PXP_HW_PXP_COMP_FORMAT0_RSVD1(x) (HW_PXP_HW_PXP_COMP_FORMAT0(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT0, field PIXEL_PITCH_64B[25:16] (RW)
 *
 * extend each line to be 64-bit aligned
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B (16U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B. */
#define BM_PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B (0x03FF0000U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B. */
#define BS_PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B (10U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B field. */
#define BR_PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B(x) (HW_PXP_HW_PXP_COMP_FORMAT0(x).B.PIXEL_PITCH_64B)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B. */
#define BF_PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B) & BM_PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B)

/*! @brief Set the PIXEL_PITCH_64B field to a new value. */
#define BW_PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B(x, v) (HW_PXP_HW_PXP_COMP_FORMAT0_WR(x, (HW_PXP_HW_PXP_COMP_FORMAT0_RD(x) & ~BM_PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B) | BF_PXP_HW_PXP_COMP_FORMAT0_PIXEL_PITCH_64B(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT0, field ERR_PRONE[26] (RO)
 *
 * step1 write fifo full. If detected, this bit is 1, there is data error in
 * current frame.
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT0_ERR_PRONE (26U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT0_ERR_PRONE. */
#define BM_PXP_HW_PXP_COMP_FORMAT0_ERR_PRONE (0x04000000U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT0_ERR_PRONE. */
#define BS_PXP_HW_PXP_COMP_FORMAT0_ERR_PRONE (1U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT0_ERR_PRONE. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT0_ERR_PRONE field. */
#define BR_PXP_HW_PXP_COMP_FORMAT0_ERR_PRONE(x) (HW_PXP_HW_PXP_COMP_FORMAT0(x).B.ERR_PRONE)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT0, field FIFOFULL[27] (RO)
 *
 * step1 write fifo full
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT0_FIFOFULL (27U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT0_FIFOFULL. */
#define BM_PXP_HW_PXP_COMP_FORMAT0_FIFOFULL (0x08000000U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT0_FIFOFULL. */
#define BS_PXP_HW_PXP_COMP_FORMAT0_FIFOFULL (1U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT0_FIFOFULL. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT0_FIFOFULL field. */
#define BR_PXP_HW_PXP_COMP_FORMAT0_FIFOFULL(x) (HW_PXP_HW_PXP_COMP_FORMAT0(x).B.FIFOFULL)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT0, field RSVD0[31:28] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT0_RSVD0 (28U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT0_RSVD0. */
#define BM_PXP_HW_PXP_COMP_FORMAT0_RSVD0 (0xF0000000U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT0_RSVD0. */
#define BS_PXP_HW_PXP_COMP_FORMAT0_RSVD0 (4U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT0_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT0_RSVD0 field. */
#define BR_PXP_HW_PXP_COMP_FORMAT0_RSVD0(x) (HW_PXP_HW_PXP_COMP_FORMAT0(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_COMP_FORMAT1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_COMP_FORMAT1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the format bits for the pxp compression sub-block.
 * EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_comp_format1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_comp_format1_bitfields
    {
        uint32_t A_OFFSET : 5;         /*!< [4:0]  */
        uint32_t A_LEN : 3;            /*!< [7:5]  */
        uint32_t B_OFFSET : 5;         /*!< [12:8]  */
        uint32_t B_LEN : 3;            /*!< [15:13]  */
        uint32_t C_OFFSET : 5;         /*!< [20:16]  */
        uint32_t C_LEN : 3;            /*!< [23:21]  */
        uint32_t D_OFFSET : 5;         /*!< [28:24]  */
        uint32_t D_LEN : 3;            /*!< [31:29]  */
    } B;
} hw_pxp_hw_pxp_comp_format1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_COMP_FORMAT1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_COMP_FORMAT1_ADDR(x) ((uintptr_t)(x) + 0x2C20U)

#define HW_PXP_HW_PXP_COMP_FORMAT1(x) (*(__IO hw_pxp_hw_pxp_comp_format1_t *) HW_PXP_HW_PXP_COMP_FORMAT1_ADDR(x))
#define HW_PXP_HW_PXP_COMP_FORMAT1_RD(x) (HW_PXP_HW_PXP_COMP_FORMAT1(x).U)
#define HW_PXP_HW_PXP_COMP_FORMAT1_WR(x, v) (HW_PXP_HW_PXP_COMP_FORMAT1(x).U = (v))
#define HW_PXP_HW_PXP_COMP_FORMAT1_SET(x, v) (HW_PXP_HW_PXP_COMP_FORMAT1_WR(x, HW_PXP_HW_PXP_COMP_FORMAT1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_COMP_FORMAT1_CLR(x, v) (HW_PXP_HW_PXP_COMP_FORMAT1_WR(x, HW_PXP_HW_PXP_COMP_FORMAT1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_COMP_FORMAT1_TOG(x, v) (HW_PXP_HW_PXP_COMP_FORMAT1_WR(x, HW_PXP_HW_PXP_COMP_FORMAT1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_COMP_FORMAT1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT1, field A_OFFSET[4:0] (RW)
 *
 * offset for field A, 0 means A start from bit0
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT1_A_OFFSET (0U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT1_A_OFFSET. */
#define BM_PXP_HW_PXP_COMP_FORMAT1_A_OFFSET (0x0000001FU) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT1_A_OFFSET. */
#define BS_PXP_HW_PXP_COMP_FORMAT1_A_OFFSET (5U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT1_A_OFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT1_A_OFFSET field. */
#define BR_PXP_HW_PXP_COMP_FORMAT1_A_OFFSET(x) (HW_PXP_HW_PXP_COMP_FORMAT1(x).B.A_OFFSET)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_FORMAT1_A_OFFSET. */
#define BF_PXP_HW_PXP_COMP_FORMAT1_A_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_FORMAT1_A_OFFSET) & BM_PXP_HW_PXP_COMP_FORMAT1_A_OFFSET)

/*! @brief Set the A_OFFSET field to a new value. */
#define BW_PXP_HW_PXP_COMP_FORMAT1_A_OFFSET(x, v) (HW_PXP_HW_PXP_COMP_FORMAT1_WR(x, (HW_PXP_HW_PXP_COMP_FORMAT1_RD(x) & ~BM_PXP_HW_PXP_COMP_FORMAT1_A_OFFSET) | BF_PXP_HW_PXP_COMP_FORMAT1_A_OFFSET(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT1, field A_LEN[7:5] (RW)
 *
 * length of field A, 0 for 1 byte, 7 for 8 bytes, length of the field plus the
 * length of RLE(*_runlen) should not more than 16-bit
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT1_A_LEN (5U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT1_A_LEN. */
#define BM_PXP_HW_PXP_COMP_FORMAT1_A_LEN (0x000000E0U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT1_A_LEN. */
#define BS_PXP_HW_PXP_COMP_FORMAT1_A_LEN (3U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT1_A_LEN. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT1_A_LEN field. */
#define BR_PXP_HW_PXP_COMP_FORMAT1_A_LEN(x) (HW_PXP_HW_PXP_COMP_FORMAT1(x).B.A_LEN)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_FORMAT1_A_LEN. */
#define BF_PXP_HW_PXP_COMP_FORMAT1_A_LEN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_FORMAT1_A_LEN) & BM_PXP_HW_PXP_COMP_FORMAT1_A_LEN)

/*! @brief Set the A_LEN field to a new value. */
#define BW_PXP_HW_PXP_COMP_FORMAT1_A_LEN(x, v) (HW_PXP_HW_PXP_COMP_FORMAT1_WR(x, (HW_PXP_HW_PXP_COMP_FORMAT1_RD(x) & ~BM_PXP_HW_PXP_COMP_FORMAT1_A_LEN) | BF_PXP_HW_PXP_COMP_FORMAT1_A_LEN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT1, field B_OFFSET[12:8] (RW)
 *
 * offset for field B, 0 means B start from bit0
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT1_B_OFFSET (8U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT1_B_OFFSET. */
#define BM_PXP_HW_PXP_COMP_FORMAT1_B_OFFSET (0x00001F00U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT1_B_OFFSET. */
#define BS_PXP_HW_PXP_COMP_FORMAT1_B_OFFSET (5U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT1_B_OFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT1_B_OFFSET field. */
#define BR_PXP_HW_PXP_COMP_FORMAT1_B_OFFSET(x) (HW_PXP_HW_PXP_COMP_FORMAT1(x).B.B_OFFSET)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_FORMAT1_B_OFFSET. */
#define BF_PXP_HW_PXP_COMP_FORMAT1_B_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_FORMAT1_B_OFFSET) & BM_PXP_HW_PXP_COMP_FORMAT1_B_OFFSET)

/*! @brief Set the B_OFFSET field to a new value. */
#define BW_PXP_HW_PXP_COMP_FORMAT1_B_OFFSET(x, v) (HW_PXP_HW_PXP_COMP_FORMAT1_WR(x, (HW_PXP_HW_PXP_COMP_FORMAT1_RD(x) & ~BM_PXP_HW_PXP_COMP_FORMAT1_B_OFFSET) | BF_PXP_HW_PXP_COMP_FORMAT1_B_OFFSET(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT1, field B_LEN[15:13] (RW)
 *
 * length of field B, 0 for 1 byte, 7 for 8 bytes, length of the field plus the
 * length of RLE(*_runlen) should not more than 16-bit
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT1_B_LEN (13U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT1_B_LEN. */
#define BM_PXP_HW_PXP_COMP_FORMAT1_B_LEN (0x0000E000U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT1_B_LEN. */
#define BS_PXP_HW_PXP_COMP_FORMAT1_B_LEN (3U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT1_B_LEN. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT1_B_LEN field. */
#define BR_PXP_HW_PXP_COMP_FORMAT1_B_LEN(x) (HW_PXP_HW_PXP_COMP_FORMAT1(x).B.B_LEN)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_FORMAT1_B_LEN. */
#define BF_PXP_HW_PXP_COMP_FORMAT1_B_LEN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_FORMAT1_B_LEN) & BM_PXP_HW_PXP_COMP_FORMAT1_B_LEN)

/*! @brief Set the B_LEN field to a new value. */
#define BW_PXP_HW_PXP_COMP_FORMAT1_B_LEN(x, v) (HW_PXP_HW_PXP_COMP_FORMAT1_WR(x, (HW_PXP_HW_PXP_COMP_FORMAT1_RD(x) & ~BM_PXP_HW_PXP_COMP_FORMAT1_B_LEN) | BF_PXP_HW_PXP_COMP_FORMAT1_B_LEN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT1, field C_OFFSET[20:16] (RW)
 *
 * offset for field C, 0 means C start from bit0
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT1_C_OFFSET (16U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT1_C_OFFSET. */
#define BM_PXP_HW_PXP_COMP_FORMAT1_C_OFFSET (0x001F0000U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT1_C_OFFSET. */
#define BS_PXP_HW_PXP_COMP_FORMAT1_C_OFFSET (5U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT1_C_OFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT1_C_OFFSET field. */
#define BR_PXP_HW_PXP_COMP_FORMAT1_C_OFFSET(x) (HW_PXP_HW_PXP_COMP_FORMAT1(x).B.C_OFFSET)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_FORMAT1_C_OFFSET. */
#define BF_PXP_HW_PXP_COMP_FORMAT1_C_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_FORMAT1_C_OFFSET) & BM_PXP_HW_PXP_COMP_FORMAT1_C_OFFSET)

/*! @brief Set the C_OFFSET field to a new value. */
#define BW_PXP_HW_PXP_COMP_FORMAT1_C_OFFSET(x, v) (HW_PXP_HW_PXP_COMP_FORMAT1_WR(x, (HW_PXP_HW_PXP_COMP_FORMAT1_RD(x) & ~BM_PXP_HW_PXP_COMP_FORMAT1_C_OFFSET) | BF_PXP_HW_PXP_COMP_FORMAT1_C_OFFSET(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT1, field C_LEN[23:21] (RW)
 *
 * length of field C, 0 for 1 byte, 7 for 8 bytes, length of the field plus the
 * length of RLE(*_runlen) should not more than 16-bit
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT1_C_LEN (21U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT1_C_LEN. */
#define BM_PXP_HW_PXP_COMP_FORMAT1_C_LEN (0x00E00000U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT1_C_LEN. */
#define BS_PXP_HW_PXP_COMP_FORMAT1_C_LEN (3U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT1_C_LEN. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT1_C_LEN field. */
#define BR_PXP_HW_PXP_COMP_FORMAT1_C_LEN(x) (HW_PXP_HW_PXP_COMP_FORMAT1(x).B.C_LEN)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_FORMAT1_C_LEN. */
#define BF_PXP_HW_PXP_COMP_FORMAT1_C_LEN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_FORMAT1_C_LEN) & BM_PXP_HW_PXP_COMP_FORMAT1_C_LEN)

/*! @brief Set the C_LEN field to a new value. */
#define BW_PXP_HW_PXP_COMP_FORMAT1_C_LEN(x, v) (HW_PXP_HW_PXP_COMP_FORMAT1_WR(x, (HW_PXP_HW_PXP_COMP_FORMAT1_RD(x) & ~BM_PXP_HW_PXP_COMP_FORMAT1_C_LEN) | BF_PXP_HW_PXP_COMP_FORMAT1_C_LEN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT1, field D_OFFSET[28:24] (RW)
 *
 * offset for field D, 0 means D start from bit0
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT1_D_OFFSET (24U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT1_D_OFFSET. */
#define BM_PXP_HW_PXP_COMP_FORMAT1_D_OFFSET (0x1F000000U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT1_D_OFFSET. */
#define BS_PXP_HW_PXP_COMP_FORMAT1_D_OFFSET (5U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT1_D_OFFSET. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT1_D_OFFSET field. */
#define BR_PXP_HW_PXP_COMP_FORMAT1_D_OFFSET(x) (HW_PXP_HW_PXP_COMP_FORMAT1(x).B.D_OFFSET)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_FORMAT1_D_OFFSET. */
#define BF_PXP_HW_PXP_COMP_FORMAT1_D_OFFSET(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_FORMAT1_D_OFFSET) & BM_PXP_HW_PXP_COMP_FORMAT1_D_OFFSET)

/*! @brief Set the D_OFFSET field to a new value. */
#define BW_PXP_HW_PXP_COMP_FORMAT1_D_OFFSET(x, v) (HW_PXP_HW_PXP_COMP_FORMAT1_WR(x, (HW_PXP_HW_PXP_COMP_FORMAT1_RD(x) & ~BM_PXP_HW_PXP_COMP_FORMAT1_D_OFFSET) | BF_PXP_HW_PXP_COMP_FORMAT1_D_OFFSET(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT1, field D_LEN[31:29] (RW)
 *
 * length of field D, 0 for 1 byte, 7 for 8 bytes, length of the field plus the
 * length of RLE(*_runlen) should not more than 16-bit
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT1_D_LEN (29U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT1_D_LEN. */
#define BM_PXP_HW_PXP_COMP_FORMAT1_D_LEN (0xE0000000U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT1_D_LEN. */
#define BS_PXP_HW_PXP_COMP_FORMAT1_D_LEN (3U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT1_D_LEN. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT1_D_LEN field. */
#define BR_PXP_HW_PXP_COMP_FORMAT1_D_LEN(x) (HW_PXP_HW_PXP_COMP_FORMAT1(x).B.D_LEN)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_FORMAT1_D_LEN. */
#define BF_PXP_HW_PXP_COMP_FORMAT1_D_LEN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_FORMAT1_D_LEN) & BM_PXP_HW_PXP_COMP_FORMAT1_D_LEN)

/*! @brief Set the D_LEN field to a new value. */
#define BW_PXP_HW_PXP_COMP_FORMAT1_D_LEN(x, v) (HW_PXP_HW_PXP_COMP_FORMAT1_WR(x, (HW_PXP_HW_PXP_COMP_FORMAT1_RD(x) & ~BM_PXP_HW_PXP_COMP_FORMAT1_D_LEN) | BF_PXP_HW_PXP_COMP_FORMAT1_D_LEN(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_COMP_FORMAT2 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_COMP_FORMAT2 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the format bits for the pxp compression sub-block.
 * EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_comp_format2
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_comp_format2_bitfields
    {
        uint32_t A_RUNLEN : 4;         /*!< [3:0]  */
        uint32_t B_RUNLEN : 4;         /*!< [7:4]  */
        uint32_t C_RUNLEN : 4;         /*!< [11:8]  */
        uint32_t D_RUNLEN : 4;         /*!< [15:12]  */
        uint32_t RSVD : 16;            /*!< [31:16]  */
    } B;
} hw_pxp_hw_pxp_comp_format2_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_COMP_FORMAT2 register
 */
/*@{*/
#define HW_PXP_HW_PXP_COMP_FORMAT2_ADDR(x) ((uintptr_t)(x) + 0x2C30U)

#define HW_PXP_HW_PXP_COMP_FORMAT2(x) (*(__IO hw_pxp_hw_pxp_comp_format2_t *) HW_PXP_HW_PXP_COMP_FORMAT2_ADDR(x))
#define HW_PXP_HW_PXP_COMP_FORMAT2_RD(x) (HW_PXP_HW_PXP_COMP_FORMAT2(x).U)
#define HW_PXP_HW_PXP_COMP_FORMAT2_WR(x, v) (HW_PXP_HW_PXP_COMP_FORMAT2(x).U = (v))
#define HW_PXP_HW_PXP_COMP_FORMAT2_SET(x, v) (HW_PXP_HW_PXP_COMP_FORMAT2_WR(x, HW_PXP_HW_PXP_COMP_FORMAT2_RD(x) |  (v)))
#define HW_PXP_HW_PXP_COMP_FORMAT2_CLR(x, v) (HW_PXP_HW_PXP_COMP_FORMAT2_WR(x, HW_PXP_HW_PXP_COMP_FORMAT2_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_COMP_FORMAT2_TOG(x, v) (HW_PXP_HW_PXP_COMP_FORMAT2_WR(x, HW_PXP_HW_PXP_COMP_FORMAT2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_COMP_FORMAT2 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT2, field A_RUNLEN[3:0] (RW)
 *
 * length of the RLE for field A, 12-bit(4095) max
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN (0U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN. */
#define BM_PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN (0x0000000FU) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN. */
#define BS_PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN (4U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN field. */
#define BR_PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN(x) (HW_PXP_HW_PXP_COMP_FORMAT2(x).B.A_RUNLEN)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN. */
#define BF_PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN) & BM_PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN)

/*! @brief Set the A_RUNLEN field to a new value. */
#define BW_PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN(x, v) (HW_PXP_HW_PXP_COMP_FORMAT2_WR(x, (HW_PXP_HW_PXP_COMP_FORMAT2_RD(x) & ~BM_PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN) | BF_PXP_HW_PXP_COMP_FORMAT2_A_RUNLEN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT2, field B_RUNLEN[7:4] (RW)
 *
 * length of the RLE for field B, 12-bit(4095) max
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN (4U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN. */
#define BM_PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN (0x000000F0U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN. */
#define BS_PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN (4U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN field. */
#define BR_PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN(x) (HW_PXP_HW_PXP_COMP_FORMAT2(x).B.B_RUNLEN)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN. */
#define BF_PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN) & BM_PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN)

/*! @brief Set the B_RUNLEN field to a new value. */
#define BW_PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN(x, v) (HW_PXP_HW_PXP_COMP_FORMAT2_WR(x, (HW_PXP_HW_PXP_COMP_FORMAT2_RD(x) & ~BM_PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN) | BF_PXP_HW_PXP_COMP_FORMAT2_B_RUNLEN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT2, field C_RUNLEN[11:8] (RW)
 *
 * length of the RLE for field C, 12-bit(4095) max
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN (8U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN. */
#define BM_PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN (0x00000F00U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN. */
#define BS_PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN (4U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN field. */
#define BR_PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN(x) (HW_PXP_HW_PXP_COMP_FORMAT2(x).B.C_RUNLEN)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN. */
#define BF_PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN) & BM_PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN)

/*! @brief Set the C_RUNLEN field to a new value. */
#define BW_PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN(x, v) (HW_PXP_HW_PXP_COMP_FORMAT2_WR(x, (HW_PXP_HW_PXP_COMP_FORMAT2_RD(x) & ~BM_PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN) | BF_PXP_HW_PXP_COMP_FORMAT2_C_RUNLEN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT2, field D_RUNLEN[15:12] (RW)
 *
 * length of the RLE for field D, 12-bit(4095) max
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN (12U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN. */
#define BM_PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN (0x0000F000U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN. */
#define BS_PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN (4U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN field. */
#define BR_PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN(x) (HW_PXP_HW_PXP_COMP_FORMAT2(x).B.D_RUNLEN)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN. */
#define BF_PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN) & BM_PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN)

/*! @brief Set the D_RUNLEN field to a new value. */
#define BW_PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN(x, v) (HW_PXP_HW_PXP_COMP_FORMAT2_WR(x, (HW_PXP_HW_PXP_COMP_FORMAT2_RD(x) & ~BM_PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN) | BF_PXP_HW_PXP_COMP_FORMAT2_D_RUNLEN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_FORMAT2, field RSVD[31:16] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_FORMAT2_RSVD (16U) /*!< Bit position for PXP_HW_PXP_COMP_FORMAT2_RSVD. */
#define BM_PXP_HW_PXP_COMP_FORMAT2_RSVD (0xFFFF0000U) /*!< Bit mask for PXP_HW_PXP_COMP_FORMAT2_RSVD. */
#define BS_PXP_HW_PXP_COMP_FORMAT2_RSVD (16U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_FORMAT2_RSVD. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_FORMAT2_RSVD field. */
#define BR_PXP_HW_PXP_COMP_FORMAT2_RSVD(x) (HW_PXP_HW_PXP_COMP_FORMAT2(x).B.RSVD)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_COMP_MASK0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_COMP_MASK0 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the format bits for the pxp compress mask configure.
 * EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_comp_mask0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_comp_mask0_bitfields
    {
        uint32_t VLD_MASK_LOW : 32;    /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_comp_mask0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_COMP_MASK0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_COMP_MASK0_ADDR(x) ((uintptr_t)(x) + 0x2C40U)

#define HW_PXP_HW_PXP_COMP_MASK0(x) (*(__IO hw_pxp_hw_pxp_comp_mask0_t *) HW_PXP_HW_PXP_COMP_MASK0_ADDR(x))
#define HW_PXP_HW_PXP_COMP_MASK0_RD(x) (HW_PXP_HW_PXP_COMP_MASK0(x).U)
#define HW_PXP_HW_PXP_COMP_MASK0_WR(x, v) (HW_PXP_HW_PXP_COMP_MASK0(x).U = (v))
#define HW_PXP_HW_PXP_COMP_MASK0_SET(x, v) (HW_PXP_HW_PXP_COMP_MASK0_WR(x, HW_PXP_HW_PXP_COMP_MASK0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_COMP_MASK0_CLR(x, v) (HW_PXP_HW_PXP_COMP_MASK0_WR(x, HW_PXP_HW_PXP_COMP_MASK0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_COMP_MASK0_TOG(x, v) (HW_PXP_HW_PXP_COMP_MASK0_WR(x, HW_PXP_HW_PXP_COMP_MASK0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_COMP_MASK0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_COMP_MASK0, field VLD_MASK_LOW[31:0] (RW)
 *
 * low 32bit of the valid mask, one of ABCD will be vld_flag,1 left shifted by
 * vld_flag anded with vld_mask will be used to check whether this pixel is valid
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_MASK0_VLD_MASK_LOW (0U) /*!< Bit position for PXP_HW_PXP_COMP_MASK0_VLD_MASK_LOW. */
#define BM_PXP_HW_PXP_COMP_MASK0_VLD_MASK_LOW (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_COMP_MASK0_VLD_MASK_LOW. */
#define BS_PXP_HW_PXP_COMP_MASK0_VLD_MASK_LOW (32U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_MASK0_VLD_MASK_LOW. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_MASK0_VLD_MASK_LOW field. */
#define BR_PXP_HW_PXP_COMP_MASK0_VLD_MASK_LOW(x) (HW_PXP_HW_PXP_COMP_MASK0(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_MASK0_VLD_MASK_LOW. */
#define BF_PXP_HW_PXP_COMP_MASK0_VLD_MASK_LOW(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_MASK0_VLD_MASK_LOW) & BM_PXP_HW_PXP_COMP_MASK0_VLD_MASK_LOW)

/*! @brief Set the VLD_MASK_LOW field to a new value. */
#define BW_PXP_HW_PXP_COMP_MASK0_VLD_MASK_LOW(x, v) (HW_PXP_HW_PXP_COMP_MASK0_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_COMP_MASK1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_COMP_MASK1 -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the format bits for the pxp compress mask configure.
 * EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_comp_mask1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_comp_mask1_bitfields
    {
        uint32_t VLD_MASK_HIGH : 32;   /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_comp_mask1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_COMP_MASK1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_COMP_MASK1_ADDR(x) ((uintptr_t)(x) + 0x2C50U)

#define HW_PXP_HW_PXP_COMP_MASK1(x) (*(__IO hw_pxp_hw_pxp_comp_mask1_t *) HW_PXP_HW_PXP_COMP_MASK1_ADDR(x))
#define HW_PXP_HW_PXP_COMP_MASK1_RD(x) (HW_PXP_HW_PXP_COMP_MASK1(x).U)
#define HW_PXP_HW_PXP_COMP_MASK1_WR(x, v) (HW_PXP_HW_PXP_COMP_MASK1(x).U = (v))
#define HW_PXP_HW_PXP_COMP_MASK1_SET(x, v) (HW_PXP_HW_PXP_COMP_MASK1_WR(x, HW_PXP_HW_PXP_COMP_MASK1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_COMP_MASK1_CLR(x, v) (HW_PXP_HW_PXP_COMP_MASK1_WR(x, HW_PXP_HW_PXP_COMP_MASK1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_COMP_MASK1_TOG(x, v) (HW_PXP_HW_PXP_COMP_MASK1_WR(x, HW_PXP_HW_PXP_COMP_MASK1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_COMP_MASK1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_COMP_MASK1, field VLD_MASK_HIGH[31:0] (RW)
 *
 * high 32bit of the valid mask
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_MASK1_VLD_MASK_HIGH (0U) /*!< Bit position for PXP_HW_PXP_COMP_MASK1_VLD_MASK_HIGH. */
#define BM_PXP_HW_PXP_COMP_MASK1_VLD_MASK_HIGH (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_COMP_MASK1_VLD_MASK_HIGH. */
#define BS_PXP_HW_PXP_COMP_MASK1_VLD_MASK_HIGH (32U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_MASK1_VLD_MASK_HIGH. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_MASK1_VLD_MASK_HIGH field. */
#define BR_PXP_HW_PXP_COMP_MASK1_VLD_MASK_HIGH(x) (HW_PXP_HW_PXP_COMP_MASK1(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_MASK1_VLD_MASK_HIGH. */
#define BF_PXP_HW_PXP_COMP_MASK1_VLD_MASK_HIGH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_MASK1_VLD_MASK_HIGH) & BM_PXP_HW_PXP_COMP_MASK1_VLD_MASK_HIGH)

/*! @brief Set the VLD_MASK_HIGH field to a new value. */
#define BW_PXP_HW_PXP_COMP_MASK1_VLD_MASK_HIGH(x, v) (HW_PXP_HW_PXP_COMP_MASK1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_COMP_BUFFER_SIZE -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_COMP_BUFFER_SIZE -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the format bits for the pxp compress mask configure.
 * EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_comp_buffer_size
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_comp_buffer_size_bitfields
    {
        uint32_t PIXEL_LENGTH : 13;    /*!< [12:0]  */
        uint32_t RSVD1 : 3;            /*!< [15:13]  */
        uint32_t PIXEL_WIDTH : 13;     /*!< [28:16]  */
        uint32_t RSVD0 : 3;            /*!< [31:29]  */
    } B;
} hw_pxp_hw_pxp_comp_buffer_size_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_COMP_BUFFER_SIZE register
 */
/*@{*/
#define HW_PXP_HW_PXP_COMP_BUFFER_SIZE_ADDR(x) ((uintptr_t)(x) + 0x2C60U)

#define HW_PXP_HW_PXP_COMP_BUFFER_SIZE(x) (*(__IO hw_pxp_hw_pxp_comp_buffer_size_t *) HW_PXP_HW_PXP_COMP_BUFFER_SIZE_ADDR(x))
#define HW_PXP_HW_PXP_COMP_BUFFER_SIZE_RD(x) (HW_PXP_HW_PXP_COMP_BUFFER_SIZE(x).U)
#define HW_PXP_HW_PXP_COMP_BUFFER_SIZE_WR(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_SIZE(x).U = (v))
#define HW_PXP_HW_PXP_COMP_BUFFER_SIZE_SET(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_SIZE_WR(x, HW_PXP_HW_PXP_COMP_BUFFER_SIZE_RD(x) |  (v)))
#define HW_PXP_HW_PXP_COMP_BUFFER_SIZE_CLR(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_SIZE_WR(x, HW_PXP_HW_PXP_COMP_BUFFER_SIZE_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_COMP_BUFFER_SIZE_TOG(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_SIZE_WR(x, HW_PXP_HW_PXP_COMP_BUFFER_SIZE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_COMP_BUFFER_SIZE bitfields
 */

/*!
 * @name Register PXP_HW_PXP_COMP_BUFFER_SIZE, field PIXEL_LENGTH[12:0] (RW)
 *
 * pixel length of the input frame, 4096 max
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH (0U) /*!< Bit position for PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH. */
#define BM_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH (0x00001FFFU) /*!< Bit mask for PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH. */
#define BS_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH (13U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH field. */
#define BR_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH(x) (HW_PXP_HW_PXP_COMP_BUFFER_SIZE(x).B.PIXEL_LENGTH)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH. */
#define BF_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH) & BM_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH)

/*! @brief Set the PIXEL_LENGTH field to a new value. */
#define BW_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_SIZE_WR(x, (HW_PXP_HW_PXP_COMP_BUFFER_SIZE_RD(x) & ~BM_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH) | BF_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_LENGTH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_BUFFER_SIZE, field RSVD1[15:13] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD1 (13U) /*!< Bit position for PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD1. */
#define BM_PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD1 (0x0000E000U) /*!< Bit mask for PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD1. */
#define BS_PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD1 (3U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD1 field. */
#define BR_PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD1(x) (HW_PXP_HW_PXP_COMP_BUFFER_SIZE(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_BUFFER_SIZE, field PIXEL_WIDTH[28:16] (RW)
 *
 * pixel width of the input frame, 4096 max
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH (16U) /*!< Bit position for PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH. */
#define BM_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH (0x1FFF0000U) /*!< Bit mask for PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH. */
#define BS_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH (13U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH field. */
#define BR_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH(x) (HW_PXP_HW_PXP_COMP_BUFFER_SIZE(x).B.PIXEL_WIDTH)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH. */
#define BF_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH) & BM_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH)

/*! @brief Set the PIXEL_WIDTH field to a new value. */
#define BW_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_SIZE_WR(x, (HW_PXP_HW_PXP_COMP_BUFFER_SIZE_RD(x) & ~BM_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH) | BF_PXP_HW_PXP_COMP_BUFFER_SIZE_PIXEL_WIDTH(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_BUFFER_SIZE, field RSVD0[31:29] (RO)
 *
 * Reserved. This field always reads 0.
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD0 (29U) /*!< Bit position for PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD0. */
#define BM_PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD0 (0xE0000000U) /*!< Bit mask for PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD0. */
#define BS_PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD0 (3U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD0 field. */
#define BR_PXP_HW_PXP_COMP_BUFFER_SIZE_RSVD0(x) (HW_PXP_HW_PXP_COMP_BUFFER_SIZE(x).B.RSVD0)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_COMP_SOURCE -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_COMP_SOURCE -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the pxp compress source buffer address register. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_comp_source
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_comp_source_bitfields
    {
        uint32_t SOURCE_ADDR : 32;     /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_comp_source_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_COMP_SOURCE register
 */
/*@{*/
#define HW_PXP_HW_PXP_COMP_SOURCE_ADDR(x) ((uintptr_t)(x) + 0x2C70U)

#define HW_PXP_HW_PXP_COMP_SOURCE(x) (*(__IO hw_pxp_hw_pxp_comp_source_t *) HW_PXP_HW_PXP_COMP_SOURCE_ADDR(x))
#define HW_PXP_HW_PXP_COMP_SOURCE_RD(x) (HW_PXP_HW_PXP_COMP_SOURCE(x).U)
#define HW_PXP_HW_PXP_COMP_SOURCE_WR(x, v) (HW_PXP_HW_PXP_COMP_SOURCE(x).U = (v))
#define HW_PXP_HW_PXP_COMP_SOURCE_SET(x, v) (HW_PXP_HW_PXP_COMP_SOURCE_WR(x, HW_PXP_HW_PXP_COMP_SOURCE_RD(x) |  (v)))
#define HW_PXP_HW_PXP_COMP_SOURCE_CLR(x, v) (HW_PXP_HW_PXP_COMP_SOURCE_WR(x, HW_PXP_HW_PXP_COMP_SOURCE_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_COMP_SOURCE_TOG(x, v) (HW_PXP_HW_PXP_COMP_SOURCE_WR(x, HW_PXP_HW_PXP_COMP_SOURCE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_COMP_SOURCE bitfields
 */

/*!
 * @name Register PXP_HW_PXP_COMP_SOURCE, field SOURCE_ADDR[31:0] (RW)
 *
 * source address of the input frame that located in the memory, should be
 * 32-byte aligned
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_SOURCE_SOURCE_ADDR (0U) /*!< Bit position for PXP_HW_PXP_COMP_SOURCE_SOURCE_ADDR. */
#define BM_PXP_HW_PXP_COMP_SOURCE_SOURCE_ADDR (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_COMP_SOURCE_SOURCE_ADDR. */
#define BS_PXP_HW_PXP_COMP_SOURCE_SOURCE_ADDR (32U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_SOURCE_SOURCE_ADDR. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_SOURCE_SOURCE_ADDR field. */
#define BR_PXP_HW_PXP_COMP_SOURCE_SOURCE_ADDR(x) (HW_PXP_HW_PXP_COMP_SOURCE(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_SOURCE_SOURCE_ADDR. */
#define BF_PXP_HW_PXP_COMP_SOURCE_SOURCE_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_SOURCE_SOURCE_ADDR) & BM_PXP_HW_PXP_COMP_SOURCE_SOURCE_ADDR)

/*! @brief Set the SOURCE_ADDR field to a new value. */
#define BW_PXP_HW_PXP_COMP_SOURCE_SOURCE_ADDR(x, v) (HW_PXP_HW_PXP_COMP_SOURCE_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_COMP_TARGET -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_COMP_TARGET -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the pxp compress target buffer address register. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_comp_target
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_comp_target_bitfields
    {
        uint32_t TARGET_ADDR : 32;     /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_comp_target_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_COMP_TARGET register
 */
/*@{*/
#define HW_PXP_HW_PXP_COMP_TARGET_ADDR(x) ((uintptr_t)(x) + 0x2C80U)

#define HW_PXP_HW_PXP_COMP_TARGET(x) (*(__IO hw_pxp_hw_pxp_comp_target_t *) HW_PXP_HW_PXP_COMP_TARGET_ADDR(x))
#define HW_PXP_HW_PXP_COMP_TARGET_RD(x) (HW_PXP_HW_PXP_COMP_TARGET(x).U)
#define HW_PXP_HW_PXP_COMP_TARGET_WR(x, v) (HW_PXP_HW_PXP_COMP_TARGET(x).U = (v))
#define HW_PXP_HW_PXP_COMP_TARGET_SET(x, v) (HW_PXP_HW_PXP_COMP_TARGET_WR(x, HW_PXP_HW_PXP_COMP_TARGET_RD(x) |  (v)))
#define HW_PXP_HW_PXP_COMP_TARGET_CLR(x, v) (HW_PXP_HW_PXP_COMP_TARGET_WR(x, HW_PXP_HW_PXP_COMP_TARGET_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_COMP_TARGET_TOG(x, v) (HW_PXP_HW_PXP_COMP_TARGET_WR(x, HW_PXP_HW_PXP_COMP_TARGET_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_COMP_TARGET bitfields
 */

/*!
 * @name Register PXP_HW_PXP_COMP_TARGET, field TARGET_ADDR[31:0] (RW)
 *
 * taget address of the output frmae that the pxp compress engine should write
 * to the memory, should be 32-byte aligned
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_TARGET_TARGET_ADDR (0U) /*!< Bit position for PXP_HW_PXP_COMP_TARGET_TARGET_ADDR. */
#define BM_PXP_HW_PXP_COMP_TARGET_TARGET_ADDR (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_COMP_TARGET_TARGET_ADDR. */
#define BS_PXP_HW_PXP_COMP_TARGET_TARGET_ADDR (32U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_TARGET_TARGET_ADDR. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_TARGET_TARGET_ADDR field. */
#define BR_PXP_HW_PXP_COMP_TARGET_TARGET_ADDR(x) (HW_PXP_HW_PXP_COMP_TARGET(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_TARGET_TARGET_ADDR. */
#define BF_PXP_HW_PXP_COMP_TARGET_TARGET_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_TARGET_TARGET_ADDR) & BM_PXP_HW_PXP_COMP_TARGET_TARGET_ADDR)

/*! @brief Set the TARGET_ADDR field to a new value. */
#define BW_PXP_HW_PXP_COMP_TARGET_TARGET_ADDR(x, v) (HW_PXP_HW_PXP_COMP_TARGET_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_COMP_BUFFER_A -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_COMP_BUFFER_A -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the pxp compress field A buffer address register.
 * EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_comp_buffer_a
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_comp_buffer_a_bitfields
    {
        uint32_t A_SRAM_ADDR : 32;     /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_comp_buffer_a_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_COMP_BUFFER_A register
 */
/*@{*/
#define HW_PXP_HW_PXP_COMP_BUFFER_A_ADDR(x) ((uintptr_t)(x) + 0x2C90U)

#define HW_PXP_HW_PXP_COMP_BUFFER_A(x) (*(__IO hw_pxp_hw_pxp_comp_buffer_a_t *) HW_PXP_HW_PXP_COMP_BUFFER_A_ADDR(x))
#define HW_PXP_HW_PXP_COMP_BUFFER_A_RD(x) (HW_PXP_HW_PXP_COMP_BUFFER_A(x).U)
#define HW_PXP_HW_PXP_COMP_BUFFER_A_WR(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_A(x).U = (v))
#define HW_PXP_HW_PXP_COMP_BUFFER_A_SET(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_A_WR(x, HW_PXP_HW_PXP_COMP_BUFFER_A_RD(x) |  (v)))
#define HW_PXP_HW_PXP_COMP_BUFFER_A_CLR(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_A_WR(x, HW_PXP_HW_PXP_COMP_BUFFER_A_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_COMP_BUFFER_A_TOG(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_A_WR(x, HW_PXP_HW_PXP_COMP_BUFFER_A_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_COMP_BUFFER_A bitfields
 */

/*!
 * @name Register PXP_HW_PXP_COMP_BUFFER_A, field A_SRAM_ADDR[31:0] (RW)
 *
 * sram address used for inter-data saving of A filed,should be 32-bit aligned,
 * SW should make sure the SRAM addr for 4 field will not overlap
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_BUFFER_A_A_SRAM_ADDR (0U) /*!< Bit position for PXP_HW_PXP_COMP_BUFFER_A_A_SRAM_ADDR. */
#define BM_PXP_HW_PXP_COMP_BUFFER_A_A_SRAM_ADDR (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_COMP_BUFFER_A_A_SRAM_ADDR. */
#define BS_PXP_HW_PXP_COMP_BUFFER_A_A_SRAM_ADDR (32U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_BUFFER_A_A_SRAM_ADDR. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_BUFFER_A_A_SRAM_ADDR field. */
#define BR_PXP_HW_PXP_COMP_BUFFER_A_A_SRAM_ADDR(x) (HW_PXP_HW_PXP_COMP_BUFFER_A(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_BUFFER_A_A_SRAM_ADDR. */
#define BF_PXP_HW_PXP_COMP_BUFFER_A_A_SRAM_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_BUFFER_A_A_SRAM_ADDR) & BM_PXP_HW_PXP_COMP_BUFFER_A_A_SRAM_ADDR)

/*! @brief Set the A_SRAM_ADDR field to a new value. */
#define BW_PXP_HW_PXP_COMP_BUFFER_A_A_SRAM_ADDR(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_A_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_COMP_BUFFER_B -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_COMP_BUFFER_B -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the pxp compress field B buffer address register.
 * EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_comp_buffer_b
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_comp_buffer_b_bitfields
    {
        uint32_t B_SRAM_ADDR : 32;     /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_comp_buffer_b_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_COMP_BUFFER_B register
 */
/*@{*/
#define HW_PXP_HW_PXP_COMP_BUFFER_B_ADDR(x) ((uintptr_t)(x) + 0x2CA0U)

#define HW_PXP_HW_PXP_COMP_BUFFER_B(x) (*(__IO hw_pxp_hw_pxp_comp_buffer_b_t *) HW_PXP_HW_PXP_COMP_BUFFER_B_ADDR(x))
#define HW_PXP_HW_PXP_COMP_BUFFER_B_RD(x) (HW_PXP_HW_PXP_COMP_BUFFER_B(x).U)
#define HW_PXP_HW_PXP_COMP_BUFFER_B_WR(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_B(x).U = (v))
#define HW_PXP_HW_PXP_COMP_BUFFER_B_SET(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_B_WR(x, HW_PXP_HW_PXP_COMP_BUFFER_B_RD(x) |  (v)))
#define HW_PXP_HW_PXP_COMP_BUFFER_B_CLR(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_B_WR(x, HW_PXP_HW_PXP_COMP_BUFFER_B_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_COMP_BUFFER_B_TOG(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_B_WR(x, HW_PXP_HW_PXP_COMP_BUFFER_B_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_COMP_BUFFER_B bitfields
 */

/*!
 * @name Register PXP_HW_PXP_COMP_BUFFER_B, field B_SRAM_ADDR[31:0] (RW)
 *
 * sram address used for inter-data saving of B filed,should be 32-bit aligned,
 * SW should make sure the SRAM addr for 4 field will not overlap
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_BUFFER_B_B_SRAM_ADDR (0U) /*!< Bit position for PXP_HW_PXP_COMP_BUFFER_B_B_SRAM_ADDR. */
#define BM_PXP_HW_PXP_COMP_BUFFER_B_B_SRAM_ADDR (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_COMP_BUFFER_B_B_SRAM_ADDR. */
#define BS_PXP_HW_PXP_COMP_BUFFER_B_B_SRAM_ADDR (32U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_BUFFER_B_B_SRAM_ADDR. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_BUFFER_B_B_SRAM_ADDR field. */
#define BR_PXP_HW_PXP_COMP_BUFFER_B_B_SRAM_ADDR(x) (HW_PXP_HW_PXP_COMP_BUFFER_B(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_BUFFER_B_B_SRAM_ADDR. */
#define BF_PXP_HW_PXP_COMP_BUFFER_B_B_SRAM_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_BUFFER_B_B_SRAM_ADDR) & BM_PXP_HW_PXP_COMP_BUFFER_B_B_SRAM_ADDR)

/*! @brief Set the B_SRAM_ADDR field to a new value. */
#define BW_PXP_HW_PXP_COMP_BUFFER_B_B_SRAM_ADDR(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_B_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_COMP_BUFFER_C -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_COMP_BUFFER_C -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the pxp compress field C buffer address register.
 * EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_comp_buffer_c
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_comp_buffer_c_bitfields
    {
        uint32_t C_SRAM_ADDR : 32;     /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_comp_buffer_c_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_COMP_BUFFER_C register
 */
/*@{*/
#define HW_PXP_HW_PXP_COMP_BUFFER_C_ADDR(x) ((uintptr_t)(x) + 0x2CB0U)

#define HW_PXP_HW_PXP_COMP_BUFFER_C(x) (*(__IO hw_pxp_hw_pxp_comp_buffer_c_t *) HW_PXP_HW_PXP_COMP_BUFFER_C_ADDR(x))
#define HW_PXP_HW_PXP_COMP_BUFFER_C_RD(x) (HW_PXP_HW_PXP_COMP_BUFFER_C(x).U)
#define HW_PXP_HW_PXP_COMP_BUFFER_C_WR(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_C(x).U = (v))
#define HW_PXP_HW_PXP_COMP_BUFFER_C_SET(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_C_WR(x, HW_PXP_HW_PXP_COMP_BUFFER_C_RD(x) |  (v)))
#define HW_PXP_HW_PXP_COMP_BUFFER_C_CLR(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_C_WR(x, HW_PXP_HW_PXP_COMP_BUFFER_C_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_COMP_BUFFER_C_TOG(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_C_WR(x, HW_PXP_HW_PXP_COMP_BUFFER_C_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_COMP_BUFFER_C bitfields
 */

/*!
 * @name Register PXP_HW_PXP_COMP_BUFFER_C, field C_SRAM_ADDR[31:0] (RW)
 *
 * sram address used for inter-data saving of C filed,should be 32-bit aligned,
 * SW should make sure the SRAM addr for 4 field will not overlap
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_BUFFER_C_C_SRAM_ADDR (0U) /*!< Bit position for PXP_HW_PXP_COMP_BUFFER_C_C_SRAM_ADDR. */
#define BM_PXP_HW_PXP_COMP_BUFFER_C_C_SRAM_ADDR (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_COMP_BUFFER_C_C_SRAM_ADDR. */
#define BS_PXP_HW_PXP_COMP_BUFFER_C_C_SRAM_ADDR (32U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_BUFFER_C_C_SRAM_ADDR. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_BUFFER_C_C_SRAM_ADDR field. */
#define BR_PXP_HW_PXP_COMP_BUFFER_C_C_SRAM_ADDR(x) (HW_PXP_HW_PXP_COMP_BUFFER_C(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_BUFFER_C_C_SRAM_ADDR. */
#define BF_PXP_HW_PXP_COMP_BUFFER_C_C_SRAM_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_BUFFER_C_C_SRAM_ADDR) & BM_PXP_HW_PXP_COMP_BUFFER_C_C_SRAM_ADDR)

/*! @brief Set the C_SRAM_ADDR field to a new value. */
#define BW_PXP_HW_PXP_COMP_BUFFER_C_C_SRAM_ADDR(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_C_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_COMP_BUFFER_D -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_COMP_BUFFER_D -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the pxp compress field D buffer address register.
 * EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_comp_buffer_d
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_comp_buffer_d_bitfields
    {
        uint32_t D_SRAM_ADDR : 32;     /*!< [31:0]  */
    } B;
} hw_pxp_hw_pxp_comp_buffer_d_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_COMP_BUFFER_D register
 */
/*@{*/
#define HW_PXP_HW_PXP_COMP_BUFFER_D_ADDR(x) ((uintptr_t)(x) + 0x2CC0U)

#define HW_PXP_HW_PXP_COMP_BUFFER_D(x) (*(__IO hw_pxp_hw_pxp_comp_buffer_d_t *) HW_PXP_HW_PXP_COMP_BUFFER_D_ADDR(x))
#define HW_PXP_HW_PXP_COMP_BUFFER_D_RD(x) (HW_PXP_HW_PXP_COMP_BUFFER_D(x).U)
#define HW_PXP_HW_PXP_COMP_BUFFER_D_WR(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_D(x).U = (v))
#define HW_PXP_HW_PXP_COMP_BUFFER_D_SET(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_D_WR(x, HW_PXP_HW_PXP_COMP_BUFFER_D_RD(x) |  (v)))
#define HW_PXP_HW_PXP_COMP_BUFFER_D_CLR(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_D_WR(x, HW_PXP_HW_PXP_COMP_BUFFER_D_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_COMP_BUFFER_D_TOG(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_D_WR(x, HW_PXP_HW_PXP_COMP_BUFFER_D_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_COMP_BUFFER_D bitfields
 */

/*!
 * @name Register PXP_HW_PXP_COMP_BUFFER_D, field D_SRAM_ADDR[31:0] (RW)
 *
 * sram address used for inter-data saving of D filed,should be 32-bit aligned,
 * SW should make sure the SRAM addr for 4 field will not overlap
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_BUFFER_D_D_SRAM_ADDR (0U) /*!< Bit position for PXP_HW_PXP_COMP_BUFFER_D_D_SRAM_ADDR. */
#define BM_PXP_HW_PXP_COMP_BUFFER_D_D_SRAM_ADDR (0xFFFFFFFFU) /*!< Bit mask for PXP_HW_PXP_COMP_BUFFER_D_D_SRAM_ADDR. */
#define BS_PXP_HW_PXP_COMP_BUFFER_D_D_SRAM_ADDR (32U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_BUFFER_D_D_SRAM_ADDR. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_BUFFER_D_D_SRAM_ADDR field. */
#define BR_PXP_HW_PXP_COMP_BUFFER_D_D_SRAM_ADDR(x) (HW_PXP_HW_PXP_COMP_BUFFER_D(x).U)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_BUFFER_D_D_SRAM_ADDR. */
#define BF_PXP_HW_PXP_COMP_BUFFER_D_D_SRAM_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_BUFFER_D_D_SRAM_ADDR) & BM_PXP_HW_PXP_COMP_BUFFER_D_D_SRAM_ADDR)

/*! @brief Set the D_SRAM_ADDR field to a new value. */
#define BW_PXP_HW_PXP_COMP_BUFFER_D_D_SRAM_ADDR(x, v) (HW_PXP_HW_PXP_COMP_BUFFER_D_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_COMP_DEBUG -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_COMP_DEBUG -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the pxp compress debug register. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_comp_debug
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_comp_debug_bitfields
    {
        uint32_t DEBUG_SEL : 8;        /*!< [7:0]  */
        uint32_t DEBUG_VALUE : 24;     /*!< [31:8]  */
    } B;
} hw_pxp_hw_pxp_comp_debug_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_COMP_DEBUG register
 */
/*@{*/
#define HW_PXP_HW_PXP_COMP_DEBUG_ADDR(x) ((uintptr_t)(x) + 0x2CD0U)

#define HW_PXP_HW_PXP_COMP_DEBUG(x) (*(__IO hw_pxp_hw_pxp_comp_debug_t *) HW_PXP_HW_PXP_COMP_DEBUG_ADDR(x))
#define HW_PXP_HW_PXP_COMP_DEBUG_RD(x) (HW_PXP_HW_PXP_COMP_DEBUG(x).U)
#define HW_PXP_HW_PXP_COMP_DEBUG_WR(x, v) (HW_PXP_HW_PXP_COMP_DEBUG(x).U = (v))
#define HW_PXP_HW_PXP_COMP_DEBUG_SET(x, v) (HW_PXP_HW_PXP_COMP_DEBUG_WR(x, HW_PXP_HW_PXP_COMP_DEBUG_RD(x) |  (v)))
#define HW_PXP_HW_PXP_COMP_DEBUG_CLR(x, v) (HW_PXP_HW_PXP_COMP_DEBUG_WR(x, HW_PXP_HW_PXP_COMP_DEBUG_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_COMP_DEBUG_TOG(x, v) (HW_PXP_HW_PXP_COMP_DEBUG_WR(x, HW_PXP_HW_PXP_COMP_DEBUG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_COMP_DEBUG bitfields
 */

/*!
 * @name Register PXP_HW_PXP_COMP_DEBUG, field DEBUG_SEL[7:0] (RW)
 *
 * debug selection
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL (0U) /*!< Bit position for PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL. */
#define BM_PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL (0x000000FFU) /*!< Bit mask for PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL. */
#define BS_PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL (8U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL field. */
#define BR_PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL(x) (HW_PXP_HW_PXP_COMP_DEBUG(x).B.DEBUG_SEL)

/*! @brief Format value for bitfield PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL. */
#define BF_PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL) & BM_PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL)

/*! @brief Set the DEBUG_SEL field to a new value. */
#define BW_PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL(x, v) (HW_PXP_HW_PXP_COMP_DEBUG_WR(x, (HW_PXP_HW_PXP_COMP_DEBUG_RD(x) & ~BM_PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL) | BF_PXP_HW_PXP_COMP_DEBUG_DEBUG_SEL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_COMP_DEBUG, field DEBUG_VALUE[31:8] (RO)
 *
 * value of selected debug signal
 */
/*@{*/
#define BP_PXP_HW_PXP_COMP_DEBUG_DEBUG_VALUE (8U) /*!< Bit position for PXP_HW_PXP_COMP_DEBUG_DEBUG_VALUE. */
#define BM_PXP_HW_PXP_COMP_DEBUG_DEBUG_VALUE (0xFFFFFF00U) /*!< Bit mask for PXP_HW_PXP_COMP_DEBUG_DEBUG_VALUE. */
#define BS_PXP_HW_PXP_COMP_DEBUG_DEBUG_VALUE (24U) /*!< Bit field size in bits for PXP_HW_PXP_COMP_DEBUG_DEBUG_VALUE. */

/*! @brief Read current value of the PXP_HW_PXP_COMP_DEBUG_DEBUG_VALUE field. */
#define BR_PXP_HW_PXP_COMP_DEBUG_DEBUG_VALUE(x) (HW_PXP_HW_PXP_COMP_DEBUG(x).B.DEBUG_VALUE)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_BUS_MUX -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_BUS_MUX -  (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the pxp subblock bus mux on top level. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_bus_mux
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_bus_mux_bitfields
    {
        uint32_t RD_SEL : 8;           /*!< [7:0]  */
        uint32_t RSVD0 : 8;            /*!< [15:8]  */
        uint32_t WR_SEL : 8;           /*!< [23:16]  */
        uint32_t RSVD1 : 8;            /*!< [31:24]  */
    } B;
} hw_pxp_hw_pxp_bus_mux_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_BUS_MUX register
 */
/*@{*/
#define HW_PXP_HW_PXP_BUS_MUX_ADDR(x) ((uintptr_t)(x) + 0x2CE0U)

#define HW_PXP_HW_PXP_BUS_MUX(x) (*(__IO hw_pxp_hw_pxp_bus_mux_t *) HW_PXP_HW_PXP_BUS_MUX_ADDR(x))
#define HW_PXP_HW_PXP_BUS_MUX_RD(x) (HW_PXP_HW_PXP_BUS_MUX(x).U)
#define HW_PXP_HW_PXP_BUS_MUX_WR(x, v) (HW_PXP_HW_PXP_BUS_MUX(x).U = (v))
#define HW_PXP_HW_PXP_BUS_MUX_SET(x, v) (HW_PXP_HW_PXP_BUS_MUX_WR(x, HW_PXP_HW_PXP_BUS_MUX_RD(x) |  (v)))
#define HW_PXP_HW_PXP_BUS_MUX_CLR(x, v) (HW_PXP_HW_PXP_BUS_MUX_WR(x, HW_PXP_HW_PXP_BUS_MUX_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_BUS_MUX_TOG(x, v) (HW_PXP_HW_PXP_BUS_MUX_WR(x, HW_PXP_HW_PXP_BUS_MUX_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_BUS_MUX bitfields
 */

/*!
 * @name Register PXP_HW_PXP_BUS_MUX, field RD_SEL[7:0] (RW)
 *
 * Subblock BUS to AXI MUX, setting 0 to axi0 and setting 1 to axi1
 */
/*@{*/
#define BP_PXP_HW_PXP_BUS_MUX_RD_SEL (0U)  /*!< Bit position for PXP_HW_PXP_BUS_MUX_RD_SEL. */
#define BM_PXP_HW_PXP_BUS_MUX_RD_SEL (0x000000FFU) /*!< Bit mask for PXP_HW_PXP_BUS_MUX_RD_SEL. */
#define BS_PXP_HW_PXP_BUS_MUX_RD_SEL (8U)  /*!< Bit field size in bits for PXP_HW_PXP_BUS_MUX_RD_SEL. */

/*! @brief Read current value of the PXP_HW_PXP_BUS_MUX_RD_SEL field. */
#define BR_PXP_HW_PXP_BUS_MUX_RD_SEL(x) (HW_PXP_HW_PXP_BUS_MUX(x).B.RD_SEL)

/*! @brief Format value for bitfield PXP_HW_PXP_BUS_MUX_RD_SEL. */
#define BF_PXP_HW_PXP_BUS_MUX_RD_SEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_BUS_MUX_RD_SEL) & BM_PXP_HW_PXP_BUS_MUX_RD_SEL)

/*! @brief Set the RD_SEL field to a new value. */
#define BW_PXP_HW_PXP_BUS_MUX_RD_SEL(x, v) (HW_PXP_HW_PXP_BUS_MUX_WR(x, (HW_PXP_HW_PXP_BUS_MUX_RD(x) & ~BM_PXP_HW_PXP_BUS_MUX_RD_SEL) | BF_PXP_HW_PXP_BUS_MUX_RD_SEL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_BUS_MUX, field RSVD0[15:8] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_BUS_MUX_RSVD0 (8U)   /*!< Bit position for PXP_HW_PXP_BUS_MUX_RSVD0. */
#define BM_PXP_HW_PXP_BUS_MUX_RSVD0 (0x0000FF00U) /*!< Bit mask for PXP_HW_PXP_BUS_MUX_RSVD0. */
#define BS_PXP_HW_PXP_BUS_MUX_RSVD0 (8U)   /*!< Bit field size in bits for PXP_HW_PXP_BUS_MUX_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_BUS_MUX_RSVD0 field. */
#define BR_PXP_HW_PXP_BUS_MUX_RSVD0(x) (HW_PXP_HW_PXP_BUS_MUX(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_BUS_MUX, field WR_SEL[23:16] (RW)
 *
 * Subblock BUS to AXI MUX, setting 0 to axi0 and setting 1 to axi1
 */
/*@{*/
#define BP_PXP_HW_PXP_BUS_MUX_WR_SEL (16U) /*!< Bit position for PXP_HW_PXP_BUS_MUX_WR_SEL. */
#define BM_PXP_HW_PXP_BUS_MUX_WR_SEL (0x00FF0000U) /*!< Bit mask for PXP_HW_PXP_BUS_MUX_WR_SEL. */
#define BS_PXP_HW_PXP_BUS_MUX_WR_SEL (8U)  /*!< Bit field size in bits for PXP_HW_PXP_BUS_MUX_WR_SEL. */

/*! @brief Read current value of the PXP_HW_PXP_BUS_MUX_WR_SEL field. */
#define BR_PXP_HW_PXP_BUS_MUX_WR_SEL(x) (HW_PXP_HW_PXP_BUS_MUX(x).B.WR_SEL)

/*! @brief Format value for bitfield PXP_HW_PXP_BUS_MUX_WR_SEL. */
#define BF_PXP_HW_PXP_BUS_MUX_WR_SEL(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_BUS_MUX_WR_SEL) & BM_PXP_HW_PXP_BUS_MUX_WR_SEL)

/*! @brief Set the WR_SEL field to a new value. */
#define BW_PXP_HW_PXP_BUS_MUX_WR_SEL(x, v) (HW_PXP_HW_PXP_BUS_MUX_WR(x, (HW_PXP_HW_PXP_BUS_MUX_RD(x) & ~BM_PXP_HW_PXP_BUS_MUX_WR_SEL) | BF_PXP_HW_PXP_BUS_MUX_WR_SEL(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_BUS_MUX, field RSVD1[31:24] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_BUS_MUX_RSVD1 (24U)  /*!< Bit position for PXP_HW_PXP_BUS_MUX_RSVD1. */
#define BM_PXP_HW_PXP_BUS_MUX_RSVD1 (0xFF000000U) /*!< Bit mask for PXP_HW_PXP_BUS_MUX_RSVD1. */
#define BS_PXP_HW_PXP_BUS_MUX_RSVD1 (8U)   /*!< Bit field size in bits for PXP_HW_PXP_BUS_MUX_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_BUS_MUX_RSVD1 field. */
#define BR_PXP_HW_PXP_BUS_MUX_RSVD1(x) (HW_PXP_HW_PXP_BUS_MUX(x).B.RSVD1)
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0 -  (RW)
 *
 * Reset value: 0x76543210U
 *
 * This register defines the pxp subblock handshake signals ready mux on top
 * level. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_handshake_ready_mux0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_handshake_ready_mux0_bitfields
    {
        uint32_t HSK0 : 4;             /*!< [3:0]  */
        uint32_t HSK1 : 4;             /*!< [7:4]  */
        uint32_t HSK2 : 4;             /*!< [11:8]  */
        uint32_t HSK3 : 4;             /*!< [15:12]  */
        uint32_t HSK4 : 4;             /*!< [19:16]  */
        uint32_t HSK5 : 4;             /*!< [23:20]  */
        uint32_t HSK6 : 4;             /*!< [27:24]  */
        uint32_t HSK7 : 4;             /*!< [31:28]  */
    } B;
} hw_pxp_hw_pxp_handshake_ready_mux0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HANDSHAKE_READY_MUX0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_ADDR(x) ((uintptr_t)(x) + 0x2CF0U)

#define HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0(x) (*(__IO hw_pxp_hw_pxp_handshake_ready_mux0_t *) HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_ADDR(x))
#define HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_RD(x) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0(x).U)
#define HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_WR(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0(x).U = (v))
#define HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_SET(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_WR(x, HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_CLR(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_WR(x, HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_TOG(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_WR(x, HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HANDSHAKE_READY_MUX0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_READY_MUX0, field HSK0[3:0] (RW)
 *
 * Subblock double buffer handshake signals MUX 0: Ready signal source is from
 * pxp_control; 1: Ready signal source is from pxp_store_wfe_B CH0; 2: Ready
 * signal source is from pxp_store_wfe_B CH1; 3: Ready signal source is from
 * pxp_store_pre_ditering CH0; 4: Ready signal source is from pxp_store_pre_ditering CH1;
 * 5: Ready signal source is from pxp_store_dithering CH0; 6: Ready signal source
 * is from pxp_store_dithering CH1; 7: Ready signal source is from
 * pxp_store_wfe_a CH0; 8: Ready signal source is from pxp_store_wfe_a CH1; 9: Ready signal
 * source is from cpu_fetch_sw0_ready; A: Ready signal source is from
 * cpu_fetch_sw1_ready; B: Ready signal source is from cpu_store_sw0_ready; C: Ready signal
 * source is from cpu_store_sw1_ready;
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0 (0U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0. */
#define BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0 (0x0000000FU) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0. */
#define BS_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0(x) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0(x).B.HSK0)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0. */
#define BF_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0) & BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0)

/*! @brief Set the HSK0 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0) | BF_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_READY_MUX0, field HSK1[7:4] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1 (4U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1. */
#define BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1 (0x000000F0U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1. */
#define BS_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1(x) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0(x).B.HSK1)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1. */
#define BF_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1) & BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1)

/*! @brief Set the HSK1 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1) | BF_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_READY_MUX0, field HSK2[11:8] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2 (8U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2. */
#define BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2 (0x00000F00U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2. */
#define BS_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2(x) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0(x).B.HSK2)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2. */
#define BF_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2) & BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2)

/*! @brief Set the HSK2 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2) | BF_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_READY_MUX0, field HSK3[15:12] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3 (12U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3. */
#define BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3 (0x0000F000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3. */
#define BS_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3(x) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0(x).B.HSK3)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3. */
#define BF_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3) & BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3)

/*! @brief Set the HSK3 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3) | BF_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_READY_MUX0, field HSK4[19:16] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4 (16U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4. */
#define BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4 (0x000F0000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4. */
#define BS_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4(x) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0(x).B.HSK4)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4. */
#define BF_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4) & BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4)

/*! @brief Set the HSK4 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4) | BF_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK4(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_READY_MUX0, field HSK5[23:20] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5 (20U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5. */
#define BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5 (0x00F00000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5. */
#define BS_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5(x) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0(x).B.HSK5)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5. */
#define BF_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5) & BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5)

/*! @brief Set the HSK5 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5) | BF_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK5(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_READY_MUX0, field HSK6[27:24] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6 (24U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6. */
#define BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6 (0x0F000000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6. */
#define BS_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6(x) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0(x).B.HSK6)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6. */
#define BF_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6) & BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6)

/*! @brief Set the HSK6 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6) | BF_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK6(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_READY_MUX0, field HSK7[31:28] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7 (28U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7. */
#define BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7 (0xF0000000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7. */
#define BS_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7(x) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0(x).B.HSK7)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7. */
#define BF_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7) & BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7)

/*! @brief Set the HSK7 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX0_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7) | BF_PXP_HW_PXP_HANDSHAKE_READY_MUX0_HSK7(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1 -  (RW)
 *
 * Reset value: 0xFEDCBA98U
 *
 * This register defines the pxp subblock handshake signals ready mux on top
 * level. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_handshake_ready_mux1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_handshake_ready_mux1_bitfields
    {
        uint32_t HSK8 : 4;             /*!< [3:0]  */
        uint32_t HSK9 : 4;             /*!< [7:4]  */
        uint32_t HSK10 : 4;            /*!< [11:8]  */
        uint32_t HSK11 : 4;            /*!< [15:12]  */
        uint32_t HSK12 : 4;            /*!< [19:16]  */
        uint32_t HSK13 : 4;            /*!< [23:20]  */
        uint32_t HSK14 : 4;            /*!< [27:24]  */
        uint32_t HSK15 : 4;            /*!< [31:28]  */
    } B;
} hw_pxp_hw_pxp_handshake_ready_mux1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HANDSHAKE_READY_MUX1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_ADDR(x) ((uintptr_t)(x) + 0x2D00U)

#define HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1(x) (*(__IO hw_pxp_hw_pxp_handshake_ready_mux1_t *) HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_ADDR(x))
#define HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_RD(x) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1(x).U)
#define HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_WR(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1(x).U = (v))
#define HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_SET(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_WR(x, HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_CLR(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_WR(x, HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_TOG(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_WR(x, HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HANDSHAKE_READY_MUX1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_READY_MUX1, field HSK8[3:0] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8 (0U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8. */
#define BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8 (0x0000000FU) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8. */
#define BS_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8(x) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1(x).B.HSK8)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8. */
#define BF_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8) & BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8)

/*! @brief Set the HSK8 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8) | BF_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK8(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_READY_MUX1, field HSK9[7:4] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9 (4U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9. */
#define BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9 (0x000000F0U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9. */
#define BS_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9(x) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1(x).B.HSK9)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9. */
#define BF_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9) & BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9)

/*! @brief Set the HSK9 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9) | BF_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK9(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_READY_MUX1, field HSK10[11:8] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10 (8U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10. */
#define BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10 (0x00000F00U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10. */
#define BS_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10(x) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1(x).B.HSK10)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10. */
#define BF_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10) & BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10)

/*! @brief Set the HSK10 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10) | BF_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK10(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_READY_MUX1, field HSK11[15:12] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11 (12U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11. */
#define BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11 (0x0000F000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11. */
#define BS_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11(x) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1(x).B.HSK11)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11. */
#define BF_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11) & BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11)

/*! @brief Set the HSK11 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11) | BF_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK11(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_READY_MUX1, field HSK12[19:16] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12 (16U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12. */
#define BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12 (0x000F0000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12. */
#define BS_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12(x) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1(x).B.HSK12)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12. */
#define BF_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12) & BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12)

/*! @brief Set the HSK12 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12) | BF_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK12(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_READY_MUX1, field HSK13[23:20] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13 (20U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13. */
#define BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13 (0x00F00000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13. */
#define BS_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13(x) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1(x).B.HSK13)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13. */
#define BF_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13) & BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13)

/*! @brief Set the HSK13 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13) | BF_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK13(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_READY_MUX1, field HSK14[27:24] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14 (24U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14. */
#define BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14 (0x0F000000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14. */
#define BS_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14(x) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1(x).B.HSK14)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14. */
#define BF_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14) & BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14)

/*! @brief Set the HSK14 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14) | BF_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK14(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_READY_MUX1, field HSK15[31:28] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15 (28U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15. */
#define BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15 (0xF0000000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15. */
#define BS_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15(x) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1(x).B.HSK15)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15. */
#define BF_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15) & BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15)

/*! @brief Set the HSK15 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15(x, v) (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_READY_MUX1_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15) | BF_PXP_HW_PXP_HANDSHAKE_READY_MUX1_HSK15(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0 -  (RW)
 *
 * Reset value: 0x76543210U
 *
 * This register defines the pxp subblock handshake signals done mux on top
 * level. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_handshake_done_mux0
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_handshake_done_mux0_bitfields
    {
        uint32_t HSK0 : 4;             /*!< [3:0]  */
        uint32_t HSK1 : 4;             /*!< [7:4]  */
        uint32_t HSK2 : 4;             /*!< [11:8]  */
        uint32_t HSK3 : 4;             /*!< [15:12]  */
        uint32_t HSK4 : 4;             /*!< [19:16]  */
        uint32_t HSK5 : 4;             /*!< [23:20]  */
        uint32_t HSK6 : 4;             /*!< [27:24]  */
        uint32_t HSK7 : 4;             /*!< [31:28]  */
    } B;
} hw_pxp_hw_pxp_handshake_done_mux0_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HANDSHAKE_DONE_MUX0 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_ADDR(x) ((uintptr_t)(x) + 0x2D10U)

#define HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0(x) (*(__IO hw_pxp_hw_pxp_handshake_done_mux0_t *) HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_ADDR(x))
#define HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_RD(x) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0(x).U)
#define HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_WR(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0(x).U = (v))
#define HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_SET(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_WR(x, HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_CLR(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_WR(x, HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_TOG(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_WR(x, HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HANDSHAKE_DONE_MUX0 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_DONE_MUX0, field HSK0[3:0] (RW)
 *
 * Subblock double buffer handshake signals MUX 0: Done signal source is from
 * LCDIF; 1: Done signal source is from pxp_fetch_input CH0; 2: Done signal source
 * is from pxp_fetch_input CH1; 3: Done signal source is from pxp_fetch_dithering
 * CH0; 4: Done signal source is from pxp_fetch_dithering CH1; 5: Done signal
 * source is from pxp_fetch_wfe_a CH0; 6: Done signal source is from
 * pxp_fetch_wfe_a CH1; 7: Done signal source is from pxp_fetch_wfe_b CH0; 8: Done signal
 * source is from pxp_fetch_wfe_b CH1; 9: Done signal source is from
 * cpu_fetch_sw0_done; A: Done signal source is from cpu_fetch_sw1_done; B: Done signal source is
 * from cpu_store_sw0_done; C: Done signal source is from cpu_store_sw1_done;
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0 (0U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0. */
#define BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0 (0x0000000FU) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0. */
#define BS_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0(x) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0(x).B.HSK0)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0. */
#define BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0) & BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0)

/*! @brief Set the HSK0 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0) | BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK0(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_DONE_MUX0, field HSK1[7:4] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1 (4U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1. */
#define BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1 (0x000000F0U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1. */
#define BS_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1(x) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0(x).B.HSK1)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1. */
#define BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1) & BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1)

/*! @brief Set the HSK1 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1) | BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK1(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_DONE_MUX0, field HSK2[11:8] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2 (8U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2. */
#define BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2 (0x00000F00U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2. */
#define BS_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2(x) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0(x).B.HSK2)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2. */
#define BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2) & BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2)

/*! @brief Set the HSK2 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2) | BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK2(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_DONE_MUX0, field HSK3[15:12] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3 (12U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3. */
#define BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3 (0x0000F000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3. */
#define BS_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3(x) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0(x).B.HSK3)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3. */
#define BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3) & BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3)

/*! @brief Set the HSK3 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3) | BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK3(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_DONE_MUX0, field HSK4[19:16] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4 (16U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4. */
#define BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4 (0x000F0000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4. */
#define BS_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4(x) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0(x).B.HSK4)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4. */
#define BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4) & BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4)

/*! @brief Set the HSK4 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4) | BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK4(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_DONE_MUX0, field HSK5[23:20] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5 (20U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5. */
#define BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5 (0x00F00000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5. */
#define BS_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5(x) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0(x).B.HSK5)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5. */
#define BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5) & BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5)

/*! @brief Set the HSK5 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5) | BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK5(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_DONE_MUX0, field HSK6[27:24] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6 (24U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6. */
#define BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6 (0x0F000000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6. */
#define BS_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6(x) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0(x).B.HSK6)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6. */
#define BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6) & BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6)

/*! @brief Set the HSK6 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6) | BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK6(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_DONE_MUX0, field HSK7[31:28] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7 (28U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7. */
#define BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7 (0xF0000000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7. */
#define BS_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7(x) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0(x).B.HSK7)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7. */
#define BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7) & BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7)

/*! @brief Set the HSK7 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7) | BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX0_HSK7(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1 -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1 -  (RW)
 *
 * Reset value: 0xFEDCBA98U
 *
 * This register defines the pxp subblock handshake signals done mux on top
 * level. EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_handshake_done_mux1
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_handshake_done_mux1_bitfields
    {
        uint32_t HSK8 : 4;             /*!< [3:0]  */
        uint32_t HSK9 : 4;             /*!< [7:4]  */
        uint32_t HSK10 : 4;            /*!< [11:8]  */
        uint32_t HSK11 : 4;            /*!< [15:12]  */
        uint32_t HSK12 : 4;            /*!< [19:16]  */
        uint32_t HSK13 : 4;            /*!< [23:20]  */
        uint32_t HSK14 : 4;            /*!< [27:24]  */
        uint32_t HSK15 : 4;            /*!< [31:28]  */
    } B;
} hw_pxp_hw_pxp_handshake_done_mux1_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HANDSHAKE_DONE_MUX1 register
 */
/*@{*/
#define HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_ADDR(x) ((uintptr_t)(x) + 0x2D20U)

#define HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1(x) (*(__IO hw_pxp_hw_pxp_handshake_done_mux1_t *) HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_ADDR(x))
#define HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_RD(x) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1(x).U)
#define HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_WR(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1(x).U = (v))
#define HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_SET(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_WR(x, HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_CLR(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_WR(x, HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_TOG(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_WR(x, HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HANDSHAKE_DONE_MUX1 bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_DONE_MUX1, field HSK8[3:0] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8 (0U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8. */
#define BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8 (0x0000000FU) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8. */
#define BS_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8(x) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1(x).B.HSK8)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8. */
#define BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8) & BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8)

/*! @brief Set the HSK8 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8) | BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK8(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_DONE_MUX1, field HSK9[7:4] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9 (4U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9. */
#define BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9 (0x000000F0U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9. */
#define BS_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9(x) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1(x).B.HSK9)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9. */
#define BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9) & BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9)

/*! @brief Set the HSK9 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9) | BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK9(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_DONE_MUX1, field HSK10[11:8] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10 (8U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10. */
#define BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10 (0x00000F00U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10. */
#define BS_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10(x) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1(x).B.HSK10)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10. */
#define BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10) & BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10)

/*! @brief Set the HSK10 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10) | BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK10(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_DONE_MUX1, field HSK11[15:12] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11 (12U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11. */
#define BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11 (0x0000F000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11. */
#define BS_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11(x) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1(x).B.HSK11)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11. */
#define BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11) & BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11)

/*! @brief Set the HSK11 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11) | BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK11(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_DONE_MUX1, field HSK12[19:16] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12 (16U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12. */
#define BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12 (0x000F0000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12. */
#define BS_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12(x) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1(x).B.HSK12)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12. */
#define BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12) & BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12)

/*! @brief Set the HSK12 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12) | BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK12(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_DONE_MUX1, field HSK13[23:20] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13 (20U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13. */
#define BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13 (0x00F00000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13. */
#define BS_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13(x) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1(x).B.HSK13)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13. */
#define BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13) & BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13)

/*! @brief Set the HSK13 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13) | BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK13(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_DONE_MUX1, field HSK14[27:24] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14 (24U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14. */
#define BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14 (0x0F000000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14. */
#define BS_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14(x) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1(x).B.HSK14)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14. */
#define BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14) & BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14)

/*! @brief Set the HSK14 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14) | BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK14(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_DONE_MUX1, field HSK15[31:28] (RW)
 *
 * Subblock double buffer handshake signals MUX
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15 (28U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15. */
#define BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15 (0xF0000000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15. */
#define BS_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15 (4U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15(x) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1(x).B.HSK15)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15. */
#define BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15) & BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15)

/*! @brief Set the HSK15 field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15(x, v) (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15) | BF_PXP_HW_PXP_HANDSHAKE_DONE_MUX1_HSK15(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH -  (RW)
 *
 * Reset value: 0x00100010U
 *
 * This register defines the pxp software handshake signals with CPU.
 * HW_PXP_HANDSHAKE_CPU_FETCH: 0x2D30 HW_PXP_HANDSHAKE_CPU_FETCH_SET: 0x2D34
 * HW_PXP_HANDSHAKE_CPU_FETCH_CLR: 0x2D38 HW_PXP_HANDSHAKE_CPU_FETCH_TOG: 0x2D3C EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_handshake_cpu_fetch
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_handshake_cpu_fetch_bitfields
    {
        uint32_t SW0_B0_READY : 1;     /*!< [0]  */
        uint32_t SW0_B1_READY : 1;     /*!< [1]  */
        uint32_t SW0_B0_DONE : 1;      /*!< [2]  */
        uint32_t SW0_B1_DONE : 1;      /*!< [3]  */
        uint32_t SW0_BUF_LINES : 2;    /*!< [5:4]  */
        uint32_t RSVD0 : 9;            /*!< [14:6]  */
        uint32_t SW0_HSK_EN : 1;       /*!< [15]  */
        uint32_t SW1_B0_READY : 1;     /*!< [16]  */
        uint32_t SW1_B1_READY : 1;     /*!< [17]  */
        uint32_t SW1_B0_DONE : 1;      /*!< [18]  */
        uint32_t SW1_B1_DONE : 1;      /*!< [19]  */
        uint32_t SW1_BUF_LINES : 2;    /*!< [21:20]  */
        uint32_t RSVD1 : 9;            /*!< [30:22]  */
        uint32_t SW1_HSK_EN : 1;       /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_handshake_cpu_fetch_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HANDSHAKE_CPU_FETCH register
 */
/*@{*/
#define HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_ADDR(x) ((uintptr_t)(x) + 0x2D30U)

#define HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH(x) (*(__IO hw_pxp_hw_pxp_handshake_cpu_fetch_t *) HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_ADDR(x))
#define HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RD(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH(x).U)
#define HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_WR(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH(x).U = (v))
#define HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SET(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_WR(x, HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_CLR(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_WR(x, HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_TOG(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_WR(x, HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HANDSHAKE_CPU_FETCH bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_FETCH, field SW0_B0_READY[0] (RO)
 *
 * PXP b0 buffer ready to CPU
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_READY (0U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_READY. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_READY (0x00000001U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_READY. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_READY (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_READY. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_READY field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_READY(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH(x).B.SW0_B0_READY)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_FETCH, field SW0_B1_READY[1] (RO)
 *
 * PXP b1 buffer ready to CPU
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_READY (1U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_READY. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_READY (0x00000002U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_READY. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_READY (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_READY. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_READY field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_READY(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH(x).B.SW0_B1_READY)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_FETCH, field SW0_B0_DONE[2] (RW)
 *
 * CPU b0 buffer done to PXP
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_DONE (2U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_DONE. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_DONE (0x00000004U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_DONE. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_DONE (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_DONE. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_DONE field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_DONE(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH(x).B.SW0_B0_DONE)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_DONE. */
#define BF_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_DONE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_DONE) & BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_DONE)

/*! @brief Set the SW0_B0_DONE field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_DONE(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_DONE) | BF_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B0_DONE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_FETCH, field SW0_B1_DONE[3] (RW)
 *
 * CPU b1 buffer done to PXP
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_DONE (3U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_DONE. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_DONE (0x00000008U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_DONE. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_DONE (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_DONE. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_DONE field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_DONE(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH(x).B.SW0_B1_DONE)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_DONE. */
#define BF_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_DONE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_DONE) & BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_DONE)

/*! @brief Set the SW0_B1_DONE field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_DONE(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_DONE) | BF_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_B1_DONE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_FETCH, field SW0_BUF_LINES[5:4] (RO)
 *
 * Buffer lines for software handshake
 *
 * Values:
 * - 0 - Buffer lines is 4 lines.
 * - 1 - Buffer lines is 8 lines.
 * - 10 - Buffer lines is 16 lines.
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_BUF_LINES (4U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_BUF_LINES. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_BUF_LINES (0x00000030U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_BUF_LINES. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_BUF_LINES (2U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_BUF_LINES. */

#define BV_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_BUF_LINES_LINE_4 (0U) /*!< Bit field value for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_BUF_LINES: Buffer lines is 4 lines. */
#define BV_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_BUF_LINES_LINE_8 (0x1U) /*!< Bit field value for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_BUF_LINES: Buffer lines is 8 lines. */
#define BV_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_BUF_LINES_LINE_16 (0x2U) /*!< Bit field value for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_BUF_LINES: Buffer lines is 16 lines. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_BUF_LINES field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_BUF_LINES(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH(x).B.SW0_BUF_LINES)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_FETCH, field RSVD0[14:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD0 (6U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD0. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD0 (0x00007FC0U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD0. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD0 (9U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD0 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD0(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_FETCH, field SW0_HSK_EN[15] (RW)
 *
 * Enable software handshake 0 with CPU
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_HSK_EN (15U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_HSK_EN. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_HSK_EN (0x00008000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_HSK_EN. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_HSK_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_HSK_EN. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_HSK_EN field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_HSK_EN(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH(x).B.SW0_HSK_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_HSK_EN. */
#define BF_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_HSK_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_HSK_EN) & BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_HSK_EN)

/*! @brief Set the SW0_HSK_EN field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_HSK_EN(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_HSK_EN) | BF_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW0_HSK_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_FETCH, field SW1_B0_READY[16] (RO)
 *
 * PXP b0 buffer ready to CPU
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_READY (16U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_READY. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_READY (0x00010000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_READY. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_READY (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_READY. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_READY field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_READY(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH(x).B.SW1_B0_READY)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_FETCH, field SW1_B1_READY[17] (RO)
 *
 * PXP b1 buffer ready to CPU
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_READY (17U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_READY. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_READY (0x00020000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_READY. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_READY (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_READY. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_READY field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_READY(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH(x).B.SW1_B1_READY)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_FETCH, field SW1_B0_DONE[18] (RW)
 *
 * CPU b0 buffer done to PXP
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_DONE (18U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_DONE. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_DONE (0x00040000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_DONE. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_DONE (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_DONE. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_DONE field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_DONE(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH(x).B.SW1_B0_DONE)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_DONE. */
#define BF_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_DONE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_DONE) & BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_DONE)

/*! @brief Set the SW1_B0_DONE field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_DONE(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_DONE) | BF_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B0_DONE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_FETCH, field SW1_B1_DONE[19] (RW)
 *
 * CPU b1 buffer done to PXP
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_DONE (19U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_DONE. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_DONE (0x00080000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_DONE. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_DONE (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_DONE. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_DONE field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_DONE(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH(x).B.SW1_B1_DONE)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_DONE. */
#define BF_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_DONE(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_DONE) & BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_DONE)

/*! @brief Set the SW1_B1_DONE field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_DONE(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_DONE) | BF_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_B1_DONE(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_FETCH, field SW1_BUF_LINES[21:20] (RO)
 *
 * Buffer lines for software handshake
 *
 * Values:
 * - 0 - Buffer lines is 4 lines.
 * - 1 - Buffer lines is 8 lines.
 * - 10 - Buffer lines is 16 lines.
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_BUF_LINES (20U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_BUF_LINES. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_BUF_LINES (0x00300000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_BUF_LINES. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_BUF_LINES (2U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_BUF_LINES. */

#define BV_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_BUF_LINES_LINE_4 (0U) /*!< Bit field value for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_BUF_LINES: Buffer lines is 4 lines. */
#define BV_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_BUF_LINES_LINE_8 (0x1U) /*!< Bit field value for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_BUF_LINES: Buffer lines is 8 lines. */
#define BV_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_BUF_LINES_LINE_16 (0x2U) /*!< Bit field value for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_BUF_LINES: Buffer lines is 16 lines. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_BUF_LINES field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_BUF_LINES(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH(x).B.SW1_BUF_LINES)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_FETCH, field RSVD1[30:22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD1 (22U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD1. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD1 (0x7FC00000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD1. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD1 (9U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD1 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RSVD1(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_FETCH, field SW1_HSK_EN[31] (RW)
 *
 * Enable software handshake 1 with CPU
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_HSK_EN (31U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_HSK_EN. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_HSK_EN (0x80000000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_HSK_EN. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_HSK_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_HSK_EN. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_HSK_EN field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_HSK_EN(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH(x).B.SW1_HSK_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_HSK_EN. */
#define BF_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_HSK_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_HSK_EN) & BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_HSK_EN)

/*! @brief Set the SW1_HSK_EN field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_HSK_EN(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_HSK_EN) | BF_PXP_HW_PXP_HANDSHAKE_CPU_FETCH_SW1_HSK_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE -
 ******************************************************************************/

/*!
 * @brief HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE -  (RW)
 *
 * Reset value: 0x00100010U
 *
 * This register defines the pxp software handshake signals with CPU.
 * HW_PXP_HANDSHAKE_CPU_STORE: 0x2D40 HW_PXP_HANDSHAKE_CPU_STORE_SET: 0x2D44
 * HW_PXP_HANDSHAKE_CPU_STORE_CLR: 0x2D48 HW_PXP_HANDSHAKE_CPU_STORE_TOG: 0x2D4C EXAMPLE
 */
typedef union _hw_pxp_hw_pxp_handshake_cpu_store
{
    uint32_t U;
    struct _hw_pxp_hw_pxp_handshake_cpu_store_bitfields
    {
        uint32_t SW0_B0_READY : 1;     /*!< [0]  */
        uint32_t SW0_B1_READY : 1;     /*!< [1]  */
        uint32_t SW0_B0_DONE : 1;      /*!< [2]  */
        uint32_t SW0_B1_DONE : 1;      /*!< [3]  */
        uint32_t SW0_BUF_LINES : 2;    /*!< [5:4]  */
        uint32_t RSVD0 : 9;            /*!< [14:6]  */
        uint32_t SW0_HSK_EN : 1;       /*!< [15]  */
        uint32_t SW1_B0_READY : 1;     /*!< [16]  */
        uint32_t SW1_B1_READY : 1;     /*!< [17]  */
        uint32_t SW1_B0_DONE : 1;      /*!< [18]  */
        uint32_t SW1_B1_DONE : 1;      /*!< [19]  */
        uint32_t SW1_BUF_LINES : 2;    /*!< [21:20]  */
        uint32_t RSVD1 : 9;            /*!< [30:22]  */
        uint32_t SW1_HSK_EN : 1;       /*!< [31]  */
    } B;
} hw_pxp_hw_pxp_handshake_cpu_store_t;

/*!
 * @name Constants and macros for entire PXP_HW_PXP_HANDSHAKE_CPU_STORE register
 */
/*@{*/
#define HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_ADDR(x) ((uintptr_t)(x) + 0x2D40U)

#define HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE(x) (*(__IO hw_pxp_hw_pxp_handshake_cpu_store_t *) HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_ADDR(x))
#define HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_RD(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE(x).U)
#define HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_WR(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE(x).U = (v))
#define HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SET(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_WR(x, HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_RD(x) |  (v)))
#define HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_CLR(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_WR(x, HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_RD(x) & ~(v)))
#define HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_TOG(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_WR(x, HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual PXP_HW_PXP_HANDSHAKE_CPU_STORE bitfields
 */

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_STORE, field SW0_B0_READY[0] (RW)
 *
 * PXP b0 buffer ready to CPU
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_READY (0U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_READY. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_READY (0x00000001U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_READY. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_READY (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_READY. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_READY field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_READY(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE(x).B.SW0_B0_READY)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_READY. */
#define BF_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_READY(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_READY) & BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_READY)

/*! @brief Set the SW0_B0_READY field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_READY(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_READY) | BF_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_READY(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_STORE, field SW0_B1_READY[1] (RW)
 *
 * PXP b1 buffer ready to CPU
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_READY (1U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_READY. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_READY (0x00000002U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_READY. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_READY (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_READY. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_READY field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_READY(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE(x).B.SW0_B1_READY)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_READY. */
#define BF_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_READY(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_READY) & BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_READY)

/*! @brief Set the SW0_B1_READY field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_READY(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_READY) | BF_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_READY(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_STORE, field SW0_B0_DONE[2] (RO)
 *
 * CPU b0 buffer done to PXP
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_DONE (2U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_DONE. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_DONE (0x00000004U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_DONE. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_DONE (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_DONE. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_DONE field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B0_DONE(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE(x).B.SW0_B0_DONE)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_STORE, field SW0_B1_DONE[3] (RO)
 *
 * CPU b1 buffer done to PXP
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_DONE (3U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_DONE. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_DONE (0x00000008U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_DONE. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_DONE (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_DONE. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_DONE field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_B1_DONE(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE(x).B.SW0_B1_DONE)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_STORE, field SW0_BUF_LINES[5:4] (RO)
 *
 * Buffer lines for software handshake
 *
 * Values:
 * - 0 - Buffer lines is 4 lines.
 * - 1 - Buffer lines is 8 lines.
 * - 10 - Buffer lines is 16 lines.
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_BUF_LINES (4U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_BUF_LINES. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_BUF_LINES (0x00000030U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_BUF_LINES. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_BUF_LINES (2U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_BUF_LINES. */

#define BV_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_BUF_LINES_LINE_4 (0U) /*!< Bit field value for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_BUF_LINES: Buffer lines is 4 lines. */
#define BV_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_BUF_LINES_LINE_8 (0x1U) /*!< Bit field value for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_BUF_LINES: Buffer lines is 8 lines. */
#define BV_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_BUF_LINES_LINE_16 (0x2U) /*!< Bit field value for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_BUF_LINES: Buffer lines is 16 lines. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_BUF_LINES field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_BUF_LINES(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE(x).B.SW0_BUF_LINES)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_STORE, field RSVD0[14:6] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD0 (6U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD0. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD0 (0x00007FC0U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD0. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD0 (9U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD0. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD0 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD0(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE(x).B.RSVD0)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_STORE, field SW0_HSK_EN[15] (RW)
 *
 * Enable software handshake 0 with CPU
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_HSK_EN (15U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_HSK_EN. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_HSK_EN (0x00008000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_HSK_EN. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_HSK_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_HSK_EN. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_HSK_EN field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_HSK_EN(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE(x).B.SW0_HSK_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_HSK_EN. */
#define BF_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_HSK_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_HSK_EN) & BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_HSK_EN)

/*! @brief Set the SW0_HSK_EN field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_HSK_EN(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_HSK_EN) | BF_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW0_HSK_EN(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_STORE, field SW1_B0_READY[16] (RW)
 *
 * PXP b0 buffer ready to CPU
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_READY (16U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_READY. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_READY (0x00010000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_READY. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_READY (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_READY. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_READY field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_READY(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE(x).B.SW1_B0_READY)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_READY. */
#define BF_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_READY(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_READY) & BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_READY)

/*! @brief Set the SW1_B0_READY field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_READY(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_READY) | BF_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_READY(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_STORE, field SW1_B1_READY[17] (RW)
 *
 * PXP b1 buffer ready to CPU
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_READY (17U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_READY. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_READY (0x00020000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_READY. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_READY (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_READY. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_READY field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_READY(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE(x).B.SW1_B1_READY)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_READY. */
#define BF_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_READY(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_READY) & BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_READY)

/*! @brief Set the SW1_B1_READY field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_READY(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_READY) | BF_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_READY(v)))
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_STORE, field SW1_B0_DONE[18] (RO)
 *
 * CPU b0 buffer done to PXP
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_DONE (18U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_DONE. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_DONE (0x00040000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_DONE. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_DONE (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_DONE. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_DONE field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B0_DONE(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE(x).B.SW1_B0_DONE)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_STORE, field SW1_B1_DONE[19] (RO)
 *
 * CPU b1 buffer done to PXP
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_DONE (19U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_DONE. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_DONE (0x00080000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_DONE. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_DONE (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_DONE. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_DONE field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_B1_DONE(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE(x).B.SW1_B1_DONE)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_STORE, field SW1_BUF_LINES[21:20] (RO)
 *
 * Buffer lines for software handshake
 *
 * Values:
 * - 0 - Buffer lines is 4 lines.
 * - 1 - Buffer lines is 8 lines.
 * - 10 - Buffer lines is 16 lines.
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_BUF_LINES (20U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_BUF_LINES. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_BUF_LINES (0x00300000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_BUF_LINES. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_BUF_LINES (2U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_BUF_LINES. */

#define BV_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_BUF_LINES_LINE_4 (0U) /*!< Bit field value for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_BUF_LINES: Buffer lines is 4 lines. */
#define BV_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_BUF_LINES_LINE_8 (0x1U) /*!< Bit field value for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_BUF_LINES: Buffer lines is 8 lines. */
#define BV_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_BUF_LINES_LINE_16 (0x2U) /*!< Bit field value for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_BUF_LINES: Buffer lines is 16 lines. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_BUF_LINES field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_BUF_LINES(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE(x).B.SW1_BUF_LINES)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_STORE, field RSVD1[30:22] (RO)
 *
 * Reserved, always set to zero.
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD1 (22U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD1. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD1 (0x7FC00000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD1. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD1 (9U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD1. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD1 field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_STORE_RSVD1(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE(x).B.RSVD1)
/*@}*/

/*!
 * @name Register PXP_HW_PXP_HANDSHAKE_CPU_STORE, field SW1_HSK_EN[31] (RW)
 *
 * Enable software handshake 1 with CPU
 */
/*@{*/
#define BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_HSK_EN (31U) /*!< Bit position for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_HSK_EN. */
#define BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_HSK_EN (0x80000000U) /*!< Bit mask for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_HSK_EN. */
#define BS_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_HSK_EN (1U) /*!< Bit field size in bits for PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_HSK_EN. */

/*! @brief Read current value of the PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_HSK_EN field. */
#define BR_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_HSK_EN(x) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE(x).B.SW1_HSK_EN)

/*! @brief Format value for bitfield PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_HSK_EN. */
#define BF_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_HSK_EN(v) ((uint32_t)((uint32_t)(v) << BP_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_HSK_EN) & BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_HSK_EN)

/*! @brief Set the SW1_HSK_EN field to a new value. */
#define BW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_HSK_EN(x, v) (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_WR(x, (HW_PXP_HW_PXP_HANDSHAKE_CPU_STORE_RD(x) & ~BM_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_HSK_EN) | BF_PXP_HW_PXP_HANDSHAKE_CPU_STORE_SW1_HSK_EN(v)))
/*@}*/

/*******************************************************************************
 * hw_pxp_t - module struct
 ******************************************************************************/
/*!
 * @brief All PXP module registers.
 */
#pragma pack(1)
typedef struct _hw_pxp
{
    __IO hw_pxp_hw_pxp_ctrl_t HW_PXP_CTRL; /*!< [0x0] Control Register 0 */
    uint8_t _reserved0[12];
    __IO hw_pxp_hw_pxp_stat_t HW_PXP_STAT; /*!< [0x10] Status Register */
    uint8_t _reserved1[12];
    __IO hw_pxp_hw_pxp_out_ctrl_t HW_PXP_OUT_CTRL; /*!< [0x20] Output Buffer Control Register */
    uint8_t _reserved2[12];
    __IO hw_pxp_hw_pxp_out_buf_t HW_PXP_OUT_BUF; /*!< [0x30] Output Frame Buffer Pointer */
    uint8_t _reserved3[12];
    __IO hw_pxp_hw_pxp_out_buf2_t HW_PXP_OUT_BUF2; /*!< [0x40] Output Frame Buffer Pointer #2 */
    uint8_t _reserved4[12];
    __IO hw_pxp_hw_pxp_out_pitch_t HW_PXP_OUT_PITCH; /*!< [0x50] Output Buffer Pitch */
    uint8_t _reserved5[12];
    __IO hw_pxp_hw_pxp_out_lrc_t HW_PXP_OUT_LRC; /*!< [0x60] Output Surface Lower Right Coordinate */
    uint8_t _reserved6[12];
    __IO hw_pxp_hw_pxp_out_ps_ulc_t HW_PXP_OUT_PS_ULC; /*!< [0x70] Processed Surface Upper Left Coordinate */
    uint8_t _reserved7[12];
    __IO hw_pxp_hw_pxp_out_ps_lrc_t HW_PXP_OUT_PS_LRC; /*!< [0x80] Processed Surface Lower Right Coordinate */
    uint8_t _reserved8[12];
    __IO hw_pxp_hw_pxp_out_as_ulc_t HW_PXP_OUT_AS_ULC; /*!< [0x90] Alpha Surface Upper Left Coordinate */
    uint8_t _reserved9[12];
    __IO hw_pxp_hw_pxp_out_as_lrc_t HW_PXP_OUT_AS_LRC; /*!< [0xA0] Alpha Surface Lower Right Coordinate */
    uint8_t _reserved10[12];
    __IO hw_pxp_hw_pxp_ps_ctrl_t HW_PXP_PS_CTRL; /*!< [0xB0] Processed Surface (PS) Control Register */
    uint8_t _reserved11[12];
    __IO hw_pxp_hw_pxp_ps_buf_t HW_PXP_PS_BUF; /*!< [0xC0] PS Input Buffer Address */
    uint8_t _reserved12[12];
    __IO hw_pxp_hw_pxp_ps_ubuf_t HW_PXP_PS_UBUF; /*!< [0xD0] PS U/Cb or 2 Plane UV Input Buffer Address */
    uint8_t _reserved13[12];
    __IO hw_pxp_hw_pxp_ps_vbuf_t HW_PXP_PS_VBUF; /*!< [0xE0] PS V/Cr Input Buffer Address */
    uint8_t _reserved14[12];
    __IO hw_pxp_hw_pxp_ps_pitch_t HW_PXP_PS_PITCH; /*!< [0xF0] Processed Surface Pitch */
    uint8_t _reserved15[12];
    __IO hw_pxp_hw_pxp_ps_background_0_t HW_PXP_PS_BACKGROUND_0; /*!< [0x100] PS Background Color */
    uint8_t _reserved16[12];
    __IO hw_pxp_hw_pxp_ps_scale_t HW_PXP_PS_SCALE; /*!< [0x110] PS Scale Factor Register */
    uint8_t _reserved17[12];
    __IO hw_pxp_hw_pxp_ps_offset_t HW_PXP_PS_OFFSET; /*!< [0x120] PS Scale Offset Register */
    uint8_t _reserved18[12];
    __IO hw_pxp_hw_pxp_ps_clrkeylow_0_t HW_PXP_PS_CLRKEYLOW_0; /*!< [0x130] PS Color Key Low */
    uint8_t _reserved19[12];
    __IO hw_pxp_hw_pxp_ps_clrkeyhigh_0_t HW_PXP_PS_CLRKEYHIGH_0; /*!< [0x140] PS Color Key High */
    uint8_t _reserved20[12];
    __IO hw_pxp_hw_pxp_as_ctrl_t HW_PXP_AS_CTRL; /*!< [0x150] Alpha Surface Control */
    uint8_t _reserved21[12];
    __IO hw_pxp_hw_pxp_as_buf_t HW_PXP_AS_BUF; /*!< [0x160] Alpha Surface Buffer Pointer */
    uint8_t _reserved22[12];
    __IO hw_pxp_hw_pxp_as_pitch_t HW_PXP_AS_PITCH; /*!< [0x170] Alpha Surface Pitch */
    uint8_t _reserved23[12];
    __IO hw_pxp_hw_pxp_as_clrkeylow_0_t HW_PXP_AS_CLRKEYLOW_0; /*!< [0x180] Overlay Color Key Low */
    uint8_t _reserved24[12];
    __IO hw_pxp_hw_pxp_as_clrkeyhigh_0_t HW_PXP_AS_CLRKEYHIGH_0; /*!< [0x190] Overlay Color Key High */
    uint8_t _reserved25[12];
    __IO hw_pxp_hw_pxp_csc1_coef0_t HW_PXP_CSC1_COEF0; /*!< [0x1A0] Color Space Conversion Coefficient Register 0 */
    uint8_t _reserved26[12];
    __IO hw_pxp_hw_pxp_csc1_coef1_t HW_PXP_CSC1_COEF1; /*!< [0x1B0] Color Space Conversion Coefficient Register 1 */
    uint8_t _reserved27[12];
    __IO hw_pxp_hw_pxp_csc1_coef2_t HW_PXP_CSC1_COEF2; /*!< [0x1C0] Color Space Conversion Coefficient Register 2 */
    uint8_t _reserved28[12];
    __IO hw_pxp_hw_pxp_csc2_ctrl_t HW_PXP_CSC2_CTRL; /*!< [0x1D0] Color Space Conversion Control Register. */
    uint8_t _reserved29[12];
    __IO hw_pxp_hw_pxp_csc2_coef0_t HW_PXP_CSC2_COEF0; /*!< [0x1E0] Color Space Conversion Coefficient Register 0 */
    uint8_t _reserved30[12];
    __IO hw_pxp_hw_pxp_csc2_coef1_t HW_PXP_CSC2_COEF1; /*!< [0x1F0] Color Space Conversion Coefficient Register 1 */
    uint8_t _reserved31[12];
    __IO hw_pxp_hw_pxp_csc2_coef2_t HW_PXP_CSC2_COEF2; /*!< [0x200] Color Space Conversion Coefficient Register 2 */
    uint8_t _reserved32[12];
    __IO hw_pxp_hw_pxp_csc2_coef3_t HW_PXP_CSC2_COEF3; /*!< [0x210] Color Space Conversion Coefficient Register 3 */
    uint8_t _reserved33[12];
    __IO hw_pxp_hw_pxp_csc2_coef4_t HW_PXP_CSC2_COEF4; /*!< [0x220] Color Space Conversion Coefficient Register 4 */
    uint8_t _reserved34[12];
    __IO hw_pxp_hw_pxp_csc2_coef5_t HW_PXP_CSC2_COEF5; /*!< [0x230] Color Space Conversion Coefficient Register 5 */
    uint8_t _reserved35[12];
    __IO hw_pxp_hw_pxp_lut_ctrl_t HW_PXP_LUT_CTRL; /*!< [0x240] Lookup Table Control Register. */
    uint8_t _reserved36[12];
    __IO hw_pxp_hw_pxp_lut_addr_t HW_PXP_LUT_ADDR; /*!< [0x250] Lookup Table Control Register. */
    uint8_t _reserved37[12];
    __IO hw_pxp_hw_pxp_lut_data_t HW_PXP_LUT_DATA; /*!< [0x260] Lookup Table Data Register. */
    uint8_t _reserved38[12];
    __IO hw_pxp_hw_pxp_lut_extmem_t HW_PXP_LUT_EXTMEM; /*!< [0x270] Lookup Table External Memory Address Register. */
    uint8_t _reserved39[12];
    __IO hw_pxp_hw_pxp_cfa_t HW_PXP_CFA;   /*!< [0x280] Color Filter Array Register. */
    uint8_t _reserved40[12];
    __IO hw_pxp_hw_pxp_alpha_a_ctrl_t HW_PXP_ALPHA_A_CTRL; /*!< [0x290] PXP Alpha Engine A Control Register. */
    uint8_t _reserved41[12];
    __IO hw_pxp_hw_pxp_alpha_b_ctrl_t HW_PXP_ALPHA_B_CTRL; /*!< [0x2A0] PXP Alpha Engine B Control Register. */
    uint8_t _reserved42[12];
    __IO hw_pxp_hw_pxp_alpha_b_ctrl_1_t HW_PXP_ALPHA_B_CTRL_1; /*!< [0x2B0]  */
    uint8_t _reserved43[12];
    __IO hw_pxp_hw_pxp_ps_background_1_t HW_PXP_PS_BACKGROUND_1; /*!< [0x2C0] PS Background Color 1 */
    uint8_t _reserved44[12];
    __IO hw_pxp_hw_pxp_ps_clrkeylow_1_t HW_PXP_PS_CLRKEYLOW_1; /*!< [0x2D0] PS Color Key Low 1 */
    uint8_t _reserved45[12];
    __IO hw_pxp_hw_pxp_ps_clrkeyhigh_1_t HW_PXP_PS_CLRKEYHIGH_1; /*!< [0x2E0] PS Color Key High 1 */
    uint8_t _reserved46[12];
    __IO hw_pxp_hw_pxp_as_clrkeylow_1_t HW_PXP_AS_CLRKEYLOW_1; /*!< [0x2F0] Overlay Color Key Low */
    uint8_t _reserved47[12];
    __IO hw_pxp_hw_pxp_as_clrkeyhigh_1_t HW_PXP_AS_CLRKEYHIGH_1; /*!< [0x300] Overlay Color Key High */
    uint8_t _reserved48[12];
    __IO hw_pxp_hw_pxp_ctrl2_t HW_PXP_CTRL2; /*!< [0x310] Control Register 2 */
    uint8_t _reserved49[12];
    __IO hw_pxp_hw_pxp_power_reg0_t HW_PXP_POWER_REG0; /*!< [0x320] PXP Power Control Register. */
    uint8_t _reserved50[12];
    __IO hw_pxp_hw_pxp_power_reg1_t HW_PXP_POWER_REG1; /*!< [0x330] PXP Power Control Register 1. */
    uint8_t _reserved51[28];
    __IO hw_pxp_hw_pxp_data_path_ctrl1_t HW_PXP_DATA_PATH_CTRL1; /*!< [0x350]  */
    uint8_t _reserved52[12];
    __IO hw_pxp_hw_pxp_init_mem_ctrl_t HW_PXP_INIT_MEM_CTRL; /*!< [0x360] Initialize memory buffer control Register */
    uint8_t _reserved53[12];
    __IO hw_pxp_hw_pxp_init_mem_data_t HW_PXP_INIT_MEM_DATA; /*!< [0x370] Write data Register */
    uint8_t _reserved54[12];
    __IO hw_pxp_hw_pxp_init_mem_data_high_t HW_PXP_INIT_MEM_DATA_HIGH; /*!< [0x380] Write data Register */
    uint8_t _reserved55[12];
    __IO hw_pxp_hw_pxp_irq_mask_t HW_PXP_IRQ_MASK; /*!< [0x390] PXP IRQ Mask Register */
    uint8_t _reserved56[12];
    __IO hw_pxp_hw_pxp_irq_t HW_PXP_IRQ;   /*!< [0x3A0] PXP Interrupt Register */
    uint8_t _reserved57[92];
    __IO hw_pxp_hw_pxp_next_t HW_PXP_NEXT; /*!< [0x400] Next Frame Pointer */
    uint8_t _reserved58[76];
    __IO hw_pxp_hw_pxp_input_fetch_ctrl_ch0_t HW_PXP_INPUT_FETCH_CTRL_CH0; /*!< [0x450] Pre-fetch engine Control Channel 0 Register */
    uint8_t _reserved59[12];
    __IO hw_pxp_hw_pxp_input_fetch_ctrl_ch1_t HW_PXP_INPUT_FETCH_CTRL_CH1; /*!< [0x460] Pre-fetch engine Control Channel 1 Register */
    uint8_t _reserved60[12];
    __I hw_pxp_hw_pxp_input_fetch_status_ch0_t HW_PXP_INPUT_FETCH_STATUS_CH0; /*!< [0x470] Pre-fetch engine status Channel 0 Register */
    uint8_t _reserved61[12];
    __I hw_pxp_hw_pxp_input_fetch_status_ch1_t HW_PXP_INPUT_FETCH_STATUS_CH1; /*!< [0x480] Store engine status Channel 1 Register */
    uint8_t _reserved62[12];
    __IO hw_pxp_hw_pxp_input_fetch_active_size_ulc_ch0_t HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH0; /*!< [0x490]  */
    uint8_t _reserved63[12];
    __IO hw_pxp_hw_pxp_input_fetch_active_size_lrc_ch0_t HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH0; /*!< [0x4A0]  */
    uint8_t _reserved64[12];
    __IO hw_pxp_hw_pxp_input_fetch_active_size_ulc_ch1_t HW_PXP_INPUT_FETCH_ACTIVE_SIZE_ULC_CH1; /*!< [0x4B0]  */
    uint8_t _reserved65[12];
    __IO hw_pxp_hw_pxp_input_fetch_active_size_lrc_ch1_t HW_PXP_INPUT_FETCH_ACTIVE_SIZE_LRC_CH1; /*!< [0x4C0]  */
    uint8_t _reserved66[12];
    __IO hw_pxp_hw_pxp_input_fetch_size_ch0_t HW_PXP_INPUT_FETCH_SIZE_CH0; /*!< [0x4D0]  */
    uint8_t _reserved67[12];
    __IO hw_pxp_hw_pxp_input_fetch_size_ch1_t HW_PXP_INPUT_FETCH_SIZE_CH1; /*!< [0x4E0]  */
    uint8_t _reserved68[12];
    __IO hw_pxp_hw_pxp_input_fetch_background_color_ch0_t HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH0; /*!< [0x4F0]  */
    uint8_t _reserved69[12];
    __IO hw_pxp_hw_pxp_input_fetch_background_color_ch1_t HW_PXP_INPUT_FETCH_BACKGROUND_COLOR_CH1; /*!< [0x500]  */
    uint8_t _reserved70[12];
    __IO hw_pxp_hw_pxp_input_fetch_pitch_t HW_PXP_INPUT_FETCH_PITCH; /*!< [0x510]  */
    uint8_t _reserved71[12];
    __IO hw_pxp_hw_pxp_input_fetch_shift_ctrl_ch0_t HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH0; /*!< [0x520]  */
    uint8_t _reserved72[12];
    __IO hw_pxp_hw_pxp_input_fetch_shift_ctrl_ch1_t HW_PXP_INPUT_FETCH_SHIFT_CTRL_CH1; /*!< [0x530]  */
    uint8_t _reserved73[12];
    __IO hw_pxp_hw_pxp_input_fetch_shift_offset_ch0_t HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH0; /*!< [0x540]  */
    uint8_t _reserved74[12];
    __IO hw_pxp_hw_pxp_input_fetch_shift_offset_ch1_t HW_PXP_INPUT_FETCH_SHIFT_OFFSET_CH1; /*!< [0x550]  */
    uint8_t _reserved75[12];
    __IO hw_pxp_hw_pxp_input_fetch_shift_width_ch0_t HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH0; /*!< [0x560]  */
    uint8_t _reserved76[12];
    __IO hw_pxp_hw_pxp_input_fetch_shift_width_ch1_t HW_PXP_INPUT_FETCH_SHIFT_WIDTH_CH1; /*!< [0x570]  */
    uint8_t _reserved77[12];
    __IO hw_pxp_hw_pxp_input_fetch_addr_0_ch0_t HW_PXP_INPUT_FETCH_ADDR_0_CH0; /*!< [0x580]  */
    uint8_t _reserved78[12];
    __IO hw_pxp_hw_pxp_input_fetch_addr_1_ch0_t HW_PXP_INPUT_FETCH_ADDR_1_CH0; /*!< [0x590]  */
    uint8_t _reserved79[12];
    __IO hw_pxp_hw_pxp_input_fetch_addr_0_ch1_t HW_PXP_INPUT_FETCH_ADDR_0_CH1; /*!< [0x5A0]  */
    uint8_t _reserved80[12];
    __IO hw_pxp_hw_pxp_input_fetch_addr_1_ch1_t HW_PXP_INPUT_FETCH_ADDR_1_CH1; /*!< [0x5B0]  */
    uint8_t _reserved81[12];
    __IO hw_pxp_hw_pxp_input_store_ctrl_ch0_t HW_PXP_INPUT_STORE_CTRL_CH0; /*!< [0x5C0] Store engine Control Channel 0 Register */
    uint8_t _reserved82[12];
    __IO hw_pxp_hw_pxp_input_store_ctrl_ch1_t HW_PXP_INPUT_STORE_CTRL_CH1; /*!< [0x5D0] Store engine Control Channel 1 Register */
    uint8_t _reserved83[12];
    __I hw_pxp_hw_pxp_input_store_status_ch0_t HW_PXP_INPUT_STORE_STATUS_CH0; /*!< [0x5E0] Store engine status Channel 0 Register */
    uint8_t _reserved84[12];
    __I hw_pxp_hw_pxp_input_store_status_ch1_t HW_PXP_INPUT_STORE_STATUS_CH1; /*!< [0x5F0] Store engine status Channel 1 Register */
    uint8_t _reserved85[12];
    __IO hw_pxp_hw_pxp_input_store_size_ch0_t HW_PXP_INPUT_STORE_SIZE_CH0; /*!< [0x600]  */
    uint8_t _reserved86[12];
    __IO hw_pxp_hw_pxp_input_store_size_ch1_t HW_PXP_INPUT_STORE_SIZE_CH1; /*!< [0x610]  */
    uint8_t _reserved87[12];
    __IO hw_pxp_hw_pxp_input_store_pitch_t HW_PXP_INPUT_STORE_PITCH; /*!< [0x620]  */
    uint8_t _reserved88[12];
    __IO hw_pxp_hw_pxp_input_store_shift_ctrl_ch0_t HW_PXP_INPUT_STORE_SHIFT_CTRL_CH0; /*!< [0x630]  */
    uint8_t _reserved89[12];
    __IO hw_pxp_hw_pxp_input_store_shift_ctrl_ch1_t HW_PXP_INPUT_STORE_SHIFT_CTRL_CH1; /*!< [0x640]  */
    uint8_t _reserved90[76];
    __IO hw_pxp_hw_pxp_input_store_addr_0_ch0_t HW_PXP_INPUT_STORE_ADDR_0_CH0; /*!< [0x690]  */
    uint8_t _reserved91[12];
    __IO hw_pxp_hw_pxp_input_store_addr_1_ch0_t HW_PXP_INPUT_STORE_ADDR_1_CH0; /*!< [0x6A0]  */
    uint8_t _reserved92[12];
    __IO hw_pxp_hw_pxp_input_store_fill_data_ch0_t HW_PXP_INPUT_STORE_FILL_DATA_CH0; /*!< [0x6B0]  */
    uint8_t _reserved93[12];
    __IO hw_pxp_hw_pxp_input_store_addr_0_ch1_t HW_PXP_INPUT_STORE_ADDR_0_CH1; /*!< [0x6C0]  */
    uint8_t _reserved94[12];
    __IO hw_pxp_hw_pxp_input_store_addr_1_ch1_t HW_PXP_INPUT_STORE_ADDR_1_CH1; /*!< [0x6D0]  */
    uint8_t _reserved95[12];
    __IO hw_pxp_hw_pxp_input_store_d_mask0_h_ch0_t HW_PXP_INPUT_STORE_D_MASK0_H_CH0; /*!< [0x6E0]  */
    uint8_t _reserved96[12];
    __IO hw_pxp_hw_pxp_input_store_d_mask0_l_ch0_t HW_PXP_INPUT_STORE_D_MASK0_L_CH0; /*!< [0x6F0]  */
    uint8_t _reserved97[12];
    __IO hw_pxp_hw_pxp_input_store_d_mask1_h_ch0_t HW_PXP_INPUT_STORE_D_MASK1_H_CH0; /*!< [0x700]  */
    uint8_t _reserved98[12];
    __IO hw_pxp_hw_pxp_input_store_d_mask1_l_ch0_t HW_PXP_INPUT_STORE_D_MASK1_L_CH0; /*!< [0x710]  */
    uint8_t _reserved99[12];
    __IO hw_pxp_hw_pxp_input_store_d_mask2_h_ch0_t HW_PXP_INPUT_STORE_D_MASK2_H_CH0; /*!< [0x720]  */
    uint8_t _reserved100[12];
    __IO hw_pxp_hw_pxp_input_store_d_mask2_l_ch0_t HW_PXP_INPUT_STORE_D_MASK2_L_CH0; /*!< [0x730]  */
    uint8_t _reserved101[12];
    __IO hw_pxp_hw_pxp_input_store_d_mask3_h_ch0_t HW_PXP_INPUT_STORE_D_MASK3_H_CH0; /*!< [0x740]  */
    uint8_t _reserved102[12];
    __IO hw_pxp_hw_pxp_input_store_d_mask3_l_ch0_t HW_PXP_INPUT_STORE_D_MASK3_L_CH0; /*!< [0x750]  */
    uint8_t _reserved103[12];
    __IO hw_pxp_hw_pxp_input_store_d_mask4_h_ch0_t HW_PXP_INPUT_STORE_D_MASK4_H_CH0; /*!< [0x760]  */
    uint8_t _reserved104[12];
    __IO hw_pxp_hw_pxp_input_store_d_mask4_l_ch0_t HW_PXP_INPUT_STORE_D_MASK4_L_CH0; /*!< [0x770]  */
    uint8_t _reserved105[12];
    __IO hw_pxp_hw_pxp_input_store_d_mask5_h_ch0_t HW_PXP_INPUT_STORE_D_MASK5_H_CH0; /*!< [0x780]  */
    uint8_t _reserved106[12];
    __IO hw_pxp_hw_pxp_input_store_d_mask5_l_ch0_t HW_PXP_INPUT_STORE_D_MASK5_L_CH0; /*!< [0x790]  */
    uint8_t _reserved107[12];
    __IO hw_pxp_hw_pxp_input_store_d_mask6_h_ch0_t HW_PXP_INPUT_STORE_D_MASK6_H_CH0; /*!< [0x7A0]  */
    uint8_t _reserved108[12];
    __IO hw_pxp_hw_pxp_input_store_d_mask6_l_ch0_t HW_PXP_INPUT_STORE_D_MASK6_L_CH0; /*!< [0x7B0]  */
    uint8_t _reserved109[12];
    __IO hw_pxp_hw_pxp_input_store_d_mask7_h_ch0_t HW_PXP_INPUT_STORE_D_MASK7_H_CH0; /*!< [0x7C0]  */
    uint8_t _reserved110[28];
    __IO hw_pxp_hw_pxp_input_store_d_mask7_l_ch0_t HW_PXP_INPUT_STORE_D_MASK7_L_CH0; /*!< [0x7E0]  */
    uint8_t _reserved111[12];
    __IO hw_pxp_hw_pxp_input_store_d_shift_l_ch0_t HW_PXP_INPUT_STORE_D_SHIFT_L_CH0; /*!< [0x7F0]  */
    uint8_t _reserved112[12];
    __IO hw_pxp_hw_pxp_input_store_d_shift_h_ch0_t HW_PXP_INPUT_STORE_D_SHIFT_H_CH0; /*!< [0x800]  */
    uint8_t _reserved113[12];
    __IO hw_pxp_hw_pxp_input_store_f_shift_l_ch0_t HW_PXP_INPUT_STORE_F_SHIFT_L_CH0; /*!< [0x810]  */
    uint8_t _reserved114[12];
    __IO hw_pxp_hw_pxp_input_store_f_shift_h_ch0_t HW_PXP_INPUT_STORE_F_SHIFT_H_CH0; /*!< [0x820]  */
    uint8_t _reserved115[12];
    __IO hw_pxp_hw_pxp_input_store_f_mask_l_ch0_t HW_PXP_INPUT_STORE_F_MASK_L_CH0; /*!< [0x830]  */
    uint8_t _reserved116[12];
    __IO hw_pxp_hw_pxp_input_store_f_mask_h_ch0_t HW_PXP_INPUT_STORE_F_MASK_H_CH0; /*!< [0x840]  */
    uint8_t _reserved117[12];
    __IO hw_pxp_hw_pxp_dither_fetch_ctrl_ch0_t HW_PXP_DITHER_FETCH_CTRL_CH0; /*!< [0x850] Pre-fetch engine Control Channel 0 Register */
    uint8_t _reserved118[12];
    __IO hw_pxp_hw_pxp_dither_fetch_ctrl_ch1_t HW_PXP_DITHER_FETCH_CTRL_CH1; /*!< [0x860] Pre-fetch engine Control Channel 1 Register */
    uint8_t _reserved119[12];
    __I hw_pxp_hw_pxp_dither_fetch_status_ch0_t HW_PXP_DITHER_FETCH_STATUS_CH0; /*!< [0x870] Pre-fetch engine status Channel 0 Register */
    uint8_t _reserved120[12];
    __I hw_pxp_hw_pxp_dither_fetch_status_ch1_t HW_PXP_DITHER_FETCH_STATUS_CH1; /*!< [0x880] Store engine status Channel 1 Register */
    uint8_t _reserved121[12];
    __IO hw_pxp_hw_pxp_dither_fetch_active_size_ulc_ch0_t HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH0; /*!< [0x890]  */
    uint8_t _reserved122[12];
    __IO hw_pxp_hw_pxp_dither_fetch_active_size_lrc_ch0_t HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH0; /*!< [0x8A0]  */
    uint8_t _reserved123[12];
    __IO hw_pxp_hw_pxp_dither_fetch_active_size_ulc_ch1_t HW_PXP_DITHER_FETCH_ACTIVE_SIZE_ULC_CH1; /*!< [0x8B0]  */
    uint8_t _reserved124[12];
    __IO hw_pxp_hw_pxp_dither_fetch_active_size_lrc_ch1_t HW_PXP_DITHER_FETCH_ACTIVE_SIZE_LRC_CH1; /*!< [0x8C0]  */
    uint8_t _reserved125[12];
    __IO hw_pxp_hw_pxp_dither_fetch_size_ch0_t HW_PXP_DITHER_FETCH_SIZE_CH0; /*!< [0x8D0]  */
    uint8_t _reserved126[12];
    __IO hw_pxp_hw_pxp_dither_fetch_size_ch1_t HW_PXP_DITHER_FETCH_SIZE_CH1; /*!< [0x8E0]  */
    uint8_t _reserved127[12];
    __IO hw_pxp_hw_pxp_dither_fetch_background_color_ch0_t HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH0; /*!< [0x8F0]  */
    uint8_t _reserved128[12];
    __IO hw_pxp_hw_pxp_dither_fetch_background_color_ch1_t HW_PXP_DITHER_FETCH_BACKGROUND_COLOR_CH1; /*!< [0x900]  */
    uint8_t _reserved129[12];
    __IO hw_pxp_hw_pxp_dither_fetch_pitch_t HW_PXP_DITHER_FETCH_PITCH; /*!< [0x910]  */
    uint8_t _reserved130[12];
    __IO hw_pxp_hw_pxp_dither_fetch_shift_ctrl_ch0_t HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH0; /*!< [0x920]  */
    uint8_t _reserved131[12];
    __IO hw_pxp_hw_pxp_dither_fetch_shift_ctrl_ch1_t HW_PXP_DITHER_FETCH_SHIFT_CTRL_CH1; /*!< [0x930]  */
    uint8_t _reserved132[12];
    __IO hw_pxp_hw_pxp_dither_fetch_shift_offset_ch0_t HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH0; /*!< [0x940]  */
    uint8_t _reserved133[12];
    __IO hw_pxp_hw_pxp_dither_fetch_shift_offset_ch1_t HW_PXP_DITHER_FETCH_SHIFT_OFFSET_CH1; /*!< [0x950]  */
    uint8_t _reserved134[12];
    __IO hw_pxp_hw_pxp_dither_fetch_shift_width_ch0_t HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH0; /*!< [0x960]  */
    uint8_t _reserved135[12];
    __IO hw_pxp_hw_pxp_dither_fetch_shift_width_ch1_t HW_PXP_DITHER_FETCH_SHIFT_WIDTH_CH1; /*!< [0x970]  */
    uint8_t _reserved136[12];
    __IO hw_pxp_hw_pxp_dither_fetch_addr_0_ch0_t HW_PXP_DITHER_FETCH_ADDR_0_CH0; /*!< [0x980]  */
    uint8_t _reserved137[12];
    __IO hw_pxp_hw_pxp_dither_fetch_addr_1_ch0_t HW_PXP_DITHER_FETCH_ADDR_1_CH0; /*!< [0x990]  */
    uint8_t _reserved138[12];
    __IO hw_pxp_hw_pxp_dither_fetch_addr_0_ch1_t HW_PXP_DITHER_FETCH_ADDR_0_CH1; /*!< [0x9A0]  */
    uint8_t _reserved139[12];
    __IO hw_pxp_hw_pxp_dither_fetch_addr_1_ch1_t HW_PXP_DITHER_FETCH_ADDR_1_CH1; /*!< [0x9B0]  */
    uint8_t _reserved140[12];
    __IO hw_pxp_hw_pxp_dither_store_ctrl_ch0_t HW_PXP_DITHER_STORE_CTRL_CH0; /*!< [0x9C0] Store engine Control Channel 0 Register */
    uint8_t _reserved141[12];
    __IO hw_pxp_hw_pxp_dither_store_ctrl_ch1_t HW_PXP_DITHER_STORE_CTRL_CH1; /*!< [0x9D0] Store engine Control Channel 1 Register */
    uint8_t _reserved142[12];
    __I hw_pxp_hw_pxp_dither_store_status_ch0_t HW_PXP_DITHER_STORE_STATUS_CH0; /*!< [0x9E0] Store engine status Channel 0 Register */
    uint8_t _reserved143[12];
    __I hw_pxp_hw_pxp_dither_store_status_ch1_t HW_PXP_DITHER_STORE_STATUS_CH1; /*!< [0x9F0] Store engine status Channel 1 Register */
    uint8_t _reserved144[12];
    __IO hw_pxp_hw_pxp_dither_store_size_ch0_t HW_PXP_DITHER_STORE_SIZE_CH0; /*!< [0xA00]  */
    uint8_t _reserved145[12];
    __IO hw_pxp_hw_pxp_dither_store_size_ch1_t HW_PXP_DITHER_STORE_SIZE_CH1; /*!< [0xA10]  */
    uint8_t _reserved146[12];
    __IO hw_pxp_hw_pxp_dither_store_pitch_t HW_PXP_DITHER_STORE_PITCH; /*!< [0xA20]  */
    uint8_t _reserved147[12];
    __IO hw_pxp_hw_pxp_dither_store_shift_ctrl_ch0_t HW_PXP_DITHER_STORE_SHIFT_CTRL_CH0; /*!< [0xA30]  */
    uint8_t _reserved148[12];
    __IO hw_pxp_hw_pxp_dither_store_shift_ctrl_ch1_t HW_PXP_DITHER_STORE_SHIFT_CTRL_CH1; /*!< [0xA40]  */
    uint8_t _reserved149[76];
    __IO hw_pxp_hw_pxp_dither_store_addr_0_ch0_t HW_PXP_DITHER_STORE_ADDR_0_CH0; /*!< [0xA90]  */
    uint8_t _reserved150[12];
    __IO hw_pxp_hw_pxp_dither_store_addr_1_ch0_t HW_PXP_DITHER_STORE_ADDR_1_CH0; /*!< [0xAA0]  */
    uint8_t _reserved151[12];
    __IO hw_pxp_hw_pxp_dither_store_fill_data_ch0_t HW_PXP_DITHER_STORE_FILL_DATA_CH0; /*!< [0xAB0]  */
    uint8_t _reserved152[12];
    __IO hw_pxp_hw_pxp_dither_store_addr_0_ch1_t HW_PXP_DITHER_STORE_ADDR_0_CH1; /*!< [0xAC0]  */
    uint8_t _reserved153[12];
    __IO hw_pxp_hw_pxp_dither_store_addr_1_ch1_t HW_PXP_DITHER_STORE_ADDR_1_CH1; /*!< [0xAD0]  */
    uint8_t _reserved154[12];
    __IO hw_pxp_hw_pxp_dither_store_d_mask0_h_ch0_t HW_PXP_DITHER_STORE_D_MASK0_H_CH0; /*!< [0xAE0]  */
    uint8_t _reserved155[12];
    __IO hw_pxp_hw_pxp_dither_store_d_mask0_l_ch0_t HW_PXP_DITHER_STORE_D_MASK0_L_CH0; /*!< [0xAF0]  */
    uint8_t _reserved156[12];
    __IO hw_pxp_hw_pxp_dither_store_d_mask1_h_ch0_t HW_PXP_DITHER_STORE_D_MASK1_H_CH0; /*!< [0xB00]  */
    uint8_t _reserved157[12];
    __IO hw_pxp_hw_pxp_dither_store_d_mask1_l_ch0_t HW_PXP_DITHER_STORE_D_MASK1_L_CH0; /*!< [0xB10]  */
    uint8_t _reserved158[12];
    __IO hw_pxp_hw_pxp_dither_store_d_mask2_h_ch0_t HW_PXP_DITHER_STORE_D_MASK2_H_CH0; /*!< [0xB20]  */
    uint8_t _reserved159[12];
    __IO hw_pxp_hw_pxp_dither_store_d_mask2_l_ch0_t HW_PXP_DITHER_STORE_D_MASK2_L_CH0; /*!< [0xB30]  */
    uint8_t _reserved160[12];
    __IO hw_pxp_hw_pxp_dither_store_d_mask3_h_ch0_t HW_PXP_DITHER_STORE_D_MASK3_H_CH0; /*!< [0xB40]  */
    uint8_t _reserved161[12];
    __IO hw_pxp_hw_pxp_dither_store_d_mask3_l_ch0_t HW_PXP_DITHER_STORE_D_MASK3_L_CH0; /*!< [0xB50]  */
    uint8_t _reserved162[12];
    __IO hw_pxp_hw_pxp_dither_store_d_mask4_h_ch0_t HW_PXP_DITHER_STORE_D_MASK4_H_CH0; /*!< [0xB60]  */
    uint8_t _reserved163[12];
    __IO hw_pxp_hw_pxp_dither_store_d_mask4_l_ch0_t HW_PXP_DITHER_STORE_D_MASK4_L_CH0; /*!< [0xB70]  */
    uint8_t _reserved164[12];
    __IO hw_pxp_hw_pxp_dither_store_d_mask5_h_ch0_t HW_PXP_DITHER_STORE_D_MASK5_H_CH0; /*!< [0xB80]  */
    uint8_t _reserved165[12];
    __IO hw_pxp_hw_pxp_dither_store_d_mask5_l_ch0_t HW_PXP_DITHER_STORE_D_MASK5_L_CH0; /*!< [0xB90]  */
    uint8_t _reserved166[12];
    __IO hw_pxp_hw_pxp_dither_store_d_mask6_h_ch0_t HW_PXP_DITHER_STORE_D_MASK6_H_CH0; /*!< [0xBA0]  */
    uint8_t _reserved167[12];
    __IO hw_pxp_hw_pxp_dither_store_d_mask6_l_ch0_t HW_PXP_DITHER_STORE_D_MASK6_L_CH0; /*!< [0xBB0]  */
    uint8_t _reserved168[12];
    __IO hw_pxp_hw_pxp_dither_store_d_mask7_h_ch0_t HW_PXP_DITHER_STORE_D_MASK7_H_CH0; /*!< [0xBC0]  */
    uint8_t _reserved169[12];
    __IO hw_pxp_hw_pxp_dither_store_d_mask7_l_ch0_t HW_PXP_DITHER_STORE_D_MASK7_L_CH0; /*!< [0xBD0]  */
    uint8_t _reserved170[12];
    __IO hw_pxp_hw_pxp_dither_store_d_shift_l_ch0_t HW_PXP_DITHER_STORE_D_SHIFT_L_CH0; /*!< [0xBE0]  */
    uint8_t _reserved171[12];
    __IO hw_pxp_hw_pxp_dither_store_d_shift_h_ch0_t HW_PXP_DITHER_STORE_D_SHIFT_H_CH0; /*!< [0xBF0]  */
    uint8_t _reserved172[12];
    __IO hw_pxp_hw_pxp_dither_store_f_shift_l_ch0_t HW_PXP_DITHER_STORE_F_SHIFT_L_CH0; /*!< [0xC00]  */
    uint8_t _reserved173[12];
    __IO hw_pxp_hw_pxp_dither_store_f_shift_h_ch0_t HW_PXP_DITHER_STORE_F_SHIFT_H_CH0; /*!< [0xC10]  */
    uint8_t _reserved174[12];
    __IO hw_pxp_hw_pxp_dither_store_f_mask_l_ch0_t HW_PXP_DITHER_STORE_F_MASK_L_CH0; /*!< [0xC20]  */
    uint8_t _reserved175[12];
    __IO hw_pxp_hw_pxp_dither_store_f_mask_h_ch0_t HW_PXP_DITHER_STORE_F_MASK_H_CH0; /*!< [0xC30]  */
    uint8_t _reserved176[2620];
    __IO hw_pxp_hw_pxp_dither_ctrl_t HW_PXP_DITHER_CTRL; /*!< [0x1670] Dither Control Register 0 */
    uint8_t _reserved177[12];
    __IO hw_pxp_hw_pxp_dither_final_lut_data0_t HW_PXP_DITHER_FINAL_LUT_DATA0; /*!< [0x1680] Final stage lookup value Register */
    uint8_t _reserved178[12];
    __IO hw_pxp_hw_pxp_dither_final_lut_data1_t HW_PXP_DITHER_FINAL_LUT_DATA1; /*!< [0x1690] Final stage lookup value Register */
    uint8_t _reserved179[12];
    __IO hw_pxp_hw_pxp_dither_final_lut_data2_t HW_PXP_DITHER_FINAL_LUT_DATA2; /*!< [0x16A0] Final stage lookup value Register */
    uint8_t _reserved180[12];
    __IO hw_pxp_hw_pxp_dither_final_lut_data3_t HW_PXP_DITHER_FINAL_LUT_DATA3; /*!< [0x16B0] Final stage lookup value Register */
    uint8_t _reserved181[4940];
    __IO hw_pxp_hw_pxp_hist_a_ctrl_t HW_PXP_HIST_A_CTRL; /*!< [0x2A00] Histogram Control Register. */
    uint8_t _reserved182[12];
    __IO hw_pxp_hw_pxp_hist_a_mask_t HW_PXP_HIST_A_MASK; /*!< [0x2A10] Histogram Pixel Mask Register. */
    uint8_t _reserved183[12];
    __IO hw_pxp_hw_pxp_hist_a_buf_size_t HW_PXP_HIST_A_BUF_SIZE; /*!< [0x2A20] Histogram Pixel Buffer Size Register. */
    uint8_t _reserved184[12];
    __I hw_pxp_hw_pxp_hist_a_total_pixel_t HW_PXP_HIST_A_TOTAL_PIXEL; /*!< [0x2A30] Total Number of Pixels Used by Histogram Engine. */
    uint8_t _reserved185[12];
    __I hw_pxp_hw_pxp_hist_a_active_area_x_t HW_PXP_HIST_A_ACTIVE_AREA_X; /*!< [0x2A40] The X Coordinate Offset for Active Area. */
    uint8_t _reserved186[12];
    __I hw_pxp_hw_pxp_hist_a_active_area_y_t HW_PXP_HIST_A_ACTIVE_AREA_Y; /*!< [0x2A50] The Y Coordinate Offset for Active Area. */
    uint8_t _reserved187[12];
    __I hw_pxp_hw_pxp_hist_a_raw_stat0_t HW_PXP_HIST_A_RAW_STAT0; /*!< [0x2A60] Histogram Result Based on RAW Pixel Value. */
    uint8_t _reserved188[12];
    __I hw_pxp_hw_pxp_hist_a_raw_stat1_t HW_PXP_HIST_A_RAW_STAT1; /*!< [0x2A70] Histogram Result Based on RAW Pixel Value. */
    uint8_t _reserved189[12];
    __IO hw_pxp_hw_pxp_hist_b_ctrl_t HW_PXP_HIST_B_CTRL; /*!< [0x2A80] Histogram Control Register. */
    uint8_t _reserved190[12];
    __IO hw_pxp_hw_pxp_hist_b_mask_t HW_PXP_HIST_B_MASK; /*!< [0x2A90] Histogram Pixel Mask Register. */
    uint8_t _reserved191[12];
    __IO hw_pxp_hw_pxp_hist_b_buf_size_t HW_PXP_HIST_B_BUF_SIZE; /*!< [0x2AA0] Histogram Pixel Buffer Size Register. */
    uint8_t _reserved192[12];
    __I hw_pxp_hw_pxp_hist_b_total_pixel_t HW_PXP_HIST_B_TOTAL_PIXEL; /*!< [0x2AB0] Total Number of Pixels Used by Histogram Engine. */
    uint8_t _reserved193[12];
    __I hw_pxp_hw_pxp_hist_b_active_area_x_t HW_PXP_HIST_B_ACTIVE_AREA_X; /*!< [0x2AC0] The X Coordinate Offset for Active Area. */
    uint8_t _reserved194[12];
    __I hw_pxp_hw_pxp_hist_b_active_area_y_t HW_PXP_HIST_B_ACTIVE_AREA_Y; /*!< [0x2AD0] The Y Coordinate Offset for Active Area. */
    uint8_t _reserved195[12];
    __I hw_pxp_hw_pxp_hist_b_raw_stat0_t HW_PXP_HIST_B_RAW_STAT0; /*!< [0x2AE0] Histogram Result Based on RAW Pixel Value. */
    uint8_t _reserved196[12];
    __I hw_pxp_hw_pxp_hist_b_raw_stat1_t HW_PXP_HIST_B_RAW_STAT1; /*!< [0x2AF0] Histogram Result Based on RAW Pixel Value. */
    uint8_t _reserved197[12];
    __IO hw_pxp_hw_pxp_hist2_param_t HW_PXP_HIST2_PARAM; /*!< [0x2B00] 2-level Histogram Parameter Register. */
    uint8_t _reserved198[12];
    __IO hw_pxp_hw_pxp_hist4_param_t HW_PXP_HIST4_PARAM; /*!< [0x2B10] 4-level Histogram Parameter Register. */
    uint8_t _reserved199[12];
    __IO hw_pxp_hw_pxp_hist8_param0_t HW_PXP_HIST8_PARAM0; /*!< [0x2B20] 8-level Histogram Parameter 0 Register. */
    uint8_t _reserved200[12];
    __IO hw_pxp_hw_pxp_hist8_param1_t HW_PXP_HIST8_PARAM1; /*!< [0x2B30] 8-level Histogram Parameter 1 Register. */
    uint8_t _reserved201[12];
    __IO hw_pxp_hw_pxp_hist16_param0_t HW_PXP_HIST16_PARAM0; /*!< [0x2B40] 16-level Histogram Parameter 0 Register. */
    uint8_t _reserved202[12];
    __IO hw_pxp_hw_pxp_hist16_param1_t HW_PXP_HIST16_PARAM1; /*!< [0x2B50] 16-level Histogram Parameter 1 Register. */
    uint8_t _reserved203[12];
    __IO hw_pxp_hw_pxp_hist16_param2_t HW_PXP_HIST16_PARAM2; /*!< [0x2B60] 16-level Histogram Parameter 2 Register. */
    uint8_t _reserved204[12];
    __IO hw_pxp_hw_pxp_hist16_param3_t HW_PXP_HIST16_PARAM3; /*!< [0x2B70] 16-level Histogram Parameter 3 Register. */
    uint8_t _reserved205[12];
    __IO hw_pxp_hw_pxp_hist32_param0_t HW_PXP_HIST32_PARAM0; /*!< [0x2B80] 32-level Histogram Parameter 0 Register. */
    uint8_t _reserved206[12];
    __IO hw_pxp_hw_pxp_hist32_param1_t HW_PXP_HIST32_PARAM1; /*!< [0x2B90] 32-level Histogram Parameter 1 Register. */
    uint8_t _reserved207[12];
    __IO hw_pxp_hw_pxp_hist32_param2_t HW_PXP_HIST32_PARAM2; /*!< [0x2BA0] 32-level Histogram Parameter 2 Register. */
    uint8_t _reserved208[12];
    __IO hw_pxp_hw_pxp_hist32_param3_t HW_PXP_HIST32_PARAM3; /*!< [0x2BB0] 32-level Histogram Parameter 3 Register. */
    uint8_t _reserved209[12];
    __IO hw_pxp_hw_pxp_hist32_param4_t HW_PXP_HIST32_PARAM4; /*!< [0x2BC0] 32-level Histogram Parameter 0 Register. */
    uint8_t _reserved210[12];
    __IO hw_pxp_hw_pxp_hist32_param5_t HW_PXP_HIST32_PARAM5; /*!< [0x2BD0] 32-level Histogram Parameter 1 Register. */
    uint8_t _reserved211[12];
    __IO hw_pxp_hw_pxp_hist32_param6_t HW_PXP_HIST32_PARAM6; /*!< [0x2BE0] 32-level Histogram Parameter 2 Register. */
    uint8_t _reserved212[12];
    __IO hw_pxp_hw_pxp_hist32_param7_t HW_PXP_HIST32_PARAM7; /*!< [0x2BF0] 32-level Histogram Parameter 3 Register. */
    uint8_t _reserved213[12];
    __IO hw_pxp_hw_pxp_comp_ctrl_t HW_PXP_COMP_CTRL; /*!< [0x2C00]  */
    uint8_t _reserved214[12];
    __IO hw_pxp_hw_pxp_comp_format0_t HW_PXP_COMP_FORMAT0; /*!< [0x2C10]  */
    uint8_t _reserved215[12];
    __IO hw_pxp_hw_pxp_comp_format1_t HW_PXP_COMP_FORMAT1; /*!< [0x2C20]  */
    uint8_t _reserved216[12];
    __IO hw_pxp_hw_pxp_comp_format2_t HW_PXP_COMP_FORMAT2; /*!< [0x2C30]  */
    uint8_t _reserved217[12];
    __IO hw_pxp_hw_pxp_comp_mask0_t HW_PXP_COMP_MASK0; /*!< [0x2C40]  */
    uint8_t _reserved218[12];
    __IO hw_pxp_hw_pxp_comp_mask1_t HW_PXP_COMP_MASK1; /*!< [0x2C50]  */
    uint8_t _reserved219[12];
    __IO hw_pxp_hw_pxp_comp_buffer_size_t HW_PXP_COMP_BUFFER_SIZE; /*!< [0x2C60]  */
    uint8_t _reserved220[12];
    __IO hw_pxp_hw_pxp_comp_source_t HW_PXP_COMP_SOURCE; /*!< [0x2C70]  */
    uint8_t _reserved221[12];
    __IO hw_pxp_hw_pxp_comp_target_t HW_PXP_COMP_TARGET; /*!< [0x2C80]  */
    uint8_t _reserved222[12];
    __IO hw_pxp_hw_pxp_comp_buffer_a_t HW_PXP_COMP_BUFFER_A; /*!< [0x2C90]  */
    uint8_t _reserved223[12];
    __IO hw_pxp_hw_pxp_comp_buffer_b_t HW_PXP_COMP_BUFFER_B; /*!< [0x2CA0]  */
    uint8_t _reserved224[12];
    __IO hw_pxp_hw_pxp_comp_buffer_c_t HW_PXP_COMP_BUFFER_C; /*!< [0x2CB0]  */
    uint8_t _reserved225[12];
    __IO hw_pxp_hw_pxp_comp_buffer_d_t HW_PXP_COMP_BUFFER_D; /*!< [0x2CC0]  */
    uint8_t _reserved226[12];
    __IO hw_pxp_hw_pxp_comp_debug_t HW_PXP_COMP_DEBUG; /*!< [0x2CD0]  */
    uint8_t _reserved227[12];
    __IO hw_pxp_hw_pxp_bus_mux_t HW_PXP_BUS_MUX; /*!< [0x2CE0]  */
    uint8_t _reserved228[12];
    __IO hw_pxp_hw_pxp_handshake_ready_mux0_t HW_PXP_HANDSHAKE_READY_MUX0; /*!< [0x2CF0]  */
    uint8_t _reserved229[12];
    __IO hw_pxp_hw_pxp_handshake_ready_mux1_t HW_PXP_HANDSHAKE_READY_MUX1; /*!< [0x2D00]  */
    uint8_t _reserved230[12];
    __IO hw_pxp_hw_pxp_handshake_done_mux0_t HW_PXP_HANDSHAKE_DONE_MUX0; /*!< [0x2D10]  */
    uint8_t _reserved231[12];
    __IO hw_pxp_hw_pxp_handshake_done_mux1_t HW_PXP_HANDSHAKE_DONE_MUX1; /*!< [0x2D20]  */
    uint8_t _reserved232[12];
    __IO hw_pxp_hw_pxp_handshake_cpu_fetch_t HW_PXP_HANDSHAKE_CPU_FETCH; /*!< [0x2D30]  */
    uint8_t _reserved233[12];
    __IO hw_pxp_hw_pxp_handshake_cpu_store_t HW_PXP_HANDSHAKE_CPU_STORE; /*!< [0x2D40]  */
} hw_pxp_t;
#pragma pack()

/*! @brief Macro to access all PXP registers. */
/*! @param x PXP module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_PXP_REGS(PXP_BASE)</code>. */
#define HW_PXP_REGS(x) (*(hw_pxp_t *)(x))

/*
 * iMX7D QuadSPI
 *
 * QuadSPI
 *
 * Registers defined in this header file:
 * - HW_QuadSPI_MCR - Module Configuration Register
 * - HW_QuadSPI_IPCR - IP Configuration Register
 * - HW_QuadSPI_FLSHCR - Flash Configuration Register
 * - HW_QuadSPI_BUF0CR - Buffer0 Configuration Register
 * - HW_QuadSPI_BUF1CR - Buffer1 Configuration Register
 * - HW_QuadSPI_BUF2CR - Buffer2 Configuration Register
 * - HW_QuadSPI_BUF3CR - Buffer3 Configuration Register
 * - HW_QuadSPI_BFGENCR - Buffer Generic Configuration Register
 * - HW_QuadSPI_BUF0IND - Buffer0 Top Index Register
 * - HW_QuadSPI_BUF1IND - Buffer1 Top Index Register
 * - HW_QuadSPI_BUF2IND - Buffer2 Top Index Register
 * - HW_QuadSPI_SFAR - Serial Flash Address Register
 * - HW_QuadSPI_SMPR - Sampling Register
 * - HW_QuadSPI_RBSR - RX Buffer Status Register
 * - HW_QuadSPI_RBCT - RX Buffer Control Register
 * - HW_QuadSPI_TBSR - TX Buffer Status Register
 * - HW_QuadSPI_TBDR - TX Buffer Data Register
 * - HW_QuadSPI_SR - Status Register
 * - HW_QuadSPI_FR - Flag Register
 * - HW_QuadSPI_RSER - Interrupt and DMA Request Select and Enable Register
 * - HW_QuadSPI_SPNDST - Sequence Suspend Status Register
 * - HW_QuadSPI_SPTRCLR - Sequence Pointer Clear Register
 * - HW_QuadSPI_SFA1AD - Serial Flash A1 Top Address
 * - HW_QuadSPI_SFA2AD - Serial Flash A2 Top Address
 * - HW_QuadSPI_SFB1AD - Serial Flash B1Top Address
 * - HW_QuadSPI_SFB2AD - Serial Flash B2Top Address
 * - HW_QuadSPI_RBDRn - RX Buffer Data Register
 * - HW_QuadSPI_LUTKEY - LUT Key Register
 * - HW_QuadSPI_LCKCR - LUT Lock Configuration Register
 * - HW_QuadSPI_LUT0 - Look-up Table register
 * - HW_QuadSPI_LUT1 - Look-up Table register
 * - HW_QuadSPI_LUT2 - Look-up Table register
 * - HW_QuadSPI_LUT3 - Look-up Table register
 * - HW_QuadSPI_LUT4 - Look-up Table register
 * - HW_QuadSPI_LUT5 - Look-up Table register
 * - HW_QuadSPI_LUT6 - Look-up Table register
 * - HW_QuadSPI_LUT7 - Look-up Table register
 * - HW_QuadSPI_LUT8 - Look-up Table register
 * - HW_QuadSPI_LUT9 - Look-up Table register
 * - HW_QuadSPI_LUT10 - Look-up Table register
 * - HW_QuadSPI_LUT11 - Look-up Table register
 * - HW_QuadSPI_LUT12 - Look-up Table register
 * - HW_QuadSPI_LUT13 - Look-up Table register
 * - HW_QuadSPI_LUT14 - Look-up Table register
 * - HW_QuadSPI_LUT15 - Look-up Table register
 * - HW_QuadSPI_LUT16 - Look-up Table register
 * - HW_QuadSPI_LUT17 - Look-up Table register
 * - HW_QuadSPI_LUT18 - Look-up Table register
 * - HW_QuadSPI_LUT19 - Look-up Table register
 * - HW_QuadSPI_LUT20 - Look-up Table register
 * - HW_QuadSPI_LUT21 - Look-up Table register
 * - HW_QuadSPI_LUT22 - Look-up Table register
 * - HW_QuadSPI_LUT23 - Look-up Table register
 * - HW_QuadSPI_LUT24 - Look-up Table register
 * - HW_QuadSPI_LUT25 - Look-up Table register
 * - HW_QuadSPI_LUT26 - Look-up Table register
 * - HW_QuadSPI_LUT27 - Look-up Table register
 * - HW_QuadSPI_LUT28 - Look-up Table register
 * - HW_QuadSPI_LUT29 - Look-up Table register
 * - HW_QuadSPI_LUT30 - Look-up Table register
 * - HW_QuadSPI_LUT31 - Look-up Table register
 * - HW_QuadSPI_LUT32 - Look-up Table register
 * - HW_QuadSPI_LUT33 - Look-up Table register
 * - HW_QuadSPI_LUT34 - Look-up Table register
 * - HW_QuadSPI_LUT35 - Look-up Table register
 * - HW_QuadSPI_LUT36 - Look-up Table register
 * - HW_QuadSPI_LUT37 - Look-up Table register
 * - HW_QuadSPI_LUT38 - Look-up Table register
 * - HW_QuadSPI_LUT39 - Look-up Table register
 * - HW_QuadSPI_LUT40 - Look-up Table register
 * - HW_QuadSPI_LUT41 - Look-up Table register
 * - HW_QuadSPI_LUT42 - Look-up Table register
 * - HW_QuadSPI_LUT43 - Look-up Table register
 * - HW_QuadSPI_LUT44 - Look-up Table register
 * - HW_QuadSPI_LUT45 - Look-up Table register
 * - HW_QuadSPI_LUT46 - Look-up Table register
 * - HW_QuadSPI_LUT47 - Look-up Table register
 * - HW_QuadSPI_LUT48 - Look-up Table register
 * - HW_QuadSPI_LUT49 - Look-up Table register
 * - HW_QuadSPI_LUT50 - Look-up Table register
 * - HW_QuadSPI_LUT51 - Look-up Table register
 * - HW_QuadSPI_LUT52 - Look-up Table register
 * - HW_QuadSPI_LUT53 - Look-up Table register
 * - HW_QuadSPI_LUT54 - Look-up Table register
 * - HW_QuadSPI_LUT55 - Look-up Table register
 * - HW_QuadSPI_LUT56 - Look-up Table register
 * - HW_QuadSPI_LUT57 - Look-up Table register
 * - HW_QuadSPI_LUT58 - Look-up Table register
 * - HW_QuadSPI_LUT59 - Look-up Table register
 * - HW_QuadSPI_LUT60 - Look-up Table register
 * - HW_QuadSPI_LUT61 - Look-up Table register
 * - HW_QuadSPI_LUT62 - Look-up Table register
 * - HW_QuadSPI_LUT63 - Look-up Table register
 *
 * - hw_quadspi_t - Struct containing all module registers.
 */

#define HW_QuadSPI_INSTANCE_COUNT (2U) /*!< Number of instances of the QuadSPI module. */
#define HW_QuadSPI1 (0U) /*!< Instance number for QuadSPI1. */
#define HW_QuadSPI2 (1U) /*!< Instance number for QuadSPI2. */
#define QuadSPI1_BASE         (0x30BB0000U) /*!< Base address for QuadSPI1. */
#define QuadSPI2_BASE         (0x30BB4000U) /*!< Base address for QuadSPI2. */
/*! Array initializer of QuadSPI base addresses. */
#define QUADSPI_BASE_ADDRS    { QuadSPI1_BASE, QuadSPI2_BASE }

/*******************************************************************************
 * HW_QuadSPI_MCR - Module Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_MCR - Module Configuration Register (RW)
 *
 * Reset value: 0x000F4000U
 *
 * The QuadSPI_MCR holds configuration data associated with QuadSPI operation.
 * Write: All other fields: Anytime
 */
typedef union _hw_quadspi_mcr
{
    uint32_t U;
    struct _hw_quadspi_mcr_bitfields
    {
        uint32_t SWRSTSD : 1;          /*!< [0]  */
        uint32_t SWRSTHD : 1;          /*!< [1]  */
        uint32_t END_CFG : 2;          /*!< [3:2]  */
        uint32_t RESERVED0 : 2;        /*!< [5:4]  */
        uint32_t DQS_EN : 1;           /*!< [6]  */
        uint32_t DDR_EN : 1;           /*!< [7]  */
        uint32_t RESERVED1 : 2;        /*!< [9:8]  */
        uint32_t CLR_RXF : 1;          /*!< [10]  */
        uint32_t CLR_TXF : 1;          /*!< [11]  */
        uint32_t RESERVED2 : 2;        /*!< [13:12]  */
        uint32_t MDIS : 1;             /*!< [14]  */
        uint32_t RESERVED3 : 9;        /*!< [23:15]  */
        uint32_t DQS_LOOPBACK_FROM_PAD : 1; /*!< [24]  */
        uint32_t DQS_LOOPBACK_EN : 1;  /*!< [25]  */
        uint32_t DQS_PHASE_EN : 1;     /*!< [26]  */
        uint32_t RESERVED4 : 5;        /*!< [31:27]  */
    } B;
} hw_quadspi_mcr_t;

/*!
 * @name Constants and macros for entire QuadSPI_MCR register
 */
/*@{*/
#define HW_QuadSPI_MCR_ADDR(x)   ((uintptr_t)(x) + 0x0U)

#define HW_QuadSPI_MCR(x)        (*(__IO hw_quadspi_mcr_t *) HW_QuadSPI_MCR_ADDR(x))
#define HW_QuadSPI_MCR_RD(x)     (HW_QuadSPI_MCR(x).U)
#define HW_QuadSPI_MCR_WR(x, v)  (HW_QuadSPI_MCR(x).U = (v))
#define HW_QuadSPI_MCR_SET(x, v) (HW_QuadSPI_MCR_WR(x, HW_QuadSPI_MCR_RD(x) |  (v)))
#define HW_QuadSPI_MCR_CLR(x, v) (HW_QuadSPI_MCR_WR(x, HW_QuadSPI_MCR_RD(x) & ~(v)))
#define HW_QuadSPI_MCR_TOG(x, v) (HW_QuadSPI_MCR_WR(x, HW_QuadSPI_MCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_MCR bitfields
 */

/*!
 * @name Register QuadSPI_MCR, field SWRSTSD[0] (RW)
 *
 * Software reset for Serial Flash domainPlease keep other fields value when
 * write to SWRSTHD and SWRSTSD These software reset don't reset register setting
 * but only reset internal flip‐flops in quadspi controller To remove the reset,
 * need to write 0 to SWRSTHD and SWRSTSD
 *
 * Values:
 * - 0 - No action
 * - 1 - Serial Flash domain flops are reset. Does not reset configuration
 *     registers. It is advisable to reset both the serial flash domain and AHB domain
 *     at the same time. Resetting only one domain might lead to side effects.
 */
/*@{*/
#define BP_QuadSPI_MCR_SWRSTSD (0U)        /*!< Bit position for QuadSPI_MCR_SWRSTSD. */
#define BM_QuadSPI_MCR_SWRSTSD (0x00000001U) /*!< Bit mask for QuadSPI_MCR_SWRSTSD. */
#define BS_QuadSPI_MCR_SWRSTSD (1U)        /*!< Bit field size in bits for QuadSPI_MCR_SWRSTSD. */

/*! @brief Read current value of the QuadSPI_MCR_SWRSTSD field. */
#define BR_QuadSPI_MCR_SWRSTSD(x) (HW_QuadSPI_MCR(x).B.SWRSTSD)

/*! @brief Format value for bitfield QuadSPI_MCR_SWRSTSD. */
#define BF_QuadSPI_MCR_SWRSTSD(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_MCR_SWRSTSD) & BM_QuadSPI_MCR_SWRSTSD)

/*! @brief Set the SWRSTSD field to a new value. */
#define BW_QuadSPI_MCR_SWRSTSD(x, v) (HW_QuadSPI_MCR_WR(x, (HW_QuadSPI_MCR_RD(x) & ~BM_QuadSPI_MCR_SWRSTSD) | BF_QuadSPI_MCR_SWRSTSD(v)))
/*@}*/

/*!
 * @name Register QuadSPI_MCR, field SWRSTHD[1] (RW)
 *
 * Software reset for AHB domainPlease keep other fields value when write to
 * SWRSTHD and SWRSTSD These software reset don't reset register setting but only
 * reset internal flip‐flops in quadspi controller To remove the reset, need to
 * write 0 to SWRSTHD and SWRSTSD
 *
 * Values:
 * - 0 - No action
 * - 1 - AHB domain flops are reset. Does not reset configuration registers. It
 *     is advisable to reset both the serial flash domain and AHB domain at the
 *     same time. Resetting only one domain might lead to side effects.
 */
/*@{*/
#define BP_QuadSPI_MCR_SWRSTHD (1U)        /*!< Bit position for QuadSPI_MCR_SWRSTHD. */
#define BM_QuadSPI_MCR_SWRSTHD (0x00000002U) /*!< Bit mask for QuadSPI_MCR_SWRSTHD. */
#define BS_QuadSPI_MCR_SWRSTHD (1U)        /*!< Bit field size in bits for QuadSPI_MCR_SWRSTHD. */

/*! @brief Read current value of the QuadSPI_MCR_SWRSTHD field. */
#define BR_QuadSPI_MCR_SWRSTHD(x) (HW_QuadSPI_MCR(x).B.SWRSTHD)

/*! @brief Format value for bitfield QuadSPI_MCR_SWRSTHD. */
#define BF_QuadSPI_MCR_SWRSTHD(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_MCR_SWRSTHD) & BM_QuadSPI_MCR_SWRSTHD)

/*! @brief Set the SWRSTHD field to a new value. */
#define BW_QuadSPI_MCR_SWRSTHD(x, v) (HW_QuadSPI_MCR_WR(x, (HW_QuadSPI_MCR_RD(x) & ~BM_QuadSPI_MCR_SWRSTHD) | BF_QuadSPI_MCR_SWRSTHD(v)))
/*@}*/

/*!
 * @name Register QuadSPI_MCR, field END_CFG[3:2] (RW)
 *
 * Defines the endianness of the QSPI module.For more details refer to Byte
 * Ordering Endianess
 */
/*@{*/
#define BP_QuadSPI_MCR_END_CFG (2U)        /*!< Bit position for QuadSPI_MCR_END_CFG. */
#define BM_QuadSPI_MCR_END_CFG (0x0000000CU) /*!< Bit mask for QuadSPI_MCR_END_CFG. */
#define BS_QuadSPI_MCR_END_CFG (2U)        /*!< Bit field size in bits for QuadSPI_MCR_END_CFG. */

/*! @brief Read current value of the QuadSPI_MCR_END_CFG field. */
#define BR_QuadSPI_MCR_END_CFG(x) (HW_QuadSPI_MCR(x).B.END_CFG)

/*! @brief Format value for bitfield QuadSPI_MCR_END_CFG. */
#define BF_QuadSPI_MCR_END_CFG(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_MCR_END_CFG) & BM_QuadSPI_MCR_END_CFG)

/*! @brief Set the END_CFG field to a new value. */
#define BW_QuadSPI_MCR_END_CFG(x, v) (HW_QuadSPI_MCR_WR(x, (HW_QuadSPI_MCR_RD(x) & ~BM_QuadSPI_MCR_END_CFG) | BF_QuadSPI_MCR_END_CFG(v)))
/*@}*/

/*!
 * @name Register QuadSPI_MCR, field DQS_EN[6] (RW)
 *
 * DQS enable: This field is valid for both SDR and DDR mode.For more details
 * Refer Data Strobe Signal Functionality
 *
 * Values:
 * - 0 - DQS disabled.
 * - 1 - DQS enabled- When enabled, the incoming data is sampled on both the
 *     edges of DQS input when QSPI_MCR[DDR_EN] is set, else, on only one edge when
 *     QSPI_MCR[DDR_EN] is 0. The QSPI_SMPR[DDR_SMP] values are ignored.
 */
/*@{*/
#define BP_QuadSPI_MCR_DQS_EN (6U)         /*!< Bit position for QuadSPI_MCR_DQS_EN. */
#define BM_QuadSPI_MCR_DQS_EN (0x00000040U) /*!< Bit mask for QuadSPI_MCR_DQS_EN. */
#define BS_QuadSPI_MCR_DQS_EN (1U)         /*!< Bit field size in bits for QuadSPI_MCR_DQS_EN. */

/*! @brief Read current value of the QuadSPI_MCR_DQS_EN field. */
#define BR_QuadSPI_MCR_DQS_EN(x) (HW_QuadSPI_MCR(x).B.DQS_EN)

/*! @brief Format value for bitfield QuadSPI_MCR_DQS_EN. */
#define BF_QuadSPI_MCR_DQS_EN(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_MCR_DQS_EN) & BM_QuadSPI_MCR_DQS_EN)

/*! @brief Set the DQS_EN field to a new value. */
#define BW_QuadSPI_MCR_DQS_EN(x, v) (HW_QuadSPI_MCR_WR(x, (HW_QuadSPI_MCR_RD(x) & ~BM_QuadSPI_MCR_DQS_EN) | BF_QuadSPI_MCR_DQS_EN(v)))
/*@}*/

/*!
 * @name Register QuadSPI_MCR, field DDR_EN[7] (RW)
 *
 * DDR mode enable:
 *
 * Values:
 * - 0 - 2x and 4x clocks are disabled for SDR instructions only
 * - 1 - 2x and 4x clocks are enabled supports both SDR and DDR instruction.
 */
/*@{*/
#define BP_QuadSPI_MCR_DDR_EN (7U)         /*!< Bit position for QuadSPI_MCR_DDR_EN. */
#define BM_QuadSPI_MCR_DDR_EN (0x00000080U) /*!< Bit mask for QuadSPI_MCR_DDR_EN. */
#define BS_QuadSPI_MCR_DDR_EN (1U)         /*!< Bit field size in bits for QuadSPI_MCR_DDR_EN. */

/*! @brief Read current value of the QuadSPI_MCR_DDR_EN field. */
#define BR_QuadSPI_MCR_DDR_EN(x) (HW_QuadSPI_MCR(x).B.DDR_EN)

/*! @brief Format value for bitfield QuadSPI_MCR_DDR_EN. */
#define BF_QuadSPI_MCR_DDR_EN(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_MCR_DDR_EN) & BM_QuadSPI_MCR_DDR_EN)

/*! @brief Set the DDR_EN field to a new value. */
#define BW_QuadSPI_MCR_DDR_EN(x, v) (HW_QuadSPI_MCR_WR(x, (HW_QuadSPI_MCR_RD(x) & ~BM_QuadSPI_MCR_DDR_EN) | BF_QuadSPI_MCR_DDR_EN(v)))
/*@}*/

/*!
 * @name Register QuadSPI_MCR, field CLR_RXF[10] (RW)
 *
 * Clear RX FIFO. Invalidate the RX Buffer.
 *
 * Values:
 * - 0 - No action.
 * - 1 - Read and write pointers of the RX Buffer are reset to 0.
 *     QSPI_RBSR[RDBFL] is reset to 0.
 */
/*@{*/
#define BP_QuadSPI_MCR_CLR_RXF (10U)       /*!< Bit position for QuadSPI_MCR_CLR_RXF. */
#define BM_QuadSPI_MCR_CLR_RXF (0x00000400U) /*!< Bit mask for QuadSPI_MCR_CLR_RXF. */
#define BS_QuadSPI_MCR_CLR_RXF (1U)        /*!< Bit field size in bits for QuadSPI_MCR_CLR_RXF. */

/*! @brief Read current value of the QuadSPI_MCR_CLR_RXF field. */
#define BR_QuadSPI_MCR_CLR_RXF(x) (HW_QuadSPI_MCR(x).B.CLR_RXF)

/*! @brief Format value for bitfield QuadSPI_MCR_CLR_RXF. */
#define BF_QuadSPI_MCR_CLR_RXF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_MCR_CLR_RXF) & BM_QuadSPI_MCR_CLR_RXF)

/*! @brief Set the CLR_RXF field to a new value. */
#define BW_QuadSPI_MCR_CLR_RXF(x, v) (HW_QuadSPI_MCR_WR(x, (HW_QuadSPI_MCR_RD(x) & ~BM_QuadSPI_MCR_CLR_RXF) | BF_QuadSPI_MCR_CLR_RXF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_MCR, field CLR_TXF[11] (RW)
 *
 * Clear TX FIFO/Buffer. Invalidate the TX Buffer content.
 *
 * Values:
 * - 0 - No action.
 * - 1 - Read and write pointers of the TX Buffer are reset to 0.
 *     QSPI_TBSR[TRCTR] is reset to 0.
 */
/*@{*/
#define BP_QuadSPI_MCR_CLR_TXF (11U)       /*!< Bit position for QuadSPI_MCR_CLR_TXF. */
#define BM_QuadSPI_MCR_CLR_TXF (0x00000800U) /*!< Bit mask for QuadSPI_MCR_CLR_TXF. */
#define BS_QuadSPI_MCR_CLR_TXF (1U)        /*!< Bit field size in bits for QuadSPI_MCR_CLR_TXF. */

/*! @brief Read current value of the QuadSPI_MCR_CLR_TXF field. */
#define BR_QuadSPI_MCR_CLR_TXF(x) (HW_QuadSPI_MCR(x).B.CLR_TXF)

/*! @brief Format value for bitfield QuadSPI_MCR_CLR_TXF. */
#define BF_QuadSPI_MCR_CLR_TXF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_MCR_CLR_TXF) & BM_QuadSPI_MCR_CLR_TXF)

/*! @brief Set the CLR_TXF field to a new value. */
#define BW_QuadSPI_MCR_CLR_TXF(x, v) (HW_QuadSPI_MCR_WR(x, (HW_QuadSPI_MCR_RD(x) & ~BM_QuadSPI_MCR_CLR_TXF) | BF_QuadSPI_MCR_CLR_TXF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_MCR, field MDIS[14] (RW)
 *
 * Module Disable. The MDIS bit allows the clock to the non-memory mapped logic
 * in the QuadSPI to be stopped, putting the QuadSPI in a software controlled
 * power-saving state. Please refer to , for more information.
 *
 * Values:
 * - 0 - Enable QuadSPI clocks.
 * - 1 - Allow external logic to disable QuadSPI clocks.
 */
/*@{*/
#define BP_QuadSPI_MCR_MDIS  (14U)         /*!< Bit position for QuadSPI_MCR_MDIS. */
#define BM_QuadSPI_MCR_MDIS  (0x00004000U) /*!< Bit mask for QuadSPI_MCR_MDIS. */
#define BS_QuadSPI_MCR_MDIS  (1U)          /*!< Bit field size in bits for QuadSPI_MCR_MDIS. */

/*! @brief Read current value of the QuadSPI_MCR_MDIS field. */
#define BR_QuadSPI_MCR_MDIS(x) (HW_QuadSPI_MCR(x).B.MDIS)

/*! @brief Format value for bitfield QuadSPI_MCR_MDIS. */
#define BF_QuadSPI_MCR_MDIS(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_MCR_MDIS) & BM_QuadSPI_MCR_MDIS)

/*! @brief Set the MDIS field to a new value. */
#define BW_QuadSPI_MCR_MDIS(x, v) (HW_QuadSPI_MCR_WR(x, (HW_QuadSPI_MCR_RD(x) & ~BM_QuadSPI_MCR_MDIS) | BF_QuadSPI_MCR_MDIS(v)))
/*@}*/

/*!
 * @name Register QuadSPI_MCR, field DQS_LOOPBACK_FROM_PAD[24] (RW)
 *
 * This bit should always be set to '1' when DQS_LOOPBACK_EN is set to '1'. When
 * DQS_LOOPBACK_EN is set to '1', this bit is ignored.
 */
/*@{*/
#define BP_QuadSPI_MCR_DQS_LOOPBACK_FROM_PAD (24U) /*!< Bit position for QuadSPI_MCR_DQS_LOOPBACK_FROM_PAD. */
#define BM_QuadSPI_MCR_DQS_LOOPBACK_FROM_PAD (0x01000000U) /*!< Bit mask for QuadSPI_MCR_DQS_LOOPBACK_FROM_PAD. */
#define BS_QuadSPI_MCR_DQS_LOOPBACK_FROM_PAD (1U) /*!< Bit field size in bits for QuadSPI_MCR_DQS_LOOPBACK_FROM_PAD. */

/*! @brief Read current value of the QuadSPI_MCR_DQS_LOOPBACK_FROM_PAD field. */
#define BR_QuadSPI_MCR_DQS_LOOPBACK_FROM_PAD(x) (HW_QuadSPI_MCR(x).B.DQS_LOOPBACK_FROM_PAD)

/*! @brief Format value for bitfield QuadSPI_MCR_DQS_LOOPBACK_FROM_PAD. */
#define BF_QuadSPI_MCR_DQS_LOOPBACK_FROM_PAD(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_MCR_DQS_LOOPBACK_FROM_PAD) & BM_QuadSPI_MCR_DQS_LOOPBACK_FROM_PAD)

/*! @brief Set the DQS_LOOPBACK_FROM_PAD field to a new value. */
#define BW_QuadSPI_MCR_DQS_LOOPBACK_FROM_PAD(x, v) (HW_QuadSPI_MCR_WR(x, (HW_QuadSPI_MCR_RD(x) & ~BM_QuadSPI_MCR_DQS_LOOPBACK_FROM_PAD) | BF_QuadSPI_MCR_DQS_LOOPBACK_FROM_PAD(v)))
/*@}*/

/*!
 * @name Register QuadSPI_MCR, field DQS_LOOPBACK_EN[25] (RW)
 *
 * Quadspi will output serial data strobe signal which will be loopback from pad
 * to sample input flash serial data. Please note pad should be force input for
 * loopback.Quadspi will output serial data strobe signal which will be loopback
 * from pad to sample input flash serial data. Please note pad should be force
 * input for loopback. This bit is a don't care when DQS_EN is set to 0.
 */
/*@{*/
#define BP_QuadSPI_MCR_DQS_LOOPBACK_EN (25U) /*!< Bit position for QuadSPI_MCR_DQS_LOOPBACK_EN. */
#define BM_QuadSPI_MCR_DQS_LOOPBACK_EN (0x02000000U) /*!< Bit mask for QuadSPI_MCR_DQS_LOOPBACK_EN. */
#define BS_QuadSPI_MCR_DQS_LOOPBACK_EN (1U) /*!< Bit field size in bits for QuadSPI_MCR_DQS_LOOPBACK_EN. */

/*! @brief Read current value of the QuadSPI_MCR_DQS_LOOPBACK_EN field. */
#define BR_QuadSPI_MCR_DQS_LOOPBACK_EN(x) (HW_QuadSPI_MCR(x).B.DQS_LOOPBACK_EN)

/*! @brief Format value for bitfield QuadSPI_MCR_DQS_LOOPBACK_EN. */
#define BF_QuadSPI_MCR_DQS_LOOPBACK_EN(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_MCR_DQS_LOOPBACK_EN) & BM_QuadSPI_MCR_DQS_LOOPBACK_EN)

/*! @brief Set the DQS_LOOPBACK_EN field to a new value. */
#define BW_QuadSPI_MCR_DQS_LOOPBACK_EN(x, v) (HW_QuadSPI_MCR_WR(x, (HW_QuadSPI_MCR_RD(x) & ~BM_QuadSPI_MCR_DQS_LOOPBACK_EN) | BF_QuadSPI_MCR_DQS_LOOPBACK_EN(v)))
/*@}*/

/*!
 * @name Register QuadSPI_MCR, field DQS_PHASE_EN[26] (RW)
 *
 * This bit controls internal DQS output phase. If DQS_EN and DQS_LOOPBACK_EN
 * are both set to 1, this bit should be set in SDR mode, and cleared in DDR mode.
 * If either DQS_EN or DQS_LOOPBACK_EN is set to 0, this bit is ignored.
 */
/*@{*/
#define BP_QuadSPI_MCR_DQS_PHASE_EN (26U)  /*!< Bit position for QuadSPI_MCR_DQS_PHASE_EN. */
#define BM_QuadSPI_MCR_DQS_PHASE_EN (0x04000000U) /*!< Bit mask for QuadSPI_MCR_DQS_PHASE_EN. */
#define BS_QuadSPI_MCR_DQS_PHASE_EN (1U)   /*!< Bit field size in bits for QuadSPI_MCR_DQS_PHASE_EN. */

/*! @brief Read current value of the QuadSPI_MCR_DQS_PHASE_EN field. */
#define BR_QuadSPI_MCR_DQS_PHASE_EN(x) (HW_QuadSPI_MCR(x).B.DQS_PHASE_EN)

/*! @brief Format value for bitfield QuadSPI_MCR_DQS_PHASE_EN. */
#define BF_QuadSPI_MCR_DQS_PHASE_EN(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_MCR_DQS_PHASE_EN) & BM_QuadSPI_MCR_DQS_PHASE_EN)

/*! @brief Set the DQS_PHASE_EN field to a new value. */
#define BW_QuadSPI_MCR_DQS_PHASE_EN(x, v) (HW_QuadSPI_MCR_WR(x, (HW_QuadSPI_MCR_RD(x) & ~BM_QuadSPI_MCR_DQS_PHASE_EN) | BF_QuadSPI_MCR_DQS_PHASE_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_IPCR - IP Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_IPCR - IP Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The IP configuration register provides all the configuration required for an
 * IP initiated command. An IP command can be triggered by writing in the SEQID
 * field of this register. If the SEQID field is written successfully, a new
 * command to the external serial flash is started as per the sequence pointed to by
 * the SEQID field. Refer to Normal Mode , for details about the command
 * triggering and command execution. Write: QSPI_SR[IP_ACC]=0
 */
typedef union _hw_quadspi_ipcr
{
    uint32_t U;
    struct _hw_quadspi_ipcr_bitfields
    {
        uint32_t IDATSZ : 16;          /*!< [15:0]  */
        uint32_t PAR_EN : 1;           /*!< [16]  */
        uint32_t RESERVED0 : 7;        /*!< [23:17]  */
        uint32_t SEQID : 4;            /*!< [27:24]  */
        uint32_t RESERVED1 : 4;        /*!< [31:28]  */
    } B;
} hw_quadspi_ipcr_t;

/*!
 * @name Constants and macros for entire QuadSPI_IPCR register
 */
/*@{*/
#define HW_QuadSPI_IPCR_ADDR(x)  ((uintptr_t)(x) + 0x8U)

#define HW_QuadSPI_IPCR(x)       (*(__IO hw_quadspi_ipcr_t *) HW_QuadSPI_IPCR_ADDR(x))
#define HW_QuadSPI_IPCR_RD(x)    (HW_QuadSPI_IPCR(x).U)
#define HW_QuadSPI_IPCR_WR(x, v) (HW_QuadSPI_IPCR(x).U = (v))
#define HW_QuadSPI_IPCR_SET(x, v) (HW_QuadSPI_IPCR_WR(x, HW_QuadSPI_IPCR_RD(x) |  (v)))
#define HW_QuadSPI_IPCR_CLR(x, v) (HW_QuadSPI_IPCR_WR(x, HW_QuadSPI_IPCR_RD(x) & ~(v)))
#define HW_QuadSPI_IPCR_TOG(x, v) (HW_QuadSPI_IPCR_WR(x, HW_QuadSPI_IPCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_IPCR bitfields
 */

/*!
 * @name Register QuadSPI_IPCR, field IDATSZ[15:0] (RW)
 *
 * IP data transfer size: Defines the data transfer size in bytes of the IP
 * command.
 */
/*@{*/
#define BP_QuadSPI_IPCR_IDATSZ (0U)        /*!< Bit position for QuadSPI_IPCR_IDATSZ. */
#define BM_QuadSPI_IPCR_IDATSZ (0x0000FFFFU) /*!< Bit mask for QuadSPI_IPCR_IDATSZ. */
#define BS_QuadSPI_IPCR_IDATSZ (16U)       /*!< Bit field size in bits for QuadSPI_IPCR_IDATSZ. */

/*! @brief Read current value of the QuadSPI_IPCR_IDATSZ field. */
#define BR_QuadSPI_IPCR_IDATSZ(x) (HW_QuadSPI_IPCR(x).B.IDATSZ)

/*! @brief Format value for bitfield QuadSPI_IPCR_IDATSZ. */
#define BF_QuadSPI_IPCR_IDATSZ(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_IPCR_IDATSZ) & BM_QuadSPI_IPCR_IDATSZ)

/*! @brief Set the IDATSZ field to a new value. */
#define BW_QuadSPI_IPCR_IDATSZ(x, v) (HW_QuadSPI_IPCR_WR(x, (HW_QuadSPI_IPCR_RD(x) & ~BM_QuadSPI_IPCR_IDATSZ) | BF_QuadSPI_IPCR_IDATSZ(v)))
/*@}*/

/*!
 * @name Register QuadSPI_IPCR, field PAR_EN[16] (RW)
 *
 * When set, a transaction to two serial flash devices is triggered in parallel
 * mode. Refer to Parallel Flash Modefor more details.
 */
/*@{*/
#define BP_QuadSPI_IPCR_PAR_EN (16U)       /*!< Bit position for QuadSPI_IPCR_PAR_EN. */
#define BM_QuadSPI_IPCR_PAR_EN (0x00010000U) /*!< Bit mask for QuadSPI_IPCR_PAR_EN. */
#define BS_QuadSPI_IPCR_PAR_EN (1U)        /*!< Bit field size in bits for QuadSPI_IPCR_PAR_EN. */

/*! @brief Read current value of the QuadSPI_IPCR_PAR_EN field. */
#define BR_QuadSPI_IPCR_PAR_EN(x) (HW_QuadSPI_IPCR(x).B.PAR_EN)

/*! @brief Format value for bitfield QuadSPI_IPCR_PAR_EN. */
#define BF_QuadSPI_IPCR_PAR_EN(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_IPCR_PAR_EN) & BM_QuadSPI_IPCR_PAR_EN)

/*! @brief Set the PAR_EN field to a new value. */
#define BW_QuadSPI_IPCR_PAR_EN(x, v) (HW_QuadSPI_IPCR_WR(x, (HW_QuadSPI_IPCR_RD(x) & ~BM_QuadSPI_IPCR_PAR_EN) | BF_QuadSPI_IPCR_PAR_EN(v)))
/*@}*/

/*!
 * @name Register QuadSPI_IPCR, field SEQID[27:24] (RW)
 *
 * Points to a sequence in the Look-up-table. The SEQID defines the bits [6:2]
 * of the LUT index. The bits [1:0] are always assumed to be 0. Refer to Look-up
 * Table for more details. A write to this bit -field triggers a transaction on
 * the serial flash interface.
 */
/*@{*/
#define BP_QuadSPI_IPCR_SEQID (24U)        /*!< Bit position for QuadSPI_IPCR_SEQID. */
#define BM_QuadSPI_IPCR_SEQID (0x0F000000U) /*!< Bit mask for QuadSPI_IPCR_SEQID. */
#define BS_QuadSPI_IPCR_SEQID (4U)         /*!< Bit field size in bits for QuadSPI_IPCR_SEQID. */

/*! @brief Read current value of the QuadSPI_IPCR_SEQID field. */
#define BR_QuadSPI_IPCR_SEQID(x) (HW_QuadSPI_IPCR(x).B.SEQID)

/*! @brief Format value for bitfield QuadSPI_IPCR_SEQID. */
#define BF_QuadSPI_IPCR_SEQID(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_IPCR_SEQID) & BM_QuadSPI_IPCR_SEQID)

/*! @brief Set the SEQID field to a new value. */
#define BW_QuadSPI_IPCR_SEQID(x, v) (HW_QuadSPI_IPCR_WR(x, (HW_QuadSPI_IPCR_RD(x) & ~BM_QuadSPI_IPCR_SEQID) | BF_QuadSPI_IPCR_SEQID(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_FLSHCR - Flash Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_FLSHCR - Flash Configuration Register (RW)
 *
 * Reset value: 0x00000303U
 *
 * The Flash configuration register contains the flash device specific timings
 * that must be met by the QuadSPI controller for the device to function
 * correctly. Write: QSPI_SR[AHB_ACC] = 0 QSPI_SR[IP_ACC] = 0
 */
typedef union _hw_quadspi_flshcr
{
    uint32_t U;
    struct _hw_quadspi_flshcr_bitfields
    {
        uint32_t TCSS : 4;             /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t TCSH : 4;             /*!< [11:8]  */
        uint32_t RESERVED1 : 4;        /*!< [15:12]  */
        uint32_t TDH : 2;              /*!< [17:16]  */
        uint32_t RESERVED2 : 14;       /*!< [31:18]  */
    } B;
} hw_quadspi_flshcr_t;

/*!
 * @name Constants and macros for entire QuadSPI_FLSHCR register
 */
/*@{*/
#define HW_QuadSPI_FLSHCR_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_QuadSPI_FLSHCR(x)     (*(__IO hw_quadspi_flshcr_t *) HW_QuadSPI_FLSHCR_ADDR(x))
#define HW_QuadSPI_FLSHCR_RD(x)  (HW_QuadSPI_FLSHCR(x).U)
#define HW_QuadSPI_FLSHCR_WR(x, v) (HW_QuadSPI_FLSHCR(x).U = (v))
#define HW_QuadSPI_FLSHCR_SET(x, v) (HW_QuadSPI_FLSHCR_WR(x, HW_QuadSPI_FLSHCR_RD(x) |  (v)))
#define HW_QuadSPI_FLSHCR_CLR(x, v) (HW_QuadSPI_FLSHCR_WR(x, HW_QuadSPI_FLSHCR_RD(x) & ~(v)))
#define HW_QuadSPI_FLSHCR_TOG(x, v) (HW_QuadSPI_FLSHCR_WR(x, HW_QuadSPI_FLSHCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_FLSHCR bitfields
 */

/*!
 * @name Register QuadSPI_FLSHCR, field TCSS[3:0] (RW)
 *
 * Serial flash CS setup time in terms of serial flash clock cycles. The actual
 * delay between chip select assertion and clock fall edge is defined as: 0.5 SCK
 * cycle if TCSS is set 0 or 1 N+0.5 SCK cycle if TCSS is set N (N>1) Any update
 * to TCSS register bits is visible on the flash interface only from the second
 * transaction following the update.
 */
/*@{*/
#define BP_QuadSPI_FLSHCR_TCSS (0U)        /*!< Bit position for QuadSPI_FLSHCR_TCSS. */
#define BM_QuadSPI_FLSHCR_TCSS (0x0000000FU) /*!< Bit mask for QuadSPI_FLSHCR_TCSS. */
#define BS_QuadSPI_FLSHCR_TCSS (4U)        /*!< Bit field size in bits for QuadSPI_FLSHCR_TCSS. */

/*! @brief Read current value of the QuadSPI_FLSHCR_TCSS field. */
#define BR_QuadSPI_FLSHCR_TCSS(x) (HW_QuadSPI_FLSHCR(x).B.TCSS)

/*! @brief Format value for bitfield QuadSPI_FLSHCR_TCSS. */
#define BF_QuadSPI_FLSHCR_TCSS(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FLSHCR_TCSS) & BM_QuadSPI_FLSHCR_TCSS)

/*! @brief Set the TCSS field to a new value. */
#define BW_QuadSPI_FLSHCR_TCSS(x, v) (HW_QuadSPI_FLSHCR_WR(x, (HW_QuadSPI_FLSHCR_RD(x) & ~BM_QuadSPI_FLSHCR_TCSS) | BF_QuadSPI_FLSHCR_TCSS(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FLSHCR, field TCSH[11:8] (RW)
 *
 * Serial flash CS hold time in terms of serial flash clock cycles. The actual
 * delay between chip select assertion and clock fall edge is defined as: 1 SCK
 * cycle if TCSH is set 0 or 1 N SCK cycle if TCSH is set N (N>1)
 */
/*@{*/
#define BP_QuadSPI_FLSHCR_TCSH (8U)        /*!< Bit position for QuadSPI_FLSHCR_TCSH. */
#define BM_QuadSPI_FLSHCR_TCSH (0x00000F00U) /*!< Bit mask for QuadSPI_FLSHCR_TCSH. */
#define BS_QuadSPI_FLSHCR_TCSH (4U)        /*!< Bit field size in bits for QuadSPI_FLSHCR_TCSH. */

/*! @brief Read current value of the QuadSPI_FLSHCR_TCSH field. */
#define BR_QuadSPI_FLSHCR_TCSH(x) (HW_QuadSPI_FLSHCR(x).B.TCSH)

/*! @brief Format value for bitfield QuadSPI_FLSHCR_TCSH. */
#define BF_QuadSPI_FLSHCR_TCSH(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FLSHCR_TCSH) & BM_QuadSPI_FLSHCR_TCSH)

/*! @brief Set the TCSH field to a new value. */
#define BW_QuadSPI_FLSHCR_TCSH(x, v) (HW_QuadSPI_FLSHCR_WR(x, (HW_QuadSPI_FLSHCR_RD(x) & ~BM_QuadSPI_FLSHCR_TCSH) | BF_QuadSPI_FLSHCR_TCSH(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FLSHCR, field TDH[17:16] (RW)
 *
 * Serial flash Data In hold time: This helps in meeting the Data In Hold time
 * requirement of a Flash. This is valid only in DDR mode. Refer to Data input
 * hold requirement of Flash for details.This field should be set to 01 in DDR mode
 * (DDR_EN=1) and set to 00 in SDR mode (DDR_EN=0). Other value are reserved.
 *
 * Values:
 * - 00 - Data aligned with the posedge of Internal reference clock of QuadSPI
 * - 01 - Data aligned with 2x serial flash half clock
 * - 10 - Reserved
 * - 11 - Reserved
 */
/*@{*/
#define BP_QuadSPI_FLSHCR_TDH (16U)        /*!< Bit position for QuadSPI_FLSHCR_TDH. */
#define BM_QuadSPI_FLSHCR_TDH (0x00030000U) /*!< Bit mask for QuadSPI_FLSHCR_TDH. */
#define BS_QuadSPI_FLSHCR_TDH (2U)         /*!< Bit field size in bits for QuadSPI_FLSHCR_TDH. */

/*! @brief Read current value of the QuadSPI_FLSHCR_TDH field. */
#define BR_QuadSPI_FLSHCR_TDH(x) (HW_QuadSPI_FLSHCR(x).B.TDH)

/*! @brief Format value for bitfield QuadSPI_FLSHCR_TDH. */
#define BF_QuadSPI_FLSHCR_TDH(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FLSHCR_TDH) & BM_QuadSPI_FLSHCR_TDH)

/*! @brief Set the TDH field to a new value. */
#define BW_QuadSPI_FLSHCR_TDH(x, v) (HW_QuadSPI_FLSHCR_WR(x, (HW_QuadSPI_FLSHCR_RD(x) & ~BM_QuadSPI_FLSHCR_TDH) | BF_QuadSPI_FLSHCR_TDH(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_BUF0CR - Buffer0 Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_BUF0CR - Buffer0 Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the configuration for any access to buffer0. An access
 * is routed to buffer0 when the master port number of the incoming AHB request
 * matches the MSTRID field of the BUF0CR. Any buffer "miss" leads to a serial
 * flash transaction being triggered as per the sequence pointed to the SEQID
 * field. Buffer0 may also be configured as a high priority buffer by setting the
 * HP_EN field of this register. Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_buf0cr
{
    uint32_t U;
    struct _hw_quadspi_buf0cr_bitfields
    {
        uint32_t MSTRID : 4;           /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t ADATSZ : 8;           /*!< [15:8]  */
        uint32_t RESERVED1 : 15;       /*!< [30:16]  */
        uint32_t HP_EN : 1;            /*!< [31]  */
    } B;
} hw_quadspi_buf0cr_t;

/*!
 * @name Constants and macros for entire QuadSPI_BUF0CR register
 */
/*@{*/
#define HW_QuadSPI_BUF0CR_ADDR(x) ((uintptr_t)(x) + 0x10U)

#define HW_QuadSPI_BUF0CR(x)     (*(__IO hw_quadspi_buf0cr_t *) HW_QuadSPI_BUF0CR_ADDR(x))
#define HW_QuadSPI_BUF0CR_RD(x)  (HW_QuadSPI_BUF0CR(x).U)
#define HW_QuadSPI_BUF0CR_WR(x, v) (HW_QuadSPI_BUF0CR(x).U = (v))
#define HW_QuadSPI_BUF0CR_SET(x, v) (HW_QuadSPI_BUF0CR_WR(x, HW_QuadSPI_BUF0CR_RD(x) |  (v)))
#define HW_QuadSPI_BUF0CR_CLR(x, v) (HW_QuadSPI_BUF0CR_WR(x, HW_QuadSPI_BUF0CR_RD(x) & ~(v)))
#define HW_QuadSPI_BUF0CR_TOG(x, v) (HW_QuadSPI_BUF0CR_WR(x, HW_QuadSPI_BUF0CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_BUF0CR bitfields
 */

/*!
 * @name Register QuadSPI_BUF0CR, field MSTRID[3:0] (RW)
 *
 * Master ID: The ID of the AHB master associated with BUFFER0. Any AHB access
 * with this master port number is routed to this buffer.
 */
/*@{*/
#define BP_QuadSPI_BUF0CR_MSTRID (0U)      /*!< Bit position for QuadSPI_BUF0CR_MSTRID. */
#define BM_QuadSPI_BUF0CR_MSTRID (0x0000000FU) /*!< Bit mask for QuadSPI_BUF0CR_MSTRID. */
#define BS_QuadSPI_BUF0CR_MSTRID (4U)      /*!< Bit field size in bits for QuadSPI_BUF0CR_MSTRID. */

/*! @brief Read current value of the QuadSPI_BUF0CR_MSTRID field. */
#define BR_QuadSPI_BUF0CR_MSTRID(x) (HW_QuadSPI_BUF0CR(x).B.MSTRID)

/*! @brief Format value for bitfield QuadSPI_BUF0CR_MSTRID. */
#define BF_QuadSPI_BUF0CR_MSTRID(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF0CR_MSTRID) & BM_QuadSPI_BUF0CR_MSTRID)

/*! @brief Set the MSTRID field to a new value. */
#define BW_QuadSPI_BUF0CR_MSTRID(x, v) (HW_QuadSPI_BUF0CR_WR(x, (HW_QuadSPI_BUF0CR_RD(x) & ~BM_QuadSPI_BUF0CR_MSTRID) | BF_QuadSPI_BUF0CR_MSTRID(v)))
/*@}*/

/*!
 * @name Register QuadSPI_BUF0CR, field ADATSZ[15:8] (RW)
 *
 * AHB data transfer size: Defines the data transfer size in 8 bytes of an AHB
 * triggered access to serial flash. For example,a value of 0x2 will set transfer
 * size to 16bytes.When ADATSZ = 0, the data size mentioned the sequence pointed
 * to by the SEQID field overrides this value. SW should ensure that this
 * transfer size is not greater than the size of this buffer.
 */
/*@{*/
#define BP_QuadSPI_BUF0CR_ADATSZ (8U)      /*!< Bit position for QuadSPI_BUF0CR_ADATSZ. */
#define BM_QuadSPI_BUF0CR_ADATSZ (0x0000FF00U) /*!< Bit mask for QuadSPI_BUF0CR_ADATSZ. */
#define BS_QuadSPI_BUF0CR_ADATSZ (8U)      /*!< Bit field size in bits for QuadSPI_BUF0CR_ADATSZ. */

/*! @brief Read current value of the QuadSPI_BUF0CR_ADATSZ field. */
#define BR_QuadSPI_BUF0CR_ADATSZ(x) (HW_QuadSPI_BUF0CR(x).B.ADATSZ)

/*! @brief Format value for bitfield QuadSPI_BUF0CR_ADATSZ. */
#define BF_QuadSPI_BUF0CR_ADATSZ(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF0CR_ADATSZ) & BM_QuadSPI_BUF0CR_ADATSZ)

/*! @brief Set the ADATSZ field to a new value. */
#define BW_QuadSPI_BUF0CR_ADATSZ(x, v) (HW_QuadSPI_BUF0CR_WR(x, (HW_QuadSPI_BUF0CR_RD(x) & ~BM_QuadSPI_BUF0CR_ADATSZ) | BF_QuadSPI_BUF0CR_ADATSZ(v)))
/*@}*/

/*!
 * @name Register QuadSPI_BUF0CR, field HP_EN[31] (RW)
 *
 * High Priority Enable: When set, the master associated with this buffer is
 * assigned a priority higher than the rest of the masters. An access by a high
 * priority master will suspend any ongoing prefetch by another AHB master and will
 * be serviced on high priority. Refer to Flexible AHB Buffersfor details.
 */
/*@{*/
#define BP_QuadSPI_BUF0CR_HP_EN (31U)      /*!< Bit position for QuadSPI_BUF0CR_HP_EN. */
#define BM_QuadSPI_BUF0CR_HP_EN (0x80000000U) /*!< Bit mask for QuadSPI_BUF0CR_HP_EN. */
#define BS_QuadSPI_BUF0CR_HP_EN (1U)       /*!< Bit field size in bits for QuadSPI_BUF0CR_HP_EN. */

/*! @brief Read current value of the QuadSPI_BUF0CR_HP_EN field. */
#define BR_QuadSPI_BUF0CR_HP_EN(x) (HW_QuadSPI_BUF0CR(x).B.HP_EN)

/*! @brief Format value for bitfield QuadSPI_BUF0CR_HP_EN. */
#define BF_QuadSPI_BUF0CR_HP_EN(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF0CR_HP_EN) & BM_QuadSPI_BUF0CR_HP_EN)

/*! @brief Set the HP_EN field to a new value. */
#define BW_QuadSPI_BUF0CR_HP_EN(x, v) (HW_QuadSPI_BUF0CR_WR(x, (HW_QuadSPI_BUF0CR_RD(x) & ~BM_QuadSPI_BUF0CR_HP_EN) | BF_QuadSPI_BUF0CR_HP_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_BUF1CR - Buffer1 Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_BUF1CR - Buffer1 Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the configuration for any access to buffer1. An access
 * is routed to buffer1 when the master port number of the incoming AHB request
 * matches the MSTRID field of the BUF1CR. Any buffer "miss" leads to the buffer
 * being flushed and a serial flash transaction being triggered as per the
 * sequence pointed to by the SEQID field. Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_buf1cr
{
    uint32_t U;
    struct _hw_quadspi_buf1cr_bitfields
    {
        uint32_t MSTRID : 4;           /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t ADATSZ : 8;           /*!< [15:8]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_quadspi_buf1cr_t;

/*!
 * @name Constants and macros for entire QuadSPI_BUF1CR register
 */
/*@{*/
#define HW_QuadSPI_BUF1CR_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_QuadSPI_BUF1CR(x)     (*(__IO hw_quadspi_buf1cr_t *) HW_QuadSPI_BUF1CR_ADDR(x))
#define HW_QuadSPI_BUF1CR_RD(x)  (HW_QuadSPI_BUF1CR(x).U)
#define HW_QuadSPI_BUF1CR_WR(x, v) (HW_QuadSPI_BUF1CR(x).U = (v))
#define HW_QuadSPI_BUF1CR_SET(x, v) (HW_QuadSPI_BUF1CR_WR(x, HW_QuadSPI_BUF1CR_RD(x) |  (v)))
#define HW_QuadSPI_BUF1CR_CLR(x, v) (HW_QuadSPI_BUF1CR_WR(x, HW_QuadSPI_BUF1CR_RD(x) & ~(v)))
#define HW_QuadSPI_BUF1CR_TOG(x, v) (HW_QuadSPI_BUF1CR_WR(x, HW_QuadSPI_BUF1CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_BUF1CR bitfields
 */

/*!
 * @name Register QuadSPI_BUF1CR, field MSTRID[3:0] (RW)
 *
 * Master ID: The ID of the AHB master associated with BUFFER1. Any AHB access
 * with this master port number is routed to this buffer.
 */
/*@{*/
#define BP_QuadSPI_BUF1CR_MSTRID (0U)      /*!< Bit position for QuadSPI_BUF1CR_MSTRID. */
#define BM_QuadSPI_BUF1CR_MSTRID (0x0000000FU) /*!< Bit mask for QuadSPI_BUF1CR_MSTRID. */
#define BS_QuadSPI_BUF1CR_MSTRID (4U)      /*!< Bit field size in bits for QuadSPI_BUF1CR_MSTRID. */

/*! @brief Read current value of the QuadSPI_BUF1CR_MSTRID field. */
#define BR_QuadSPI_BUF1CR_MSTRID(x) (HW_QuadSPI_BUF1CR(x).B.MSTRID)

/*! @brief Format value for bitfield QuadSPI_BUF1CR_MSTRID. */
#define BF_QuadSPI_BUF1CR_MSTRID(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF1CR_MSTRID) & BM_QuadSPI_BUF1CR_MSTRID)

/*! @brief Set the MSTRID field to a new value. */
#define BW_QuadSPI_BUF1CR_MSTRID(x, v) (HW_QuadSPI_BUF1CR_WR(x, (HW_QuadSPI_BUF1CR_RD(x) & ~BM_QuadSPI_BUF1CR_MSTRID) | BF_QuadSPI_BUF1CR_MSTRID(v)))
/*@}*/

/*!
 * @name Register QuadSPI_BUF1CR, field ADATSZ[15:8] (RW)
 *
 * AHB data transfer size: Defines the data transfer size in 8 bytes of an AHB
 * triggered access to serial flash.For example, a value of 0x2 will set transfer
 * size to 16bytes. When ADATSZ = 0, the data size mentioned the sequence pointed
 * to by the SEQID field overrides this value. SW should ensure that this
 * transfer size is not greater than the size of this buffer.
 */
/*@{*/
#define BP_QuadSPI_BUF1CR_ADATSZ (8U)      /*!< Bit position for QuadSPI_BUF1CR_ADATSZ. */
#define BM_QuadSPI_BUF1CR_ADATSZ (0x0000FF00U) /*!< Bit mask for QuadSPI_BUF1CR_ADATSZ. */
#define BS_QuadSPI_BUF1CR_ADATSZ (8U)      /*!< Bit field size in bits for QuadSPI_BUF1CR_ADATSZ. */

/*! @brief Read current value of the QuadSPI_BUF1CR_ADATSZ field. */
#define BR_QuadSPI_BUF1CR_ADATSZ(x) (HW_QuadSPI_BUF1CR(x).B.ADATSZ)

/*! @brief Format value for bitfield QuadSPI_BUF1CR_ADATSZ. */
#define BF_QuadSPI_BUF1CR_ADATSZ(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF1CR_ADATSZ) & BM_QuadSPI_BUF1CR_ADATSZ)

/*! @brief Set the ADATSZ field to a new value. */
#define BW_QuadSPI_BUF1CR_ADATSZ(x, v) (HW_QuadSPI_BUF1CR_WR(x, (HW_QuadSPI_BUF1CR_RD(x) & ~BM_QuadSPI_BUF1CR_ADATSZ) | BF_QuadSPI_BUF1CR_ADATSZ(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_BUF2CR - Buffer2 Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_BUF2CR - Buffer2 Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the configuration for any access to buffer2. An access
 * is routed to buffer2 when the master port number of the incoming AHB request
 * matches the MSTRID field of the BUF2CR. Any buffer "miss" leads to the buffer
 * being flushed and a serial flash transaction being triggered as per the
 * sequence pointed to by the SEQID field. Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_buf2cr
{
    uint32_t U;
    struct _hw_quadspi_buf2cr_bitfields
    {
        uint32_t MSTRID : 4;           /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t ADATSZ : 8;           /*!< [15:8]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_quadspi_buf2cr_t;

/*!
 * @name Constants and macros for entire QuadSPI_BUF2CR register
 */
/*@{*/
#define HW_QuadSPI_BUF2CR_ADDR(x) ((uintptr_t)(x) + 0x18U)

#define HW_QuadSPI_BUF2CR(x)     (*(__IO hw_quadspi_buf2cr_t *) HW_QuadSPI_BUF2CR_ADDR(x))
#define HW_QuadSPI_BUF2CR_RD(x)  (HW_QuadSPI_BUF2CR(x).U)
#define HW_QuadSPI_BUF2CR_WR(x, v) (HW_QuadSPI_BUF2CR(x).U = (v))
#define HW_QuadSPI_BUF2CR_SET(x, v) (HW_QuadSPI_BUF2CR_WR(x, HW_QuadSPI_BUF2CR_RD(x) |  (v)))
#define HW_QuadSPI_BUF2CR_CLR(x, v) (HW_QuadSPI_BUF2CR_WR(x, HW_QuadSPI_BUF2CR_RD(x) & ~(v)))
#define HW_QuadSPI_BUF2CR_TOG(x, v) (HW_QuadSPI_BUF2CR_WR(x, HW_QuadSPI_BUF2CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_BUF2CR bitfields
 */

/*!
 * @name Register QuadSPI_BUF2CR, field MSTRID[3:0] (RW)
 *
 * Master ID: The ID of the AHB master associated with BUFFER2. Any AHB access
 * with this master port number is routed to this buffer.
 */
/*@{*/
#define BP_QuadSPI_BUF2CR_MSTRID (0U)      /*!< Bit position for QuadSPI_BUF2CR_MSTRID. */
#define BM_QuadSPI_BUF2CR_MSTRID (0x0000000FU) /*!< Bit mask for QuadSPI_BUF2CR_MSTRID. */
#define BS_QuadSPI_BUF2CR_MSTRID (4U)      /*!< Bit field size in bits for QuadSPI_BUF2CR_MSTRID. */

/*! @brief Read current value of the QuadSPI_BUF2CR_MSTRID field. */
#define BR_QuadSPI_BUF2CR_MSTRID(x) (HW_QuadSPI_BUF2CR(x).B.MSTRID)

/*! @brief Format value for bitfield QuadSPI_BUF2CR_MSTRID. */
#define BF_QuadSPI_BUF2CR_MSTRID(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF2CR_MSTRID) & BM_QuadSPI_BUF2CR_MSTRID)

/*! @brief Set the MSTRID field to a new value. */
#define BW_QuadSPI_BUF2CR_MSTRID(x, v) (HW_QuadSPI_BUF2CR_WR(x, (HW_QuadSPI_BUF2CR_RD(x) & ~BM_QuadSPI_BUF2CR_MSTRID) | BF_QuadSPI_BUF2CR_MSTRID(v)))
/*@}*/

/*!
 * @name Register QuadSPI_BUF2CR, field ADATSZ[15:8] (RW)
 *
 * AHB data transfer size: Defines the data transfer size in 8 Bytes of an AHB
 * triggered access to serial flash. For example, a value of 0x2 will set transfer
 * size to 16bytes.When ADATSZ = 0, the data size mentioned the sequence pointed
 * to by the SEQID field overrides this value. SW should ensure that this
 * transfer size is not greater than the size of this buffer.
 */
/*@{*/
#define BP_QuadSPI_BUF2CR_ADATSZ (8U)      /*!< Bit position for QuadSPI_BUF2CR_ADATSZ. */
#define BM_QuadSPI_BUF2CR_ADATSZ (0x0000FF00U) /*!< Bit mask for QuadSPI_BUF2CR_ADATSZ. */
#define BS_QuadSPI_BUF2CR_ADATSZ (8U)      /*!< Bit field size in bits for QuadSPI_BUF2CR_ADATSZ. */

/*! @brief Read current value of the QuadSPI_BUF2CR_ADATSZ field. */
#define BR_QuadSPI_BUF2CR_ADATSZ(x) (HW_QuadSPI_BUF2CR(x).B.ADATSZ)

/*! @brief Format value for bitfield QuadSPI_BUF2CR_ADATSZ. */
#define BF_QuadSPI_BUF2CR_ADATSZ(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF2CR_ADATSZ) & BM_QuadSPI_BUF2CR_ADATSZ)

/*! @brief Set the ADATSZ field to a new value. */
#define BW_QuadSPI_BUF2CR_ADATSZ(x, v) (HW_QuadSPI_BUF2CR_WR(x, (HW_QuadSPI_BUF2CR_RD(x) & ~BM_QuadSPI_BUF2CR_ADATSZ) | BF_QuadSPI_BUF2CR_ADATSZ(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_BUF3CR - Buffer3 Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_BUF3CR - Buffer3 Configuration Register (RW)
 *
 * Reset value: 0x80000000U
 *
 * This register provides the configuration for any access to buffer3. An access
 * is routed to buffer3 when the master port number of the incoming AHB request
 * matches the MSTRID field of the BUF3CR. Any buffer "miss" leads to the buffer
 * being flushed a serial flash transaction being triggered as per the sequence
 * pointed to by the SEQID field. If the ALLMST field is set, any transaction
 * where the master port number does not match any of the buffer MSTRID fields will
 * be routed to this buffer. In the case that the ALLMST field is not set, any
 * such transaction (where master port number does not match any of the MSTRID
 * fields) will be returned an ERROR response. Write: QSPI_SR[AHB_ACC] = 0 .
 */
typedef union _hw_quadspi_buf3cr
{
    uint32_t U;
    struct _hw_quadspi_buf3cr_bitfields
    {
        uint32_t MSTRID : 4;           /*!< [3:0]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t ADATSZ : 8;           /*!< [15:8]  */
        uint32_t RESERVED1 : 15;       /*!< [30:16]  */
        uint32_t ALLMST : 1;           /*!< [31]  */
    } B;
} hw_quadspi_buf3cr_t;

/*!
 * @name Constants and macros for entire QuadSPI_BUF3CR register
 */
/*@{*/
#define HW_QuadSPI_BUF3CR_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_QuadSPI_BUF3CR(x)     (*(__IO hw_quadspi_buf3cr_t *) HW_QuadSPI_BUF3CR_ADDR(x))
#define HW_QuadSPI_BUF3CR_RD(x)  (HW_QuadSPI_BUF3CR(x).U)
#define HW_QuadSPI_BUF3CR_WR(x, v) (HW_QuadSPI_BUF3CR(x).U = (v))
#define HW_QuadSPI_BUF3CR_SET(x, v) (HW_QuadSPI_BUF3CR_WR(x, HW_QuadSPI_BUF3CR_RD(x) |  (v)))
#define HW_QuadSPI_BUF3CR_CLR(x, v) (HW_QuadSPI_BUF3CR_WR(x, HW_QuadSPI_BUF3CR_RD(x) & ~(v)))
#define HW_QuadSPI_BUF3CR_TOG(x, v) (HW_QuadSPI_BUF3CR_WR(x, HW_QuadSPI_BUF3CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_BUF3CR bitfields
 */

/*!
 * @name Register QuadSPI_BUF3CR, field MSTRID[3:0] (RW)
 *
 * Master ID: The ID of the AHB master associated with BUFFER3. Any AHB access
 * with this master port number is routed to this buffer.
 */
/*@{*/
#define BP_QuadSPI_BUF3CR_MSTRID (0U)      /*!< Bit position for QuadSPI_BUF3CR_MSTRID. */
#define BM_QuadSPI_BUF3CR_MSTRID (0x0000000FU) /*!< Bit mask for QuadSPI_BUF3CR_MSTRID. */
#define BS_QuadSPI_BUF3CR_MSTRID (4U)      /*!< Bit field size in bits for QuadSPI_BUF3CR_MSTRID. */

/*! @brief Read current value of the QuadSPI_BUF3CR_MSTRID field. */
#define BR_QuadSPI_BUF3CR_MSTRID(x) (HW_QuadSPI_BUF3CR(x).B.MSTRID)

/*! @brief Format value for bitfield QuadSPI_BUF3CR_MSTRID. */
#define BF_QuadSPI_BUF3CR_MSTRID(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF3CR_MSTRID) & BM_QuadSPI_BUF3CR_MSTRID)

/*! @brief Set the MSTRID field to a new value. */
#define BW_QuadSPI_BUF3CR_MSTRID(x, v) (HW_QuadSPI_BUF3CR_WR(x, (HW_QuadSPI_BUF3CR_RD(x) & ~BM_QuadSPI_BUF3CR_MSTRID) | BF_QuadSPI_BUF3CR_MSTRID(v)))
/*@}*/

/*!
 * @name Register QuadSPI_BUF3CR, field ADATSZ[15:8] (RW)
 *
 * AHB data transfer size: Defines the data transfer size in 8 Bytes of an AHB
 * triggered access to serial flash. When ADATSZ = 0, the data size mentioned the
 * sequence pointed to by the SEQID field overrides this value. SW should ensure
 * that this transfer size is not greater than the size of this buffer.
 */
/*@{*/
#define BP_QuadSPI_BUF3CR_ADATSZ (8U)      /*!< Bit position for QuadSPI_BUF3CR_ADATSZ. */
#define BM_QuadSPI_BUF3CR_ADATSZ (0x0000FF00U) /*!< Bit mask for QuadSPI_BUF3CR_ADATSZ. */
#define BS_QuadSPI_BUF3CR_ADATSZ (8U)      /*!< Bit field size in bits for QuadSPI_BUF3CR_ADATSZ. */

/*! @brief Read current value of the QuadSPI_BUF3CR_ADATSZ field. */
#define BR_QuadSPI_BUF3CR_ADATSZ(x) (HW_QuadSPI_BUF3CR(x).B.ADATSZ)

/*! @brief Format value for bitfield QuadSPI_BUF3CR_ADATSZ. */
#define BF_QuadSPI_BUF3CR_ADATSZ(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF3CR_ADATSZ) & BM_QuadSPI_BUF3CR_ADATSZ)

/*! @brief Set the ADATSZ field to a new value. */
#define BW_QuadSPI_BUF3CR_ADATSZ(x, v) (HW_QuadSPI_BUF3CR_WR(x, (HW_QuadSPI_BUF3CR_RD(x) & ~BM_QuadSPI_BUF3CR_ADATSZ) | BF_QuadSPI_BUF3CR_ADATSZ(v)))
/*@}*/

/*!
 * @name Register QuadSPI_BUF3CR, field ALLMST[31] (RW)
 *
 * All master enable: When set, buffer3 acts as an all-master buffer. Any AHB
 * access with a master port number not matching with the master ID of buffer0 or
 * buffer1 or buffer2 is routed to buffer3. When set, the MSTRID field of this
 * register is ignored.
 */
/*@{*/
#define BP_QuadSPI_BUF3CR_ALLMST (31U)     /*!< Bit position for QuadSPI_BUF3CR_ALLMST. */
#define BM_QuadSPI_BUF3CR_ALLMST (0x80000000U) /*!< Bit mask for QuadSPI_BUF3CR_ALLMST. */
#define BS_QuadSPI_BUF3CR_ALLMST (1U)      /*!< Bit field size in bits for QuadSPI_BUF3CR_ALLMST. */

/*! @brief Read current value of the QuadSPI_BUF3CR_ALLMST field. */
#define BR_QuadSPI_BUF3CR_ALLMST(x) (HW_QuadSPI_BUF3CR(x).B.ALLMST)

/*! @brief Format value for bitfield QuadSPI_BUF3CR_ALLMST. */
#define BF_QuadSPI_BUF3CR_ALLMST(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF3CR_ALLMST) & BM_QuadSPI_BUF3CR_ALLMST)

/*! @brief Set the ALLMST field to a new value. */
#define BW_QuadSPI_BUF3CR_ALLMST(x, v) (HW_QuadSPI_BUF3CR_WR(x, (HW_QuadSPI_BUF3CR_RD(x) & ~BM_QuadSPI_BUF3CR_ALLMST) | BF_QuadSPI_BUF3CR_ALLMST(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_BFGENCR - Buffer Generic Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_BFGENCR - Buffer Generic Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the generic configuration to any of the buffer
 * accesses. Any buffer "miss" leads to the buffer being flushed and a serial flash
 * transaction being triggered as per the sequence pointed to by the SEQID field. If
 * the PAR_EN field is set, all the buffer accesses result in parallel accesses
 * to the flashes. Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_bfgencr
{
    uint32_t U;
    struct _hw_quadspi_bfgencr_bitfields
    {
        uint32_t RESERVED0 : 12;       /*!< [11:0]  */
        uint32_t SEQID : 4;            /*!< [15:12]  */
        uint32_t PAR_EN : 1;           /*!< [16]  */
        uint32_t RESERVED1 : 15;       /*!< [31:17]  */
    } B;
} hw_quadspi_bfgencr_t;

/*!
 * @name Constants and macros for entire QuadSPI_BFGENCR register
 */
/*@{*/
#define HW_QuadSPI_BFGENCR_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_QuadSPI_BFGENCR(x)    (*(__IO hw_quadspi_bfgencr_t *) HW_QuadSPI_BFGENCR_ADDR(x))
#define HW_QuadSPI_BFGENCR_RD(x) (HW_QuadSPI_BFGENCR(x).U)
#define HW_QuadSPI_BFGENCR_WR(x, v) (HW_QuadSPI_BFGENCR(x).U = (v))
#define HW_QuadSPI_BFGENCR_SET(x, v) (HW_QuadSPI_BFGENCR_WR(x, HW_QuadSPI_BFGENCR_RD(x) |  (v)))
#define HW_QuadSPI_BFGENCR_CLR(x, v) (HW_QuadSPI_BFGENCR_WR(x, HW_QuadSPI_BFGENCR_RD(x) & ~(v)))
#define HW_QuadSPI_BFGENCR_TOG(x, v) (HW_QuadSPI_BFGENCR_WR(x, HW_QuadSPI_BFGENCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_BFGENCR bitfields
 */

/*!
 * @name Register QuadSPI_BFGENCR, field SEQID[15:12] (RW)
 *
 * Points to a sequence in the Look-up-table. The SEQID defines the bits [6:2]
 * of the LUT index. The bits [1:0] are always assumed to be 0. Refer to Look-up
 * Table. If the sequence pointer differs between the new and previous sequence
 * then the user should reset this. See QSPI_SPTRCLR for more information.
 */
/*@{*/
#define BP_QuadSPI_BFGENCR_SEQID (12U)     /*!< Bit position for QuadSPI_BFGENCR_SEQID. */
#define BM_QuadSPI_BFGENCR_SEQID (0x0000F000U) /*!< Bit mask for QuadSPI_BFGENCR_SEQID. */
#define BS_QuadSPI_BFGENCR_SEQID (4U)      /*!< Bit field size in bits for QuadSPI_BFGENCR_SEQID. */

/*! @brief Read current value of the QuadSPI_BFGENCR_SEQID field. */
#define BR_QuadSPI_BFGENCR_SEQID(x) (HW_QuadSPI_BFGENCR(x).B.SEQID)

/*! @brief Format value for bitfield QuadSPI_BFGENCR_SEQID. */
#define BF_QuadSPI_BFGENCR_SEQID(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BFGENCR_SEQID) & BM_QuadSPI_BFGENCR_SEQID)

/*! @brief Set the SEQID field to a new value. */
#define BW_QuadSPI_BFGENCR_SEQID(x, v) (HW_QuadSPI_BFGENCR_WR(x, (HW_QuadSPI_BFGENCR_RD(x) & ~BM_QuadSPI_BFGENCR_SEQID) | BF_QuadSPI_BFGENCR_SEQID(v)))
/*@}*/

/*!
 * @name Register QuadSPI_BFGENCR, field PAR_EN[16] (RW)
 *
 * When set, a transaction to two serial flash devices is triggered in parallel
 * mode. Refer to Parallel Flash Mode for more details.
 */
/*@{*/
#define BP_QuadSPI_BFGENCR_PAR_EN (16U)    /*!< Bit position for QuadSPI_BFGENCR_PAR_EN. */
#define BM_QuadSPI_BFGENCR_PAR_EN (0x00010000U) /*!< Bit mask for QuadSPI_BFGENCR_PAR_EN. */
#define BS_QuadSPI_BFGENCR_PAR_EN (1U)     /*!< Bit field size in bits for QuadSPI_BFGENCR_PAR_EN. */

/*! @brief Read current value of the QuadSPI_BFGENCR_PAR_EN field. */
#define BR_QuadSPI_BFGENCR_PAR_EN(x) (HW_QuadSPI_BFGENCR(x).B.PAR_EN)

/*! @brief Format value for bitfield QuadSPI_BFGENCR_PAR_EN. */
#define BF_QuadSPI_BFGENCR_PAR_EN(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BFGENCR_PAR_EN) & BM_QuadSPI_BFGENCR_PAR_EN)

/*! @brief Set the PAR_EN field to a new value. */
#define BW_QuadSPI_BFGENCR_PAR_EN(x, v) (HW_QuadSPI_BFGENCR_WR(x, (HW_QuadSPI_BFGENCR_RD(x) & ~BM_QuadSPI_BFGENCR_PAR_EN) | BF_QuadSPI_BFGENCR_PAR_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_BUF0IND - Buffer0 Top Index Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_BUF0IND - Buffer0 Top Index Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register specifies the top index of buffer0, which defines its size.
 * Note that that the 3 LSBs of this register are set to zero - this ensures that
 * the buffer is 64bit aligned, as each buffer entry is 64bits long. The register
 * value should be set to the desired number of bytes less 8. For example, setting
 * BUF0IND to 0 gives 8 bytes, 1 give 16bytes etc. The size of buffer0 is the
 * difference between the BUF0IND+8 and 0. It is the responsibility of the software
 * to ensure that BUF0IND value is not greater than the overall size of the
 * buffer. The hardware does not provide any protection against illegal programming.
 * Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_buf0ind
{
    uint32_t U;
    struct _hw_quadspi_buf0ind_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t TPINDX0 : 29;         /*!< [31:3]  */
    } B;
} hw_quadspi_buf0ind_t;

/*!
 * @name Constants and macros for entire QuadSPI_BUF0IND register
 */
/*@{*/
#define HW_QuadSPI_BUF0IND_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_QuadSPI_BUF0IND(x)    (*(__IO hw_quadspi_buf0ind_t *) HW_QuadSPI_BUF0IND_ADDR(x))
#define HW_QuadSPI_BUF0IND_RD(x) (HW_QuadSPI_BUF0IND(x).U)
#define HW_QuadSPI_BUF0IND_WR(x, v) (HW_QuadSPI_BUF0IND(x).U = (v))
#define HW_QuadSPI_BUF0IND_SET(x, v) (HW_QuadSPI_BUF0IND_WR(x, HW_QuadSPI_BUF0IND_RD(x) |  (v)))
#define HW_QuadSPI_BUF0IND_CLR(x, v) (HW_QuadSPI_BUF0IND_WR(x, HW_QuadSPI_BUF0IND_RD(x) & ~(v)))
#define HW_QuadSPI_BUF0IND_TOG(x, v) (HW_QuadSPI_BUF0IND_WR(x, HW_QuadSPI_BUF0IND_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_BUF0IND bitfields
 */

/*!
 * @name Register QuadSPI_BUF0IND, field TPINDX0[31:3] (RW)
 *
 * Top index of buffer 0.
 */
/*@{*/
#define BP_QuadSPI_BUF0IND_TPINDX0 (3U)    /*!< Bit position for QuadSPI_BUF0IND_TPINDX0. */
#define BM_QuadSPI_BUF0IND_TPINDX0 (0xFFFFFFF8U) /*!< Bit mask for QuadSPI_BUF0IND_TPINDX0. */
#define BS_QuadSPI_BUF0IND_TPINDX0 (29U)   /*!< Bit field size in bits for QuadSPI_BUF0IND_TPINDX0. */

/*! @brief Read current value of the QuadSPI_BUF0IND_TPINDX0 field. */
#define BR_QuadSPI_BUF0IND_TPINDX0(x) (HW_QuadSPI_BUF0IND(x).B.TPINDX0)

/*! @brief Format value for bitfield QuadSPI_BUF0IND_TPINDX0. */
#define BF_QuadSPI_BUF0IND_TPINDX0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF0IND_TPINDX0) & BM_QuadSPI_BUF0IND_TPINDX0)

/*! @brief Set the TPINDX0 field to a new value. */
#define BW_QuadSPI_BUF0IND_TPINDX0(x, v) (HW_QuadSPI_BUF0IND_WR(x, (HW_QuadSPI_BUF0IND_RD(x) & ~BM_QuadSPI_BUF0IND_TPINDX0) | BF_QuadSPI_BUF0IND_TPINDX0(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_BUF1IND - Buffer1 Top Index Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_BUF1IND - Buffer1 Top Index Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register specifies the top index of buffer1, which defines its size.
 * Note that the 3 LSBs of this register are set to zero - this ensures that the
 * buffer is 64bit aligned as each buffer entry is 64bits long. The register value
 * should be set to the desired number of bytes less. The size of buffer1 is the
 * difference between the BUF1IND and BUF0IND. It is the responsibility of the
 * software to ensure that BUF1IND value is not greater than the overall size of the
 * buffer. The hardware does not provide any protection against illegal
 * programming. Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_buf1ind
{
    uint32_t U;
    struct _hw_quadspi_buf1ind_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t TPINDX1 : 29;         /*!< [31:3]  */
    } B;
} hw_quadspi_buf1ind_t;

/*!
 * @name Constants and macros for entire QuadSPI_BUF1IND register
 */
/*@{*/
#define HW_QuadSPI_BUF1IND_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_QuadSPI_BUF1IND(x)    (*(__IO hw_quadspi_buf1ind_t *) HW_QuadSPI_BUF1IND_ADDR(x))
#define HW_QuadSPI_BUF1IND_RD(x) (HW_QuadSPI_BUF1IND(x).U)
#define HW_QuadSPI_BUF1IND_WR(x, v) (HW_QuadSPI_BUF1IND(x).U = (v))
#define HW_QuadSPI_BUF1IND_SET(x, v) (HW_QuadSPI_BUF1IND_WR(x, HW_QuadSPI_BUF1IND_RD(x) |  (v)))
#define HW_QuadSPI_BUF1IND_CLR(x, v) (HW_QuadSPI_BUF1IND_WR(x, HW_QuadSPI_BUF1IND_RD(x) & ~(v)))
#define HW_QuadSPI_BUF1IND_TOG(x, v) (HW_QuadSPI_BUF1IND_WR(x, HW_QuadSPI_BUF1IND_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_BUF1IND bitfields
 */

/*!
 * @name Register QuadSPI_BUF1IND, field TPINDX1[31:3] (RW)
 *
 * Top index of buffer 1.
 */
/*@{*/
#define BP_QuadSPI_BUF1IND_TPINDX1 (3U)    /*!< Bit position for QuadSPI_BUF1IND_TPINDX1. */
#define BM_QuadSPI_BUF1IND_TPINDX1 (0xFFFFFFF8U) /*!< Bit mask for QuadSPI_BUF1IND_TPINDX1. */
#define BS_QuadSPI_BUF1IND_TPINDX1 (29U)   /*!< Bit field size in bits for QuadSPI_BUF1IND_TPINDX1. */

/*! @brief Read current value of the QuadSPI_BUF1IND_TPINDX1 field. */
#define BR_QuadSPI_BUF1IND_TPINDX1(x) (HW_QuadSPI_BUF1IND(x).B.TPINDX1)

/*! @brief Format value for bitfield QuadSPI_BUF1IND_TPINDX1. */
#define BF_QuadSPI_BUF1IND_TPINDX1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF1IND_TPINDX1) & BM_QuadSPI_BUF1IND_TPINDX1)

/*! @brief Set the TPINDX1 field to a new value. */
#define BW_QuadSPI_BUF1IND_TPINDX1(x, v) (HW_QuadSPI_BUF1IND_WR(x, (HW_QuadSPI_BUF1IND_RD(x) & ~BM_QuadSPI_BUF1IND_TPINDX1) | BF_QuadSPI_BUF1IND_TPINDX1(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_BUF2IND - Buffer2 Top Index Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_BUF2IND - Buffer2 Top Index Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register specifies the top index of buffer2, which defines its size.
 * Note that that the 3 LSBs of this register are set to zero - this ensures that
 * the buffer is 64bit aligned as each buffer entry is 64bits long. The register
 * value should be set to the desired number of bytes less 8. The size of buffer2
 * is the difference between the BUF2IND and BUF1IND. It is the responsibility of
 * the software to ensure that BUF2IND value is not greater than the overall size
 * of the buffer. The hardware does not provide any protection against illegal
 * programming. Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_buf2ind
{
    uint32_t U;
    struct _hw_quadspi_buf2ind_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t TPINDX2 : 29;         /*!< [31:3]  */
    } B;
} hw_quadspi_buf2ind_t;

/*!
 * @name Constants and macros for entire QuadSPI_BUF2IND register
 */
/*@{*/
#define HW_QuadSPI_BUF2IND_ADDR(x) ((uintptr_t)(x) + 0x38U)

#define HW_QuadSPI_BUF2IND(x)    (*(__IO hw_quadspi_buf2ind_t *) HW_QuadSPI_BUF2IND_ADDR(x))
#define HW_QuadSPI_BUF2IND_RD(x) (HW_QuadSPI_BUF2IND(x).U)
#define HW_QuadSPI_BUF2IND_WR(x, v) (HW_QuadSPI_BUF2IND(x).U = (v))
#define HW_QuadSPI_BUF2IND_SET(x, v) (HW_QuadSPI_BUF2IND_WR(x, HW_QuadSPI_BUF2IND_RD(x) |  (v)))
#define HW_QuadSPI_BUF2IND_CLR(x, v) (HW_QuadSPI_BUF2IND_WR(x, HW_QuadSPI_BUF2IND_RD(x) & ~(v)))
#define HW_QuadSPI_BUF2IND_TOG(x, v) (HW_QuadSPI_BUF2IND_WR(x, HW_QuadSPI_BUF2IND_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_BUF2IND bitfields
 */

/*!
 * @name Register QuadSPI_BUF2IND, field TPINDX2[31:3] (RW)
 *
 * Top index of buffer 2.
 */
/*@{*/
#define BP_QuadSPI_BUF2IND_TPINDX2 (3U)    /*!< Bit position for QuadSPI_BUF2IND_TPINDX2. */
#define BM_QuadSPI_BUF2IND_TPINDX2 (0xFFFFFFF8U) /*!< Bit mask for QuadSPI_BUF2IND_TPINDX2. */
#define BS_QuadSPI_BUF2IND_TPINDX2 (29U)   /*!< Bit field size in bits for QuadSPI_BUF2IND_TPINDX2. */

/*! @brief Read current value of the QuadSPI_BUF2IND_TPINDX2 field. */
#define BR_QuadSPI_BUF2IND_TPINDX2(x) (HW_QuadSPI_BUF2IND(x).B.TPINDX2)

/*! @brief Format value for bitfield QuadSPI_BUF2IND_TPINDX2. */
#define BF_QuadSPI_BUF2IND_TPINDX2(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_BUF2IND_TPINDX2) & BM_QuadSPI_BUF2IND_TPINDX2)

/*! @brief Set the TPINDX2 field to a new value. */
#define BW_QuadSPI_BUF2IND_TPINDX2(x, v) (HW_QuadSPI_BUF2IND_WR(x, (HW_QuadSPI_BUF2IND_RD(x) & ~BM_QuadSPI_BUF2IND_TPINDX2) | BF_QuadSPI_BUF2IND_TPINDX2(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_SFAR - Serial Flash Address Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_SFAR - Serial Flash Address Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The module automatically translates this address on the memory map to the
 * address on the flash itself. When operating in 24bit mode, only bits 23-0 are
 * sent to the flash, in 32bit mode, bits 27-0 are used with bits 31-28 driven to 0
 * Refer to for the mapping between the access mode and the QSPI_SFAR content and
 * to Normal Modefor details about the command triggering and command execution.
 * The software should ensure that the serial flash address provided in the
 * QSPI_SFAR register lies in the valid flash address range as defined in . Write:
 * QSPI_SR[IP_ACC] = 0
 */
typedef union _hw_quadspi_sfar
{
    uint32_t U;
    struct _hw_quadspi_sfar_bitfields
    {
        uint32_t SFADR : 32;           /*!< [31:0]  */
    } B;
} hw_quadspi_sfar_t;

/*!
 * @name Constants and macros for entire QuadSPI_SFAR register
 */
/*@{*/
#define HW_QuadSPI_SFAR_ADDR(x)  ((uintptr_t)(x) + 0x100U)

#define HW_QuadSPI_SFAR(x)       (*(__IO hw_quadspi_sfar_t *) HW_QuadSPI_SFAR_ADDR(x))
#define HW_QuadSPI_SFAR_RD(x)    (HW_QuadSPI_SFAR(x).U)
#define HW_QuadSPI_SFAR_WR(x, v) (HW_QuadSPI_SFAR(x).U = (v))
#define HW_QuadSPI_SFAR_SET(x, v) (HW_QuadSPI_SFAR_WR(x, HW_QuadSPI_SFAR_RD(x) |  (v)))
#define HW_QuadSPI_SFAR_CLR(x, v) (HW_QuadSPI_SFAR_WR(x, HW_QuadSPI_SFAR_RD(x) & ~(v)))
#define HW_QuadSPI_SFAR_TOG(x, v) (HW_QuadSPI_SFAR_WR(x, HW_QuadSPI_SFAR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_SFAR bitfields
 */

/*!
 * @name Register QuadSPI_SFAR, field SFADR[31:0] (RW)
 *
 * Serial Flash Address. The register content is used as byte address for all
 * following IP Commands.
 */
/*@{*/
#define BP_QuadSPI_SFAR_SFADR (0U)         /*!< Bit position for QuadSPI_SFAR_SFADR. */
#define BM_QuadSPI_SFAR_SFADR (0xFFFFFFFFU) /*!< Bit mask for QuadSPI_SFAR_SFADR. */
#define BS_QuadSPI_SFAR_SFADR (32U)        /*!< Bit field size in bits for QuadSPI_SFAR_SFADR. */

/*! @brief Read current value of the QuadSPI_SFAR_SFADR field. */
#define BR_QuadSPI_SFAR_SFADR(x) (HW_QuadSPI_SFAR(x).U)

/*! @brief Format value for bitfield QuadSPI_SFAR_SFADR. */
#define BF_QuadSPI_SFAR_SFADR(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SFAR_SFADR) & BM_QuadSPI_SFAR_SFADR)

/*! @brief Set the SFADR field to a new value. */
#define BW_QuadSPI_SFAR_SFADR(x, v) (HW_QuadSPI_SFAR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_SMPR - Sampling Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_SMPR - Sampling Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Sampling Register allows configuration of how the incoming data from the
 * external serial flash devices are sampled in the QuadSPI module.
 * Write:Disabled Mode
 */
typedef union _hw_quadspi_smpr
{
    uint32_t U;
    struct _hw_quadspi_smpr_bitfields
    {
        uint32_t RESERVED0 : 5;        /*!< [4:0]  */
        uint32_t SDRSMP : 2;           /*!< [6:5]  */
        uint32_t RESERVED1 : 9;        /*!< [15:7]  */
        uint32_t DDRSMP : 3;           /*!< [18:16]  */
        uint32_t RESERVED2 : 13;       /*!< [31:19]  */
    } B;
} hw_quadspi_smpr_t;

/*!
 * @name Constants and macros for entire QuadSPI_SMPR register
 */
/*@{*/
#define HW_QuadSPI_SMPR_ADDR(x)  ((uintptr_t)(x) + 0x108U)

#define HW_QuadSPI_SMPR(x)       (*(__IO hw_quadspi_smpr_t *) HW_QuadSPI_SMPR_ADDR(x))
#define HW_QuadSPI_SMPR_RD(x)    (HW_QuadSPI_SMPR(x).U)
#define HW_QuadSPI_SMPR_WR(x, v) (HW_QuadSPI_SMPR(x).U = (v))
#define HW_QuadSPI_SMPR_SET(x, v) (HW_QuadSPI_SMPR_WR(x, HW_QuadSPI_SMPR_RD(x) |  (v)))
#define HW_QuadSPI_SMPR_CLR(x, v) (HW_QuadSPI_SMPR_WR(x, HW_QuadSPI_SMPR_RD(x) & ~(v)))
#define HW_QuadSPI_SMPR_TOG(x, v) (HW_QuadSPI_SMPR_WR(x, HW_QuadSPI_SMPR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_SMPR bitfields
 */

/*!
 * @name Register QuadSPI_SMPR, field SDRSMP[6:5] (RW)
 *
 * SDR sampling point.
 */
/*@{*/
#define BP_QuadSPI_SMPR_SDRSMP (5U)        /*!< Bit position for QuadSPI_SMPR_SDRSMP. */
#define BM_QuadSPI_SMPR_SDRSMP (0x00000060U) /*!< Bit mask for QuadSPI_SMPR_SDRSMP. */
#define BS_QuadSPI_SMPR_SDRSMP (2U)        /*!< Bit field size in bits for QuadSPI_SMPR_SDRSMP. */

/*! @brief Read current value of the QuadSPI_SMPR_SDRSMP field. */
#define BR_QuadSPI_SMPR_SDRSMP(x) (HW_QuadSPI_SMPR(x).B.SDRSMP)

/*! @brief Format value for bitfield QuadSPI_SMPR_SDRSMP. */
#define BF_QuadSPI_SMPR_SDRSMP(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SMPR_SDRSMP) & BM_QuadSPI_SMPR_SDRSMP)

/*! @brief Set the SDRSMP field to a new value. */
#define BW_QuadSPI_SMPR_SDRSMP(x, v) (HW_QuadSPI_SMPR_WR(x, (HW_QuadSPI_SMPR_RD(x) & ~BM_QuadSPI_SMPR_SDRSMP) | BF_QuadSPI_SMPR_SDRSMP(v)))
/*@}*/

/*!
 * @name Register QuadSPI_SMPR, field DDRSMP[18:16] (RW)
 *
 * DDR Sampling point. Select the sampling point for incoming data when serial
 * flash is executing a DDR instruction. Refer to Input timing in DDR mode with
 * internal sampling , for details on the sampling points.
 */
/*@{*/
#define BP_QuadSPI_SMPR_DDRSMP (16U)       /*!< Bit position for QuadSPI_SMPR_DDRSMP. */
#define BM_QuadSPI_SMPR_DDRSMP (0x00070000U) /*!< Bit mask for QuadSPI_SMPR_DDRSMP. */
#define BS_QuadSPI_SMPR_DDRSMP (3U)        /*!< Bit field size in bits for QuadSPI_SMPR_DDRSMP. */

/*! @brief Read current value of the QuadSPI_SMPR_DDRSMP field. */
#define BR_QuadSPI_SMPR_DDRSMP(x) (HW_QuadSPI_SMPR(x).B.DDRSMP)

/*! @brief Format value for bitfield QuadSPI_SMPR_DDRSMP. */
#define BF_QuadSPI_SMPR_DDRSMP(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SMPR_DDRSMP) & BM_QuadSPI_SMPR_DDRSMP)

/*! @brief Set the DDRSMP field to a new value. */
#define BW_QuadSPI_SMPR_DDRSMP(x, v) (HW_QuadSPI_SMPR_WR(x, (HW_QuadSPI_SMPR_RD(x) & ~BM_QuadSPI_SMPR_DDRSMP) | BF_QuadSPI_SMPR_DDRSMP(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_RBSR - RX Buffer Status Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_RBSR - RX Buffer Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register contains information related to the receive data buffer.
 */
typedef union _hw_quadspi_rbsr
{
    uint32_t U;
    struct _hw_quadspi_rbsr_bitfields
    {
        uint32_t RESERVED0 : 8;        /*!< [7:0]  */
        uint32_t RDBFL : 6;            /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t RDCTR : 16;           /*!< [31:16]  */
    } B;
} hw_quadspi_rbsr_t;

/*!
 * @name Constants and macros for entire QuadSPI_RBSR register
 */
/*@{*/
#define HW_QuadSPI_RBSR_ADDR(x)  ((uintptr_t)(x) + 0x10CU)

#define HW_QuadSPI_RBSR(x)       (*(__I hw_quadspi_rbsr_t *) HW_QuadSPI_RBSR_ADDR(x))
#define HW_QuadSPI_RBSR_RD(x)    (HW_QuadSPI_RBSR(x).U)
/*@}*/

/*
 * Constants & macros for individual QuadSPI_RBSR bitfields
 */

/*!
 * @name Register QuadSPI_RBSR, field RDBFL[13:8] (RO)
 *
 * RX Buffer Fill Level, indicates how many entries of 4 bytes are still
 * available in the RX Buffer.For example a value of 0x2 would indicate 8bytes are
 * available.
 */
/*@{*/
#define BP_QuadSPI_RBSR_RDBFL (8U)         /*!< Bit position for QuadSPI_RBSR_RDBFL. */
#define BM_QuadSPI_RBSR_RDBFL (0x00003F00U) /*!< Bit mask for QuadSPI_RBSR_RDBFL. */
#define BS_QuadSPI_RBSR_RDBFL (6U)         /*!< Bit field size in bits for QuadSPI_RBSR_RDBFL. */

/*! @brief Read current value of the QuadSPI_RBSR_RDBFL field. */
#define BR_QuadSPI_RBSR_RDBFL(x) (HW_QuadSPI_RBSR(x).B.RDBFL)
/*@}*/

/*!
 * @name Register QuadSPI_RBSR, field RDCTR[31:16] (RO)
 *
 * Read Counter, indicates how many entries of 4 bytes have been removed from
 * the RX Buffer.For example a value of 0x2 would indicate 8bytes have been removed
 * It is incremented by the number (QSPI_RBCT[WMRK] + 1) on RX Buffer POP event.
 * The RX Buffer can be popped using DMA or pop flag QSPI_FR[RBDF]. The
 * QSPI_RSER[RBDDE] defines which pop has to be done. For further details please refer to
 * AHB RX Data Buffer (QSPI_ARDB0 to QSPI_ARDB31) and "Data Transfer from the
 * QuadSPI Module Internal Buffers section in Flash Readsection.
 */
/*@{*/
#define BP_QuadSPI_RBSR_RDCTR (16U)        /*!< Bit position for QuadSPI_RBSR_RDCTR. */
#define BM_QuadSPI_RBSR_RDCTR (0xFFFF0000U) /*!< Bit mask for QuadSPI_RBSR_RDCTR. */
#define BS_QuadSPI_RBSR_RDCTR (16U)        /*!< Bit field size in bits for QuadSPI_RBSR_RDCTR. */

/*! @brief Read current value of the QuadSPI_RBSR_RDCTR field. */
#define BR_QuadSPI_RBSR_RDCTR(x) (HW_QuadSPI_RBSR(x).B.RDCTR)
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_RBCT - RX Buffer Control Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_RBCT - RX Buffer Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains control data related to the receive data buffer.
 * Write: QSPI_SR[IP_ACC] = 0
 */
typedef union _hw_quadspi_rbct
{
    uint32_t U;
    struct _hw_quadspi_rbct_bitfields
    {
        uint32_t WMRK : 5;             /*!< [4:0]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t RXBRD : 1;            /*!< [8]  */
        uint32_t RESERVED1 : 23;       /*!< [31:9]  */
    } B;
} hw_quadspi_rbct_t;

/*!
 * @name Constants and macros for entire QuadSPI_RBCT register
 */
/*@{*/
#define HW_QuadSPI_RBCT_ADDR(x)  ((uintptr_t)(x) + 0x110U)

#define HW_QuadSPI_RBCT(x)       (*(__IO hw_quadspi_rbct_t *) HW_QuadSPI_RBCT_ADDR(x))
#define HW_QuadSPI_RBCT_RD(x)    (HW_QuadSPI_RBCT(x).U)
#define HW_QuadSPI_RBCT_WR(x, v) (HW_QuadSPI_RBCT(x).U = (v))
#define HW_QuadSPI_RBCT_SET(x, v) (HW_QuadSPI_RBCT_WR(x, HW_QuadSPI_RBCT_RD(x) |  (v)))
#define HW_QuadSPI_RBCT_CLR(x, v) (HW_QuadSPI_RBCT_WR(x, HW_QuadSPI_RBCT_RD(x) & ~(v)))
#define HW_QuadSPI_RBCT_TOG(x, v) (HW_QuadSPI_RBCT_WR(x, HW_QuadSPI_RBCT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_RBCT bitfields
 */

/*!
 * @name Register QuadSPI_RBCT, field WMRK[4:0] (RW)
 *
 * RX Buffer Watermark: This field determines when the readout action of the RX
 * Buffer is triggered. When the number of valid entries in the RX Buffer is
 * equal to or greater than the number given by (WMRK+1) the QSPI_SR[RXWE] flag is
 * asserted.The value should be entered as the number of 4byte entries minus 1. For
 * example a value of 0x0 would set the watermark to 4bytes, 1 to 8bytes, 2 to
 * 12bytes etc. For details, refer to DMA Usage.
 */
/*@{*/
#define BP_QuadSPI_RBCT_WMRK (0U)          /*!< Bit position for QuadSPI_RBCT_WMRK. */
#define BM_QuadSPI_RBCT_WMRK (0x0000001FU) /*!< Bit mask for QuadSPI_RBCT_WMRK. */
#define BS_QuadSPI_RBCT_WMRK (5U)          /*!< Bit field size in bits for QuadSPI_RBCT_WMRK. */

/*! @brief Read current value of the QuadSPI_RBCT_WMRK field. */
#define BR_QuadSPI_RBCT_WMRK(x) (HW_QuadSPI_RBCT(x).B.WMRK)

/*! @brief Format value for bitfield QuadSPI_RBCT_WMRK. */
#define BF_QuadSPI_RBCT_WMRK(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RBCT_WMRK) & BM_QuadSPI_RBCT_WMRK)

/*! @brief Set the WMRK field to a new value. */
#define BW_QuadSPI_RBCT_WMRK(x, v) (HW_QuadSPI_RBCT_WR(x, (HW_QuadSPI_RBCT_RD(x) & ~BM_QuadSPI_RBCT_WMRK) | BF_QuadSPI_RBCT_WMRK(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RBCT, field RXBRD[8] (RW)
 *
 * RX Buffer Readout: This bit specifies the access scheme for the RX Buffer
 * readout.
 *
 * Values:
 * - 0 - RX Buffer content is read using the AHB Bus registers QSPI_ARDB0 to
 *     QSPI_ARDB31. For details, refer to Exclusive Access to Serial Flash for AHB
 *     Commands.
 * - 1 - RX Buffer content is read using the IP Bus registers QSPI_RBDR0 to
 *     QSPI_RBDR31.
 */
/*@{*/
#define BP_QuadSPI_RBCT_RXBRD (8U)         /*!< Bit position for QuadSPI_RBCT_RXBRD. */
#define BM_QuadSPI_RBCT_RXBRD (0x00000100U) /*!< Bit mask for QuadSPI_RBCT_RXBRD. */
#define BS_QuadSPI_RBCT_RXBRD (1U)         /*!< Bit field size in bits for QuadSPI_RBCT_RXBRD. */

/*! @brief Read current value of the QuadSPI_RBCT_RXBRD field. */
#define BR_QuadSPI_RBCT_RXBRD(x) (HW_QuadSPI_RBCT(x).B.RXBRD)

/*! @brief Format value for bitfield QuadSPI_RBCT_RXBRD. */
#define BF_QuadSPI_RBCT_RXBRD(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RBCT_RXBRD) & BM_QuadSPI_RBCT_RXBRD)

/*! @brief Set the RXBRD field to a new value. */
#define BW_QuadSPI_RBCT_RXBRD(x, v) (HW_QuadSPI_RBCT_WR(x, (HW_QuadSPI_RBCT_RD(x) & ~BM_QuadSPI_RBCT_RXBRD) | BF_QuadSPI_RBCT_RXBRD(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_TBSR - TX Buffer Status Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_TBSR - TX Buffer Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register contains information related to the transmit data buffer.
 */
typedef union _hw_quadspi_tbsr
{
    uint32_t U;
    struct _hw_quadspi_tbsr_bitfields
    {
        uint32_t RESERVED0 : 8;        /*!< [7:0]  */
        uint32_t TRBFL : 5;            /*!< [12:8]  */
        uint32_t RESERVED1 : 3;        /*!< [15:13]  */
        uint32_t TRCTR : 16;           /*!< [31:16]  */
    } B;
} hw_quadspi_tbsr_t;

/*!
 * @name Constants and macros for entire QuadSPI_TBSR register
 */
/*@{*/
#define HW_QuadSPI_TBSR_ADDR(x)  ((uintptr_t)(x) + 0x150U)

#define HW_QuadSPI_TBSR(x)       (*(__I hw_quadspi_tbsr_t *) HW_QuadSPI_TBSR_ADDR(x))
#define HW_QuadSPI_TBSR_RD(x)    (HW_QuadSPI_TBSR(x).U)
/*@}*/

/*
 * Constants & macros for individual QuadSPI_TBSR bitfields
 */

/*!
 * @name Register QuadSPI_TBSR, field TRBFL[12:8] (RO)
 *
 * TX Buffer Fill Level. The TRBFL field contains the number of entries of 4
 * bytes each available in the TX Buffer for the QuadSPI module to transmit to the
 * serial flash device.
 */
/*@{*/
#define BP_QuadSPI_TBSR_TRBFL (8U)         /*!< Bit position for QuadSPI_TBSR_TRBFL. */
#define BM_QuadSPI_TBSR_TRBFL (0x00001F00U) /*!< Bit mask for QuadSPI_TBSR_TRBFL. */
#define BS_QuadSPI_TBSR_TRBFL (5U)         /*!< Bit field size in bits for QuadSPI_TBSR_TRBFL. */

/*! @brief Read current value of the QuadSPI_TBSR_TRBFL field. */
#define BR_QuadSPI_TBSR_TRBFL(x) (HW_QuadSPI_TBSR(x).B.TRBFL)
/*@}*/

/*!
 * @name Register QuadSPI_TBSR, field TRCTR[31:16] (RO)
 *
 * Transmit Counter. This field indicates how many entries of 4 bytes have been
 * written into the TX Buffer by host accesses. It is reset to 0 when a 1 is
 * written into the QSPI_MCR[CLR_TXF] bit. It is incremented on each write access to
 * the QSPI_TBDR register when another word has been pushed onto the TX Buffer.
 * When it is not cleared the TRCTR field wraps around to 0. Refer to TBDRTX
 * Buffer Data Register for details.
 */
/*@{*/
#define BP_QuadSPI_TBSR_TRCTR (16U)        /*!< Bit position for QuadSPI_TBSR_TRCTR. */
#define BM_QuadSPI_TBSR_TRCTR (0xFFFF0000U) /*!< Bit mask for QuadSPI_TBSR_TRCTR. */
#define BS_QuadSPI_TBSR_TRCTR (16U)        /*!< Bit field size in bits for QuadSPI_TBSR_TRCTR. */

/*! @brief Read current value of the QuadSPI_TBSR_TRCTR field. */
#define BR_QuadSPI_TBSR_TRCTR(x) (HW_QuadSPI_TBSR(x).B.TRCTR)
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_TBDR - TX Buffer Data Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_TBDR - TX Buffer Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QSPI_TBDR register provides access to the circular TX Buffer of depth 128
 * bytes. This buffer provides the data written into it as write data for the
 * page programming commands to the serial flash device. Refer to for the byte
 * ordering scheme. A write transaction on the flash with data size of less than 32
 * bits will lead to the removal of four data entry from the TX buffer. The valid
 * bits will be used and the rest of the bits will be discarded. Write:
 * QSPI_SR[TXFULL] = 0 32-bit write access required There is no limitation on Flash
 * programming size. But the data size written to TX Buffer should be 64 Byte aligned.
 * If flash programming size is not 64 bytes aligned, please write redundant data
 * to TX Buffers. The redundant data will be ignored by QuadSPI controller.
 */
typedef union _hw_quadspi_tbdr
{
    uint32_t U;
    struct _hw_quadspi_tbdr_bitfields
    {
        uint32_t TXDATA : 32;          /*!< [31:0]  */
    } B;
} hw_quadspi_tbdr_t;

/*!
 * @name Constants and macros for entire QuadSPI_TBDR register
 */
/*@{*/
#define HW_QuadSPI_TBDR_ADDR(x)  ((uintptr_t)(x) + 0x154U)

#define HW_QuadSPI_TBDR(x)       (*(__IO hw_quadspi_tbdr_t *) HW_QuadSPI_TBDR_ADDR(x))
#define HW_QuadSPI_TBDR_RD(x)    (HW_QuadSPI_TBDR(x).U)
#define HW_QuadSPI_TBDR_WR(x, v) (HW_QuadSPI_TBDR(x).U = (v))
#define HW_QuadSPI_TBDR_SET(x, v) (HW_QuadSPI_TBDR_WR(x, HW_QuadSPI_TBDR_RD(x) |  (v)))
#define HW_QuadSPI_TBDR_CLR(x, v) (HW_QuadSPI_TBDR_WR(x, HW_QuadSPI_TBDR_RD(x) & ~(v)))
#define HW_QuadSPI_TBDR_TOG(x, v) (HW_QuadSPI_TBDR_WR(x, HW_QuadSPI_TBDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_TBDR bitfields
 */

/*!
 * @name Register QuadSPI_TBDR, field TXDATA[31:0] (RW)
 *
 * TX Data On write access the data is written into the next available entry of
 * the TX Buffer and the QPSI_TBSR[TRBFL] field is updated accordingly. On a read
 * access, the last data written to the register is returned.
 */
/*@{*/
#define BP_QuadSPI_TBDR_TXDATA (0U)        /*!< Bit position for QuadSPI_TBDR_TXDATA. */
#define BM_QuadSPI_TBDR_TXDATA (0xFFFFFFFFU) /*!< Bit mask for QuadSPI_TBDR_TXDATA. */
#define BS_QuadSPI_TBDR_TXDATA (32U)       /*!< Bit field size in bits for QuadSPI_TBDR_TXDATA. */

/*! @brief Read current value of the QuadSPI_TBDR_TXDATA field. */
#define BR_QuadSPI_TBDR_TXDATA(x) (HW_QuadSPI_TBDR(x).U)

/*! @brief Format value for bitfield QuadSPI_TBDR_TXDATA. */
#define BF_QuadSPI_TBDR_TXDATA(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_TBDR_TXDATA) & BM_QuadSPI_TBDR_TXDATA)

/*! @brief Set the TXDATA field to a new value. */
#define BW_QuadSPI_TBDR_TXDATA(x, v) (HW_QuadSPI_TBDR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_SR - Status Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_SR - Status Register (RO)
 *
 * Reset value: 0x00003800U
 *
 * The QSPI_SR register provides all available status information about SFM
 * command execution and arbitration, the RX Buffer and TX Buffer and the AHB Buffer.
 */
typedef union _hw_quadspi_sr
{
    uint32_t U;
    struct _hw_quadspi_sr_bitfields
    {
        uint32_t BUSY : 1;             /*!< [0]  */
        uint32_t IP_ACC : 1;           /*!< [1]  */
        uint32_t AHB_ACC : 1;          /*!< [2]  */
        uint32_t RESERVED0 : 2;        /*!< [4:3]  */
        uint32_t AHBGNT : 1;           /*!< [5]  */
        uint32_t AHBTRN : 1;           /*!< [6]  */
        uint32_t AHB0NE : 1;           /*!< [7]  */
        uint32_t AHB1NE : 1;           /*!< [8]  */
        uint32_t AHB2NE : 1;           /*!< [9]  */
        uint32_t AHB3NE : 1;           /*!< [10]  */
        uint32_t AHB0FUL : 1;          /*!< [11]  */
        uint32_t AHB1FUL : 1;          /*!< [12]  */
        uint32_t AHB2FUL : 1;          /*!< [13]  */
        uint32_t AHB3FUL : 1;          /*!< [14]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t RXWE : 1;             /*!< [16]  */
        uint32_t RESERVED2 : 2;        /*!< [18:17]  */
        uint32_t RXFULL : 1;           /*!< [19]  */
        uint32_t RESERVED3 : 3;        /*!< [22:20]  */
        uint32_t RXDMA : 1;            /*!< [23]  */
        uint32_t TXEDA : 1;            /*!< [24] Tx Buffer Enough Data Available */
        uint32_t RESERVED4 : 2;        /*!< [26:25]  */
        uint32_t TXFULL : 1;           /*!< [27]  */
        uint32_t RESERVED5 : 1;        /*!< [28]  */
        uint32_t DLPSMP : 3;           /*!< [31:29]  */
    } B;
} hw_quadspi_sr_t;

/*!
 * @name Constants and macros for entire QuadSPI_SR register
 */
/*@{*/
#define HW_QuadSPI_SR_ADDR(x)    ((uintptr_t)(x) + 0x15CU)

#define HW_QuadSPI_SR(x)         (*(__I hw_quadspi_sr_t *) HW_QuadSPI_SR_ADDR(x))
#define HW_QuadSPI_SR_RD(x)      (HW_QuadSPI_SR(x).U)
/*@}*/

/*
 * Constants & macros for individual QuadSPI_SR bitfields
 */

/*!
 * @name Register QuadSPI_SR, field BUSY[0] (RO)
 *
 * Module Busy: Asserted when module is currently busy handling a transaction to
 * an external flash device.
 */
/*@{*/
#define BP_QuadSPI_SR_BUSY   (0U)          /*!< Bit position for QuadSPI_SR_BUSY. */
#define BM_QuadSPI_SR_BUSY   (0x00000001U) /*!< Bit mask for QuadSPI_SR_BUSY. */
#define BS_QuadSPI_SR_BUSY   (1U)          /*!< Bit field size in bits for QuadSPI_SR_BUSY. */

/*! @brief Read current value of the QuadSPI_SR_BUSY field. */
#define BR_QuadSPI_SR_BUSY(x) (HW_QuadSPI_SR(x).B.BUSY)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field IP_ACC[1] (RO)
 *
 * IP Access: Asserted when transaction currently executed was initiated by IP
 * bus.
 */
/*@{*/
#define BP_QuadSPI_SR_IP_ACC (1U)          /*!< Bit position for QuadSPI_SR_IP_ACC. */
#define BM_QuadSPI_SR_IP_ACC (0x00000002U) /*!< Bit mask for QuadSPI_SR_IP_ACC. */
#define BS_QuadSPI_SR_IP_ACC (1U)          /*!< Bit field size in bits for QuadSPI_SR_IP_ACC. */

/*! @brief Read current value of the QuadSPI_SR_IP_ACC field. */
#define BR_QuadSPI_SR_IP_ACC(x) (HW_QuadSPI_SR(x).B.IP_ACC)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHB_ACC[2] (RO)
 *
 * AHB Access: Asserted when the transaction currently executed was initiated by
 * AHB bus.
 */
/*@{*/
#define BP_QuadSPI_SR_AHB_ACC (2U)         /*!< Bit position for QuadSPI_SR_AHB_ACC. */
#define BM_QuadSPI_SR_AHB_ACC (0x00000004U) /*!< Bit mask for QuadSPI_SR_AHB_ACC. */
#define BS_QuadSPI_SR_AHB_ACC (1U)         /*!< Bit field size in bits for QuadSPI_SR_AHB_ACC. */

/*! @brief Read current value of the QuadSPI_SR_AHB_ACC field. */
#define BR_QuadSPI_SR_AHB_ACC(x) (HW_QuadSPI_SR(x).B.AHB_ACC)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHBGNT[5] (RO)
 *
 * AHB Command priority Granted: Asserted when another module has been granted
 * priority of AHB Commands against IP Commands. For details refer to Command
 * Arbitration.
 */
/*@{*/
#define BP_QuadSPI_SR_AHBGNT (5U)          /*!< Bit position for QuadSPI_SR_AHBGNT. */
#define BM_QuadSPI_SR_AHBGNT (0x00000020U) /*!< Bit mask for QuadSPI_SR_AHBGNT. */
#define BS_QuadSPI_SR_AHBGNT (1U)          /*!< Bit field size in bits for QuadSPI_SR_AHBGNT. */

/*! @brief Read current value of the QuadSPI_SR_AHBGNT field. */
#define BR_QuadSPI_SR_AHBGNT(x) (HW_QuadSPI_SR(x).B.AHBGNT)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHBTRN[6] (RO)
 *
 * AHB Access Transaction pending: Asserted when there is a pending request on
 * the AHB interface. Refer to the AMBA specification for details.
 */
/*@{*/
#define BP_QuadSPI_SR_AHBTRN (6U)          /*!< Bit position for QuadSPI_SR_AHBTRN. */
#define BM_QuadSPI_SR_AHBTRN (0x00000040U) /*!< Bit mask for QuadSPI_SR_AHBTRN. */
#define BS_QuadSPI_SR_AHBTRN (1U)          /*!< Bit field size in bits for QuadSPI_SR_AHBTRN. */

/*! @brief Read current value of the QuadSPI_SR_AHBTRN field. */
#define BR_QuadSPI_SR_AHBTRN(x) (HW_QuadSPI_SR(x).B.AHBTRN)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHB0NE[7] (RO)
 *
 * AHB 0 Buffer Not Empty: Asserted when AHB 0 buffer contains data.
 */
/*@{*/
#define BP_QuadSPI_SR_AHB0NE (7U)          /*!< Bit position for QuadSPI_SR_AHB0NE. */
#define BM_QuadSPI_SR_AHB0NE (0x00000080U) /*!< Bit mask for QuadSPI_SR_AHB0NE. */
#define BS_QuadSPI_SR_AHB0NE (1U)          /*!< Bit field size in bits for QuadSPI_SR_AHB0NE. */

/*! @brief Read current value of the QuadSPI_SR_AHB0NE field. */
#define BR_QuadSPI_SR_AHB0NE(x) (HW_QuadSPI_SR(x).B.AHB0NE)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHB1NE[8] (RO)
 *
 * AHB 1 Buffer Not Empty: Asserted when AHB 1 buffer contains data.
 */
/*@{*/
#define BP_QuadSPI_SR_AHB1NE (8U)          /*!< Bit position for QuadSPI_SR_AHB1NE. */
#define BM_QuadSPI_SR_AHB1NE (0x00000100U) /*!< Bit mask for QuadSPI_SR_AHB1NE. */
#define BS_QuadSPI_SR_AHB1NE (1U)          /*!< Bit field size in bits for QuadSPI_SR_AHB1NE. */

/*! @brief Read current value of the QuadSPI_SR_AHB1NE field. */
#define BR_QuadSPI_SR_AHB1NE(x) (HW_QuadSPI_SR(x).B.AHB1NE)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHB2NE[9] (RO)
 *
 * AHB 2 Buffer Not Empty: Asserted when AHB 2 buffer contains data.
 */
/*@{*/
#define BP_QuadSPI_SR_AHB2NE (9U)          /*!< Bit position for QuadSPI_SR_AHB2NE. */
#define BM_QuadSPI_SR_AHB2NE (0x00000200U) /*!< Bit mask for QuadSPI_SR_AHB2NE. */
#define BS_QuadSPI_SR_AHB2NE (1U)          /*!< Bit field size in bits for QuadSPI_SR_AHB2NE. */

/*! @brief Read current value of the QuadSPI_SR_AHB2NE field. */
#define BR_QuadSPI_SR_AHB2NE(x) (HW_QuadSPI_SR(x).B.AHB2NE)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHB3NE[10] (RO)
 *
 * AHB 3 Buffer Not Empty: Asserted when AHB 3 buffer contains data.
 */
/*@{*/
#define BP_QuadSPI_SR_AHB3NE (10U)         /*!< Bit position for QuadSPI_SR_AHB3NE. */
#define BM_QuadSPI_SR_AHB3NE (0x00000400U) /*!< Bit mask for QuadSPI_SR_AHB3NE. */
#define BS_QuadSPI_SR_AHB3NE (1U)          /*!< Bit field size in bits for QuadSPI_SR_AHB3NE. */

/*! @brief Read current value of the QuadSPI_SR_AHB3NE field. */
#define BR_QuadSPI_SR_AHB3NE(x) (HW_QuadSPI_SR(x).B.AHB3NE)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHB0FUL[11] (RO)
 *
 * AHB 0 Buffer Full: Asserted when AHB 0 buffer is full.
 */
/*@{*/
#define BP_QuadSPI_SR_AHB0FUL (11U)        /*!< Bit position for QuadSPI_SR_AHB0FUL. */
#define BM_QuadSPI_SR_AHB0FUL (0x00000800U) /*!< Bit mask for QuadSPI_SR_AHB0FUL. */
#define BS_QuadSPI_SR_AHB0FUL (1U)         /*!< Bit field size in bits for QuadSPI_SR_AHB0FUL. */

/*! @brief Read current value of the QuadSPI_SR_AHB0FUL field. */
#define BR_QuadSPI_SR_AHB0FUL(x) (HW_QuadSPI_SR(x).B.AHB0FUL)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHB1FUL[12] (RO)
 *
 * AHB 1 Buffer Full: Asserted when AHB 1 buffer is full.
 */
/*@{*/
#define BP_QuadSPI_SR_AHB1FUL (12U)        /*!< Bit position for QuadSPI_SR_AHB1FUL. */
#define BM_QuadSPI_SR_AHB1FUL (0x00001000U) /*!< Bit mask for QuadSPI_SR_AHB1FUL. */
#define BS_QuadSPI_SR_AHB1FUL (1U)         /*!< Bit field size in bits for QuadSPI_SR_AHB1FUL. */

/*! @brief Read current value of the QuadSPI_SR_AHB1FUL field. */
#define BR_QuadSPI_SR_AHB1FUL(x) (HW_QuadSPI_SR(x).B.AHB1FUL)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHB2FUL[13] (RO)
 *
 * AHB 2 Buffer Full: Asserted when AHB 2 buffer is full.
 */
/*@{*/
#define BP_QuadSPI_SR_AHB2FUL (13U)        /*!< Bit position for QuadSPI_SR_AHB2FUL. */
#define BM_QuadSPI_SR_AHB2FUL (0x00002000U) /*!< Bit mask for QuadSPI_SR_AHB2FUL. */
#define BS_QuadSPI_SR_AHB2FUL (1U)         /*!< Bit field size in bits for QuadSPI_SR_AHB2FUL. */

/*! @brief Read current value of the QuadSPI_SR_AHB2FUL field. */
#define BR_QuadSPI_SR_AHB2FUL(x) (HW_QuadSPI_SR(x).B.AHB2FUL)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field AHB3FUL[14] (RO)
 *
 * AHB 3 Buffer Full: Asserted when AHB 3 buffer is full.
 */
/*@{*/
#define BP_QuadSPI_SR_AHB3FUL (14U)        /*!< Bit position for QuadSPI_SR_AHB3FUL. */
#define BM_QuadSPI_SR_AHB3FUL (0x00004000U) /*!< Bit mask for QuadSPI_SR_AHB3FUL. */
#define BS_QuadSPI_SR_AHB3FUL (1U)         /*!< Bit field size in bits for QuadSPI_SR_AHB3FUL. */

/*! @brief Read current value of the QuadSPI_SR_AHB3FUL field. */
#define BR_QuadSPI_SR_AHB3FUL(x) (HW_QuadSPI_SR(x).B.AHB3FUL)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field RXWE[16] (RO)
 *
 * RX Buffer Watermark Exceeded: Asserted when the number of valid entries in
 * the RX Buffer exceeds the number given in the QSPI_RBCT[WMRK] field.
 */
/*@{*/
#define BP_QuadSPI_SR_RXWE   (16U)         /*!< Bit position for QuadSPI_SR_RXWE. */
#define BM_QuadSPI_SR_RXWE   (0x00010000U) /*!< Bit mask for QuadSPI_SR_RXWE. */
#define BS_QuadSPI_SR_RXWE   (1U)          /*!< Bit field size in bits for QuadSPI_SR_RXWE. */

/*! @brief Read current value of the QuadSPI_SR_RXWE field. */
#define BR_QuadSPI_SR_RXWE(x) (HW_QuadSPI_SR(x).B.RXWE)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field RXFULL[19] (RO)
 *
 * RX Buffer Full: Asserted when the RX Buffer is full, i.e. that
 * QSPI_RBSR[RDBFL] field is equal to 32.
 */
/*@{*/
#define BP_QuadSPI_SR_RXFULL (19U)         /*!< Bit position for QuadSPI_SR_RXFULL. */
#define BM_QuadSPI_SR_RXFULL (0x00080000U) /*!< Bit mask for QuadSPI_SR_RXFULL. */
#define BS_QuadSPI_SR_RXFULL (1U)          /*!< Bit field size in bits for QuadSPI_SR_RXFULL. */

/*! @brief Read current value of the QuadSPI_SR_RXFULL field. */
#define BR_QuadSPI_SR_RXFULL(x) (HW_QuadSPI_SR(x).B.RXFULL)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field RXDMA[23] (RO)
 *
 * RX Buffer DMA: Asserted when RX Buffer read out via DMA is active i.e DMA is
 * requested or running.
 */
/*@{*/
#define BP_QuadSPI_SR_RXDMA  (23U)         /*!< Bit position for QuadSPI_SR_RXDMA. */
#define BM_QuadSPI_SR_RXDMA  (0x00800000U) /*!< Bit mask for QuadSPI_SR_RXDMA. */
#define BS_QuadSPI_SR_RXDMA  (1U)          /*!< Bit field size in bits for QuadSPI_SR_RXDMA. */

/*! @brief Read current value of the QuadSPI_SR_RXDMA field. */
#define BR_QuadSPI_SR_RXDMA(x) (HW_QuadSPI_SR(x).B.RXDMA)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field TXEDA[24] (RO)
 *
 * Asserted when TX Buffer contains enough data for any pop operation to take
 * place. There must be atleast 128bit data available in TX FIFO for any pop
 * operation otherwise QSPI_FR[TBUF] will be set.
 */
/*@{*/
#define BP_QuadSPI_SR_TXEDA  (24U)         /*!< Bit position for QuadSPI_SR_TXEDA. */
#define BM_QuadSPI_SR_TXEDA  (0x01000000U) /*!< Bit mask for QuadSPI_SR_TXEDA. */
#define BS_QuadSPI_SR_TXEDA  (1U)          /*!< Bit field size in bits for QuadSPI_SR_TXEDA. */

/*! @brief Read current value of the QuadSPI_SR_TXEDA field. */
#define BR_QuadSPI_SR_TXEDA(x) (HW_QuadSPI_SR(x).B.TXEDA)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field TXFULL[27] (RO)
 *
 * TX Buffer Full: Asserted when no more data can be stored.
 */
/*@{*/
#define BP_QuadSPI_SR_TXFULL (27U)         /*!< Bit position for QuadSPI_SR_TXFULL. */
#define BM_QuadSPI_SR_TXFULL (0x08000000U) /*!< Bit mask for QuadSPI_SR_TXFULL. */
#define BS_QuadSPI_SR_TXFULL (1U)          /*!< Bit field size in bits for QuadSPI_SR_TXFULL. */

/*! @brief Read current value of the QuadSPI_SR_TXFULL field. */
#define BR_QuadSPI_SR_TXFULL(x) (HW_QuadSPI_SR(x).B.TXFULL)
/*@}*/

/*!
 * @name Register QuadSPI_SR, field DLPSMP[31:29] (RO)
 *
 * Data learning is not implemented on this chip. Data learning pattern sampling
 * point: The sampling point found by the controller with the data learning
 * pattern. This is used for DDR only. If the learning fails, this field will return
 * garbage and DLPFF bit will be set.
 */
/*@{*/
#define BP_QuadSPI_SR_DLPSMP (29U)         /*!< Bit position for QuadSPI_SR_DLPSMP. */
#define BM_QuadSPI_SR_DLPSMP (0xE0000000U) /*!< Bit mask for QuadSPI_SR_DLPSMP. */
#define BS_QuadSPI_SR_DLPSMP (3U)          /*!< Bit field size in bits for QuadSPI_SR_DLPSMP. */

/*! @brief Read current value of the QuadSPI_SR_DLPSMP field. */
#define BR_QuadSPI_SR_DLPSMP(x) (HW_QuadSPI_SR(x).B.DLPSMP)
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_FR - Flag Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_FR - Flag Register (RW)
 *
 * Reset value: 0x08000000U
 *
 * The QSPI_FR register provides all available flags about SFM command execution
 * and arbitration which may serve as source for the generation of interrupt
 * service requests. Note that the error flags in this register do not relate
 * directly to the execution of the transaction in the serial flash device itself but
 * only to the behavior and conditions visible in the QuadSPI module.
 * Write:Enabled Mode
 */
typedef union _hw_quadspi_fr
{
    uint32_t U;
    struct _hw_quadspi_fr_bitfields
    {
        uint32_t TFF : 1;              /*!< [0]  */
        uint32_t RESERVED0 : 3;        /*!< [3:1]  */
        uint32_t IPGEF : 1;            /*!< [4]  */
        uint32_t RESERVED1 : 1;        /*!< [5]  */
        uint32_t IPIEF : 1;            /*!< [6]  */
        uint32_t IPAEF : 1;            /*!< [7]  */
        uint32_t RESERVED2 : 3;        /*!< [10:8]  */
        uint32_t IUEF : 1;             /*!< [11]  */
        uint32_t ABOF : 1;             /*!< [12]  */
        uint32_t RESERVED3 : 2;        /*!< [14:13] Reserved */
        uint32_t ABSEF : 1;            /*!< [15]  */
        uint32_t RBDF : 1;             /*!< [16]  */
        uint32_t RBOF : 1;             /*!< [17]  */
        uint32_t RESERVED4 : 5;        /*!< [22:18]  */
        uint32_t ILLINE : 1;           /*!< [23]  */
        uint32_t RESERVED5 : 2;        /*!< [25:24]  */
        uint32_t TBUF : 1;             /*!< [26]  */
        uint32_t TBFF : 1;             /*!< [27]  */
        uint32_t RESERVED6 : 3;        /*!< [30:28]  */
        uint32_t DLPFF : 1;            /*!< [31]  */
    } B;
} hw_quadspi_fr_t;

/*!
 * @name Constants and macros for entire QuadSPI_FR register
 */
/*@{*/
#define HW_QuadSPI_FR_ADDR(x)    ((uintptr_t)(x) + 0x160U)

#define HW_QuadSPI_FR(x)         (*(__IO hw_quadspi_fr_t *) HW_QuadSPI_FR_ADDR(x))
#define HW_QuadSPI_FR_RD(x)      (HW_QuadSPI_FR(x).U)
#define HW_QuadSPI_FR_WR(x, v)   (HW_QuadSPI_FR(x).U = (v))
#define HW_QuadSPI_FR_SET(x, v)  (HW_QuadSPI_FR_WR(x, HW_QuadSPI_FR_RD(x) |  (v)))
#define HW_QuadSPI_FR_CLR(x, v)  (HW_QuadSPI_FR_WR(x, HW_QuadSPI_FR_RD(x) & ~(v)))
#define HW_QuadSPI_FR_TOG(x, v)  (HW_QuadSPI_FR_WR(x, HW_QuadSPI_FR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_FR bitfields
 */

/*!
 * @name Register QuadSPI_FR, field TFF[0] (W1C)
 *
 * IP Command Transaction Finished Flag: Set when the QuadSPI module has
 * finished a running IP Command. If an error occurred the related error flags are
 * valid, at the latest, in the same clock cycle when the TFF flag is asserted.
 */
/*@{*/
#define BP_QuadSPI_FR_TFF    (0U)          /*!< Bit position for QuadSPI_FR_TFF. */
#define BM_QuadSPI_FR_TFF    (0x00000001U) /*!< Bit mask for QuadSPI_FR_TFF. */
#define BS_QuadSPI_FR_TFF    (1U)          /*!< Bit field size in bits for QuadSPI_FR_TFF. */

/*! @brief Read current value of the QuadSPI_FR_TFF field. */
#define BR_QuadSPI_FR_TFF(x) (HW_QuadSPI_FR(x).B.TFF)

/*! @brief Format value for bitfield QuadSPI_FR_TFF. */
#define BF_QuadSPI_FR_TFF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_TFF) & BM_QuadSPI_FR_TFF)

/*! @brief Set the TFF field to a new value. */
#define BW_QuadSPI_FR_TFF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_TFF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field IPGEF[4] (W1C)
 *
 * IP Command Trigger during AHB Grant Error Flag: Set when the following
 * condition occurs: A write access occurs to the QSPI_IPCR[SEQID] field and the
 * QSPI_SR[AHBGNT] bit is set. Any command leading to the assertion of the IPGEF flag
 * is ignored.
 */
/*@{*/
#define BP_QuadSPI_FR_IPGEF  (4U)          /*!< Bit position for QuadSPI_FR_IPGEF. */
#define BM_QuadSPI_FR_IPGEF  (0x00000010U) /*!< Bit mask for QuadSPI_FR_IPGEF. */
#define BS_QuadSPI_FR_IPGEF  (1U)          /*!< Bit field size in bits for QuadSPI_FR_IPGEF. */

/*! @brief Read current value of the QuadSPI_FR_IPGEF field. */
#define BR_QuadSPI_FR_IPGEF(x) (HW_QuadSPI_FR(x).B.IPGEF)

/*! @brief Format value for bitfield QuadSPI_FR_IPGEF. */
#define BF_QuadSPI_FR_IPGEF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_IPGEF) & BM_QuadSPI_FR_IPGEF)

/*! @brief Set the IPGEF field to a new value. */
#define BW_QuadSPI_FR_IPGEF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_IPGEF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field IPIEF[6] (W1C)
 *
 * IP Command Trigger could not be executed Error Flag. Set when the
 * QSPI_SR[IP_ACC] bit is set (i.e. an IP triggered command is currently executing) and any
 * of the following conditions occurs: Write access to the QSPI_IPCR register.
 * Any command leading to the assertion of the IPIEF flag is ignored Write access
 * to the QSPI_SFAR register. Write access to the QSPI_RBCT register.
 */
/*@{*/
#define BP_QuadSPI_FR_IPIEF  (6U)          /*!< Bit position for QuadSPI_FR_IPIEF. */
#define BM_QuadSPI_FR_IPIEF  (0x00000040U) /*!< Bit mask for QuadSPI_FR_IPIEF. */
#define BS_QuadSPI_FR_IPIEF  (1U)          /*!< Bit field size in bits for QuadSPI_FR_IPIEF. */

/*! @brief Read current value of the QuadSPI_FR_IPIEF field. */
#define BR_QuadSPI_FR_IPIEF(x) (HW_QuadSPI_FR(x).B.IPIEF)

/*! @brief Format value for bitfield QuadSPI_FR_IPIEF. */
#define BF_QuadSPI_FR_IPIEF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_IPIEF) & BM_QuadSPI_FR_IPIEF)

/*! @brief Set the IPIEF field to a new value. */
#define BW_QuadSPI_FR_IPIEF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_IPIEF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field IPAEF[7] (W1C)
 *
 * IP Command Trigger during AHB Access Error Flag. Set when the following
 * condition occurs: A write access occurs to the QSPI_IPCR[SEQID] field and the
 * QSPI_SR[AHB_ACC] bit is set. Any command leading to the assertion of the IPAEF flag
 * is ignored.
 */
/*@{*/
#define BP_QuadSPI_FR_IPAEF  (7U)          /*!< Bit position for QuadSPI_FR_IPAEF. */
#define BM_QuadSPI_FR_IPAEF  (0x00000080U) /*!< Bit mask for QuadSPI_FR_IPAEF. */
#define BS_QuadSPI_FR_IPAEF  (1U)          /*!< Bit field size in bits for QuadSPI_FR_IPAEF. */

/*! @brief Read current value of the QuadSPI_FR_IPAEF field. */
#define BR_QuadSPI_FR_IPAEF(x) (HW_QuadSPI_FR(x).B.IPAEF)

/*! @brief Format value for bitfield QuadSPI_FR_IPAEF. */
#define BF_QuadSPI_FR_IPAEF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_IPAEF) & BM_QuadSPI_FR_IPAEF)

/*! @brief Set the IPAEF field to a new value. */
#define BW_QuadSPI_FR_IPAEF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_IPAEF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field IUEF[11] (W1C)
 *
 * IP Command Usage Error Flag: Set when in parallel flash mode the execution of
 * an IP Command is started and the sequence pointed to by the sequence ID
 * contains a WRITE or a WRITE_DDR command. Refer to table for the related commands.
 * Communication with the serial flash device is terminated before the execution
 * of WRITE/WRITE_DDR command by the QuadSPI module.
 */
/*@{*/
#define BP_QuadSPI_FR_IUEF   (11U)         /*!< Bit position for QuadSPI_FR_IUEF. */
#define BM_QuadSPI_FR_IUEF   (0x00000800U) /*!< Bit mask for QuadSPI_FR_IUEF. */
#define BS_QuadSPI_FR_IUEF   (1U)          /*!< Bit field size in bits for QuadSPI_FR_IUEF. */

/*! @brief Read current value of the QuadSPI_FR_IUEF field. */
#define BR_QuadSPI_FR_IUEF(x) (HW_QuadSPI_FR(x).B.IUEF)

/*! @brief Format value for bitfield QuadSPI_FR_IUEF. */
#define BF_QuadSPI_FR_IUEF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_IUEF) & BM_QuadSPI_FR_IUEF)

/*! @brief Set the IUEF field to a new value. */
#define BW_QuadSPI_FR_IUEF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_IUEF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field ABOF[12] (W1C)
 *
 * AHB Buffer Overflow Flag: Set when the size of the AHB access exceeds the
 * size of the AHB buffer. This condition can occur only if the QSPI_BUFxCR[ADATSZ]
 * field is programmed incorrectly. The AHB Command leading to this condition is
 * continued until the number of entries according to the QSPI_BUFxCR[ADATSZ]
 * field has been read from the serial flash device. The content of the AHB Buffer
 * is not changed.
 */
/*@{*/
#define BP_QuadSPI_FR_ABOF   (12U)         /*!< Bit position for QuadSPI_FR_ABOF. */
#define BM_QuadSPI_FR_ABOF   (0x00001000U) /*!< Bit mask for QuadSPI_FR_ABOF. */
#define BS_QuadSPI_FR_ABOF   (1U)          /*!< Bit field size in bits for QuadSPI_FR_ABOF. */

/*! @brief Read current value of the QuadSPI_FR_ABOF field. */
#define BR_QuadSPI_FR_ABOF(x) (HW_QuadSPI_FR(x).B.ABOF)

/*! @brief Format value for bitfield QuadSPI_FR_ABOF. */
#define BF_QuadSPI_FR_ABOF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_ABOF) & BM_QuadSPI_FR_ABOF)

/*! @brief Set the ABOF field to a new value. */
#define BW_QuadSPI_FR_ABOF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_ABOF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field ABSEF[15] (W1C)
 *
 * AHB Sequence Error Flag: Set when the execution of an AHB Command is started
 * with an WRITE or WRITE_DDR Command in the sequence pointed to by the
 * QSPI_BUFxCR QSPI_BUFxCR implies anyone of
 * QSPI_BUF0CR/QSPI_BUF1CR/QSPI_BUF2CR/QSPI_BUF3CR register Communication with the serial flash device is terminated before
 * the execution of WRITE/WRITE_DDR command by the QuadSPI module. The AHB bus
 * request which triggered this command is answered with an ERROR response.
 */
/*@{*/
#define BP_QuadSPI_FR_ABSEF  (15U)         /*!< Bit position for QuadSPI_FR_ABSEF. */
#define BM_QuadSPI_FR_ABSEF  (0x00008000U) /*!< Bit mask for QuadSPI_FR_ABSEF. */
#define BS_QuadSPI_FR_ABSEF  (1U)          /*!< Bit field size in bits for QuadSPI_FR_ABSEF. */

/*! @brief Read current value of the QuadSPI_FR_ABSEF field. */
#define BR_QuadSPI_FR_ABSEF(x) (HW_QuadSPI_FR(x).B.ABSEF)

/*! @brief Format value for bitfield QuadSPI_FR_ABSEF. */
#define BF_QuadSPI_FR_ABSEF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_ABSEF) & BM_QuadSPI_FR_ABSEF)

/*! @brief Set the ABSEF field to a new value. */
#define BW_QuadSPI_FR_ABSEF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_ABSEF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field RBDF[16] (W1C)
 *
 * RX Buffer Drain Flag: Will be set if the QuadSPI_SR[RXWE] status bit is
 * asserted. Writing 1 into this bit triggers one of the following actions: If the RX
 * Buffer has up to QuadSPI_RBCT[WMRK] valid entries then the flag is cleared. If
 * the RX Buffer has more than QuadSPI_RBCT[WMRK] valid entries and the
 * QuadSPI_RSER[RBDDE] bit is not set (flag driven mode) a RX Buffer POP event is
 * triggered. The flag remains set if the RX Buffer contains more than
 * QuadSPI_RBCT[WMRK] valid entries after the RX Buffer POP event is finished. The flag is cleared
 * if the RX Buffer contains less than or equal to QuadSPI_RBCT[WMRK] valid
 * entries after the RX Buffer POP event is finished. Refer to "Receive Buffer Drain
 * Interrupt or DMA Request" section in Normal Mode Interrupt and DMA Requests,
 * for details.
 */
/*@{*/
#define BP_QuadSPI_FR_RBDF   (16U)         /*!< Bit position for QuadSPI_FR_RBDF. */
#define BM_QuadSPI_FR_RBDF   (0x00010000U) /*!< Bit mask for QuadSPI_FR_RBDF. */
#define BS_QuadSPI_FR_RBDF   (1U)          /*!< Bit field size in bits for QuadSPI_FR_RBDF. */

/*! @brief Read current value of the QuadSPI_FR_RBDF field. */
#define BR_QuadSPI_FR_RBDF(x) (HW_QuadSPI_FR(x).B.RBDF)

/*! @brief Format value for bitfield QuadSPI_FR_RBDF. */
#define BF_QuadSPI_FR_RBDF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_RBDF) & BM_QuadSPI_FR_RBDF)

/*! @brief Set the RBDF field to a new value. */
#define BW_QuadSPI_FR_RBDF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_RBDF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field RBOF[17] (W1C)
 *
 * RX Buffer Overflow Flag: Set when not all the data read from the serial flash
 * device could be pushed into the RX Buffer. The IP Command leading to this
 * condition is continued until the number of bytes according to the
 * QSPI_IPCR[IDATSZ] field has been read from the serial flash device. The content of the RX
 * Buffer is not changed.
 */
/*@{*/
#define BP_QuadSPI_FR_RBOF   (17U)         /*!< Bit position for QuadSPI_FR_RBOF. */
#define BM_QuadSPI_FR_RBOF   (0x00020000U) /*!< Bit mask for QuadSPI_FR_RBOF. */
#define BS_QuadSPI_FR_RBOF   (1U)          /*!< Bit field size in bits for QuadSPI_FR_RBOF. */

/*! @brief Read current value of the QuadSPI_FR_RBOF field. */
#define BR_QuadSPI_FR_RBOF(x) (HW_QuadSPI_FR(x).B.RBOF)

/*! @brief Format value for bitfield QuadSPI_FR_RBOF. */
#define BF_QuadSPI_FR_RBOF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_RBOF) & BM_QuadSPI_FR_RBOF)

/*! @brief Set the RBOF field to a new value. */
#define BW_QuadSPI_FR_RBOF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_RBOF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field ILLINE[23] (W1C)
 *
 * Illegal Instruction Error Flag: Set when an illegal instruction is
 * encountered by the controller in any of the sequences. Refer to for a list of legal
 * instructions.
 */
/*@{*/
#define BP_QuadSPI_FR_ILLINE (23U)         /*!< Bit position for QuadSPI_FR_ILLINE. */
#define BM_QuadSPI_FR_ILLINE (0x00800000U) /*!< Bit mask for QuadSPI_FR_ILLINE. */
#define BS_QuadSPI_FR_ILLINE (1U)          /*!< Bit field size in bits for QuadSPI_FR_ILLINE. */

/*! @brief Read current value of the QuadSPI_FR_ILLINE field. */
#define BR_QuadSPI_FR_ILLINE(x) (HW_QuadSPI_FR(x).B.ILLINE)

/*! @brief Format value for bitfield QuadSPI_FR_ILLINE. */
#define BF_QuadSPI_FR_ILLINE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_ILLINE) & BM_QuadSPI_FR_ILLINE)

/*! @brief Set the ILLINE field to a new value. */
#define BW_QuadSPI_FR_ILLINE(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_ILLINE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field TBUF[26] (W1C)
 *
 * TX Buffer Underrun Flag: Set when the module tried to pull data although TX
 * Buffer was emptyor the buffer contains less than 128bits of data. The
 * application must ensure that the buffer never goes empty during a transaction expect
 * for the last data fetch. The IP Command leading to the TX Buffer underrun is
 * continued (data sent to the serial flash device is all F in case of valid tx
 * underrun. The application must clear the TX Buffer in response to this event by
 * writing a 1 into the QSPI_MCR[CLR_TXF] bit.
 */
/*@{*/
#define BP_QuadSPI_FR_TBUF   (26U)         /*!< Bit position for QuadSPI_FR_TBUF. */
#define BM_QuadSPI_FR_TBUF   (0x04000000U) /*!< Bit mask for QuadSPI_FR_TBUF. */
#define BS_QuadSPI_FR_TBUF   (1U)          /*!< Bit field size in bits for QuadSPI_FR_TBUF. */

/*! @brief Read current value of the QuadSPI_FR_TBUF field. */
#define BR_QuadSPI_FR_TBUF(x) (HW_QuadSPI_FR(x).B.TBUF)

/*! @brief Format value for bitfield QuadSPI_FR_TBUF. */
#define BF_QuadSPI_FR_TBUF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_TBUF) & BM_QuadSPI_FR_TBUF)

/*! @brief Set the TBUF field to a new value. */
#define BW_QuadSPI_FR_TBUF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_TBUF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field TBFF[27] (W1C)
 *
 * TX Buffer Fill Flag: Before writing to the TX buffer, this bit should be
 * cleared. Then this bit has to be read back. If the bit is set, the TX Buffer can
 * take more data. If the bit remains cleared, the TX buffer is full. Refer to Tx
 * Buffer Operation for details.
 */
/*@{*/
#define BP_QuadSPI_FR_TBFF   (27U)         /*!< Bit position for QuadSPI_FR_TBFF. */
#define BM_QuadSPI_FR_TBFF   (0x08000000U) /*!< Bit mask for QuadSPI_FR_TBFF. */
#define BS_QuadSPI_FR_TBFF   (1U)          /*!< Bit field size in bits for QuadSPI_FR_TBFF. */

/*! @brief Read current value of the QuadSPI_FR_TBFF field. */
#define BR_QuadSPI_FR_TBFF(x) (HW_QuadSPI_FR(x).B.TBFF)

/*! @brief Format value for bitfield QuadSPI_FR_TBFF. */
#define BF_QuadSPI_FR_TBFF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_TBFF) & BM_QuadSPI_FR_TBFF)

/*! @brief Set the TBFF field to a new value. */
#define BW_QuadSPI_FR_TBFF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_TBFF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_DLPFF)) | BF_QuadSPI_FR_TBFF(v)))
/*@}*/

/*!
 * @name Register QuadSPI_FR, field DLPFF[31] (W1C)
 *
 * Data learning is not implemented on this chip. Data Learning Pattern Failure
 * Flag: Set when DATA_LEARN instruction was encountered in a sequence but no
 * sampling point was found for the data learning pattern The controller
 * automatically starts sampling using the value in QSPI_SMPR[DDRSMP].
 */
/*@{*/
#define BP_QuadSPI_FR_DLPFF  (31U)         /*!< Bit position for QuadSPI_FR_DLPFF. */
#define BM_QuadSPI_FR_DLPFF  (0x80000000U) /*!< Bit mask for QuadSPI_FR_DLPFF. */
#define BS_QuadSPI_FR_DLPFF  (1U)          /*!< Bit field size in bits for QuadSPI_FR_DLPFF. */

/*! @brief Read current value of the QuadSPI_FR_DLPFF field. */
#define BR_QuadSPI_FR_DLPFF(x) (HW_QuadSPI_FR(x).B.DLPFF)

/*! @brief Format value for bitfield QuadSPI_FR_DLPFF. */
#define BF_QuadSPI_FR_DLPFF(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_FR_DLPFF) & BM_QuadSPI_FR_DLPFF)

/*! @brief Set the DLPFF field to a new value. */
#define BW_QuadSPI_FR_DLPFF(x, v) (HW_QuadSPI_FR_WR(x, (HW_QuadSPI_FR_RD(x) & ~(BM_QuadSPI_FR_DLPFF | BM_QuadSPI_FR_TFF | BM_QuadSPI_FR_IPGEF | BM_QuadSPI_FR_IPIEF | BM_QuadSPI_FR_IPAEF | BM_QuadSPI_FR_IUEF | BM_QuadSPI_FR_ABOF | BM_QuadSPI_FR_ABSEF | BM_QuadSPI_FR_RBDF | BM_QuadSPI_FR_RBOF | BM_QuadSPI_FR_ILLINE | BM_QuadSPI_FR_TBUF | BM_QuadSPI_FR_TBFF)) | BF_QuadSPI_FR_DLPFF(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_RSER - Interrupt and DMA Request Select and Enable Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_RSER - Interrupt and DMA Request Select and Enable Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QuadSPI_RSER register provides enables and selectors for the interrupts
 * in the QuadSPI module. Each flag of the QuadSPI_FR register enabled as source
 * for an interrupt prevents the QuadSPI module from entering Stop Mode or Module
 * Disable Mode when this flag is set.> Write:Anytime
 */
typedef union _hw_quadspi_rser
{
    uint32_t U;
    struct _hw_quadspi_rser_bitfields
    {
        uint32_t TFIE : 1;             /*!< [0]  */
        uint32_t RESERVED0 : 3;        /*!< [3:1]  */
        uint32_t IPGEIE : 1;           /*!< [4]  */
        uint32_t RESERVED1 : 1;        /*!< [5]  */
        uint32_t IPIEIE : 1;           /*!< [6]  */
        uint32_t IPAEIE : 1;           /*!< [7]  */
        uint32_t RESERVED2 : 3;        /*!< [10:8]  */
        uint32_t IUEIE : 1;            /*!< [11]  */
        uint32_t ABOIE : 1;            /*!< [12]  */
        uint32_t RESERVED3 : 2;        /*!< [14:13] Reserved */
        uint32_t ABSEIE : 1;           /*!< [15]  */
        uint32_t RBDIE : 1;            /*!< [16]  */
        uint32_t RBOIE : 1;            /*!< [17]  */
        uint32_t RESERVED4 : 3;        /*!< [20:18]  */
        uint32_t RBDDE : 1;            /*!< [21]  */
        uint32_t RESERVED5 : 1;        /*!< [22]  */
        uint32_t ILLINIE : 1;          /*!< [23]  */
        uint32_t RESERVED6 : 2;        /*!< [25:24]  */
        uint32_t TBUIE : 1;            /*!< [26]  */
        uint32_t TBFIE : 1;            /*!< [27]  */
        uint32_t RESERVED7 : 3;        /*!< [30:28]  */
        uint32_t DLPFIE : 1;           /*!< [31]  */
    } B;
} hw_quadspi_rser_t;

/*!
 * @name Constants and macros for entire QuadSPI_RSER register
 */
/*@{*/
#define HW_QuadSPI_RSER_ADDR(x)  ((uintptr_t)(x) + 0x164U)

#define HW_QuadSPI_RSER(x)       (*(__IO hw_quadspi_rser_t *) HW_QuadSPI_RSER_ADDR(x))
#define HW_QuadSPI_RSER_RD(x)    (HW_QuadSPI_RSER(x).U)
#define HW_QuadSPI_RSER_WR(x, v) (HW_QuadSPI_RSER(x).U = (v))
#define HW_QuadSPI_RSER_SET(x, v) (HW_QuadSPI_RSER_WR(x, HW_QuadSPI_RSER_RD(x) |  (v)))
#define HW_QuadSPI_RSER_CLR(x, v) (HW_QuadSPI_RSER_WR(x, HW_QuadSPI_RSER_RD(x) & ~(v)))
#define HW_QuadSPI_RSER_TOG(x, v) (HW_QuadSPI_RSER_WR(x, HW_QuadSPI_RSER_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_RSER bitfields
 */

/*!
 * @name Register QuadSPI_RSER, field TFIE[0] (RW)
 *
 * Transaction Finished Interrupt Enable
 *
 * Values:
 * - 0 - No TFF interrupt will be generated
 * - 1 - TFF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_TFIE (0U)          /*!< Bit position for QuadSPI_RSER_TFIE. */
#define BM_QuadSPI_RSER_TFIE (0x00000001U) /*!< Bit mask for QuadSPI_RSER_TFIE. */
#define BS_QuadSPI_RSER_TFIE (1U)          /*!< Bit field size in bits for QuadSPI_RSER_TFIE. */

/*! @brief Read current value of the QuadSPI_RSER_TFIE field. */
#define BR_QuadSPI_RSER_TFIE(x) (HW_QuadSPI_RSER(x).B.TFIE)

/*! @brief Format value for bitfield QuadSPI_RSER_TFIE. */
#define BF_QuadSPI_RSER_TFIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_TFIE) & BM_QuadSPI_RSER_TFIE)

/*! @brief Set the TFIE field to a new value. */
#define BW_QuadSPI_RSER_TFIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_TFIE) | BF_QuadSPI_RSER_TFIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field IPGEIE[4] (RW)
 *
 * IP Command Trigger during AHB Grant Error Interrupt Enable
 *
 * Values:
 * - 0 - No IPGEF interrupt will be generated
 * - 1 - IPGEF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_IPGEIE (4U)        /*!< Bit position for QuadSPI_RSER_IPGEIE. */
#define BM_QuadSPI_RSER_IPGEIE (0x00000010U) /*!< Bit mask for QuadSPI_RSER_IPGEIE. */
#define BS_QuadSPI_RSER_IPGEIE (1U)        /*!< Bit field size in bits for QuadSPI_RSER_IPGEIE. */

/*! @brief Read current value of the QuadSPI_RSER_IPGEIE field. */
#define BR_QuadSPI_RSER_IPGEIE(x) (HW_QuadSPI_RSER(x).B.IPGEIE)

/*! @brief Format value for bitfield QuadSPI_RSER_IPGEIE. */
#define BF_QuadSPI_RSER_IPGEIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_IPGEIE) & BM_QuadSPI_RSER_IPGEIE)

/*! @brief Set the IPGEIE field to a new value. */
#define BW_QuadSPI_RSER_IPGEIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_IPGEIE) | BF_QuadSPI_RSER_IPGEIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field IPIEIE[6] (RW)
 *
 * IP Command Trigger during IP Access Error Interrupt Enable
 *
 * Values:
 * - 0 - No IPIEF interrupt will be generated
 * - 0 - IPIEF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_IPIEIE (6U)        /*!< Bit position for QuadSPI_RSER_IPIEIE. */
#define BM_QuadSPI_RSER_IPIEIE (0x00000040U) /*!< Bit mask for QuadSPI_RSER_IPIEIE. */
#define BS_QuadSPI_RSER_IPIEIE (1U)        /*!< Bit field size in bits for QuadSPI_RSER_IPIEIE. */

/*! @brief Read current value of the QuadSPI_RSER_IPIEIE field. */
#define BR_QuadSPI_RSER_IPIEIE(x) (HW_QuadSPI_RSER(x).B.IPIEIE)

/*! @brief Format value for bitfield QuadSPI_RSER_IPIEIE. */
#define BF_QuadSPI_RSER_IPIEIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_IPIEIE) & BM_QuadSPI_RSER_IPIEIE)

/*! @brief Set the IPIEIE field to a new value. */
#define BW_QuadSPI_RSER_IPIEIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_IPIEIE) | BF_QuadSPI_RSER_IPIEIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field IPAEIE[7] (RW)
 *
 * IP Command Trigger during AHB Access Error Interrupt Enable
 *
 * Values:
 * - 0 - No IPAEF interrupt will be generated
 * - 1 - IPAEF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_IPAEIE (7U)        /*!< Bit position for QuadSPI_RSER_IPAEIE. */
#define BM_QuadSPI_RSER_IPAEIE (0x00000080U) /*!< Bit mask for QuadSPI_RSER_IPAEIE. */
#define BS_QuadSPI_RSER_IPAEIE (1U)        /*!< Bit field size in bits for QuadSPI_RSER_IPAEIE. */

/*! @brief Read current value of the QuadSPI_RSER_IPAEIE field. */
#define BR_QuadSPI_RSER_IPAEIE(x) (HW_QuadSPI_RSER(x).B.IPAEIE)

/*! @brief Format value for bitfield QuadSPI_RSER_IPAEIE. */
#define BF_QuadSPI_RSER_IPAEIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_IPAEIE) & BM_QuadSPI_RSER_IPAEIE)

/*! @brief Set the IPAEIE field to a new value. */
#define BW_QuadSPI_RSER_IPAEIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_IPAEIE) | BF_QuadSPI_RSER_IPAEIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field IUEIE[11] (RW)
 *
 * IP Command Usage Error Interrupt Enable
 *
 * Values:
 * - 0 - No IUEF interrupt will be generated
 * - 1 - IUEF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_IUEIE (11U)        /*!< Bit position for QuadSPI_RSER_IUEIE. */
#define BM_QuadSPI_RSER_IUEIE (0x00000800U) /*!< Bit mask for QuadSPI_RSER_IUEIE. */
#define BS_QuadSPI_RSER_IUEIE (1U)         /*!< Bit field size in bits for QuadSPI_RSER_IUEIE. */

/*! @brief Read current value of the QuadSPI_RSER_IUEIE field. */
#define BR_QuadSPI_RSER_IUEIE(x) (HW_QuadSPI_RSER(x).B.IUEIE)

/*! @brief Format value for bitfield QuadSPI_RSER_IUEIE. */
#define BF_QuadSPI_RSER_IUEIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_IUEIE) & BM_QuadSPI_RSER_IUEIE)

/*! @brief Set the IUEIE field to a new value. */
#define BW_QuadSPI_RSER_IUEIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_IUEIE) | BF_QuadSPI_RSER_IUEIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field ABOIE[12] (RW)
 *
 * AHB Buffer Overflow Interrupt Enable
 *
 * Values:
 * - 0 - No ABOF interrupt will be generated
 * - 1 - ABOF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_ABOIE (12U)        /*!< Bit position for QuadSPI_RSER_ABOIE. */
#define BM_QuadSPI_RSER_ABOIE (0x00001000U) /*!< Bit mask for QuadSPI_RSER_ABOIE. */
#define BS_QuadSPI_RSER_ABOIE (1U)         /*!< Bit field size in bits for QuadSPI_RSER_ABOIE. */

/*! @brief Read current value of the QuadSPI_RSER_ABOIE field. */
#define BR_QuadSPI_RSER_ABOIE(x) (HW_QuadSPI_RSER(x).B.ABOIE)

/*! @brief Format value for bitfield QuadSPI_RSER_ABOIE. */
#define BF_QuadSPI_RSER_ABOIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_ABOIE) & BM_QuadSPI_RSER_ABOIE)

/*! @brief Set the ABOIE field to a new value. */
#define BW_QuadSPI_RSER_ABOIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_ABOIE) | BF_QuadSPI_RSER_ABOIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field ABSEIE[15] (RW)
 *
 * AHB Sequence Error Interrupt Enable: Triggered by ABSEF flags of QSPI_FR
 *
 * Values:
 * - 0 - No ABSEF interrupt will be generated
 * - 1 - ABSEF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_ABSEIE (15U)       /*!< Bit position for QuadSPI_RSER_ABSEIE. */
#define BM_QuadSPI_RSER_ABSEIE (0x00008000U) /*!< Bit mask for QuadSPI_RSER_ABSEIE. */
#define BS_QuadSPI_RSER_ABSEIE (1U)        /*!< Bit field size in bits for QuadSPI_RSER_ABSEIE. */

/*! @brief Read current value of the QuadSPI_RSER_ABSEIE field. */
#define BR_QuadSPI_RSER_ABSEIE(x) (HW_QuadSPI_RSER(x).B.ABSEIE)

/*! @brief Format value for bitfield QuadSPI_RSER_ABSEIE. */
#define BF_QuadSPI_RSER_ABSEIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_ABSEIE) & BM_QuadSPI_RSER_ABSEIE)

/*! @brief Set the ABSEIE field to a new value. */
#define BW_QuadSPI_RSER_ABSEIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_ABSEIE) | BF_QuadSPI_RSER_ABSEIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field RBDIE[16] (RW)
 *
 * RX Buffer Drain Interrupt Enable: Enables generation of IRQ requests for RX
 * Buffer Drain. When this bit is set the interrupt is asserted as long as the
 * QuadSPI_SR[RBDF] flag is set.
 *
 * Values:
 * - 0 - No RBDF interrupt will be generated
 * - 1 - RBDF Interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_RBDIE (16U)        /*!< Bit position for QuadSPI_RSER_RBDIE. */
#define BM_QuadSPI_RSER_RBDIE (0x00010000U) /*!< Bit mask for QuadSPI_RSER_RBDIE. */
#define BS_QuadSPI_RSER_RBDIE (1U)         /*!< Bit field size in bits for QuadSPI_RSER_RBDIE. */

/*! @brief Read current value of the QuadSPI_RSER_RBDIE field. */
#define BR_QuadSPI_RSER_RBDIE(x) (HW_QuadSPI_RSER(x).B.RBDIE)

/*! @brief Format value for bitfield QuadSPI_RSER_RBDIE. */
#define BF_QuadSPI_RSER_RBDIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_RBDIE) & BM_QuadSPI_RSER_RBDIE)

/*! @brief Set the RBDIE field to a new value. */
#define BW_QuadSPI_RSER_RBDIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_RBDIE) | BF_QuadSPI_RSER_RBDIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field RBOIE[17] (RW)
 *
 * RX Buffer Overflow Interrupt Enable
 *
 * Values:
 * - 0 - No RBOF interrupt will be generated
 * - 1 - RBOF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_RBOIE (17U)        /*!< Bit position for QuadSPI_RSER_RBOIE. */
#define BM_QuadSPI_RSER_RBOIE (0x00020000U) /*!< Bit mask for QuadSPI_RSER_RBOIE. */
#define BS_QuadSPI_RSER_RBOIE (1U)         /*!< Bit field size in bits for QuadSPI_RSER_RBOIE. */

/*! @brief Read current value of the QuadSPI_RSER_RBOIE field. */
#define BR_QuadSPI_RSER_RBOIE(x) (HW_QuadSPI_RSER(x).B.RBOIE)

/*! @brief Format value for bitfield QuadSPI_RSER_RBOIE. */
#define BF_QuadSPI_RSER_RBOIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_RBOIE) & BM_QuadSPI_RSER_RBOIE)

/*! @brief Set the RBOIE field to a new value. */
#define BW_QuadSPI_RSER_RBOIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_RBOIE) | BF_QuadSPI_RSER_RBOIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field RBDDE[21] (RW)
 *
 * RX Buffer Drain DMA Enable: Enables generation of DMA requests for RX Buffer
 * Drain. When this bit is set DMA requests are generated as long as the
 * QSPI_SR[RXWE] status bit is set.
 *
 * Values:
 * - 0 - No DMA request will be generated
 * - 1 - DMA request will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_RBDDE (21U)        /*!< Bit position for QuadSPI_RSER_RBDDE. */
#define BM_QuadSPI_RSER_RBDDE (0x00200000U) /*!< Bit mask for QuadSPI_RSER_RBDDE. */
#define BS_QuadSPI_RSER_RBDDE (1U)         /*!< Bit field size in bits for QuadSPI_RSER_RBDDE. */

/*! @brief Read current value of the QuadSPI_RSER_RBDDE field. */
#define BR_QuadSPI_RSER_RBDDE(x) (HW_QuadSPI_RSER(x).B.RBDDE)

/*! @brief Format value for bitfield QuadSPI_RSER_RBDDE. */
#define BF_QuadSPI_RSER_RBDDE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_RBDDE) & BM_QuadSPI_RSER_RBDDE)

/*! @brief Set the RBDDE field to a new value. */
#define BW_QuadSPI_RSER_RBDDE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_RBDDE) | BF_QuadSPI_RSER_RBDDE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field ILLINIE[23] (RW)
 *
 * Illegal Instruction Error Interrupt Enable. Triggered by ILLINE flag in
 * QSPI_FR
 *
 * Values:
 * - 0 - No ILLINE interrupt will be generated
 * - 1 - ILLINE interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_ILLINIE (23U)      /*!< Bit position for QuadSPI_RSER_ILLINIE. */
#define BM_QuadSPI_RSER_ILLINIE (0x00800000U) /*!< Bit mask for QuadSPI_RSER_ILLINIE. */
#define BS_QuadSPI_RSER_ILLINIE (1U)       /*!< Bit field size in bits for QuadSPI_RSER_ILLINIE. */

/*! @brief Read current value of the QuadSPI_RSER_ILLINIE field. */
#define BR_QuadSPI_RSER_ILLINIE(x) (HW_QuadSPI_RSER(x).B.ILLINIE)

/*! @brief Format value for bitfield QuadSPI_RSER_ILLINIE. */
#define BF_QuadSPI_RSER_ILLINIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_ILLINIE) & BM_QuadSPI_RSER_ILLINIE)

/*! @brief Set the ILLINIE field to a new value. */
#define BW_QuadSPI_RSER_ILLINIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_ILLINIE) | BF_QuadSPI_RSER_ILLINIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field TBUIE[26] (RW)
 *
 * TX Buffer Underrun Interrupt Enable
 *
 * Values:
 * - 0 - No TBUF interrupt will be generated
 * - 1 - TBUF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_TBUIE (26U)        /*!< Bit position for QuadSPI_RSER_TBUIE. */
#define BM_QuadSPI_RSER_TBUIE (0x04000000U) /*!< Bit mask for QuadSPI_RSER_TBUIE. */
#define BS_QuadSPI_RSER_TBUIE (1U)         /*!< Bit field size in bits for QuadSPI_RSER_TBUIE. */

/*! @brief Read current value of the QuadSPI_RSER_TBUIE field. */
#define BR_QuadSPI_RSER_TBUIE(x) (HW_QuadSPI_RSER(x).B.TBUIE)

/*! @brief Format value for bitfield QuadSPI_RSER_TBUIE. */
#define BF_QuadSPI_RSER_TBUIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_TBUIE) & BM_QuadSPI_RSER_TBUIE)

/*! @brief Set the TBUIE field to a new value. */
#define BW_QuadSPI_RSER_TBUIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_TBUIE) | BF_QuadSPI_RSER_TBUIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field TBFIE[27] (RW)
 *
 * TX Buffer Fill Interrupt Enable
 *
 * Values:
 * - 0 - No TBFF interrupt will be generated
 * - 1 - TBFF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_TBFIE (27U)        /*!< Bit position for QuadSPI_RSER_TBFIE. */
#define BM_QuadSPI_RSER_TBFIE (0x08000000U) /*!< Bit mask for QuadSPI_RSER_TBFIE. */
#define BS_QuadSPI_RSER_TBFIE (1U)         /*!< Bit field size in bits for QuadSPI_RSER_TBFIE. */

/*! @brief Read current value of the QuadSPI_RSER_TBFIE field. */
#define BR_QuadSPI_RSER_TBFIE(x) (HW_QuadSPI_RSER(x).B.TBFIE)

/*! @brief Format value for bitfield QuadSPI_RSER_TBFIE. */
#define BF_QuadSPI_RSER_TBFIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_TBFIE) & BM_QuadSPI_RSER_TBFIE)

/*! @brief Set the TBFIE field to a new value. */
#define BW_QuadSPI_RSER_TBFIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_TBFIE) | BF_QuadSPI_RSER_TBFIE(v)))
/*@}*/

/*!
 * @name Register QuadSPI_RSER, field DLPFIE[31] (RW)
 *
 * Data learning is not implemented on this chip. Data Learning Pattern Failure
 * Interrupt enable . Triggered by DLPFF flag in QSPI_FR register
 *
 * Values:
 * - 0 - No DLPFF interrupt will be generated
 * - 1 - DLPFF interrupt will be generated
 */
/*@{*/
#define BP_QuadSPI_RSER_DLPFIE (31U)       /*!< Bit position for QuadSPI_RSER_DLPFIE. */
#define BM_QuadSPI_RSER_DLPFIE (0x80000000U) /*!< Bit mask for QuadSPI_RSER_DLPFIE. */
#define BS_QuadSPI_RSER_DLPFIE (1U)        /*!< Bit field size in bits for QuadSPI_RSER_DLPFIE. */

/*! @brief Read current value of the QuadSPI_RSER_DLPFIE field. */
#define BR_QuadSPI_RSER_DLPFIE(x) (HW_QuadSPI_RSER(x).B.DLPFIE)

/*! @brief Format value for bitfield QuadSPI_RSER_DLPFIE. */
#define BF_QuadSPI_RSER_DLPFIE(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RSER_DLPFIE) & BM_QuadSPI_RSER_DLPFIE)

/*! @brief Set the DLPFIE field to a new value. */
#define BW_QuadSPI_RSER_DLPFIE(x, v) (HW_QuadSPI_RSER_WR(x, (HW_QuadSPI_RSER_RD(x) & ~BM_QuadSPI_RSER_DLPFIE) | BF_QuadSPI_RSER_DLPFIE(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_SPNDST - Sequence Suspend Status Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_SPNDST - Sequence Suspend Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The sequence suspend status register provides information specific to any
 * suspended sequence. An AHB sequence may be suspended when a high priority AHB
 * master makes an access before the AHB sequence completes the data transfer
 * requested.
 */
typedef union _hw_quadspi_spndst
{
    uint32_t U;
    struct _hw_quadspi_spndst_bitfields
    {
        uint32_t SUSPND : 1;           /*!< [0]  */
        uint32_t RESERVED0 : 5;        /*!< [5:1]  */
        uint32_t SPDBUF : 2;           /*!< [7:6]  */
        uint32_t RESERVED1 : 1;        /*!< [8]  */
        uint32_t DATLFT : 7;           /*!< [15:9]  */
        uint32_t RESERVED2 : 16;       /*!< [31:16]  */
    } B;
} hw_quadspi_spndst_t;

/*!
 * @name Constants and macros for entire QuadSPI_SPNDST register
 */
/*@{*/
#define HW_QuadSPI_SPNDST_ADDR(x) ((uintptr_t)(x) + 0x168U)

#define HW_QuadSPI_SPNDST(x)     (*(__I hw_quadspi_spndst_t *) HW_QuadSPI_SPNDST_ADDR(x))
#define HW_QuadSPI_SPNDST_RD(x)  (HW_QuadSPI_SPNDST(x).U)
/*@}*/

/*
 * Constants & macros for individual QuadSPI_SPNDST bitfields
 */

/*!
 * @name Register QuadSPI_SPNDST, field SUSPND[0] (RO)
 *
 * When set, it signifies that a sequence is in suspended state
 */
/*@{*/
#define BP_QuadSPI_SPNDST_SUSPND (0U)      /*!< Bit position for QuadSPI_SPNDST_SUSPND. */
#define BM_QuadSPI_SPNDST_SUSPND (0x00000001U) /*!< Bit mask for QuadSPI_SPNDST_SUSPND. */
#define BS_QuadSPI_SPNDST_SUSPND (1U)      /*!< Bit field size in bits for QuadSPI_SPNDST_SUSPND. */

/*! @brief Read current value of the QuadSPI_SPNDST_SUSPND field. */
#define BR_QuadSPI_SPNDST_SUSPND(x) (HW_QuadSPI_SPNDST(x).B.SUSPND)
/*@}*/

/*!
 * @name Register QuadSPI_SPNDST, field SPDBUF[7:6] (RO)
 *
 * Suspended Buffer: Provides the suspended buffer number. Valid only when
 * SUSPND is set to 1'b1
 */
/*@{*/
#define BP_QuadSPI_SPNDST_SPDBUF (6U)      /*!< Bit position for QuadSPI_SPNDST_SPDBUF. */
#define BM_QuadSPI_SPNDST_SPDBUF (0x000000C0U) /*!< Bit mask for QuadSPI_SPNDST_SPDBUF. */
#define BS_QuadSPI_SPNDST_SPDBUF (2U)      /*!< Bit field size in bits for QuadSPI_SPNDST_SPDBUF. */

/*! @brief Read current value of the QuadSPI_SPNDST_SPDBUF field. */
#define BR_QuadSPI_SPNDST_SPDBUF(x) (HW_QuadSPI_SPNDST(x).B.SPDBUF)
/*@}*/

/*!
 * @name Register QuadSPI_SPNDST, field DATLFT[15:9] (RO)
 *
 * Data left: Provides information about the amount of data left to be read in
 * the suspended sequence. Valid only when SUSPND is set to 1'b1. Value in terms
 * of 64 bits or 8 bytes
 */
/*@{*/
#define BP_QuadSPI_SPNDST_DATLFT (9U)      /*!< Bit position for QuadSPI_SPNDST_DATLFT. */
#define BM_QuadSPI_SPNDST_DATLFT (0x0000FE00U) /*!< Bit mask for QuadSPI_SPNDST_DATLFT. */
#define BS_QuadSPI_SPNDST_DATLFT (7U)      /*!< Bit field size in bits for QuadSPI_SPNDST_DATLFT. */

/*! @brief Read current value of the QuadSPI_SPNDST_DATLFT field. */
#define BR_QuadSPI_SPNDST_DATLFT(x) (HW_QuadSPI_SPNDST(x).B.DATLFT)
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_SPTRCLR - Sequence Pointer Clear Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_SPTRCLR - Sequence Pointer Clear Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The sequence pointer clear register provides bits to reset the IP and Buffer
 * sequence pointers. The sequence pointer contains the index of which
 * instruction within the LUT entry is to be executed next. For example, if the LUT entry
 * ends on a JMP_ON_CS value of 2, the index will be stored as 2. The software
 * should reset the sequence pointers whenever the sequence ID is changed by
 * updating the SEQID field in QSPI_IPCR or QSPI_BFGENCR.
 */
typedef union _hw_quadspi_sptrclr
{
    uint32_t U;
    struct _hw_quadspi_sptrclr_bitfields
    {
        uint32_t BFPTRC : 1;           /*!< [0]  */
        uint32_t RESERVED0 : 7;        /*!< [7:1]  */
        uint32_t IPPTRC : 1;           /*!< [8]  */
        uint32_t RESERVED1 : 23;       /*!< [31:9]  */
    } B;
} hw_quadspi_sptrclr_t;

/*!
 * @name Constants and macros for entire QuadSPI_SPTRCLR register
 */
/*@{*/
#define HW_QuadSPI_SPTRCLR_ADDR(x) ((uintptr_t)(x) + 0x16CU)

#define HW_QuadSPI_SPTRCLR(x)    (*(__IO hw_quadspi_sptrclr_t *) HW_QuadSPI_SPTRCLR_ADDR(x))
#define HW_QuadSPI_SPTRCLR_RD(x) (HW_QuadSPI_SPTRCLR(x).U)
#define HW_QuadSPI_SPTRCLR_WR(x, v) (HW_QuadSPI_SPTRCLR(x).U = (v))
#define HW_QuadSPI_SPTRCLR_SET(x, v) (HW_QuadSPI_SPTRCLR_WR(x, HW_QuadSPI_SPTRCLR_RD(x) |  (v)))
#define HW_QuadSPI_SPTRCLR_CLR(x, v) (HW_QuadSPI_SPTRCLR_WR(x, HW_QuadSPI_SPTRCLR_RD(x) & ~(v)))
#define HW_QuadSPI_SPTRCLR_TOG(x, v) (HW_QuadSPI_SPTRCLR_WR(x, HW_QuadSPI_SPTRCLR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_SPTRCLR bitfields
 */

/*!
 * @name Register QuadSPI_SPTRCLR, field BFPTRC[0] (RW)
 *
 * Buffer Pointer Clear: 1: Clears the sequence pointer for AHB accesses as
 * defined in QuadSPI_BFGENCR.
 */
/*@{*/
#define BP_QuadSPI_SPTRCLR_BFPTRC (0U)     /*!< Bit position for QuadSPI_SPTRCLR_BFPTRC. */
#define BM_QuadSPI_SPTRCLR_BFPTRC (0x00000001U) /*!< Bit mask for QuadSPI_SPTRCLR_BFPTRC. */
#define BS_QuadSPI_SPTRCLR_BFPTRC (1U)     /*!< Bit field size in bits for QuadSPI_SPTRCLR_BFPTRC. */

/*! @brief Read current value of the QuadSPI_SPTRCLR_BFPTRC field. */
#define BR_QuadSPI_SPTRCLR_BFPTRC(x) (HW_QuadSPI_SPTRCLR(x).B.BFPTRC)

/*! @brief Format value for bitfield QuadSPI_SPTRCLR_BFPTRC. */
#define BF_QuadSPI_SPTRCLR_BFPTRC(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SPTRCLR_BFPTRC) & BM_QuadSPI_SPTRCLR_BFPTRC)

/*! @brief Set the BFPTRC field to a new value. */
#define BW_QuadSPI_SPTRCLR_BFPTRC(x, v) (HW_QuadSPI_SPTRCLR_WR(x, (HW_QuadSPI_SPTRCLR_RD(x) & ~BM_QuadSPI_SPTRCLR_BFPTRC) | BF_QuadSPI_SPTRCLR_BFPTRC(v)))
/*@}*/

/*!
 * @name Register QuadSPI_SPTRCLR, field IPPTRC[8] (RW)
 *
 * IP Pointer Clear: 1: Clears the sequence pointer for IP accesses as defined
 * in QuadSPI_IPCR
 */
/*@{*/
#define BP_QuadSPI_SPTRCLR_IPPTRC (8U)     /*!< Bit position for QuadSPI_SPTRCLR_IPPTRC. */
#define BM_QuadSPI_SPTRCLR_IPPTRC (0x00000100U) /*!< Bit mask for QuadSPI_SPTRCLR_IPPTRC. */
#define BS_QuadSPI_SPTRCLR_IPPTRC (1U)     /*!< Bit field size in bits for QuadSPI_SPTRCLR_IPPTRC. */

/*! @brief Read current value of the QuadSPI_SPTRCLR_IPPTRC field. */
#define BR_QuadSPI_SPTRCLR_IPPTRC(x) (HW_QuadSPI_SPTRCLR(x).B.IPPTRC)

/*! @brief Format value for bitfield QuadSPI_SPTRCLR_IPPTRC. */
#define BF_QuadSPI_SPTRCLR_IPPTRC(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SPTRCLR_IPPTRC) & BM_QuadSPI_SPTRCLR_IPPTRC)

/*! @brief Set the IPPTRC field to a new value. */
#define BW_QuadSPI_SPTRCLR_IPPTRC(x, v) (HW_QuadSPI_SPTRCLR_WR(x, (HW_QuadSPI_SPTRCLR_RD(x) & ~BM_QuadSPI_SPTRCLR_IPPTRC) | BF_QuadSPI_SPTRCLR_IPPTRC(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_SFA1AD - Serial Flash A1 Top Address
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_SFA1AD - Serial Flash A1 Top Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QSPI_SFA1AD register provides the address mapping for the serial flash
 * A1.The difference between QSPI_SFA1AD[TPADA1] and QSPI_AMBA_BASE defines the
 * size of the memory map for serial flash A1. Write: QSPI_SR[IP_ACC] = 0
 * QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_sfa1ad
{
    uint32_t U;
    struct _hw_quadspi_sfa1ad_bitfields
    {
        uint32_t RESERVED0 : 10;       /*!< [9:0]  */
        uint32_t TPADA1 : 22;          /*!< [31:10]  */
    } B;
} hw_quadspi_sfa1ad_t;

/*!
 * @name Constants and macros for entire QuadSPI_SFA1AD register
 */
/*@{*/
#define HW_QuadSPI_SFA1AD_ADDR(x) ((uintptr_t)(x) + 0x180U)

#define HW_QuadSPI_SFA1AD(x)     (*(__IO hw_quadspi_sfa1ad_t *) HW_QuadSPI_SFA1AD_ADDR(x))
#define HW_QuadSPI_SFA1AD_RD(x)  (HW_QuadSPI_SFA1AD(x).U)
#define HW_QuadSPI_SFA1AD_WR(x, v) (HW_QuadSPI_SFA1AD(x).U = (v))
#define HW_QuadSPI_SFA1AD_SET(x, v) (HW_QuadSPI_SFA1AD_WR(x, HW_QuadSPI_SFA1AD_RD(x) |  (v)))
#define HW_QuadSPI_SFA1AD_CLR(x, v) (HW_QuadSPI_SFA1AD_WR(x, HW_QuadSPI_SFA1AD_RD(x) & ~(v)))
#define HW_QuadSPI_SFA1AD_TOG(x, v) (HW_QuadSPI_SFA1AD_WR(x, HW_QuadSPI_SFA1AD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_SFA1AD bitfields
 */

/*!
 * @name Register QuadSPI_SFA1AD, field TPADA1[31:10] (RW)
 *
 * Top address for Serial Flash A1. In effect, TPADxx is the first location of
 * the next memory.
 */
/*@{*/
#define BP_QuadSPI_SFA1AD_TPADA1 (10U)     /*!< Bit position for QuadSPI_SFA1AD_TPADA1. */
#define BM_QuadSPI_SFA1AD_TPADA1 (0xFFFFFC00U) /*!< Bit mask for QuadSPI_SFA1AD_TPADA1. */
#define BS_QuadSPI_SFA1AD_TPADA1 (22U)     /*!< Bit field size in bits for QuadSPI_SFA1AD_TPADA1. */

/*! @brief Read current value of the QuadSPI_SFA1AD_TPADA1 field. */
#define BR_QuadSPI_SFA1AD_TPADA1(x) (HW_QuadSPI_SFA1AD(x).B.TPADA1)

/*! @brief Format value for bitfield QuadSPI_SFA1AD_TPADA1. */
#define BF_QuadSPI_SFA1AD_TPADA1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SFA1AD_TPADA1) & BM_QuadSPI_SFA1AD_TPADA1)

/*! @brief Set the TPADA1 field to a new value. */
#define BW_QuadSPI_SFA1AD_TPADA1(x, v) (HW_QuadSPI_SFA1AD_WR(x, (HW_QuadSPI_SFA1AD_RD(x) & ~BM_QuadSPI_SFA1AD_TPADA1) | BF_QuadSPI_SFA1AD_TPADA1(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_SFA2AD - Serial Flash A2 Top Address
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_SFA2AD - Serial Flash A2 Top Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QSPI_SFA2AD register provides the address mapping for the serial flash
 * A2.The difference between QSPI_SFA2AD[TPADA2] and QSPI_SFA1AD[TPADA1] defines
 * the size of the memory map for serial flash A2. Write: QSPI_SR[IP_ACC] = 0
 * QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_sfa2ad
{
    uint32_t U;
    struct _hw_quadspi_sfa2ad_bitfields
    {
        uint32_t RESERVED0 : 10;       /*!< [9:0]  */
        uint32_t TPADA2 : 22;          /*!< [31:10]  */
    } B;
} hw_quadspi_sfa2ad_t;

/*!
 * @name Constants and macros for entire QuadSPI_SFA2AD register
 */
/*@{*/
#define HW_QuadSPI_SFA2AD_ADDR(x) ((uintptr_t)(x) + 0x184U)

#define HW_QuadSPI_SFA2AD(x)     (*(__IO hw_quadspi_sfa2ad_t *) HW_QuadSPI_SFA2AD_ADDR(x))
#define HW_QuadSPI_SFA2AD_RD(x)  (HW_QuadSPI_SFA2AD(x).U)
#define HW_QuadSPI_SFA2AD_WR(x, v) (HW_QuadSPI_SFA2AD(x).U = (v))
#define HW_QuadSPI_SFA2AD_SET(x, v) (HW_QuadSPI_SFA2AD_WR(x, HW_QuadSPI_SFA2AD_RD(x) |  (v)))
#define HW_QuadSPI_SFA2AD_CLR(x, v) (HW_QuadSPI_SFA2AD_WR(x, HW_QuadSPI_SFA2AD_RD(x) & ~(v)))
#define HW_QuadSPI_SFA2AD_TOG(x, v) (HW_QuadSPI_SFA2AD_WR(x, HW_QuadSPI_SFA2AD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_SFA2AD bitfields
 */

/*!
 * @name Register QuadSPI_SFA2AD, field TPADA2[31:10] (RW)
 *
 * Top address for Serial Flash A2. In effect, TPxxAD is the first location of
 * the next memory.
 */
/*@{*/
#define BP_QuadSPI_SFA2AD_TPADA2 (10U)     /*!< Bit position for QuadSPI_SFA2AD_TPADA2. */
#define BM_QuadSPI_SFA2AD_TPADA2 (0xFFFFFC00U) /*!< Bit mask for QuadSPI_SFA2AD_TPADA2. */
#define BS_QuadSPI_SFA2AD_TPADA2 (22U)     /*!< Bit field size in bits for QuadSPI_SFA2AD_TPADA2. */

/*! @brief Read current value of the QuadSPI_SFA2AD_TPADA2 field. */
#define BR_QuadSPI_SFA2AD_TPADA2(x) (HW_QuadSPI_SFA2AD(x).B.TPADA2)

/*! @brief Format value for bitfield QuadSPI_SFA2AD_TPADA2. */
#define BF_QuadSPI_SFA2AD_TPADA2(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SFA2AD_TPADA2) & BM_QuadSPI_SFA2AD_TPADA2)

/*! @brief Set the TPADA2 field to a new value. */
#define BW_QuadSPI_SFA2AD_TPADA2(x, v) (HW_QuadSPI_SFA2AD_WR(x, (HW_QuadSPI_SFA2AD_RD(x) & ~BM_QuadSPI_SFA2AD_TPADA2) | BF_QuadSPI_SFA2AD_TPADA2(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_SFB1AD - Serial Flash B1Top Address
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_SFB1AD - Serial Flash B1Top Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QSPI_SFB1AD register provides the address mapping for the serial flash
 * B1.The difference between QSPI_SFB1AD[TPADB1] and QSPI_SFA2AD[TPADA2] defines
 * the size of the memory map for serial flash B1. Write: QSPI_SR[IP_ACC] = 0
 * QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_sfb1ad
{
    uint32_t U;
    struct _hw_quadspi_sfb1ad_bitfields
    {
        uint32_t RESERVED0 : 10;       /*!< [9:0]  */
        uint32_t TPADB1 : 22;          /*!< [31:10]  */
    } B;
} hw_quadspi_sfb1ad_t;

/*!
 * @name Constants and macros for entire QuadSPI_SFB1AD register
 */
/*@{*/
#define HW_QuadSPI_SFB1AD_ADDR(x) ((uintptr_t)(x) + 0x188U)

#define HW_QuadSPI_SFB1AD(x)     (*(__IO hw_quadspi_sfb1ad_t *) HW_QuadSPI_SFB1AD_ADDR(x))
#define HW_QuadSPI_SFB1AD_RD(x)  (HW_QuadSPI_SFB1AD(x).U)
#define HW_QuadSPI_SFB1AD_WR(x, v) (HW_QuadSPI_SFB1AD(x).U = (v))
#define HW_QuadSPI_SFB1AD_SET(x, v) (HW_QuadSPI_SFB1AD_WR(x, HW_QuadSPI_SFB1AD_RD(x) |  (v)))
#define HW_QuadSPI_SFB1AD_CLR(x, v) (HW_QuadSPI_SFB1AD_WR(x, HW_QuadSPI_SFB1AD_RD(x) & ~(v)))
#define HW_QuadSPI_SFB1AD_TOG(x, v) (HW_QuadSPI_SFB1AD_WR(x, HW_QuadSPI_SFB1AD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_SFB1AD bitfields
 */

/*!
 * @name Register QuadSPI_SFB1AD, field TPADB1[31:10] (RW)
 *
 * Top address for Serial Flash B1.In effect, TPxxAD is the first location of
 * the next memory.
 */
/*@{*/
#define BP_QuadSPI_SFB1AD_TPADB1 (10U)     /*!< Bit position for QuadSPI_SFB1AD_TPADB1. */
#define BM_QuadSPI_SFB1AD_TPADB1 (0xFFFFFC00U) /*!< Bit mask for QuadSPI_SFB1AD_TPADB1. */
#define BS_QuadSPI_SFB1AD_TPADB1 (22U)     /*!< Bit field size in bits for QuadSPI_SFB1AD_TPADB1. */

/*! @brief Read current value of the QuadSPI_SFB1AD_TPADB1 field. */
#define BR_QuadSPI_SFB1AD_TPADB1(x) (HW_QuadSPI_SFB1AD(x).B.TPADB1)

/*! @brief Format value for bitfield QuadSPI_SFB1AD_TPADB1. */
#define BF_QuadSPI_SFB1AD_TPADB1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SFB1AD_TPADB1) & BM_QuadSPI_SFB1AD_TPADB1)

/*! @brief Set the TPADB1 field to a new value. */
#define BW_QuadSPI_SFB1AD_TPADB1(x, v) (HW_QuadSPI_SFB1AD_WR(x, (HW_QuadSPI_SFB1AD_RD(x) & ~BM_QuadSPI_SFB1AD_TPADB1) | BF_QuadSPI_SFB1AD_TPADB1(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_SFB2AD - Serial Flash B2Top Address
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_SFB2AD - Serial Flash B2Top Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QSPI_SFB2AD register provides the address mapping for the serial flash
 * B2.The difference between QSPI_SFB2AD[TPADB2] and QSPI_SFB1AD[TPADB1] defines
 * the size of the memory map for serial flash B2. Write: QSPI_SR[IP_ACC] = 0
 * QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_sfb2ad
{
    uint32_t U;
    struct _hw_quadspi_sfb2ad_bitfields
    {
        uint32_t RESERVED0 : 10;       /*!< [9:0]  */
        uint32_t TPADB2 : 22;          /*!< [31:10]  */
    } B;
} hw_quadspi_sfb2ad_t;

/*!
 * @name Constants and macros for entire QuadSPI_SFB2AD register
 */
/*@{*/
#define HW_QuadSPI_SFB2AD_ADDR(x) ((uintptr_t)(x) + 0x18CU)

#define HW_QuadSPI_SFB2AD(x)     (*(__IO hw_quadspi_sfb2ad_t *) HW_QuadSPI_SFB2AD_ADDR(x))
#define HW_QuadSPI_SFB2AD_RD(x)  (HW_QuadSPI_SFB2AD(x).U)
#define HW_QuadSPI_SFB2AD_WR(x, v) (HW_QuadSPI_SFB2AD(x).U = (v))
#define HW_QuadSPI_SFB2AD_SET(x, v) (HW_QuadSPI_SFB2AD_WR(x, HW_QuadSPI_SFB2AD_RD(x) |  (v)))
#define HW_QuadSPI_SFB2AD_CLR(x, v) (HW_QuadSPI_SFB2AD_WR(x, HW_QuadSPI_SFB2AD_RD(x) & ~(v)))
#define HW_QuadSPI_SFB2AD_TOG(x, v) (HW_QuadSPI_SFB2AD_WR(x, HW_QuadSPI_SFB2AD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_SFB2AD bitfields
 */

/*!
 * @name Register QuadSPI_SFB2AD, field TPADB2[31:10] (RW)
 *
 * Top address for Serial Flash B2. In effect, TPxxAD is the first location of
 * the next memory.
 */
/*@{*/
#define BP_QuadSPI_SFB2AD_TPADB2 (10U)     /*!< Bit position for QuadSPI_SFB2AD_TPADB2. */
#define BM_QuadSPI_SFB2AD_TPADB2 (0xFFFFFC00U) /*!< Bit mask for QuadSPI_SFB2AD_TPADB2. */
#define BS_QuadSPI_SFB2AD_TPADB2 (22U)     /*!< Bit field size in bits for QuadSPI_SFB2AD_TPADB2. */

/*! @brief Read current value of the QuadSPI_SFB2AD_TPADB2 field. */
#define BR_QuadSPI_SFB2AD_TPADB2(x) (HW_QuadSPI_SFB2AD(x).B.TPADB2)

/*! @brief Format value for bitfield QuadSPI_SFB2AD_TPADB2. */
#define BF_QuadSPI_SFB2AD_TPADB2(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_SFB2AD_TPADB2) & BM_QuadSPI_SFB2AD_TPADB2)

/*! @brief Set the TPADB2 field to a new value. */
#define BW_QuadSPI_SFB2AD_TPADB2(x, v) (HW_QuadSPI_SFB2AD_WR(x, (HW_QuadSPI_SFB2AD_RD(x) & ~BM_QuadSPI_SFB2AD_TPADB2) | BF_QuadSPI_SFB2AD_TPADB2(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_RBDRn - RX Buffer Data Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_RBDRn - RX Buffer Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QuadSPI_RBDR registers provide access to the individual entries in the RX
 * Buffer. Refer to for the byte ordering scheme. QuadSPI_RBDR0 corresponds to
 * the actual position of the read pointer within the RX Buffer. The number of
 * valid entries available depends from the number of RX Buffer entries implemented
 * and from the number of valid buffer entries available in the RX Buffer.
 * Example 1, RX Buffer filled completely with 32 words: In this case the address range
 * for valid read access extends from QuadSPI_RBDR0 to QuadSPI_RBDR31. Example
 * 2, RX Buffer filled with 5 valid words: RX Buffer fill level
 * QuadSPI_RBSR[RDBFL] is 5. In this case an access to QuadSPI_RBDR4 provides the last valid entry.
 * Any access beyond the range of valid RX Buffer entries provides undefined
 * results.
 */
typedef union _hw_quadspi_rbdrn
{
    uint32_t U;
    struct _hw_quadspi_rbdrn_bitfields
    {
        uint32_t RXDATA : 32;          /*!< [31:0]  */
    } B;
} hw_quadspi_rbdrn_t;

/*!
 * @name Constants and macros for entire QuadSPI_RBDRn register
 */
/*@{*/
#define HW_QuadSPI_RBDRn_COUNT (32U)

#define HW_QuadSPI_RBDRn_ADDR(x, n) ((uintptr_t)(x) + 0x200U + (0x4U * (n)))

#define HW_QuadSPI_RBDRn(x, n)   (*(__IO hw_quadspi_rbdrn_t *) HW_QuadSPI_RBDRn_ADDR(x, n))
#define HW_QuadSPI_RBDRn_RD(x, n) (HW_QuadSPI_RBDRn(x, n).U)
#define HW_QuadSPI_RBDRn_WR(x, n, v) (HW_QuadSPI_RBDRn(x, n).U = (v))
#define HW_QuadSPI_RBDRn_SET(x, n, v) (HW_QuadSPI_RBDRn_WR(x, n, HW_QuadSPI_RBDRn_RD(x, n) |  (v)))
#define HW_QuadSPI_RBDRn_CLR(x, n, v) (HW_QuadSPI_RBDRn_WR(x, n, HW_QuadSPI_RBDRn_RD(x, n) & ~(v)))
#define HW_QuadSPI_RBDRn_TOG(x, n, v) (HW_QuadSPI_RBDRn_WR(x, n, HW_QuadSPI_RBDRn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_RBDRn bitfields
 */

/*!
 * @name Register QuadSPI_RBDRn, field RXDATA[31:0] (RW)
 *
 * RX Data. The RXDATA field contains the data associated with the related RX
 * Buffer entry. Data format and byte ordering is given in Byte Ordering of Serial
 * Flash Read Data .
 */
/*@{*/
#define BP_QuadSPI_RBDRn_RXDATA (0U)       /*!< Bit position for QuadSPI_RBDRn_RXDATA. */
#define BM_QuadSPI_RBDRn_RXDATA (0xFFFFFFFFU) /*!< Bit mask for QuadSPI_RBDRn_RXDATA. */
#define BS_QuadSPI_RBDRn_RXDATA (32U)      /*!< Bit field size in bits for QuadSPI_RBDRn_RXDATA. */

/*! @brief Read current value of the QuadSPI_RBDRn_RXDATA field. */
#define BR_QuadSPI_RBDRn_RXDATA(x, n) (HW_QuadSPI_RBDRn(x, n).U)

/*! @brief Format value for bitfield QuadSPI_RBDRn_RXDATA. */
#define BF_QuadSPI_RBDRn_RXDATA(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_RBDRn_RXDATA) & BM_QuadSPI_RBDRn_RXDATA)

/*! @brief Set the RXDATA field to a new value. */
#define BW_QuadSPI_RBDRn_RXDATA(x, n, v) (HW_QuadSPI_RBDRn_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_LUTKEY - LUT Key Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUTKEY - LUT Key Register (RW)
 *
 * Reset value: 0x5AF05AF0U
 *
 * The LUT Key register contains the key to lock and unlock the Look-up-table.
 * Refer to Look-up Table for details. Write:Anytime
 */
typedef union _hw_quadspi_lutkey
{
    uint32_t U;
    struct _hw_quadspi_lutkey_bitfields
    {
        uint32_t KEY : 32;             /*!< [31:0]  */
    } B;
} hw_quadspi_lutkey_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUTKEY register
 */
/*@{*/
#define HW_QuadSPI_LUTKEY_ADDR(x) ((uintptr_t)(x) + 0x300U)

#define HW_QuadSPI_LUTKEY(x)     (*(__IO hw_quadspi_lutkey_t *) HW_QuadSPI_LUTKEY_ADDR(x))
#define HW_QuadSPI_LUTKEY_RD(x)  (HW_QuadSPI_LUTKEY(x).U)
#define HW_QuadSPI_LUTKEY_WR(x, v) (HW_QuadSPI_LUTKEY(x).U = (v))
#define HW_QuadSPI_LUTKEY_SET(x, v) (HW_QuadSPI_LUTKEY_WR(x, HW_QuadSPI_LUTKEY_RD(x) |  (v)))
#define HW_QuadSPI_LUTKEY_CLR(x, v) (HW_QuadSPI_LUTKEY_WR(x, HW_QuadSPI_LUTKEY_RD(x) & ~(v)))
#define HW_QuadSPI_LUTKEY_TOG(x, v) (HW_QuadSPI_LUTKEY_WR(x, HW_QuadSPI_LUTKEY_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUTKEY bitfields
 */

/*!
 * @name Register QuadSPI_LUTKEY, field KEY[31:0] (RW)
 *
 * The key to lock or unlock the LUT. The KEY is 0x5AF05AF0. The read value is
 * always 0x5AF05AF0
 */
/*@{*/
#define BP_QuadSPI_LUTKEY_KEY (0U)         /*!< Bit position for QuadSPI_LUTKEY_KEY. */
#define BM_QuadSPI_LUTKEY_KEY (0xFFFFFFFFU) /*!< Bit mask for QuadSPI_LUTKEY_KEY. */
#define BS_QuadSPI_LUTKEY_KEY (32U)        /*!< Bit field size in bits for QuadSPI_LUTKEY_KEY. */

/*! @brief Read current value of the QuadSPI_LUTKEY_KEY field. */
#define BR_QuadSPI_LUTKEY_KEY(x) (HW_QuadSPI_LUTKEY(x).U)

/*! @brief Format value for bitfield QuadSPI_LUTKEY_KEY. */
#define BF_QuadSPI_LUTKEY_KEY(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUTKEY_KEY) & BM_QuadSPI_LUTKEY_KEY)

/*! @brief Set the KEY field to a new value. */
#define BW_QuadSPI_LUTKEY_KEY(x, v) (HW_QuadSPI_LUTKEY_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_LCKCR - LUT Lock Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LCKCR - LUT Lock Configuration Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * The LUT lock configuration register is used along with QSPI_LUTKEY register
 * to lock or unlock the LUT. This register has to be written immediately after
 * QSPI_LUTKEY register for the lock or unlock operation to be successful. Refer to
 * Look-up Table for details. Setting both the LOCK and UNLOCK bits as "00" or
 * "11" is not allowed. Write:Just after writing the LUT Key Register (QSPI_LUTKEY)
 */
typedef union _hw_quadspi_lckcr
{
    uint32_t U;
    struct _hw_quadspi_lckcr_bitfields
    {
        uint32_t LOCK : 1;             /*!< [0]  */
        uint32_t UNLOCK : 1;           /*!< [1]  */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_quadspi_lckcr_t;

/*!
 * @name Constants and macros for entire QuadSPI_LCKCR register
 */
/*@{*/
#define HW_QuadSPI_LCKCR_ADDR(x) ((uintptr_t)(x) + 0x304U)

#define HW_QuadSPI_LCKCR(x)      (*(__IO hw_quadspi_lckcr_t *) HW_QuadSPI_LCKCR_ADDR(x))
#define HW_QuadSPI_LCKCR_RD(x)   (HW_QuadSPI_LCKCR(x).U)
#define HW_QuadSPI_LCKCR_WR(x, v) (HW_QuadSPI_LCKCR(x).U = (v))
#define HW_QuadSPI_LCKCR_SET(x, v) (HW_QuadSPI_LCKCR_WR(x, HW_QuadSPI_LCKCR_RD(x) |  (v)))
#define HW_QuadSPI_LCKCR_CLR(x, v) (HW_QuadSPI_LCKCR_WR(x, HW_QuadSPI_LCKCR_RD(x) & ~(v)))
#define HW_QuadSPI_LCKCR_TOG(x, v) (HW_QuadSPI_LCKCR_WR(x, HW_QuadSPI_LCKCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LCKCR bitfields
 */

/*!
 * @name Register QuadSPI_LCKCR, field LOCK[0] (RW)
 *
 * Locks the LUT when the following condition is met: This register is written
 * just after the LUTKEYLUT Key Register The LUT key register was written with
 * 0x5AF05AF0 key
 */
/*@{*/
#define BP_QuadSPI_LCKCR_LOCK (0U)         /*!< Bit position for QuadSPI_LCKCR_LOCK. */
#define BM_QuadSPI_LCKCR_LOCK (0x00000001U) /*!< Bit mask for QuadSPI_LCKCR_LOCK. */
#define BS_QuadSPI_LCKCR_LOCK (1U)         /*!< Bit field size in bits for QuadSPI_LCKCR_LOCK. */

/*! @brief Read current value of the QuadSPI_LCKCR_LOCK field. */
#define BR_QuadSPI_LCKCR_LOCK(x) (HW_QuadSPI_LCKCR(x).B.LOCK)

/*! @brief Format value for bitfield QuadSPI_LCKCR_LOCK. */
#define BF_QuadSPI_LCKCR_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LCKCR_LOCK) & BM_QuadSPI_LCKCR_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_QuadSPI_LCKCR_LOCK(x, v) (HW_QuadSPI_LCKCR_WR(x, (HW_QuadSPI_LCKCR_RD(x) & ~BM_QuadSPI_LCKCR_LOCK) | BF_QuadSPI_LCKCR_LOCK(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LCKCR, field UNLOCK[1] (RW)
 *
 * Unlocks the LUT when the following two conditions are met: 1. This register
 * is written just after the LUTKEYLUT Key Register 2. The LUT key register was
 * written with 0x5AF05AF0 key
 */
/*@{*/
#define BP_QuadSPI_LCKCR_UNLOCK (1U)       /*!< Bit position for QuadSPI_LCKCR_UNLOCK. */
#define BM_QuadSPI_LCKCR_UNLOCK (0x00000002U) /*!< Bit mask for QuadSPI_LCKCR_UNLOCK. */
#define BS_QuadSPI_LCKCR_UNLOCK (1U)       /*!< Bit field size in bits for QuadSPI_LCKCR_UNLOCK. */

/*! @brief Read current value of the QuadSPI_LCKCR_UNLOCK field. */
#define BR_QuadSPI_LCKCR_UNLOCK(x) (HW_QuadSPI_LCKCR(x).B.UNLOCK)

/*! @brief Format value for bitfield QuadSPI_LCKCR_UNLOCK. */
#define BF_QuadSPI_LCKCR_UNLOCK(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LCKCR_UNLOCK) & BM_QuadSPI_LCKCR_UNLOCK)

/*! @brief Set the UNLOCK field to a new value. */
#define BW_QuadSPI_LCKCR_UNLOCK(x, v) (HW_QuadSPI_LCKCR_WR(x, (HW_QuadSPI_LCKCR_RD(x) & ~BM_QuadSPI_LCKCR_UNLOCK) | BF_QuadSPI_LCKCR_UNLOCK(v)))
/*@}*/

/*******************************************************************************
 * HW_QuadSPI_LUT0 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT0 - Look-up Table register (RW)
 *
 * Reset value: 0x08180403U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut0
{
    uint32_t U;
    struct _hw_quadspi_lut0_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut0_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT0 register
 */
/*@{*/
#define HW_QuadSPI_LUT0_ADDR(x)   ((uintptr_t)(x) + 0x310U)

#define HW_QuadSPI_LUT0(x)        (*(__IO hw_quadspi_lut0_t *) HW_QuadSPI_LUT0_ADDR(x))
#define HW_QuadSPI_LUT0_RD(x)     (HW_QuadSPI_LUT0(x).U)
#define HW_QuadSPI_LUT0_WR(x, v)  (HW_QuadSPI_LUT0(x).U = (v))
#define HW_QuadSPI_LUT0_SET(x, v) (HW_QuadSPI_LUT0_WR(x, HW_QuadSPI_LUT0_RD(x) |  (v)))
#define HW_QuadSPI_LUT0_CLR(x, v) (HW_QuadSPI_LUT0_WR(x, HW_QuadSPI_LUT0_RD(x) & ~(v)))
#define HW_QuadSPI_LUT0_TOG(x, v) (HW_QuadSPI_LUT0_WR(x, HW_QuadSPI_LUT0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT0 bitfields
 */

/*!
 * @name Register QuadSPI_LUT0, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT0_OPRND0 (0U)         /*!< Bit position for QuadSPI_LUT0_OPRND0. */
#define BM_QuadSPI_LUT0_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT0_OPRND0. */
#define BS_QuadSPI_LUT0_OPRND0 (8U)         /*!< Bit field size in bits for QuadSPI_LUT0_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT0_OPRND0 field. */
#define BR_QuadSPI_LUT0_OPRND0(x) (HW_QuadSPI_LUT0(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT0_OPRND0. */
#define BF_QuadSPI_LUT0_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT0_OPRND0) & BM_QuadSPI_LUT0_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT0_OPRND0(x, v) (HW_QuadSPI_LUT0_WR(x, (HW_QuadSPI_LUT0_RD(x) & ~BM_QuadSPI_LUT0_OPRND0) | BF_QuadSPI_LUT0_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT0, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT0_PAD0  (8U)          /*!< Bit position for QuadSPI_LUT0_PAD0. */
#define BM_QuadSPI_LUT0_PAD0  (0x00000300U) /*!< Bit mask for QuadSPI_LUT0_PAD0. */
#define BS_QuadSPI_LUT0_PAD0  (2U)          /*!< Bit field size in bits for QuadSPI_LUT0_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT0_PAD0 field. */
#define BR_QuadSPI_LUT0_PAD0(x) (HW_QuadSPI_LUT0(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT0_PAD0. */
#define BF_QuadSPI_LUT0_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT0_PAD0) & BM_QuadSPI_LUT0_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT0_PAD0(x, v) (HW_QuadSPI_LUT0_WR(x, (HW_QuadSPI_LUT0_RD(x) & ~BM_QuadSPI_LUT0_PAD0) | BF_QuadSPI_LUT0_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT0, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT0_INSTR0 (10U)        /*!< Bit position for QuadSPI_LUT0_INSTR0. */
#define BM_QuadSPI_LUT0_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT0_INSTR0. */
#define BS_QuadSPI_LUT0_INSTR0 (6U)         /*!< Bit field size in bits for QuadSPI_LUT0_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT0_INSTR0 field. */
#define BR_QuadSPI_LUT0_INSTR0(x) (HW_QuadSPI_LUT0(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT0_INSTR0. */
#define BF_QuadSPI_LUT0_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT0_INSTR0) & BM_QuadSPI_LUT0_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT0_INSTR0(x, v) (HW_QuadSPI_LUT0_WR(x, (HW_QuadSPI_LUT0_RD(x) & ~BM_QuadSPI_LUT0_INSTR0) | BF_QuadSPI_LUT0_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT0, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT0_OPRND1 (16U)        /*!< Bit position for QuadSPI_LUT0_OPRND1. */
#define BM_QuadSPI_LUT0_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT0_OPRND1. */
#define BS_QuadSPI_LUT0_OPRND1 (8U)         /*!< Bit field size in bits for QuadSPI_LUT0_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT0_OPRND1 field. */
#define BR_QuadSPI_LUT0_OPRND1(x) (HW_QuadSPI_LUT0(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT0_OPRND1. */
#define BF_QuadSPI_LUT0_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT0_OPRND1) & BM_QuadSPI_LUT0_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT0_OPRND1(x, v) (HW_QuadSPI_LUT0_WR(x, (HW_QuadSPI_LUT0_RD(x) & ~BM_QuadSPI_LUT0_OPRND1) | BF_QuadSPI_LUT0_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT0, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT0_PAD1  (24U)         /*!< Bit position for QuadSPI_LUT0_PAD1. */
#define BM_QuadSPI_LUT0_PAD1  (0x03000000U) /*!< Bit mask for QuadSPI_LUT0_PAD1. */
#define BS_QuadSPI_LUT0_PAD1  (2U)          /*!< Bit field size in bits for QuadSPI_LUT0_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT0_PAD1 field. */
#define BR_QuadSPI_LUT0_PAD1(x) (HW_QuadSPI_LUT0(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT0_PAD1. */
#define BF_QuadSPI_LUT0_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT0_PAD1) & BM_QuadSPI_LUT0_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT0_PAD1(x, v) (HW_QuadSPI_LUT0_WR(x, (HW_QuadSPI_LUT0_RD(x) & ~BM_QuadSPI_LUT0_PAD1) | BF_QuadSPI_LUT0_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT0, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT0_INSTR1 (26U)        /*!< Bit position for QuadSPI_LUT0_INSTR1. */
#define BM_QuadSPI_LUT0_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT0_INSTR1. */
#define BS_QuadSPI_LUT0_INSTR1 (6U)         /*!< Bit field size in bits for QuadSPI_LUT0_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT0_INSTR1 field. */
#define BR_QuadSPI_LUT0_INSTR1(x) (HW_QuadSPI_LUT0(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT0_INSTR1. */
#define BF_QuadSPI_LUT0_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT0_INSTR1) & BM_QuadSPI_LUT0_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT0_INSTR1(x, v) (HW_QuadSPI_LUT0_WR(x, (HW_QuadSPI_LUT0_RD(x) & ~BM_QuadSPI_LUT0_INSTR1) | BF_QuadSPI_LUT0_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT1 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT1 - Look-up Table register (RW)
 *
 * Reset value: 0x24001C08U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut1
{
    uint32_t U;
    struct _hw_quadspi_lut1_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut1_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT1 register
 */
/*@{*/
#define HW_QuadSPI_LUT1_ADDR(x)   ((uintptr_t)(x) + 0x314U)

#define HW_QuadSPI_LUT1(x)        (*(__IO hw_quadspi_lut1_t *) HW_QuadSPI_LUT1_ADDR(x))
#define HW_QuadSPI_LUT1_RD(x)     (HW_QuadSPI_LUT1(x).U)
#define HW_QuadSPI_LUT1_WR(x, v)  (HW_QuadSPI_LUT1(x).U = (v))
#define HW_QuadSPI_LUT1_SET(x, v) (HW_QuadSPI_LUT1_WR(x, HW_QuadSPI_LUT1_RD(x) |  (v)))
#define HW_QuadSPI_LUT1_CLR(x, v) (HW_QuadSPI_LUT1_WR(x, HW_QuadSPI_LUT1_RD(x) & ~(v)))
#define HW_QuadSPI_LUT1_TOG(x, v) (HW_QuadSPI_LUT1_WR(x, HW_QuadSPI_LUT1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT1 bitfields
 */

/*!
 * @name Register QuadSPI_LUT1, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT1_OPRND0 (0U)         /*!< Bit position for QuadSPI_LUT1_OPRND0. */
#define BM_QuadSPI_LUT1_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT1_OPRND0. */
#define BS_QuadSPI_LUT1_OPRND0 (8U)         /*!< Bit field size in bits for QuadSPI_LUT1_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT1_OPRND0 field. */
#define BR_QuadSPI_LUT1_OPRND0(x) (HW_QuadSPI_LUT1(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT1_OPRND0. */
#define BF_QuadSPI_LUT1_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT1_OPRND0) & BM_QuadSPI_LUT1_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT1_OPRND0(x, v) (HW_QuadSPI_LUT1_WR(x, (HW_QuadSPI_LUT1_RD(x) & ~BM_QuadSPI_LUT1_OPRND0) | BF_QuadSPI_LUT1_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT1, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT1_PAD0  (8U)          /*!< Bit position for QuadSPI_LUT1_PAD0. */
#define BM_QuadSPI_LUT1_PAD0  (0x00000300U) /*!< Bit mask for QuadSPI_LUT1_PAD0. */
#define BS_QuadSPI_LUT1_PAD0  (2U)          /*!< Bit field size in bits for QuadSPI_LUT1_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT1_PAD0 field. */
#define BR_QuadSPI_LUT1_PAD0(x) (HW_QuadSPI_LUT1(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT1_PAD0. */
#define BF_QuadSPI_LUT1_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT1_PAD0) & BM_QuadSPI_LUT1_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT1_PAD0(x, v) (HW_QuadSPI_LUT1_WR(x, (HW_QuadSPI_LUT1_RD(x) & ~BM_QuadSPI_LUT1_PAD0) | BF_QuadSPI_LUT1_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT1, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT1_INSTR0 (10U)        /*!< Bit position for QuadSPI_LUT1_INSTR0. */
#define BM_QuadSPI_LUT1_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT1_INSTR0. */
#define BS_QuadSPI_LUT1_INSTR0 (6U)         /*!< Bit field size in bits for QuadSPI_LUT1_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT1_INSTR0 field. */
#define BR_QuadSPI_LUT1_INSTR0(x) (HW_QuadSPI_LUT1(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT1_INSTR0. */
#define BF_QuadSPI_LUT1_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT1_INSTR0) & BM_QuadSPI_LUT1_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT1_INSTR0(x, v) (HW_QuadSPI_LUT1_WR(x, (HW_QuadSPI_LUT1_RD(x) & ~BM_QuadSPI_LUT1_INSTR0) | BF_QuadSPI_LUT1_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT1, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT1_OPRND1 (16U)        /*!< Bit position for QuadSPI_LUT1_OPRND1. */
#define BM_QuadSPI_LUT1_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT1_OPRND1. */
#define BS_QuadSPI_LUT1_OPRND1 (8U)         /*!< Bit field size in bits for QuadSPI_LUT1_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT1_OPRND1 field. */
#define BR_QuadSPI_LUT1_OPRND1(x) (HW_QuadSPI_LUT1(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT1_OPRND1. */
#define BF_QuadSPI_LUT1_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT1_OPRND1) & BM_QuadSPI_LUT1_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT1_OPRND1(x, v) (HW_QuadSPI_LUT1_WR(x, (HW_QuadSPI_LUT1_RD(x) & ~BM_QuadSPI_LUT1_OPRND1) | BF_QuadSPI_LUT1_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT1, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT1_PAD1  (24U)         /*!< Bit position for QuadSPI_LUT1_PAD1. */
#define BM_QuadSPI_LUT1_PAD1  (0x03000000U) /*!< Bit mask for QuadSPI_LUT1_PAD1. */
#define BS_QuadSPI_LUT1_PAD1  (2U)          /*!< Bit field size in bits for QuadSPI_LUT1_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT1_PAD1 field. */
#define BR_QuadSPI_LUT1_PAD1(x) (HW_QuadSPI_LUT1(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT1_PAD1. */
#define BF_QuadSPI_LUT1_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT1_PAD1) & BM_QuadSPI_LUT1_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT1_PAD1(x, v) (HW_QuadSPI_LUT1_WR(x, (HW_QuadSPI_LUT1_RD(x) & ~BM_QuadSPI_LUT1_PAD1) | BF_QuadSPI_LUT1_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT1, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT1_INSTR1 (26U)        /*!< Bit position for QuadSPI_LUT1_INSTR1. */
#define BM_QuadSPI_LUT1_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT1_INSTR1. */
#define BS_QuadSPI_LUT1_INSTR1 (6U)         /*!< Bit field size in bits for QuadSPI_LUT1_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT1_INSTR1 field. */
#define BR_QuadSPI_LUT1_INSTR1(x) (HW_QuadSPI_LUT1(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT1_INSTR1. */
#define BF_QuadSPI_LUT1_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT1_INSTR1) & BM_QuadSPI_LUT1_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT1_INSTR1(x, v) (HW_QuadSPI_LUT1_WR(x, (HW_QuadSPI_LUT1_RD(x) & ~BM_QuadSPI_LUT1_INSTR1) | BF_QuadSPI_LUT1_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT2 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT2 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut2
{
    uint32_t U;
    struct _hw_quadspi_lut2_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut2_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT2 register
 */
/*@{*/
#define HW_QuadSPI_LUT2_ADDR(x)  ((uintptr_t)(x) + 0x318U)

#define HW_QuadSPI_LUT2(x)       (*(__IO hw_quadspi_lut2_t *) HW_QuadSPI_LUT2_ADDR(x))
#define HW_QuadSPI_LUT2_RD(x)    (HW_QuadSPI_LUT2(x).U)
#define HW_QuadSPI_LUT2_WR(x, v) (HW_QuadSPI_LUT2(x).U = (v))
#define HW_QuadSPI_LUT2_SET(x, v) (HW_QuadSPI_LUT2_WR(x, HW_QuadSPI_LUT2_RD(x) |  (v)))
#define HW_QuadSPI_LUT2_CLR(x, v) (HW_QuadSPI_LUT2_WR(x, HW_QuadSPI_LUT2_RD(x) & ~(v)))
#define HW_QuadSPI_LUT2_TOG(x, v) (HW_QuadSPI_LUT2_WR(x, HW_QuadSPI_LUT2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT2 bitfields
 */

/*!
 * @name Register QuadSPI_LUT2, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT2_OPRND0 (0U)        /*!< Bit position for QuadSPI_LUT2_OPRND0. */
#define BM_QuadSPI_LUT2_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT2_OPRND0. */
#define BS_QuadSPI_LUT2_OPRND0 (8U)        /*!< Bit field size in bits for QuadSPI_LUT2_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT2_OPRND0 field. */
#define BR_QuadSPI_LUT2_OPRND0(x) (HW_QuadSPI_LUT2(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT2_OPRND0. */
#define BF_QuadSPI_LUT2_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT2_OPRND0) & BM_QuadSPI_LUT2_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT2_OPRND0(x, v) (HW_QuadSPI_LUT2_WR(x, (HW_QuadSPI_LUT2_RD(x) & ~BM_QuadSPI_LUT2_OPRND0) | BF_QuadSPI_LUT2_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT2, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT2_PAD0 (8U)          /*!< Bit position for QuadSPI_LUT2_PAD0. */
#define BM_QuadSPI_LUT2_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT2_PAD0. */
#define BS_QuadSPI_LUT2_PAD0 (2U)          /*!< Bit field size in bits for QuadSPI_LUT2_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT2_PAD0 field. */
#define BR_QuadSPI_LUT2_PAD0(x) (HW_QuadSPI_LUT2(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT2_PAD0. */
#define BF_QuadSPI_LUT2_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT2_PAD0) & BM_QuadSPI_LUT2_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT2_PAD0(x, v) (HW_QuadSPI_LUT2_WR(x, (HW_QuadSPI_LUT2_RD(x) & ~BM_QuadSPI_LUT2_PAD0) | BF_QuadSPI_LUT2_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT2, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT2_INSTR0 (10U)       /*!< Bit position for QuadSPI_LUT2_INSTR0. */
#define BM_QuadSPI_LUT2_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT2_INSTR0. */
#define BS_QuadSPI_LUT2_INSTR0 (6U)        /*!< Bit field size in bits for QuadSPI_LUT2_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT2_INSTR0 field. */
#define BR_QuadSPI_LUT2_INSTR0(x) (HW_QuadSPI_LUT2(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT2_INSTR0. */
#define BF_QuadSPI_LUT2_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT2_INSTR0) & BM_QuadSPI_LUT2_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT2_INSTR0(x, v) (HW_QuadSPI_LUT2_WR(x, (HW_QuadSPI_LUT2_RD(x) & ~BM_QuadSPI_LUT2_INSTR0) | BF_QuadSPI_LUT2_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT2, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT2_OPRND1 (16U)       /*!< Bit position for QuadSPI_LUT2_OPRND1. */
#define BM_QuadSPI_LUT2_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT2_OPRND1. */
#define BS_QuadSPI_LUT2_OPRND1 (8U)        /*!< Bit field size in bits for QuadSPI_LUT2_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT2_OPRND1 field. */
#define BR_QuadSPI_LUT2_OPRND1(x) (HW_QuadSPI_LUT2(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT2_OPRND1. */
#define BF_QuadSPI_LUT2_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT2_OPRND1) & BM_QuadSPI_LUT2_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT2_OPRND1(x, v) (HW_QuadSPI_LUT2_WR(x, (HW_QuadSPI_LUT2_RD(x) & ~BM_QuadSPI_LUT2_OPRND1) | BF_QuadSPI_LUT2_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT2, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT2_PAD1 (24U)         /*!< Bit position for QuadSPI_LUT2_PAD1. */
#define BM_QuadSPI_LUT2_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT2_PAD1. */
#define BS_QuadSPI_LUT2_PAD1 (2U)          /*!< Bit field size in bits for QuadSPI_LUT2_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT2_PAD1 field. */
#define BR_QuadSPI_LUT2_PAD1(x) (HW_QuadSPI_LUT2(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT2_PAD1. */
#define BF_QuadSPI_LUT2_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT2_PAD1) & BM_QuadSPI_LUT2_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT2_PAD1(x, v) (HW_QuadSPI_LUT2_WR(x, (HW_QuadSPI_LUT2_RD(x) & ~BM_QuadSPI_LUT2_PAD1) | BF_QuadSPI_LUT2_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT2, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT2_INSTR1 (26U)       /*!< Bit position for QuadSPI_LUT2_INSTR1. */
#define BM_QuadSPI_LUT2_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT2_INSTR1. */
#define BS_QuadSPI_LUT2_INSTR1 (6U)        /*!< Bit field size in bits for QuadSPI_LUT2_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT2_INSTR1 field. */
#define BR_QuadSPI_LUT2_INSTR1(x) (HW_QuadSPI_LUT2(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT2_INSTR1. */
#define BF_QuadSPI_LUT2_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT2_INSTR1) & BM_QuadSPI_LUT2_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT2_INSTR1(x, v) (HW_QuadSPI_LUT2_WR(x, (HW_QuadSPI_LUT2_RD(x) & ~BM_QuadSPI_LUT2_INSTR1) | BF_QuadSPI_LUT2_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT3 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT3 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut3
{
    uint32_t U;
    struct _hw_quadspi_lut3_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut3_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT3 register
 */
/*@{*/
#define HW_QuadSPI_LUT3_ADDR(x)  ((uintptr_t)(x) + 0x31CU)

#define HW_QuadSPI_LUT3(x)       (*(__IO hw_quadspi_lut3_t *) HW_QuadSPI_LUT3_ADDR(x))
#define HW_QuadSPI_LUT3_RD(x)    (HW_QuadSPI_LUT3(x).U)
#define HW_QuadSPI_LUT3_WR(x, v) (HW_QuadSPI_LUT3(x).U = (v))
#define HW_QuadSPI_LUT3_SET(x, v) (HW_QuadSPI_LUT3_WR(x, HW_QuadSPI_LUT3_RD(x) |  (v)))
#define HW_QuadSPI_LUT3_CLR(x, v) (HW_QuadSPI_LUT3_WR(x, HW_QuadSPI_LUT3_RD(x) & ~(v)))
#define HW_QuadSPI_LUT3_TOG(x, v) (HW_QuadSPI_LUT3_WR(x, HW_QuadSPI_LUT3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT3 bitfields
 */

/*!
 * @name Register QuadSPI_LUT3, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT3_OPRND0 (0U)        /*!< Bit position for QuadSPI_LUT3_OPRND0. */
#define BM_QuadSPI_LUT3_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT3_OPRND0. */
#define BS_QuadSPI_LUT3_OPRND0 (8U)        /*!< Bit field size in bits for QuadSPI_LUT3_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT3_OPRND0 field. */
#define BR_QuadSPI_LUT3_OPRND0(x) (HW_QuadSPI_LUT3(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT3_OPRND0. */
#define BF_QuadSPI_LUT3_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT3_OPRND0) & BM_QuadSPI_LUT3_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT3_OPRND0(x, v) (HW_QuadSPI_LUT3_WR(x, (HW_QuadSPI_LUT3_RD(x) & ~BM_QuadSPI_LUT3_OPRND0) | BF_QuadSPI_LUT3_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT3, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT3_PAD0 (8U)          /*!< Bit position for QuadSPI_LUT3_PAD0. */
#define BM_QuadSPI_LUT3_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT3_PAD0. */
#define BS_QuadSPI_LUT3_PAD0 (2U)          /*!< Bit field size in bits for QuadSPI_LUT3_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT3_PAD0 field. */
#define BR_QuadSPI_LUT3_PAD0(x) (HW_QuadSPI_LUT3(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT3_PAD0. */
#define BF_QuadSPI_LUT3_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT3_PAD0) & BM_QuadSPI_LUT3_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT3_PAD0(x, v) (HW_QuadSPI_LUT3_WR(x, (HW_QuadSPI_LUT3_RD(x) & ~BM_QuadSPI_LUT3_PAD0) | BF_QuadSPI_LUT3_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT3, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT3_INSTR0 (10U)       /*!< Bit position for QuadSPI_LUT3_INSTR0. */
#define BM_QuadSPI_LUT3_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT3_INSTR0. */
#define BS_QuadSPI_LUT3_INSTR0 (6U)        /*!< Bit field size in bits for QuadSPI_LUT3_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT3_INSTR0 field. */
#define BR_QuadSPI_LUT3_INSTR0(x) (HW_QuadSPI_LUT3(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT3_INSTR0. */
#define BF_QuadSPI_LUT3_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT3_INSTR0) & BM_QuadSPI_LUT3_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT3_INSTR0(x, v) (HW_QuadSPI_LUT3_WR(x, (HW_QuadSPI_LUT3_RD(x) & ~BM_QuadSPI_LUT3_INSTR0) | BF_QuadSPI_LUT3_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT3, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT3_OPRND1 (16U)       /*!< Bit position for QuadSPI_LUT3_OPRND1. */
#define BM_QuadSPI_LUT3_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT3_OPRND1. */
#define BS_QuadSPI_LUT3_OPRND1 (8U)        /*!< Bit field size in bits for QuadSPI_LUT3_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT3_OPRND1 field. */
#define BR_QuadSPI_LUT3_OPRND1(x) (HW_QuadSPI_LUT3(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT3_OPRND1. */
#define BF_QuadSPI_LUT3_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT3_OPRND1) & BM_QuadSPI_LUT3_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT3_OPRND1(x, v) (HW_QuadSPI_LUT3_WR(x, (HW_QuadSPI_LUT3_RD(x) & ~BM_QuadSPI_LUT3_OPRND1) | BF_QuadSPI_LUT3_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT3, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT3_PAD1 (24U)         /*!< Bit position for QuadSPI_LUT3_PAD1. */
#define BM_QuadSPI_LUT3_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT3_PAD1. */
#define BS_QuadSPI_LUT3_PAD1 (2U)          /*!< Bit field size in bits for QuadSPI_LUT3_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT3_PAD1 field. */
#define BR_QuadSPI_LUT3_PAD1(x) (HW_QuadSPI_LUT3(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT3_PAD1. */
#define BF_QuadSPI_LUT3_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT3_PAD1) & BM_QuadSPI_LUT3_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT3_PAD1(x, v) (HW_QuadSPI_LUT3_WR(x, (HW_QuadSPI_LUT3_RD(x) & ~BM_QuadSPI_LUT3_PAD1) | BF_QuadSPI_LUT3_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT3, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT3_INSTR1 (26U)       /*!< Bit position for QuadSPI_LUT3_INSTR1. */
#define BM_QuadSPI_LUT3_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT3_INSTR1. */
#define BS_QuadSPI_LUT3_INSTR1 (6U)        /*!< Bit field size in bits for QuadSPI_LUT3_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT3_INSTR1 field. */
#define BR_QuadSPI_LUT3_INSTR1(x) (HW_QuadSPI_LUT3(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT3_INSTR1. */
#define BF_QuadSPI_LUT3_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT3_INSTR1) & BM_QuadSPI_LUT3_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT3_INSTR1(x, v) (HW_QuadSPI_LUT3_WR(x, (HW_QuadSPI_LUT3_RD(x) & ~BM_QuadSPI_LUT3_INSTR1) | BF_QuadSPI_LUT3_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT4 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT4 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut4
{
    uint32_t U;
    struct _hw_quadspi_lut4_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut4_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT4 register
 */
/*@{*/
#define HW_QuadSPI_LUT4_ADDR(x)  ((uintptr_t)(x) + 0x320U)

#define HW_QuadSPI_LUT4(x)       (*(__IO hw_quadspi_lut4_t *) HW_QuadSPI_LUT4_ADDR(x))
#define HW_QuadSPI_LUT4_RD(x)    (HW_QuadSPI_LUT4(x).U)
#define HW_QuadSPI_LUT4_WR(x, v) (HW_QuadSPI_LUT4(x).U = (v))
#define HW_QuadSPI_LUT4_SET(x, v) (HW_QuadSPI_LUT4_WR(x, HW_QuadSPI_LUT4_RD(x) |  (v)))
#define HW_QuadSPI_LUT4_CLR(x, v) (HW_QuadSPI_LUT4_WR(x, HW_QuadSPI_LUT4_RD(x) & ~(v)))
#define HW_QuadSPI_LUT4_TOG(x, v) (HW_QuadSPI_LUT4_WR(x, HW_QuadSPI_LUT4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT4 bitfields
 */

/*!
 * @name Register QuadSPI_LUT4, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT4_OPRND0 (0U)        /*!< Bit position for QuadSPI_LUT4_OPRND0. */
#define BM_QuadSPI_LUT4_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT4_OPRND0. */
#define BS_QuadSPI_LUT4_OPRND0 (8U)        /*!< Bit field size in bits for QuadSPI_LUT4_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT4_OPRND0 field. */
#define BR_QuadSPI_LUT4_OPRND0(x) (HW_QuadSPI_LUT4(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT4_OPRND0. */
#define BF_QuadSPI_LUT4_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT4_OPRND0) & BM_QuadSPI_LUT4_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT4_OPRND0(x, v) (HW_QuadSPI_LUT4_WR(x, (HW_QuadSPI_LUT4_RD(x) & ~BM_QuadSPI_LUT4_OPRND0) | BF_QuadSPI_LUT4_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT4, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT4_PAD0 (8U)          /*!< Bit position for QuadSPI_LUT4_PAD0. */
#define BM_QuadSPI_LUT4_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT4_PAD0. */
#define BS_QuadSPI_LUT4_PAD0 (2U)          /*!< Bit field size in bits for QuadSPI_LUT4_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT4_PAD0 field. */
#define BR_QuadSPI_LUT4_PAD0(x) (HW_QuadSPI_LUT4(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT4_PAD0. */
#define BF_QuadSPI_LUT4_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT4_PAD0) & BM_QuadSPI_LUT4_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT4_PAD0(x, v) (HW_QuadSPI_LUT4_WR(x, (HW_QuadSPI_LUT4_RD(x) & ~BM_QuadSPI_LUT4_PAD0) | BF_QuadSPI_LUT4_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT4, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT4_INSTR0 (10U)       /*!< Bit position for QuadSPI_LUT4_INSTR0. */
#define BM_QuadSPI_LUT4_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT4_INSTR0. */
#define BS_QuadSPI_LUT4_INSTR0 (6U)        /*!< Bit field size in bits for QuadSPI_LUT4_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT4_INSTR0 field. */
#define BR_QuadSPI_LUT4_INSTR0(x) (HW_QuadSPI_LUT4(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT4_INSTR0. */
#define BF_QuadSPI_LUT4_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT4_INSTR0) & BM_QuadSPI_LUT4_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT4_INSTR0(x, v) (HW_QuadSPI_LUT4_WR(x, (HW_QuadSPI_LUT4_RD(x) & ~BM_QuadSPI_LUT4_INSTR0) | BF_QuadSPI_LUT4_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT4, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT4_OPRND1 (16U)       /*!< Bit position for QuadSPI_LUT4_OPRND1. */
#define BM_QuadSPI_LUT4_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT4_OPRND1. */
#define BS_QuadSPI_LUT4_OPRND1 (8U)        /*!< Bit field size in bits for QuadSPI_LUT4_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT4_OPRND1 field. */
#define BR_QuadSPI_LUT4_OPRND1(x) (HW_QuadSPI_LUT4(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT4_OPRND1. */
#define BF_QuadSPI_LUT4_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT4_OPRND1) & BM_QuadSPI_LUT4_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT4_OPRND1(x, v) (HW_QuadSPI_LUT4_WR(x, (HW_QuadSPI_LUT4_RD(x) & ~BM_QuadSPI_LUT4_OPRND1) | BF_QuadSPI_LUT4_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT4, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT4_PAD1 (24U)         /*!< Bit position for QuadSPI_LUT4_PAD1. */
#define BM_QuadSPI_LUT4_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT4_PAD1. */
#define BS_QuadSPI_LUT4_PAD1 (2U)          /*!< Bit field size in bits for QuadSPI_LUT4_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT4_PAD1 field. */
#define BR_QuadSPI_LUT4_PAD1(x) (HW_QuadSPI_LUT4(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT4_PAD1. */
#define BF_QuadSPI_LUT4_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT4_PAD1) & BM_QuadSPI_LUT4_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT4_PAD1(x, v) (HW_QuadSPI_LUT4_WR(x, (HW_QuadSPI_LUT4_RD(x) & ~BM_QuadSPI_LUT4_PAD1) | BF_QuadSPI_LUT4_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT4, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT4_INSTR1 (26U)       /*!< Bit position for QuadSPI_LUT4_INSTR1. */
#define BM_QuadSPI_LUT4_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT4_INSTR1. */
#define BS_QuadSPI_LUT4_INSTR1 (6U)        /*!< Bit field size in bits for QuadSPI_LUT4_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT4_INSTR1 field. */
#define BR_QuadSPI_LUT4_INSTR1(x) (HW_QuadSPI_LUT4(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT4_INSTR1. */
#define BF_QuadSPI_LUT4_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT4_INSTR1) & BM_QuadSPI_LUT4_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT4_INSTR1(x, v) (HW_QuadSPI_LUT4_WR(x, (HW_QuadSPI_LUT4_RD(x) & ~BM_QuadSPI_LUT4_INSTR1) | BF_QuadSPI_LUT4_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT5 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT5 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut5
{
    uint32_t U;
    struct _hw_quadspi_lut5_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut5_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT5 register
 */
/*@{*/
#define HW_QuadSPI_LUT5_ADDR(x)  ((uintptr_t)(x) + 0x324U)

#define HW_QuadSPI_LUT5(x)       (*(__IO hw_quadspi_lut5_t *) HW_QuadSPI_LUT5_ADDR(x))
#define HW_QuadSPI_LUT5_RD(x)    (HW_QuadSPI_LUT5(x).U)
#define HW_QuadSPI_LUT5_WR(x, v) (HW_QuadSPI_LUT5(x).U = (v))
#define HW_QuadSPI_LUT5_SET(x, v) (HW_QuadSPI_LUT5_WR(x, HW_QuadSPI_LUT5_RD(x) |  (v)))
#define HW_QuadSPI_LUT5_CLR(x, v) (HW_QuadSPI_LUT5_WR(x, HW_QuadSPI_LUT5_RD(x) & ~(v)))
#define HW_QuadSPI_LUT5_TOG(x, v) (HW_QuadSPI_LUT5_WR(x, HW_QuadSPI_LUT5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT5 bitfields
 */

/*!
 * @name Register QuadSPI_LUT5, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT5_OPRND0 (0U)        /*!< Bit position for QuadSPI_LUT5_OPRND0. */
#define BM_QuadSPI_LUT5_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT5_OPRND0. */
#define BS_QuadSPI_LUT5_OPRND0 (8U)        /*!< Bit field size in bits for QuadSPI_LUT5_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT5_OPRND0 field. */
#define BR_QuadSPI_LUT5_OPRND0(x) (HW_QuadSPI_LUT5(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT5_OPRND0. */
#define BF_QuadSPI_LUT5_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT5_OPRND0) & BM_QuadSPI_LUT5_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT5_OPRND0(x, v) (HW_QuadSPI_LUT5_WR(x, (HW_QuadSPI_LUT5_RD(x) & ~BM_QuadSPI_LUT5_OPRND0) | BF_QuadSPI_LUT5_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT5, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT5_PAD0 (8U)          /*!< Bit position for QuadSPI_LUT5_PAD0. */
#define BM_QuadSPI_LUT5_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT5_PAD0. */
#define BS_QuadSPI_LUT5_PAD0 (2U)          /*!< Bit field size in bits for QuadSPI_LUT5_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT5_PAD0 field. */
#define BR_QuadSPI_LUT5_PAD0(x) (HW_QuadSPI_LUT5(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT5_PAD0. */
#define BF_QuadSPI_LUT5_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT5_PAD0) & BM_QuadSPI_LUT5_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT5_PAD0(x, v) (HW_QuadSPI_LUT5_WR(x, (HW_QuadSPI_LUT5_RD(x) & ~BM_QuadSPI_LUT5_PAD0) | BF_QuadSPI_LUT5_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT5, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT5_INSTR0 (10U)       /*!< Bit position for QuadSPI_LUT5_INSTR0. */
#define BM_QuadSPI_LUT5_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT5_INSTR0. */
#define BS_QuadSPI_LUT5_INSTR0 (6U)        /*!< Bit field size in bits for QuadSPI_LUT5_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT5_INSTR0 field. */
#define BR_QuadSPI_LUT5_INSTR0(x) (HW_QuadSPI_LUT5(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT5_INSTR0. */
#define BF_QuadSPI_LUT5_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT5_INSTR0) & BM_QuadSPI_LUT5_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT5_INSTR0(x, v) (HW_QuadSPI_LUT5_WR(x, (HW_QuadSPI_LUT5_RD(x) & ~BM_QuadSPI_LUT5_INSTR0) | BF_QuadSPI_LUT5_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT5, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT5_OPRND1 (16U)       /*!< Bit position for QuadSPI_LUT5_OPRND1. */
#define BM_QuadSPI_LUT5_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT5_OPRND1. */
#define BS_QuadSPI_LUT5_OPRND1 (8U)        /*!< Bit field size in bits for QuadSPI_LUT5_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT5_OPRND1 field. */
#define BR_QuadSPI_LUT5_OPRND1(x) (HW_QuadSPI_LUT5(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT5_OPRND1. */
#define BF_QuadSPI_LUT5_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT5_OPRND1) & BM_QuadSPI_LUT5_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT5_OPRND1(x, v) (HW_QuadSPI_LUT5_WR(x, (HW_QuadSPI_LUT5_RD(x) & ~BM_QuadSPI_LUT5_OPRND1) | BF_QuadSPI_LUT5_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT5, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT5_PAD1 (24U)         /*!< Bit position for QuadSPI_LUT5_PAD1. */
#define BM_QuadSPI_LUT5_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT5_PAD1. */
#define BS_QuadSPI_LUT5_PAD1 (2U)          /*!< Bit field size in bits for QuadSPI_LUT5_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT5_PAD1 field. */
#define BR_QuadSPI_LUT5_PAD1(x) (HW_QuadSPI_LUT5(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT5_PAD1. */
#define BF_QuadSPI_LUT5_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT5_PAD1) & BM_QuadSPI_LUT5_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT5_PAD1(x, v) (HW_QuadSPI_LUT5_WR(x, (HW_QuadSPI_LUT5_RD(x) & ~BM_QuadSPI_LUT5_PAD1) | BF_QuadSPI_LUT5_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT5, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT5_INSTR1 (26U)       /*!< Bit position for QuadSPI_LUT5_INSTR1. */
#define BM_QuadSPI_LUT5_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT5_INSTR1. */
#define BS_QuadSPI_LUT5_INSTR1 (6U)        /*!< Bit field size in bits for QuadSPI_LUT5_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT5_INSTR1 field. */
#define BR_QuadSPI_LUT5_INSTR1(x) (HW_QuadSPI_LUT5(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT5_INSTR1. */
#define BF_QuadSPI_LUT5_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT5_INSTR1) & BM_QuadSPI_LUT5_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT5_INSTR1(x, v) (HW_QuadSPI_LUT5_WR(x, (HW_QuadSPI_LUT5_RD(x) & ~BM_QuadSPI_LUT5_INSTR1) | BF_QuadSPI_LUT5_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT6 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT6 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut6
{
    uint32_t U;
    struct _hw_quadspi_lut6_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut6_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT6 register
 */
/*@{*/
#define HW_QuadSPI_LUT6_ADDR(x)  ((uintptr_t)(x) + 0x328U)

#define HW_QuadSPI_LUT6(x)       (*(__IO hw_quadspi_lut6_t *) HW_QuadSPI_LUT6_ADDR(x))
#define HW_QuadSPI_LUT6_RD(x)    (HW_QuadSPI_LUT6(x).U)
#define HW_QuadSPI_LUT6_WR(x, v) (HW_QuadSPI_LUT6(x).U = (v))
#define HW_QuadSPI_LUT6_SET(x, v) (HW_QuadSPI_LUT6_WR(x, HW_QuadSPI_LUT6_RD(x) |  (v)))
#define HW_QuadSPI_LUT6_CLR(x, v) (HW_QuadSPI_LUT6_WR(x, HW_QuadSPI_LUT6_RD(x) & ~(v)))
#define HW_QuadSPI_LUT6_TOG(x, v) (HW_QuadSPI_LUT6_WR(x, HW_QuadSPI_LUT6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT6 bitfields
 */

/*!
 * @name Register QuadSPI_LUT6, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT6_OPRND0 (0U)        /*!< Bit position for QuadSPI_LUT6_OPRND0. */
#define BM_QuadSPI_LUT6_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT6_OPRND0. */
#define BS_QuadSPI_LUT6_OPRND0 (8U)        /*!< Bit field size in bits for QuadSPI_LUT6_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT6_OPRND0 field. */
#define BR_QuadSPI_LUT6_OPRND0(x) (HW_QuadSPI_LUT6(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT6_OPRND0. */
#define BF_QuadSPI_LUT6_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT6_OPRND0) & BM_QuadSPI_LUT6_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT6_OPRND0(x, v) (HW_QuadSPI_LUT6_WR(x, (HW_QuadSPI_LUT6_RD(x) & ~BM_QuadSPI_LUT6_OPRND0) | BF_QuadSPI_LUT6_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT6, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT6_PAD0 (8U)          /*!< Bit position for QuadSPI_LUT6_PAD0. */
#define BM_QuadSPI_LUT6_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT6_PAD0. */
#define BS_QuadSPI_LUT6_PAD0 (2U)          /*!< Bit field size in bits for QuadSPI_LUT6_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT6_PAD0 field. */
#define BR_QuadSPI_LUT6_PAD0(x) (HW_QuadSPI_LUT6(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT6_PAD0. */
#define BF_QuadSPI_LUT6_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT6_PAD0) & BM_QuadSPI_LUT6_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT6_PAD0(x, v) (HW_QuadSPI_LUT6_WR(x, (HW_QuadSPI_LUT6_RD(x) & ~BM_QuadSPI_LUT6_PAD0) | BF_QuadSPI_LUT6_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT6, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT6_INSTR0 (10U)       /*!< Bit position for QuadSPI_LUT6_INSTR0. */
#define BM_QuadSPI_LUT6_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT6_INSTR0. */
#define BS_QuadSPI_LUT6_INSTR0 (6U)        /*!< Bit field size in bits for QuadSPI_LUT6_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT6_INSTR0 field. */
#define BR_QuadSPI_LUT6_INSTR0(x) (HW_QuadSPI_LUT6(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT6_INSTR0. */
#define BF_QuadSPI_LUT6_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT6_INSTR0) & BM_QuadSPI_LUT6_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT6_INSTR0(x, v) (HW_QuadSPI_LUT6_WR(x, (HW_QuadSPI_LUT6_RD(x) & ~BM_QuadSPI_LUT6_INSTR0) | BF_QuadSPI_LUT6_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT6, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT6_OPRND1 (16U)       /*!< Bit position for QuadSPI_LUT6_OPRND1. */
#define BM_QuadSPI_LUT6_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT6_OPRND1. */
#define BS_QuadSPI_LUT6_OPRND1 (8U)        /*!< Bit field size in bits for QuadSPI_LUT6_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT6_OPRND1 field. */
#define BR_QuadSPI_LUT6_OPRND1(x) (HW_QuadSPI_LUT6(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT6_OPRND1. */
#define BF_QuadSPI_LUT6_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT6_OPRND1) & BM_QuadSPI_LUT6_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT6_OPRND1(x, v) (HW_QuadSPI_LUT6_WR(x, (HW_QuadSPI_LUT6_RD(x) & ~BM_QuadSPI_LUT6_OPRND1) | BF_QuadSPI_LUT6_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT6, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT6_PAD1 (24U)         /*!< Bit position for QuadSPI_LUT6_PAD1. */
#define BM_QuadSPI_LUT6_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT6_PAD1. */
#define BS_QuadSPI_LUT6_PAD1 (2U)          /*!< Bit field size in bits for QuadSPI_LUT6_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT6_PAD1 field. */
#define BR_QuadSPI_LUT6_PAD1(x) (HW_QuadSPI_LUT6(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT6_PAD1. */
#define BF_QuadSPI_LUT6_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT6_PAD1) & BM_QuadSPI_LUT6_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT6_PAD1(x, v) (HW_QuadSPI_LUT6_WR(x, (HW_QuadSPI_LUT6_RD(x) & ~BM_QuadSPI_LUT6_PAD1) | BF_QuadSPI_LUT6_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT6, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT6_INSTR1 (26U)       /*!< Bit position for QuadSPI_LUT6_INSTR1. */
#define BM_QuadSPI_LUT6_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT6_INSTR1. */
#define BS_QuadSPI_LUT6_INSTR1 (6U)        /*!< Bit field size in bits for QuadSPI_LUT6_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT6_INSTR1 field. */
#define BR_QuadSPI_LUT6_INSTR1(x) (HW_QuadSPI_LUT6(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT6_INSTR1. */
#define BF_QuadSPI_LUT6_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT6_INSTR1) & BM_QuadSPI_LUT6_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT6_INSTR1(x, v) (HW_QuadSPI_LUT6_WR(x, (HW_QuadSPI_LUT6_RD(x) & ~BM_QuadSPI_LUT6_INSTR1) | BF_QuadSPI_LUT6_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT7 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT7 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut7
{
    uint32_t U;
    struct _hw_quadspi_lut7_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut7_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT7 register
 */
/*@{*/
#define HW_QuadSPI_LUT7_ADDR(x)  ((uintptr_t)(x) + 0x32CU)

#define HW_QuadSPI_LUT7(x)       (*(__IO hw_quadspi_lut7_t *) HW_QuadSPI_LUT7_ADDR(x))
#define HW_QuadSPI_LUT7_RD(x)    (HW_QuadSPI_LUT7(x).U)
#define HW_QuadSPI_LUT7_WR(x, v) (HW_QuadSPI_LUT7(x).U = (v))
#define HW_QuadSPI_LUT7_SET(x, v) (HW_QuadSPI_LUT7_WR(x, HW_QuadSPI_LUT7_RD(x) |  (v)))
#define HW_QuadSPI_LUT7_CLR(x, v) (HW_QuadSPI_LUT7_WR(x, HW_QuadSPI_LUT7_RD(x) & ~(v)))
#define HW_QuadSPI_LUT7_TOG(x, v) (HW_QuadSPI_LUT7_WR(x, HW_QuadSPI_LUT7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT7 bitfields
 */

/*!
 * @name Register QuadSPI_LUT7, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT7_OPRND0 (0U)        /*!< Bit position for QuadSPI_LUT7_OPRND0. */
#define BM_QuadSPI_LUT7_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT7_OPRND0. */
#define BS_QuadSPI_LUT7_OPRND0 (8U)        /*!< Bit field size in bits for QuadSPI_LUT7_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT7_OPRND0 field. */
#define BR_QuadSPI_LUT7_OPRND0(x) (HW_QuadSPI_LUT7(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT7_OPRND0. */
#define BF_QuadSPI_LUT7_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT7_OPRND0) & BM_QuadSPI_LUT7_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT7_OPRND0(x, v) (HW_QuadSPI_LUT7_WR(x, (HW_QuadSPI_LUT7_RD(x) & ~BM_QuadSPI_LUT7_OPRND0) | BF_QuadSPI_LUT7_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT7, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT7_PAD0 (8U)          /*!< Bit position for QuadSPI_LUT7_PAD0. */
#define BM_QuadSPI_LUT7_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT7_PAD0. */
#define BS_QuadSPI_LUT7_PAD0 (2U)          /*!< Bit field size in bits for QuadSPI_LUT7_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT7_PAD0 field. */
#define BR_QuadSPI_LUT7_PAD0(x) (HW_QuadSPI_LUT7(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT7_PAD0. */
#define BF_QuadSPI_LUT7_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT7_PAD0) & BM_QuadSPI_LUT7_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT7_PAD0(x, v) (HW_QuadSPI_LUT7_WR(x, (HW_QuadSPI_LUT7_RD(x) & ~BM_QuadSPI_LUT7_PAD0) | BF_QuadSPI_LUT7_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT7, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT7_INSTR0 (10U)       /*!< Bit position for QuadSPI_LUT7_INSTR0. */
#define BM_QuadSPI_LUT7_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT7_INSTR0. */
#define BS_QuadSPI_LUT7_INSTR0 (6U)        /*!< Bit field size in bits for QuadSPI_LUT7_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT7_INSTR0 field. */
#define BR_QuadSPI_LUT7_INSTR0(x) (HW_QuadSPI_LUT7(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT7_INSTR0. */
#define BF_QuadSPI_LUT7_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT7_INSTR0) & BM_QuadSPI_LUT7_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT7_INSTR0(x, v) (HW_QuadSPI_LUT7_WR(x, (HW_QuadSPI_LUT7_RD(x) & ~BM_QuadSPI_LUT7_INSTR0) | BF_QuadSPI_LUT7_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT7, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT7_OPRND1 (16U)       /*!< Bit position for QuadSPI_LUT7_OPRND1. */
#define BM_QuadSPI_LUT7_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT7_OPRND1. */
#define BS_QuadSPI_LUT7_OPRND1 (8U)        /*!< Bit field size in bits for QuadSPI_LUT7_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT7_OPRND1 field. */
#define BR_QuadSPI_LUT7_OPRND1(x) (HW_QuadSPI_LUT7(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT7_OPRND1. */
#define BF_QuadSPI_LUT7_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT7_OPRND1) & BM_QuadSPI_LUT7_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT7_OPRND1(x, v) (HW_QuadSPI_LUT7_WR(x, (HW_QuadSPI_LUT7_RD(x) & ~BM_QuadSPI_LUT7_OPRND1) | BF_QuadSPI_LUT7_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT7, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT7_PAD1 (24U)         /*!< Bit position for QuadSPI_LUT7_PAD1. */
#define BM_QuadSPI_LUT7_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT7_PAD1. */
#define BS_QuadSPI_LUT7_PAD1 (2U)          /*!< Bit field size in bits for QuadSPI_LUT7_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT7_PAD1 field. */
#define BR_QuadSPI_LUT7_PAD1(x) (HW_QuadSPI_LUT7(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT7_PAD1. */
#define BF_QuadSPI_LUT7_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT7_PAD1) & BM_QuadSPI_LUT7_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT7_PAD1(x, v) (HW_QuadSPI_LUT7_WR(x, (HW_QuadSPI_LUT7_RD(x) & ~BM_QuadSPI_LUT7_PAD1) | BF_QuadSPI_LUT7_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT7, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT7_INSTR1 (26U)       /*!< Bit position for QuadSPI_LUT7_INSTR1. */
#define BM_QuadSPI_LUT7_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT7_INSTR1. */
#define BS_QuadSPI_LUT7_INSTR1 (6U)        /*!< Bit field size in bits for QuadSPI_LUT7_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT7_INSTR1 field. */
#define BR_QuadSPI_LUT7_INSTR1(x) (HW_QuadSPI_LUT7(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT7_INSTR1. */
#define BF_QuadSPI_LUT7_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT7_INSTR1) & BM_QuadSPI_LUT7_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT7_INSTR1(x, v) (HW_QuadSPI_LUT7_WR(x, (HW_QuadSPI_LUT7_RD(x) & ~BM_QuadSPI_LUT7_INSTR1) | BF_QuadSPI_LUT7_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT8 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT8 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut8
{
    uint32_t U;
    struct _hw_quadspi_lut8_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut8_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT8 register
 */
/*@{*/
#define HW_QuadSPI_LUT8_ADDR(x)  ((uintptr_t)(x) + 0x330U)

#define HW_QuadSPI_LUT8(x)       (*(__IO hw_quadspi_lut8_t *) HW_QuadSPI_LUT8_ADDR(x))
#define HW_QuadSPI_LUT8_RD(x)    (HW_QuadSPI_LUT8(x).U)
#define HW_QuadSPI_LUT8_WR(x, v) (HW_QuadSPI_LUT8(x).U = (v))
#define HW_QuadSPI_LUT8_SET(x, v) (HW_QuadSPI_LUT8_WR(x, HW_QuadSPI_LUT8_RD(x) |  (v)))
#define HW_QuadSPI_LUT8_CLR(x, v) (HW_QuadSPI_LUT8_WR(x, HW_QuadSPI_LUT8_RD(x) & ~(v)))
#define HW_QuadSPI_LUT8_TOG(x, v) (HW_QuadSPI_LUT8_WR(x, HW_QuadSPI_LUT8_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT8 bitfields
 */

/*!
 * @name Register QuadSPI_LUT8, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT8_OPRND0 (0U)        /*!< Bit position for QuadSPI_LUT8_OPRND0. */
#define BM_QuadSPI_LUT8_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT8_OPRND0. */
#define BS_QuadSPI_LUT8_OPRND0 (8U)        /*!< Bit field size in bits for QuadSPI_LUT8_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT8_OPRND0 field. */
#define BR_QuadSPI_LUT8_OPRND0(x) (HW_QuadSPI_LUT8(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT8_OPRND0. */
#define BF_QuadSPI_LUT8_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT8_OPRND0) & BM_QuadSPI_LUT8_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT8_OPRND0(x, v) (HW_QuadSPI_LUT8_WR(x, (HW_QuadSPI_LUT8_RD(x) & ~BM_QuadSPI_LUT8_OPRND0) | BF_QuadSPI_LUT8_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT8, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT8_PAD0 (8U)          /*!< Bit position for QuadSPI_LUT8_PAD0. */
#define BM_QuadSPI_LUT8_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT8_PAD0. */
#define BS_QuadSPI_LUT8_PAD0 (2U)          /*!< Bit field size in bits for QuadSPI_LUT8_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT8_PAD0 field. */
#define BR_QuadSPI_LUT8_PAD0(x) (HW_QuadSPI_LUT8(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT8_PAD0. */
#define BF_QuadSPI_LUT8_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT8_PAD0) & BM_QuadSPI_LUT8_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT8_PAD0(x, v) (HW_QuadSPI_LUT8_WR(x, (HW_QuadSPI_LUT8_RD(x) & ~BM_QuadSPI_LUT8_PAD0) | BF_QuadSPI_LUT8_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT8, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT8_INSTR0 (10U)       /*!< Bit position for QuadSPI_LUT8_INSTR0. */
#define BM_QuadSPI_LUT8_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT8_INSTR0. */
#define BS_QuadSPI_LUT8_INSTR0 (6U)        /*!< Bit field size in bits for QuadSPI_LUT8_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT8_INSTR0 field. */
#define BR_QuadSPI_LUT8_INSTR0(x) (HW_QuadSPI_LUT8(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT8_INSTR0. */
#define BF_QuadSPI_LUT8_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT8_INSTR0) & BM_QuadSPI_LUT8_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT8_INSTR0(x, v) (HW_QuadSPI_LUT8_WR(x, (HW_QuadSPI_LUT8_RD(x) & ~BM_QuadSPI_LUT8_INSTR0) | BF_QuadSPI_LUT8_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT8, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT8_OPRND1 (16U)       /*!< Bit position for QuadSPI_LUT8_OPRND1. */
#define BM_QuadSPI_LUT8_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT8_OPRND1. */
#define BS_QuadSPI_LUT8_OPRND1 (8U)        /*!< Bit field size in bits for QuadSPI_LUT8_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT8_OPRND1 field. */
#define BR_QuadSPI_LUT8_OPRND1(x) (HW_QuadSPI_LUT8(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT8_OPRND1. */
#define BF_QuadSPI_LUT8_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT8_OPRND1) & BM_QuadSPI_LUT8_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT8_OPRND1(x, v) (HW_QuadSPI_LUT8_WR(x, (HW_QuadSPI_LUT8_RD(x) & ~BM_QuadSPI_LUT8_OPRND1) | BF_QuadSPI_LUT8_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT8, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT8_PAD1 (24U)         /*!< Bit position for QuadSPI_LUT8_PAD1. */
#define BM_QuadSPI_LUT8_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT8_PAD1. */
#define BS_QuadSPI_LUT8_PAD1 (2U)          /*!< Bit field size in bits for QuadSPI_LUT8_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT8_PAD1 field. */
#define BR_QuadSPI_LUT8_PAD1(x) (HW_QuadSPI_LUT8(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT8_PAD1. */
#define BF_QuadSPI_LUT8_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT8_PAD1) & BM_QuadSPI_LUT8_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT8_PAD1(x, v) (HW_QuadSPI_LUT8_WR(x, (HW_QuadSPI_LUT8_RD(x) & ~BM_QuadSPI_LUT8_PAD1) | BF_QuadSPI_LUT8_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT8, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT8_INSTR1 (26U)       /*!< Bit position for QuadSPI_LUT8_INSTR1. */
#define BM_QuadSPI_LUT8_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT8_INSTR1. */
#define BS_QuadSPI_LUT8_INSTR1 (6U)        /*!< Bit field size in bits for QuadSPI_LUT8_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT8_INSTR1 field. */
#define BR_QuadSPI_LUT8_INSTR1(x) (HW_QuadSPI_LUT8(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT8_INSTR1. */
#define BF_QuadSPI_LUT8_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT8_INSTR1) & BM_QuadSPI_LUT8_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT8_INSTR1(x, v) (HW_QuadSPI_LUT8_WR(x, (HW_QuadSPI_LUT8_RD(x) & ~BM_QuadSPI_LUT8_INSTR1) | BF_QuadSPI_LUT8_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT9 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT9 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut9
{
    uint32_t U;
    struct _hw_quadspi_lut9_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut9_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT9 register
 */
/*@{*/
#define HW_QuadSPI_LUT9_ADDR(x)  ((uintptr_t)(x) + 0x334U)

#define HW_QuadSPI_LUT9(x)       (*(__IO hw_quadspi_lut9_t *) HW_QuadSPI_LUT9_ADDR(x))
#define HW_QuadSPI_LUT9_RD(x)    (HW_QuadSPI_LUT9(x).U)
#define HW_QuadSPI_LUT9_WR(x, v) (HW_QuadSPI_LUT9(x).U = (v))
#define HW_QuadSPI_LUT9_SET(x, v) (HW_QuadSPI_LUT9_WR(x, HW_QuadSPI_LUT9_RD(x) |  (v)))
#define HW_QuadSPI_LUT9_CLR(x, v) (HW_QuadSPI_LUT9_WR(x, HW_QuadSPI_LUT9_RD(x) & ~(v)))
#define HW_QuadSPI_LUT9_TOG(x, v) (HW_QuadSPI_LUT9_WR(x, HW_QuadSPI_LUT9_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT9 bitfields
 */

/*!
 * @name Register QuadSPI_LUT9, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT9_OPRND0 (0U)        /*!< Bit position for QuadSPI_LUT9_OPRND0. */
#define BM_QuadSPI_LUT9_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT9_OPRND0. */
#define BS_QuadSPI_LUT9_OPRND0 (8U)        /*!< Bit field size in bits for QuadSPI_LUT9_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT9_OPRND0 field. */
#define BR_QuadSPI_LUT9_OPRND0(x) (HW_QuadSPI_LUT9(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT9_OPRND0. */
#define BF_QuadSPI_LUT9_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT9_OPRND0) & BM_QuadSPI_LUT9_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT9_OPRND0(x, v) (HW_QuadSPI_LUT9_WR(x, (HW_QuadSPI_LUT9_RD(x) & ~BM_QuadSPI_LUT9_OPRND0) | BF_QuadSPI_LUT9_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT9, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT9_PAD0 (8U)          /*!< Bit position for QuadSPI_LUT9_PAD0. */
#define BM_QuadSPI_LUT9_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT9_PAD0. */
#define BS_QuadSPI_LUT9_PAD0 (2U)          /*!< Bit field size in bits for QuadSPI_LUT9_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT9_PAD0 field. */
#define BR_QuadSPI_LUT9_PAD0(x) (HW_QuadSPI_LUT9(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT9_PAD0. */
#define BF_QuadSPI_LUT9_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT9_PAD0) & BM_QuadSPI_LUT9_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT9_PAD0(x, v) (HW_QuadSPI_LUT9_WR(x, (HW_QuadSPI_LUT9_RD(x) & ~BM_QuadSPI_LUT9_PAD0) | BF_QuadSPI_LUT9_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT9, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT9_INSTR0 (10U)       /*!< Bit position for QuadSPI_LUT9_INSTR0. */
#define BM_QuadSPI_LUT9_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT9_INSTR0. */
#define BS_QuadSPI_LUT9_INSTR0 (6U)        /*!< Bit field size in bits for QuadSPI_LUT9_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT9_INSTR0 field. */
#define BR_QuadSPI_LUT9_INSTR0(x) (HW_QuadSPI_LUT9(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT9_INSTR0. */
#define BF_QuadSPI_LUT9_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT9_INSTR0) & BM_QuadSPI_LUT9_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT9_INSTR0(x, v) (HW_QuadSPI_LUT9_WR(x, (HW_QuadSPI_LUT9_RD(x) & ~BM_QuadSPI_LUT9_INSTR0) | BF_QuadSPI_LUT9_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT9, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT9_OPRND1 (16U)       /*!< Bit position for QuadSPI_LUT9_OPRND1. */
#define BM_QuadSPI_LUT9_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT9_OPRND1. */
#define BS_QuadSPI_LUT9_OPRND1 (8U)        /*!< Bit field size in bits for QuadSPI_LUT9_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT9_OPRND1 field. */
#define BR_QuadSPI_LUT9_OPRND1(x) (HW_QuadSPI_LUT9(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT9_OPRND1. */
#define BF_QuadSPI_LUT9_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT9_OPRND1) & BM_QuadSPI_LUT9_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT9_OPRND1(x, v) (HW_QuadSPI_LUT9_WR(x, (HW_QuadSPI_LUT9_RD(x) & ~BM_QuadSPI_LUT9_OPRND1) | BF_QuadSPI_LUT9_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT9, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT9_PAD1 (24U)         /*!< Bit position for QuadSPI_LUT9_PAD1. */
#define BM_QuadSPI_LUT9_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT9_PAD1. */
#define BS_QuadSPI_LUT9_PAD1 (2U)          /*!< Bit field size in bits for QuadSPI_LUT9_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT9_PAD1 field. */
#define BR_QuadSPI_LUT9_PAD1(x) (HW_QuadSPI_LUT9(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT9_PAD1. */
#define BF_QuadSPI_LUT9_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT9_PAD1) & BM_QuadSPI_LUT9_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT9_PAD1(x, v) (HW_QuadSPI_LUT9_WR(x, (HW_QuadSPI_LUT9_RD(x) & ~BM_QuadSPI_LUT9_PAD1) | BF_QuadSPI_LUT9_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT9, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT9_INSTR1 (26U)       /*!< Bit position for QuadSPI_LUT9_INSTR1. */
#define BM_QuadSPI_LUT9_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT9_INSTR1. */
#define BS_QuadSPI_LUT9_INSTR1 (6U)        /*!< Bit field size in bits for QuadSPI_LUT9_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT9_INSTR1 field. */
#define BR_QuadSPI_LUT9_INSTR1(x) (HW_QuadSPI_LUT9(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT9_INSTR1. */
#define BF_QuadSPI_LUT9_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT9_INSTR1) & BM_QuadSPI_LUT9_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT9_INSTR1(x, v) (HW_QuadSPI_LUT9_WR(x, (HW_QuadSPI_LUT9_RD(x) & ~BM_QuadSPI_LUT9_INSTR1) | BF_QuadSPI_LUT9_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT10 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT10 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut10
{
    uint32_t U;
    struct _hw_quadspi_lut10_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut10_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT10 register
 */
/*@{*/
#define HW_QuadSPI_LUT10_ADDR(x) ((uintptr_t)(x) + 0x338U)

#define HW_QuadSPI_LUT10(x)      (*(__IO hw_quadspi_lut10_t *) HW_QuadSPI_LUT10_ADDR(x))
#define HW_QuadSPI_LUT10_RD(x)   (HW_QuadSPI_LUT10(x).U)
#define HW_QuadSPI_LUT10_WR(x, v) (HW_QuadSPI_LUT10(x).U = (v))
#define HW_QuadSPI_LUT10_SET(x, v) (HW_QuadSPI_LUT10_WR(x, HW_QuadSPI_LUT10_RD(x) |  (v)))
#define HW_QuadSPI_LUT10_CLR(x, v) (HW_QuadSPI_LUT10_WR(x, HW_QuadSPI_LUT10_RD(x) & ~(v)))
#define HW_QuadSPI_LUT10_TOG(x, v) (HW_QuadSPI_LUT10_WR(x, HW_QuadSPI_LUT10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT10 bitfields
 */

/*!
 * @name Register QuadSPI_LUT10, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT10_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT10_OPRND0. */
#define BM_QuadSPI_LUT10_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT10_OPRND0. */
#define BS_QuadSPI_LUT10_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT10_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT10_OPRND0 field. */
#define BR_QuadSPI_LUT10_OPRND0(x) (HW_QuadSPI_LUT10(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT10_OPRND0. */
#define BF_QuadSPI_LUT10_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT10_OPRND0) & BM_QuadSPI_LUT10_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT10_OPRND0(x, v) (HW_QuadSPI_LUT10_WR(x, (HW_QuadSPI_LUT10_RD(x) & ~BM_QuadSPI_LUT10_OPRND0) | BF_QuadSPI_LUT10_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT10, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT10_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT10_PAD0. */
#define BM_QuadSPI_LUT10_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT10_PAD0. */
#define BS_QuadSPI_LUT10_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT10_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT10_PAD0 field. */
#define BR_QuadSPI_LUT10_PAD0(x) (HW_QuadSPI_LUT10(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT10_PAD0. */
#define BF_QuadSPI_LUT10_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT10_PAD0) & BM_QuadSPI_LUT10_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT10_PAD0(x, v) (HW_QuadSPI_LUT10_WR(x, (HW_QuadSPI_LUT10_RD(x) & ~BM_QuadSPI_LUT10_PAD0) | BF_QuadSPI_LUT10_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT10, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT10_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT10_INSTR0. */
#define BM_QuadSPI_LUT10_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT10_INSTR0. */
#define BS_QuadSPI_LUT10_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT10_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT10_INSTR0 field. */
#define BR_QuadSPI_LUT10_INSTR0(x) (HW_QuadSPI_LUT10(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT10_INSTR0. */
#define BF_QuadSPI_LUT10_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT10_INSTR0) & BM_QuadSPI_LUT10_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT10_INSTR0(x, v) (HW_QuadSPI_LUT10_WR(x, (HW_QuadSPI_LUT10_RD(x) & ~BM_QuadSPI_LUT10_INSTR0) | BF_QuadSPI_LUT10_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT10, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT10_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT10_OPRND1. */
#define BM_QuadSPI_LUT10_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT10_OPRND1. */
#define BS_QuadSPI_LUT10_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT10_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT10_OPRND1 field. */
#define BR_QuadSPI_LUT10_OPRND1(x) (HW_QuadSPI_LUT10(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT10_OPRND1. */
#define BF_QuadSPI_LUT10_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT10_OPRND1) & BM_QuadSPI_LUT10_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT10_OPRND1(x, v) (HW_QuadSPI_LUT10_WR(x, (HW_QuadSPI_LUT10_RD(x) & ~BM_QuadSPI_LUT10_OPRND1) | BF_QuadSPI_LUT10_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT10, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT10_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT10_PAD1. */
#define BM_QuadSPI_LUT10_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT10_PAD1. */
#define BS_QuadSPI_LUT10_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT10_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT10_PAD1 field. */
#define BR_QuadSPI_LUT10_PAD1(x) (HW_QuadSPI_LUT10(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT10_PAD1. */
#define BF_QuadSPI_LUT10_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT10_PAD1) & BM_QuadSPI_LUT10_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT10_PAD1(x, v) (HW_QuadSPI_LUT10_WR(x, (HW_QuadSPI_LUT10_RD(x) & ~BM_QuadSPI_LUT10_PAD1) | BF_QuadSPI_LUT10_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT10, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT10_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT10_INSTR1. */
#define BM_QuadSPI_LUT10_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT10_INSTR1. */
#define BS_QuadSPI_LUT10_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT10_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT10_INSTR1 field. */
#define BR_QuadSPI_LUT10_INSTR1(x) (HW_QuadSPI_LUT10(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT10_INSTR1. */
#define BF_QuadSPI_LUT10_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT10_INSTR1) & BM_QuadSPI_LUT10_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT10_INSTR1(x, v) (HW_QuadSPI_LUT10_WR(x, (HW_QuadSPI_LUT10_RD(x) & ~BM_QuadSPI_LUT10_INSTR1) | BF_QuadSPI_LUT10_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT11 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT11 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut11
{
    uint32_t U;
    struct _hw_quadspi_lut11_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut11_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT11 register
 */
/*@{*/
#define HW_QuadSPI_LUT11_ADDR(x) ((uintptr_t)(x) + 0x33CU)

#define HW_QuadSPI_LUT11(x)      (*(__IO hw_quadspi_lut11_t *) HW_QuadSPI_LUT11_ADDR(x))
#define HW_QuadSPI_LUT11_RD(x)   (HW_QuadSPI_LUT11(x).U)
#define HW_QuadSPI_LUT11_WR(x, v) (HW_QuadSPI_LUT11(x).U = (v))
#define HW_QuadSPI_LUT11_SET(x, v) (HW_QuadSPI_LUT11_WR(x, HW_QuadSPI_LUT11_RD(x) |  (v)))
#define HW_QuadSPI_LUT11_CLR(x, v) (HW_QuadSPI_LUT11_WR(x, HW_QuadSPI_LUT11_RD(x) & ~(v)))
#define HW_QuadSPI_LUT11_TOG(x, v) (HW_QuadSPI_LUT11_WR(x, HW_QuadSPI_LUT11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT11 bitfields
 */

/*!
 * @name Register QuadSPI_LUT11, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT11_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT11_OPRND0. */
#define BM_QuadSPI_LUT11_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT11_OPRND0. */
#define BS_QuadSPI_LUT11_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT11_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT11_OPRND0 field. */
#define BR_QuadSPI_LUT11_OPRND0(x) (HW_QuadSPI_LUT11(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT11_OPRND0. */
#define BF_QuadSPI_LUT11_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT11_OPRND0) & BM_QuadSPI_LUT11_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT11_OPRND0(x, v) (HW_QuadSPI_LUT11_WR(x, (HW_QuadSPI_LUT11_RD(x) & ~BM_QuadSPI_LUT11_OPRND0) | BF_QuadSPI_LUT11_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT11, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT11_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT11_PAD0. */
#define BM_QuadSPI_LUT11_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT11_PAD0. */
#define BS_QuadSPI_LUT11_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT11_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT11_PAD0 field. */
#define BR_QuadSPI_LUT11_PAD0(x) (HW_QuadSPI_LUT11(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT11_PAD0. */
#define BF_QuadSPI_LUT11_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT11_PAD0) & BM_QuadSPI_LUT11_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT11_PAD0(x, v) (HW_QuadSPI_LUT11_WR(x, (HW_QuadSPI_LUT11_RD(x) & ~BM_QuadSPI_LUT11_PAD0) | BF_QuadSPI_LUT11_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT11, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT11_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT11_INSTR0. */
#define BM_QuadSPI_LUT11_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT11_INSTR0. */
#define BS_QuadSPI_LUT11_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT11_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT11_INSTR0 field. */
#define BR_QuadSPI_LUT11_INSTR0(x) (HW_QuadSPI_LUT11(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT11_INSTR0. */
#define BF_QuadSPI_LUT11_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT11_INSTR0) & BM_QuadSPI_LUT11_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT11_INSTR0(x, v) (HW_QuadSPI_LUT11_WR(x, (HW_QuadSPI_LUT11_RD(x) & ~BM_QuadSPI_LUT11_INSTR0) | BF_QuadSPI_LUT11_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT11, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT11_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT11_OPRND1. */
#define BM_QuadSPI_LUT11_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT11_OPRND1. */
#define BS_QuadSPI_LUT11_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT11_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT11_OPRND1 field. */
#define BR_QuadSPI_LUT11_OPRND1(x) (HW_QuadSPI_LUT11(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT11_OPRND1. */
#define BF_QuadSPI_LUT11_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT11_OPRND1) & BM_QuadSPI_LUT11_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT11_OPRND1(x, v) (HW_QuadSPI_LUT11_WR(x, (HW_QuadSPI_LUT11_RD(x) & ~BM_QuadSPI_LUT11_OPRND1) | BF_QuadSPI_LUT11_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT11, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT11_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT11_PAD1. */
#define BM_QuadSPI_LUT11_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT11_PAD1. */
#define BS_QuadSPI_LUT11_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT11_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT11_PAD1 field. */
#define BR_QuadSPI_LUT11_PAD1(x) (HW_QuadSPI_LUT11(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT11_PAD1. */
#define BF_QuadSPI_LUT11_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT11_PAD1) & BM_QuadSPI_LUT11_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT11_PAD1(x, v) (HW_QuadSPI_LUT11_WR(x, (HW_QuadSPI_LUT11_RD(x) & ~BM_QuadSPI_LUT11_PAD1) | BF_QuadSPI_LUT11_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT11, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT11_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT11_INSTR1. */
#define BM_QuadSPI_LUT11_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT11_INSTR1. */
#define BS_QuadSPI_LUT11_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT11_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT11_INSTR1 field. */
#define BR_QuadSPI_LUT11_INSTR1(x) (HW_QuadSPI_LUT11(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT11_INSTR1. */
#define BF_QuadSPI_LUT11_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT11_INSTR1) & BM_QuadSPI_LUT11_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT11_INSTR1(x, v) (HW_QuadSPI_LUT11_WR(x, (HW_QuadSPI_LUT11_RD(x) & ~BM_QuadSPI_LUT11_INSTR1) | BF_QuadSPI_LUT11_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT12 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT12 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut12
{
    uint32_t U;
    struct _hw_quadspi_lut12_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut12_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT12 register
 */
/*@{*/
#define HW_QuadSPI_LUT12_ADDR(x) ((uintptr_t)(x) + 0x340U)

#define HW_QuadSPI_LUT12(x)      (*(__IO hw_quadspi_lut12_t *) HW_QuadSPI_LUT12_ADDR(x))
#define HW_QuadSPI_LUT12_RD(x)   (HW_QuadSPI_LUT12(x).U)
#define HW_QuadSPI_LUT12_WR(x, v) (HW_QuadSPI_LUT12(x).U = (v))
#define HW_QuadSPI_LUT12_SET(x, v) (HW_QuadSPI_LUT12_WR(x, HW_QuadSPI_LUT12_RD(x) |  (v)))
#define HW_QuadSPI_LUT12_CLR(x, v) (HW_QuadSPI_LUT12_WR(x, HW_QuadSPI_LUT12_RD(x) & ~(v)))
#define HW_QuadSPI_LUT12_TOG(x, v) (HW_QuadSPI_LUT12_WR(x, HW_QuadSPI_LUT12_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT12 bitfields
 */

/*!
 * @name Register QuadSPI_LUT12, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT12_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT12_OPRND0. */
#define BM_QuadSPI_LUT12_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT12_OPRND0. */
#define BS_QuadSPI_LUT12_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT12_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT12_OPRND0 field. */
#define BR_QuadSPI_LUT12_OPRND0(x) (HW_QuadSPI_LUT12(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT12_OPRND0. */
#define BF_QuadSPI_LUT12_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT12_OPRND0) & BM_QuadSPI_LUT12_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT12_OPRND0(x, v) (HW_QuadSPI_LUT12_WR(x, (HW_QuadSPI_LUT12_RD(x) & ~BM_QuadSPI_LUT12_OPRND0) | BF_QuadSPI_LUT12_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT12, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT12_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT12_PAD0. */
#define BM_QuadSPI_LUT12_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT12_PAD0. */
#define BS_QuadSPI_LUT12_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT12_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT12_PAD0 field. */
#define BR_QuadSPI_LUT12_PAD0(x) (HW_QuadSPI_LUT12(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT12_PAD0. */
#define BF_QuadSPI_LUT12_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT12_PAD0) & BM_QuadSPI_LUT12_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT12_PAD0(x, v) (HW_QuadSPI_LUT12_WR(x, (HW_QuadSPI_LUT12_RD(x) & ~BM_QuadSPI_LUT12_PAD0) | BF_QuadSPI_LUT12_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT12, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT12_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT12_INSTR0. */
#define BM_QuadSPI_LUT12_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT12_INSTR0. */
#define BS_QuadSPI_LUT12_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT12_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT12_INSTR0 field. */
#define BR_QuadSPI_LUT12_INSTR0(x) (HW_QuadSPI_LUT12(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT12_INSTR0. */
#define BF_QuadSPI_LUT12_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT12_INSTR0) & BM_QuadSPI_LUT12_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT12_INSTR0(x, v) (HW_QuadSPI_LUT12_WR(x, (HW_QuadSPI_LUT12_RD(x) & ~BM_QuadSPI_LUT12_INSTR0) | BF_QuadSPI_LUT12_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT12, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT12_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT12_OPRND1. */
#define BM_QuadSPI_LUT12_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT12_OPRND1. */
#define BS_QuadSPI_LUT12_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT12_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT12_OPRND1 field. */
#define BR_QuadSPI_LUT12_OPRND1(x) (HW_QuadSPI_LUT12(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT12_OPRND1. */
#define BF_QuadSPI_LUT12_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT12_OPRND1) & BM_QuadSPI_LUT12_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT12_OPRND1(x, v) (HW_QuadSPI_LUT12_WR(x, (HW_QuadSPI_LUT12_RD(x) & ~BM_QuadSPI_LUT12_OPRND1) | BF_QuadSPI_LUT12_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT12, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT12_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT12_PAD1. */
#define BM_QuadSPI_LUT12_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT12_PAD1. */
#define BS_QuadSPI_LUT12_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT12_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT12_PAD1 field. */
#define BR_QuadSPI_LUT12_PAD1(x) (HW_QuadSPI_LUT12(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT12_PAD1. */
#define BF_QuadSPI_LUT12_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT12_PAD1) & BM_QuadSPI_LUT12_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT12_PAD1(x, v) (HW_QuadSPI_LUT12_WR(x, (HW_QuadSPI_LUT12_RD(x) & ~BM_QuadSPI_LUT12_PAD1) | BF_QuadSPI_LUT12_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT12, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT12_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT12_INSTR1. */
#define BM_QuadSPI_LUT12_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT12_INSTR1. */
#define BS_QuadSPI_LUT12_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT12_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT12_INSTR1 field. */
#define BR_QuadSPI_LUT12_INSTR1(x) (HW_QuadSPI_LUT12(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT12_INSTR1. */
#define BF_QuadSPI_LUT12_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT12_INSTR1) & BM_QuadSPI_LUT12_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT12_INSTR1(x, v) (HW_QuadSPI_LUT12_WR(x, (HW_QuadSPI_LUT12_RD(x) & ~BM_QuadSPI_LUT12_INSTR1) | BF_QuadSPI_LUT12_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT13 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT13 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut13
{
    uint32_t U;
    struct _hw_quadspi_lut13_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut13_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT13 register
 */
/*@{*/
#define HW_QuadSPI_LUT13_ADDR(x) ((uintptr_t)(x) + 0x344U)

#define HW_QuadSPI_LUT13(x)      (*(__IO hw_quadspi_lut13_t *) HW_QuadSPI_LUT13_ADDR(x))
#define HW_QuadSPI_LUT13_RD(x)   (HW_QuadSPI_LUT13(x).U)
#define HW_QuadSPI_LUT13_WR(x, v) (HW_QuadSPI_LUT13(x).U = (v))
#define HW_QuadSPI_LUT13_SET(x, v) (HW_QuadSPI_LUT13_WR(x, HW_QuadSPI_LUT13_RD(x) |  (v)))
#define HW_QuadSPI_LUT13_CLR(x, v) (HW_QuadSPI_LUT13_WR(x, HW_QuadSPI_LUT13_RD(x) & ~(v)))
#define HW_QuadSPI_LUT13_TOG(x, v) (HW_QuadSPI_LUT13_WR(x, HW_QuadSPI_LUT13_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT13 bitfields
 */

/*!
 * @name Register QuadSPI_LUT13, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT13_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT13_OPRND0. */
#define BM_QuadSPI_LUT13_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT13_OPRND0. */
#define BS_QuadSPI_LUT13_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT13_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT13_OPRND0 field. */
#define BR_QuadSPI_LUT13_OPRND0(x) (HW_QuadSPI_LUT13(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT13_OPRND0. */
#define BF_QuadSPI_LUT13_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT13_OPRND0) & BM_QuadSPI_LUT13_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT13_OPRND0(x, v) (HW_QuadSPI_LUT13_WR(x, (HW_QuadSPI_LUT13_RD(x) & ~BM_QuadSPI_LUT13_OPRND0) | BF_QuadSPI_LUT13_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT13, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT13_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT13_PAD0. */
#define BM_QuadSPI_LUT13_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT13_PAD0. */
#define BS_QuadSPI_LUT13_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT13_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT13_PAD0 field. */
#define BR_QuadSPI_LUT13_PAD0(x) (HW_QuadSPI_LUT13(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT13_PAD0. */
#define BF_QuadSPI_LUT13_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT13_PAD0) & BM_QuadSPI_LUT13_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT13_PAD0(x, v) (HW_QuadSPI_LUT13_WR(x, (HW_QuadSPI_LUT13_RD(x) & ~BM_QuadSPI_LUT13_PAD0) | BF_QuadSPI_LUT13_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT13, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT13_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT13_INSTR0. */
#define BM_QuadSPI_LUT13_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT13_INSTR0. */
#define BS_QuadSPI_LUT13_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT13_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT13_INSTR0 field. */
#define BR_QuadSPI_LUT13_INSTR0(x) (HW_QuadSPI_LUT13(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT13_INSTR0. */
#define BF_QuadSPI_LUT13_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT13_INSTR0) & BM_QuadSPI_LUT13_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT13_INSTR0(x, v) (HW_QuadSPI_LUT13_WR(x, (HW_QuadSPI_LUT13_RD(x) & ~BM_QuadSPI_LUT13_INSTR0) | BF_QuadSPI_LUT13_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT13, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT13_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT13_OPRND1. */
#define BM_QuadSPI_LUT13_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT13_OPRND1. */
#define BS_QuadSPI_LUT13_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT13_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT13_OPRND1 field. */
#define BR_QuadSPI_LUT13_OPRND1(x) (HW_QuadSPI_LUT13(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT13_OPRND1. */
#define BF_QuadSPI_LUT13_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT13_OPRND1) & BM_QuadSPI_LUT13_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT13_OPRND1(x, v) (HW_QuadSPI_LUT13_WR(x, (HW_QuadSPI_LUT13_RD(x) & ~BM_QuadSPI_LUT13_OPRND1) | BF_QuadSPI_LUT13_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT13, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT13_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT13_PAD1. */
#define BM_QuadSPI_LUT13_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT13_PAD1. */
#define BS_QuadSPI_LUT13_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT13_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT13_PAD1 field. */
#define BR_QuadSPI_LUT13_PAD1(x) (HW_QuadSPI_LUT13(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT13_PAD1. */
#define BF_QuadSPI_LUT13_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT13_PAD1) & BM_QuadSPI_LUT13_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT13_PAD1(x, v) (HW_QuadSPI_LUT13_WR(x, (HW_QuadSPI_LUT13_RD(x) & ~BM_QuadSPI_LUT13_PAD1) | BF_QuadSPI_LUT13_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT13, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT13_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT13_INSTR1. */
#define BM_QuadSPI_LUT13_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT13_INSTR1. */
#define BS_QuadSPI_LUT13_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT13_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT13_INSTR1 field. */
#define BR_QuadSPI_LUT13_INSTR1(x) (HW_QuadSPI_LUT13(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT13_INSTR1. */
#define BF_QuadSPI_LUT13_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT13_INSTR1) & BM_QuadSPI_LUT13_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT13_INSTR1(x, v) (HW_QuadSPI_LUT13_WR(x, (HW_QuadSPI_LUT13_RD(x) & ~BM_QuadSPI_LUT13_INSTR1) | BF_QuadSPI_LUT13_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT14 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT14 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut14
{
    uint32_t U;
    struct _hw_quadspi_lut14_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut14_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT14 register
 */
/*@{*/
#define HW_QuadSPI_LUT14_ADDR(x) ((uintptr_t)(x) + 0x348U)

#define HW_QuadSPI_LUT14(x)      (*(__IO hw_quadspi_lut14_t *) HW_QuadSPI_LUT14_ADDR(x))
#define HW_QuadSPI_LUT14_RD(x)   (HW_QuadSPI_LUT14(x).U)
#define HW_QuadSPI_LUT14_WR(x, v) (HW_QuadSPI_LUT14(x).U = (v))
#define HW_QuadSPI_LUT14_SET(x, v) (HW_QuadSPI_LUT14_WR(x, HW_QuadSPI_LUT14_RD(x) |  (v)))
#define HW_QuadSPI_LUT14_CLR(x, v) (HW_QuadSPI_LUT14_WR(x, HW_QuadSPI_LUT14_RD(x) & ~(v)))
#define HW_QuadSPI_LUT14_TOG(x, v) (HW_QuadSPI_LUT14_WR(x, HW_QuadSPI_LUT14_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT14 bitfields
 */

/*!
 * @name Register QuadSPI_LUT14, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT14_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT14_OPRND0. */
#define BM_QuadSPI_LUT14_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT14_OPRND0. */
#define BS_QuadSPI_LUT14_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT14_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT14_OPRND0 field. */
#define BR_QuadSPI_LUT14_OPRND0(x) (HW_QuadSPI_LUT14(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT14_OPRND0. */
#define BF_QuadSPI_LUT14_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT14_OPRND0) & BM_QuadSPI_LUT14_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT14_OPRND0(x, v) (HW_QuadSPI_LUT14_WR(x, (HW_QuadSPI_LUT14_RD(x) & ~BM_QuadSPI_LUT14_OPRND0) | BF_QuadSPI_LUT14_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT14, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT14_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT14_PAD0. */
#define BM_QuadSPI_LUT14_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT14_PAD0. */
#define BS_QuadSPI_LUT14_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT14_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT14_PAD0 field. */
#define BR_QuadSPI_LUT14_PAD0(x) (HW_QuadSPI_LUT14(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT14_PAD0. */
#define BF_QuadSPI_LUT14_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT14_PAD0) & BM_QuadSPI_LUT14_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT14_PAD0(x, v) (HW_QuadSPI_LUT14_WR(x, (HW_QuadSPI_LUT14_RD(x) & ~BM_QuadSPI_LUT14_PAD0) | BF_QuadSPI_LUT14_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT14, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT14_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT14_INSTR0. */
#define BM_QuadSPI_LUT14_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT14_INSTR0. */
#define BS_QuadSPI_LUT14_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT14_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT14_INSTR0 field. */
#define BR_QuadSPI_LUT14_INSTR0(x) (HW_QuadSPI_LUT14(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT14_INSTR0. */
#define BF_QuadSPI_LUT14_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT14_INSTR0) & BM_QuadSPI_LUT14_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT14_INSTR0(x, v) (HW_QuadSPI_LUT14_WR(x, (HW_QuadSPI_LUT14_RD(x) & ~BM_QuadSPI_LUT14_INSTR0) | BF_QuadSPI_LUT14_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT14, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT14_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT14_OPRND1. */
#define BM_QuadSPI_LUT14_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT14_OPRND1. */
#define BS_QuadSPI_LUT14_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT14_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT14_OPRND1 field. */
#define BR_QuadSPI_LUT14_OPRND1(x) (HW_QuadSPI_LUT14(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT14_OPRND1. */
#define BF_QuadSPI_LUT14_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT14_OPRND1) & BM_QuadSPI_LUT14_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT14_OPRND1(x, v) (HW_QuadSPI_LUT14_WR(x, (HW_QuadSPI_LUT14_RD(x) & ~BM_QuadSPI_LUT14_OPRND1) | BF_QuadSPI_LUT14_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT14, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT14_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT14_PAD1. */
#define BM_QuadSPI_LUT14_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT14_PAD1. */
#define BS_QuadSPI_LUT14_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT14_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT14_PAD1 field. */
#define BR_QuadSPI_LUT14_PAD1(x) (HW_QuadSPI_LUT14(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT14_PAD1. */
#define BF_QuadSPI_LUT14_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT14_PAD1) & BM_QuadSPI_LUT14_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT14_PAD1(x, v) (HW_QuadSPI_LUT14_WR(x, (HW_QuadSPI_LUT14_RD(x) & ~BM_QuadSPI_LUT14_PAD1) | BF_QuadSPI_LUT14_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT14, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT14_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT14_INSTR1. */
#define BM_QuadSPI_LUT14_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT14_INSTR1. */
#define BS_QuadSPI_LUT14_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT14_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT14_INSTR1 field. */
#define BR_QuadSPI_LUT14_INSTR1(x) (HW_QuadSPI_LUT14(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT14_INSTR1. */
#define BF_QuadSPI_LUT14_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT14_INSTR1) & BM_QuadSPI_LUT14_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT14_INSTR1(x, v) (HW_QuadSPI_LUT14_WR(x, (HW_QuadSPI_LUT14_RD(x) & ~BM_QuadSPI_LUT14_INSTR1) | BF_QuadSPI_LUT14_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT15 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT15 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut15
{
    uint32_t U;
    struct _hw_quadspi_lut15_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut15_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT15 register
 */
/*@{*/
#define HW_QuadSPI_LUT15_ADDR(x) ((uintptr_t)(x) + 0x34CU)

#define HW_QuadSPI_LUT15(x)      (*(__IO hw_quadspi_lut15_t *) HW_QuadSPI_LUT15_ADDR(x))
#define HW_QuadSPI_LUT15_RD(x)   (HW_QuadSPI_LUT15(x).U)
#define HW_QuadSPI_LUT15_WR(x, v) (HW_QuadSPI_LUT15(x).U = (v))
#define HW_QuadSPI_LUT15_SET(x, v) (HW_QuadSPI_LUT15_WR(x, HW_QuadSPI_LUT15_RD(x) |  (v)))
#define HW_QuadSPI_LUT15_CLR(x, v) (HW_QuadSPI_LUT15_WR(x, HW_QuadSPI_LUT15_RD(x) & ~(v)))
#define HW_QuadSPI_LUT15_TOG(x, v) (HW_QuadSPI_LUT15_WR(x, HW_QuadSPI_LUT15_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT15 bitfields
 */

/*!
 * @name Register QuadSPI_LUT15, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT15_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT15_OPRND0. */
#define BM_QuadSPI_LUT15_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT15_OPRND0. */
#define BS_QuadSPI_LUT15_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT15_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT15_OPRND0 field. */
#define BR_QuadSPI_LUT15_OPRND0(x) (HW_QuadSPI_LUT15(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT15_OPRND0. */
#define BF_QuadSPI_LUT15_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT15_OPRND0) & BM_QuadSPI_LUT15_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT15_OPRND0(x, v) (HW_QuadSPI_LUT15_WR(x, (HW_QuadSPI_LUT15_RD(x) & ~BM_QuadSPI_LUT15_OPRND0) | BF_QuadSPI_LUT15_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT15, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT15_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT15_PAD0. */
#define BM_QuadSPI_LUT15_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT15_PAD0. */
#define BS_QuadSPI_LUT15_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT15_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT15_PAD0 field. */
#define BR_QuadSPI_LUT15_PAD0(x) (HW_QuadSPI_LUT15(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT15_PAD0. */
#define BF_QuadSPI_LUT15_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT15_PAD0) & BM_QuadSPI_LUT15_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT15_PAD0(x, v) (HW_QuadSPI_LUT15_WR(x, (HW_QuadSPI_LUT15_RD(x) & ~BM_QuadSPI_LUT15_PAD0) | BF_QuadSPI_LUT15_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT15, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT15_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT15_INSTR0. */
#define BM_QuadSPI_LUT15_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT15_INSTR0. */
#define BS_QuadSPI_LUT15_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT15_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT15_INSTR0 field. */
#define BR_QuadSPI_LUT15_INSTR0(x) (HW_QuadSPI_LUT15(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT15_INSTR0. */
#define BF_QuadSPI_LUT15_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT15_INSTR0) & BM_QuadSPI_LUT15_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT15_INSTR0(x, v) (HW_QuadSPI_LUT15_WR(x, (HW_QuadSPI_LUT15_RD(x) & ~BM_QuadSPI_LUT15_INSTR0) | BF_QuadSPI_LUT15_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT15, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT15_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT15_OPRND1. */
#define BM_QuadSPI_LUT15_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT15_OPRND1. */
#define BS_QuadSPI_LUT15_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT15_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT15_OPRND1 field. */
#define BR_QuadSPI_LUT15_OPRND1(x) (HW_QuadSPI_LUT15(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT15_OPRND1. */
#define BF_QuadSPI_LUT15_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT15_OPRND1) & BM_QuadSPI_LUT15_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT15_OPRND1(x, v) (HW_QuadSPI_LUT15_WR(x, (HW_QuadSPI_LUT15_RD(x) & ~BM_QuadSPI_LUT15_OPRND1) | BF_QuadSPI_LUT15_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT15, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT15_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT15_PAD1. */
#define BM_QuadSPI_LUT15_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT15_PAD1. */
#define BS_QuadSPI_LUT15_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT15_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT15_PAD1 field. */
#define BR_QuadSPI_LUT15_PAD1(x) (HW_QuadSPI_LUT15(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT15_PAD1. */
#define BF_QuadSPI_LUT15_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT15_PAD1) & BM_QuadSPI_LUT15_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT15_PAD1(x, v) (HW_QuadSPI_LUT15_WR(x, (HW_QuadSPI_LUT15_RD(x) & ~BM_QuadSPI_LUT15_PAD1) | BF_QuadSPI_LUT15_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT15, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT15_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT15_INSTR1. */
#define BM_QuadSPI_LUT15_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT15_INSTR1. */
#define BS_QuadSPI_LUT15_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT15_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT15_INSTR1 field. */
#define BR_QuadSPI_LUT15_INSTR1(x) (HW_QuadSPI_LUT15(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT15_INSTR1. */
#define BF_QuadSPI_LUT15_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT15_INSTR1) & BM_QuadSPI_LUT15_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT15_INSTR1(x, v) (HW_QuadSPI_LUT15_WR(x, (HW_QuadSPI_LUT15_RD(x) & ~BM_QuadSPI_LUT15_INSTR1) | BF_QuadSPI_LUT15_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT16 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT16 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut16
{
    uint32_t U;
    struct _hw_quadspi_lut16_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut16_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT16 register
 */
/*@{*/
#define HW_QuadSPI_LUT16_ADDR(x) ((uintptr_t)(x) + 0x350U)

#define HW_QuadSPI_LUT16(x)      (*(__IO hw_quadspi_lut16_t *) HW_QuadSPI_LUT16_ADDR(x))
#define HW_QuadSPI_LUT16_RD(x)   (HW_QuadSPI_LUT16(x).U)
#define HW_QuadSPI_LUT16_WR(x, v) (HW_QuadSPI_LUT16(x).U = (v))
#define HW_QuadSPI_LUT16_SET(x, v) (HW_QuadSPI_LUT16_WR(x, HW_QuadSPI_LUT16_RD(x) |  (v)))
#define HW_QuadSPI_LUT16_CLR(x, v) (HW_QuadSPI_LUT16_WR(x, HW_QuadSPI_LUT16_RD(x) & ~(v)))
#define HW_QuadSPI_LUT16_TOG(x, v) (HW_QuadSPI_LUT16_WR(x, HW_QuadSPI_LUT16_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT16 bitfields
 */

/*!
 * @name Register QuadSPI_LUT16, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT16_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT16_OPRND0. */
#define BM_QuadSPI_LUT16_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT16_OPRND0. */
#define BS_QuadSPI_LUT16_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT16_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT16_OPRND0 field. */
#define BR_QuadSPI_LUT16_OPRND0(x) (HW_QuadSPI_LUT16(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT16_OPRND0. */
#define BF_QuadSPI_LUT16_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT16_OPRND0) & BM_QuadSPI_LUT16_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT16_OPRND0(x, v) (HW_QuadSPI_LUT16_WR(x, (HW_QuadSPI_LUT16_RD(x) & ~BM_QuadSPI_LUT16_OPRND0) | BF_QuadSPI_LUT16_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT16, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT16_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT16_PAD0. */
#define BM_QuadSPI_LUT16_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT16_PAD0. */
#define BS_QuadSPI_LUT16_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT16_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT16_PAD0 field. */
#define BR_QuadSPI_LUT16_PAD0(x) (HW_QuadSPI_LUT16(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT16_PAD0. */
#define BF_QuadSPI_LUT16_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT16_PAD0) & BM_QuadSPI_LUT16_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT16_PAD0(x, v) (HW_QuadSPI_LUT16_WR(x, (HW_QuadSPI_LUT16_RD(x) & ~BM_QuadSPI_LUT16_PAD0) | BF_QuadSPI_LUT16_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT16, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT16_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT16_INSTR0. */
#define BM_QuadSPI_LUT16_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT16_INSTR0. */
#define BS_QuadSPI_LUT16_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT16_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT16_INSTR0 field. */
#define BR_QuadSPI_LUT16_INSTR0(x) (HW_QuadSPI_LUT16(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT16_INSTR0. */
#define BF_QuadSPI_LUT16_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT16_INSTR0) & BM_QuadSPI_LUT16_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT16_INSTR0(x, v) (HW_QuadSPI_LUT16_WR(x, (HW_QuadSPI_LUT16_RD(x) & ~BM_QuadSPI_LUT16_INSTR0) | BF_QuadSPI_LUT16_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT16, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT16_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT16_OPRND1. */
#define BM_QuadSPI_LUT16_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT16_OPRND1. */
#define BS_QuadSPI_LUT16_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT16_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT16_OPRND1 field. */
#define BR_QuadSPI_LUT16_OPRND1(x) (HW_QuadSPI_LUT16(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT16_OPRND1. */
#define BF_QuadSPI_LUT16_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT16_OPRND1) & BM_QuadSPI_LUT16_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT16_OPRND1(x, v) (HW_QuadSPI_LUT16_WR(x, (HW_QuadSPI_LUT16_RD(x) & ~BM_QuadSPI_LUT16_OPRND1) | BF_QuadSPI_LUT16_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT16, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT16_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT16_PAD1. */
#define BM_QuadSPI_LUT16_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT16_PAD1. */
#define BS_QuadSPI_LUT16_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT16_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT16_PAD1 field. */
#define BR_QuadSPI_LUT16_PAD1(x) (HW_QuadSPI_LUT16(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT16_PAD1. */
#define BF_QuadSPI_LUT16_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT16_PAD1) & BM_QuadSPI_LUT16_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT16_PAD1(x, v) (HW_QuadSPI_LUT16_WR(x, (HW_QuadSPI_LUT16_RD(x) & ~BM_QuadSPI_LUT16_PAD1) | BF_QuadSPI_LUT16_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT16, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT16_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT16_INSTR1. */
#define BM_QuadSPI_LUT16_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT16_INSTR1. */
#define BS_QuadSPI_LUT16_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT16_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT16_INSTR1 field. */
#define BR_QuadSPI_LUT16_INSTR1(x) (HW_QuadSPI_LUT16(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT16_INSTR1. */
#define BF_QuadSPI_LUT16_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT16_INSTR1) & BM_QuadSPI_LUT16_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT16_INSTR1(x, v) (HW_QuadSPI_LUT16_WR(x, (HW_QuadSPI_LUT16_RD(x) & ~BM_QuadSPI_LUT16_INSTR1) | BF_QuadSPI_LUT16_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT17 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT17 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut17
{
    uint32_t U;
    struct _hw_quadspi_lut17_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut17_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT17 register
 */
/*@{*/
#define HW_QuadSPI_LUT17_ADDR(x) ((uintptr_t)(x) + 0x354U)

#define HW_QuadSPI_LUT17(x)      (*(__IO hw_quadspi_lut17_t *) HW_QuadSPI_LUT17_ADDR(x))
#define HW_QuadSPI_LUT17_RD(x)   (HW_QuadSPI_LUT17(x).U)
#define HW_QuadSPI_LUT17_WR(x, v) (HW_QuadSPI_LUT17(x).U = (v))
#define HW_QuadSPI_LUT17_SET(x, v) (HW_QuadSPI_LUT17_WR(x, HW_QuadSPI_LUT17_RD(x) |  (v)))
#define HW_QuadSPI_LUT17_CLR(x, v) (HW_QuadSPI_LUT17_WR(x, HW_QuadSPI_LUT17_RD(x) & ~(v)))
#define HW_QuadSPI_LUT17_TOG(x, v) (HW_QuadSPI_LUT17_WR(x, HW_QuadSPI_LUT17_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT17 bitfields
 */

/*!
 * @name Register QuadSPI_LUT17, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT17_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT17_OPRND0. */
#define BM_QuadSPI_LUT17_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT17_OPRND0. */
#define BS_QuadSPI_LUT17_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT17_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT17_OPRND0 field. */
#define BR_QuadSPI_LUT17_OPRND0(x) (HW_QuadSPI_LUT17(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT17_OPRND0. */
#define BF_QuadSPI_LUT17_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT17_OPRND0) & BM_QuadSPI_LUT17_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT17_OPRND0(x, v) (HW_QuadSPI_LUT17_WR(x, (HW_QuadSPI_LUT17_RD(x) & ~BM_QuadSPI_LUT17_OPRND0) | BF_QuadSPI_LUT17_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT17, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT17_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT17_PAD0. */
#define BM_QuadSPI_LUT17_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT17_PAD0. */
#define BS_QuadSPI_LUT17_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT17_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT17_PAD0 field. */
#define BR_QuadSPI_LUT17_PAD0(x) (HW_QuadSPI_LUT17(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT17_PAD0. */
#define BF_QuadSPI_LUT17_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT17_PAD0) & BM_QuadSPI_LUT17_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT17_PAD0(x, v) (HW_QuadSPI_LUT17_WR(x, (HW_QuadSPI_LUT17_RD(x) & ~BM_QuadSPI_LUT17_PAD0) | BF_QuadSPI_LUT17_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT17, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT17_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT17_INSTR0. */
#define BM_QuadSPI_LUT17_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT17_INSTR0. */
#define BS_QuadSPI_LUT17_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT17_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT17_INSTR0 field. */
#define BR_QuadSPI_LUT17_INSTR0(x) (HW_QuadSPI_LUT17(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT17_INSTR0. */
#define BF_QuadSPI_LUT17_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT17_INSTR0) & BM_QuadSPI_LUT17_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT17_INSTR0(x, v) (HW_QuadSPI_LUT17_WR(x, (HW_QuadSPI_LUT17_RD(x) & ~BM_QuadSPI_LUT17_INSTR0) | BF_QuadSPI_LUT17_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT17, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT17_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT17_OPRND1. */
#define BM_QuadSPI_LUT17_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT17_OPRND1. */
#define BS_QuadSPI_LUT17_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT17_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT17_OPRND1 field. */
#define BR_QuadSPI_LUT17_OPRND1(x) (HW_QuadSPI_LUT17(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT17_OPRND1. */
#define BF_QuadSPI_LUT17_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT17_OPRND1) & BM_QuadSPI_LUT17_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT17_OPRND1(x, v) (HW_QuadSPI_LUT17_WR(x, (HW_QuadSPI_LUT17_RD(x) & ~BM_QuadSPI_LUT17_OPRND1) | BF_QuadSPI_LUT17_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT17, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT17_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT17_PAD1. */
#define BM_QuadSPI_LUT17_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT17_PAD1. */
#define BS_QuadSPI_LUT17_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT17_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT17_PAD1 field. */
#define BR_QuadSPI_LUT17_PAD1(x) (HW_QuadSPI_LUT17(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT17_PAD1. */
#define BF_QuadSPI_LUT17_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT17_PAD1) & BM_QuadSPI_LUT17_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT17_PAD1(x, v) (HW_QuadSPI_LUT17_WR(x, (HW_QuadSPI_LUT17_RD(x) & ~BM_QuadSPI_LUT17_PAD1) | BF_QuadSPI_LUT17_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT17, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT17_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT17_INSTR1. */
#define BM_QuadSPI_LUT17_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT17_INSTR1. */
#define BS_QuadSPI_LUT17_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT17_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT17_INSTR1 field. */
#define BR_QuadSPI_LUT17_INSTR1(x) (HW_QuadSPI_LUT17(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT17_INSTR1. */
#define BF_QuadSPI_LUT17_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT17_INSTR1) & BM_QuadSPI_LUT17_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT17_INSTR1(x, v) (HW_QuadSPI_LUT17_WR(x, (HW_QuadSPI_LUT17_RD(x) & ~BM_QuadSPI_LUT17_INSTR1) | BF_QuadSPI_LUT17_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT18 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT18 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut18
{
    uint32_t U;
    struct _hw_quadspi_lut18_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut18_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT18 register
 */
/*@{*/
#define HW_QuadSPI_LUT18_ADDR(x) ((uintptr_t)(x) + 0x358U)

#define HW_QuadSPI_LUT18(x)      (*(__IO hw_quadspi_lut18_t *) HW_QuadSPI_LUT18_ADDR(x))
#define HW_QuadSPI_LUT18_RD(x)   (HW_QuadSPI_LUT18(x).U)
#define HW_QuadSPI_LUT18_WR(x, v) (HW_QuadSPI_LUT18(x).U = (v))
#define HW_QuadSPI_LUT18_SET(x, v) (HW_QuadSPI_LUT18_WR(x, HW_QuadSPI_LUT18_RD(x) |  (v)))
#define HW_QuadSPI_LUT18_CLR(x, v) (HW_QuadSPI_LUT18_WR(x, HW_QuadSPI_LUT18_RD(x) & ~(v)))
#define HW_QuadSPI_LUT18_TOG(x, v) (HW_QuadSPI_LUT18_WR(x, HW_QuadSPI_LUT18_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT18 bitfields
 */

/*!
 * @name Register QuadSPI_LUT18, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT18_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT18_OPRND0. */
#define BM_QuadSPI_LUT18_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT18_OPRND0. */
#define BS_QuadSPI_LUT18_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT18_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT18_OPRND0 field. */
#define BR_QuadSPI_LUT18_OPRND0(x) (HW_QuadSPI_LUT18(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT18_OPRND0. */
#define BF_QuadSPI_LUT18_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT18_OPRND0) & BM_QuadSPI_LUT18_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT18_OPRND0(x, v) (HW_QuadSPI_LUT18_WR(x, (HW_QuadSPI_LUT18_RD(x) & ~BM_QuadSPI_LUT18_OPRND0) | BF_QuadSPI_LUT18_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT18, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT18_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT18_PAD0. */
#define BM_QuadSPI_LUT18_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT18_PAD0. */
#define BS_QuadSPI_LUT18_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT18_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT18_PAD0 field. */
#define BR_QuadSPI_LUT18_PAD0(x) (HW_QuadSPI_LUT18(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT18_PAD0. */
#define BF_QuadSPI_LUT18_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT18_PAD0) & BM_QuadSPI_LUT18_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT18_PAD0(x, v) (HW_QuadSPI_LUT18_WR(x, (HW_QuadSPI_LUT18_RD(x) & ~BM_QuadSPI_LUT18_PAD0) | BF_QuadSPI_LUT18_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT18, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT18_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT18_INSTR0. */
#define BM_QuadSPI_LUT18_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT18_INSTR0. */
#define BS_QuadSPI_LUT18_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT18_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT18_INSTR0 field. */
#define BR_QuadSPI_LUT18_INSTR0(x) (HW_QuadSPI_LUT18(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT18_INSTR0. */
#define BF_QuadSPI_LUT18_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT18_INSTR0) & BM_QuadSPI_LUT18_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT18_INSTR0(x, v) (HW_QuadSPI_LUT18_WR(x, (HW_QuadSPI_LUT18_RD(x) & ~BM_QuadSPI_LUT18_INSTR0) | BF_QuadSPI_LUT18_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT18, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT18_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT18_OPRND1. */
#define BM_QuadSPI_LUT18_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT18_OPRND1. */
#define BS_QuadSPI_LUT18_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT18_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT18_OPRND1 field. */
#define BR_QuadSPI_LUT18_OPRND1(x) (HW_QuadSPI_LUT18(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT18_OPRND1. */
#define BF_QuadSPI_LUT18_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT18_OPRND1) & BM_QuadSPI_LUT18_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT18_OPRND1(x, v) (HW_QuadSPI_LUT18_WR(x, (HW_QuadSPI_LUT18_RD(x) & ~BM_QuadSPI_LUT18_OPRND1) | BF_QuadSPI_LUT18_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT18, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT18_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT18_PAD1. */
#define BM_QuadSPI_LUT18_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT18_PAD1. */
#define BS_QuadSPI_LUT18_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT18_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT18_PAD1 field. */
#define BR_QuadSPI_LUT18_PAD1(x) (HW_QuadSPI_LUT18(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT18_PAD1. */
#define BF_QuadSPI_LUT18_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT18_PAD1) & BM_QuadSPI_LUT18_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT18_PAD1(x, v) (HW_QuadSPI_LUT18_WR(x, (HW_QuadSPI_LUT18_RD(x) & ~BM_QuadSPI_LUT18_PAD1) | BF_QuadSPI_LUT18_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT18, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT18_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT18_INSTR1. */
#define BM_QuadSPI_LUT18_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT18_INSTR1. */
#define BS_QuadSPI_LUT18_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT18_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT18_INSTR1 field. */
#define BR_QuadSPI_LUT18_INSTR1(x) (HW_QuadSPI_LUT18(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT18_INSTR1. */
#define BF_QuadSPI_LUT18_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT18_INSTR1) & BM_QuadSPI_LUT18_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT18_INSTR1(x, v) (HW_QuadSPI_LUT18_WR(x, (HW_QuadSPI_LUT18_RD(x) & ~BM_QuadSPI_LUT18_INSTR1) | BF_QuadSPI_LUT18_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT19 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT19 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut19
{
    uint32_t U;
    struct _hw_quadspi_lut19_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut19_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT19 register
 */
/*@{*/
#define HW_QuadSPI_LUT19_ADDR(x) ((uintptr_t)(x) + 0x35CU)

#define HW_QuadSPI_LUT19(x)      (*(__IO hw_quadspi_lut19_t *) HW_QuadSPI_LUT19_ADDR(x))
#define HW_QuadSPI_LUT19_RD(x)   (HW_QuadSPI_LUT19(x).U)
#define HW_QuadSPI_LUT19_WR(x, v) (HW_QuadSPI_LUT19(x).U = (v))
#define HW_QuadSPI_LUT19_SET(x, v) (HW_QuadSPI_LUT19_WR(x, HW_QuadSPI_LUT19_RD(x) |  (v)))
#define HW_QuadSPI_LUT19_CLR(x, v) (HW_QuadSPI_LUT19_WR(x, HW_QuadSPI_LUT19_RD(x) & ~(v)))
#define HW_QuadSPI_LUT19_TOG(x, v) (HW_QuadSPI_LUT19_WR(x, HW_QuadSPI_LUT19_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT19 bitfields
 */

/*!
 * @name Register QuadSPI_LUT19, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT19_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT19_OPRND0. */
#define BM_QuadSPI_LUT19_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT19_OPRND0. */
#define BS_QuadSPI_LUT19_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT19_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT19_OPRND0 field. */
#define BR_QuadSPI_LUT19_OPRND0(x) (HW_QuadSPI_LUT19(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT19_OPRND0. */
#define BF_QuadSPI_LUT19_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT19_OPRND0) & BM_QuadSPI_LUT19_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT19_OPRND0(x, v) (HW_QuadSPI_LUT19_WR(x, (HW_QuadSPI_LUT19_RD(x) & ~BM_QuadSPI_LUT19_OPRND0) | BF_QuadSPI_LUT19_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT19, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT19_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT19_PAD0. */
#define BM_QuadSPI_LUT19_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT19_PAD0. */
#define BS_QuadSPI_LUT19_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT19_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT19_PAD0 field. */
#define BR_QuadSPI_LUT19_PAD0(x) (HW_QuadSPI_LUT19(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT19_PAD0. */
#define BF_QuadSPI_LUT19_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT19_PAD0) & BM_QuadSPI_LUT19_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT19_PAD0(x, v) (HW_QuadSPI_LUT19_WR(x, (HW_QuadSPI_LUT19_RD(x) & ~BM_QuadSPI_LUT19_PAD0) | BF_QuadSPI_LUT19_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT19, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT19_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT19_INSTR0. */
#define BM_QuadSPI_LUT19_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT19_INSTR0. */
#define BS_QuadSPI_LUT19_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT19_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT19_INSTR0 field. */
#define BR_QuadSPI_LUT19_INSTR0(x) (HW_QuadSPI_LUT19(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT19_INSTR0. */
#define BF_QuadSPI_LUT19_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT19_INSTR0) & BM_QuadSPI_LUT19_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT19_INSTR0(x, v) (HW_QuadSPI_LUT19_WR(x, (HW_QuadSPI_LUT19_RD(x) & ~BM_QuadSPI_LUT19_INSTR0) | BF_QuadSPI_LUT19_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT19, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT19_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT19_OPRND1. */
#define BM_QuadSPI_LUT19_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT19_OPRND1. */
#define BS_QuadSPI_LUT19_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT19_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT19_OPRND1 field. */
#define BR_QuadSPI_LUT19_OPRND1(x) (HW_QuadSPI_LUT19(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT19_OPRND1. */
#define BF_QuadSPI_LUT19_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT19_OPRND1) & BM_QuadSPI_LUT19_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT19_OPRND1(x, v) (HW_QuadSPI_LUT19_WR(x, (HW_QuadSPI_LUT19_RD(x) & ~BM_QuadSPI_LUT19_OPRND1) | BF_QuadSPI_LUT19_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT19, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT19_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT19_PAD1. */
#define BM_QuadSPI_LUT19_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT19_PAD1. */
#define BS_QuadSPI_LUT19_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT19_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT19_PAD1 field. */
#define BR_QuadSPI_LUT19_PAD1(x) (HW_QuadSPI_LUT19(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT19_PAD1. */
#define BF_QuadSPI_LUT19_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT19_PAD1) & BM_QuadSPI_LUT19_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT19_PAD1(x, v) (HW_QuadSPI_LUT19_WR(x, (HW_QuadSPI_LUT19_RD(x) & ~BM_QuadSPI_LUT19_PAD1) | BF_QuadSPI_LUT19_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT19, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT19_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT19_INSTR1. */
#define BM_QuadSPI_LUT19_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT19_INSTR1. */
#define BS_QuadSPI_LUT19_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT19_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT19_INSTR1 field. */
#define BR_QuadSPI_LUT19_INSTR1(x) (HW_QuadSPI_LUT19(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT19_INSTR1. */
#define BF_QuadSPI_LUT19_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT19_INSTR1) & BM_QuadSPI_LUT19_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT19_INSTR1(x, v) (HW_QuadSPI_LUT19_WR(x, (HW_QuadSPI_LUT19_RD(x) & ~BM_QuadSPI_LUT19_INSTR1) | BF_QuadSPI_LUT19_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT20 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT20 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut20
{
    uint32_t U;
    struct _hw_quadspi_lut20_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut20_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT20 register
 */
/*@{*/
#define HW_QuadSPI_LUT20_ADDR(x) ((uintptr_t)(x) + 0x360U)

#define HW_QuadSPI_LUT20(x)      (*(__IO hw_quadspi_lut20_t *) HW_QuadSPI_LUT20_ADDR(x))
#define HW_QuadSPI_LUT20_RD(x)   (HW_QuadSPI_LUT20(x).U)
#define HW_QuadSPI_LUT20_WR(x, v) (HW_QuadSPI_LUT20(x).U = (v))
#define HW_QuadSPI_LUT20_SET(x, v) (HW_QuadSPI_LUT20_WR(x, HW_QuadSPI_LUT20_RD(x) |  (v)))
#define HW_QuadSPI_LUT20_CLR(x, v) (HW_QuadSPI_LUT20_WR(x, HW_QuadSPI_LUT20_RD(x) & ~(v)))
#define HW_QuadSPI_LUT20_TOG(x, v) (HW_QuadSPI_LUT20_WR(x, HW_QuadSPI_LUT20_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT20 bitfields
 */

/*!
 * @name Register QuadSPI_LUT20, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT20_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT20_OPRND0. */
#define BM_QuadSPI_LUT20_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT20_OPRND0. */
#define BS_QuadSPI_LUT20_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT20_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT20_OPRND0 field. */
#define BR_QuadSPI_LUT20_OPRND0(x) (HW_QuadSPI_LUT20(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT20_OPRND0. */
#define BF_QuadSPI_LUT20_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT20_OPRND0) & BM_QuadSPI_LUT20_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT20_OPRND0(x, v) (HW_QuadSPI_LUT20_WR(x, (HW_QuadSPI_LUT20_RD(x) & ~BM_QuadSPI_LUT20_OPRND0) | BF_QuadSPI_LUT20_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT20, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT20_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT20_PAD0. */
#define BM_QuadSPI_LUT20_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT20_PAD0. */
#define BS_QuadSPI_LUT20_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT20_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT20_PAD0 field. */
#define BR_QuadSPI_LUT20_PAD0(x) (HW_QuadSPI_LUT20(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT20_PAD0. */
#define BF_QuadSPI_LUT20_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT20_PAD0) & BM_QuadSPI_LUT20_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT20_PAD0(x, v) (HW_QuadSPI_LUT20_WR(x, (HW_QuadSPI_LUT20_RD(x) & ~BM_QuadSPI_LUT20_PAD0) | BF_QuadSPI_LUT20_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT20, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT20_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT20_INSTR0. */
#define BM_QuadSPI_LUT20_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT20_INSTR0. */
#define BS_QuadSPI_LUT20_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT20_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT20_INSTR0 field. */
#define BR_QuadSPI_LUT20_INSTR0(x) (HW_QuadSPI_LUT20(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT20_INSTR0. */
#define BF_QuadSPI_LUT20_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT20_INSTR0) & BM_QuadSPI_LUT20_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT20_INSTR0(x, v) (HW_QuadSPI_LUT20_WR(x, (HW_QuadSPI_LUT20_RD(x) & ~BM_QuadSPI_LUT20_INSTR0) | BF_QuadSPI_LUT20_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT20, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT20_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT20_OPRND1. */
#define BM_QuadSPI_LUT20_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT20_OPRND1. */
#define BS_QuadSPI_LUT20_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT20_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT20_OPRND1 field. */
#define BR_QuadSPI_LUT20_OPRND1(x) (HW_QuadSPI_LUT20(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT20_OPRND1. */
#define BF_QuadSPI_LUT20_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT20_OPRND1) & BM_QuadSPI_LUT20_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT20_OPRND1(x, v) (HW_QuadSPI_LUT20_WR(x, (HW_QuadSPI_LUT20_RD(x) & ~BM_QuadSPI_LUT20_OPRND1) | BF_QuadSPI_LUT20_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT20, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT20_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT20_PAD1. */
#define BM_QuadSPI_LUT20_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT20_PAD1. */
#define BS_QuadSPI_LUT20_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT20_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT20_PAD1 field. */
#define BR_QuadSPI_LUT20_PAD1(x) (HW_QuadSPI_LUT20(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT20_PAD1. */
#define BF_QuadSPI_LUT20_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT20_PAD1) & BM_QuadSPI_LUT20_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT20_PAD1(x, v) (HW_QuadSPI_LUT20_WR(x, (HW_QuadSPI_LUT20_RD(x) & ~BM_QuadSPI_LUT20_PAD1) | BF_QuadSPI_LUT20_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT20, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT20_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT20_INSTR1. */
#define BM_QuadSPI_LUT20_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT20_INSTR1. */
#define BS_QuadSPI_LUT20_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT20_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT20_INSTR1 field. */
#define BR_QuadSPI_LUT20_INSTR1(x) (HW_QuadSPI_LUT20(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT20_INSTR1. */
#define BF_QuadSPI_LUT20_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT20_INSTR1) & BM_QuadSPI_LUT20_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT20_INSTR1(x, v) (HW_QuadSPI_LUT20_WR(x, (HW_QuadSPI_LUT20_RD(x) & ~BM_QuadSPI_LUT20_INSTR1) | BF_QuadSPI_LUT20_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT21 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT21 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut21
{
    uint32_t U;
    struct _hw_quadspi_lut21_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut21_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT21 register
 */
/*@{*/
#define HW_QuadSPI_LUT21_ADDR(x) ((uintptr_t)(x) + 0x364U)

#define HW_QuadSPI_LUT21(x)      (*(__IO hw_quadspi_lut21_t *) HW_QuadSPI_LUT21_ADDR(x))
#define HW_QuadSPI_LUT21_RD(x)   (HW_QuadSPI_LUT21(x).U)
#define HW_QuadSPI_LUT21_WR(x, v) (HW_QuadSPI_LUT21(x).U = (v))
#define HW_QuadSPI_LUT21_SET(x, v) (HW_QuadSPI_LUT21_WR(x, HW_QuadSPI_LUT21_RD(x) |  (v)))
#define HW_QuadSPI_LUT21_CLR(x, v) (HW_QuadSPI_LUT21_WR(x, HW_QuadSPI_LUT21_RD(x) & ~(v)))
#define HW_QuadSPI_LUT21_TOG(x, v) (HW_QuadSPI_LUT21_WR(x, HW_QuadSPI_LUT21_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT21 bitfields
 */

/*!
 * @name Register QuadSPI_LUT21, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT21_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT21_OPRND0. */
#define BM_QuadSPI_LUT21_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT21_OPRND0. */
#define BS_QuadSPI_LUT21_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT21_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT21_OPRND0 field. */
#define BR_QuadSPI_LUT21_OPRND0(x) (HW_QuadSPI_LUT21(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT21_OPRND0. */
#define BF_QuadSPI_LUT21_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT21_OPRND0) & BM_QuadSPI_LUT21_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT21_OPRND0(x, v) (HW_QuadSPI_LUT21_WR(x, (HW_QuadSPI_LUT21_RD(x) & ~BM_QuadSPI_LUT21_OPRND0) | BF_QuadSPI_LUT21_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT21, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT21_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT21_PAD0. */
#define BM_QuadSPI_LUT21_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT21_PAD0. */
#define BS_QuadSPI_LUT21_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT21_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT21_PAD0 field. */
#define BR_QuadSPI_LUT21_PAD0(x) (HW_QuadSPI_LUT21(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT21_PAD0. */
#define BF_QuadSPI_LUT21_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT21_PAD0) & BM_QuadSPI_LUT21_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT21_PAD0(x, v) (HW_QuadSPI_LUT21_WR(x, (HW_QuadSPI_LUT21_RD(x) & ~BM_QuadSPI_LUT21_PAD0) | BF_QuadSPI_LUT21_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT21, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT21_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT21_INSTR0. */
#define BM_QuadSPI_LUT21_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT21_INSTR0. */
#define BS_QuadSPI_LUT21_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT21_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT21_INSTR0 field. */
#define BR_QuadSPI_LUT21_INSTR0(x) (HW_QuadSPI_LUT21(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT21_INSTR0. */
#define BF_QuadSPI_LUT21_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT21_INSTR0) & BM_QuadSPI_LUT21_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT21_INSTR0(x, v) (HW_QuadSPI_LUT21_WR(x, (HW_QuadSPI_LUT21_RD(x) & ~BM_QuadSPI_LUT21_INSTR0) | BF_QuadSPI_LUT21_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT21, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT21_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT21_OPRND1. */
#define BM_QuadSPI_LUT21_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT21_OPRND1. */
#define BS_QuadSPI_LUT21_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT21_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT21_OPRND1 field. */
#define BR_QuadSPI_LUT21_OPRND1(x) (HW_QuadSPI_LUT21(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT21_OPRND1. */
#define BF_QuadSPI_LUT21_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT21_OPRND1) & BM_QuadSPI_LUT21_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT21_OPRND1(x, v) (HW_QuadSPI_LUT21_WR(x, (HW_QuadSPI_LUT21_RD(x) & ~BM_QuadSPI_LUT21_OPRND1) | BF_QuadSPI_LUT21_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT21, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT21_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT21_PAD1. */
#define BM_QuadSPI_LUT21_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT21_PAD1. */
#define BS_QuadSPI_LUT21_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT21_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT21_PAD1 field. */
#define BR_QuadSPI_LUT21_PAD1(x) (HW_QuadSPI_LUT21(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT21_PAD1. */
#define BF_QuadSPI_LUT21_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT21_PAD1) & BM_QuadSPI_LUT21_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT21_PAD1(x, v) (HW_QuadSPI_LUT21_WR(x, (HW_QuadSPI_LUT21_RD(x) & ~BM_QuadSPI_LUT21_PAD1) | BF_QuadSPI_LUT21_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT21, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT21_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT21_INSTR1. */
#define BM_QuadSPI_LUT21_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT21_INSTR1. */
#define BS_QuadSPI_LUT21_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT21_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT21_INSTR1 field. */
#define BR_QuadSPI_LUT21_INSTR1(x) (HW_QuadSPI_LUT21(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT21_INSTR1. */
#define BF_QuadSPI_LUT21_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT21_INSTR1) & BM_QuadSPI_LUT21_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT21_INSTR1(x, v) (HW_QuadSPI_LUT21_WR(x, (HW_QuadSPI_LUT21_RD(x) & ~BM_QuadSPI_LUT21_INSTR1) | BF_QuadSPI_LUT21_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT22 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT22 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut22
{
    uint32_t U;
    struct _hw_quadspi_lut22_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut22_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT22 register
 */
/*@{*/
#define HW_QuadSPI_LUT22_ADDR(x) ((uintptr_t)(x) + 0x368U)

#define HW_QuadSPI_LUT22(x)      (*(__IO hw_quadspi_lut22_t *) HW_QuadSPI_LUT22_ADDR(x))
#define HW_QuadSPI_LUT22_RD(x)   (HW_QuadSPI_LUT22(x).U)
#define HW_QuadSPI_LUT22_WR(x, v) (HW_QuadSPI_LUT22(x).U = (v))
#define HW_QuadSPI_LUT22_SET(x, v) (HW_QuadSPI_LUT22_WR(x, HW_QuadSPI_LUT22_RD(x) |  (v)))
#define HW_QuadSPI_LUT22_CLR(x, v) (HW_QuadSPI_LUT22_WR(x, HW_QuadSPI_LUT22_RD(x) & ~(v)))
#define HW_QuadSPI_LUT22_TOG(x, v) (HW_QuadSPI_LUT22_WR(x, HW_QuadSPI_LUT22_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT22 bitfields
 */

/*!
 * @name Register QuadSPI_LUT22, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT22_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT22_OPRND0. */
#define BM_QuadSPI_LUT22_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT22_OPRND0. */
#define BS_QuadSPI_LUT22_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT22_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT22_OPRND0 field. */
#define BR_QuadSPI_LUT22_OPRND0(x) (HW_QuadSPI_LUT22(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT22_OPRND0. */
#define BF_QuadSPI_LUT22_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT22_OPRND0) & BM_QuadSPI_LUT22_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT22_OPRND0(x, v) (HW_QuadSPI_LUT22_WR(x, (HW_QuadSPI_LUT22_RD(x) & ~BM_QuadSPI_LUT22_OPRND0) | BF_QuadSPI_LUT22_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT22, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT22_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT22_PAD0. */
#define BM_QuadSPI_LUT22_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT22_PAD0. */
#define BS_QuadSPI_LUT22_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT22_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT22_PAD0 field. */
#define BR_QuadSPI_LUT22_PAD0(x) (HW_QuadSPI_LUT22(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT22_PAD0. */
#define BF_QuadSPI_LUT22_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT22_PAD0) & BM_QuadSPI_LUT22_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT22_PAD0(x, v) (HW_QuadSPI_LUT22_WR(x, (HW_QuadSPI_LUT22_RD(x) & ~BM_QuadSPI_LUT22_PAD0) | BF_QuadSPI_LUT22_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT22, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT22_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT22_INSTR0. */
#define BM_QuadSPI_LUT22_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT22_INSTR0. */
#define BS_QuadSPI_LUT22_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT22_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT22_INSTR0 field. */
#define BR_QuadSPI_LUT22_INSTR0(x) (HW_QuadSPI_LUT22(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT22_INSTR0. */
#define BF_QuadSPI_LUT22_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT22_INSTR0) & BM_QuadSPI_LUT22_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT22_INSTR0(x, v) (HW_QuadSPI_LUT22_WR(x, (HW_QuadSPI_LUT22_RD(x) & ~BM_QuadSPI_LUT22_INSTR0) | BF_QuadSPI_LUT22_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT22, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT22_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT22_OPRND1. */
#define BM_QuadSPI_LUT22_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT22_OPRND1. */
#define BS_QuadSPI_LUT22_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT22_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT22_OPRND1 field. */
#define BR_QuadSPI_LUT22_OPRND1(x) (HW_QuadSPI_LUT22(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT22_OPRND1. */
#define BF_QuadSPI_LUT22_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT22_OPRND1) & BM_QuadSPI_LUT22_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT22_OPRND1(x, v) (HW_QuadSPI_LUT22_WR(x, (HW_QuadSPI_LUT22_RD(x) & ~BM_QuadSPI_LUT22_OPRND1) | BF_QuadSPI_LUT22_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT22, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT22_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT22_PAD1. */
#define BM_QuadSPI_LUT22_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT22_PAD1. */
#define BS_QuadSPI_LUT22_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT22_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT22_PAD1 field. */
#define BR_QuadSPI_LUT22_PAD1(x) (HW_QuadSPI_LUT22(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT22_PAD1. */
#define BF_QuadSPI_LUT22_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT22_PAD1) & BM_QuadSPI_LUT22_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT22_PAD1(x, v) (HW_QuadSPI_LUT22_WR(x, (HW_QuadSPI_LUT22_RD(x) & ~BM_QuadSPI_LUT22_PAD1) | BF_QuadSPI_LUT22_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT22, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT22_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT22_INSTR1. */
#define BM_QuadSPI_LUT22_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT22_INSTR1. */
#define BS_QuadSPI_LUT22_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT22_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT22_INSTR1 field. */
#define BR_QuadSPI_LUT22_INSTR1(x) (HW_QuadSPI_LUT22(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT22_INSTR1. */
#define BF_QuadSPI_LUT22_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT22_INSTR1) & BM_QuadSPI_LUT22_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT22_INSTR1(x, v) (HW_QuadSPI_LUT22_WR(x, (HW_QuadSPI_LUT22_RD(x) & ~BM_QuadSPI_LUT22_INSTR1) | BF_QuadSPI_LUT22_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT23 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT23 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut23
{
    uint32_t U;
    struct _hw_quadspi_lut23_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut23_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT23 register
 */
/*@{*/
#define HW_QuadSPI_LUT23_ADDR(x) ((uintptr_t)(x) + 0x36CU)

#define HW_QuadSPI_LUT23(x)      (*(__IO hw_quadspi_lut23_t *) HW_QuadSPI_LUT23_ADDR(x))
#define HW_QuadSPI_LUT23_RD(x)   (HW_QuadSPI_LUT23(x).U)
#define HW_QuadSPI_LUT23_WR(x, v) (HW_QuadSPI_LUT23(x).U = (v))
#define HW_QuadSPI_LUT23_SET(x, v) (HW_QuadSPI_LUT23_WR(x, HW_QuadSPI_LUT23_RD(x) |  (v)))
#define HW_QuadSPI_LUT23_CLR(x, v) (HW_QuadSPI_LUT23_WR(x, HW_QuadSPI_LUT23_RD(x) & ~(v)))
#define HW_QuadSPI_LUT23_TOG(x, v) (HW_QuadSPI_LUT23_WR(x, HW_QuadSPI_LUT23_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT23 bitfields
 */

/*!
 * @name Register QuadSPI_LUT23, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT23_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT23_OPRND0. */
#define BM_QuadSPI_LUT23_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT23_OPRND0. */
#define BS_QuadSPI_LUT23_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT23_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT23_OPRND0 field. */
#define BR_QuadSPI_LUT23_OPRND0(x) (HW_QuadSPI_LUT23(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT23_OPRND0. */
#define BF_QuadSPI_LUT23_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT23_OPRND0) & BM_QuadSPI_LUT23_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT23_OPRND0(x, v) (HW_QuadSPI_LUT23_WR(x, (HW_QuadSPI_LUT23_RD(x) & ~BM_QuadSPI_LUT23_OPRND0) | BF_QuadSPI_LUT23_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT23, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT23_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT23_PAD0. */
#define BM_QuadSPI_LUT23_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT23_PAD0. */
#define BS_QuadSPI_LUT23_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT23_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT23_PAD0 field. */
#define BR_QuadSPI_LUT23_PAD0(x) (HW_QuadSPI_LUT23(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT23_PAD0. */
#define BF_QuadSPI_LUT23_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT23_PAD0) & BM_QuadSPI_LUT23_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT23_PAD0(x, v) (HW_QuadSPI_LUT23_WR(x, (HW_QuadSPI_LUT23_RD(x) & ~BM_QuadSPI_LUT23_PAD0) | BF_QuadSPI_LUT23_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT23, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT23_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT23_INSTR0. */
#define BM_QuadSPI_LUT23_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT23_INSTR0. */
#define BS_QuadSPI_LUT23_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT23_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT23_INSTR0 field. */
#define BR_QuadSPI_LUT23_INSTR0(x) (HW_QuadSPI_LUT23(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT23_INSTR0. */
#define BF_QuadSPI_LUT23_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT23_INSTR0) & BM_QuadSPI_LUT23_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT23_INSTR0(x, v) (HW_QuadSPI_LUT23_WR(x, (HW_QuadSPI_LUT23_RD(x) & ~BM_QuadSPI_LUT23_INSTR0) | BF_QuadSPI_LUT23_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT23, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT23_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT23_OPRND1. */
#define BM_QuadSPI_LUT23_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT23_OPRND1. */
#define BS_QuadSPI_LUT23_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT23_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT23_OPRND1 field. */
#define BR_QuadSPI_LUT23_OPRND1(x) (HW_QuadSPI_LUT23(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT23_OPRND1. */
#define BF_QuadSPI_LUT23_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT23_OPRND1) & BM_QuadSPI_LUT23_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT23_OPRND1(x, v) (HW_QuadSPI_LUT23_WR(x, (HW_QuadSPI_LUT23_RD(x) & ~BM_QuadSPI_LUT23_OPRND1) | BF_QuadSPI_LUT23_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT23, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT23_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT23_PAD1. */
#define BM_QuadSPI_LUT23_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT23_PAD1. */
#define BS_QuadSPI_LUT23_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT23_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT23_PAD1 field. */
#define BR_QuadSPI_LUT23_PAD1(x) (HW_QuadSPI_LUT23(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT23_PAD1. */
#define BF_QuadSPI_LUT23_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT23_PAD1) & BM_QuadSPI_LUT23_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT23_PAD1(x, v) (HW_QuadSPI_LUT23_WR(x, (HW_QuadSPI_LUT23_RD(x) & ~BM_QuadSPI_LUT23_PAD1) | BF_QuadSPI_LUT23_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT23, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT23_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT23_INSTR1. */
#define BM_QuadSPI_LUT23_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT23_INSTR1. */
#define BS_QuadSPI_LUT23_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT23_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT23_INSTR1 field. */
#define BR_QuadSPI_LUT23_INSTR1(x) (HW_QuadSPI_LUT23(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT23_INSTR1. */
#define BF_QuadSPI_LUT23_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT23_INSTR1) & BM_QuadSPI_LUT23_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT23_INSTR1(x, v) (HW_QuadSPI_LUT23_WR(x, (HW_QuadSPI_LUT23_RD(x) & ~BM_QuadSPI_LUT23_INSTR1) | BF_QuadSPI_LUT23_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT24 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT24 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut24
{
    uint32_t U;
    struct _hw_quadspi_lut24_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut24_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT24 register
 */
/*@{*/
#define HW_QuadSPI_LUT24_ADDR(x) ((uintptr_t)(x) + 0x370U)

#define HW_QuadSPI_LUT24(x)      (*(__IO hw_quadspi_lut24_t *) HW_QuadSPI_LUT24_ADDR(x))
#define HW_QuadSPI_LUT24_RD(x)   (HW_QuadSPI_LUT24(x).U)
#define HW_QuadSPI_LUT24_WR(x, v) (HW_QuadSPI_LUT24(x).U = (v))
#define HW_QuadSPI_LUT24_SET(x, v) (HW_QuadSPI_LUT24_WR(x, HW_QuadSPI_LUT24_RD(x) |  (v)))
#define HW_QuadSPI_LUT24_CLR(x, v) (HW_QuadSPI_LUT24_WR(x, HW_QuadSPI_LUT24_RD(x) & ~(v)))
#define HW_QuadSPI_LUT24_TOG(x, v) (HW_QuadSPI_LUT24_WR(x, HW_QuadSPI_LUT24_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT24 bitfields
 */

/*!
 * @name Register QuadSPI_LUT24, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT24_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT24_OPRND0. */
#define BM_QuadSPI_LUT24_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT24_OPRND0. */
#define BS_QuadSPI_LUT24_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT24_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT24_OPRND0 field. */
#define BR_QuadSPI_LUT24_OPRND0(x) (HW_QuadSPI_LUT24(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT24_OPRND0. */
#define BF_QuadSPI_LUT24_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT24_OPRND0) & BM_QuadSPI_LUT24_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT24_OPRND0(x, v) (HW_QuadSPI_LUT24_WR(x, (HW_QuadSPI_LUT24_RD(x) & ~BM_QuadSPI_LUT24_OPRND0) | BF_QuadSPI_LUT24_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT24, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT24_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT24_PAD0. */
#define BM_QuadSPI_LUT24_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT24_PAD0. */
#define BS_QuadSPI_LUT24_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT24_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT24_PAD0 field. */
#define BR_QuadSPI_LUT24_PAD0(x) (HW_QuadSPI_LUT24(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT24_PAD0. */
#define BF_QuadSPI_LUT24_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT24_PAD0) & BM_QuadSPI_LUT24_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT24_PAD0(x, v) (HW_QuadSPI_LUT24_WR(x, (HW_QuadSPI_LUT24_RD(x) & ~BM_QuadSPI_LUT24_PAD0) | BF_QuadSPI_LUT24_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT24, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT24_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT24_INSTR0. */
#define BM_QuadSPI_LUT24_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT24_INSTR0. */
#define BS_QuadSPI_LUT24_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT24_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT24_INSTR0 field. */
#define BR_QuadSPI_LUT24_INSTR0(x) (HW_QuadSPI_LUT24(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT24_INSTR0. */
#define BF_QuadSPI_LUT24_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT24_INSTR0) & BM_QuadSPI_LUT24_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT24_INSTR0(x, v) (HW_QuadSPI_LUT24_WR(x, (HW_QuadSPI_LUT24_RD(x) & ~BM_QuadSPI_LUT24_INSTR0) | BF_QuadSPI_LUT24_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT24, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT24_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT24_OPRND1. */
#define BM_QuadSPI_LUT24_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT24_OPRND1. */
#define BS_QuadSPI_LUT24_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT24_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT24_OPRND1 field. */
#define BR_QuadSPI_LUT24_OPRND1(x) (HW_QuadSPI_LUT24(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT24_OPRND1. */
#define BF_QuadSPI_LUT24_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT24_OPRND1) & BM_QuadSPI_LUT24_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT24_OPRND1(x, v) (HW_QuadSPI_LUT24_WR(x, (HW_QuadSPI_LUT24_RD(x) & ~BM_QuadSPI_LUT24_OPRND1) | BF_QuadSPI_LUT24_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT24, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT24_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT24_PAD1. */
#define BM_QuadSPI_LUT24_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT24_PAD1. */
#define BS_QuadSPI_LUT24_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT24_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT24_PAD1 field. */
#define BR_QuadSPI_LUT24_PAD1(x) (HW_QuadSPI_LUT24(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT24_PAD1. */
#define BF_QuadSPI_LUT24_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT24_PAD1) & BM_QuadSPI_LUT24_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT24_PAD1(x, v) (HW_QuadSPI_LUT24_WR(x, (HW_QuadSPI_LUT24_RD(x) & ~BM_QuadSPI_LUT24_PAD1) | BF_QuadSPI_LUT24_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT24, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT24_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT24_INSTR1. */
#define BM_QuadSPI_LUT24_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT24_INSTR1. */
#define BS_QuadSPI_LUT24_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT24_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT24_INSTR1 field. */
#define BR_QuadSPI_LUT24_INSTR1(x) (HW_QuadSPI_LUT24(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT24_INSTR1. */
#define BF_QuadSPI_LUT24_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT24_INSTR1) & BM_QuadSPI_LUT24_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT24_INSTR1(x, v) (HW_QuadSPI_LUT24_WR(x, (HW_QuadSPI_LUT24_RD(x) & ~BM_QuadSPI_LUT24_INSTR1) | BF_QuadSPI_LUT24_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT25 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT25 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut25
{
    uint32_t U;
    struct _hw_quadspi_lut25_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut25_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT25 register
 */
/*@{*/
#define HW_QuadSPI_LUT25_ADDR(x) ((uintptr_t)(x) + 0x374U)

#define HW_QuadSPI_LUT25(x)      (*(__IO hw_quadspi_lut25_t *) HW_QuadSPI_LUT25_ADDR(x))
#define HW_QuadSPI_LUT25_RD(x)   (HW_QuadSPI_LUT25(x).U)
#define HW_QuadSPI_LUT25_WR(x, v) (HW_QuadSPI_LUT25(x).U = (v))
#define HW_QuadSPI_LUT25_SET(x, v) (HW_QuadSPI_LUT25_WR(x, HW_QuadSPI_LUT25_RD(x) |  (v)))
#define HW_QuadSPI_LUT25_CLR(x, v) (HW_QuadSPI_LUT25_WR(x, HW_QuadSPI_LUT25_RD(x) & ~(v)))
#define HW_QuadSPI_LUT25_TOG(x, v) (HW_QuadSPI_LUT25_WR(x, HW_QuadSPI_LUT25_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT25 bitfields
 */

/*!
 * @name Register QuadSPI_LUT25, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT25_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT25_OPRND0. */
#define BM_QuadSPI_LUT25_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT25_OPRND0. */
#define BS_QuadSPI_LUT25_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT25_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT25_OPRND0 field. */
#define BR_QuadSPI_LUT25_OPRND0(x) (HW_QuadSPI_LUT25(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT25_OPRND0. */
#define BF_QuadSPI_LUT25_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT25_OPRND0) & BM_QuadSPI_LUT25_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT25_OPRND0(x, v) (HW_QuadSPI_LUT25_WR(x, (HW_QuadSPI_LUT25_RD(x) & ~BM_QuadSPI_LUT25_OPRND0) | BF_QuadSPI_LUT25_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT25, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT25_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT25_PAD0. */
#define BM_QuadSPI_LUT25_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT25_PAD0. */
#define BS_QuadSPI_LUT25_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT25_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT25_PAD0 field. */
#define BR_QuadSPI_LUT25_PAD0(x) (HW_QuadSPI_LUT25(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT25_PAD0. */
#define BF_QuadSPI_LUT25_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT25_PAD0) & BM_QuadSPI_LUT25_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT25_PAD0(x, v) (HW_QuadSPI_LUT25_WR(x, (HW_QuadSPI_LUT25_RD(x) & ~BM_QuadSPI_LUT25_PAD0) | BF_QuadSPI_LUT25_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT25, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT25_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT25_INSTR0. */
#define BM_QuadSPI_LUT25_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT25_INSTR0. */
#define BS_QuadSPI_LUT25_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT25_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT25_INSTR0 field. */
#define BR_QuadSPI_LUT25_INSTR0(x) (HW_QuadSPI_LUT25(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT25_INSTR0. */
#define BF_QuadSPI_LUT25_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT25_INSTR0) & BM_QuadSPI_LUT25_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT25_INSTR0(x, v) (HW_QuadSPI_LUT25_WR(x, (HW_QuadSPI_LUT25_RD(x) & ~BM_QuadSPI_LUT25_INSTR0) | BF_QuadSPI_LUT25_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT25, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT25_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT25_OPRND1. */
#define BM_QuadSPI_LUT25_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT25_OPRND1. */
#define BS_QuadSPI_LUT25_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT25_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT25_OPRND1 field. */
#define BR_QuadSPI_LUT25_OPRND1(x) (HW_QuadSPI_LUT25(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT25_OPRND1. */
#define BF_QuadSPI_LUT25_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT25_OPRND1) & BM_QuadSPI_LUT25_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT25_OPRND1(x, v) (HW_QuadSPI_LUT25_WR(x, (HW_QuadSPI_LUT25_RD(x) & ~BM_QuadSPI_LUT25_OPRND1) | BF_QuadSPI_LUT25_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT25, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT25_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT25_PAD1. */
#define BM_QuadSPI_LUT25_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT25_PAD1. */
#define BS_QuadSPI_LUT25_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT25_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT25_PAD1 field. */
#define BR_QuadSPI_LUT25_PAD1(x) (HW_QuadSPI_LUT25(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT25_PAD1. */
#define BF_QuadSPI_LUT25_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT25_PAD1) & BM_QuadSPI_LUT25_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT25_PAD1(x, v) (HW_QuadSPI_LUT25_WR(x, (HW_QuadSPI_LUT25_RD(x) & ~BM_QuadSPI_LUT25_PAD1) | BF_QuadSPI_LUT25_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT25, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT25_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT25_INSTR1. */
#define BM_QuadSPI_LUT25_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT25_INSTR1. */
#define BS_QuadSPI_LUT25_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT25_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT25_INSTR1 field. */
#define BR_QuadSPI_LUT25_INSTR1(x) (HW_QuadSPI_LUT25(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT25_INSTR1. */
#define BF_QuadSPI_LUT25_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT25_INSTR1) & BM_QuadSPI_LUT25_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT25_INSTR1(x, v) (HW_QuadSPI_LUT25_WR(x, (HW_QuadSPI_LUT25_RD(x) & ~BM_QuadSPI_LUT25_INSTR1) | BF_QuadSPI_LUT25_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT26 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT26 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut26
{
    uint32_t U;
    struct _hw_quadspi_lut26_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut26_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT26 register
 */
/*@{*/
#define HW_QuadSPI_LUT26_ADDR(x) ((uintptr_t)(x) + 0x378U)

#define HW_QuadSPI_LUT26(x)      (*(__IO hw_quadspi_lut26_t *) HW_QuadSPI_LUT26_ADDR(x))
#define HW_QuadSPI_LUT26_RD(x)   (HW_QuadSPI_LUT26(x).U)
#define HW_QuadSPI_LUT26_WR(x, v) (HW_QuadSPI_LUT26(x).U = (v))
#define HW_QuadSPI_LUT26_SET(x, v) (HW_QuadSPI_LUT26_WR(x, HW_QuadSPI_LUT26_RD(x) |  (v)))
#define HW_QuadSPI_LUT26_CLR(x, v) (HW_QuadSPI_LUT26_WR(x, HW_QuadSPI_LUT26_RD(x) & ~(v)))
#define HW_QuadSPI_LUT26_TOG(x, v) (HW_QuadSPI_LUT26_WR(x, HW_QuadSPI_LUT26_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT26 bitfields
 */

/*!
 * @name Register QuadSPI_LUT26, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT26_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT26_OPRND0. */
#define BM_QuadSPI_LUT26_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT26_OPRND0. */
#define BS_QuadSPI_LUT26_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT26_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT26_OPRND0 field. */
#define BR_QuadSPI_LUT26_OPRND0(x) (HW_QuadSPI_LUT26(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT26_OPRND0. */
#define BF_QuadSPI_LUT26_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT26_OPRND0) & BM_QuadSPI_LUT26_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT26_OPRND0(x, v) (HW_QuadSPI_LUT26_WR(x, (HW_QuadSPI_LUT26_RD(x) & ~BM_QuadSPI_LUT26_OPRND0) | BF_QuadSPI_LUT26_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT26, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT26_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT26_PAD0. */
#define BM_QuadSPI_LUT26_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT26_PAD0. */
#define BS_QuadSPI_LUT26_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT26_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT26_PAD0 field. */
#define BR_QuadSPI_LUT26_PAD0(x) (HW_QuadSPI_LUT26(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT26_PAD0. */
#define BF_QuadSPI_LUT26_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT26_PAD0) & BM_QuadSPI_LUT26_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT26_PAD0(x, v) (HW_QuadSPI_LUT26_WR(x, (HW_QuadSPI_LUT26_RD(x) & ~BM_QuadSPI_LUT26_PAD0) | BF_QuadSPI_LUT26_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT26, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT26_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT26_INSTR0. */
#define BM_QuadSPI_LUT26_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT26_INSTR0. */
#define BS_QuadSPI_LUT26_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT26_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT26_INSTR0 field. */
#define BR_QuadSPI_LUT26_INSTR0(x) (HW_QuadSPI_LUT26(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT26_INSTR0. */
#define BF_QuadSPI_LUT26_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT26_INSTR0) & BM_QuadSPI_LUT26_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT26_INSTR0(x, v) (HW_QuadSPI_LUT26_WR(x, (HW_QuadSPI_LUT26_RD(x) & ~BM_QuadSPI_LUT26_INSTR0) | BF_QuadSPI_LUT26_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT26, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT26_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT26_OPRND1. */
#define BM_QuadSPI_LUT26_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT26_OPRND1. */
#define BS_QuadSPI_LUT26_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT26_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT26_OPRND1 field. */
#define BR_QuadSPI_LUT26_OPRND1(x) (HW_QuadSPI_LUT26(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT26_OPRND1. */
#define BF_QuadSPI_LUT26_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT26_OPRND1) & BM_QuadSPI_LUT26_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT26_OPRND1(x, v) (HW_QuadSPI_LUT26_WR(x, (HW_QuadSPI_LUT26_RD(x) & ~BM_QuadSPI_LUT26_OPRND1) | BF_QuadSPI_LUT26_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT26, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT26_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT26_PAD1. */
#define BM_QuadSPI_LUT26_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT26_PAD1. */
#define BS_QuadSPI_LUT26_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT26_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT26_PAD1 field. */
#define BR_QuadSPI_LUT26_PAD1(x) (HW_QuadSPI_LUT26(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT26_PAD1. */
#define BF_QuadSPI_LUT26_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT26_PAD1) & BM_QuadSPI_LUT26_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT26_PAD1(x, v) (HW_QuadSPI_LUT26_WR(x, (HW_QuadSPI_LUT26_RD(x) & ~BM_QuadSPI_LUT26_PAD1) | BF_QuadSPI_LUT26_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT26, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT26_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT26_INSTR1. */
#define BM_QuadSPI_LUT26_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT26_INSTR1. */
#define BS_QuadSPI_LUT26_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT26_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT26_INSTR1 field. */
#define BR_QuadSPI_LUT26_INSTR1(x) (HW_QuadSPI_LUT26(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT26_INSTR1. */
#define BF_QuadSPI_LUT26_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT26_INSTR1) & BM_QuadSPI_LUT26_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT26_INSTR1(x, v) (HW_QuadSPI_LUT26_WR(x, (HW_QuadSPI_LUT26_RD(x) & ~BM_QuadSPI_LUT26_INSTR1) | BF_QuadSPI_LUT26_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT27 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT27 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut27
{
    uint32_t U;
    struct _hw_quadspi_lut27_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut27_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT27 register
 */
/*@{*/
#define HW_QuadSPI_LUT27_ADDR(x) ((uintptr_t)(x) + 0x37CU)

#define HW_QuadSPI_LUT27(x)      (*(__IO hw_quadspi_lut27_t *) HW_QuadSPI_LUT27_ADDR(x))
#define HW_QuadSPI_LUT27_RD(x)   (HW_QuadSPI_LUT27(x).U)
#define HW_QuadSPI_LUT27_WR(x, v) (HW_QuadSPI_LUT27(x).U = (v))
#define HW_QuadSPI_LUT27_SET(x, v) (HW_QuadSPI_LUT27_WR(x, HW_QuadSPI_LUT27_RD(x) |  (v)))
#define HW_QuadSPI_LUT27_CLR(x, v) (HW_QuadSPI_LUT27_WR(x, HW_QuadSPI_LUT27_RD(x) & ~(v)))
#define HW_QuadSPI_LUT27_TOG(x, v) (HW_QuadSPI_LUT27_WR(x, HW_QuadSPI_LUT27_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT27 bitfields
 */

/*!
 * @name Register QuadSPI_LUT27, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT27_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT27_OPRND0. */
#define BM_QuadSPI_LUT27_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT27_OPRND0. */
#define BS_QuadSPI_LUT27_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT27_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT27_OPRND0 field. */
#define BR_QuadSPI_LUT27_OPRND0(x) (HW_QuadSPI_LUT27(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT27_OPRND0. */
#define BF_QuadSPI_LUT27_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT27_OPRND0) & BM_QuadSPI_LUT27_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT27_OPRND0(x, v) (HW_QuadSPI_LUT27_WR(x, (HW_QuadSPI_LUT27_RD(x) & ~BM_QuadSPI_LUT27_OPRND0) | BF_QuadSPI_LUT27_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT27, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT27_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT27_PAD0. */
#define BM_QuadSPI_LUT27_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT27_PAD0. */
#define BS_QuadSPI_LUT27_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT27_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT27_PAD0 field. */
#define BR_QuadSPI_LUT27_PAD0(x) (HW_QuadSPI_LUT27(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT27_PAD0. */
#define BF_QuadSPI_LUT27_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT27_PAD0) & BM_QuadSPI_LUT27_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT27_PAD0(x, v) (HW_QuadSPI_LUT27_WR(x, (HW_QuadSPI_LUT27_RD(x) & ~BM_QuadSPI_LUT27_PAD0) | BF_QuadSPI_LUT27_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT27, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT27_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT27_INSTR0. */
#define BM_QuadSPI_LUT27_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT27_INSTR0. */
#define BS_QuadSPI_LUT27_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT27_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT27_INSTR0 field. */
#define BR_QuadSPI_LUT27_INSTR0(x) (HW_QuadSPI_LUT27(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT27_INSTR0. */
#define BF_QuadSPI_LUT27_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT27_INSTR0) & BM_QuadSPI_LUT27_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT27_INSTR0(x, v) (HW_QuadSPI_LUT27_WR(x, (HW_QuadSPI_LUT27_RD(x) & ~BM_QuadSPI_LUT27_INSTR0) | BF_QuadSPI_LUT27_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT27, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT27_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT27_OPRND1. */
#define BM_QuadSPI_LUT27_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT27_OPRND1. */
#define BS_QuadSPI_LUT27_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT27_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT27_OPRND1 field. */
#define BR_QuadSPI_LUT27_OPRND1(x) (HW_QuadSPI_LUT27(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT27_OPRND1. */
#define BF_QuadSPI_LUT27_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT27_OPRND1) & BM_QuadSPI_LUT27_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT27_OPRND1(x, v) (HW_QuadSPI_LUT27_WR(x, (HW_QuadSPI_LUT27_RD(x) & ~BM_QuadSPI_LUT27_OPRND1) | BF_QuadSPI_LUT27_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT27, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT27_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT27_PAD1. */
#define BM_QuadSPI_LUT27_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT27_PAD1. */
#define BS_QuadSPI_LUT27_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT27_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT27_PAD1 field. */
#define BR_QuadSPI_LUT27_PAD1(x) (HW_QuadSPI_LUT27(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT27_PAD1. */
#define BF_QuadSPI_LUT27_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT27_PAD1) & BM_QuadSPI_LUT27_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT27_PAD1(x, v) (HW_QuadSPI_LUT27_WR(x, (HW_QuadSPI_LUT27_RD(x) & ~BM_QuadSPI_LUT27_PAD1) | BF_QuadSPI_LUT27_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT27, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT27_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT27_INSTR1. */
#define BM_QuadSPI_LUT27_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT27_INSTR1. */
#define BS_QuadSPI_LUT27_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT27_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT27_INSTR1 field. */
#define BR_QuadSPI_LUT27_INSTR1(x) (HW_QuadSPI_LUT27(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT27_INSTR1. */
#define BF_QuadSPI_LUT27_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT27_INSTR1) & BM_QuadSPI_LUT27_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT27_INSTR1(x, v) (HW_QuadSPI_LUT27_WR(x, (HW_QuadSPI_LUT27_RD(x) & ~BM_QuadSPI_LUT27_INSTR1) | BF_QuadSPI_LUT27_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT28 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT28 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut28
{
    uint32_t U;
    struct _hw_quadspi_lut28_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut28_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT28 register
 */
/*@{*/
#define HW_QuadSPI_LUT28_ADDR(x) ((uintptr_t)(x) + 0x380U)

#define HW_QuadSPI_LUT28(x)      (*(__IO hw_quadspi_lut28_t *) HW_QuadSPI_LUT28_ADDR(x))
#define HW_QuadSPI_LUT28_RD(x)   (HW_QuadSPI_LUT28(x).U)
#define HW_QuadSPI_LUT28_WR(x, v) (HW_QuadSPI_LUT28(x).U = (v))
#define HW_QuadSPI_LUT28_SET(x, v) (HW_QuadSPI_LUT28_WR(x, HW_QuadSPI_LUT28_RD(x) |  (v)))
#define HW_QuadSPI_LUT28_CLR(x, v) (HW_QuadSPI_LUT28_WR(x, HW_QuadSPI_LUT28_RD(x) & ~(v)))
#define HW_QuadSPI_LUT28_TOG(x, v) (HW_QuadSPI_LUT28_WR(x, HW_QuadSPI_LUT28_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT28 bitfields
 */

/*!
 * @name Register QuadSPI_LUT28, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT28_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT28_OPRND0. */
#define BM_QuadSPI_LUT28_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT28_OPRND0. */
#define BS_QuadSPI_LUT28_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT28_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT28_OPRND0 field. */
#define BR_QuadSPI_LUT28_OPRND0(x) (HW_QuadSPI_LUT28(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT28_OPRND0. */
#define BF_QuadSPI_LUT28_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT28_OPRND0) & BM_QuadSPI_LUT28_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT28_OPRND0(x, v) (HW_QuadSPI_LUT28_WR(x, (HW_QuadSPI_LUT28_RD(x) & ~BM_QuadSPI_LUT28_OPRND0) | BF_QuadSPI_LUT28_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT28, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT28_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT28_PAD0. */
#define BM_QuadSPI_LUT28_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT28_PAD0. */
#define BS_QuadSPI_LUT28_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT28_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT28_PAD0 field. */
#define BR_QuadSPI_LUT28_PAD0(x) (HW_QuadSPI_LUT28(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT28_PAD0. */
#define BF_QuadSPI_LUT28_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT28_PAD0) & BM_QuadSPI_LUT28_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT28_PAD0(x, v) (HW_QuadSPI_LUT28_WR(x, (HW_QuadSPI_LUT28_RD(x) & ~BM_QuadSPI_LUT28_PAD0) | BF_QuadSPI_LUT28_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT28, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT28_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT28_INSTR0. */
#define BM_QuadSPI_LUT28_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT28_INSTR0. */
#define BS_QuadSPI_LUT28_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT28_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT28_INSTR0 field. */
#define BR_QuadSPI_LUT28_INSTR0(x) (HW_QuadSPI_LUT28(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT28_INSTR0. */
#define BF_QuadSPI_LUT28_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT28_INSTR0) & BM_QuadSPI_LUT28_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT28_INSTR0(x, v) (HW_QuadSPI_LUT28_WR(x, (HW_QuadSPI_LUT28_RD(x) & ~BM_QuadSPI_LUT28_INSTR0) | BF_QuadSPI_LUT28_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT28, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT28_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT28_OPRND1. */
#define BM_QuadSPI_LUT28_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT28_OPRND1. */
#define BS_QuadSPI_LUT28_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT28_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT28_OPRND1 field. */
#define BR_QuadSPI_LUT28_OPRND1(x) (HW_QuadSPI_LUT28(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT28_OPRND1. */
#define BF_QuadSPI_LUT28_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT28_OPRND1) & BM_QuadSPI_LUT28_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT28_OPRND1(x, v) (HW_QuadSPI_LUT28_WR(x, (HW_QuadSPI_LUT28_RD(x) & ~BM_QuadSPI_LUT28_OPRND1) | BF_QuadSPI_LUT28_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT28, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT28_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT28_PAD1. */
#define BM_QuadSPI_LUT28_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT28_PAD1. */
#define BS_QuadSPI_LUT28_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT28_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT28_PAD1 field. */
#define BR_QuadSPI_LUT28_PAD1(x) (HW_QuadSPI_LUT28(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT28_PAD1. */
#define BF_QuadSPI_LUT28_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT28_PAD1) & BM_QuadSPI_LUT28_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT28_PAD1(x, v) (HW_QuadSPI_LUT28_WR(x, (HW_QuadSPI_LUT28_RD(x) & ~BM_QuadSPI_LUT28_PAD1) | BF_QuadSPI_LUT28_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT28, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT28_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT28_INSTR1. */
#define BM_QuadSPI_LUT28_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT28_INSTR1. */
#define BS_QuadSPI_LUT28_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT28_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT28_INSTR1 field. */
#define BR_QuadSPI_LUT28_INSTR1(x) (HW_QuadSPI_LUT28(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT28_INSTR1. */
#define BF_QuadSPI_LUT28_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT28_INSTR1) & BM_QuadSPI_LUT28_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT28_INSTR1(x, v) (HW_QuadSPI_LUT28_WR(x, (HW_QuadSPI_LUT28_RD(x) & ~BM_QuadSPI_LUT28_INSTR1) | BF_QuadSPI_LUT28_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT29 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT29 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut29
{
    uint32_t U;
    struct _hw_quadspi_lut29_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut29_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT29 register
 */
/*@{*/
#define HW_QuadSPI_LUT29_ADDR(x) ((uintptr_t)(x) + 0x384U)

#define HW_QuadSPI_LUT29(x)      (*(__IO hw_quadspi_lut29_t *) HW_QuadSPI_LUT29_ADDR(x))
#define HW_QuadSPI_LUT29_RD(x)   (HW_QuadSPI_LUT29(x).U)
#define HW_QuadSPI_LUT29_WR(x, v) (HW_QuadSPI_LUT29(x).U = (v))
#define HW_QuadSPI_LUT29_SET(x, v) (HW_QuadSPI_LUT29_WR(x, HW_QuadSPI_LUT29_RD(x) |  (v)))
#define HW_QuadSPI_LUT29_CLR(x, v) (HW_QuadSPI_LUT29_WR(x, HW_QuadSPI_LUT29_RD(x) & ~(v)))
#define HW_QuadSPI_LUT29_TOG(x, v) (HW_QuadSPI_LUT29_WR(x, HW_QuadSPI_LUT29_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT29 bitfields
 */

/*!
 * @name Register QuadSPI_LUT29, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT29_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT29_OPRND0. */
#define BM_QuadSPI_LUT29_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT29_OPRND0. */
#define BS_QuadSPI_LUT29_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT29_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT29_OPRND0 field. */
#define BR_QuadSPI_LUT29_OPRND0(x) (HW_QuadSPI_LUT29(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT29_OPRND0. */
#define BF_QuadSPI_LUT29_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT29_OPRND0) & BM_QuadSPI_LUT29_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT29_OPRND0(x, v) (HW_QuadSPI_LUT29_WR(x, (HW_QuadSPI_LUT29_RD(x) & ~BM_QuadSPI_LUT29_OPRND0) | BF_QuadSPI_LUT29_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT29, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT29_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT29_PAD0. */
#define BM_QuadSPI_LUT29_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT29_PAD0. */
#define BS_QuadSPI_LUT29_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT29_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT29_PAD0 field. */
#define BR_QuadSPI_LUT29_PAD0(x) (HW_QuadSPI_LUT29(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT29_PAD0. */
#define BF_QuadSPI_LUT29_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT29_PAD0) & BM_QuadSPI_LUT29_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT29_PAD0(x, v) (HW_QuadSPI_LUT29_WR(x, (HW_QuadSPI_LUT29_RD(x) & ~BM_QuadSPI_LUT29_PAD0) | BF_QuadSPI_LUT29_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT29, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT29_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT29_INSTR0. */
#define BM_QuadSPI_LUT29_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT29_INSTR0. */
#define BS_QuadSPI_LUT29_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT29_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT29_INSTR0 field. */
#define BR_QuadSPI_LUT29_INSTR0(x) (HW_QuadSPI_LUT29(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT29_INSTR0. */
#define BF_QuadSPI_LUT29_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT29_INSTR0) & BM_QuadSPI_LUT29_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT29_INSTR0(x, v) (HW_QuadSPI_LUT29_WR(x, (HW_QuadSPI_LUT29_RD(x) & ~BM_QuadSPI_LUT29_INSTR0) | BF_QuadSPI_LUT29_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT29, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT29_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT29_OPRND1. */
#define BM_QuadSPI_LUT29_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT29_OPRND1. */
#define BS_QuadSPI_LUT29_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT29_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT29_OPRND1 field. */
#define BR_QuadSPI_LUT29_OPRND1(x) (HW_QuadSPI_LUT29(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT29_OPRND1. */
#define BF_QuadSPI_LUT29_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT29_OPRND1) & BM_QuadSPI_LUT29_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT29_OPRND1(x, v) (HW_QuadSPI_LUT29_WR(x, (HW_QuadSPI_LUT29_RD(x) & ~BM_QuadSPI_LUT29_OPRND1) | BF_QuadSPI_LUT29_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT29, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT29_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT29_PAD1. */
#define BM_QuadSPI_LUT29_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT29_PAD1. */
#define BS_QuadSPI_LUT29_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT29_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT29_PAD1 field. */
#define BR_QuadSPI_LUT29_PAD1(x) (HW_QuadSPI_LUT29(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT29_PAD1. */
#define BF_QuadSPI_LUT29_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT29_PAD1) & BM_QuadSPI_LUT29_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT29_PAD1(x, v) (HW_QuadSPI_LUT29_WR(x, (HW_QuadSPI_LUT29_RD(x) & ~BM_QuadSPI_LUT29_PAD1) | BF_QuadSPI_LUT29_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT29, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT29_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT29_INSTR1. */
#define BM_QuadSPI_LUT29_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT29_INSTR1. */
#define BS_QuadSPI_LUT29_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT29_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT29_INSTR1 field. */
#define BR_QuadSPI_LUT29_INSTR1(x) (HW_QuadSPI_LUT29(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT29_INSTR1. */
#define BF_QuadSPI_LUT29_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT29_INSTR1) & BM_QuadSPI_LUT29_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT29_INSTR1(x, v) (HW_QuadSPI_LUT29_WR(x, (HW_QuadSPI_LUT29_RD(x) & ~BM_QuadSPI_LUT29_INSTR1) | BF_QuadSPI_LUT29_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT30 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT30 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut30
{
    uint32_t U;
    struct _hw_quadspi_lut30_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut30_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT30 register
 */
/*@{*/
#define HW_QuadSPI_LUT30_ADDR(x) ((uintptr_t)(x) + 0x388U)

#define HW_QuadSPI_LUT30(x)      (*(__IO hw_quadspi_lut30_t *) HW_QuadSPI_LUT30_ADDR(x))
#define HW_QuadSPI_LUT30_RD(x)   (HW_QuadSPI_LUT30(x).U)
#define HW_QuadSPI_LUT30_WR(x, v) (HW_QuadSPI_LUT30(x).U = (v))
#define HW_QuadSPI_LUT30_SET(x, v) (HW_QuadSPI_LUT30_WR(x, HW_QuadSPI_LUT30_RD(x) |  (v)))
#define HW_QuadSPI_LUT30_CLR(x, v) (HW_QuadSPI_LUT30_WR(x, HW_QuadSPI_LUT30_RD(x) & ~(v)))
#define HW_QuadSPI_LUT30_TOG(x, v) (HW_QuadSPI_LUT30_WR(x, HW_QuadSPI_LUT30_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT30 bitfields
 */

/*!
 * @name Register QuadSPI_LUT30, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT30_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT30_OPRND0. */
#define BM_QuadSPI_LUT30_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT30_OPRND0. */
#define BS_QuadSPI_LUT30_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT30_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT30_OPRND0 field. */
#define BR_QuadSPI_LUT30_OPRND0(x) (HW_QuadSPI_LUT30(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT30_OPRND0. */
#define BF_QuadSPI_LUT30_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT30_OPRND0) & BM_QuadSPI_LUT30_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT30_OPRND0(x, v) (HW_QuadSPI_LUT30_WR(x, (HW_QuadSPI_LUT30_RD(x) & ~BM_QuadSPI_LUT30_OPRND0) | BF_QuadSPI_LUT30_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT30, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT30_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT30_PAD0. */
#define BM_QuadSPI_LUT30_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT30_PAD0. */
#define BS_QuadSPI_LUT30_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT30_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT30_PAD0 field. */
#define BR_QuadSPI_LUT30_PAD0(x) (HW_QuadSPI_LUT30(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT30_PAD0. */
#define BF_QuadSPI_LUT30_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT30_PAD0) & BM_QuadSPI_LUT30_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT30_PAD0(x, v) (HW_QuadSPI_LUT30_WR(x, (HW_QuadSPI_LUT30_RD(x) & ~BM_QuadSPI_LUT30_PAD0) | BF_QuadSPI_LUT30_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT30, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT30_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT30_INSTR0. */
#define BM_QuadSPI_LUT30_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT30_INSTR0. */
#define BS_QuadSPI_LUT30_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT30_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT30_INSTR0 field. */
#define BR_QuadSPI_LUT30_INSTR0(x) (HW_QuadSPI_LUT30(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT30_INSTR0. */
#define BF_QuadSPI_LUT30_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT30_INSTR0) & BM_QuadSPI_LUT30_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT30_INSTR0(x, v) (HW_QuadSPI_LUT30_WR(x, (HW_QuadSPI_LUT30_RD(x) & ~BM_QuadSPI_LUT30_INSTR0) | BF_QuadSPI_LUT30_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT30, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT30_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT30_OPRND1. */
#define BM_QuadSPI_LUT30_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT30_OPRND1. */
#define BS_QuadSPI_LUT30_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT30_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT30_OPRND1 field. */
#define BR_QuadSPI_LUT30_OPRND1(x) (HW_QuadSPI_LUT30(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT30_OPRND1. */
#define BF_QuadSPI_LUT30_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT30_OPRND1) & BM_QuadSPI_LUT30_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT30_OPRND1(x, v) (HW_QuadSPI_LUT30_WR(x, (HW_QuadSPI_LUT30_RD(x) & ~BM_QuadSPI_LUT30_OPRND1) | BF_QuadSPI_LUT30_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT30, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT30_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT30_PAD1. */
#define BM_QuadSPI_LUT30_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT30_PAD1. */
#define BS_QuadSPI_LUT30_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT30_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT30_PAD1 field. */
#define BR_QuadSPI_LUT30_PAD1(x) (HW_QuadSPI_LUT30(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT30_PAD1. */
#define BF_QuadSPI_LUT30_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT30_PAD1) & BM_QuadSPI_LUT30_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT30_PAD1(x, v) (HW_QuadSPI_LUT30_WR(x, (HW_QuadSPI_LUT30_RD(x) & ~BM_QuadSPI_LUT30_PAD1) | BF_QuadSPI_LUT30_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT30, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT30_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT30_INSTR1. */
#define BM_QuadSPI_LUT30_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT30_INSTR1. */
#define BS_QuadSPI_LUT30_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT30_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT30_INSTR1 field. */
#define BR_QuadSPI_LUT30_INSTR1(x) (HW_QuadSPI_LUT30(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT30_INSTR1. */
#define BF_QuadSPI_LUT30_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT30_INSTR1) & BM_QuadSPI_LUT30_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT30_INSTR1(x, v) (HW_QuadSPI_LUT30_WR(x, (HW_QuadSPI_LUT30_RD(x) & ~BM_QuadSPI_LUT30_INSTR1) | BF_QuadSPI_LUT30_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT31 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT31 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut31
{
    uint32_t U;
    struct _hw_quadspi_lut31_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut31_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT31 register
 */
/*@{*/
#define HW_QuadSPI_LUT31_ADDR(x) ((uintptr_t)(x) + 0x38CU)

#define HW_QuadSPI_LUT31(x)      (*(__IO hw_quadspi_lut31_t *) HW_QuadSPI_LUT31_ADDR(x))
#define HW_QuadSPI_LUT31_RD(x)   (HW_QuadSPI_LUT31(x).U)
#define HW_QuadSPI_LUT31_WR(x, v) (HW_QuadSPI_LUT31(x).U = (v))
#define HW_QuadSPI_LUT31_SET(x, v) (HW_QuadSPI_LUT31_WR(x, HW_QuadSPI_LUT31_RD(x) |  (v)))
#define HW_QuadSPI_LUT31_CLR(x, v) (HW_QuadSPI_LUT31_WR(x, HW_QuadSPI_LUT31_RD(x) & ~(v)))
#define HW_QuadSPI_LUT31_TOG(x, v) (HW_QuadSPI_LUT31_WR(x, HW_QuadSPI_LUT31_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT31 bitfields
 */

/*!
 * @name Register QuadSPI_LUT31, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT31_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT31_OPRND0. */
#define BM_QuadSPI_LUT31_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT31_OPRND0. */
#define BS_QuadSPI_LUT31_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT31_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT31_OPRND0 field. */
#define BR_QuadSPI_LUT31_OPRND0(x) (HW_QuadSPI_LUT31(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT31_OPRND0. */
#define BF_QuadSPI_LUT31_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT31_OPRND0) & BM_QuadSPI_LUT31_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT31_OPRND0(x, v) (HW_QuadSPI_LUT31_WR(x, (HW_QuadSPI_LUT31_RD(x) & ~BM_QuadSPI_LUT31_OPRND0) | BF_QuadSPI_LUT31_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT31, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT31_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT31_PAD0. */
#define BM_QuadSPI_LUT31_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT31_PAD0. */
#define BS_QuadSPI_LUT31_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT31_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT31_PAD0 field. */
#define BR_QuadSPI_LUT31_PAD0(x) (HW_QuadSPI_LUT31(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT31_PAD0. */
#define BF_QuadSPI_LUT31_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT31_PAD0) & BM_QuadSPI_LUT31_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT31_PAD0(x, v) (HW_QuadSPI_LUT31_WR(x, (HW_QuadSPI_LUT31_RD(x) & ~BM_QuadSPI_LUT31_PAD0) | BF_QuadSPI_LUT31_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT31, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT31_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT31_INSTR0. */
#define BM_QuadSPI_LUT31_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT31_INSTR0. */
#define BS_QuadSPI_LUT31_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT31_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT31_INSTR0 field. */
#define BR_QuadSPI_LUT31_INSTR0(x) (HW_QuadSPI_LUT31(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT31_INSTR0. */
#define BF_QuadSPI_LUT31_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT31_INSTR0) & BM_QuadSPI_LUT31_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT31_INSTR0(x, v) (HW_QuadSPI_LUT31_WR(x, (HW_QuadSPI_LUT31_RD(x) & ~BM_QuadSPI_LUT31_INSTR0) | BF_QuadSPI_LUT31_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT31, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT31_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT31_OPRND1. */
#define BM_QuadSPI_LUT31_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT31_OPRND1. */
#define BS_QuadSPI_LUT31_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT31_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT31_OPRND1 field. */
#define BR_QuadSPI_LUT31_OPRND1(x) (HW_QuadSPI_LUT31(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT31_OPRND1. */
#define BF_QuadSPI_LUT31_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT31_OPRND1) & BM_QuadSPI_LUT31_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT31_OPRND1(x, v) (HW_QuadSPI_LUT31_WR(x, (HW_QuadSPI_LUT31_RD(x) & ~BM_QuadSPI_LUT31_OPRND1) | BF_QuadSPI_LUT31_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT31, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT31_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT31_PAD1. */
#define BM_QuadSPI_LUT31_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT31_PAD1. */
#define BS_QuadSPI_LUT31_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT31_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT31_PAD1 field. */
#define BR_QuadSPI_LUT31_PAD1(x) (HW_QuadSPI_LUT31(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT31_PAD1. */
#define BF_QuadSPI_LUT31_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT31_PAD1) & BM_QuadSPI_LUT31_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT31_PAD1(x, v) (HW_QuadSPI_LUT31_WR(x, (HW_QuadSPI_LUT31_RD(x) & ~BM_QuadSPI_LUT31_PAD1) | BF_QuadSPI_LUT31_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT31, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT31_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT31_INSTR1. */
#define BM_QuadSPI_LUT31_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT31_INSTR1. */
#define BS_QuadSPI_LUT31_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT31_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT31_INSTR1 field. */
#define BR_QuadSPI_LUT31_INSTR1(x) (HW_QuadSPI_LUT31(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT31_INSTR1. */
#define BF_QuadSPI_LUT31_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT31_INSTR1) & BM_QuadSPI_LUT31_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT31_INSTR1(x, v) (HW_QuadSPI_LUT31_WR(x, (HW_QuadSPI_LUT31_RD(x) & ~BM_QuadSPI_LUT31_INSTR1) | BF_QuadSPI_LUT31_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT32 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT32 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut32
{
    uint32_t U;
    struct _hw_quadspi_lut32_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut32_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT32 register
 */
/*@{*/
#define HW_QuadSPI_LUT32_ADDR(x) ((uintptr_t)(x) + 0x390U)

#define HW_QuadSPI_LUT32(x)      (*(__IO hw_quadspi_lut32_t *) HW_QuadSPI_LUT32_ADDR(x))
#define HW_QuadSPI_LUT32_RD(x)   (HW_QuadSPI_LUT32(x).U)
#define HW_QuadSPI_LUT32_WR(x, v) (HW_QuadSPI_LUT32(x).U = (v))
#define HW_QuadSPI_LUT32_SET(x, v) (HW_QuadSPI_LUT32_WR(x, HW_QuadSPI_LUT32_RD(x) |  (v)))
#define HW_QuadSPI_LUT32_CLR(x, v) (HW_QuadSPI_LUT32_WR(x, HW_QuadSPI_LUT32_RD(x) & ~(v)))
#define HW_QuadSPI_LUT32_TOG(x, v) (HW_QuadSPI_LUT32_WR(x, HW_QuadSPI_LUT32_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT32 bitfields
 */

/*!
 * @name Register QuadSPI_LUT32, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT32_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT32_OPRND0. */
#define BM_QuadSPI_LUT32_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT32_OPRND0. */
#define BS_QuadSPI_LUT32_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT32_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT32_OPRND0 field. */
#define BR_QuadSPI_LUT32_OPRND0(x) (HW_QuadSPI_LUT32(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT32_OPRND0. */
#define BF_QuadSPI_LUT32_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT32_OPRND0) & BM_QuadSPI_LUT32_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT32_OPRND0(x, v) (HW_QuadSPI_LUT32_WR(x, (HW_QuadSPI_LUT32_RD(x) & ~BM_QuadSPI_LUT32_OPRND0) | BF_QuadSPI_LUT32_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT32, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT32_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT32_PAD0. */
#define BM_QuadSPI_LUT32_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT32_PAD0. */
#define BS_QuadSPI_LUT32_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT32_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT32_PAD0 field. */
#define BR_QuadSPI_LUT32_PAD0(x) (HW_QuadSPI_LUT32(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT32_PAD0. */
#define BF_QuadSPI_LUT32_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT32_PAD0) & BM_QuadSPI_LUT32_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT32_PAD0(x, v) (HW_QuadSPI_LUT32_WR(x, (HW_QuadSPI_LUT32_RD(x) & ~BM_QuadSPI_LUT32_PAD0) | BF_QuadSPI_LUT32_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT32, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT32_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT32_INSTR0. */
#define BM_QuadSPI_LUT32_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT32_INSTR0. */
#define BS_QuadSPI_LUT32_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT32_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT32_INSTR0 field. */
#define BR_QuadSPI_LUT32_INSTR0(x) (HW_QuadSPI_LUT32(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT32_INSTR0. */
#define BF_QuadSPI_LUT32_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT32_INSTR0) & BM_QuadSPI_LUT32_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT32_INSTR0(x, v) (HW_QuadSPI_LUT32_WR(x, (HW_QuadSPI_LUT32_RD(x) & ~BM_QuadSPI_LUT32_INSTR0) | BF_QuadSPI_LUT32_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT32, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT32_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT32_OPRND1. */
#define BM_QuadSPI_LUT32_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT32_OPRND1. */
#define BS_QuadSPI_LUT32_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT32_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT32_OPRND1 field. */
#define BR_QuadSPI_LUT32_OPRND1(x) (HW_QuadSPI_LUT32(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT32_OPRND1. */
#define BF_QuadSPI_LUT32_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT32_OPRND1) & BM_QuadSPI_LUT32_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT32_OPRND1(x, v) (HW_QuadSPI_LUT32_WR(x, (HW_QuadSPI_LUT32_RD(x) & ~BM_QuadSPI_LUT32_OPRND1) | BF_QuadSPI_LUT32_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT32, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT32_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT32_PAD1. */
#define BM_QuadSPI_LUT32_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT32_PAD1. */
#define BS_QuadSPI_LUT32_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT32_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT32_PAD1 field. */
#define BR_QuadSPI_LUT32_PAD1(x) (HW_QuadSPI_LUT32(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT32_PAD1. */
#define BF_QuadSPI_LUT32_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT32_PAD1) & BM_QuadSPI_LUT32_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT32_PAD1(x, v) (HW_QuadSPI_LUT32_WR(x, (HW_QuadSPI_LUT32_RD(x) & ~BM_QuadSPI_LUT32_PAD1) | BF_QuadSPI_LUT32_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT32, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT32_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT32_INSTR1. */
#define BM_QuadSPI_LUT32_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT32_INSTR1. */
#define BS_QuadSPI_LUT32_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT32_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT32_INSTR1 field. */
#define BR_QuadSPI_LUT32_INSTR1(x) (HW_QuadSPI_LUT32(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT32_INSTR1. */
#define BF_QuadSPI_LUT32_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT32_INSTR1) & BM_QuadSPI_LUT32_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT32_INSTR1(x, v) (HW_QuadSPI_LUT32_WR(x, (HW_QuadSPI_LUT32_RD(x) & ~BM_QuadSPI_LUT32_INSTR1) | BF_QuadSPI_LUT32_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT33 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT33 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut33
{
    uint32_t U;
    struct _hw_quadspi_lut33_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut33_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT33 register
 */
/*@{*/
#define HW_QuadSPI_LUT33_ADDR(x) ((uintptr_t)(x) + 0x394U)

#define HW_QuadSPI_LUT33(x)      (*(__IO hw_quadspi_lut33_t *) HW_QuadSPI_LUT33_ADDR(x))
#define HW_QuadSPI_LUT33_RD(x)   (HW_QuadSPI_LUT33(x).U)
#define HW_QuadSPI_LUT33_WR(x, v) (HW_QuadSPI_LUT33(x).U = (v))
#define HW_QuadSPI_LUT33_SET(x, v) (HW_QuadSPI_LUT33_WR(x, HW_QuadSPI_LUT33_RD(x) |  (v)))
#define HW_QuadSPI_LUT33_CLR(x, v) (HW_QuadSPI_LUT33_WR(x, HW_QuadSPI_LUT33_RD(x) & ~(v)))
#define HW_QuadSPI_LUT33_TOG(x, v) (HW_QuadSPI_LUT33_WR(x, HW_QuadSPI_LUT33_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT33 bitfields
 */

/*!
 * @name Register QuadSPI_LUT33, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT33_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT33_OPRND0. */
#define BM_QuadSPI_LUT33_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT33_OPRND0. */
#define BS_QuadSPI_LUT33_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT33_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT33_OPRND0 field. */
#define BR_QuadSPI_LUT33_OPRND0(x) (HW_QuadSPI_LUT33(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT33_OPRND0. */
#define BF_QuadSPI_LUT33_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT33_OPRND0) & BM_QuadSPI_LUT33_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT33_OPRND0(x, v) (HW_QuadSPI_LUT33_WR(x, (HW_QuadSPI_LUT33_RD(x) & ~BM_QuadSPI_LUT33_OPRND0) | BF_QuadSPI_LUT33_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT33, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT33_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT33_PAD0. */
#define BM_QuadSPI_LUT33_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT33_PAD0. */
#define BS_QuadSPI_LUT33_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT33_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT33_PAD0 field. */
#define BR_QuadSPI_LUT33_PAD0(x) (HW_QuadSPI_LUT33(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT33_PAD0. */
#define BF_QuadSPI_LUT33_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT33_PAD0) & BM_QuadSPI_LUT33_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT33_PAD0(x, v) (HW_QuadSPI_LUT33_WR(x, (HW_QuadSPI_LUT33_RD(x) & ~BM_QuadSPI_LUT33_PAD0) | BF_QuadSPI_LUT33_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT33, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT33_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT33_INSTR0. */
#define BM_QuadSPI_LUT33_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT33_INSTR0. */
#define BS_QuadSPI_LUT33_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT33_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT33_INSTR0 field. */
#define BR_QuadSPI_LUT33_INSTR0(x) (HW_QuadSPI_LUT33(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT33_INSTR0. */
#define BF_QuadSPI_LUT33_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT33_INSTR0) & BM_QuadSPI_LUT33_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT33_INSTR0(x, v) (HW_QuadSPI_LUT33_WR(x, (HW_QuadSPI_LUT33_RD(x) & ~BM_QuadSPI_LUT33_INSTR0) | BF_QuadSPI_LUT33_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT33, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT33_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT33_OPRND1. */
#define BM_QuadSPI_LUT33_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT33_OPRND1. */
#define BS_QuadSPI_LUT33_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT33_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT33_OPRND1 field. */
#define BR_QuadSPI_LUT33_OPRND1(x) (HW_QuadSPI_LUT33(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT33_OPRND1. */
#define BF_QuadSPI_LUT33_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT33_OPRND1) & BM_QuadSPI_LUT33_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT33_OPRND1(x, v) (HW_QuadSPI_LUT33_WR(x, (HW_QuadSPI_LUT33_RD(x) & ~BM_QuadSPI_LUT33_OPRND1) | BF_QuadSPI_LUT33_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT33, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT33_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT33_PAD1. */
#define BM_QuadSPI_LUT33_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT33_PAD1. */
#define BS_QuadSPI_LUT33_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT33_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT33_PAD1 field. */
#define BR_QuadSPI_LUT33_PAD1(x) (HW_QuadSPI_LUT33(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT33_PAD1. */
#define BF_QuadSPI_LUT33_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT33_PAD1) & BM_QuadSPI_LUT33_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT33_PAD1(x, v) (HW_QuadSPI_LUT33_WR(x, (HW_QuadSPI_LUT33_RD(x) & ~BM_QuadSPI_LUT33_PAD1) | BF_QuadSPI_LUT33_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT33, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT33_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT33_INSTR1. */
#define BM_QuadSPI_LUT33_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT33_INSTR1. */
#define BS_QuadSPI_LUT33_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT33_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT33_INSTR1 field. */
#define BR_QuadSPI_LUT33_INSTR1(x) (HW_QuadSPI_LUT33(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT33_INSTR1. */
#define BF_QuadSPI_LUT33_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT33_INSTR1) & BM_QuadSPI_LUT33_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT33_INSTR1(x, v) (HW_QuadSPI_LUT33_WR(x, (HW_QuadSPI_LUT33_RD(x) & ~BM_QuadSPI_LUT33_INSTR1) | BF_QuadSPI_LUT33_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT34 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT34 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut34
{
    uint32_t U;
    struct _hw_quadspi_lut34_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut34_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT34 register
 */
/*@{*/
#define HW_QuadSPI_LUT34_ADDR(x) ((uintptr_t)(x) + 0x398U)

#define HW_QuadSPI_LUT34(x)      (*(__IO hw_quadspi_lut34_t *) HW_QuadSPI_LUT34_ADDR(x))
#define HW_QuadSPI_LUT34_RD(x)   (HW_QuadSPI_LUT34(x).U)
#define HW_QuadSPI_LUT34_WR(x, v) (HW_QuadSPI_LUT34(x).U = (v))
#define HW_QuadSPI_LUT34_SET(x, v) (HW_QuadSPI_LUT34_WR(x, HW_QuadSPI_LUT34_RD(x) |  (v)))
#define HW_QuadSPI_LUT34_CLR(x, v) (HW_QuadSPI_LUT34_WR(x, HW_QuadSPI_LUT34_RD(x) & ~(v)))
#define HW_QuadSPI_LUT34_TOG(x, v) (HW_QuadSPI_LUT34_WR(x, HW_QuadSPI_LUT34_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT34 bitfields
 */

/*!
 * @name Register QuadSPI_LUT34, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT34_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT34_OPRND0. */
#define BM_QuadSPI_LUT34_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT34_OPRND0. */
#define BS_QuadSPI_LUT34_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT34_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT34_OPRND0 field. */
#define BR_QuadSPI_LUT34_OPRND0(x) (HW_QuadSPI_LUT34(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT34_OPRND0. */
#define BF_QuadSPI_LUT34_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT34_OPRND0) & BM_QuadSPI_LUT34_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT34_OPRND0(x, v) (HW_QuadSPI_LUT34_WR(x, (HW_QuadSPI_LUT34_RD(x) & ~BM_QuadSPI_LUT34_OPRND0) | BF_QuadSPI_LUT34_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT34, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT34_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT34_PAD0. */
#define BM_QuadSPI_LUT34_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT34_PAD0. */
#define BS_QuadSPI_LUT34_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT34_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT34_PAD0 field. */
#define BR_QuadSPI_LUT34_PAD0(x) (HW_QuadSPI_LUT34(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT34_PAD0. */
#define BF_QuadSPI_LUT34_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT34_PAD0) & BM_QuadSPI_LUT34_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT34_PAD0(x, v) (HW_QuadSPI_LUT34_WR(x, (HW_QuadSPI_LUT34_RD(x) & ~BM_QuadSPI_LUT34_PAD0) | BF_QuadSPI_LUT34_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT34, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT34_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT34_INSTR0. */
#define BM_QuadSPI_LUT34_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT34_INSTR0. */
#define BS_QuadSPI_LUT34_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT34_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT34_INSTR0 field. */
#define BR_QuadSPI_LUT34_INSTR0(x) (HW_QuadSPI_LUT34(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT34_INSTR0. */
#define BF_QuadSPI_LUT34_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT34_INSTR0) & BM_QuadSPI_LUT34_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT34_INSTR0(x, v) (HW_QuadSPI_LUT34_WR(x, (HW_QuadSPI_LUT34_RD(x) & ~BM_QuadSPI_LUT34_INSTR0) | BF_QuadSPI_LUT34_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT34, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT34_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT34_OPRND1. */
#define BM_QuadSPI_LUT34_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT34_OPRND1. */
#define BS_QuadSPI_LUT34_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT34_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT34_OPRND1 field. */
#define BR_QuadSPI_LUT34_OPRND1(x) (HW_QuadSPI_LUT34(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT34_OPRND1. */
#define BF_QuadSPI_LUT34_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT34_OPRND1) & BM_QuadSPI_LUT34_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT34_OPRND1(x, v) (HW_QuadSPI_LUT34_WR(x, (HW_QuadSPI_LUT34_RD(x) & ~BM_QuadSPI_LUT34_OPRND1) | BF_QuadSPI_LUT34_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT34, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT34_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT34_PAD1. */
#define BM_QuadSPI_LUT34_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT34_PAD1. */
#define BS_QuadSPI_LUT34_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT34_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT34_PAD1 field. */
#define BR_QuadSPI_LUT34_PAD1(x) (HW_QuadSPI_LUT34(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT34_PAD1. */
#define BF_QuadSPI_LUT34_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT34_PAD1) & BM_QuadSPI_LUT34_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT34_PAD1(x, v) (HW_QuadSPI_LUT34_WR(x, (HW_QuadSPI_LUT34_RD(x) & ~BM_QuadSPI_LUT34_PAD1) | BF_QuadSPI_LUT34_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT34, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT34_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT34_INSTR1. */
#define BM_QuadSPI_LUT34_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT34_INSTR1. */
#define BS_QuadSPI_LUT34_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT34_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT34_INSTR1 field. */
#define BR_QuadSPI_LUT34_INSTR1(x) (HW_QuadSPI_LUT34(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT34_INSTR1. */
#define BF_QuadSPI_LUT34_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT34_INSTR1) & BM_QuadSPI_LUT34_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT34_INSTR1(x, v) (HW_QuadSPI_LUT34_WR(x, (HW_QuadSPI_LUT34_RD(x) & ~BM_QuadSPI_LUT34_INSTR1) | BF_QuadSPI_LUT34_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT35 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT35 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut35
{
    uint32_t U;
    struct _hw_quadspi_lut35_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut35_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT35 register
 */
/*@{*/
#define HW_QuadSPI_LUT35_ADDR(x) ((uintptr_t)(x) + 0x39CU)

#define HW_QuadSPI_LUT35(x)      (*(__IO hw_quadspi_lut35_t *) HW_QuadSPI_LUT35_ADDR(x))
#define HW_QuadSPI_LUT35_RD(x)   (HW_QuadSPI_LUT35(x).U)
#define HW_QuadSPI_LUT35_WR(x, v) (HW_QuadSPI_LUT35(x).U = (v))
#define HW_QuadSPI_LUT35_SET(x, v) (HW_QuadSPI_LUT35_WR(x, HW_QuadSPI_LUT35_RD(x) |  (v)))
#define HW_QuadSPI_LUT35_CLR(x, v) (HW_QuadSPI_LUT35_WR(x, HW_QuadSPI_LUT35_RD(x) & ~(v)))
#define HW_QuadSPI_LUT35_TOG(x, v) (HW_QuadSPI_LUT35_WR(x, HW_QuadSPI_LUT35_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT35 bitfields
 */

/*!
 * @name Register QuadSPI_LUT35, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT35_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT35_OPRND0. */
#define BM_QuadSPI_LUT35_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT35_OPRND0. */
#define BS_QuadSPI_LUT35_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT35_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT35_OPRND0 field. */
#define BR_QuadSPI_LUT35_OPRND0(x) (HW_QuadSPI_LUT35(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT35_OPRND0. */
#define BF_QuadSPI_LUT35_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT35_OPRND0) & BM_QuadSPI_LUT35_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT35_OPRND0(x, v) (HW_QuadSPI_LUT35_WR(x, (HW_QuadSPI_LUT35_RD(x) & ~BM_QuadSPI_LUT35_OPRND0) | BF_QuadSPI_LUT35_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT35, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT35_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT35_PAD0. */
#define BM_QuadSPI_LUT35_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT35_PAD0. */
#define BS_QuadSPI_LUT35_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT35_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT35_PAD0 field. */
#define BR_QuadSPI_LUT35_PAD0(x) (HW_QuadSPI_LUT35(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT35_PAD0. */
#define BF_QuadSPI_LUT35_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT35_PAD0) & BM_QuadSPI_LUT35_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT35_PAD0(x, v) (HW_QuadSPI_LUT35_WR(x, (HW_QuadSPI_LUT35_RD(x) & ~BM_QuadSPI_LUT35_PAD0) | BF_QuadSPI_LUT35_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT35, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT35_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT35_INSTR0. */
#define BM_QuadSPI_LUT35_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT35_INSTR0. */
#define BS_QuadSPI_LUT35_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT35_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT35_INSTR0 field. */
#define BR_QuadSPI_LUT35_INSTR0(x) (HW_QuadSPI_LUT35(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT35_INSTR0. */
#define BF_QuadSPI_LUT35_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT35_INSTR0) & BM_QuadSPI_LUT35_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT35_INSTR0(x, v) (HW_QuadSPI_LUT35_WR(x, (HW_QuadSPI_LUT35_RD(x) & ~BM_QuadSPI_LUT35_INSTR0) | BF_QuadSPI_LUT35_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT35, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT35_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT35_OPRND1. */
#define BM_QuadSPI_LUT35_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT35_OPRND1. */
#define BS_QuadSPI_LUT35_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT35_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT35_OPRND1 field. */
#define BR_QuadSPI_LUT35_OPRND1(x) (HW_QuadSPI_LUT35(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT35_OPRND1. */
#define BF_QuadSPI_LUT35_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT35_OPRND1) & BM_QuadSPI_LUT35_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT35_OPRND1(x, v) (HW_QuadSPI_LUT35_WR(x, (HW_QuadSPI_LUT35_RD(x) & ~BM_QuadSPI_LUT35_OPRND1) | BF_QuadSPI_LUT35_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT35, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT35_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT35_PAD1. */
#define BM_QuadSPI_LUT35_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT35_PAD1. */
#define BS_QuadSPI_LUT35_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT35_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT35_PAD1 field. */
#define BR_QuadSPI_LUT35_PAD1(x) (HW_QuadSPI_LUT35(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT35_PAD1. */
#define BF_QuadSPI_LUT35_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT35_PAD1) & BM_QuadSPI_LUT35_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT35_PAD1(x, v) (HW_QuadSPI_LUT35_WR(x, (HW_QuadSPI_LUT35_RD(x) & ~BM_QuadSPI_LUT35_PAD1) | BF_QuadSPI_LUT35_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT35, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT35_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT35_INSTR1. */
#define BM_QuadSPI_LUT35_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT35_INSTR1. */
#define BS_QuadSPI_LUT35_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT35_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT35_INSTR1 field. */
#define BR_QuadSPI_LUT35_INSTR1(x) (HW_QuadSPI_LUT35(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT35_INSTR1. */
#define BF_QuadSPI_LUT35_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT35_INSTR1) & BM_QuadSPI_LUT35_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT35_INSTR1(x, v) (HW_QuadSPI_LUT35_WR(x, (HW_QuadSPI_LUT35_RD(x) & ~BM_QuadSPI_LUT35_INSTR1) | BF_QuadSPI_LUT35_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT36 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT36 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut36
{
    uint32_t U;
    struct _hw_quadspi_lut36_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut36_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT36 register
 */
/*@{*/
#define HW_QuadSPI_LUT36_ADDR(x) ((uintptr_t)(x) + 0x3A0U)

#define HW_QuadSPI_LUT36(x)      (*(__IO hw_quadspi_lut36_t *) HW_QuadSPI_LUT36_ADDR(x))
#define HW_QuadSPI_LUT36_RD(x)   (HW_QuadSPI_LUT36(x).U)
#define HW_QuadSPI_LUT36_WR(x, v) (HW_QuadSPI_LUT36(x).U = (v))
#define HW_QuadSPI_LUT36_SET(x, v) (HW_QuadSPI_LUT36_WR(x, HW_QuadSPI_LUT36_RD(x) |  (v)))
#define HW_QuadSPI_LUT36_CLR(x, v) (HW_QuadSPI_LUT36_WR(x, HW_QuadSPI_LUT36_RD(x) & ~(v)))
#define HW_QuadSPI_LUT36_TOG(x, v) (HW_QuadSPI_LUT36_WR(x, HW_QuadSPI_LUT36_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT36 bitfields
 */

/*!
 * @name Register QuadSPI_LUT36, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT36_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT36_OPRND0. */
#define BM_QuadSPI_LUT36_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT36_OPRND0. */
#define BS_QuadSPI_LUT36_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT36_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT36_OPRND0 field. */
#define BR_QuadSPI_LUT36_OPRND0(x) (HW_QuadSPI_LUT36(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT36_OPRND0. */
#define BF_QuadSPI_LUT36_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT36_OPRND0) & BM_QuadSPI_LUT36_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT36_OPRND0(x, v) (HW_QuadSPI_LUT36_WR(x, (HW_QuadSPI_LUT36_RD(x) & ~BM_QuadSPI_LUT36_OPRND0) | BF_QuadSPI_LUT36_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT36, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT36_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT36_PAD0. */
#define BM_QuadSPI_LUT36_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT36_PAD0. */
#define BS_QuadSPI_LUT36_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT36_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT36_PAD0 field. */
#define BR_QuadSPI_LUT36_PAD0(x) (HW_QuadSPI_LUT36(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT36_PAD0. */
#define BF_QuadSPI_LUT36_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT36_PAD0) & BM_QuadSPI_LUT36_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT36_PAD0(x, v) (HW_QuadSPI_LUT36_WR(x, (HW_QuadSPI_LUT36_RD(x) & ~BM_QuadSPI_LUT36_PAD0) | BF_QuadSPI_LUT36_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT36, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT36_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT36_INSTR0. */
#define BM_QuadSPI_LUT36_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT36_INSTR0. */
#define BS_QuadSPI_LUT36_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT36_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT36_INSTR0 field. */
#define BR_QuadSPI_LUT36_INSTR0(x) (HW_QuadSPI_LUT36(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT36_INSTR0. */
#define BF_QuadSPI_LUT36_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT36_INSTR0) & BM_QuadSPI_LUT36_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT36_INSTR0(x, v) (HW_QuadSPI_LUT36_WR(x, (HW_QuadSPI_LUT36_RD(x) & ~BM_QuadSPI_LUT36_INSTR0) | BF_QuadSPI_LUT36_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT36, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT36_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT36_OPRND1. */
#define BM_QuadSPI_LUT36_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT36_OPRND1. */
#define BS_QuadSPI_LUT36_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT36_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT36_OPRND1 field. */
#define BR_QuadSPI_LUT36_OPRND1(x) (HW_QuadSPI_LUT36(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT36_OPRND1. */
#define BF_QuadSPI_LUT36_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT36_OPRND1) & BM_QuadSPI_LUT36_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT36_OPRND1(x, v) (HW_QuadSPI_LUT36_WR(x, (HW_QuadSPI_LUT36_RD(x) & ~BM_QuadSPI_LUT36_OPRND1) | BF_QuadSPI_LUT36_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT36, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT36_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT36_PAD1. */
#define BM_QuadSPI_LUT36_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT36_PAD1. */
#define BS_QuadSPI_LUT36_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT36_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT36_PAD1 field. */
#define BR_QuadSPI_LUT36_PAD1(x) (HW_QuadSPI_LUT36(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT36_PAD1. */
#define BF_QuadSPI_LUT36_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT36_PAD1) & BM_QuadSPI_LUT36_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT36_PAD1(x, v) (HW_QuadSPI_LUT36_WR(x, (HW_QuadSPI_LUT36_RD(x) & ~BM_QuadSPI_LUT36_PAD1) | BF_QuadSPI_LUT36_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT36, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT36_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT36_INSTR1. */
#define BM_QuadSPI_LUT36_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT36_INSTR1. */
#define BS_QuadSPI_LUT36_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT36_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT36_INSTR1 field. */
#define BR_QuadSPI_LUT36_INSTR1(x) (HW_QuadSPI_LUT36(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT36_INSTR1. */
#define BF_QuadSPI_LUT36_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT36_INSTR1) & BM_QuadSPI_LUT36_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT36_INSTR1(x, v) (HW_QuadSPI_LUT36_WR(x, (HW_QuadSPI_LUT36_RD(x) & ~BM_QuadSPI_LUT36_INSTR1) | BF_QuadSPI_LUT36_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT37 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT37 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut37
{
    uint32_t U;
    struct _hw_quadspi_lut37_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut37_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT37 register
 */
/*@{*/
#define HW_QuadSPI_LUT37_ADDR(x) ((uintptr_t)(x) + 0x3A4U)

#define HW_QuadSPI_LUT37(x)      (*(__IO hw_quadspi_lut37_t *) HW_QuadSPI_LUT37_ADDR(x))
#define HW_QuadSPI_LUT37_RD(x)   (HW_QuadSPI_LUT37(x).U)
#define HW_QuadSPI_LUT37_WR(x, v) (HW_QuadSPI_LUT37(x).U = (v))
#define HW_QuadSPI_LUT37_SET(x, v) (HW_QuadSPI_LUT37_WR(x, HW_QuadSPI_LUT37_RD(x) |  (v)))
#define HW_QuadSPI_LUT37_CLR(x, v) (HW_QuadSPI_LUT37_WR(x, HW_QuadSPI_LUT37_RD(x) & ~(v)))
#define HW_QuadSPI_LUT37_TOG(x, v) (HW_QuadSPI_LUT37_WR(x, HW_QuadSPI_LUT37_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT37 bitfields
 */

/*!
 * @name Register QuadSPI_LUT37, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT37_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT37_OPRND0. */
#define BM_QuadSPI_LUT37_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT37_OPRND0. */
#define BS_QuadSPI_LUT37_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT37_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT37_OPRND0 field. */
#define BR_QuadSPI_LUT37_OPRND0(x) (HW_QuadSPI_LUT37(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT37_OPRND0. */
#define BF_QuadSPI_LUT37_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT37_OPRND0) & BM_QuadSPI_LUT37_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT37_OPRND0(x, v) (HW_QuadSPI_LUT37_WR(x, (HW_QuadSPI_LUT37_RD(x) & ~BM_QuadSPI_LUT37_OPRND0) | BF_QuadSPI_LUT37_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT37, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT37_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT37_PAD0. */
#define BM_QuadSPI_LUT37_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT37_PAD0. */
#define BS_QuadSPI_LUT37_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT37_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT37_PAD0 field. */
#define BR_QuadSPI_LUT37_PAD0(x) (HW_QuadSPI_LUT37(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT37_PAD0. */
#define BF_QuadSPI_LUT37_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT37_PAD0) & BM_QuadSPI_LUT37_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT37_PAD0(x, v) (HW_QuadSPI_LUT37_WR(x, (HW_QuadSPI_LUT37_RD(x) & ~BM_QuadSPI_LUT37_PAD0) | BF_QuadSPI_LUT37_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT37, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT37_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT37_INSTR0. */
#define BM_QuadSPI_LUT37_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT37_INSTR0. */
#define BS_QuadSPI_LUT37_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT37_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT37_INSTR0 field. */
#define BR_QuadSPI_LUT37_INSTR0(x) (HW_QuadSPI_LUT37(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT37_INSTR0. */
#define BF_QuadSPI_LUT37_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT37_INSTR0) & BM_QuadSPI_LUT37_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT37_INSTR0(x, v) (HW_QuadSPI_LUT37_WR(x, (HW_QuadSPI_LUT37_RD(x) & ~BM_QuadSPI_LUT37_INSTR0) | BF_QuadSPI_LUT37_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT37, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT37_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT37_OPRND1. */
#define BM_QuadSPI_LUT37_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT37_OPRND1. */
#define BS_QuadSPI_LUT37_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT37_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT37_OPRND1 field. */
#define BR_QuadSPI_LUT37_OPRND1(x) (HW_QuadSPI_LUT37(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT37_OPRND1. */
#define BF_QuadSPI_LUT37_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT37_OPRND1) & BM_QuadSPI_LUT37_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT37_OPRND1(x, v) (HW_QuadSPI_LUT37_WR(x, (HW_QuadSPI_LUT37_RD(x) & ~BM_QuadSPI_LUT37_OPRND1) | BF_QuadSPI_LUT37_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT37, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT37_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT37_PAD1. */
#define BM_QuadSPI_LUT37_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT37_PAD1. */
#define BS_QuadSPI_LUT37_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT37_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT37_PAD1 field. */
#define BR_QuadSPI_LUT37_PAD1(x) (HW_QuadSPI_LUT37(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT37_PAD1. */
#define BF_QuadSPI_LUT37_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT37_PAD1) & BM_QuadSPI_LUT37_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT37_PAD1(x, v) (HW_QuadSPI_LUT37_WR(x, (HW_QuadSPI_LUT37_RD(x) & ~BM_QuadSPI_LUT37_PAD1) | BF_QuadSPI_LUT37_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT37, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT37_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT37_INSTR1. */
#define BM_QuadSPI_LUT37_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT37_INSTR1. */
#define BS_QuadSPI_LUT37_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT37_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT37_INSTR1 field. */
#define BR_QuadSPI_LUT37_INSTR1(x) (HW_QuadSPI_LUT37(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT37_INSTR1. */
#define BF_QuadSPI_LUT37_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT37_INSTR1) & BM_QuadSPI_LUT37_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT37_INSTR1(x, v) (HW_QuadSPI_LUT37_WR(x, (HW_QuadSPI_LUT37_RD(x) & ~BM_QuadSPI_LUT37_INSTR1) | BF_QuadSPI_LUT37_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT38 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT38 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut38
{
    uint32_t U;
    struct _hw_quadspi_lut38_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut38_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT38 register
 */
/*@{*/
#define HW_QuadSPI_LUT38_ADDR(x) ((uintptr_t)(x) + 0x3A8U)

#define HW_QuadSPI_LUT38(x)      (*(__IO hw_quadspi_lut38_t *) HW_QuadSPI_LUT38_ADDR(x))
#define HW_QuadSPI_LUT38_RD(x)   (HW_QuadSPI_LUT38(x).U)
#define HW_QuadSPI_LUT38_WR(x, v) (HW_QuadSPI_LUT38(x).U = (v))
#define HW_QuadSPI_LUT38_SET(x, v) (HW_QuadSPI_LUT38_WR(x, HW_QuadSPI_LUT38_RD(x) |  (v)))
#define HW_QuadSPI_LUT38_CLR(x, v) (HW_QuadSPI_LUT38_WR(x, HW_QuadSPI_LUT38_RD(x) & ~(v)))
#define HW_QuadSPI_LUT38_TOG(x, v) (HW_QuadSPI_LUT38_WR(x, HW_QuadSPI_LUT38_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT38 bitfields
 */

/*!
 * @name Register QuadSPI_LUT38, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT38_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT38_OPRND0. */
#define BM_QuadSPI_LUT38_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT38_OPRND0. */
#define BS_QuadSPI_LUT38_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT38_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT38_OPRND0 field. */
#define BR_QuadSPI_LUT38_OPRND0(x) (HW_QuadSPI_LUT38(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT38_OPRND0. */
#define BF_QuadSPI_LUT38_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT38_OPRND0) & BM_QuadSPI_LUT38_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT38_OPRND0(x, v) (HW_QuadSPI_LUT38_WR(x, (HW_QuadSPI_LUT38_RD(x) & ~BM_QuadSPI_LUT38_OPRND0) | BF_QuadSPI_LUT38_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT38, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT38_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT38_PAD0. */
#define BM_QuadSPI_LUT38_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT38_PAD0. */
#define BS_QuadSPI_LUT38_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT38_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT38_PAD0 field. */
#define BR_QuadSPI_LUT38_PAD0(x) (HW_QuadSPI_LUT38(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT38_PAD0. */
#define BF_QuadSPI_LUT38_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT38_PAD0) & BM_QuadSPI_LUT38_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT38_PAD0(x, v) (HW_QuadSPI_LUT38_WR(x, (HW_QuadSPI_LUT38_RD(x) & ~BM_QuadSPI_LUT38_PAD0) | BF_QuadSPI_LUT38_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT38, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT38_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT38_INSTR0. */
#define BM_QuadSPI_LUT38_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT38_INSTR0. */
#define BS_QuadSPI_LUT38_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT38_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT38_INSTR0 field. */
#define BR_QuadSPI_LUT38_INSTR0(x) (HW_QuadSPI_LUT38(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT38_INSTR0. */
#define BF_QuadSPI_LUT38_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT38_INSTR0) & BM_QuadSPI_LUT38_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT38_INSTR0(x, v) (HW_QuadSPI_LUT38_WR(x, (HW_QuadSPI_LUT38_RD(x) & ~BM_QuadSPI_LUT38_INSTR0) | BF_QuadSPI_LUT38_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT38, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT38_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT38_OPRND1. */
#define BM_QuadSPI_LUT38_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT38_OPRND1. */
#define BS_QuadSPI_LUT38_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT38_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT38_OPRND1 field. */
#define BR_QuadSPI_LUT38_OPRND1(x) (HW_QuadSPI_LUT38(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT38_OPRND1. */
#define BF_QuadSPI_LUT38_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT38_OPRND1) & BM_QuadSPI_LUT38_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT38_OPRND1(x, v) (HW_QuadSPI_LUT38_WR(x, (HW_QuadSPI_LUT38_RD(x) & ~BM_QuadSPI_LUT38_OPRND1) | BF_QuadSPI_LUT38_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT38, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT38_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT38_PAD1. */
#define BM_QuadSPI_LUT38_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT38_PAD1. */
#define BS_QuadSPI_LUT38_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT38_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT38_PAD1 field. */
#define BR_QuadSPI_LUT38_PAD1(x) (HW_QuadSPI_LUT38(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT38_PAD1. */
#define BF_QuadSPI_LUT38_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT38_PAD1) & BM_QuadSPI_LUT38_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT38_PAD1(x, v) (HW_QuadSPI_LUT38_WR(x, (HW_QuadSPI_LUT38_RD(x) & ~BM_QuadSPI_LUT38_PAD1) | BF_QuadSPI_LUT38_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT38, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT38_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT38_INSTR1. */
#define BM_QuadSPI_LUT38_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT38_INSTR1. */
#define BS_QuadSPI_LUT38_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT38_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT38_INSTR1 field. */
#define BR_QuadSPI_LUT38_INSTR1(x) (HW_QuadSPI_LUT38(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT38_INSTR1. */
#define BF_QuadSPI_LUT38_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT38_INSTR1) & BM_QuadSPI_LUT38_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT38_INSTR1(x, v) (HW_QuadSPI_LUT38_WR(x, (HW_QuadSPI_LUT38_RD(x) & ~BM_QuadSPI_LUT38_INSTR1) | BF_QuadSPI_LUT38_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT39 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT39 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut39
{
    uint32_t U;
    struct _hw_quadspi_lut39_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut39_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT39 register
 */
/*@{*/
#define HW_QuadSPI_LUT39_ADDR(x) ((uintptr_t)(x) + 0x3ACU)

#define HW_QuadSPI_LUT39(x)      (*(__IO hw_quadspi_lut39_t *) HW_QuadSPI_LUT39_ADDR(x))
#define HW_QuadSPI_LUT39_RD(x)   (HW_QuadSPI_LUT39(x).U)
#define HW_QuadSPI_LUT39_WR(x, v) (HW_QuadSPI_LUT39(x).U = (v))
#define HW_QuadSPI_LUT39_SET(x, v) (HW_QuadSPI_LUT39_WR(x, HW_QuadSPI_LUT39_RD(x) |  (v)))
#define HW_QuadSPI_LUT39_CLR(x, v) (HW_QuadSPI_LUT39_WR(x, HW_QuadSPI_LUT39_RD(x) & ~(v)))
#define HW_QuadSPI_LUT39_TOG(x, v) (HW_QuadSPI_LUT39_WR(x, HW_QuadSPI_LUT39_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT39 bitfields
 */

/*!
 * @name Register QuadSPI_LUT39, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT39_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT39_OPRND0. */
#define BM_QuadSPI_LUT39_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT39_OPRND0. */
#define BS_QuadSPI_LUT39_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT39_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT39_OPRND0 field. */
#define BR_QuadSPI_LUT39_OPRND0(x) (HW_QuadSPI_LUT39(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT39_OPRND0. */
#define BF_QuadSPI_LUT39_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT39_OPRND0) & BM_QuadSPI_LUT39_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT39_OPRND0(x, v) (HW_QuadSPI_LUT39_WR(x, (HW_QuadSPI_LUT39_RD(x) & ~BM_QuadSPI_LUT39_OPRND0) | BF_QuadSPI_LUT39_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT39, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT39_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT39_PAD0. */
#define BM_QuadSPI_LUT39_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT39_PAD0. */
#define BS_QuadSPI_LUT39_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT39_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT39_PAD0 field. */
#define BR_QuadSPI_LUT39_PAD0(x) (HW_QuadSPI_LUT39(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT39_PAD0. */
#define BF_QuadSPI_LUT39_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT39_PAD0) & BM_QuadSPI_LUT39_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT39_PAD0(x, v) (HW_QuadSPI_LUT39_WR(x, (HW_QuadSPI_LUT39_RD(x) & ~BM_QuadSPI_LUT39_PAD0) | BF_QuadSPI_LUT39_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT39, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT39_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT39_INSTR0. */
#define BM_QuadSPI_LUT39_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT39_INSTR0. */
#define BS_QuadSPI_LUT39_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT39_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT39_INSTR0 field. */
#define BR_QuadSPI_LUT39_INSTR0(x) (HW_QuadSPI_LUT39(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT39_INSTR0. */
#define BF_QuadSPI_LUT39_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT39_INSTR0) & BM_QuadSPI_LUT39_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT39_INSTR0(x, v) (HW_QuadSPI_LUT39_WR(x, (HW_QuadSPI_LUT39_RD(x) & ~BM_QuadSPI_LUT39_INSTR0) | BF_QuadSPI_LUT39_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT39, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT39_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT39_OPRND1. */
#define BM_QuadSPI_LUT39_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT39_OPRND1. */
#define BS_QuadSPI_LUT39_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT39_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT39_OPRND1 field. */
#define BR_QuadSPI_LUT39_OPRND1(x) (HW_QuadSPI_LUT39(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT39_OPRND1. */
#define BF_QuadSPI_LUT39_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT39_OPRND1) & BM_QuadSPI_LUT39_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT39_OPRND1(x, v) (HW_QuadSPI_LUT39_WR(x, (HW_QuadSPI_LUT39_RD(x) & ~BM_QuadSPI_LUT39_OPRND1) | BF_QuadSPI_LUT39_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT39, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT39_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT39_PAD1. */
#define BM_QuadSPI_LUT39_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT39_PAD1. */
#define BS_QuadSPI_LUT39_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT39_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT39_PAD1 field. */
#define BR_QuadSPI_LUT39_PAD1(x) (HW_QuadSPI_LUT39(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT39_PAD1. */
#define BF_QuadSPI_LUT39_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT39_PAD1) & BM_QuadSPI_LUT39_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT39_PAD1(x, v) (HW_QuadSPI_LUT39_WR(x, (HW_QuadSPI_LUT39_RD(x) & ~BM_QuadSPI_LUT39_PAD1) | BF_QuadSPI_LUT39_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT39, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT39_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT39_INSTR1. */
#define BM_QuadSPI_LUT39_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT39_INSTR1. */
#define BS_QuadSPI_LUT39_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT39_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT39_INSTR1 field. */
#define BR_QuadSPI_LUT39_INSTR1(x) (HW_QuadSPI_LUT39(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT39_INSTR1. */
#define BF_QuadSPI_LUT39_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT39_INSTR1) & BM_QuadSPI_LUT39_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT39_INSTR1(x, v) (HW_QuadSPI_LUT39_WR(x, (HW_QuadSPI_LUT39_RD(x) & ~BM_QuadSPI_LUT39_INSTR1) | BF_QuadSPI_LUT39_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT40 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT40 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut40
{
    uint32_t U;
    struct _hw_quadspi_lut40_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut40_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT40 register
 */
/*@{*/
#define HW_QuadSPI_LUT40_ADDR(x) ((uintptr_t)(x) + 0x3B0U)

#define HW_QuadSPI_LUT40(x)      (*(__IO hw_quadspi_lut40_t *) HW_QuadSPI_LUT40_ADDR(x))
#define HW_QuadSPI_LUT40_RD(x)   (HW_QuadSPI_LUT40(x).U)
#define HW_QuadSPI_LUT40_WR(x, v) (HW_QuadSPI_LUT40(x).U = (v))
#define HW_QuadSPI_LUT40_SET(x, v) (HW_QuadSPI_LUT40_WR(x, HW_QuadSPI_LUT40_RD(x) |  (v)))
#define HW_QuadSPI_LUT40_CLR(x, v) (HW_QuadSPI_LUT40_WR(x, HW_QuadSPI_LUT40_RD(x) & ~(v)))
#define HW_QuadSPI_LUT40_TOG(x, v) (HW_QuadSPI_LUT40_WR(x, HW_QuadSPI_LUT40_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT40 bitfields
 */

/*!
 * @name Register QuadSPI_LUT40, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT40_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT40_OPRND0. */
#define BM_QuadSPI_LUT40_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT40_OPRND0. */
#define BS_QuadSPI_LUT40_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT40_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT40_OPRND0 field. */
#define BR_QuadSPI_LUT40_OPRND0(x) (HW_QuadSPI_LUT40(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT40_OPRND0. */
#define BF_QuadSPI_LUT40_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT40_OPRND0) & BM_QuadSPI_LUT40_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT40_OPRND0(x, v) (HW_QuadSPI_LUT40_WR(x, (HW_QuadSPI_LUT40_RD(x) & ~BM_QuadSPI_LUT40_OPRND0) | BF_QuadSPI_LUT40_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT40, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT40_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT40_PAD0. */
#define BM_QuadSPI_LUT40_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT40_PAD0. */
#define BS_QuadSPI_LUT40_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT40_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT40_PAD0 field. */
#define BR_QuadSPI_LUT40_PAD0(x) (HW_QuadSPI_LUT40(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT40_PAD0. */
#define BF_QuadSPI_LUT40_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT40_PAD0) & BM_QuadSPI_LUT40_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT40_PAD0(x, v) (HW_QuadSPI_LUT40_WR(x, (HW_QuadSPI_LUT40_RD(x) & ~BM_QuadSPI_LUT40_PAD0) | BF_QuadSPI_LUT40_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT40, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT40_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT40_INSTR0. */
#define BM_QuadSPI_LUT40_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT40_INSTR0. */
#define BS_QuadSPI_LUT40_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT40_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT40_INSTR0 field. */
#define BR_QuadSPI_LUT40_INSTR0(x) (HW_QuadSPI_LUT40(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT40_INSTR0. */
#define BF_QuadSPI_LUT40_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT40_INSTR0) & BM_QuadSPI_LUT40_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT40_INSTR0(x, v) (HW_QuadSPI_LUT40_WR(x, (HW_QuadSPI_LUT40_RD(x) & ~BM_QuadSPI_LUT40_INSTR0) | BF_QuadSPI_LUT40_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT40, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT40_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT40_OPRND1. */
#define BM_QuadSPI_LUT40_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT40_OPRND1. */
#define BS_QuadSPI_LUT40_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT40_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT40_OPRND1 field. */
#define BR_QuadSPI_LUT40_OPRND1(x) (HW_QuadSPI_LUT40(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT40_OPRND1. */
#define BF_QuadSPI_LUT40_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT40_OPRND1) & BM_QuadSPI_LUT40_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT40_OPRND1(x, v) (HW_QuadSPI_LUT40_WR(x, (HW_QuadSPI_LUT40_RD(x) & ~BM_QuadSPI_LUT40_OPRND1) | BF_QuadSPI_LUT40_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT40, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT40_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT40_PAD1. */
#define BM_QuadSPI_LUT40_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT40_PAD1. */
#define BS_QuadSPI_LUT40_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT40_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT40_PAD1 field. */
#define BR_QuadSPI_LUT40_PAD1(x) (HW_QuadSPI_LUT40(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT40_PAD1. */
#define BF_QuadSPI_LUT40_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT40_PAD1) & BM_QuadSPI_LUT40_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT40_PAD1(x, v) (HW_QuadSPI_LUT40_WR(x, (HW_QuadSPI_LUT40_RD(x) & ~BM_QuadSPI_LUT40_PAD1) | BF_QuadSPI_LUT40_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT40, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT40_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT40_INSTR1. */
#define BM_QuadSPI_LUT40_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT40_INSTR1. */
#define BS_QuadSPI_LUT40_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT40_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT40_INSTR1 field. */
#define BR_QuadSPI_LUT40_INSTR1(x) (HW_QuadSPI_LUT40(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT40_INSTR1. */
#define BF_QuadSPI_LUT40_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT40_INSTR1) & BM_QuadSPI_LUT40_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT40_INSTR1(x, v) (HW_QuadSPI_LUT40_WR(x, (HW_QuadSPI_LUT40_RD(x) & ~BM_QuadSPI_LUT40_INSTR1) | BF_QuadSPI_LUT40_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT41 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT41 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut41
{
    uint32_t U;
    struct _hw_quadspi_lut41_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut41_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT41 register
 */
/*@{*/
#define HW_QuadSPI_LUT41_ADDR(x) ((uintptr_t)(x) + 0x3B4U)

#define HW_QuadSPI_LUT41(x)      (*(__IO hw_quadspi_lut41_t *) HW_QuadSPI_LUT41_ADDR(x))
#define HW_QuadSPI_LUT41_RD(x)   (HW_QuadSPI_LUT41(x).U)
#define HW_QuadSPI_LUT41_WR(x, v) (HW_QuadSPI_LUT41(x).U = (v))
#define HW_QuadSPI_LUT41_SET(x, v) (HW_QuadSPI_LUT41_WR(x, HW_QuadSPI_LUT41_RD(x) |  (v)))
#define HW_QuadSPI_LUT41_CLR(x, v) (HW_QuadSPI_LUT41_WR(x, HW_QuadSPI_LUT41_RD(x) & ~(v)))
#define HW_QuadSPI_LUT41_TOG(x, v) (HW_QuadSPI_LUT41_WR(x, HW_QuadSPI_LUT41_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT41 bitfields
 */

/*!
 * @name Register QuadSPI_LUT41, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT41_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT41_OPRND0. */
#define BM_QuadSPI_LUT41_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT41_OPRND0. */
#define BS_QuadSPI_LUT41_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT41_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT41_OPRND0 field. */
#define BR_QuadSPI_LUT41_OPRND0(x) (HW_QuadSPI_LUT41(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT41_OPRND0. */
#define BF_QuadSPI_LUT41_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT41_OPRND0) & BM_QuadSPI_LUT41_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT41_OPRND0(x, v) (HW_QuadSPI_LUT41_WR(x, (HW_QuadSPI_LUT41_RD(x) & ~BM_QuadSPI_LUT41_OPRND0) | BF_QuadSPI_LUT41_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT41, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT41_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT41_PAD0. */
#define BM_QuadSPI_LUT41_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT41_PAD0. */
#define BS_QuadSPI_LUT41_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT41_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT41_PAD0 field. */
#define BR_QuadSPI_LUT41_PAD0(x) (HW_QuadSPI_LUT41(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT41_PAD0. */
#define BF_QuadSPI_LUT41_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT41_PAD0) & BM_QuadSPI_LUT41_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT41_PAD0(x, v) (HW_QuadSPI_LUT41_WR(x, (HW_QuadSPI_LUT41_RD(x) & ~BM_QuadSPI_LUT41_PAD0) | BF_QuadSPI_LUT41_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT41, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT41_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT41_INSTR0. */
#define BM_QuadSPI_LUT41_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT41_INSTR0. */
#define BS_QuadSPI_LUT41_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT41_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT41_INSTR0 field. */
#define BR_QuadSPI_LUT41_INSTR0(x) (HW_QuadSPI_LUT41(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT41_INSTR0. */
#define BF_QuadSPI_LUT41_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT41_INSTR0) & BM_QuadSPI_LUT41_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT41_INSTR0(x, v) (HW_QuadSPI_LUT41_WR(x, (HW_QuadSPI_LUT41_RD(x) & ~BM_QuadSPI_LUT41_INSTR0) | BF_QuadSPI_LUT41_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT41, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT41_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT41_OPRND1. */
#define BM_QuadSPI_LUT41_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT41_OPRND1. */
#define BS_QuadSPI_LUT41_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT41_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT41_OPRND1 field. */
#define BR_QuadSPI_LUT41_OPRND1(x) (HW_QuadSPI_LUT41(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT41_OPRND1. */
#define BF_QuadSPI_LUT41_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT41_OPRND1) & BM_QuadSPI_LUT41_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT41_OPRND1(x, v) (HW_QuadSPI_LUT41_WR(x, (HW_QuadSPI_LUT41_RD(x) & ~BM_QuadSPI_LUT41_OPRND1) | BF_QuadSPI_LUT41_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT41, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT41_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT41_PAD1. */
#define BM_QuadSPI_LUT41_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT41_PAD1. */
#define BS_QuadSPI_LUT41_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT41_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT41_PAD1 field. */
#define BR_QuadSPI_LUT41_PAD1(x) (HW_QuadSPI_LUT41(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT41_PAD1. */
#define BF_QuadSPI_LUT41_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT41_PAD1) & BM_QuadSPI_LUT41_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT41_PAD1(x, v) (HW_QuadSPI_LUT41_WR(x, (HW_QuadSPI_LUT41_RD(x) & ~BM_QuadSPI_LUT41_PAD1) | BF_QuadSPI_LUT41_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT41, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT41_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT41_INSTR1. */
#define BM_QuadSPI_LUT41_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT41_INSTR1. */
#define BS_QuadSPI_LUT41_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT41_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT41_INSTR1 field. */
#define BR_QuadSPI_LUT41_INSTR1(x) (HW_QuadSPI_LUT41(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT41_INSTR1. */
#define BF_QuadSPI_LUT41_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT41_INSTR1) & BM_QuadSPI_LUT41_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT41_INSTR1(x, v) (HW_QuadSPI_LUT41_WR(x, (HW_QuadSPI_LUT41_RD(x) & ~BM_QuadSPI_LUT41_INSTR1) | BF_QuadSPI_LUT41_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT42 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT42 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut42
{
    uint32_t U;
    struct _hw_quadspi_lut42_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut42_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT42 register
 */
/*@{*/
#define HW_QuadSPI_LUT42_ADDR(x) ((uintptr_t)(x) + 0x3B8U)

#define HW_QuadSPI_LUT42(x)      (*(__IO hw_quadspi_lut42_t *) HW_QuadSPI_LUT42_ADDR(x))
#define HW_QuadSPI_LUT42_RD(x)   (HW_QuadSPI_LUT42(x).U)
#define HW_QuadSPI_LUT42_WR(x, v) (HW_QuadSPI_LUT42(x).U = (v))
#define HW_QuadSPI_LUT42_SET(x, v) (HW_QuadSPI_LUT42_WR(x, HW_QuadSPI_LUT42_RD(x) |  (v)))
#define HW_QuadSPI_LUT42_CLR(x, v) (HW_QuadSPI_LUT42_WR(x, HW_QuadSPI_LUT42_RD(x) & ~(v)))
#define HW_QuadSPI_LUT42_TOG(x, v) (HW_QuadSPI_LUT42_WR(x, HW_QuadSPI_LUT42_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT42 bitfields
 */

/*!
 * @name Register QuadSPI_LUT42, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT42_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT42_OPRND0. */
#define BM_QuadSPI_LUT42_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT42_OPRND0. */
#define BS_QuadSPI_LUT42_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT42_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT42_OPRND0 field. */
#define BR_QuadSPI_LUT42_OPRND0(x) (HW_QuadSPI_LUT42(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT42_OPRND0. */
#define BF_QuadSPI_LUT42_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT42_OPRND0) & BM_QuadSPI_LUT42_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT42_OPRND0(x, v) (HW_QuadSPI_LUT42_WR(x, (HW_QuadSPI_LUT42_RD(x) & ~BM_QuadSPI_LUT42_OPRND0) | BF_QuadSPI_LUT42_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT42, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT42_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT42_PAD0. */
#define BM_QuadSPI_LUT42_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT42_PAD0. */
#define BS_QuadSPI_LUT42_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT42_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT42_PAD0 field. */
#define BR_QuadSPI_LUT42_PAD0(x) (HW_QuadSPI_LUT42(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT42_PAD0. */
#define BF_QuadSPI_LUT42_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT42_PAD0) & BM_QuadSPI_LUT42_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT42_PAD0(x, v) (HW_QuadSPI_LUT42_WR(x, (HW_QuadSPI_LUT42_RD(x) & ~BM_QuadSPI_LUT42_PAD0) | BF_QuadSPI_LUT42_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT42, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT42_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT42_INSTR0. */
#define BM_QuadSPI_LUT42_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT42_INSTR0. */
#define BS_QuadSPI_LUT42_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT42_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT42_INSTR0 field. */
#define BR_QuadSPI_LUT42_INSTR0(x) (HW_QuadSPI_LUT42(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT42_INSTR0. */
#define BF_QuadSPI_LUT42_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT42_INSTR0) & BM_QuadSPI_LUT42_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT42_INSTR0(x, v) (HW_QuadSPI_LUT42_WR(x, (HW_QuadSPI_LUT42_RD(x) & ~BM_QuadSPI_LUT42_INSTR0) | BF_QuadSPI_LUT42_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT42, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT42_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT42_OPRND1. */
#define BM_QuadSPI_LUT42_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT42_OPRND1. */
#define BS_QuadSPI_LUT42_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT42_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT42_OPRND1 field. */
#define BR_QuadSPI_LUT42_OPRND1(x) (HW_QuadSPI_LUT42(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT42_OPRND1. */
#define BF_QuadSPI_LUT42_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT42_OPRND1) & BM_QuadSPI_LUT42_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT42_OPRND1(x, v) (HW_QuadSPI_LUT42_WR(x, (HW_QuadSPI_LUT42_RD(x) & ~BM_QuadSPI_LUT42_OPRND1) | BF_QuadSPI_LUT42_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT42, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT42_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT42_PAD1. */
#define BM_QuadSPI_LUT42_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT42_PAD1. */
#define BS_QuadSPI_LUT42_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT42_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT42_PAD1 field. */
#define BR_QuadSPI_LUT42_PAD1(x) (HW_QuadSPI_LUT42(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT42_PAD1. */
#define BF_QuadSPI_LUT42_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT42_PAD1) & BM_QuadSPI_LUT42_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT42_PAD1(x, v) (HW_QuadSPI_LUT42_WR(x, (HW_QuadSPI_LUT42_RD(x) & ~BM_QuadSPI_LUT42_PAD1) | BF_QuadSPI_LUT42_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT42, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT42_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT42_INSTR1. */
#define BM_QuadSPI_LUT42_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT42_INSTR1. */
#define BS_QuadSPI_LUT42_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT42_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT42_INSTR1 field. */
#define BR_QuadSPI_LUT42_INSTR1(x) (HW_QuadSPI_LUT42(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT42_INSTR1. */
#define BF_QuadSPI_LUT42_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT42_INSTR1) & BM_QuadSPI_LUT42_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT42_INSTR1(x, v) (HW_QuadSPI_LUT42_WR(x, (HW_QuadSPI_LUT42_RD(x) & ~BM_QuadSPI_LUT42_INSTR1) | BF_QuadSPI_LUT42_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT43 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT43 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut43
{
    uint32_t U;
    struct _hw_quadspi_lut43_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut43_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT43 register
 */
/*@{*/
#define HW_QuadSPI_LUT43_ADDR(x) ((uintptr_t)(x) + 0x3BCU)

#define HW_QuadSPI_LUT43(x)      (*(__IO hw_quadspi_lut43_t *) HW_QuadSPI_LUT43_ADDR(x))
#define HW_QuadSPI_LUT43_RD(x)   (HW_QuadSPI_LUT43(x).U)
#define HW_QuadSPI_LUT43_WR(x, v) (HW_QuadSPI_LUT43(x).U = (v))
#define HW_QuadSPI_LUT43_SET(x, v) (HW_QuadSPI_LUT43_WR(x, HW_QuadSPI_LUT43_RD(x) |  (v)))
#define HW_QuadSPI_LUT43_CLR(x, v) (HW_QuadSPI_LUT43_WR(x, HW_QuadSPI_LUT43_RD(x) & ~(v)))
#define HW_QuadSPI_LUT43_TOG(x, v) (HW_QuadSPI_LUT43_WR(x, HW_QuadSPI_LUT43_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT43 bitfields
 */

/*!
 * @name Register QuadSPI_LUT43, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT43_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT43_OPRND0. */
#define BM_QuadSPI_LUT43_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT43_OPRND0. */
#define BS_QuadSPI_LUT43_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT43_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT43_OPRND0 field. */
#define BR_QuadSPI_LUT43_OPRND0(x) (HW_QuadSPI_LUT43(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT43_OPRND0. */
#define BF_QuadSPI_LUT43_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT43_OPRND0) & BM_QuadSPI_LUT43_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT43_OPRND0(x, v) (HW_QuadSPI_LUT43_WR(x, (HW_QuadSPI_LUT43_RD(x) & ~BM_QuadSPI_LUT43_OPRND0) | BF_QuadSPI_LUT43_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT43, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT43_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT43_PAD0. */
#define BM_QuadSPI_LUT43_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT43_PAD0. */
#define BS_QuadSPI_LUT43_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT43_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT43_PAD0 field. */
#define BR_QuadSPI_LUT43_PAD0(x) (HW_QuadSPI_LUT43(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT43_PAD0. */
#define BF_QuadSPI_LUT43_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT43_PAD0) & BM_QuadSPI_LUT43_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT43_PAD0(x, v) (HW_QuadSPI_LUT43_WR(x, (HW_QuadSPI_LUT43_RD(x) & ~BM_QuadSPI_LUT43_PAD0) | BF_QuadSPI_LUT43_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT43, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT43_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT43_INSTR0. */
#define BM_QuadSPI_LUT43_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT43_INSTR0. */
#define BS_QuadSPI_LUT43_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT43_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT43_INSTR0 field. */
#define BR_QuadSPI_LUT43_INSTR0(x) (HW_QuadSPI_LUT43(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT43_INSTR0. */
#define BF_QuadSPI_LUT43_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT43_INSTR0) & BM_QuadSPI_LUT43_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT43_INSTR0(x, v) (HW_QuadSPI_LUT43_WR(x, (HW_QuadSPI_LUT43_RD(x) & ~BM_QuadSPI_LUT43_INSTR0) | BF_QuadSPI_LUT43_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT43, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT43_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT43_OPRND1. */
#define BM_QuadSPI_LUT43_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT43_OPRND1. */
#define BS_QuadSPI_LUT43_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT43_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT43_OPRND1 field. */
#define BR_QuadSPI_LUT43_OPRND1(x) (HW_QuadSPI_LUT43(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT43_OPRND1. */
#define BF_QuadSPI_LUT43_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT43_OPRND1) & BM_QuadSPI_LUT43_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT43_OPRND1(x, v) (HW_QuadSPI_LUT43_WR(x, (HW_QuadSPI_LUT43_RD(x) & ~BM_QuadSPI_LUT43_OPRND1) | BF_QuadSPI_LUT43_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT43, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT43_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT43_PAD1. */
#define BM_QuadSPI_LUT43_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT43_PAD1. */
#define BS_QuadSPI_LUT43_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT43_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT43_PAD1 field. */
#define BR_QuadSPI_LUT43_PAD1(x) (HW_QuadSPI_LUT43(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT43_PAD1. */
#define BF_QuadSPI_LUT43_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT43_PAD1) & BM_QuadSPI_LUT43_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT43_PAD1(x, v) (HW_QuadSPI_LUT43_WR(x, (HW_QuadSPI_LUT43_RD(x) & ~BM_QuadSPI_LUT43_PAD1) | BF_QuadSPI_LUT43_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT43, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT43_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT43_INSTR1. */
#define BM_QuadSPI_LUT43_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT43_INSTR1. */
#define BS_QuadSPI_LUT43_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT43_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT43_INSTR1 field. */
#define BR_QuadSPI_LUT43_INSTR1(x) (HW_QuadSPI_LUT43(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT43_INSTR1. */
#define BF_QuadSPI_LUT43_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT43_INSTR1) & BM_QuadSPI_LUT43_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT43_INSTR1(x, v) (HW_QuadSPI_LUT43_WR(x, (HW_QuadSPI_LUT43_RD(x) & ~BM_QuadSPI_LUT43_INSTR1) | BF_QuadSPI_LUT43_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT44 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT44 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut44
{
    uint32_t U;
    struct _hw_quadspi_lut44_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut44_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT44 register
 */
/*@{*/
#define HW_QuadSPI_LUT44_ADDR(x) ((uintptr_t)(x) + 0x3C0U)

#define HW_QuadSPI_LUT44(x)      (*(__IO hw_quadspi_lut44_t *) HW_QuadSPI_LUT44_ADDR(x))
#define HW_QuadSPI_LUT44_RD(x)   (HW_QuadSPI_LUT44(x).U)
#define HW_QuadSPI_LUT44_WR(x, v) (HW_QuadSPI_LUT44(x).U = (v))
#define HW_QuadSPI_LUT44_SET(x, v) (HW_QuadSPI_LUT44_WR(x, HW_QuadSPI_LUT44_RD(x) |  (v)))
#define HW_QuadSPI_LUT44_CLR(x, v) (HW_QuadSPI_LUT44_WR(x, HW_QuadSPI_LUT44_RD(x) & ~(v)))
#define HW_QuadSPI_LUT44_TOG(x, v) (HW_QuadSPI_LUT44_WR(x, HW_QuadSPI_LUT44_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT44 bitfields
 */

/*!
 * @name Register QuadSPI_LUT44, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT44_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT44_OPRND0. */
#define BM_QuadSPI_LUT44_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT44_OPRND0. */
#define BS_QuadSPI_LUT44_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT44_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT44_OPRND0 field. */
#define BR_QuadSPI_LUT44_OPRND0(x) (HW_QuadSPI_LUT44(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT44_OPRND0. */
#define BF_QuadSPI_LUT44_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT44_OPRND0) & BM_QuadSPI_LUT44_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT44_OPRND0(x, v) (HW_QuadSPI_LUT44_WR(x, (HW_QuadSPI_LUT44_RD(x) & ~BM_QuadSPI_LUT44_OPRND0) | BF_QuadSPI_LUT44_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT44, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT44_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT44_PAD0. */
#define BM_QuadSPI_LUT44_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT44_PAD0. */
#define BS_QuadSPI_LUT44_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT44_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT44_PAD0 field. */
#define BR_QuadSPI_LUT44_PAD0(x) (HW_QuadSPI_LUT44(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT44_PAD0. */
#define BF_QuadSPI_LUT44_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT44_PAD0) & BM_QuadSPI_LUT44_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT44_PAD0(x, v) (HW_QuadSPI_LUT44_WR(x, (HW_QuadSPI_LUT44_RD(x) & ~BM_QuadSPI_LUT44_PAD0) | BF_QuadSPI_LUT44_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT44, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT44_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT44_INSTR0. */
#define BM_QuadSPI_LUT44_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT44_INSTR0. */
#define BS_QuadSPI_LUT44_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT44_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT44_INSTR0 field. */
#define BR_QuadSPI_LUT44_INSTR0(x) (HW_QuadSPI_LUT44(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT44_INSTR0. */
#define BF_QuadSPI_LUT44_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT44_INSTR0) & BM_QuadSPI_LUT44_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT44_INSTR0(x, v) (HW_QuadSPI_LUT44_WR(x, (HW_QuadSPI_LUT44_RD(x) & ~BM_QuadSPI_LUT44_INSTR0) | BF_QuadSPI_LUT44_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT44, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT44_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT44_OPRND1. */
#define BM_QuadSPI_LUT44_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT44_OPRND1. */
#define BS_QuadSPI_LUT44_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT44_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT44_OPRND1 field. */
#define BR_QuadSPI_LUT44_OPRND1(x) (HW_QuadSPI_LUT44(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT44_OPRND1. */
#define BF_QuadSPI_LUT44_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT44_OPRND1) & BM_QuadSPI_LUT44_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT44_OPRND1(x, v) (HW_QuadSPI_LUT44_WR(x, (HW_QuadSPI_LUT44_RD(x) & ~BM_QuadSPI_LUT44_OPRND1) | BF_QuadSPI_LUT44_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT44, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT44_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT44_PAD1. */
#define BM_QuadSPI_LUT44_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT44_PAD1. */
#define BS_QuadSPI_LUT44_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT44_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT44_PAD1 field. */
#define BR_QuadSPI_LUT44_PAD1(x) (HW_QuadSPI_LUT44(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT44_PAD1. */
#define BF_QuadSPI_LUT44_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT44_PAD1) & BM_QuadSPI_LUT44_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT44_PAD1(x, v) (HW_QuadSPI_LUT44_WR(x, (HW_QuadSPI_LUT44_RD(x) & ~BM_QuadSPI_LUT44_PAD1) | BF_QuadSPI_LUT44_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT44, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT44_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT44_INSTR1. */
#define BM_QuadSPI_LUT44_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT44_INSTR1. */
#define BS_QuadSPI_LUT44_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT44_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT44_INSTR1 field. */
#define BR_QuadSPI_LUT44_INSTR1(x) (HW_QuadSPI_LUT44(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT44_INSTR1. */
#define BF_QuadSPI_LUT44_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT44_INSTR1) & BM_QuadSPI_LUT44_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT44_INSTR1(x, v) (HW_QuadSPI_LUT44_WR(x, (HW_QuadSPI_LUT44_RD(x) & ~BM_QuadSPI_LUT44_INSTR1) | BF_QuadSPI_LUT44_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT45 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT45 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut45
{
    uint32_t U;
    struct _hw_quadspi_lut45_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut45_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT45 register
 */
/*@{*/
#define HW_QuadSPI_LUT45_ADDR(x) ((uintptr_t)(x) + 0x3C4U)

#define HW_QuadSPI_LUT45(x)      (*(__IO hw_quadspi_lut45_t *) HW_QuadSPI_LUT45_ADDR(x))
#define HW_QuadSPI_LUT45_RD(x)   (HW_QuadSPI_LUT45(x).U)
#define HW_QuadSPI_LUT45_WR(x, v) (HW_QuadSPI_LUT45(x).U = (v))
#define HW_QuadSPI_LUT45_SET(x, v) (HW_QuadSPI_LUT45_WR(x, HW_QuadSPI_LUT45_RD(x) |  (v)))
#define HW_QuadSPI_LUT45_CLR(x, v) (HW_QuadSPI_LUT45_WR(x, HW_QuadSPI_LUT45_RD(x) & ~(v)))
#define HW_QuadSPI_LUT45_TOG(x, v) (HW_QuadSPI_LUT45_WR(x, HW_QuadSPI_LUT45_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT45 bitfields
 */

/*!
 * @name Register QuadSPI_LUT45, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT45_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT45_OPRND0. */
#define BM_QuadSPI_LUT45_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT45_OPRND0. */
#define BS_QuadSPI_LUT45_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT45_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT45_OPRND0 field. */
#define BR_QuadSPI_LUT45_OPRND0(x) (HW_QuadSPI_LUT45(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT45_OPRND0. */
#define BF_QuadSPI_LUT45_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT45_OPRND0) & BM_QuadSPI_LUT45_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT45_OPRND0(x, v) (HW_QuadSPI_LUT45_WR(x, (HW_QuadSPI_LUT45_RD(x) & ~BM_QuadSPI_LUT45_OPRND0) | BF_QuadSPI_LUT45_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT45, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT45_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT45_PAD0. */
#define BM_QuadSPI_LUT45_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT45_PAD0. */
#define BS_QuadSPI_LUT45_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT45_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT45_PAD0 field. */
#define BR_QuadSPI_LUT45_PAD0(x) (HW_QuadSPI_LUT45(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT45_PAD0. */
#define BF_QuadSPI_LUT45_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT45_PAD0) & BM_QuadSPI_LUT45_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT45_PAD0(x, v) (HW_QuadSPI_LUT45_WR(x, (HW_QuadSPI_LUT45_RD(x) & ~BM_QuadSPI_LUT45_PAD0) | BF_QuadSPI_LUT45_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT45, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT45_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT45_INSTR0. */
#define BM_QuadSPI_LUT45_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT45_INSTR0. */
#define BS_QuadSPI_LUT45_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT45_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT45_INSTR0 field. */
#define BR_QuadSPI_LUT45_INSTR0(x) (HW_QuadSPI_LUT45(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT45_INSTR0. */
#define BF_QuadSPI_LUT45_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT45_INSTR0) & BM_QuadSPI_LUT45_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT45_INSTR0(x, v) (HW_QuadSPI_LUT45_WR(x, (HW_QuadSPI_LUT45_RD(x) & ~BM_QuadSPI_LUT45_INSTR0) | BF_QuadSPI_LUT45_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT45, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT45_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT45_OPRND1. */
#define BM_QuadSPI_LUT45_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT45_OPRND1. */
#define BS_QuadSPI_LUT45_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT45_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT45_OPRND1 field. */
#define BR_QuadSPI_LUT45_OPRND1(x) (HW_QuadSPI_LUT45(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT45_OPRND1. */
#define BF_QuadSPI_LUT45_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT45_OPRND1) & BM_QuadSPI_LUT45_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT45_OPRND1(x, v) (HW_QuadSPI_LUT45_WR(x, (HW_QuadSPI_LUT45_RD(x) & ~BM_QuadSPI_LUT45_OPRND1) | BF_QuadSPI_LUT45_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT45, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT45_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT45_PAD1. */
#define BM_QuadSPI_LUT45_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT45_PAD1. */
#define BS_QuadSPI_LUT45_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT45_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT45_PAD1 field. */
#define BR_QuadSPI_LUT45_PAD1(x) (HW_QuadSPI_LUT45(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT45_PAD1. */
#define BF_QuadSPI_LUT45_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT45_PAD1) & BM_QuadSPI_LUT45_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT45_PAD1(x, v) (HW_QuadSPI_LUT45_WR(x, (HW_QuadSPI_LUT45_RD(x) & ~BM_QuadSPI_LUT45_PAD1) | BF_QuadSPI_LUT45_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT45, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT45_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT45_INSTR1. */
#define BM_QuadSPI_LUT45_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT45_INSTR1. */
#define BS_QuadSPI_LUT45_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT45_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT45_INSTR1 field. */
#define BR_QuadSPI_LUT45_INSTR1(x) (HW_QuadSPI_LUT45(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT45_INSTR1. */
#define BF_QuadSPI_LUT45_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT45_INSTR1) & BM_QuadSPI_LUT45_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT45_INSTR1(x, v) (HW_QuadSPI_LUT45_WR(x, (HW_QuadSPI_LUT45_RD(x) & ~BM_QuadSPI_LUT45_INSTR1) | BF_QuadSPI_LUT45_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT46 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT46 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut46
{
    uint32_t U;
    struct _hw_quadspi_lut46_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut46_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT46 register
 */
/*@{*/
#define HW_QuadSPI_LUT46_ADDR(x) ((uintptr_t)(x) + 0x3C8U)

#define HW_QuadSPI_LUT46(x)      (*(__IO hw_quadspi_lut46_t *) HW_QuadSPI_LUT46_ADDR(x))
#define HW_QuadSPI_LUT46_RD(x)   (HW_QuadSPI_LUT46(x).U)
#define HW_QuadSPI_LUT46_WR(x, v) (HW_QuadSPI_LUT46(x).U = (v))
#define HW_QuadSPI_LUT46_SET(x, v) (HW_QuadSPI_LUT46_WR(x, HW_QuadSPI_LUT46_RD(x) |  (v)))
#define HW_QuadSPI_LUT46_CLR(x, v) (HW_QuadSPI_LUT46_WR(x, HW_QuadSPI_LUT46_RD(x) & ~(v)))
#define HW_QuadSPI_LUT46_TOG(x, v) (HW_QuadSPI_LUT46_WR(x, HW_QuadSPI_LUT46_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT46 bitfields
 */

/*!
 * @name Register QuadSPI_LUT46, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT46_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT46_OPRND0. */
#define BM_QuadSPI_LUT46_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT46_OPRND0. */
#define BS_QuadSPI_LUT46_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT46_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT46_OPRND0 field. */
#define BR_QuadSPI_LUT46_OPRND0(x) (HW_QuadSPI_LUT46(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT46_OPRND0. */
#define BF_QuadSPI_LUT46_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT46_OPRND0) & BM_QuadSPI_LUT46_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT46_OPRND0(x, v) (HW_QuadSPI_LUT46_WR(x, (HW_QuadSPI_LUT46_RD(x) & ~BM_QuadSPI_LUT46_OPRND0) | BF_QuadSPI_LUT46_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT46, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT46_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT46_PAD0. */
#define BM_QuadSPI_LUT46_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT46_PAD0. */
#define BS_QuadSPI_LUT46_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT46_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT46_PAD0 field. */
#define BR_QuadSPI_LUT46_PAD0(x) (HW_QuadSPI_LUT46(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT46_PAD0. */
#define BF_QuadSPI_LUT46_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT46_PAD0) & BM_QuadSPI_LUT46_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT46_PAD0(x, v) (HW_QuadSPI_LUT46_WR(x, (HW_QuadSPI_LUT46_RD(x) & ~BM_QuadSPI_LUT46_PAD0) | BF_QuadSPI_LUT46_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT46, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT46_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT46_INSTR0. */
#define BM_QuadSPI_LUT46_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT46_INSTR0. */
#define BS_QuadSPI_LUT46_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT46_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT46_INSTR0 field. */
#define BR_QuadSPI_LUT46_INSTR0(x) (HW_QuadSPI_LUT46(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT46_INSTR0. */
#define BF_QuadSPI_LUT46_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT46_INSTR0) & BM_QuadSPI_LUT46_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT46_INSTR0(x, v) (HW_QuadSPI_LUT46_WR(x, (HW_QuadSPI_LUT46_RD(x) & ~BM_QuadSPI_LUT46_INSTR0) | BF_QuadSPI_LUT46_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT46, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT46_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT46_OPRND1. */
#define BM_QuadSPI_LUT46_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT46_OPRND1. */
#define BS_QuadSPI_LUT46_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT46_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT46_OPRND1 field. */
#define BR_QuadSPI_LUT46_OPRND1(x) (HW_QuadSPI_LUT46(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT46_OPRND1. */
#define BF_QuadSPI_LUT46_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT46_OPRND1) & BM_QuadSPI_LUT46_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT46_OPRND1(x, v) (HW_QuadSPI_LUT46_WR(x, (HW_QuadSPI_LUT46_RD(x) & ~BM_QuadSPI_LUT46_OPRND1) | BF_QuadSPI_LUT46_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT46, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT46_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT46_PAD1. */
#define BM_QuadSPI_LUT46_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT46_PAD1. */
#define BS_QuadSPI_LUT46_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT46_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT46_PAD1 field. */
#define BR_QuadSPI_LUT46_PAD1(x) (HW_QuadSPI_LUT46(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT46_PAD1. */
#define BF_QuadSPI_LUT46_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT46_PAD1) & BM_QuadSPI_LUT46_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT46_PAD1(x, v) (HW_QuadSPI_LUT46_WR(x, (HW_QuadSPI_LUT46_RD(x) & ~BM_QuadSPI_LUT46_PAD1) | BF_QuadSPI_LUT46_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT46, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT46_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT46_INSTR1. */
#define BM_QuadSPI_LUT46_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT46_INSTR1. */
#define BS_QuadSPI_LUT46_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT46_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT46_INSTR1 field. */
#define BR_QuadSPI_LUT46_INSTR1(x) (HW_QuadSPI_LUT46(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT46_INSTR1. */
#define BF_QuadSPI_LUT46_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT46_INSTR1) & BM_QuadSPI_LUT46_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT46_INSTR1(x, v) (HW_QuadSPI_LUT46_WR(x, (HW_QuadSPI_LUT46_RD(x) & ~BM_QuadSPI_LUT46_INSTR1) | BF_QuadSPI_LUT46_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT47 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT47 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut47
{
    uint32_t U;
    struct _hw_quadspi_lut47_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut47_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT47 register
 */
/*@{*/
#define HW_QuadSPI_LUT47_ADDR(x) ((uintptr_t)(x) + 0x3CCU)

#define HW_QuadSPI_LUT47(x)      (*(__IO hw_quadspi_lut47_t *) HW_QuadSPI_LUT47_ADDR(x))
#define HW_QuadSPI_LUT47_RD(x)   (HW_QuadSPI_LUT47(x).U)
#define HW_QuadSPI_LUT47_WR(x, v) (HW_QuadSPI_LUT47(x).U = (v))
#define HW_QuadSPI_LUT47_SET(x, v) (HW_QuadSPI_LUT47_WR(x, HW_QuadSPI_LUT47_RD(x) |  (v)))
#define HW_QuadSPI_LUT47_CLR(x, v) (HW_QuadSPI_LUT47_WR(x, HW_QuadSPI_LUT47_RD(x) & ~(v)))
#define HW_QuadSPI_LUT47_TOG(x, v) (HW_QuadSPI_LUT47_WR(x, HW_QuadSPI_LUT47_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT47 bitfields
 */

/*!
 * @name Register QuadSPI_LUT47, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT47_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT47_OPRND0. */
#define BM_QuadSPI_LUT47_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT47_OPRND0. */
#define BS_QuadSPI_LUT47_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT47_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT47_OPRND0 field. */
#define BR_QuadSPI_LUT47_OPRND0(x) (HW_QuadSPI_LUT47(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT47_OPRND0. */
#define BF_QuadSPI_LUT47_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT47_OPRND0) & BM_QuadSPI_LUT47_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT47_OPRND0(x, v) (HW_QuadSPI_LUT47_WR(x, (HW_QuadSPI_LUT47_RD(x) & ~BM_QuadSPI_LUT47_OPRND0) | BF_QuadSPI_LUT47_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT47, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT47_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT47_PAD0. */
#define BM_QuadSPI_LUT47_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT47_PAD0. */
#define BS_QuadSPI_LUT47_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT47_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT47_PAD0 field. */
#define BR_QuadSPI_LUT47_PAD0(x) (HW_QuadSPI_LUT47(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT47_PAD0. */
#define BF_QuadSPI_LUT47_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT47_PAD0) & BM_QuadSPI_LUT47_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT47_PAD0(x, v) (HW_QuadSPI_LUT47_WR(x, (HW_QuadSPI_LUT47_RD(x) & ~BM_QuadSPI_LUT47_PAD0) | BF_QuadSPI_LUT47_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT47, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT47_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT47_INSTR0. */
#define BM_QuadSPI_LUT47_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT47_INSTR0. */
#define BS_QuadSPI_LUT47_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT47_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT47_INSTR0 field. */
#define BR_QuadSPI_LUT47_INSTR0(x) (HW_QuadSPI_LUT47(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT47_INSTR0. */
#define BF_QuadSPI_LUT47_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT47_INSTR0) & BM_QuadSPI_LUT47_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT47_INSTR0(x, v) (HW_QuadSPI_LUT47_WR(x, (HW_QuadSPI_LUT47_RD(x) & ~BM_QuadSPI_LUT47_INSTR0) | BF_QuadSPI_LUT47_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT47, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT47_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT47_OPRND1. */
#define BM_QuadSPI_LUT47_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT47_OPRND1. */
#define BS_QuadSPI_LUT47_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT47_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT47_OPRND1 field. */
#define BR_QuadSPI_LUT47_OPRND1(x) (HW_QuadSPI_LUT47(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT47_OPRND1. */
#define BF_QuadSPI_LUT47_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT47_OPRND1) & BM_QuadSPI_LUT47_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT47_OPRND1(x, v) (HW_QuadSPI_LUT47_WR(x, (HW_QuadSPI_LUT47_RD(x) & ~BM_QuadSPI_LUT47_OPRND1) | BF_QuadSPI_LUT47_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT47, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT47_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT47_PAD1. */
#define BM_QuadSPI_LUT47_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT47_PAD1. */
#define BS_QuadSPI_LUT47_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT47_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT47_PAD1 field. */
#define BR_QuadSPI_LUT47_PAD1(x) (HW_QuadSPI_LUT47(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT47_PAD1. */
#define BF_QuadSPI_LUT47_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT47_PAD1) & BM_QuadSPI_LUT47_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT47_PAD1(x, v) (HW_QuadSPI_LUT47_WR(x, (HW_QuadSPI_LUT47_RD(x) & ~BM_QuadSPI_LUT47_PAD1) | BF_QuadSPI_LUT47_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT47, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT47_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT47_INSTR1. */
#define BM_QuadSPI_LUT47_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT47_INSTR1. */
#define BS_QuadSPI_LUT47_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT47_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT47_INSTR1 field. */
#define BR_QuadSPI_LUT47_INSTR1(x) (HW_QuadSPI_LUT47(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT47_INSTR1. */
#define BF_QuadSPI_LUT47_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT47_INSTR1) & BM_QuadSPI_LUT47_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT47_INSTR1(x, v) (HW_QuadSPI_LUT47_WR(x, (HW_QuadSPI_LUT47_RD(x) & ~BM_QuadSPI_LUT47_INSTR1) | BF_QuadSPI_LUT47_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT48 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT48 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut48
{
    uint32_t U;
    struct _hw_quadspi_lut48_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut48_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT48 register
 */
/*@{*/
#define HW_QuadSPI_LUT48_ADDR(x) ((uintptr_t)(x) + 0x3D0U)

#define HW_QuadSPI_LUT48(x)      (*(__IO hw_quadspi_lut48_t *) HW_QuadSPI_LUT48_ADDR(x))
#define HW_QuadSPI_LUT48_RD(x)   (HW_QuadSPI_LUT48(x).U)
#define HW_QuadSPI_LUT48_WR(x, v) (HW_QuadSPI_LUT48(x).U = (v))
#define HW_QuadSPI_LUT48_SET(x, v) (HW_QuadSPI_LUT48_WR(x, HW_QuadSPI_LUT48_RD(x) |  (v)))
#define HW_QuadSPI_LUT48_CLR(x, v) (HW_QuadSPI_LUT48_WR(x, HW_QuadSPI_LUT48_RD(x) & ~(v)))
#define HW_QuadSPI_LUT48_TOG(x, v) (HW_QuadSPI_LUT48_WR(x, HW_QuadSPI_LUT48_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT48 bitfields
 */

/*!
 * @name Register QuadSPI_LUT48, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT48_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT48_OPRND0. */
#define BM_QuadSPI_LUT48_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT48_OPRND0. */
#define BS_QuadSPI_LUT48_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT48_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT48_OPRND0 field. */
#define BR_QuadSPI_LUT48_OPRND0(x) (HW_QuadSPI_LUT48(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT48_OPRND0. */
#define BF_QuadSPI_LUT48_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT48_OPRND0) & BM_QuadSPI_LUT48_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT48_OPRND0(x, v) (HW_QuadSPI_LUT48_WR(x, (HW_QuadSPI_LUT48_RD(x) & ~BM_QuadSPI_LUT48_OPRND0) | BF_QuadSPI_LUT48_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT48, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT48_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT48_PAD0. */
#define BM_QuadSPI_LUT48_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT48_PAD0. */
#define BS_QuadSPI_LUT48_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT48_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT48_PAD0 field. */
#define BR_QuadSPI_LUT48_PAD0(x) (HW_QuadSPI_LUT48(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT48_PAD0. */
#define BF_QuadSPI_LUT48_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT48_PAD0) & BM_QuadSPI_LUT48_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT48_PAD0(x, v) (HW_QuadSPI_LUT48_WR(x, (HW_QuadSPI_LUT48_RD(x) & ~BM_QuadSPI_LUT48_PAD0) | BF_QuadSPI_LUT48_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT48, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT48_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT48_INSTR0. */
#define BM_QuadSPI_LUT48_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT48_INSTR0. */
#define BS_QuadSPI_LUT48_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT48_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT48_INSTR0 field. */
#define BR_QuadSPI_LUT48_INSTR0(x) (HW_QuadSPI_LUT48(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT48_INSTR0. */
#define BF_QuadSPI_LUT48_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT48_INSTR0) & BM_QuadSPI_LUT48_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT48_INSTR0(x, v) (HW_QuadSPI_LUT48_WR(x, (HW_QuadSPI_LUT48_RD(x) & ~BM_QuadSPI_LUT48_INSTR0) | BF_QuadSPI_LUT48_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT48, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT48_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT48_OPRND1. */
#define BM_QuadSPI_LUT48_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT48_OPRND1. */
#define BS_QuadSPI_LUT48_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT48_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT48_OPRND1 field. */
#define BR_QuadSPI_LUT48_OPRND1(x) (HW_QuadSPI_LUT48(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT48_OPRND1. */
#define BF_QuadSPI_LUT48_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT48_OPRND1) & BM_QuadSPI_LUT48_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT48_OPRND1(x, v) (HW_QuadSPI_LUT48_WR(x, (HW_QuadSPI_LUT48_RD(x) & ~BM_QuadSPI_LUT48_OPRND1) | BF_QuadSPI_LUT48_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT48, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT48_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT48_PAD1. */
#define BM_QuadSPI_LUT48_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT48_PAD1. */
#define BS_QuadSPI_LUT48_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT48_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT48_PAD1 field. */
#define BR_QuadSPI_LUT48_PAD1(x) (HW_QuadSPI_LUT48(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT48_PAD1. */
#define BF_QuadSPI_LUT48_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT48_PAD1) & BM_QuadSPI_LUT48_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT48_PAD1(x, v) (HW_QuadSPI_LUT48_WR(x, (HW_QuadSPI_LUT48_RD(x) & ~BM_QuadSPI_LUT48_PAD1) | BF_QuadSPI_LUT48_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT48, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT48_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT48_INSTR1. */
#define BM_QuadSPI_LUT48_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT48_INSTR1. */
#define BS_QuadSPI_LUT48_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT48_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT48_INSTR1 field. */
#define BR_QuadSPI_LUT48_INSTR1(x) (HW_QuadSPI_LUT48(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT48_INSTR1. */
#define BF_QuadSPI_LUT48_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT48_INSTR1) & BM_QuadSPI_LUT48_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT48_INSTR1(x, v) (HW_QuadSPI_LUT48_WR(x, (HW_QuadSPI_LUT48_RD(x) & ~BM_QuadSPI_LUT48_INSTR1) | BF_QuadSPI_LUT48_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT49 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT49 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut49
{
    uint32_t U;
    struct _hw_quadspi_lut49_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut49_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT49 register
 */
/*@{*/
#define HW_QuadSPI_LUT49_ADDR(x) ((uintptr_t)(x) + 0x3D4U)

#define HW_QuadSPI_LUT49(x)      (*(__IO hw_quadspi_lut49_t *) HW_QuadSPI_LUT49_ADDR(x))
#define HW_QuadSPI_LUT49_RD(x)   (HW_QuadSPI_LUT49(x).U)
#define HW_QuadSPI_LUT49_WR(x, v) (HW_QuadSPI_LUT49(x).U = (v))
#define HW_QuadSPI_LUT49_SET(x, v) (HW_QuadSPI_LUT49_WR(x, HW_QuadSPI_LUT49_RD(x) |  (v)))
#define HW_QuadSPI_LUT49_CLR(x, v) (HW_QuadSPI_LUT49_WR(x, HW_QuadSPI_LUT49_RD(x) & ~(v)))
#define HW_QuadSPI_LUT49_TOG(x, v) (HW_QuadSPI_LUT49_WR(x, HW_QuadSPI_LUT49_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT49 bitfields
 */

/*!
 * @name Register QuadSPI_LUT49, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT49_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT49_OPRND0. */
#define BM_QuadSPI_LUT49_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT49_OPRND0. */
#define BS_QuadSPI_LUT49_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT49_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT49_OPRND0 field. */
#define BR_QuadSPI_LUT49_OPRND0(x) (HW_QuadSPI_LUT49(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT49_OPRND0. */
#define BF_QuadSPI_LUT49_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT49_OPRND0) & BM_QuadSPI_LUT49_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT49_OPRND0(x, v) (HW_QuadSPI_LUT49_WR(x, (HW_QuadSPI_LUT49_RD(x) & ~BM_QuadSPI_LUT49_OPRND0) | BF_QuadSPI_LUT49_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT49, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT49_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT49_PAD0. */
#define BM_QuadSPI_LUT49_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT49_PAD0. */
#define BS_QuadSPI_LUT49_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT49_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT49_PAD0 field. */
#define BR_QuadSPI_LUT49_PAD0(x) (HW_QuadSPI_LUT49(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT49_PAD0. */
#define BF_QuadSPI_LUT49_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT49_PAD0) & BM_QuadSPI_LUT49_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT49_PAD0(x, v) (HW_QuadSPI_LUT49_WR(x, (HW_QuadSPI_LUT49_RD(x) & ~BM_QuadSPI_LUT49_PAD0) | BF_QuadSPI_LUT49_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT49, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT49_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT49_INSTR0. */
#define BM_QuadSPI_LUT49_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT49_INSTR0. */
#define BS_QuadSPI_LUT49_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT49_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT49_INSTR0 field. */
#define BR_QuadSPI_LUT49_INSTR0(x) (HW_QuadSPI_LUT49(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT49_INSTR0. */
#define BF_QuadSPI_LUT49_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT49_INSTR0) & BM_QuadSPI_LUT49_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT49_INSTR0(x, v) (HW_QuadSPI_LUT49_WR(x, (HW_QuadSPI_LUT49_RD(x) & ~BM_QuadSPI_LUT49_INSTR0) | BF_QuadSPI_LUT49_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT49, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT49_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT49_OPRND1. */
#define BM_QuadSPI_LUT49_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT49_OPRND1. */
#define BS_QuadSPI_LUT49_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT49_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT49_OPRND1 field. */
#define BR_QuadSPI_LUT49_OPRND1(x) (HW_QuadSPI_LUT49(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT49_OPRND1. */
#define BF_QuadSPI_LUT49_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT49_OPRND1) & BM_QuadSPI_LUT49_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT49_OPRND1(x, v) (HW_QuadSPI_LUT49_WR(x, (HW_QuadSPI_LUT49_RD(x) & ~BM_QuadSPI_LUT49_OPRND1) | BF_QuadSPI_LUT49_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT49, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT49_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT49_PAD1. */
#define BM_QuadSPI_LUT49_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT49_PAD1. */
#define BS_QuadSPI_LUT49_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT49_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT49_PAD1 field. */
#define BR_QuadSPI_LUT49_PAD1(x) (HW_QuadSPI_LUT49(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT49_PAD1. */
#define BF_QuadSPI_LUT49_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT49_PAD1) & BM_QuadSPI_LUT49_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT49_PAD1(x, v) (HW_QuadSPI_LUT49_WR(x, (HW_QuadSPI_LUT49_RD(x) & ~BM_QuadSPI_LUT49_PAD1) | BF_QuadSPI_LUT49_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT49, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT49_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT49_INSTR1. */
#define BM_QuadSPI_LUT49_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT49_INSTR1. */
#define BS_QuadSPI_LUT49_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT49_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT49_INSTR1 field. */
#define BR_QuadSPI_LUT49_INSTR1(x) (HW_QuadSPI_LUT49(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT49_INSTR1. */
#define BF_QuadSPI_LUT49_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT49_INSTR1) & BM_QuadSPI_LUT49_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT49_INSTR1(x, v) (HW_QuadSPI_LUT49_WR(x, (HW_QuadSPI_LUT49_RD(x) & ~BM_QuadSPI_LUT49_INSTR1) | BF_QuadSPI_LUT49_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT50 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT50 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut50
{
    uint32_t U;
    struct _hw_quadspi_lut50_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut50_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT50 register
 */
/*@{*/
#define HW_QuadSPI_LUT50_ADDR(x) ((uintptr_t)(x) + 0x3D8U)

#define HW_QuadSPI_LUT50(x)      (*(__IO hw_quadspi_lut50_t *) HW_QuadSPI_LUT50_ADDR(x))
#define HW_QuadSPI_LUT50_RD(x)   (HW_QuadSPI_LUT50(x).U)
#define HW_QuadSPI_LUT50_WR(x, v) (HW_QuadSPI_LUT50(x).U = (v))
#define HW_QuadSPI_LUT50_SET(x, v) (HW_QuadSPI_LUT50_WR(x, HW_QuadSPI_LUT50_RD(x) |  (v)))
#define HW_QuadSPI_LUT50_CLR(x, v) (HW_QuadSPI_LUT50_WR(x, HW_QuadSPI_LUT50_RD(x) & ~(v)))
#define HW_QuadSPI_LUT50_TOG(x, v) (HW_QuadSPI_LUT50_WR(x, HW_QuadSPI_LUT50_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT50 bitfields
 */

/*!
 * @name Register QuadSPI_LUT50, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT50_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT50_OPRND0. */
#define BM_QuadSPI_LUT50_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT50_OPRND0. */
#define BS_QuadSPI_LUT50_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT50_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT50_OPRND0 field. */
#define BR_QuadSPI_LUT50_OPRND0(x) (HW_QuadSPI_LUT50(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT50_OPRND0. */
#define BF_QuadSPI_LUT50_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT50_OPRND0) & BM_QuadSPI_LUT50_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT50_OPRND0(x, v) (HW_QuadSPI_LUT50_WR(x, (HW_QuadSPI_LUT50_RD(x) & ~BM_QuadSPI_LUT50_OPRND0) | BF_QuadSPI_LUT50_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT50, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT50_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT50_PAD0. */
#define BM_QuadSPI_LUT50_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT50_PAD0. */
#define BS_QuadSPI_LUT50_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT50_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT50_PAD0 field. */
#define BR_QuadSPI_LUT50_PAD0(x) (HW_QuadSPI_LUT50(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT50_PAD0. */
#define BF_QuadSPI_LUT50_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT50_PAD0) & BM_QuadSPI_LUT50_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT50_PAD0(x, v) (HW_QuadSPI_LUT50_WR(x, (HW_QuadSPI_LUT50_RD(x) & ~BM_QuadSPI_LUT50_PAD0) | BF_QuadSPI_LUT50_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT50, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT50_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT50_INSTR0. */
#define BM_QuadSPI_LUT50_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT50_INSTR0. */
#define BS_QuadSPI_LUT50_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT50_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT50_INSTR0 field. */
#define BR_QuadSPI_LUT50_INSTR0(x) (HW_QuadSPI_LUT50(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT50_INSTR0. */
#define BF_QuadSPI_LUT50_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT50_INSTR0) & BM_QuadSPI_LUT50_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT50_INSTR0(x, v) (HW_QuadSPI_LUT50_WR(x, (HW_QuadSPI_LUT50_RD(x) & ~BM_QuadSPI_LUT50_INSTR0) | BF_QuadSPI_LUT50_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT50, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT50_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT50_OPRND1. */
#define BM_QuadSPI_LUT50_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT50_OPRND1. */
#define BS_QuadSPI_LUT50_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT50_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT50_OPRND1 field. */
#define BR_QuadSPI_LUT50_OPRND1(x) (HW_QuadSPI_LUT50(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT50_OPRND1. */
#define BF_QuadSPI_LUT50_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT50_OPRND1) & BM_QuadSPI_LUT50_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT50_OPRND1(x, v) (HW_QuadSPI_LUT50_WR(x, (HW_QuadSPI_LUT50_RD(x) & ~BM_QuadSPI_LUT50_OPRND1) | BF_QuadSPI_LUT50_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT50, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT50_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT50_PAD1. */
#define BM_QuadSPI_LUT50_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT50_PAD1. */
#define BS_QuadSPI_LUT50_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT50_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT50_PAD1 field. */
#define BR_QuadSPI_LUT50_PAD1(x) (HW_QuadSPI_LUT50(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT50_PAD1. */
#define BF_QuadSPI_LUT50_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT50_PAD1) & BM_QuadSPI_LUT50_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT50_PAD1(x, v) (HW_QuadSPI_LUT50_WR(x, (HW_QuadSPI_LUT50_RD(x) & ~BM_QuadSPI_LUT50_PAD1) | BF_QuadSPI_LUT50_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT50, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT50_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT50_INSTR1. */
#define BM_QuadSPI_LUT50_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT50_INSTR1. */
#define BS_QuadSPI_LUT50_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT50_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT50_INSTR1 field. */
#define BR_QuadSPI_LUT50_INSTR1(x) (HW_QuadSPI_LUT50(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT50_INSTR1. */
#define BF_QuadSPI_LUT50_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT50_INSTR1) & BM_QuadSPI_LUT50_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT50_INSTR1(x, v) (HW_QuadSPI_LUT50_WR(x, (HW_QuadSPI_LUT50_RD(x) & ~BM_QuadSPI_LUT50_INSTR1) | BF_QuadSPI_LUT50_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT51 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT51 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut51
{
    uint32_t U;
    struct _hw_quadspi_lut51_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut51_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT51 register
 */
/*@{*/
#define HW_QuadSPI_LUT51_ADDR(x) ((uintptr_t)(x) + 0x3DCU)

#define HW_QuadSPI_LUT51(x)      (*(__IO hw_quadspi_lut51_t *) HW_QuadSPI_LUT51_ADDR(x))
#define HW_QuadSPI_LUT51_RD(x)   (HW_QuadSPI_LUT51(x).U)
#define HW_QuadSPI_LUT51_WR(x, v) (HW_QuadSPI_LUT51(x).U = (v))
#define HW_QuadSPI_LUT51_SET(x, v) (HW_QuadSPI_LUT51_WR(x, HW_QuadSPI_LUT51_RD(x) |  (v)))
#define HW_QuadSPI_LUT51_CLR(x, v) (HW_QuadSPI_LUT51_WR(x, HW_QuadSPI_LUT51_RD(x) & ~(v)))
#define HW_QuadSPI_LUT51_TOG(x, v) (HW_QuadSPI_LUT51_WR(x, HW_QuadSPI_LUT51_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT51 bitfields
 */

/*!
 * @name Register QuadSPI_LUT51, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT51_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT51_OPRND0. */
#define BM_QuadSPI_LUT51_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT51_OPRND0. */
#define BS_QuadSPI_LUT51_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT51_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT51_OPRND0 field. */
#define BR_QuadSPI_LUT51_OPRND0(x) (HW_QuadSPI_LUT51(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT51_OPRND0. */
#define BF_QuadSPI_LUT51_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT51_OPRND0) & BM_QuadSPI_LUT51_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT51_OPRND0(x, v) (HW_QuadSPI_LUT51_WR(x, (HW_QuadSPI_LUT51_RD(x) & ~BM_QuadSPI_LUT51_OPRND0) | BF_QuadSPI_LUT51_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT51, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT51_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT51_PAD0. */
#define BM_QuadSPI_LUT51_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT51_PAD0. */
#define BS_QuadSPI_LUT51_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT51_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT51_PAD0 field. */
#define BR_QuadSPI_LUT51_PAD0(x) (HW_QuadSPI_LUT51(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT51_PAD0. */
#define BF_QuadSPI_LUT51_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT51_PAD0) & BM_QuadSPI_LUT51_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT51_PAD0(x, v) (HW_QuadSPI_LUT51_WR(x, (HW_QuadSPI_LUT51_RD(x) & ~BM_QuadSPI_LUT51_PAD0) | BF_QuadSPI_LUT51_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT51, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT51_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT51_INSTR0. */
#define BM_QuadSPI_LUT51_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT51_INSTR0. */
#define BS_QuadSPI_LUT51_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT51_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT51_INSTR0 field. */
#define BR_QuadSPI_LUT51_INSTR0(x) (HW_QuadSPI_LUT51(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT51_INSTR0. */
#define BF_QuadSPI_LUT51_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT51_INSTR0) & BM_QuadSPI_LUT51_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT51_INSTR0(x, v) (HW_QuadSPI_LUT51_WR(x, (HW_QuadSPI_LUT51_RD(x) & ~BM_QuadSPI_LUT51_INSTR0) | BF_QuadSPI_LUT51_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT51, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT51_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT51_OPRND1. */
#define BM_QuadSPI_LUT51_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT51_OPRND1. */
#define BS_QuadSPI_LUT51_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT51_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT51_OPRND1 field. */
#define BR_QuadSPI_LUT51_OPRND1(x) (HW_QuadSPI_LUT51(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT51_OPRND1. */
#define BF_QuadSPI_LUT51_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT51_OPRND1) & BM_QuadSPI_LUT51_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT51_OPRND1(x, v) (HW_QuadSPI_LUT51_WR(x, (HW_QuadSPI_LUT51_RD(x) & ~BM_QuadSPI_LUT51_OPRND1) | BF_QuadSPI_LUT51_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT51, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT51_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT51_PAD1. */
#define BM_QuadSPI_LUT51_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT51_PAD1. */
#define BS_QuadSPI_LUT51_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT51_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT51_PAD1 field. */
#define BR_QuadSPI_LUT51_PAD1(x) (HW_QuadSPI_LUT51(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT51_PAD1. */
#define BF_QuadSPI_LUT51_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT51_PAD1) & BM_QuadSPI_LUT51_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT51_PAD1(x, v) (HW_QuadSPI_LUT51_WR(x, (HW_QuadSPI_LUT51_RD(x) & ~BM_QuadSPI_LUT51_PAD1) | BF_QuadSPI_LUT51_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT51, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT51_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT51_INSTR1. */
#define BM_QuadSPI_LUT51_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT51_INSTR1. */
#define BS_QuadSPI_LUT51_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT51_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT51_INSTR1 field. */
#define BR_QuadSPI_LUT51_INSTR1(x) (HW_QuadSPI_LUT51(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT51_INSTR1. */
#define BF_QuadSPI_LUT51_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT51_INSTR1) & BM_QuadSPI_LUT51_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT51_INSTR1(x, v) (HW_QuadSPI_LUT51_WR(x, (HW_QuadSPI_LUT51_RD(x) & ~BM_QuadSPI_LUT51_INSTR1) | BF_QuadSPI_LUT51_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT52 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT52 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut52
{
    uint32_t U;
    struct _hw_quadspi_lut52_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut52_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT52 register
 */
/*@{*/
#define HW_QuadSPI_LUT52_ADDR(x) ((uintptr_t)(x) + 0x3E0U)

#define HW_QuadSPI_LUT52(x)      (*(__IO hw_quadspi_lut52_t *) HW_QuadSPI_LUT52_ADDR(x))
#define HW_QuadSPI_LUT52_RD(x)   (HW_QuadSPI_LUT52(x).U)
#define HW_QuadSPI_LUT52_WR(x, v) (HW_QuadSPI_LUT52(x).U = (v))
#define HW_QuadSPI_LUT52_SET(x, v) (HW_QuadSPI_LUT52_WR(x, HW_QuadSPI_LUT52_RD(x) |  (v)))
#define HW_QuadSPI_LUT52_CLR(x, v) (HW_QuadSPI_LUT52_WR(x, HW_QuadSPI_LUT52_RD(x) & ~(v)))
#define HW_QuadSPI_LUT52_TOG(x, v) (HW_QuadSPI_LUT52_WR(x, HW_QuadSPI_LUT52_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT52 bitfields
 */

/*!
 * @name Register QuadSPI_LUT52, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT52_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT52_OPRND0. */
#define BM_QuadSPI_LUT52_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT52_OPRND0. */
#define BS_QuadSPI_LUT52_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT52_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT52_OPRND0 field. */
#define BR_QuadSPI_LUT52_OPRND0(x) (HW_QuadSPI_LUT52(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT52_OPRND0. */
#define BF_QuadSPI_LUT52_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT52_OPRND0) & BM_QuadSPI_LUT52_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT52_OPRND0(x, v) (HW_QuadSPI_LUT52_WR(x, (HW_QuadSPI_LUT52_RD(x) & ~BM_QuadSPI_LUT52_OPRND0) | BF_QuadSPI_LUT52_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT52, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT52_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT52_PAD0. */
#define BM_QuadSPI_LUT52_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT52_PAD0. */
#define BS_QuadSPI_LUT52_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT52_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT52_PAD0 field. */
#define BR_QuadSPI_LUT52_PAD0(x) (HW_QuadSPI_LUT52(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT52_PAD0. */
#define BF_QuadSPI_LUT52_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT52_PAD0) & BM_QuadSPI_LUT52_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT52_PAD0(x, v) (HW_QuadSPI_LUT52_WR(x, (HW_QuadSPI_LUT52_RD(x) & ~BM_QuadSPI_LUT52_PAD0) | BF_QuadSPI_LUT52_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT52, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT52_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT52_INSTR0. */
#define BM_QuadSPI_LUT52_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT52_INSTR0. */
#define BS_QuadSPI_LUT52_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT52_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT52_INSTR0 field. */
#define BR_QuadSPI_LUT52_INSTR0(x) (HW_QuadSPI_LUT52(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT52_INSTR0. */
#define BF_QuadSPI_LUT52_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT52_INSTR0) & BM_QuadSPI_LUT52_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT52_INSTR0(x, v) (HW_QuadSPI_LUT52_WR(x, (HW_QuadSPI_LUT52_RD(x) & ~BM_QuadSPI_LUT52_INSTR0) | BF_QuadSPI_LUT52_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT52, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT52_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT52_OPRND1. */
#define BM_QuadSPI_LUT52_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT52_OPRND1. */
#define BS_QuadSPI_LUT52_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT52_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT52_OPRND1 field. */
#define BR_QuadSPI_LUT52_OPRND1(x) (HW_QuadSPI_LUT52(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT52_OPRND1. */
#define BF_QuadSPI_LUT52_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT52_OPRND1) & BM_QuadSPI_LUT52_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT52_OPRND1(x, v) (HW_QuadSPI_LUT52_WR(x, (HW_QuadSPI_LUT52_RD(x) & ~BM_QuadSPI_LUT52_OPRND1) | BF_QuadSPI_LUT52_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT52, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT52_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT52_PAD1. */
#define BM_QuadSPI_LUT52_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT52_PAD1. */
#define BS_QuadSPI_LUT52_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT52_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT52_PAD1 field. */
#define BR_QuadSPI_LUT52_PAD1(x) (HW_QuadSPI_LUT52(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT52_PAD1. */
#define BF_QuadSPI_LUT52_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT52_PAD1) & BM_QuadSPI_LUT52_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT52_PAD1(x, v) (HW_QuadSPI_LUT52_WR(x, (HW_QuadSPI_LUT52_RD(x) & ~BM_QuadSPI_LUT52_PAD1) | BF_QuadSPI_LUT52_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT52, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT52_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT52_INSTR1. */
#define BM_QuadSPI_LUT52_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT52_INSTR1. */
#define BS_QuadSPI_LUT52_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT52_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT52_INSTR1 field. */
#define BR_QuadSPI_LUT52_INSTR1(x) (HW_QuadSPI_LUT52(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT52_INSTR1. */
#define BF_QuadSPI_LUT52_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT52_INSTR1) & BM_QuadSPI_LUT52_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT52_INSTR1(x, v) (HW_QuadSPI_LUT52_WR(x, (HW_QuadSPI_LUT52_RD(x) & ~BM_QuadSPI_LUT52_INSTR1) | BF_QuadSPI_LUT52_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT53 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT53 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut53
{
    uint32_t U;
    struct _hw_quadspi_lut53_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut53_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT53 register
 */
/*@{*/
#define HW_QuadSPI_LUT53_ADDR(x) ((uintptr_t)(x) + 0x3E4U)

#define HW_QuadSPI_LUT53(x)      (*(__IO hw_quadspi_lut53_t *) HW_QuadSPI_LUT53_ADDR(x))
#define HW_QuadSPI_LUT53_RD(x)   (HW_QuadSPI_LUT53(x).U)
#define HW_QuadSPI_LUT53_WR(x, v) (HW_QuadSPI_LUT53(x).U = (v))
#define HW_QuadSPI_LUT53_SET(x, v) (HW_QuadSPI_LUT53_WR(x, HW_QuadSPI_LUT53_RD(x) |  (v)))
#define HW_QuadSPI_LUT53_CLR(x, v) (HW_QuadSPI_LUT53_WR(x, HW_QuadSPI_LUT53_RD(x) & ~(v)))
#define HW_QuadSPI_LUT53_TOG(x, v) (HW_QuadSPI_LUT53_WR(x, HW_QuadSPI_LUT53_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT53 bitfields
 */

/*!
 * @name Register QuadSPI_LUT53, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT53_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT53_OPRND0. */
#define BM_QuadSPI_LUT53_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT53_OPRND0. */
#define BS_QuadSPI_LUT53_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT53_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT53_OPRND0 field. */
#define BR_QuadSPI_LUT53_OPRND0(x) (HW_QuadSPI_LUT53(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT53_OPRND0. */
#define BF_QuadSPI_LUT53_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT53_OPRND0) & BM_QuadSPI_LUT53_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT53_OPRND0(x, v) (HW_QuadSPI_LUT53_WR(x, (HW_QuadSPI_LUT53_RD(x) & ~BM_QuadSPI_LUT53_OPRND0) | BF_QuadSPI_LUT53_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT53, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT53_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT53_PAD0. */
#define BM_QuadSPI_LUT53_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT53_PAD0. */
#define BS_QuadSPI_LUT53_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT53_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT53_PAD0 field. */
#define BR_QuadSPI_LUT53_PAD0(x) (HW_QuadSPI_LUT53(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT53_PAD0. */
#define BF_QuadSPI_LUT53_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT53_PAD0) & BM_QuadSPI_LUT53_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT53_PAD0(x, v) (HW_QuadSPI_LUT53_WR(x, (HW_QuadSPI_LUT53_RD(x) & ~BM_QuadSPI_LUT53_PAD0) | BF_QuadSPI_LUT53_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT53, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT53_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT53_INSTR0. */
#define BM_QuadSPI_LUT53_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT53_INSTR0. */
#define BS_QuadSPI_LUT53_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT53_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT53_INSTR0 field. */
#define BR_QuadSPI_LUT53_INSTR0(x) (HW_QuadSPI_LUT53(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT53_INSTR0. */
#define BF_QuadSPI_LUT53_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT53_INSTR0) & BM_QuadSPI_LUT53_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT53_INSTR0(x, v) (HW_QuadSPI_LUT53_WR(x, (HW_QuadSPI_LUT53_RD(x) & ~BM_QuadSPI_LUT53_INSTR0) | BF_QuadSPI_LUT53_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT53, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT53_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT53_OPRND1. */
#define BM_QuadSPI_LUT53_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT53_OPRND1. */
#define BS_QuadSPI_LUT53_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT53_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT53_OPRND1 field. */
#define BR_QuadSPI_LUT53_OPRND1(x) (HW_QuadSPI_LUT53(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT53_OPRND1. */
#define BF_QuadSPI_LUT53_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT53_OPRND1) & BM_QuadSPI_LUT53_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT53_OPRND1(x, v) (HW_QuadSPI_LUT53_WR(x, (HW_QuadSPI_LUT53_RD(x) & ~BM_QuadSPI_LUT53_OPRND1) | BF_QuadSPI_LUT53_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT53, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT53_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT53_PAD1. */
#define BM_QuadSPI_LUT53_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT53_PAD1. */
#define BS_QuadSPI_LUT53_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT53_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT53_PAD1 field. */
#define BR_QuadSPI_LUT53_PAD1(x) (HW_QuadSPI_LUT53(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT53_PAD1. */
#define BF_QuadSPI_LUT53_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT53_PAD1) & BM_QuadSPI_LUT53_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT53_PAD1(x, v) (HW_QuadSPI_LUT53_WR(x, (HW_QuadSPI_LUT53_RD(x) & ~BM_QuadSPI_LUT53_PAD1) | BF_QuadSPI_LUT53_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT53, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT53_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT53_INSTR1. */
#define BM_QuadSPI_LUT53_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT53_INSTR1. */
#define BS_QuadSPI_LUT53_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT53_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT53_INSTR1 field. */
#define BR_QuadSPI_LUT53_INSTR1(x) (HW_QuadSPI_LUT53(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT53_INSTR1. */
#define BF_QuadSPI_LUT53_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT53_INSTR1) & BM_QuadSPI_LUT53_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT53_INSTR1(x, v) (HW_QuadSPI_LUT53_WR(x, (HW_QuadSPI_LUT53_RD(x) & ~BM_QuadSPI_LUT53_INSTR1) | BF_QuadSPI_LUT53_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT54 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT54 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut54
{
    uint32_t U;
    struct _hw_quadspi_lut54_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut54_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT54 register
 */
/*@{*/
#define HW_QuadSPI_LUT54_ADDR(x) ((uintptr_t)(x) + 0x3E8U)

#define HW_QuadSPI_LUT54(x)      (*(__IO hw_quadspi_lut54_t *) HW_QuadSPI_LUT54_ADDR(x))
#define HW_QuadSPI_LUT54_RD(x)   (HW_QuadSPI_LUT54(x).U)
#define HW_QuadSPI_LUT54_WR(x, v) (HW_QuadSPI_LUT54(x).U = (v))
#define HW_QuadSPI_LUT54_SET(x, v) (HW_QuadSPI_LUT54_WR(x, HW_QuadSPI_LUT54_RD(x) |  (v)))
#define HW_QuadSPI_LUT54_CLR(x, v) (HW_QuadSPI_LUT54_WR(x, HW_QuadSPI_LUT54_RD(x) & ~(v)))
#define HW_QuadSPI_LUT54_TOG(x, v) (HW_QuadSPI_LUT54_WR(x, HW_QuadSPI_LUT54_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT54 bitfields
 */

/*!
 * @name Register QuadSPI_LUT54, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT54_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT54_OPRND0. */
#define BM_QuadSPI_LUT54_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT54_OPRND0. */
#define BS_QuadSPI_LUT54_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT54_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT54_OPRND0 field. */
#define BR_QuadSPI_LUT54_OPRND0(x) (HW_QuadSPI_LUT54(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT54_OPRND0. */
#define BF_QuadSPI_LUT54_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT54_OPRND0) & BM_QuadSPI_LUT54_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT54_OPRND0(x, v) (HW_QuadSPI_LUT54_WR(x, (HW_QuadSPI_LUT54_RD(x) & ~BM_QuadSPI_LUT54_OPRND0) | BF_QuadSPI_LUT54_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT54, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT54_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT54_PAD0. */
#define BM_QuadSPI_LUT54_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT54_PAD0. */
#define BS_QuadSPI_LUT54_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT54_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT54_PAD0 field. */
#define BR_QuadSPI_LUT54_PAD0(x) (HW_QuadSPI_LUT54(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT54_PAD0. */
#define BF_QuadSPI_LUT54_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT54_PAD0) & BM_QuadSPI_LUT54_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT54_PAD0(x, v) (HW_QuadSPI_LUT54_WR(x, (HW_QuadSPI_LUT54_RD(x) & ~BM_QuadSPI_LUT54_PAD0) | BF_QuadSPI_LUT54_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT54, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT54_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT54_INSTR0. */
#define BM_QuadSPI_LUT54_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT54_INSTR0. */
#define BS_QuadSPI_LUT54_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT54_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT54_INSTR0 field. */
#define BR_QuadSPI_LUT54_INSTR0(x) (HW_QuadSPI_LUT54(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT54_INSTR0. */
#define BF_QuadSPI_LUT54_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT54_INSTR0) & BM_QuadSPI_LUT54_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT54_INSTR0(x, v) (HW_QuadSPI_LUT54_WR(x, (HW_QuadSPI_LUT54_RD(x) & ~BM_QuadSPI_LUT54_INSTR0) | BF_QuadSPI_LUT54_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT54, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT54_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT54_OPRND1. */
#define BM_QuadSPI_LUT54_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT54_OPRND1. */
#define BS_QuadSPI_LUT54_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT54_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT54_OPRND1 field. */
#define BR_QuadSPI_LUT54_OPRND1(x) (HW_QuadSPI_LUT54(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT54_OPRND1. */
#define BF_QuadSPI_LUT54_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT54_OPRND1) & BM_QuadSPI_LUT54_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT54_OPRND1(x, v) (HW_QuadSPI_LUT54_WR(x, (HW_QuadSPI_LUT54_RD(x) & ~BM_QuadSPI_LUT54_OPRND1) | BF_QuadSPI_LUT54_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT54, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT54_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT54_PAD1. */
#define BM_QuadSPI_LUT54_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT54_PAD1. */
#define BS_QuadSPI_LUT54_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT54_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT54_PAD1 field. */
#define BR_QuadSPI_LUT54_PAD1(x) (HW_QuadSPI_LUT54(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT54_PAD1. */
#define BF_QuadSPI_LUT54_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT54_PAD1) & BM_QuadSPI_LUT54_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT54_PAD1(x, v) (HW_QuadSPI_LUT54_WR(x, (HW_QuadSPI_LUT54_RD(x) & ~BM_QuadSPI_LUT54_PAD1) | BF_QuadSPI_LUT54_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT54, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT54_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT54_INSTR1. */
#define BM_QuadSPI_LUT54_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT54_INSTR1. */
#define BS_QuadSPI_LUT54_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT54_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT54_INSTR1 field. */
#define BR_QuadSPI_LUT54_INSTR1(x) (HW_QuadSPI_LUT54(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT54_INSTR1. */
#define BF_QuadSPI_LUT54_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT54_INSTR1) & BM_QuadSPI_LUT54_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT54_INSTR1(x, v) (HW_QuadSPI_LUT54_WR(x, (HW_QuadSPI_LUT54_RD(x) & ~BM_QuadSPI_LUT54_INSTR1) | BF_QuadSPI_LUT54_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT55 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT55 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut55
{
    uint32_t U;
    struct _hw_quadspi_lut55_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut55_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT55 register
 */
/*@{*/
#define HW_QuadSPI_LUT55_ADDR(x) ((uintptr_t)(x) + 0x3ECU)

#define HW_QuadSPI_LUT55(x)      (*(__IO hw_quadspi_lut55_t *) HW_QuadSPI_LUT55_ADDR(x))
#define HW_QuadSPI_LUT55_RD(x)   (HW_QuadSPI_LUT55(x).U)
#define HW_QuadSPI_LUT55_WR(x, v) (HW_QuadSPI_LUT55(x).U = (v))
#define HW_QuadSPI_LUT55_SET(x, v) (HW_QuadSPI_LUT55_WR(x, HW_QuadSPI_LUT55_RD(x) |  (v)))
#define HW_QuadSPI_LUT55_CLR(x, v) (HW_QuadSPI_LUT55_WR(x, HW_QuadSPI_LUT55_RD(x) & ~(v)))
#define HW_QuadSPI_LUT55_TOG(x, v) (HW_QuadSPI_LUT55_WR(x, HW_QuadSPI_LUT55_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT55 bitfields
 */

/*!
 * @name Register QuadSPI_LUT55, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT55_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT55_OPRND0. */
#define BM_QuadSPI_LUT55_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT55_OPRND0. */
#define BS_QuadSPI_LUT55_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT55_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT55_OPRND0 field. */
#define BR_QuadSPI_LUT55_OPRND0(x) (HW_QuadSPI_LUT55(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT55_OPRND0. */
#define BF_QuadSPI_LUT55_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT55_OPRND0) & BM_QuadSPI_LUT55_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT55_OPRND0(x, v) (HW_QuadSPI_LUT55_WR(x, (HW_QuadSPI_LUT55_RD(x) & ~BM_QuadSPI_LUT55_OPRND0) | BF_QuadSPI_LUT55_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT55, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT55_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT55_PAD0. */
#define BM_QuadSPI_LUT55_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT55_PAD0. */
#define BS_QuadSPI_LUT55_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT55_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT55_PAD0 field. */
#define BR_QuadSPI_LUT55_PAD0(x) (HW_QuadSPI_LUT55(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT55_PAD0. */
#define BF_QuadSPI_LUT55_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT55_PAD0) & BM_QuadSPI_LUT55_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT55_PAD0(x, v) (HW_QuadSPI_LUT55_WR(x, (HW_QuadSPI_LUT55_RD(x) & ~BM_QuadSPI_LUT55_PAD0) | BF_QuadSPI_LUT55_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT55, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT55_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT55_INSTR0. */
#define BM_QuadSPI_LUT55_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT55_INSTR0. */
#define BS_QuadSPI_LUT55_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT55_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT55_INSTR0 field. */
#define BR_QuadSPI_LUT55_INSTR0(x) (HW_QuadSPI_LUT55(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT55_INSTR0. */
#define BF_QuadSPI_LUT55_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT55_INSTR0) & BM_QuadSPI_LUT55_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT55_INSTR0(x, v) (HW_QuadSPI_LUT55_WR(x, (HW_QuadSPI_LUT55_RD(x) & ~BM_QuadSPI_LUT55_INSTR0) | BF_QuadSPI_LUT55_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT55, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT55_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT55_OPRND1. */
#define BM_QuadSPI_LUT55_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT55_OPRND1. */
#define BS_QuadSPI_LUT55_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT55_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT55_OPRND1 field. */
#define BR_QuadSPI_LUT55_OPRND1(x) (HW_QuadSPI_LUT55(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT55_OPRND1. */
#define BF_QuadSPI_LUT55_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT55_OPRND1) & BM_QuadSPI_LUT55_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT55_OPRND1(x, v) (HW_QuadSPI_LUT55_WR(x, (HW_QuadSPI_LUT55_RD(x) & ~BM_QuadSPI_LUT55_OPRND1) | BF_QuadSPI_LUT55_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT55, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT55_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT55_PAD1. */
#define BM_QuadSPI_LUT55_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT55_PAD1. */
#define BS_QuadSPI_LUT55_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT55_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT55_PAD1 field. */
#define BR_QuadSPI_LUT55_PAD1(x) (HW_QuadSPI_LUT55(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT55_PAD1. */
#define BF_QuadSPI_LUT55_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT55_PAD1) & BM_QuadSPI_LUT55_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT55_PAD1(x, v) (HW_QuadSPI_LUT55_WR(x, (HW_QuadSPI_LUT55_RD(x) & ~BM_QuadSPI_LUT55_PAD1) | BF_QuadSPI_LUT55_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT55, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT55_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT55_INSTR1. */
#define BM_QuadSPI_LUT55_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT55_INSTR1. */
#define BS_QuadSPI_LUT55_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT55_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT55_INSTR1 field. */
#define BR_QuadSPI_LUT55_INSTR1(x) (HW_QuadSPI_LUT55(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT55_INSTR1. */
#define BF_QuadSPI_LUT55_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT55_INSTR1) & BM_QuadSPI_LUT55_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT55_INSTR1(x, v) (HW_QuadSPI_LUT55_WR(x, (HW_QuadSPI_LUT55_RD(x) & ~BM_QuadSPI_LUT55_INSTR1) | BF_QuadSPI_LUT55_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT56 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT56 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut56
{
    uint32_t U;
    struct _hw_quadspi_lut56_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut56_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT56 register
 */
/*@{*/
#define HW_QuadSPI_LUT56_ADDR(x) ((uintptr_t)(x) + 0x3F0U)

#define HW_QuadSPI_LUT56(x)      (*(__IO hw_quadspi_lut56_t *) HW_QuadSPI_LUT56_ADDR(x))
#define HW_QuadSPI_LUT56_RD(x)   (HW_QuadSPI_LUT56(x).U)
#define HW_QuadSPI_LUT56_WR(x, v) (HW_QuadSPI_LUT56(x).U = (v))
#define HW_QuadSPI_LUT56_SET(x, v) (HW_QuadSPI_LUT56_WR(x, HW_QuadSPI_LUT56_RD(x) |  (v)))
#define HW_QuadSPI_LUT56_CLR(x, v) (HW_QuadSPI_LUT56_WR(x, HW_QuadSPI_LUT56_RD(x) & ~(v)))
#define HW_QuadSPI_LUT56_TOG(x, v) (HW_QuadSPI_LUT56_WR(x, HW_QuadSPI_LUT56_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT56 bitfields
 */

/*!
 * @name Register QuadSPI_LUT56, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT56_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT56_OPRND0. */
#define BM_QuadSPI_LUT56_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT56_OPRND0. */
#define BS_QuadSPI_LUT56_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT56_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT56_OPRND0 field. */
#define BR_QuadSPI_LUT56_OPRND0(x) (HW_QuadSPI_LUT56(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT56_OPRND0. */
#define BF_QuadSPI_LUT56_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT56_OPRND0) & BM_QuadSPI_LUT56_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT56_OPRND0(x, v) (HW_QuadSPI_LUT56_WR(x, (HW_QuadSPI_LUT56_RD(x) & ~BM_QuadSPI_LUT56_OPRND0) | BF_QuadSPI_LUT56_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT56, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT56_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT56_PAD0. */
#define BM_QuadSPI_LUT56_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT56_PAD0. */
#define BS_QuadSPI_LUT56_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT56_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT56_PAD0 field. */
#define BR_QuadSPI_LUT56_PAD0(x) (HW_QuadSPI_LUT56(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT56_PAD0. */
#define BF_QuadSPI_LUT56_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT56_PAD0) & BM_QuadSPI_LUT56_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT56_PAD0(x, v) (HW_QuadSPI_LUT56_WR(x, (HW_QuadSPI_LUT56_RD(x) & ~BM_QuadSPI_LUT56_PAD0) | BF_QuadSPI_LUT56_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT56, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT56_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT56_INSTR0. */
#define BM_QuadSPI_LUT56_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT56_INSTR0. */
#define BS_QuadSPI_LUT56_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT56_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT56_INSTR0 field. */
#define BR_QuadSPI_LUT56_INSTR0(x) (HW_QuadSPI_LUT56(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT56_INSTR0. */
#define BF_QuadSPI_LUT56_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT56_INSTR0) & BM_QuadSPI_LUT56_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT56_INSTR0(x, v) (HW_QuadSPI_LUT56_WR(x, (HW_QuadSPI_LUT56_RD(x) & ~BM_QuadSPI_LUT56_INSTR0) | BF_QuadSPI_LUT56_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT56, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT56_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT56_OPRND1. */
#define BM_QuadSPI_LUT56_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT56_OPRND1. */
#define BS_QuadSPI_LUT56_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT56_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT56_OPRND1 field. */
#define BR_QuadSPI_LUT56_OPRND1(x) (HW_QuadSPI_LUT56(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT56_OPRND1. */
#define BF_QuadSPI_LUT56_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT56_OPRND1) & BM_QuadSPI_LUT56_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT56_OPRND1(x, v) (HW_QuadSPI_LUT56_WR(x, (HW_QuadSPI_LUT56_RD(x) & ~BM_QuadSPI_LUT56_OPRND1) | BF_QuadSPI_LUT56_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT56, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT56_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT56_PAD1. */
#define BM_QuadSPI_LUT56_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT56_PAD1. */
#define BS_QuadSPI_LUT56_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT56_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT56_PAD1 field. */
#define BR_QuadSPI_LUT56_PAD1(x) (HW_QuadSPI_LUT56(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT56_PAD1. */
#define BF_QuadSPI_LUT56_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT56_PAD1) & BM_QuadSPI_LUT56_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT56_PAD1(x, v) (HW_QuadSPI_LUT56_WR(x, (HW_QuadSPI_LUT56_RD(x) & ~BM_QuadSPI_LUT56_PAD1) | BF_QuadSPI_LUT56_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT56, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT56_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT56_INSTR1. */
#define BM_QuadSPI_LUT56_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT56_INSTR1. */
#define BS_QuadSPI_LUT56_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT56_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT56_INSTR1 field. */
#define BR_QuadSPI_LUT56_INSTR1(x) (HW_QuadSPI_LUT56(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT56_INSTR1. */
#define BF_QuadSPI_LUT56_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT56_INSTR1) & BM_QuadSPI_LUT56_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT56_INSTR1(x, v) (HW_QuadSPI_LUT56_WR(x, (HW_QuadSPI_LUT56_RD(x) & ~BM_QuadSPI_LUT56_INSTR1) | BF_QuadSPI_LUT56_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT57 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT57 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut57
{
    uint32_t U;
    struct _hw_quadspi_lut57_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut57_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT57 register
 */
/*@{*/
#define HW_QuadSPI_LUT57_ADDR(x) ((uintptr_t)(x) + 0x3F4U)

#define HW_QuadSPI_LUT57(x)      (*(__IO hw_quadspi_lut57_t *) HW_QuadSPI_LUT57_ADDR(x))
#define HW_QuadSPI_LUT57_RD(x)   (HW_QuadSPI_LUT57(x).U)
#define HW_QuadSPI_LUT57_WR(x, v) (HW_QuadSPI_LUT57(x).U = (v))
#define HW_QuadSPI_LUT57_SET(x, v) (HW_QuadSPI_LUT57_WR(x, HW_QuadSPI_LUT57_RD(x) |  (v)))
#define HW_QuadSPI_LUT57_CLR(x, v) (HW_QuadSPI_LUT57_WR(x, HW_QuadSPI_LUT57_RD(x) & ~(v)))
#define HW_QuadSPI_LUT57_TOG(x, v) (HW_QuadSPI_LUT57_WR(x, HW_QuadSPI_LUT57_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT57 bitfields
 */

/*!
 * @name Register QuadSPI_LUT57, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT57_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT57_OPRND0. */
#define BM_QuadSPI_LUT57_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT57_OPRND0. */
#define BS_QuadSPI_LUT57_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT57_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT57_OPRND0 field. */
#define BR_QuadSPI_LUT57_OPRND0(x) (HW_QuadSPI_LUT57(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT57_OPRND0. */
#define BF_QuadSPI_LUT57_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT57_OPRND0) & BM_QuadSPI_LUT57_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT57_OPRND0(x, v) (HW_QuadSPI_LUT57_WR(x, (HW_QuadSPI_LUT57_RD(x) & ~BM_QuadSPI_LUT57_OPRND0) | BF_QuadSPI_LUT57_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT57, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT57_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT57_PAD0. */
#define BM_QuadSPI_LUT57_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT57_PAD0. */
#define BS_QuadSPI_LUT57_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT57_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT57_PAD0 field. */
#define BR_QuadSPI_LUT57_PAD0(x) (HW_QuadSPI_LUT57(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT57_PAD0. */
#define BF_QuadSPI_LUT57_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT57_PAD0) & BM_QuadSPI_LUT57_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT57_PAD0(x, v) (HW_QuadSPI_LUT57_WR(x, (HW_QuadSPI_LUT57_RD(x) & ~BM_QuadSPI_LUT57_PAD0) | BF_QuadSPI_LUT57_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT57, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT57_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT57_INSTR0. */
#define BM_QuadSPI_LUT57_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT57_INSTR0. */
#define BS_QuadSPI_LUT57_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT57_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT57_INSTR0 field. */
#define BR_QuadSPI_LUT57_INSTR0(x) (HW_QuadSPI_LUT57(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT57_INSTR0. */
#define BF_QuadSPI_LUT57_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT57_INSTR0) & BM_QuadSPI_LUT57_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT57_INSTR0(x, v) (HW_QuadSPI_LUT57_WR(x, (HW_QuadSPI_LUT57_RD(x) & ~BM_QuadSPI_LUT57_INSTR0) | BF_QuadSPI_LUT57_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT57, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT57_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT57_OPRND1. */
#define BM_QuadSPI_LUT57_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT57_OPRND1. */
#define BS_QuadSPI_LUT57_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT57_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT57_OPRND1 field. */
#define BR_QuadSPI_LUT57_OPRND1(x) (HW_QuadSPI_LUT57(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT57_OPRND1. */
#define BF_QuadSPI_LUT57_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT57_OPRND1) & BM_QuadSPI_LUT57_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT57_OPRND1(x, v) (HW_QuadSPI_LUT57_WR(x, (HW_QuadSPI_LUT57_RD(x) & ~BM_QuadSPI_LUT57_OPRND1) | BF_QuadSPI_LUT57_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT57, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT57_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT57_PAD1. */
#define BM_QuadSPI_LUT57_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT57_PAD1. */
#define BS_QuadSPI_LUT57_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT57_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT57_PAD1 field. */
#define BR_QuadSPI_LUT57_PAD1(x) (HW_QuadSPI_LUT57(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT57_PAD1. */
#define BF_QuadSPI_LUT57_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT57_PAD1) & BM_QuadSPI_LUT57_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT57_PAD1(x, v) (HW_QuadSPI_LUT57_WR(x, (HW_QuadSPI_LUT57_RD(x) & ~BM_QuadSPI_LUT57_PAD1) | BF_QuadSPI_LUT57_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT57, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT57_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT57_INSTR1. */
#define BM_QuadSPI_LUT57_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT57_INSTR1. */
#define BS_QuadSPI_LUT57_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT57_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT57_INSTR1 field. */
#define BR_QuadSPI_LUT57_INSTR1(x) (HW_QuadSPI_LUT57(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT57_INSTR1. */
#define BF_QuadSPI_LUT57_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT57_INSTR1) & BM_QuadSPI_LUT57_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT57_INSTR1(x, v) (HW_QuadSPI_LUT57_WR(x, (HW_QuadSPI_LUT57_RD(x) & ~BM_QuadSPI_LUT57_INSTR1) | BF_QuadSPI_LUT57_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT58 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT58 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut58
{
    uint32_t U;
    struct _hw_quadspi_lut58_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut58_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT58 register
 */
/*@{*/
#define HW_QuadSPI_LUT58_ADDR(x) ((uintptr_t)(x) + 0x3F8U)

#define HW_QuadSPI_LUT58(x)      (*(__IO hw_quadspi_lut58_t *) HW_QuadSPI_LUT58_ADDR(x))
#define HW_QuadSPI_LUT58_RD(x)   (HW_QuadSPI_LUT58(x).U)
#define HW_QuadSPI_LUT58_WR(x, v) (HW_QuadSPI_LUT58(x).U = (v))
#define HW_QuadSPI_LUT58_SET(x, v) (HW_QuadSPI_LUT58_WR(x, HW_QuadSPI_LUT58_RD(x) |  (v)))
#define HW_QuadSPI_LUT58_CLR(x, v) (HW_QuadSPI_LUT58_WR(x, HW_QuadSPI_LUT58_RD(x) & ~(v)))
#define HW_QuadSPI_LUT58_TOG(x, v) (HW_QuadSPI_LUT58_WR(x, HW_QuadSPI_LUT58_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT58 bitfields
 */

/*!
 * @name Register QuadSPI_LUT58, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT58_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT58_OPRND0. */
#define BM_QuadSPI_LUT58_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT58_OPRND0. */
#define BS_QuadSPI_LUT58_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT58_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT58_OPRND0 field. */
#define BR_QuadSPI_LUT58_OPRND0(x) (HW_QuadSPI_LUT58(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT58_OPRND0. */
#define BF_QuadSPI_LUT58_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT58_OPRND0) & BM_QuadSPI_LUT58_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT58_OPRND0(x, v) (HW_QuadSPI_LUT58_WR(x, (HW_QuadSPI_LUT58_RD(x) & ~BM_QuadSPI_LUT58_OPRND0) | BF_QuadSPI_LUT58_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT58, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT58_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT58_PAD0. */
#define BM_QuadSPI_LUT58_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT58_PAD0. */
#define BS_QuadSPI_LUT58_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT58_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT58_PAD0 field. */
#define BR_QuadSPI_LUT58_PAD0(x) (HW_QuadSPI_LUT58(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT58_PAD0. */
#define BF_QuadSPI_LUT58_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT58_PAD0) & BM_QuadSPI_LUT58_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT58_PAD0(x, v) (HW_QuadSPI_LUT58_WR(x, (HW_QuadSPI_LUT58_RD(x) & ~BM_QuadSPI_LUT58_PAD0) | BF_QuadSPI_LUT58_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT58, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT58_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT58_INSTR0. */
#define BM_QuadSPI_LUT58_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT58_INSTR0. */
#define BS_QuadSPI_LUT58_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT58_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT58_INSTR0 field. */
#define BR_QuadSPI_LUT58_INSTR0(x) (HW_QuadSPI_LUT58(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT58_INSTR0. */
#define BF_QuadSPI_LUT58_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT58_INSTR0) & BM_QuadSPI_LUT58_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT58_INSTR0(x, v) (HW_QuadSPI_LUT58_WR(x, (HW_QuadSPI_LUT58_RD(x) & ~BM_QuadSPI_LUT58_INSTR0) | BF_QuadSPI_LUT58_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT58, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT58_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT58_OPRND1. */
#define BM_QuadSPI_LUT58_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT58_OPRND1. */
#define BS_QuadSPI_LUT58_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT58_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT58_OPRND1 field. */
#define BR_QuadSPI_LUT58_OPRND1(x) (HW_QuadSPI_LUT58(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT58_OPRND1. */
#define BF_QuadSPI_LUT58_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT58_OPRND1) & BM_QuadSPI_LUT58_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT58_OPRND1(x, v) (HW_QuadSPI_LUT58_WR(x, (HW_QuadSPI_LUT58_RD(x) & ~BM_QuadSPI_LUT58_OPRND1) | BF_QuadSPI_LUT58_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT58, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT58_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT58_PAD1. */
#define BM_QuadSPI_LUT58_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT58_PAD1. */
#define BS_QuadSPI_LUT58_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT58_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT58_PAD1 field. */
#define BR_QuadSPI_LUT58_PAD1(x) (HW_QuadSPI_LUT58(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT58_PAD1. */
#define BF_QuadSPI_LUT58_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT58_PAD1) & BM_QuadSPI_LUT58_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT58_PAD1(x, v) (HW_QuadSPI_LUT58_WR(x, (HW_QuadSPI_LUT58_RD(x) & ~BM_QuadSPI_LUT58_PAD1) | BF_QuadSPI_LUT58_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT58, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT58_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT58_INSTR1. */
#define BM_QuadSPI_LUT58_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT58_INSTR1. */
#define BS_QuadSPI_LUT58_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT58_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT58_INSTR1 field. */
#define BR_QuadSPI_LUT58_INSTR1(x) (HW_QuadSPI_LUT58(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT58_INSTR1. */
#define BF_QuadSPI_LUT58_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT58_INSTR1) & BM_QuadSPI_LUT58_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT58_INSTR1(x, v) (HW_QuadSPI_LUT58_WR(x, (HW_QuadSPI_LUT58_RD(x) & ~BM_QuadSPI_LUT58_INSTR1) | BF_QuadSPI_LUT58_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT59 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT59 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut59
{
    uint32_t U;
    struct _hw_quadspi_lut59_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut59_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT59 register
 */
/*@{*/
#define HW_QuadSPI_LUT59_ADDR(x) ((uintptr_t)(x) + 0x3FCU)

#define HW_QuadSPI_LUT59(x)      (*(__IO hw_quadspi_lut59_t *) HW_QuadSPI_LUT59_ADDR(x))
#define HW_QuadSPI_LUT59_RD(x)   (HW_QuadSPI_LUT59(x).U)
#define HW_QuadSPI_LUT59_WR(x, v) (HW_QuadSPI_LUT59(x).U = (v))
#define HW_QuadSPI_LUT59_SET(x, v) (HW_QuadSPI_LUT59_WR(x, HW_QuadSPI_LUT59_RD(x) |  (v)))
#define HW_QuadSPI_LUT59_CLR(x, v) (HW_QuadSPI_LUT59_WR(x, HW_QuadSPI_LUT59_RD(x) & ~(v)))
#define HW_QuadSPI_LUT59_TOG(x, v) (HW_QuadSPI_LUT59_WR(x, HW_QuadSPI_LUT59_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT59 bitfields
 */

/*!
 * @name Register QuadSPI_LUT59, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT59_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT59_OPRND0. */
#define BM_QuadSPI_LUT59_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT59_OPRND0. */
#define BS_QuadSPI_LUT59_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT59_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT59_OPRND0 field. */
#define BR_QuadSPI_LUT59_OPRND0(x) (HW_QuadSPI_LUT59(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT59_OPRND0. */
#define BF_QuadSPI_LUT59_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT59_OPRND0) & BM_QuadSPI_LUT59_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT59_OPRND0(x, v) (HW_QuadSPI_LUT59_WR(x, (HW_QuadSPI_LUT59_RD(x) & ~BM_QuadSPI_LUT59_OPRND0) | BF_QuadSPI_LUT59_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT59, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT59_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT59_PAD0. */
#define BM_QuadSPI_LUT59_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT59_PAD0. */
#define BS_QuadSPI_LUT59_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT59_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT59_PAD0 field. */
#define BR_QuadSPI_LUT59_PAD0(x) (HW_QuadSPI_LUT59(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT59_PAD0. */
#define BF_QuadSPI_LUT59_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT59_PAD0) & BM_QuadSPI_LUT59_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT59_PAD0(x, v) (HW_QuadSPI_LUT59_WR(x, (HW_QuadSPI_LUT59_RD(x) & ~BM_QuadSPI_LUT59_PAD0) | BF_QuadSPI_LUT59_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT59, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT59_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT59_INSTR0. */
#define BM_QuadSPI_LUT59_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT59_INSTR0. */
#define BS_QuadSPI_LUT59_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT59_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT59_INSTR0 field. */
#define BR_QuadSPI_LUT59_INSTR0(x) (HW_QuadSPI_LUT59(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT59_INSTR0. */
#define BF_QuadSPI_LUT59_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT59_INSTR0) & BM_QuadSPI_LUT59_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT59_INSTR0(x, v) (HW_QuadSPI_LUT59_WR(x, (HW_QuadSPI_LUT59_RD(x) & ~BM_QuadSPI_LUT59_INSTR0) | BF_QuadSPI_LUT59_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT59, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT59_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT59_OPRND1. */
#define BM_QuadSPI_LUT59_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT59_OPRND1. */
#define BS_QuadSPI_LUT59_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT59_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT59_OPRND1 field. */
#define BR_QuadSPI_LUT59_OPRND1(x) (HW_QuadSPI_LUT59(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT59_OPRND1. */
#define BF_QuadSPI_LUT59_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT59_OPRND1) & BM_QuadSPI_LUT59_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT59_OPRND1(x, v) (HW_QuadSPI_LUT59_WR(x, (HW_QuadSPI_LUT59_RD(x) & ~BM_QuadSPI_LUT59_OPRND1) | BF_QuadSPI_LUT59_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT59, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT59_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT59_PAD1. */
#define BM_QuadSPI_LUT59_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT59_PAD1. */
#define BS_QuadSPI_LUT59_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT59_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT59_PAD1 field. */
#define BR_QuadSPI_LUT59_PAD1(x) (HW_QuadSPI_LUT59(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT59_PAD1. */
#define BF_QuadSPI_LUT59_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT59_PAD1) & BM_QuadSPI_LUT59_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT59_PAD1(x, v) (HW_QuadSPI_LUT59_WR(x, (HW_QuadSPI_LUT59_RD(x) & ~BM_QuadSPI_LUT59_PAD1) | BF_QuadSPI_LUT59_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT59, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT59_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT59_INSTR1. */
#define BM_QuadSPI_LUT59_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT59_INSTR1. */
#define BS_QuadSPI_LUT59_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT59_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT59_INSTR1 field. */
#define BR_QuadSPI_LUT59_INSTR1(x) (HW_QuadSPI_LUT59(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT59_INSTR1. */
#define BF_QuadSPI_LUT59_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT59_INSTR1) & BM_QuadSPI_LUT59_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT59_INSTR1(x, v) (HW_QuadSPI_LUT59_WR(x, (HW_QuadSPI_LUT59_RD(x) & ~BM_QuadSPI_LUT59_INSTR1) | BF_QuadSPI_LUT59_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT60 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT60 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut60
{
    uint32_t U;
    struct _hw_quadspi_lut60_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut60_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT60 register
 */
/*@{*/
#define HW_QuadSPI_LUT60_ADDR(x) ((uintptr_t)(x) + 0x400U)

#define HW_QuadSPI_LUT60(x)      (*(__IO hw_quadspi_lut60_t *) HW_QuadSPI_LUT60_ADDR(x))
#define HW_QuadSPI_LUT60_RD(x)   (HW_QuadSPI_LUT60(x).U)
#define HW_QuadSPI_LUT60_WR(x, v) (HW_QuadSPI_LUT60(x).U = (v))
#define HW_QuadSPI_LUT60_SET(x, v) (HW_QuadSPI_LUT60_WR(x, HW_QuadSPI_LUT60_RD(x) |  (v)))
#define HW_QuadSPI_LUT60_CLR(x, v) (HW_QuadSPI_LUT60_WR(x, HW_QuadSPI_LUT60_RD(x) & ~(v)))
#define HW_QuadSPI_LUT60_TOG(x, v) (HW_QuadSPI_LUT60_WR(x, HW_QuadSPI_LUT60_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT60 bitfields
 */

/*!
 * @name Register QuadSPI_LUT60, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT60_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT60_OPRND0. */
#define BM_QuadSPI_LUT60_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT60_OPRND0. */
#define BS_QuadSPI_LUT60_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT60_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT60_OPRND0 field. */
#define BR_QuadSPI_LUT60_OPRND0(x) (HW_QuadSPI_LUT60(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT60_OPRND0. */
#define BF_QuadSPI_LUT60_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT60_OPRND0) & BM_QuadSPI_LUT60_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT60_OPRND0(x, v) (HW_QuadSPI_LUT60_WR(x, (HW_QuadSPI_LUT60_RD(x) & ~BM_QuadSPI_LUT60_OPRND0) | BF_QuadSPI_LUT60_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT60, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT60_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT60_PAD0. */
#define BM_QuadSPI_LUT60_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT60_PAD0. */
#define BS_QuadSPI_LUT60_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT60_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT60_PAD0 field. */
#define BR_QuadSPI_LUT60_PAD0(x) (HW_QuadSPI_LUT60(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT60_PAD0. */
#define BF_QuadSPI_LUT60_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT60_PAD0) & BM_QuadSPI_LUT60_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT60_PAD0(x, v) (HW_QuadSPI_LUT60_WR(x, (HW_QuadSPI_LUT60_RD(x) & ~BM_QuadSPI_LUT60_PAD0) | BF_QuadSPI_LUT60_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT60, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT60_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT60_INSTR0. */
#define BM_QuadSPI_LUT60_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT60_INSTR0. */
#define BS_QuadSPI_LUT60_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT60_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT60_INSTR0 field. */
#define BR_QuadSPI_LUT60_INSTR0(x) (HW_QuadSPI_LUT60(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT60_INSTR0. */
#define BF_QuadSPI_LUT60_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT60_INSTR0) & BM_QuadSPI_LUT60_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT60_INSTR0(x, v) (HW_QuadSPI_LUT60_WR(x, (HW_QuadSPI_LUT60_RD(x) & ~BM_QuadSPI_LUT60_INSTR0) | BF_QuadSPI_LUT60_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT60, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT60_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT60_OPRND1. */
#define BM_QuadSPI_LUT60_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT60_OPRND1. */
#define BS_QuadSPI_LUT60_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT60_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT60_OPRND1 field. */
#define BR_QuadSPI_LUT60_OPRND1(x) (HW_QuadSPI_LUT60(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT60_OPRND1. */
#define BF_QuadSPI_LUT60_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT60_OPRND1) & BM_QuadSPI_LUT60_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT60_OPRND1(x, v) (HW_QuadSPI_LUT60_WR(x, (HW_QuadSPI_LUT60_RD(x) & ~BM_QuadSPI_LUT60_OPRND1) | BF_QuadSPI_LUT60_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT60, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT60_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT60_PAD1. */
#define BM_QuadSPI_LUT60_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT60_PAD1. */
#define BS_QuadSPI_LUT60_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT60_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT60_PAD1 field. */
#define BR_QuadSPI_LUT60_PAD1(x) (HW_QuadSPI_LUT60(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT60_PAD1. */
#define BF_QuadSPI_LUT60_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT60_PAD1) & BM_QuadSPI_LUT60_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT60_PAD1(x, v) (HW_QuadSPI_LUT60_WR(x, (HW_QuadSPI_LUT60_RD(x) & ~BM_QuadSPI_LUT60_PAD1) | BF_QuadSPI_LUT60_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT60, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT60_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT60_INSTR1. */
#define BM_QuadSPI_LUT60_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT60_INSTR1. */
#define BS_QuadSPI_LUT60_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT60_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT60_INSTR1 field. */
#define BR_QuadSPI_LUT60_INSTR1(x) (HW_QuadSPI_LUT60(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT60_INSTR1. */
#define BF_QuadSPI_LUT60_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT60_INSTR1) & BM_QuadSPI_LUT60_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT60_INSTR1(x, v) (HW_QuadSPI_LUT60_WR(x, (HW_QuadSPI_LUT60_RD(x) & ~BM_QuadSPI_LUT60_INSTR1) | BF_QuadSPI_LUT60_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT61 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT61 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut61
{
    uint32_t U;
    struct _hw_quadspi_lut61_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut61_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT61 register
 */
/*@{*/
#define HW_QuadSPI_LUT61_ADDR(x) ((uintptr_t)(x) + 0x404U)

#define HW_QuadSPI_LUT61(x)      (*(__IO hw_quadspi_lut61_t *) HW_QuadSPI_LUT61_ADDR(x))
#define HW_QuadSPI_LUT61_RD(x)   (HW_QuadSPI_LUT61(x).U)
#define HW_QuadSPI_LUT61_WR(x, v) (HW_QuadSPI_LUT61(x).U = (v))
#define HW_QuadSPI_LUT61_SET(x, v) (HW_QuadSPI_LUT61_WR(x, HW_QuadSPI_LUT61_RD(x) |  (v)))
#define HW_QuadSPI_LUT61_CLR(x, v) (HW_QuadSPI_LUT61_WR(x, HW_QuadSPI_LUT61_RD(x) & ~(v)))
#define HW_QuadSPI_LUT61_TOG(x, v) (HW_QuadSPI_LUT61_WR(x, HW_QuadSPI_LUT61_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT61 bitfields
 */

/*!
 * @name Register QuadSPI_LUT61, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT61_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT61_OPRND0. */
#define BM_QuadSPI_LUT61_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT61_OPRND0. */
#define BS_QuadSPI_LUT61_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT61_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT61_OPRND0 field. */
#define BR_QuadSPI_LUT61_OPRND0(x) (HW_QuadSPI_LUT61(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT61_OPRND0. */
#define BF_QuadSPI_LUT61_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT61_OPRND0) & BM_QuadSPI_LUT61_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT61_OPRND0(x, v) (HW_QuadSPI_LUT61_WR(x, (HW_QuadSPI_LUT61_RD(x) & ~BM_QuadSPI_LUT61_OPRND0) | BF_QuadSPI_LUT61_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT61, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT61_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT61_PAD0. */
#define BM_QuadSPI_LUT61_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT61_PAD0. */
#define BS_QuadSPI_LUT61_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT61_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT61_PAD0 field. */
#define BR_QuadSPI_LUT61_PAD0(x) (HW_QuadSPI_LUT61(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT61_PAD0. */
#define BF_QuadSPI_LUT61_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT61_PAD0) & BM_QuadSPI_LUT61_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT61_PAD0(x, v) (HW_QuadSPI_LUT61_WR(x, (HW_QuadSPI_LUT61_RD(x) & ~BM_QuadSPI_LUT61_PAD0) | BF_QuadSPI_LUT61_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT61, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT61_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT61_INSTR0. */
#define BM_QuadSPI_LUT61_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT61_INSTR0. */
#define BS_QuadSPI_LUT61_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT61_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT61_INSTR0 field. */
#define BR_QuadSPI_LUT61_INSTR0(x) (HW_QuadSPI_LUT61(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT61_INSTR0. */
#define BF_QuadSPI_LUT61_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT61_INSTR0) & BM_QuadSPI_LUT61_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT61_INSTR0(x, v) (HW_QuadSPI_LUT61_WR(x, (HW_QuadSPI_LUT61_RD(x) & ~BM_QuadSPI_LUT61_INSTR0) | BF_QuadSPI_LUT61_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT61, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT61_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT61_OPRND1. */
#define BM_QuadSPI_LUT61_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT61_OPRND1. */
#define BS_QuadSPI_LUT61_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT61_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT61_OPRND1 field. */
#define BR_QuadSPI_LUT61_OPRND1(x) (HW_QuadSPI_LUT61(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT61_OPRND1. */
#define BF_QuadSPI_LUT61_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT61_OPRND1) & BM_QuadSPI_LUT61_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT61_OPRND1(x, v) (HW_QuadSPI_LUT61_WR(x, (HW_QuadSPI_LUT61_RD(x) & ~BM_QuadSPI_LUT61_OPRND1) | BF_QuadSPI_LUT61_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT61, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT61_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT61_PAD1. */
#define BM_QuadSPI_LUT61_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT61_PAD1. */
#define BS_QuadSPI_LUT61_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT61_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT61_PAD1 field. */
#define BR_QuadSPI_LUT61_PAD1(x) (HW_QuadSPI_LUT61(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT61_PAD1. */
#define BF_QuadSPI_LUT61_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT61_PAD1) & BM_QuadSPI_LUT61_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT61_PAD1(x, v) (HW_QuadSPI_LUT61_WR(x, (HW_QuadSPI_LUT61_RD(x) & ~BM_QuadSPI_LUT61_PAD1) | BF_QuadSPI_LUT61_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT61, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT61_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT61_INSTR1. */
#define BM_QuadSPI_LUT61_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT61_INSTR1. */
#define BS_QuadSPI_LUT61_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT61_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT61_INSTR1 field. */
#define BR_QuadSPI_LUT61_INSTR1(x) (HW_QuadSPI_LUT61(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT61_INSTR1. */
#define BF_QuadSPI_LUT61_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT61_INSTR1) & BM_QuadSPI_LUT61_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT61_INSTR1(x, v) (HW_QuadSPI_LUT61_WR(x, (HW_QuadSPI_LUT61_RD(x) & ~BM_QuadSPI_LUT61_INSTR1) | BF_QuadSPI_LUT61_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT62 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT62 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut62
{
    uint32_t U;
    struct _hw_quadspi_lut62_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut62_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT62 register
 */
/*@{*/
#define HW_QuadSPI_LUT62_ADDR(x) ((uintptr_t)(x) + 0x408U)

#define HW_QuadSPI_LUT62(x)      (*(__IO hw_quadspi_lut62_t *) HW_QuadSPI_LUT62_ADDR(x))
#define HW_QuadSPI_LUT62_RD(x)   (HW_QuadSPI_LUT62(x).U)
#define HW_QuadSPI_LUT62_WR(x, v) (HW_QuadSPI_LUT62(x).U = (v))
#define HW_QuadSPI_LUT62_SET(x, v) (HW_QuadSPI_LUT62_WR(x, HW_QuadSPI_LUT62_RD(x) |  (v)))
#define HW_QuadSPI_LUT62_CLR(x, v) (HW_QuadSPI_LUT62_WR(x, HW_QuadSPI_LUT62_RD(x) & ~(v)))
#define HW_QuadSPI_LUT62_TOG(x, v) (HW_QuadSPI_LUT62_WR(x, HW_QuadSPI_LUT62_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT62 bitfields
 */

/*!
 * @name Register QuadSPI_LUT62, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT62_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT62_OPRND0. */
#define BM_QuadSPI_LUT62_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT62_OPRND0. */
#define BS_QuadSPI_LUT62_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT62_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT62_OPRND0 field. */
#define BR_QuadSPI_LUT62_OPRND0(x) (HW_QuadSPI_LUT62(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT62_OPRND0. */
#define BF_QuadSPI_LUT62_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT62_OPRND0) & BM_QuadSPI_LUT62_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT62_OPRND0(x, v) (HW_QuadSPI_LUT62_WR(x, (HW_QuadSPI_LUT62_RD(x) & ~BM_QuadSPI_LUT62_OPRND0) | BF_QuadSPI_LUT62_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT62, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT62_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT62_PAD0. */
#define BM_QuadSPI_LUT62_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT62_PAD0. */
#define BS_QuadSPI_LUT62_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT62_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT62_PAD0 field. */
#define BR_QuadSPI_LUT62_PAD0(x) (HW_QuadSPI_LUT62(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT62_PAD0. */
#define BF_QuadSPI_LUT62_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT62_PAD0) & BM_QuadSPI_LUT62_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT62_PAD0(x, v) (HW_QuadSPI_LUT62_WR(x, (HW_QuadSPI_LUT62_RD(x) & ~BM_QuadSPI_LUT62_PAD0) | BF_QuadSPI_LUT62_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT62, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT62_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT62_INSTR0. */
#define BM_QuadSPI_LUT62_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT62_INSTR0. */
#define BS_QuadSPI_LUT62_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT62_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT62_INSTR0 field. */
#define BR_QuadSPI_LUT62_INSTR0(x) (HW_QuadSPI_LUT62(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT62_INSTR0. */
#define BF_QuadSPI_LUT62_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT62_INSTR0) & BM_QuadSPI_LUT62_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT62_INSTR0(x, v) (HW_QuadSPI_LUT62_WR(x, (HW_QuadSPI_LUT62_RD(x) & ~BM_QuadSPI_LUT62_INSTR0) | BF_QuadSPI_LUT62_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT62, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT62_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT62_OPRND1. */
#define BM_QuadSPI_LUT62_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT62_OPRND1. */
#define BS_QuadSPI_LUT62_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT62_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT62_OPRND1 field. */
#define BR_QuadSPI_LUT62_OPRND1(x) (HW_QuadSPI_LUT62(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT62_OPRND1. */
#define BF_QuadSPI_LUT62_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT62_OPRND1) & BM_QuadSPI_LUT62_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT62_OPRND1(x, v) (HW_QuadSPI_LUT62_WR(x, (HW_QuadSPI_LUT62_RD(x) & ~BM_QuadSPI_LUT62_OPRND1) | BF_QuadSPI_LUT62_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT62, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT62_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT62_PAD1. */
#define BM_QuadSPI_LUT62_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT62_PAD1. */
#define BS_QuadSPI_LUT62_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT62_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT62_PAD1 field. */
#define BR_QuadSPI_LUT62_PAD1(x) (HW_QuadSPI_LUT62(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT62_PAD1. */
#define BF_QuadSPI_LUT62_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT62_PAD1) & BM_QuadSPI_LUT62_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT62_PAD1(x, v) (HW_QuadSPI_LUT62_WR(x, (HW_QuadSPI_LUT62_RD(x) & ~BM_QuadSPI_LUT62_PAD1) | BF_QuadSPI_LUT62_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT62, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT62_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT62_INSTR1. */
#define BM_QuadSPI_LUT62_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT62_INSTR1. */
#define BS_QuadSPI_LUT62_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT62_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT62_INSTR1 field. */
#define BR_QuadSPI_LUT62_INSTR1(x) (HW_QuadSPI_LUT62(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT62_INSTR1. */
#define BF_QuadSPI_LUT62_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT62_INSTR1) & BM_QuadSPI_LUT62_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT62_INSTR1(x, v) (HW_QuadSPI_LUT62_WR(x, (HW_QuadSPI_LUT62_RD(x) & ~BM_QuadSPI_LUT62_INSTR1) | BF_QuadSPI_LUT62_INSTR1(v)))
/*@}*/
/*******************************************************************************
 * HW_QuadSPI_LUT63 - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QuadSPI_LUT63 - Look-up Table register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The LUT registers are a look-up-table for sequences of instructions. The
 * programmable sequence engine executes the instructions in these sequences to
 * generate a valid serial flash transaction. There are a total of 64 LUT registers.
 * These 64 registers are divided into groups of 4 registers that make a valid
 * sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60] are
 * the starting registers of a valid sequence. Each of these sets of 4 registers
 * can have a maximum of 8 instructions. A maximum of 16 sequences can be
 * defined at one time. Look-up Table describes the LUT registers in detail. Write:Once
 * the LUT is unlocked
 */
typedef union _hw_quadspi_lut63
{
    uint32_t U;
    struct _hw_quadspi_lut63_bitfields
    {
        uint32_t OPRND0 : 8;           /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2;             /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6;           /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8;           /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2;             /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6;           /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lut63_t;

/*!
 * @name Constants and macros for entire QuadSPI_LUT63 register
 */
/*@{*/
#define HW_QuadSPI_LUT63_ADDR(x) ((uintptr_t)(x) + 0x40CU)

#define HW_QuadSPI_LUT63(x)      (*(__IO hw_quadspi_lut63_t *) HW_QuadSPI_LUT63_ADDR(x))
#define HW_QuadSPI_LUT63_RD(x)   (HW_QuadSPI_LUT63(x).U)
#define HW_QuadSPI_LUT63_WR(x, v) (HW_QuadSPI_LUT63(x).U = (v))
#define HW_QuadSPI_LUT63_SET(x, v) (HW_QuadSPI_LUT63_WR(x, HW_QuadSPI_LUT63_RD(x) |  (v)))
#define HW_QuadSPI_LUT63_CLR(x, v) (HW_QuadSPI_LUT63_WR(x, HW_QuadSPI_LUT63_RD(x) & ~(v)))
#define HW_QuadSPI_LUT63_TOG(x, v) (HW_QuadSPI_LUT63_WR(x, HW_QuadSPI_LUT63_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QuadSPI_LUT63 bitfields
 */

/*!
 * @name Register QuadSPI_LUT63, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT63_OPRND0 (0U)       /*!< Bit position for QuadSPI_LUT63_OPRND0. */
#define BM_QuadSPI_LUT63_OPRND0 (0x000000FFU) /*!< Bit mask for QuadSPI_LUT63_OPRND0. */
#define BS_QuadSPI_LUT63_OPRND0 (8U)       /*!< Bit field size in bits for QuadSPI_LUT63_OPRND0. */

/*! @brief Read current value of the QuadSPI_LUT63_OPRND0 field. */
#define BR_QuadSPI_LUT63_OPRND0(x) (HW_QuadSPI_LUT63(x).B.OPRND0)

/*! @brief Format value for bitfield QuadSPI_LUT63_OPRND0. */
#define BF_QuadSPI_LUT63_OPRND0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT63_OPRND0) & BM_QuadSPI_LUT63_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QuadSPI_LUT63_OPRND0(x, v) (HW_QuadSPI_LUT63_WR(x, (HW_QuadSPI_LUT63_RD(x) & ~BM_QuadSPI_LUT63_OPRND0) | BF_QuadSPI_LUT63_OPRND0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT63, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT63_PAD0 (8U)         /*!< Bit position for QuadSPI_LUT63_PAD0. */
#define BM_QuadSPI_LUT63_PAD0 (0x00000300U) /*!< Bit mask for QuadSPI_LUT63_PAD0. */
#define BS_QuadSPI_LUT63_PAD0 (2U)         /*!< Bit field size in bits for QuadSPI_LUT63_PAD0. */

/*! @brief Read current value of the QuadSPI_LUT63_PAD0 field. */
#define BR_QuadSPI_LUT63_PAD0(x) (HW_QuadSPI_LUT63(x).B.PAD0)

/*! @brief Format value for bitfield QuadSPI_LUT63_PAD0. */
#define BF_QuadSPI_LUT63_PAD0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT63_PAD0) & BM_QuadSPI_LUT63_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QuadSPI_LUT63_PAD0(x, v) (HW_QuadSPI_LUT63_WR(x, (HW_QuadSPI_LUT63_RD(x) & ~BM_QuadSPI_LUT63_PAD0) | BF_QuadSPI_LUT63_PAD0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT63, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT63_INSTR0 (10U)      /*!< Bit position for QuadSPI_LUT63_INSTR0. */
#define BM_QuadSPI_LUT63_INSTR0 (0x0000FC00U) /*!< Bit mask for QuadSPI_LUT63_INSTR0. */
#define BS_QuadSPI_LUT63_INSTR0 (6U)       /*!< Bit field size in bits for QuadSPI_LUT63_INSTR0. */

/*! @brief Read current value of the QuadSPI_LUT63_INSTR0 field. */
#define BR_QuadSPI_LUT63_INSTR0(x) (HW_QuadSPI_LUT63(x).B.INSTR0)

/*! @brief Format value for bitfield QuadSPI_LUT63_INSTR0. */
#define BF_QuadSPI_LUT63_INSTR0(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT63_INSTR0) & BM_QuadSPI_LUT63_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QuadSPI_LUT63_INSTR0(x, v) (HW_QuadSPI_LUT63_WR(x, (HW_QuadSPI_LUT63_RD(x) & ~BM_QuadSPI_LUT63_INSTR0) | BF_QuadSPI_LUT63_INSTR0(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT63, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT63_OPRND1 (16U)      /*!< Bit position for QuadSPI_LUT63_OPRND1. */
#define BM_QuadSPI_LUT63_OPRND1 (0x00FF0000U) /*!< Bit mask for QuadSPI_LUT63_OPRND1. */
#define BS_QuadSPI_LUT63_OPRND1 (8U)       /*!< Bit field size in bits for QuadSPI_LUT63_OPRND1. */

/*! @brief Read current value of the QuadSPI_LUT63_OPRND1 field. */
#define BR_QuadSPI_LUT63_OPRND1(x) (HW_QuadSPI_LUT63(x).B.OPRND1)

/*! @brief Format value for bitfield QuadSPI_LUT63_OPRND1. */
#define BF_QuadSPI_LUT63_OPRND1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT63_OPRND1) & BM_QuadSPI_LUT63_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QuadSPI_LUT63_OPRND1(x, v) (HW_QuadSPI_LUT63_WR(x, (HW_QuadSPI_LUT63_RD(x) & ~BM_QuadSPI_LUT63_OPRND1) | BF_QuadSPI_LUT63_OPRND1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT63, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - NA
 */
/*@{*/
#define BP_QuadSPI_LUT63_PAD1 (24U)        /*!< Bit position for QuadSPI_LUT63_PAD1. */
#define BM_QuadSPI_LUT63_PAD1 (0x03000000U) /*!< Bit mask for QuadSPI_LUT63_PAD1. */
#define BS_QuadSPI_LUT63_PAD1 (2U)         /*!< Bit field size in bits for QuadSPI_LUT63_PAD1. */

/*! @brief Read current value of the QuadSPI_LUT63_PAD1 field. */
#define BR_QuadSPI_LUT63_PAD1(x) (HW_QuadSPI_LUT63(x).B.PAD1)

/*! @brief Format value for bitfield QuadSPI_LUT63_PAD1. */
#define BF_QuadSPI_LUT63_PAD1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT63_PAD1) & BM_QuadSPI_LUT63_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QuadSPI_LUT63_PAD1(x, v) (HW_QuadSPI_LUT63_WR(x, (HW_QuadSPI_LUT63_RD(x) & ~BM_QuadSPI_LUT63_PAD1) | BF_QuadSPI_LUT63_PAD1(v)))
/*@}*/

/*!
 * @name Register QuadSPI_LUT63, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QuadSPI_LUT63_INSTR1 (26U)      /*!< Bit position for QuadSPI_LUT63_INSTR1. */
#define BM_QuadSPI_LUT63_INSTR1 (0xFC000000U) /*!< Bit mask for QuadSPI_LUT63_INSTR1. */
#define BS_QuadSPI_LUT63_INSTR1 (6U)       /*!< Bit field size in bits for QuadSPI_LUT63_INSTR1. */

/*! @brief Read current value of the QuadSPI_LUT63_INSTR1 field. */
#define BR_QuadSPI_LUT63_INSTR1(x) (HW_QuadSPI_LUT63(x).B.INSTR1)

/*! @brief Format value for bitfield QuadSPI_LUT63_INSTR1. */
#define BF_QuadSPI_LUT63_INSTR1(v) ((uint32_t)((uint32_t)(v) << BP_QuadSPI_LUT63_INSTR1) & BM_QuadSPI_LUT63_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QuadSPI_LUT63_INSTR1(x, v) (HW_QuadSPI_LUT63_WR(x, (HW_QuadSPI_LUT63_RD(x) & ~BM_QuadSPI_LUT63_INSTR1) | BF_QuadSPI_LUT63_INSTR1(v)))
/*@}*/

/*******************************************************************************
 * hw_quadspi_t - module struct
 ******************************************************************************/
/*!
 * @brief All QuadSPI module registers.
 */
#pragma pack(1)
typedef struct _hw_quadspi
{
    __IO hw_quadspi_mcr_t MCR;             /*!< [0x0] Module Configuration Register */
    uint8_t _reserved0[4];
    __IO hw_quadspi_ipcr_t IPCR;           /*!< [0x8] IP Configuration Register */
    __IO hw_quadspi_flshcr_t FLSHCR;       /*!< [0xC] Flash Configuration Register */
    __IO hw_quadspi_buf0cr_t BUF0CR;       /*!< [0x10] Buffer0 Configuration Register */
    __IO hw_quadspi_buf1cr_t BUF1CR;       /*!< [0x14] Buffer1 Configuration Register */
    __IO hw_quadspi_buf2cr_t BUF2CR;       /*!< [0x18] Buffer2 Configuration Register */
    __IO hw_quadspi_buf3cr_t BUF3CR;       /*!< [0x1C] Buffer3 Configuration Register */
    __IO hw_quadspi_bfgencr_t BFGENCR;     /*!< [0x20] Buffer Generic Configuration Register */
    uint8_t _reserved1[12];
    __IO hw_quadspi_buf0ind_t BUF0IND;     /*!< [0x30] Buffer0 Top Index Register */
    __IO hw_quadspi_buf1ind_t BUF1IND;     /*!< [0x34] Buffer1 Top Index Register */
    __IO hw_quadspi_buf2ind_t BUF2IND;     /*!< [0x38] Buffer2 Top Index Register */
    uint8_t _reserved2[196];
    __IO hw_quadspi_sfar_t SFAR;           /*!< [0x100] Serial Flash Address Register */
    uint8_t _reserved3[4];
    __IO hw_quadspi_smpr_t SMPR;           /*!< [0x108] Sampling Register */
    __I hw_quadspi_rbsr_t RBSR;            /*!< [0x10C] RX Buffer Status Register */
    __IO hw_quadspi_rbct_t RBCT;           /*!< [0x110] RX Buffer Control Register */
    uint8_t _reserved4[60];
    __I hw_quadspi_tbsr_t TBSR;            /*!< [0x150] TX Buffer Status Register */
    __IO hw_quadspi_tbdr_t TBDR;           /*!< [0x154] TX Buffer Data Register */
    uint8_t _reserved5[4];
    __I hw_quadspi_sr_t SR;                /*!< [0x15C] Status Register */
    __IO hw_quadspi_fr_t FR;               /*!< [0x160] Flag Register */
    __IO hw_quadspi_rser_t RSER;           /*!< [0x164] Interrupt and DMA Request Select and Enable Register */
    __I hw_quadspi_spndst_t SPNDST;        /*!< [0x168] Sequence Suspend Status Register */
    __IO hw_quadspi_sptrclr_t SPTRCLR;     /*!< [0x16C] Sequence Pointer Clear Register */
    uint8_t _reserved6[16];
    __IO hw_quadspi_sfa1ad_t SFA1AD;       /*!< [0x180] Serial Flash A1 Top Address */
    __IO hw_quadspi_sfa2ad_t SFA2AD;       /*!< [0x184] Serial Flash A2 Top Address */
    __IO hw_quadspi_sfb1ad_t SFB1AD;       /*!< [0x188] Serial Flash B1Top Address */
    __IO hw_quadspi_sfb2ad_t SFB2AD;       /*!< [0x18C] Serial Flash B2Top Address */
    uint8_t _reserved7[112];
    __IO hw_quadspi_rbdrn_t RBDRn[32];     /*!< [0x200] RX Buffer Data Register */
    uint8_t _reserved8[128];
    __IO hw_quadspi_lutkey_t LUTKEY;       /*!< [0x300] LUT Key Register */
    __IO hw_quadspi_lckcr_t LCKCR;         /*!< [0x304] LUT Lock Configuration Register */
    uint8_t _reserved9[8];
    __IO hw_quadspi_lut0_t LUT0;           /*!< [0x310] Look-up Table register */
    __IO hw_quadspi_lut1_t LUT1;           /*!< [0x314] Look-up Table register */
    __IO hw_quadspi_lut2_t LUT2;           /*!< [0x318] Look-up Table register */
    __IO hw_quadspi_lut3_t LUT3;           /*!< [0x31C] Look-up Table register */
    __IO hw_quadspi_lut4_t LUT4;           /*!< [0x320] Look-up Table register */
    __IO hw_quadspi_lut5_t LUT5;           /*!< [0x324] Look-up Table register */
    __IO hw_quadspi_lut6_t LUT6;           /*!< [0x328] Look-up Table register */
    __IO hw_quadspi_lut7_t LUT7;           /*!< [0x32C] Look-up Table register */
    __IO hw_quadspi_lut8_t LUT8;           /*!< [0x330] Look-up Table register */
    __IO hw_quadspi_lut9_t LUT9;           /*!< [0x334] Look-up Table register */
    __IO hw_quadspi_lut10_t LUT10;         /*!< [0x338] Look-up Table register */
    __IO hw_quadspi_lut11_t LUT11;         /*!< [0x33C] Look-up Table register */
    __IO hw_quadspi_lut12_t LUT12;         /*!< [0x340] Look-up Table register */
    __IO hw_quadspi_lut13_t LUT13;         /*!< [0x344] Look-up Table register */
    __IO hw_quadspi_lut14_t LUT14;         /*!< [0x348] Look-up Table register */
    __IO hw_quadspi_lut15_t LUT15;         /*!< [0x34C] Look-up Table register */
    __IO hw_quadspi_lut16_t LUT16;         /*!< [0x350] Look-up Table register */
    __IO hw_quadspi_lut17_t LUT17;         /*!< [0x354] Look-up Table register */
    __IO hw_quadspi_lut18_t LUT18;         /*!< [0x358] Look-up Table register */
    __IO hw_quadspi_lut19_t LUT19;         /*!< [0x35C] Look-up Table register */
    __IO hw_quadspi_lut20_t LUT20;         /*!< [0x360] Look-up Table register */
    __IO hw_quadspi_lut21_t LUT21;         /*!< [0x364] Look-up Table register */
    __IO hw_quadspi_lut22_t LUT22;         /*!< [0x368] Look-up Table register */
    __IO hw_quadspi_lut23_t LUT23;         /*!< [0x36C] Look-up Table register */
    __IO hw_quadspi_lut24_t LUT24;         /*!< [0x370] Look-up Table register */
    __IO hw_quadspi_lut25_t LUT25;         /*!< [0x374] Look-up Table register */
    __IO hw_quadspi_lut26_t LUT26;         /*!< [0x378] Look-up Table register */
    __IO hw_quadspi_lut27_t LUT27;         /*!< [0x37C] Look-up Table register */
    __IO hw_quadspi_lut28_t LUT28;         /*!< [0x380] Look-up Table register */
    __IO hw_quadspi_lut29_t LUT29;         /*!< [0x384] Look-up Table register */
    __IO hw_quadspi_lut30_t LUT30;         /*!< [0x388] Look-up Table register */
    __IO hw_quadspi_lut31_t LUT31;         /*!< [0x38C] Look-up Table register */
    __IO hw_quadspi_lut32_t LUT32;         /*!< [0x390] Look-up Table register */
    __IO hw_quadspi_lut33_t LUT33;         /*!< [0x394] Look-up Table register */
    __IO hw_quadspi_lut34_t LUT34;         /*!< [0x398] Look-up Table register */
    __IO hw_quadspi_lut35_t LUT35;         /*!< [0x39C] Look-up Table register */
    __IO hw_quadspi_lut36_t LUT36;         /*!< [0x3A0] Look-up Table register */
    __IO hw_quadspi_lut37_t LUT37;         /*!< [0x3A4] Look-up Table register */
    __IO hw_quadspi_lut38_t LUT38;         /*!< [0x3A8] Look-up Table register */
    __IO hw_quadspi_lut39_t LUT39;         /*!< [0x3AC] Look-up Table register */
    __IO hw_quadspi_lut40_t LUT40;         /*!< [0x3B0] Look-up Table register */
    __IO hw_quadspi_lut41_t LUT41;         /*!< [0x3B4] Look-up Table register */
    __IO hw_quadspi_lut42_t LUT42;         /*!< [0x3B8] Look-up Table register */
    __IO hw_quadspi_lut43_t LUT43;         /*!< [0x3BC] Look-up Table register */
    __IO hw_quadspi_lut44_t LUT44;         /*!< [0x3C0] Look-up Table register */
    __IO hw_quadspi_lut45_t LUT45;         /*!< [0x3C4] Look-up Table register */
    __IO hw_quadspi_lut46_t LUT46;         /*!< [0x3C8] Look-up Table register */
    __IO hw_quadspi_lut47_t LUT47;         /*!< [0x3CC] Look-up Table register */
    __IO hw_quadspi_lut48_t LUT48;         /*!< [0x3D0] Look-up Table register */
    __IO hw_quadspi_lut49_t LUT49;         /*!< [0x3D4] Look-up Table register */
    __IO hw_quadspi_lut50_t LUT50;         /*!< [0x3D8] Look-up Table register */
    __IO hw_quadspi_lut51_t LUT51;         /*!< [0x3DC] Look-up Table register */
    __IO hw_quadspi_lut52_t LUT52;         /*!< [0x3E0] Look-up Table register */
    __IO hw_quadspi_lut53_t LUT53;         /*!< [0x3E4] Look-up Table register */
    __IO hw_quadspi_lut54_t LUT54;         /*!< [0x3E8] Look-up Table register */
    __IO hw_quadspi_lut55_t LUT55;         /*!< [0x3EC] Look-up Table register */
    __IO hw_quadspi_lut56_t LUT56;         /*!< [0x3F0] Look-up Table register */
    __IO hw_quadspi_lut57_t LUT57;         /*!< [0x3F4] Look-up Table register */
    __IO hw_quadspi_lut58_t LUT58;         /*!< [0x3F8] Look-up Table register */
    __IO hw_quadspi_lut59_t LUT59;         /*!< [0x3FC] Look-up Table register */
    __IO hw_quadspi_lut60_t LUT60;         /*!< [0x400] Look-up Table register */
    __IO hw_quadspi_lut61_t LUT61;         /*!< [0x404] Look-up Table register */
    __IO hw_quadspi_lut62_t LUT62;         /*!< [0x408] Look-up Table register */
    __IO hw_quadspi_lut63_t LUT63;         /*!< [0x40C] Look-up Table register */
} hw_quadspi_t;
#pragma pack()

/*! @brief Macro to access all QuadSPI registers. */
/*! @param x QuadSPI module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_QuadSPI_REGS(QuadSPI1_BASE)</code>. */
#define HW_QuadSPI_REGS(x) (*(hw_quadspi_t *)(x))

/*
 * iMX7D RDC
 *
 * RDC
 *
 * Registers defined in this header file:
 * - HW_RDC_VIR - Version Information
 * - HW_RDC_STAT - Status
 * - HW_RDC_INTCTRL - Interrupt and Control
 * - HW_RDC_INTSTAT - Interrupt Status
 * - HW_RDC_MDAn - Master Domain Assignment
 * - HW_RDC_PDAPn - Peripheral Domain Access Permissions
 * - HW_RDC_MRSAn - Memory Region Start Address
 * - HW_RDC_MREAn - Memory Region End Address
 * - HW_RDC_MRCn - Memory Region Control
 * - HW_RDC_MRVSn - Memory Region Violation Status
 *
 * - hw_rdc_t - Struct containing all module registers.
 */

#define HW_RDC_INSTANCE_COUNT (1U) /*!< Number of instances of the RDC module. */
#define HW_RDC (0U) /*!< Instance number for RDC. */
#define RDC_BASE              (0x303D0000U) /*!< Base address for RDC. */
/*! Array initializer of RDC base addresses. */
#define RDC_BASE_ADDRS        { RDC_BASE }

/*******************************************************************************
 * HW_RDC_VIR - Version Information
 ******************************************************************************/

/*!
 * @brief HW_RDC_VIR - Version Information (RO)
 *
 * Reset value: 0x0376E204U
 *
 * The VIR provides version information including the number of domains, number
 * of master slots, number of peripheral slots, and number of memory regions.
 */
typedef union _hw_rdc_vir
{
    uint32_t U;
    struct _hw_rdc_vir_bitfields
    {
        uint32_t NDID : 4;             /*!< [3:0] Number of Domains */
        uint32_t NMSTR : 8;            /*!< [11:4] Number of Masters */
        uint32_t NPER : 8;             /*!< [19:12] Number of Peripherals */
        uint32_t NRGN : 8;             /*!< [27:20] Number of Memory Regions */
        uint32_t RESERVED0 : 4;        /*!< [31:28]  */
    } B;
} hw_rdc_vir_t;

/*!
 * @name Constants and macros for entire RDC_VIR register
 */
/*@{*/
#define HW_RDC_VIR_ADDR(x)       ((uintptr_t)(x) + 0x0U)

#define HW_RDC_VIR(x)            (*(__I hw_rdc_vir_t *) HW_RDC_VIR_ADDR(x))
#define HW_RDC_VIR_RD(x)         (HW_RDC_VIR(x).U)
/*@}*/

/*
 * Constants & macros for individual RDC_VIR bitfields
 */

/*!
 * @name Register RDC_VIR, field NDID[3:0] (RO)
 *
 * Indicates the number of domain ids supported by this instance of the RDC. Add
 * one to the register value to get the actual number of domains.
 */
/*@{*/
#define BP_RDC_VIR_NDID      (0U)          /*!< Bit position for RDC_VIR_NDID. */
#define BM_RDC_VIR_NDID      (0x0000000FU) /*!< Bit mask for RDC_VIR_NDID. */
#define BS_RDC_VIR_NDID      (4U)          /*!< Bit field size in bits for RDC_VIR_NDID. */

/*! @brief Read current value of the RDC_VIR_NDID field. */
#define BR_RDC_VIR_NDID(x)   (HW_RDC_VIR(x).B.NDID)
/*@}*/

/*!
 * @name Register RDC_VIR, field NMSTR[11:4] (RO)
 *
 * Indicates the number of masters supported by this instance of RDC.
 */
/*@{*/
#define BP_RDC_VIR_NMSTR     (4U)          /*!< Bit position for RDC_VIR_NMSTR. */
#define BM_RDC_VIR_NMSTR     (0x00000FF0U) /*!< Bit mask for RDC_VIR_NMSTR. */
#define BS_RDC_VIR_NMSTR     (8U)          /*!< Bit field size in bits for RDC_VIR_NMSTR. */

/*! @brief Read current value of the RDC_VIR_NMSTR field. */
#define BR_RDC_VIR_NMSTR(x)  (HW_RDC_VIR(x).B.NMSTR)
/*@}*/

/*!
 * @name Register RDC_VIR, field NPER[19:12] (RO)
 *
 * Indicates the number of peripherals that can be isolated or safe-shared
 */
/*@{*/
#define BP_RDC_VIR_NPER      (12U)         /*!< Bit position for RDC_VIR_NPER. */
#define BM_RDC_VIR_NPER      (0x000FF000U) /*!< Bit mask for RDC_VIR_NPER. */
#define BS_RDC_VIR_NPER      (8U)          /*!< Bit field size in bits for RDC_VIR_NPER. */

/*! @brief Read current value of the RDC_VIR_NPER field. */
#define BR_RDC_VIR_NPER(x)   (HW_RDC_VIR(x).B.NPER)
/*@}*/

/*!
 * @name Register RDC_VIR, field NRGN[27:20] (RO)
 *
 * Indicates the number of memory regions in this instance of the RDC.
 */
/*@{*/
#define BP_RDC_VIR_NRGN      (20U)         /*!< Bit position for RDC_VIR_NRGN. */
#define BM_RDC_VIR_NRGN      (0x0FF00000U) /*!< Bit mask for RDC_VIR_NRGN. */
#define BS_RDC_VIR_NRGN      (8U)          /*!< Bit field size in bits for RDC_VIR_NRGN. */

/*! @brief Read current value of the RDC_VIR_NRGN field. */
#define BR_RDC_VIR_NRGN(x)   (HW_RDC_VIR(x).B.NRGN)
/*@}*/

/*******************************************************************************
 * HW_RDC_STAT - Status
 ******************************************************************************/

/*!
 * @brief HW_RDC_STAT - Status (RW)
 *
 * Reset value: 0x00000100U
 */
typedef union _hw_rdc_stat
{
    uint32_t U;
    struct _hw_rdc_stat_bitfields
    {
        uint32_t DID : 4;              /*!< [3:0] Domain ID */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t PDS : 1;              /*!< [8] Power Domain Status */
        uint32_t RESERVED1 : 23;       /*!< [31:9]  */
    } B;
} hw_rdc_stat_t;

/*!
 * @name Constants and macros for entire RDC_STAT register
 */
/*@{*/
#define HW_RDC_STAT_ADDR(x)      ((uintptr_t)(x) + 0x24U)

#define HW_RDC_STAT(x)           (*(__IO hw_rdc_stat_t *) HW_RDC_STAT_ADDR(x))
#define HW_RDC_STAT_RD(x)        (HW_RDC_STAT(x).U)
#define HW_RDC_STAT_WR(x, v)     (HW_RDC_STAT(x).U = (v))
#define HW_RDC_STAT_SET(x, v)    (HW_RDC_STAT_WR(x, HW_RDC_STAT_RD(x) |  (v)))
#define HW_RDC_STAT_CLR(x, v)    (HW_RDC_STAT_WR(x, HW_RDC_STAT_RD(x) & ~(v)))
#define HW_RDC_STAT_TOG(x, v)    (HW_RDC_STAT_WR(x, HW_RDC_STAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_STAT bitfields
 */

/*!
 * @name Register RDC_STAT, field DID[3:0] (RW)
 *
 * The Domain ID of the core or bus master that is reading this. The value is
 * different for requests from different domains.
 */
/*@{*/
#define BP_RDC_STAT_DID      (0U)          /*!< Bit position for RDC_STAT_DID. */
#define BM_RDC_STAT_DID      (0x0000000FU) /*!< Bit mask for RDC_STAT_DID. */
#define BS_RDC_STAT_DID      (4U)          /*!< Bit field size in bits for RDC_STAT_DID. */

/*! @brief Read current value of the RDC_STAT_DID field. */
#define BR_RDC_STAT_DID(x)   (HW_RDC_STAT(x).B.DID)

/*! @brief Format value for bitfield RDC_STAT_DID. */
#define BF_RDC_STAT_DID(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_STAT_DID) & BM_RDC_STAT_DID)

/*! @brief Set the DID field to a new value. */
#define BW_RDC_STAT_DID(x, v) (HW_RDC_STAT_WR(x, (HW_RDC_STAT_RD(x) & ~BM_RDC_STAT_DID) | BF_RDC_STAT_DID(v)))
/*@}*/

/*!
 * @name Register RDC_STAT, field PDS[8] (RW)
 *
 * Indicates if the "Power Down" memory regions are powered and available. Power
 * Down memory regions are only those memory regions susceptible to power outage
 * for power savings are unavailable if this is zero. "Always-On" memory regions
 * remain available. Always On memory regions are those regions that are not
 * powered down unless the entire SoC is powered down. This signal remains low until
 * all access controls have been restored to the domain.
 *
 * Values:
 * - 0 - Power Down Domain is OFF
 * - 1 - Power Down Domain is ON
 */
/*@{*/
#define BP_RDC_STAT_PDS      (8U)          /*!< Bit position for RDC_STAT_PDS. */
#define BM_RDC_STAT_PDS      (0x00000100U) /*!< Bit mask for RDC_STAT_PDS. */
#define BS_RDC_STAT_PDS      (1U)          /*!< Bit field size in bits for RDC_STAT_PDS. */

/*! @brief Read current value of the RDC_STAT_PDS field. */
#define BR_RDC_STAT_PDS(x)   (HW_RDC_STAT(x).B.PDS)

/*! @brief Format value for bitfield RDC_STAT_PDS. */
#define BF_RDC_STAT_PDS(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_STAT_PDS) & BM_RDC_STAT_PDS)

/*! @brief Set the PDS field to a new value. */
#define BW_RDC_STAT_PDS(x, v) (HW_RDC_STAT_WR(x, (HW_RDC_STAT_RD(x) & ~BM_RDC_STAT_PDS) | BF_RDC_STAT_PDS(v)))
/*@}*/

/*******************************************************************************
 * HW_RDC_INTCTRL - Interrupt and Control
 ******************************************************************************/

/*!
 * @brief HW_RDC_INTCTRL - Interrupt and Control (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_rdc_intctrl
{
    uint32_t U;
    struct _hw_rdc_intctrl_bitfields
    {
        uint32_t RCI_EN : 1;           /*!< [0] Restoration Complete Interrupt */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_rdc_intctrl_t;

/*!
 * @name Constants and macros for entire RDC_INTCTRL register
 */
/*@{*/
#define HW_RDC_INTCTRL_ADDR(x)   ((uintptr_t)(x) + 0x28U)

#define HW_RDC_INTCTRL(x)        (*(__IO hw_rdc_intctrl_t *) HW_RDC_INTCTRL_ADDR(x))
#define HW_RDC_INTCTRL_RD(x)     (HW_RDC_INTCTRL(x).U)
#define HW_RDC_INTCTRL_WR(x, v)  (HW_RDC_INTCTRL(x).U = (v))
#define HW_RDC_INTCTRL_SET(x, v) (HW_RDC_INTCTRL_WR(x, HW_RDC_INTCTRL_RD(x) |  (v)))
#define HW_RDC_INTCTRL_CLR(x, v) (HW_RDC_INTCTRL_WR(x, HW_RDC_INTCTRL_RD(x) & ~(v)))
#define HW_RDC_INTCTRL_TOG(x, v) (HW_RDC_INTCTRL_WR(x, HW_RDC_INTCTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_INTCTRL bitfields
 */

/*!
 * @name Register RDC_INTCTRL, field RCI_EN[0] (RW)
 *
 * Interrupt generated when the RDC has completed restoring state to a recently
 * re-powered memory regions.
 *
 * Values:
 * - 0 - Interrupt Disabled
 * - 1 - Interrupt Enabled
 */
/*@{*/
#define BP_RDC_INTCTRL_RCI_EN (0U)         /*!< Bit position for RDC_INTCTRL_RCI_EN. */
#define BM_RDC_INTCTRL_RCI_EN (0x00000001U) /*!< Bit mask for RDC_INTCTRL_RCI_EN. */
#define BS_RDC_INTCTRL_RCI_EN (1U)         /*!< Bit field size in bits for RDC_INTCTRL_RCI_EN. */

/*! @brief Read current value of the RDC_INTCTRL_RCI_EN field. */
#define BR_RDC_INTCTRL_RCI_EN(x) (HW_RDC_INTCTRL(x).B.RCI_EN)

/*! @brief Format value for bitfield RDC_INTCTRL_RCI_EN. */
#define BF_RDC_INTCTRL_RCI_EN(v) ((uint32_t)((uint32_t)(v) << BP_RDC_INTCTRL_RCI_EN) & BM_RDC_INTCTRL_RCI_EN)

/*! @brief Set the RCI_EN field to a new value. */
#define BW_RDC_INTCTRL_RCI_EN(x, v) (HW_RDC_INTCTRL_WR(x, (HW_RDC_INTCTRL_RD(x) & ~BM_RDC_INTCTRL_RCI_EN) | BF_RDC_INTCTRL_RCI_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_RDC_INTSTAT - Interrupt Status
 ******************************************************************************/

/*!
 * @brief HW_RDC_INTSTAT - Interrupt Status (RW)
 *
 * Reset value: 0x00000000U
 *
 * Indication of Interrupt Pending for State Restoration
 */
typedef union _hw_rdc_intstat
{
    uint32_t U;
    struct _hw_rdc_intstat_bitfields
    {
        uint32_t INT : 1;              /*!< [0] Interrupt Status */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_rdc_intstat_t;

/*!
 * @name Constants and macros for entire RDC_INTSTAT register
 */
/*@{*/
#define HW_RDC_INTSTAT_ADDR(x)   ((uintptr_t)(x) + 0x2CU)

#define HW_RDC_INTSTAT(x)        (*(__IO hw_rdc_intstat_t *) HW_RDC_INTSTAT_ADDR(x))
#define HW_RDC_INTSTAT_RD(x)     (HW_RDC_INTSTAT(x).U)
#define HW_RDC_INTSTAT_WR(x, v)  (HW_RDC_INTSTAT(x).U = (v))
#define HW_RDC_INTSTAT_SET(x, v) (HW_RDC_INTSTAT_WR(x, HW_RDC_INTSTAT_RD(x) |  (v)))
#define HW_RDC_INTSTAT_CLR(x, v) (HW_RDC_INTSTAT_WR(x, HW_RDC_INTSTAT_RD(x) & ~(v)))
#define HW_RDC_INTSTAT_TOG(x, v) (HW_RDC_INTSTAT_WR(x, HW_RDC_INTSTAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_INTSTAT bitfields
 */

/*!
 * @name Register RDC_INTSTAT, field INT[0] (W1C)
 *
 * Indicates state of interrupt signal for state restoration. This is that
 * status of the interrupt enabled in RDC_INTCTRL. Write one to interrupt status to
 * clear it.
 *
 * Values:
 * - 0 - No Interrupt Pending
 * - 1 - Interrupt Pending
 */
/*@{*/
#define BP_RDC_INTSTAT_INT   (0U)          /*!< Bit position for RDC_INTSTAT_INT. */
#define BM_RDC_INTSTAT_INT   (0x00000001U) /*!< Bit mask for RDC_INTSTAT_INT. */
#define BS_RDC_INTSTAT_INT   (1U)          /*!< Bit field size in bits for RDC_INTSTAT_INT. */

/*! @brief Read current value of the RDC_INTSTAT_INT field. */
#define BR_RDC_INTSTAT_INT(x) (HW_RDC_INTSTAT(x).B.INT)

/*! @brief Format value for bitfield RDC_INTSTAT_INT. */
#define BF_RDC_INTSTAT_INT(v) ((uint32_t)((uint32_t)(v) << BP_RDC_INTSTAT_INT) & BM_RDC_INTSTAT_INT)

/*! @brief Set the INT field to a new value. */
#define BW_RDC_INTSTAT_INT(x, v) (HW_RDC_INTSTAT_WR(x, (HW_RDC_INTSTAT_RD(x) & ~BM_RDC_INTSTAT_INT) | BF_RDC_INTSTAT_INT(v)))
/*@}*/

/*******************************************************************************
 * HW_RDC_MDAn - Master Domain Assignment
 ******************************************************************************/

/*!
 * @brief HW_RDC_MDAn - Master Domain Assignment (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_rdc_mdan
{
    uint32_t U;
    struct _hw_rdc_mdan_bitfields
    {
        uint32_t DID : 2;              /*!< [1:0] Domain ID */
        uint32_t RESERVED0 : 29;       /*!< [30:2]  */
        uint32_t LCK : 1;              /*!< [31]  */
    } B;
} hw_rdc_mdan_t;

/*!
 * @name Constants and macros for entire RDC_MDAn register
 */
/*@{*/
#define HW_RDC_MDAn_COUNT (27U)

#define HW_RDC_MDAn_ADDR(x, n)   ((uintptr_t)(x) + 0x200U + (0x4U * (n)))

#define HW_RDC_MDAn(x, n)        (*(__IO hw_rdc_mdan_t *) HW_RDC_MDAn_ADDR(x, n))
#define HW_RDC_MDAn_RD(x, n)     (HW_RDC_MDAn(x, n).U)
#define HW_RDC_MDAn_WR(x, n, v)  (HW_RDC_MDAn(x, n).U = (v))
#define HW_RDC_MDAn_SET(x, n, v) (HW_RDC_MDAn_WR(x, n, HW_RDC_MDAn_RD(x, n) |  (v)))
#define HW_RDC_MDAn_CLR(x, n, v) (HW_RDC_MDAn_WR(x, n, HW_RDC_MDAn_RD(x, n) & ~(v)))
#define HW_RDC_MDAn_TOG(x, n, v) (HW_RDC_MDAn_WR(x, n, HW_RDC_MDAn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_MDAn bitfields
 */

/*!
 * @name Register RDC_MDAn, field DID[1:0] (RW)
 *
 * Indicates the domain to which the Master is assigned
 *
 * Values:
 * - 00 - Master assigned to Processing Domain 0
 * - 01 - Master assigned to Processing Domain 1
 * - 10 - Master assigned to Processing Domain 2
 * - 11 - Master assigned to Processing Domain 3
 */
/*@{*/
#define BP_RDC_MDAn_DID      (0U)          /*!< Bit position for RDC_MDAn_DID. */
#define BM_RDC_MDAn_DID      (0x00000003U) /*!< Bit mask for RDC_MDAn_DID. */
#define BS_RDC_MDAn_DID      (2U)          /*!< Bit field size in bits for RDC_MDAn_DID. */

/*! @brief Read current value of the RDC_MDAn_DID field. */
#define BR_RDC_MDAn_DID(x, n) (HW_RDC_MDAn(x, n).B.DID)

/*! @brief Format value for bitfield RDC_MDAn_DID. */
#define BF_RDC_MDAn_DID(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MDAn_DID) & BM_RDC_MDAn_DID)

/*! @brief Set the DID field to a new value. */
#define BW_RDC_MDAn_DID(x, n, v) (HW_RDC_MDAn_WR(x, n, (HW_RDC_MDAn_RD(x, n) & ~BM_RDC_MDAn_DID) | BF_RDC_MDAn_DID(v)))
/*@}*/

/*!
 * @name Register RDC_MDAn, field LCK[31] (RW)
 *
 * Values:
 * - 0 - Not Locked
 * - 1 - Locked
 */
/*@{*/
#define BP_RDC_MDAn_LCK      (31U)         /*!< Bit position for RDC_MDAn_LCK. */
#define BM_RDC_MDAn_LCK      (0x80000000U) /*!< Bit mask for RDC_MDAn_LCK. */
#define BS_RDC_MDAn_LCK      (1U)          /*!< Bit field size in bits for RDC_MDAn_LCK. */

/*! @brief Read current value of the RDC_MDAn_LCK field. */
#define BR_RDC_MDAn_LCK(x, n) (HW_RDC_MDAn(x, n).B.LCK)

/*! @brief Format value for bitfield RDC_MDAn_LCK. */
#define BF_RDC_MDAn_LCK(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MDAn_LCK) & BM_RDC_MDAn_LCK)

/*! @brief Set the LCK field to a new value. */
#define BW_RDC_MDAn_LCK(x, n, v) (HW_RDC_MDAn_WR(x, n, (HW_RDC_MDAn_RD(x, n) & ~BM_RDC_MDAn_LCK) | BF_RDC_MDAn_LCK(v)))
/*@}*/

/*******************************************************************************
 * HW_RDC_PDAPn - Peripheral Domain Access Permissions
 ******************************************************************************/

/*!
 * @brief HW_RDC_PDAPn - Peripheral Domain Access Permissions (RW)
 *
 * Reset value: 0x000000FFU
 */
typedef union _hw_rdc_pdapn
{
    uint32_t U;
    struct _hw_rdc_pdapn_bitfields
    {
        uint32_t D0W : 1;              /*!< [0] Domain 0 Write Access */
        uint32_t D0R : 1;              /*!< [1] Domain 0 Read Access */
        uint32_t D1W : 1;              /*!< [2] Domain 1 Write Access */
        uint32_t D1R : 1;              /*!< [3] Domain 1 Read Access */
        uint32_t D2W : 1;              /*!< [4] Domain 2 Write Access */
        uint32_t D2R : 1;              /*!< [5] Domain 2 Read Access */
        uint32_t D3W : 1;              /*!< [6] Domain 3 Write Access */
        uint32_t D3R : 1;              /*!< [7] Domain 3 Read Access */
        uint32_t RESERVED0 : 22;       /*!< [29:8]  */
        uint32_t SREQ : 1;             /*!< [30] Semaphore Required */
        uint32_t LCK : 1;              /*!< [31] Peripheral Permissions Lock */
    } B;
} hw_rdc_pdapn_t;

/*!
 * @name Constants and macros for entire RDC_PDAPn register
 */
/*@{*/
#define HW_RDC_PDAPn_COUNT (118U)

#define HW_RDC_PDAPn_ADDR(x, n)  ((uintptr_t)(x) + 0x400U + (0x4U * (n)))

#define HW_RDC_PDAPn(x, n)       (*(__IO hw_rdc_pdapn_t *) HW_RDC_PDAPn_ADDR(x, n))
#define HW_RDC_PDAPn_RD(x, n)    (HW_RDC_PDAPn(x, n).U)
#define HW_RDC_PDAPn_WR(x, n, v) (HW_RDC_PDAPn(x, n).U = (v))
#define HW_RDC_PDAPn_SET(x, n, v) (HW_RDC_PDAPn_WR(x, n, HW_RDC_PDAPn_RD(x, n) |  (v)))
#define HW_RDC_PDAPn_CLR(x, n, v) (HW_RDC_PDAPn_WR(x, n, HW_RDC_PDAPn_RD(x, n) & ~(v)))
#define HW_RDC_PDAPn_TOG(x, n, v) (HW_RDC_PDAPn_WR(x, n, HW_RDC_PDAPn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_PDAPn bitfields
 */

/*!
 * @name Register RDC_PDAPn, field D0W[0] (RW)
 *
 * Values:
 * - 0 - No Write Access
 * - 1 - Write Access Allowed
 */
/*@{*/
#define BP_RDC_PDAPn_D0W     (0U)          /*!< Bit position for RDC_PDAPn_D0W. */
#define BM_RDC_PDAPn_D0W     (0x00000001U) /*!< Bit mask for RDC_PDAPn_D0W. */
#define BS_RDC_PDAPn_D0W     (1U)          /*!< Bit field size in bits for RDC_PDAPn_D0W. */

/*! @brief Read current value of the RDC_PDAPn_D0W field. */
#define BR_RDC_PDAPn_D0W(x, n) (HW_RDC_PDAPn(x, n).B.D0W)

/*! @brief Format value for bitfield RDC_PDAPn_D0W. */
#define BF_RDC_PDAPn_D0W(v)  ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_D0W) & BM_RDC_PDAPn_D0W)

/*! @brief Set the D0W field to a new value. */
#define BW_RDC_PDAPn_D0W(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_D0W) | BF_RDC_PDAPn_D0W(v)))
/*@}*/

/*!
 * @name Register RDC_PDAPn, field D0R[1] (RW)
 *
 * Values:
 * - 0 - No Read Access
 * - 1 - Read Access Allowed
 */
/*@{*/
#define BP_RDC_PDAPn_D0R     (1U)          /*!< Bit position for RDC_PDAPn_D0R. */
#define BM_RDC_PDAPn_D0R     (0x00000002U) /*!< Bit mask for RDC_PDAPn_D0R. */
#define BS_RDC_PDAPn_D0R     (1U)          /*!< Bit field size in bits for RDC_PDAPn_D0R. */

/*! @brief Read current value of the RDC_PDAPn_D0R field. */
#define BR_RDC_PDAPn_D0R(x, n) (HW_RDC_PDAPn(x, n).B.D0R)

/*! @brief Format value for bitfield RDC_PDAPn_D0R. */
#define BF_RDC_PDAPn_D0R(v)  ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_D0R) & BM_RDC_PDAPn_D0R)

/*! @brief Set the D0R field to a new value. */
#define BW_RDC_PDAPn_D0R(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_D0R) | BF_RDC_PDAPn_D0R(v)))
/*@}*/

/*!
 * @name Register RDC_PDAPn, field D1W[2] (RW)
 *
 * Values:
 * - 0 - No Write Access
 * - 1 - Write Access Allowed
 */
/*@{*/
#define BP_RDC_PDAPn_D1W     (2U)          /*!< Bit position for RDC_PDAPn_D1W. */
#define BM_RDC_PDAPn_D1W     (0x00000004U) /*!< Bit mask for RDC_PDAPn_D1W. */
#define BS_RDC_PDAPn_D1W     (1U)          /*!< Bit field size in bits for RDC_PDAPn_D1W. */

/*! @brief Read current value of the RDC_PDAPn_D1W field. */
#define BR_RDC_PDAPn_D1W(x, n) (HW_RDC_PDAPn(x, n).B.D1W)

/*! @brief Format value for bitfield RDC_PDAPn_D1W. */
#define BF_RDC_PDAPn_D1W(v)  ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_D1W) & BM_RDC_PDAPn_D1W)

/*! @brief Set the D1W field to a new value. */
#define BW_RDC_PDAPn_D1W(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_D1W) | BF_RDC_PDAPn_D1W(v)))
/*@}*/

/*!
 * @name Register RDC_PDAPn, field D1R[3] (RW)
 *
 * Values:
 * - 0 - No Read Access
 * - 1 - Read Access Allowed
 */
/*@{*/
#define BP_RDC_PDAPn_D1R     (3U)          /*!< Bit position for RDC_PDAPn_D1R. */
#define BM_RDC_PDAPn_D1R     (0x00000008U) /*!< Bit mask for RDC_PDAPn_D1R. */
#define BS_RDC_PDAPn_D1R     (1U)          /*!< Bit field size in bits for RDC_PDAPn_D1R. */

/*! @brief Read current value of the RDC_PDAPn_D1R field. */
#define BR_RDC_PDAPn_D1R(x, n) (HW_RDC_PDAPn(x, n).B.D1R)

/*! @brief Format value for bitfield RDC_PDAPn_D1R. */
#define BF_RDC_PDAPn_D1R(v)  ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_D1R) & BM_RDC_PDAPn_D1R)

/*! @brief Set the D1R field to a new value. */
#define BW_RDC_PDAPn_D1R(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_D1R) | BF_RDC_PDAPn_D1R(v)))
/*@}*/

/*!
 * @name Register RDC_PDAPn, field D2W[4] (RW)
 *
 * Values:
 * - 0 - No Write Access
 * - 1 - Write Access Allowed
 */
/*@{*/
#define BP_RDC_PDAPn_D2W     (4U)          /*!< Bit position for RDC_PDAPn_D2W. */
#define BM_RDC_PDAPn_D2W     (0x00000010U) /*!< Bit mask for RDC_PDAPn_D2W. */
#define BS_RDC_PDAPn_D2W     (1U)          /*!< Bit field size in bits for RDC_PDAPn_D2W. */

/*! @brief Read current value of the RDC_PDAPn_D2W field. */
#define BR_RDC_PDAPn_D2W(x, n) (HW_RDC_PDAPn(x, n).B.D2W)

/*! @brief Format value for bitfield RDC_PDAPn_D2W. */
#define BF_RDC_PDAPn_D2W(v)  ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_D2W) & BM_RDC_PDAPn_D2W)

/*! @brief Set the D2W field to a new value. */
#define BW_RDC_PDAPn_D2W(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_D2W) | BF_RDC_PDAPn_D2W(v)))
/*@}*/

/*!
 * @name Register RDC_PDAPn, field D2R[5] (RW)
 *
 * Values:
 * - 0 - No Read Access
 * - 1 - Read Access Allowed
 */
/*@{*/
#define BP_RDC_PDAPn_D2R     (5U)          /*!< Bit position for RDC_PDAPn_D2R. */
#define BM_RDC_PDAPn_D2R     (0x00000020U) /*!< Bit mask for RDC_PDAPn_D2R. */
#define BS_RDC_PDAPn_D2R     (1U)          /*!< Bit field size in bits for RDC_PDAPn_D2R. */

/*! @brief Read current value of the RDC_PDAPn_D2R field. */
#define BR_RDC_PDAPn_D2R(x, n) (HW_RDC_PDAPn(x, n).B.D2R)

/*! @brief Format value for bitfield RDC_PDAPn_D2R. */
#define BF_RDC_PDAPn_D2R(v)  ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_D2R) & BM_RDC_PDAPn_D2R)

/*! @brief Set the D2R field to a new value. */
#define BW_RDC_PDAPn_D2R(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_D2R) | BF_RDC_PDAPn_D2R(v)))
/*@}*/

/*!
 * @name Register RDC_PDAPn, field D3W[6] (RW)
 *
 * Values:
 * - 0 - No Write Access
 * - 1 - Write Access Allowed
 */
/*@{*/
#define BP_RDC_PDAPn_D3W     (6U)          /*!< Bit position for RDC_PDAPn_D3W. */
#define BM_RDC_PDAPn_D3W     (0x00000040U) /*!< Bit mask for RDC_PDAPn_D3W. */
#define BS_RDC_PDAPn_D3W     (1U)          /*!< Bit field size in bits for RDC_PDAPn_D3W. */

/*! @brief Read current value of the RDC_PDAPn_D3W field. */
#define BR_RDC_PDAPn_D3W(x, n) (HW_RDC_PDAPn(x, n).B.D3W)

/*! @brief Format value for bitfield RDC_PDAPn_D3W. */
#define BF_RDC_PDAPn_D3W(v)  ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_D3W) & BM_RDC_PDAPn_D3W)

/*! @brief Set the D3W field to a new value. */
#define BW_RDC_PDAPn_D3W(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_D3W) | BF_RDC_PDAPn_D3W(v)))
/*@}*/

/*!
 * @name Register RDC_PDAPn, field D3R[7] (RW)
 *
 * Values:
 * - 0 - No Read Access
 * - 1 - Read Access Allowed
 */
/*@{*/
#define BP_RDC_PDAPn_D3R     (7U)          /*!< Bit position for RDC_PDAPn_D3R. */
#define BM_RDC_PDAPn_D3R     (0x00000080U) /*!< Bit mask for RDC_PDAPn_D3R. */
#define BS_RDC_PDAPn_D3R     (1U)          /*!< Bit field size in bits for RDC_PDAPn_D3R. */

/*! @brief Read current value of the RDC_PDAPn_D3R field. */
#define BR_RDC_PDAPn_D3R(x, n) (HW_RDC_PDAPn(x, n).B.D3R)

/*! @brief Format value for bitfield RDC_PDAPn_D3R. */
#define BF_RDC_PDAPn_D3R(v)  ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_D3R) & BM_RDC_PDAPn_D3R)

/*! @brief Set the D3R field to a new value. */
#define BW_RDC_PDAPn_D3R(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_D3R) | BF_RDC_PDAPn_D3R(v)))
/*@}*/

/*!
 * @name Register RDC_PDAPn, field SREQ[30] (RW)
 *
 * When set the hardware semaphore state enforces the semaphore lock. If a
 * domain has access permissions and a semaphore has locked a shared peripheral then
 * only the domain holding the semaphore signal can access this peripheral.
 *
 * Values:
 * - 0 - Semaphores have no effect
 * - 1 - Semaphores are enforced
 */
/*@{*/
#define BP_RDC_PDAPn_SREQ    (30U)         /*!< Bit position for RDC_PDAPn_SREQ. */
#define BM_RDC_PDAPn_SREQ    (0x40000000U) /*!< Bit mask for RDC_PDAPn_SREQ. */
#define BS_RDC_PDAPn_SREQ    (1U)          /*!< Bit field size in bits for RDC_PDAPn_SREQ. */

/*! @brief Read current value of the RDC_PDAPn_SREQ field. */
#define BR_RDC_PDAPn_SREQ(x, n) (HW_RDC_PDAPn(x, n).B.SREQ)

/*! @brief Format value for bitfield RDC_PDAPn_SREQ. */
#define BF_RDC_PDAPn_SREQ(v) ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_SREQ) & BM_RDC_PDAPn_SREQ)

/*! @brief Set the SREQ field to a new value. */
#define BW_RDC_PDAPn_SREQ(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_SREQ) | BF_RDC_PDAPn_SREQ(v)))
/*@}*/

/*!
 * @name Register RDC_PDAPn, field LCK[31] (RW)
 *
 * When set prevents further modification of the Peripheral Domain Access
 * Permissions (sticky bit until reset)
 *
 * Values:
 * - 0 - Not Locked
 * - 1 - Locked
 */
/*@{*/
#define BP_RDC_PDAPn_LCK     (31U)         /*!< Bit position for RDC_PDAPn_LCK. */
#define BM_RDC_PDAPn_LCK     (0x80000000U) /*!< Bit mask for RDC_PDAPn_LCK. */
#define BS_RDC_PDAPn_LCK     (1U)          /*!< Bit field size in bits for RDC_PDAPn_LCK. */

/*! @brief Read current value of the RDC_PDAPn_LCK field. */
#define BR_RDC_PDAPn_LCK(x, n) (HW_RDC_PDAPn(x, n).B.LCK)

/*! @brief Format value for bitfield RDC_PDAPn_LCK. */
#define BF_RDC_PDAPn_LCK(v)  ((uint32_t)((uint32_t)(v) << BP_RDC_PDAPn_LCK) & BM_RDC_PDAPn_LCK)

/*! @brief Set the LCK field to a new value. */
#define BW_RDC_PDAPn_LCK(x, n, v) (HW_RDC_PDAPn_WR(x, n, (HW_RDC_PDAPn_RD(x, n) & ~BM_RDC_PDAPn_LCK) | BF_RDC_PDAPn_LCK(v)))
/*@}*/

/*******************************************************************************
 * HW_RDC_MRSAn - Memory Region Start Address
 ******************************************************************************/

/*!
 * @brief HW_RDC_MRSAn - Memory Region Start Address (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_rdc_mrsan
{
    uint32_t U;
    struct _hw_rdc_mrsan_bitfields
    {
        uint32_t RESERVED0 : 7;        /*!< [6:0]  */
        uint32_t SADR : 25;            /*!< [31:7] Start address for memory region */
    } B;
} hw_rdc_mrsan_t;

/*!
 * @name Constants and macros for entire RDC_MRSAn register
 */
/*@{*/
#define HW_RDC_MRSAn_COUNT (52U)

#define HW_RDC_MRSAn_ADDR(x, n)  ((uintptr_t)(x) + 0x800U + (0x10U * (n)))

#define HW_RDC_MRSAn(x, n)       (*(__IO hw_rdc_mrsan_t *) HW_RDC_MRSAn_ADDR(x, n))
#define HW_RDC_MRSAn_RD(x, n)    (HW_RDC_MRSAn(x, n).U)
#define HW_RDC_MRSAn_WR(x, n, v) (HW_RDC_MRSAn(x, n).U = (v))
#define HW_RDC_MRSAn_SET(x, n, v) (HW_RDC_MRSAn_WR(x, n, HW_RDC_MRSAn_RD(x, n) |  (v)))
#define HW_RDC_MRSAn_CLR(x, n, v) (HW_RDC_MRSAn_WR(x, n, HW_RDC_MRSAn_RD(x, n) & ~(v)))
#define HW_RDC_MRSAn_TOG(x, n, v) (HW_RDC_MRSAn_WR(x, n, HW_RDC_MRSAn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_MRSAn bitfields
 */

/*!
 * @name Register RDC_MRSAn, field SADR[31:7] (RW)
 *
 * Lower bound (inclusive) modulo the defined granularity byte size of a region.
 * The region size (granularity) is defined for each Memory/Port in the Memory
 * Region Map section. Region boundaries are aligned to the minimum possible
 * region size for the Memory/Port.
 */
/*@{*/
#define BP_RDC_MRSAn_SADR    (7U)          /*!< Bit position for RDC_MRSAn_SADR. */
#define BM_RDC_MRSAn_SADR    (0xFFFFFF80U) /*!< Bit mask for RDC_MRSAn_SADR. */
#define BS_RDC_MRSAn_SADR    (25U)         /*!< Bit field size in bits for RDC_MRSAn_SADR. */

/*! @brief Read current value of the RDC_MRSAn_SADR field. */
#define BR_RDC_MRSAn_SADR(x, n) (HW_RDC_MRSAn(x, n).B.SADR)

/*! @brief Format value for bitfield RDC_MRSAn_SADR. */
#define BF_RDC_MRSAn_SADR(v) ((uint32_t)((uint32_t)(v) << BP_RDC_MRSAn_SADR) & BM_RDC_MRSAn_SADR)

/*! @brief Set the SADR field to a new value. */
#define BW_RDC_MRSAn_SADR(x, n, v) (HW_RDC_MRSAn_WR(x, n, (HW_RDC_MRSAn_RD(x, n) & ~BM_RDC_MRSAn_SADR) | BF_RDC_MRSAn_SADR(v)))
/*@}*/
/*******************************************************************************
 * HW_RDC_MREAn - Memory Region End Address
 ******************************************************************************/

/*!
 * @brief HW_RDC_MREAn - Memory Region End Address (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_rdc_mrean
{
    uint32_t U;
    struct _hw_rdc_mrean_bitfields
    {
        uint32_t RESERVED0 : 7;        /*!< [6:0]  */
        uint32_t EADR : 25;            /*!< [31:7] Upper bound for memory region */
    } B;
} hw_rdc_mrean_t;

/*!
 * @name Constants and macros for entire RDC_MREAn register
 */
/*@{*/
#define HW_RDC_MREAn_COUNT (52U)

#define HW_RDC_MREAn_ADDR(x, n)  ((uintptr_t)(x) + 0x804U + (0x10U * (n)))

#define HW_RDC_MREAn(x, n)       (*(__IO hw_rdc_mrean_t *) HW_RDC_MREAn_ADDR(x, n))
#define HW_RDC_MREAn_RD(x, n)    (HW_RDC_MREAn(x, n).U)
#define HW_RDC_MREAn_WR(x, n, v) (HW_RDC_MREAn(x, n).U = (v))
#define HW_RDC_MREAn_SET(x, n, v) (HW_RDC_MREAn_WR(x, n, HW_RDC_MREAn_RD(x, n) |  (v)))
#define HW_RDC_MREAn_CLR(x, n, v) (HW_RDC_MREAn_WR(x, n, HW_RDC_MREAn_RD(x, n) & ~(v)))
#define HW_RDC_MREAn_TOG(x, n, v) (HW_RDC_MREAn_WR(x, n, HW_RDC_MREAn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_MREAn bitfields
 */

/*!
 * @name Register RDC_MREAn, field EADR[31:7] (RW)
 *
 * Upper bound (exclusive) modulo the defined granularity byte size of a region.
 * The region size (granularity) is defined for each Memory/Port in the Memory
 * Region Map section. Region boundaries are aligned to the minimum possible
 * region size for the Memory/Port.
 */
/*@{*/
#define BP_RDC_MREAn_EADR    (7U)          /*!< Bit position for RDC_MREAn_EADR. */
#define BM_RDC_MREAn_EADR    (0xFFFFFF80U) /*!< Bit mask for RDC_MREAn_EADR. */
#define BS_RDC_MREAn_EADR    (25U)         /*!< Bit field size in bits for RDC_MREAn_EADR. */

/*! @brief Read current value of the RDC_MREAn_EADR field. */
#define BR_RDC_MREAn_EADR(x, n) (HW_RDC_MREAn(x, n).B.EADR)

/*! @brief Format value for bitfield RDC_MREAn_EADR. */
#define BF_RDC_MREAn_EADR(v) ((uint32_t)((uint32_t)(v) << BP_RDC_MREAn_EADR) & BM_RDC_MREAn_EADR)

/*! @brief Set the EADR field to a new value. */
#define BW_RDC_MREAn_EADR(x, n, v) (HW_RDC_MREAn_WR(x, n, (HW_RDC_MREAn_RD(x, n) & ~BM_RDC_MREAn_EADR) | BF_RDC_MREAn_EADR(v)))
/*@}*/
/*******************************************************************************
 * HW_RDC_MRCn - Memory Region Control
 ******************************************************************************/

/*!
 * @brief HW_RDC_MRCn - Memory Region Control (RW)
 *
 * Reset value: 0x000000FFU
 */
typedef union _hw_rdc_mrcn
{
    uint32_t U;
    struct _hw_rdc_mrcn_bitfields
    {
        uint32_t D0W : 1;              /*!< [0] Domain 0 Write Access to Region */
        uint32_t D0R : 1;              /*!< [1] Domain 0 Read Access to Region */
        uint32_t D1W : 1;              /*!< [2] Domain 1 Write Access to Region */
        uint32_t D1R : 1;              /*!< [3] Domain 1 Read Access to Region */
        uint32_t D2W : 1;              /*!< [4] Domain 2 Write Access to Region */
        uint32_t D2R : 1;              /*!< [5] Domain 2 Read Access to Region */
        uint32_t D3W : 1;              /*!< [6] Domain 3 Write Access to Region */
        uint32_t D3R : 1;              /*!< [7] Domain 3 Read Access to Region */
        uint32_t RESERVED0 : 22;       /*!< [29:8]  */
        uint32_t ENA : 1;              /*!< [30] Region Enable */
        uint32_t LCK : 1;              /*!< [31] Region Lock */
    } B;
} hw_rdc_mrcn_t;

/*!
 * @name Constants and macros for entire RDC_MRCn register
 */
/*@{*/
#define HW_RDC_MRCn_COUNT (52U)

#define HW_RDC_MRCn_ADDR(x, n)   ((uintptr_t)(x) + 0x808U + (0x10U * (n)))

#define HW_RDC_MRCn(x, n)        (*(__IO hw_rdc_mrcn_t *) HW_RDC_MRCn_ADDR(x, n))
#define HW_RDC_MRCn_RD(x, n)     (HW_RDC_MRCn(x, n).U)
#define HW_RDC_MRCn_WR(x, n, v)  (HW_RDC_MRCn(x, n).U = (v))
#define HW_RDC_MRCn_SET(x, n, v) (HW_RDC_MRCn_WR(x, n, HW_RDC_MRCn_RD(x, n) |  (v)))
#define HW_RDC_MRCn_CLR(x, n, v) (HW_RDC_MRCn_WR(x, n, HW_RDC_MRCn_RD(x, n) & ~(v)))
#define HW_RDC_MRCn_TOG(x, n, v) (HW_RDC_MRCn_WR(x, n, HW_RDC_MRCn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_MRCn bitfields
 */

/*!
 * @name Register RDC_MRCn, field D0W[0] (RW)
 *
 * Values:
 * - 0 - Processing Domain 0 does not have Write access to the memory region
 * - 1 - Processing Domain 0 has Write access to the memory region
 */
/*@{*/
#define BP_RDC_MRCn_D0W      (0U)          /*!< Bit position for RDC_MRCn_D0W. */
#define BM_RDC_MRCn_D0W      (0x00000001U) /*!< Bit mask for RDC_MRCn_D0W. */
#define BS_RDC_MRCn_D0W      (1U)          /*!< Bit field size in bits for RDC_MRCn_D0W. */

/*! @brief Read current value of the RDC_MRCn_D0W field. */
#define BR_RDC_MRCn_D0W(x, n) (HW_RDC_MRCn(x, n).B.D0W)

/*! @brief Format value for bitfield RDC_MRCn_D0W. */
#define BF_RDC_MRCn_D0W(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_D0W) & BM_RDC_MRCn_D0W)

/*! @brief Set the D0W field to a new value. */
#define BW_RDC_MRCn_D0W(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_D0W) | BF_RDC_MRCn_D0W(v)))
/*@}*/

/*!
 * @name Register RDC_MRCn, field D0R[1] (RW)
 *
 * Values:
 * - 0 - Processing Domain 0 does not have Read access to the memory region
 * - 1 - Processing Domain 0 has Read access to the memory region
 */
/*@{*/
#define BP_RDC_MRCn_D0R      (1U)          /*!< Bit position for RDC_MRCn_D0R. */
#define BM_RDC_MRCn_D0R      (0x00000002U) /*!< Bit mask for RDC_MRCn_D0R. */
#define BS_RDC_MRCn_D0R      (1U)          /*!< Bit field size in bits for RDC_MRCn_D0R. */

/*! @brief Read current value of the RDC_MRCn_D0R field. */
#define BR_RDC_MRCn_D0R(x, n) (HW_RDC_MRCn(x, n).B.D0R)

/*! @brief Format value for bitfield RDC_MRCn_D0R. */
#define BF_RDC_MRCn_D0R(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_D0R) & BM_RDC_MRCn_D0R)

/*! @brief Set the D0R field to a new value. */
#define BW_RDC_MRCn_D0R(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_D0R) | BF_RDC_MRCn_D0R(v)))
/*@}*/

/*!
 * @name Register RDC_MRCn, field D1W[2] (RW)
 *
 * Values:
 * - 0 - Processing Domain 1 does not have Write access to the memory region
 * - 1 - Processing Domain 1 has Write access to the memory region
 */
/*@{*/
#define BP_RDC_MRCn_D1W      (2U)          /*!< Bit position for RDC_MRCn_D1W. */
#define BM_RDC_MRCn_D1W      (0x00000004U) /*!< Bit mask for RDC_MRCn_D1W. */
#define BS_RDC_MRCn_D1W      (1U)          /*!< Bit field size in bits for RDC_MRCn_D1W. */

/*! @brief Read current value of the RDC_MRCn_D1W field. */
#define BR_RDC_MRCn_D1W(x, n) (HW_RDC_MRCn(x, n).B.D1W)

/*! @brief Format value for bitfield RDC_MRCn_D1W. */
#define BF_RDC_MRCn_D1W(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_D1W) & BM_RDC_MRCn_D1W)

/*! @brief Set the D1W field to a new value. */
#define BW_RDC_MRCn_D1W(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_D1W) | BF_RDC_MRCn_D1W(v)))
/*@}*/

/*!
 * @name Register RDC_MRCn, field D1R[3] (RW)
 *
 * Values:
 * - 0 - Processing Domain 1 does not have Read access to the memory region
 * - 1 - Processing Domain 1 has Read access to the memory region
 */
/*@{*/
#define BP_RDC_MRCn_D1R      (3U)          /*!< Bit position for RDC_MRCn_D1R. */
#define BM_RDC_MRCn_D1R      (0x00000008U) /*!< Bit mask for RDC_MRCn_D1R. */
#define BS_RDC_MRCn_D1R      (1U)          /*!< Bit field size in bits for RDC_MRCn_D1R. */

/*! @brief Read current value of the RDC_MRCn_D1R field. */
#define BR_RDC_MRCn_D1R(x, n) (HW_RDC_MRCn(x, n).B.D1R)

/*! @brief Format value for bitfield RDC_MRCn_D1R. */
#define BF_RDC_MRCn_D1R(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_D1R) & BM_RDC_MRCn_D1R)

/*! @brief Set the D1R field to a new value. */
#define BW_RDC_MRCn_D1R(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_D1R) | BF_RDC_MRCn_D1R(v)))
/*@}*/

/*!
 * @name Register RDC_MRCn, field D2W[4] (RW)
 *
 * Values:
 * - 0 - Processing Domain 2 does not have Write access to the memory region
 * - 1 - Processing Domain 2 has Write access to the memory region
 */
/*@{*/
#define BP_RDC_MRCn_D2W      (4U)          /*!< Bit position for RDC_MRCn_D2W. */
#define BM_RDC_MRCn_D2W      (0x00000010U) /*!< Bit mask for RDC_MRCn_D2W. */
#define BS_RDC_MRCn_D2W      (1U)          /*!< Bit field size in bits for RDC_MRCn_D2W. */

/*! @brief Read current value of the RDC_MRCn_D2W field. */
#define BR_RDC_MRCn_D2W(x, n) (HW_RDC_MRCn(x, n).B.D2W)

/*! @brief Format value for bitfield RDC_MRCn_D2W. */
#define BF_RDC_MRCn_D2W(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_D2W) & BM_RDC_MRCn_D2W)

/*! @brief Set the D2W field to a new value. */
#define BW_RDC_MRCn_D2W(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_D2W) | BF_RDC_MRCn_D2W(v)))
/*@}*/

/*!
 * @name Register RDC_MRCn, field D2R[5] (RW)
 *
 * Values:
 * - 0 - Processing Domain 2 does not have Read access to the memory region
 * - 1 - Processing Domain 2 has Read access to the memory region
 */
/*@{*/
#define BP_RDC_MRCn_D2R      (5U)          /*!< Bit position for RDC_MRCn_D2R. */
#define BM_RDC_MRCn_D2R      (0x00000020U) /*!< Bit mask for RDC_MRCn_D2R. */
#define BS_RDC_MRCn_D2R      (1U)          /*!< Bit field size in bits for RDC_MRCn_D2R. */

/*! @brief Read current value of the RDC_MRCn_D2R field. */
#define BR_RDC_MRCn_D2R(x, n) (HW_RDC_MRCn(x, n).B.D2R)

/*! @brief Format value for bitfield RDC_MRCn_D2R. */
#define BF_RDC_MRCn_D2R(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_D2R) & BM_RDC_MRCn_D2R)

/*! @brief Set the D2R field to a new value. */
#define BW_RDC_MRCn_D2R(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_D2R) | BF_RDC_MRCn_D2R(v)))
/*@}*/

/*!
 * @name Register RDC_MRCn, field D3W[6] (RW)
 *
 * Values:
 * - 0 - Processing Domain 3 does not have Write access to the memory region
 * - 1 - Processing Domain 3 has Read access to the memory region
 */
/*@{*/
#define BP_RDC_MRCn_D3W      (6U)          /*!< Bit position for RDC_MRCn_D3W. */
#define BM_RDC_MRCn_D3W      (0x00000040U) /*!< Bit mask for RDC_MRCn_D3W. */
#define BS_RDC_MRCn_D3W      (1U)          /*!< Bit field size in bits for RDC_MRCn_D3W. */

/*! @brief Read current value of the RDC_MRCn_D3W field. */
#define BR_RDC_MRCn_D3W(x, n) (HW_RDC_MRCn(x, n).B.D3W)

/*! @brief Format value for bitfield RDC_MRCn_D3W. */
#define BF_RDC_MRCn_D3W(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_D3W) & BM_RDC_MRCn_D3W)

/*! @brief Set the D3W field to a new value. */
#define BW_RDC_MRCn_D3W(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_D3W) | BF_RDC_MRCn_D3W(v)))
/*@}*/

/*!
 * @name Register RDC_MRCn, field D3R[7] (RW)
 *
 * Values:
 * - 0 - Processing Domain 3 does not have Read access to the memory region
 * - 1 - Processing Domain 3 has Read access to the memory region
 */
/*@{*/
#define BP_RDC_MRCn_D3R      (7U)          /*!< Bit position for RDC_MRCn_D3R. */
#define BM_RDC_MRCn_D3R      (0x00000080U) /*!< Bit mask for RDC_MRCn_D3R. */
#define BS_RDC_MRCn_D3R      (1U)          /*!< Bit field size in bits for RDC_MRCn_D3R. */

/*! @brief Read current value of the RDC_MRCn_D3R field. */
#define BR_RDC_MRCn_D3R(x, n) (HW_RDC_MRCn(x, n).B.D3R)

/*! @brief Format value for bitfield RDC_MRCn_D3R. */
#define BF_RDC_MRCn_D3R(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_D3R) & BM_RDC_MRCn_D3R)

/*! @brief Set the D3R field to a new value. */
#define BW_RDC_MRCn_D3R(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_D3R) | BF_RDC_MRCn_D3R(v)))
/*@}*/

/*!
 * @name Register RDC_MRCn, field ENA[30] (RW)
 *
 * Activates the memory region. If the region is not activated then the
 * permissions and address boundaries have not affect and the region will be fully
 * accessible.
 *
 * Values:
 * - 0 - Memory region is not defined or restricted.
 * - 1 - Memory boundaries, domain permissions and controls are in effect.
 */
/*@{*/
#define BP_RDC_MRCn_ENA      (30U)         /*!< Bit position for RDC_MRCn_ENA. */
#define BM_RDC_MRCn_ENA      (0x40000000U) /*!< Bit mask for RDC_MRCn_ENA. */
#define BS_RDC_MRCn_ENA      (1U)          /*!< Bit field size in bits for RDC_MRCn_ENA. */

/*! @brief Read current value of the RDC_MRCn_ENA field. */
#define BR_RDC_MRCn_ENA(x, n) (HW_RDC_MRCn(x, n).B.ENA)

/*! @brief Format value for bitfield RDC_MRCn_ENA. */
#define BF_RDC_MRCn_ENA(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_ENA) & BM_RDC_MRCn_ENA)

/*! @brief Set the ENA field to a new value. */
#define BW_RDC_MRCn_ENA(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_ENA) | BF_RDC_MRCn_ENA(v)))
/*@}*/

/*!
 * @name Register RDC_MRCn, field LCK[31] (RW)
 *
 * Locks all region fields from further modification except ENA, which can be
 * set but not reset after LCK is set. LCK is a sticky bit.
 *
 * Values:
 * - 0 - No Lock. All fields in this register may be modified.
 * - 1 - Locked. No fields in this register may be modified except ENA, which
 *     may be set but not cleared.
 */
/*@{*/
#define BP_RDC_MRCn_LCK      (31U)         /*!< Bit position for RDC_MRCn_LCK. */
#define BM_RDC_MRCn_LCK      (0x80000000U) /*!< Bit mask for RDC_MRCn_LCK. */
#define BS_RDC_MRCn_LCK      (1U)          /*!< Bit field size in bits for RDC_MRCn_LCK. */

/*! @brief Read current value of the RDC_MRCn_LCK field. */
#define BR_RDC_MRCn_LCK(x, n) (HW_RDC_MRCn(x, n).B.LCK)

/*! @brief Format value for bitfield RDC_MRCn_LCK. */
#define BF_RDC_MRCn_LCK(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRCn_LCK) & BM_RDC_MRCn_LCK)

/*! @brief Set the LCK field to a new value. */
#define BW_RDC_MRCn_LCK(x, n, v) (HW_RDC_MRCn_WR(x, n, (HW_RDC_MRCn_RD(x, n) & ~BM_RDC_MRCn_LCK) | BF_RDC_MRCn_LCK(v)))
/*@}*/
/*******************************************************************************
 * HW_RDC_MRVSn - Memory Region Violation Status
 ******************************************************************************/

/*!
 * @brief HW_RDC_MRVSn - Memory Region Violation Status (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_rdc_mrvsn
{
    uint32_t U;
    struct _hw_rdc_mrvsn_bitfields
    {
        uint32_t VDID : 2;             /*!< [1:0] Violating Domain ID */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t AD : 1;               /*!< [4] Access Denied */
        uint32_t VADR : 27;            /*!< [31:5] Violating Address */
    } B;
} hw_rdc_mrvsn_t;

/*!
 * @name Constants and macros for entire RDC_MRVSn register
 */
/*@{*/
#define HW_RDC_MRVSn_COUNT (52U)

#define HW_RDC_MRVSn_ADDR(x, n)  ((uintptr_t)(x) + 0x80CU + (0x10U * (n)))

#define HW_RDC_MRVSn(x, n)       (*(__IO hw_rdc_mrvsn_t *) HW_RDC_MRVSn_ADDR(x, n))
#define HW_RDC_MRVSn_RD(x, n)    (HW_RDC_MRVSn(x, n).U)
#define HW_RDC_MRVSn_WR(x, n, v) (HW_RDC_MRVSn(x, n).U = (v))
#define HW_RDC_MRVSn_SET(x, n, v) (HW_RDC_MRVSn_WR(x, n, HW_RDC_MRVSn_RD(x, n) |  (v)))
#define HW_RDC_MRVSn_CLR(x, n, v) (HW_RDC_MRVSn_WR(x, n, HW_RDC_MRVSn_RD(x, n) & ~(v)))
#define HW_RDC_MRVSn_TOG(x, n, v) (HW_RDC_MRVSn_WR(x, n, HW_RDC_MRVSn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_MRVSn bitfields
 */

/*!
 * @name Register RDC_MRVSn, field VDID[1:0] (RO)
 *
 * The domain ID of the denied access. The first access violation is captured.
 * Subsequent violations are ignored until the status register is cleared.
 * Contents are cleared upon reading the register.
 *
 * Values:
 * - 00 - Processing Domain 0
 * - 01 - Processing Domain 1
 * - 10 - Processing Domain 2
 * - 11 - Processing Domain 3
 */
/*@{*/
#define BP_RDC_MRVSn_VDID    (0U)          /*!< Bit position for RDC_MRVSn_VDID. */
#define BM_RDC_MRVSn_VDID    (0x00000003U) /*!< Bit mask for RDC_MRVSn_VDID. */
#define BS_RDC_MRVSn_VDID    (2U)          /*!< Bit field size in bits for RDC_MRVSn_VDID. */

/*! @brief Read current value of the RDC_MRVSn_VDID field. */
#define BR_RDC_MRVSn_VDID(x, n) (HW_RDC_MRVSn(x, n).B.VDID)
/*@}*/

/*!
 * @name Register RDC_MRVSn, field AD[4] (W1C)
 *
 * Access to a memory region denied. This bit is cleared when this bit is
 * written by one of the allowed domains.
 */
/*@{*/
#define BP_RDC_MRVSn_AD      (4U)          /*!< Bit position for RDC_MRVSn_AD. */
#define BM_RDC_MRVSn_AD      (0x00000010U) /*!< Bit mask for RDC_MRVSn_AD. */
#define BS_RDC_MRVSn_AD      (1U)          /*!< Bit field size in bits for RDC_MRVSn_AD. */

/*! @brief Read current value of the RDC_MRVSn_AD field. */
#define BR_RDC_MRVSn_AD(x, n) (HW_RDC_MRVSn(x, n).B.AD)

/*! @brief Format value for bitfield RDC_MRVSn_AD. */
#define BF_RDC_MRVSn_AD(v)   ((uint32_t)((uint32_t)(v) << BP_RDC_MRVSn_AD) & BM_RDC_MRVSn_AD)

/*! @brief Set the AD field to a new value. */
#define BW_RDC_MRVSn_AD(x, n, v) (HW_RDC_MRVSn_WR(x, n, (HW_RDC_MRVSn_RD(x, n) & ~BM_RDC_MRVSn_AD) | BF_RDC_MRVSn_AD(v)))
/*@}*/

/*!
 * @name Register RDC_MRVSn, field VADR[31:5] (RO)
 *
 * The address of the denied access. The first access violation is captured.
 * Subsequent violations are ignored until the status register is cleared. Contents
 * are cleared upon reading the register. Clearing of contents occurs only when
 * the status is read by the memory region's associated domain ID (s).
 */
/*@{*/
#define BP_RDC_MRVSn_VADR    (5U)          /*!< Bit position for RDC_MRVSn_VADR. */
#define BM_RDC_MRVSn_VADR    (0xFFFFFFE0U) /*!< Bit mask for RDC_MRVSn_VADR. */
#define BS_RDC_MRVSn_VADR    (27U)         /*!< Bit field size in bits for RDC_MRVSn_VADR. */

/*! @brief Read current value of the RDC_MRVSn_VADR field. */
#define BR_RDC_MRVSn_VADR(x, n) (HW_RDC_MRVSn(x, n).B.VADR)
/*@}*/

/*******************************************************************************
 * hw_rdc_t - module struct
 ******************************************************************************/
/*!
 * @brief All RDC module registers.
 */
#pragma pack(1)
typedef struct _hw_rdc
{
    __I hw_rdc_vir_t VIR;                  /*!< [0x0] Version Information */
    uint8_t _reserved0[32];
    __IO hw_rdc_stat_t STAT;               /*!< [0x24] Status */
    __IO hw_rdc_intctrl_t INTCTRL;         /*!< [0x28] Interrupt and Control */
    __IO hw_rdc_intstat_t INTSTAT;         /*!< [0x2C] Interrupt Status */
    uint8_t _reserved1[464];
    __IO hw_rdc_mdan_t MDAn[27];           /*!< [0x200] Master Domain Assignment */
    uint8_t _reserved2[404];
    __IO hw_rdc_pdapn_t PDAPn[118];        /*!< [0x400] Peripheral Domain Access Permissions */
    uint8_t _reserved3[552];
    struct {
        __IO hw_rdc_mrsan_t MRSAn;         /*!< [0x800] Memory Region Start Address */
        __IO hw_rdc_mrean_t MREAn;         /*!< [0x804] Memory Region End Address */
        __IO hw_rdc_mrcn_t MRCn;           /*!< [0x808] Memory Region Control */
        __IO hw_rdc_mrvsn_t MRVSn;         /*!< [0x80C] Memory Region Violation Status */
    } MR[52];
} hw_rdc_t;
#pragma pack()

/*! @brief Macro to access all RDC registers. */
/*! @param x RDC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_RDC_REGS(RDC_BASE)</code>. */
#define HW_RDC_REGS(x) (*(hw_rdc_t *)(x))

/*
 * iMX7D RDC_SEMAPHORE
 *
 * SEMA42
 *
 * Registers defined in this header file:
 * - HW_RDC_SEMAPHORE_GATEn - Gate Register
 * - HW_RDC_SEMAPHORE_RSTGT_R - Reset Gate Read
 * - HW_RDC_SEMAPHORE_RSTGT_W - Reset Gate Write
 *
 * - hw_rdc_semaphore_t - Struct containing all module registers.
 */

#define HW_RDC_SEMAPHORE_INSTANCE_COUNT (2U) /*!< Number of instances of the RDC_SEMAPHORE module. */
#define HW_RDC_SEMAPHORE1 (0U) /*!< Instance number for RDC_SEMAPHORE1. */
#define HW_RDC_SEMAPHORE2 (1U) /*!< Instance number for RDC_SEMAPHORE2. */
#define RDC_SEMAPHORE1_BASE   (0x303B0000U) /*!< Base address for RDC_SEMAPHORE1. */
#define RDC_SEMAPHORE2_BASE   (0x303C0000U) /*!< Base address for RDC_SEMAPHORE2. */
/*! Array initializer of RDC_SEMAPHORE base addresses. */
#define RDC_SEMAPHORE_BASE_ADDRS { RDC_SEMAPHORE1_BASE, RDC_SEMAPHORE2_BASE }

/*******************************************************************************
 * HW_RDC_SEMAPHORE_GATEn - Gate Register
 ******************************************************************************/

/*!
 * @brief HW_RDC_SEMAPHORE_GATEn - Gate Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 4-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the logical bus master
 * number (master_index) in conjunction with the data patterns to validate all
 * attempted write operations. Only processor bus masters can modify the gate
 * registers. Once locked, a gate can (and must) be opened (unlocked) by the locking
 * processor core. Multiple gate values can be read in a single access, but only a
 * single gate can be updated via a write operation at a time. Attempted writes with
 * a data value that is neither the unlock value nor the appropriate lock value
 * (master_index + 1) are simply treated as "no operation" and do not affect any
 * gate state. Attempts to write multiple gates in a single aligned access with a
 * size larger than an 8-bit (byte) reference generate an error termination and
 * do not allow any gate state changes. Processor dex values can be found in .
 */
typedef union _hw_rdc_semaphore_gaten
{
    uint8_t U;
    struct _hw_rdc_semaphore_gaten_bitfields
    {
        uint8_t GTFSM : 4;             /*!< [3:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 1;         /*!< [4]  */
        uint8_t LDOM : 2;              /*!< [6:5]  */
        uint8_t RESERVED1 : 1;         /*!< [7]  */
    } B;
} hw_rdc_semaphore_gaten_t;

/*!
 * @name Constants and macros for entire RDC_SEMAPHORE_GATEn register
 */
/*@{*/
#define HW_RDC_SEMAPHORE_GATEn_COUNT (64U)

#define HW_RDC_SEMAPHORE_GATEn_ADDR(x, n) ((uintptr_t)(x) + 0x0U + (0x1U * (n)))

#define HW_RDC_SEMAPHORE_GATEn(x, n) (*(__IO hw_rdc_semaphore_gaten_t *) HW_RDC_SEMAPHORE_GATEn_ADDR(x, n))
#define HW_RDC_SEMAPHORE_GATEn_RD(x, n) (HW_RDC_SEMAPHORE_GATEn(x, n).U)
#define HW_RDC_SEMAPHORE_GATEn_WR(x, n, v) (HW_RDC_SEMAPHORE_GATEn(x, n).U = (v))
#define HW_RDC_SEMAPHORE_GATEn_SET(x, n, v) (HW_RDC_SEMAPHORE_GATEn_WR(x, n, HW_RDC_SEMAPHORE_GATEn_RD(x, n) |  (v)))
#define HW_RDC_SEMAPHORE_GATEn_CLR(x, n, v) (HW_RDC_SEMAPHORE_GATEn_WR(x, n, HW_RDC_SEMAPHORE_GATEn_RD(x, n) & ~(v)))
#define HW_RDC_SEMAPHORE_GATEn_TOG(x, n, v) (HW_RDC_SEMAPHORE_GATEn_WR(x, n, HW_RDC_SEMAPHORE_GATEn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_SEMAPHORE_GATEn bitfields
 */

/*!
 * @name Register RDC_SEMAPHORE_GATEn, field GTFSM[3:0] (RW)
 *
 * The state of the gate reflects the last processor that locked it, which can
 * be useful during system debug. The hardware gate is maintained in a 16-state
 * implementation, defined as:
 *
 * Values:
 * - 0000 - The gate is unlocked (free).
 * - 0001 - The gate has been locked by processor with master_index = 0.
 * - 0010 - The gate has been locked by processor with master_index = 1.
 * - 0011 - The gate has been locked by processor with master_index = 2.
 * - 0100 - The gate has been locked by processor with master_index = 3.
 * - 0101 - The gate has been locked by processor with master_index = 4.
 * - 0110 - The gate has been locked by processor with master_index = 5.
 * - 0111 - The gate has been locked by processor with master_index = 6.
 * - 1000 - The gate has been locked by processor with master_index = 7.
 * - 1001 - The gate has been locked by processor with master_index = 8.
 * - 1010 - The gate has been locked by processor with master_index = 9.
 * - 1011 - The gate has been locked by processor with master_index = 10.
 * - 1100 - The gate has been locked by processor with master_index = 11.
 * - 1101 - The gate has been locked by processor with master_index = 12.
 * - 1110 - The gate has been locked by processor with master_index = 13.
 * - 1111 - The gate has been locked by processor with master_index = 14.
 */
/*@{*/
#define BP_RDC_SEMAPHORE_GATEn_GTFSM (0U)  /*!< Bit position for RDC_SEMAPHORE_GATEn_GTFSM. */
#define BM_RDC_SEMAPHORE_GATEn_GTFSM (0x0FU) /*!< Bit mask for RDC_SEMAPHORE_GATEn_GTFSM. */
#define BS_RDC_SEMAPHORE_GATEn_GTFSM (4U)  /*!< Bit field size in bits for RDC_SEMAPHORE_GATEn_GTFSM. */

/*! @brief Read current value of the RDC_SEMAPHORE_GATEn_GTFSM field. */
#define BR_RDC_SEMAPHORE_GATEn_GTFSM(x, n) (HW_RDC_SEMAPHORE_GATEn(x, n).B.GTFSM)

/*! @brief Format value for bitfield RDC_SEMAPHORE_GATEn_GTFSM. */
#define BF_RDC_SEMAPHORE_GATEn_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_RDC_SEMAPHORE_GATEn_GTFSM) & BM_RDC_SEMAPHORE_GATEn_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_RDC_SEMAPHORE_GATEn_GTFSM(x, n, v) (HW_RDC_SEMAPHORE_GATEn_WR(x, n, (HW_RDC_SEMAPHORE_GATEn_RD(x, n) & ~BM_RDC_SEMAPHORE_GATEn_GTFSM) | BF_RDC_SEMAPHORE_GATEn_GTFSM(v)))
/*@}*/

/*!
 * @name Register RDC_SEMAPHORE_GATEn, field LDOM[6:5] (RO)
 *
 * Bits 6-5 are read-only bits. They indicate which domain had currently locked
 * the gate.
 *
 * Values:
 * - 00 - The gate is locked by domain 0. (True if bits [3:0] do not equal 0000.)
 * - 01 - The gate has been locked by domain 1.
 * - 10 - The gate has been locked by domain 2.
 * - 11 - The gate has been locked by domain 3.
 */
/*@{*/
#define BP_RDC_SEMAPHORE_GATEn_LDOM (5U)   /*!< Bit position for RDC_SEMAPHORE_GATEn_LDOM. */
#define BM_RDC_SEMAPHORE_GATEn_LDOM (0x60U) /*!< Bit mask for RDC_SEMAPHORE_GATEn_LDOM. */
#define BS_RDC_SEMAPHORE_GATEn_LDOM (2U)   /*!< Bit field size in bits for RDC_SEMAPHORE_GATEn_LDOM. */

/*! @brief Read current value of the RDC_SEMAPHORE_GATEn_LDOM field. */
#define BR_RDC_SEMAPHORE_GATEn_LDOM(x, n) (HW_RDC_SEMAPHORE_GATEn(x, n).B.LDOM)
/*@}*/

/*******************************************************************************
 * HW_RDC_SEMAPHORE_RSTGT_R - Reset Gate Read
 ******************************************************************************/

/*!
 * @brief HW_RDC_SEMAPHORE_RSTGT_R - Reset Gate Read (RW)
 *
 * Reset value: 0x0000U
 *
 * Although the intent of the hardware gate implementation specifies a protocol
 * where the locking processor must unlock the gate, it is recognized that system
 * operation may require a reset function to re-initialize the state of any
 * gate(s) without requiring a system-level reset. To support this special gate reset
 * requirement, the RDC Semaphores module implements a "secure" reset mechanism
 * that allows a hardware gate (or all the gates) to be initialized by following
 * a specific dual-write access pattern. Using a technique similar to that
 * required for the servicing of a software watchdog timer, the secure gate reset
 * requires two consecutive writes with predefined data patterns from the same
 * processor to force the clearing of the specified gate(s). The required access pattern
 * is: A processor performs a 16-bit write to the RDC_SEMA42RSTGT memory
 * location. The least significant byte (RDC_SEMA42RSTGT[RSTGDP]) must be 0xE2; the most
 * significant byte is a "don't_care" for this reference. The same processor
 * then performs a second 16-bit write to the RDC_SEMA42RSTGT location. For this
 * write, the lower byte (RDC_SEMA42RSTGT[RSTGDP]) is the logical complement of the
 * first data pattern (0x1D) and the upper byte (RDC_SEMA42RSTGT[RSTGTN])
 * specifies the gate(s) to be reset. This gate field can specify a single gate be
 * cleared, or else that all gates are to be cleared. If the same processor writes
 * incorrect data on the second access or another processor performs the second
 * write access, the special gate reset sequence is aborted and no error signal will
 * be asserted. Reads of the RDC_SEMA42RSTGT location return information on the
 * 2-bit state machine (RDC_SEMA42RSTGT[RSTGSM]) that implements this function,
 * the bus master performing the reset (RDC_SEMA42RSTGT[RSTGMS]), and the gate
 * number(s) last cleared (RDC_SEMA42RSTGT[RSTGTN]). Reads of the RDC_SEMA42RSTGT
 * register do not affect the secure reset finite state machine in any manner.
 */
typedef union _hw_rdc_semaphore_rstgt_r
{
    uint16_t U;
    struct _hw_rdc_semaphore_rstgt_r_bitfields
    {
        uint16_t RSTGMS : 4;           /*!< [3:0]  */
        uint16_t RSTGSM : 2;           /*!< [5:4]  */
        uint16_t RESERVED0 : 2;        /*!< [7:6]  */
        uint16_t RSTGTN : 8;           /*!< [15:8]  */
    } B;
} hw_rdc_semaphore_rstgt_r_t;

/*!
 * @name Constants and macros for entire RDC_SEMAPHORE_RSTGT_R register
 */
/*@{*/
#define HW_RDC_SEMAPHORE_RSTGT_R_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_RDC_SEMAPHORE_RSTGT_R(x) (*(__IO hw_rdc_semaphore_rstgt_r_t *) HW_RDC_SEMAPHORE_RSTGT_R_ADDR(x))
#define HW_RDC_SEMAPHORE_RSTGT_R_RD(x) (HW_RDC_SEMAPHORE_RSTGT_R(x).U)
#define HW_RDC_SEMAPHORE_RSTGT_R_WR(x, v) (HW_RDC_SEMAPHORE_RSTGT_R(x).U = (v))
#define HW_RDC_SEMAPHORE_RSTGT_R_SET(x, v) (HW_RDC_SEMAPHORE_RSTGT_R_WR(x, HW_RDC_SEMAPHORE_RSTGT_R_RD(x) |  (v)))
#define HW_RDC_SEMAPHORE_RSTGT_R_CLR(x, v) (HW_RDC_SEMAPHORE_RSTGT_R_WR(x, HW_RDC_SEMAPHORE_RSTGT_R_RD(x) & ~(v)))
#define HW_RDC_SEMAPHORE_RSTGT_R_TOG(x, v) (HW_RDC_SEMAPHORE_RSTGT_R_WR(x, HW_RDC_SEMAPHORE_RSTGT_R_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_SEMAPHORE_RSTGT_R bitfields
 */

/*!
 * @name Register RDC_SEMAPHORE_RSTGT_R, field RSTGMS[3:0] (RO)
 *
 * Reset Gate Bus Master. This 4-bit read-only field records the logical number
 * of the bus master performing the gate reset function. The reset function
 * requires that the two consecutive writes to this register must be initiated by the
 * same bus master to succeed. This field is updated each time a write to this
 * register occurs. The association between system bus master port numbers, the
 * associated bus master device, and the logical processor number is SoC-specific.
 * Consult the device reference manual for this information.
 */
/*@{*/
#define BP_RDC_SEMAPHORE_RSTGT_R_RSTGMS (0U) /*!< Bit position for RDC_SEMAPHORE_RSTGT_R_RSTGMS. */
#define BM_RDC_SEMAPHORE_RSTGT_R_RSTGMS (0x000FU) /*!< Bit mask for RDC_SEMAPHORE_RSTGT_R_RSTGMS. */
#define BS_RDC_SEMAPHORE_RSTGT_R_RSTGMS (4U) /*!< Bit field size in bits for RDC_SEMAPHORE_RSTGT_R_RSTGMS. */

/*! @brief Read current value of the RDC_SEMAPHORE_RSTGT_R_RSTGMS field. */
#define BR_RDC_SEMAPHORE_RSTGT_R_RSTGMS(x) (HW_RDC_SEMAPHORE_RSTGT_R(x).B.RSTGMS)
/*@}*/

/*!
 * @name Register RDC_SEMAPHORE_RSTGT_R, field RSTGSM[5:4] (RO)
 *
 * Reset Gate Finite State Machine. Reads of the RDC_SEMA42RSTGT register return
 * the encoded state machine value. Note the RSTGSM = 10 state is valid for only
 * a single machine cycle, so it is impossible for a read to return this value.
 * The reset state machine is maintained in a 2-bit, 3-state implementation,
 * defined as:
 *
 * Values:
 * - 00 - Idle, waiting for the first data pattern write.
 * - 01 - Waiting for the second data pattern write.
 * - 10 - The 2-write sequence has completed. Generate the specified gate
 *     reset(s). After the reset is performed, this machine returns to the idle
 *     (waiting for first data pattern write) state. The "01" state persists for only
 *     one clock cycle. Software will never be able to observe this state.
 * - 11 - This state encoding is never used and therefore reserved.
 */
/*@{*/
#define BP_RDC_SEMAPHORE_RSTGT_R_RSTGSM (4U) /*!< Bit position for RDC_SEMAPHORE_RSTGT_R_RSTGSM. */
#define BM_RDC_SEMAPHORE_RSTGT_R_RSTGSM (0x0030U) /*!< Bit mask for RDC_SEMAPHORE_RSTGT_R_RSTGSM. */
#define BS_RDC_SEMAPHORE_RSTGT_R_RSTGSM (2U) /*!< Bit field size in bits for RDC_SEMAPHORE_RSTGT_R_RSTGSM. */

/*! @brief Read current value of the RDC_SEMAPHORE_RSTGT_R_RSTGSM field. */
#define BR_RDC_SEMAPHORE_RSTGT_R_RSTGSM(x) (HW_RDC_SEMAPHORE_RSTGT_R(x).B.RSTGSM)
/*@}*/

/*!
 * @name Register RDC_SEMAPHORE_RSTGT_R, field RSTGTN[15:8] (RW)
 *
 * Reset Gate Number. This 8-bit field specifies the specific hardware gate to
 * be reset. This field is updated by the second write. If RSTGTN < 64, then reset
 * the single gate defined by RSTGTN, else reset all the gates.
 */
/*@{*/
#define BP_RDC_SEMAPHORE_RSTGT_R_RSTGTN (8U) /*!< Bit position for RDC_SEMAPHORE_RSTGT_R_RSTGTN. */
#define BM_RDC_SEMAPHORE_RSTGT_R_RSTGTN (0xFF00U) /*!< Bit mask for RDC_SEMAPHORE_RSTGT_R_RSTGTN. */
#define BS_RDC_SEMAPHORE_RSTGT_R_RSTGTN (8U) /*!< Bit field size in bits for RDC_SEMAPHORE_RSTGT_R_RSTGTN. */

/*! @brief Read current value of the RDC_SEMAPHORE_RSTGT_R_RSTGTN field. */
#define BR_RDC_SEMAPHORE_RSTGT_R_RSTGTN(x) (HW_RDC_SEMAPHORE_RSTGT_R(x).B.RSTGTN)

/*! @brief Format value for bitfield RDC_SEMAPHORE_RSTGT_R_RSTGTN. */
#define BF_RDC_SEMAPHORE_RSTGT_R_RSTGTN(v) ((uint16_t)((uint16_t)(v) << BP_RDC_SEMAPHORE_RSTGT_R_RSTGTN) & BM_RDC_SEMAPHORE_RSTGT_R_RSTGTN)

/*! @brief Set the RSTGTN field to a new value. */
#define BW_RDC_SEMAPHORE_RSTGT_R_RSTGTN(x, v) (HW_RDC_SEMAPHORE_RSTGT_R_WR(x, (HW_RDC_SEMAPHORE_RSTGT_R_RD(x) & ~BM_RDC_SEMAPHORE_RSTGT_R_RSTGTN) | BF_RDC_SEMAPHORE_RSTGT_R_RSTGTN(v)))
/*@}*/
/*******************************************************************************
 * HW_RDC_SEMAPHORE_RSTGT_W - Reset Gate Write
 ******************************************************************************/

/*!
 * @brief HW_RDC_SEMAPHORE_RSTGT_W - Reset Gate Write (RW)
 *
 * Reset value: 0x0000U
 *
 * Although the intent of the hardware gate implementation specifies a protocol
 * where the locking processor must unlock the gate, it is recognized that system
 * operation may require a reset function to re-initialize the state of any
 * gate(s) without requiring a system-level reset. To support this special gate reset
 * requirement, the RDC Semaphores module implements a "secure" reset mechanism
 * that allows a hardware gate (or all the gates) to be initialized by following
 * a specific dual-write access pattern. Using a technique similar to that
 * required for the servicing of a software watchdog timer, the secure gate reset
 * requires two consecutive writes with predefined data patterns from the same
 * processor to force the clearing of the specified gate(s). The required access pattern
 * is: A processor performs a 16-bit write to the RDC_SEMA42RSTGT memory
 * location. The least significant byte (RDC_SEMA42RSTGT[RSTGDP]) must be 0xE2; the most
 * significant byte is a "don't_care" for this reference. The same processor
 * then performs a second 16-bit write to the RDC_SEMA42RSTGT location. For this
 * write, the lower byte (RDC_SEMA42RSTGT[RSTGDP]) is the logical complement of the
 * first data pattern (0x1D) and the upper byte (RDC_SEMA42RSTGT[RSTGTN])
 * specifies the gate(s) to be reset. This gate field can specify a single gate be
 * cleared, or else that all gates are to be cleared. If the same processor writes
 * incorrect data on the second access or another processor performs the second
 * write access, the special gate reset sequence is aborted and no error signal will
 * be asserted. Reads of the RDC_SEMA42RSTGT location return information on the
 * 2-bit state machine (RDC_SEMA42RSTGT[RSTGSM]) that implements this function,
 * the bus master performing the reset (RDC_SEMA42RSTGT[RSTGMS]), and the gate
 * number(s) last cleared (RDC_SEMA42RSTGT[RSTGTN]). Reads of the RDC_SEMA42RSTGT
 * register do not affect the secure reset finite state machine in any manner.
 */
typedef union _hw_rdc_semaphore_rstgt_w
{
    uint16_t U;
    struct _hw_rdc_semaphore_rstgt_w_bitfields
    {
        uint16_t RSTGDP : 8;           /*!< [7:0]  */
        uint16_t RSTGTN : 8;           /*!< [15:8]  */
    } B;
} hw_rdc_semaphore_rstgt_w_t;

/*!
 * @name Constants and macros for entire RDC_SEMAPHORE_RSTGT_W register
 */
/*@{*/
#define HW_RDC_SEMAPHORE_RSTGT_W_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_RDC_SEMAPHORE_RSTGT_W(x) (*(__IO hw_rdc_semaphore_rstgt_w_t *) HW_RDC_SEMAPHORE_RSTGT_W_ADDR(x))
#define HW_RDC_SEMAPHORE_RSTGT_W_RD(x) (HW_RDC_SEMAPHORE_RSTGT_W(x).U)
#define HW_RDC_SEMAPHORE_RSTGT_W_WR(x, v) (HW_RDC_SEMAPHORE_RSTGT_W(x).U = (v))
#define HW_RDC_SEMAPHORE_RSTGT_W_SET(x, v) (HW_RDC_SEMAPHORE_RSTGT_W_WR(x, HW_RDC_SEMAPHORE_RSTGT_W_RD(x) |  (v)))
#define HW_RDC_SEMAPHORE_RSTGT_W_CLR(x, v) (HW_RDC_SEMAPHORE_RSTGT_W_WR(x, HW_RDC_SEMAPHORE_RSTGT_W_RD(x) & ~(v)))
#define HW_RDC_SEMAPHORE_RSTGT_W_TOG(x, v) (HW_RDC_SEMAPHORE_RSTGT_W_WR(x, HW_RDC_SEMAPHORE_RSTGT_W_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual RDC_SEMAPHORE_RSTGT_W bitfields
 */

/*!
 * @name Register RDC_SEMAPHORE_RSTGT_W, field RSTGDP[7:0] (WORZ)
 *
 * Reset Gate Data Pattern. This write-only field is accessed with the specified
 * data patterns on the two consecutive writes to enable the gate reset
 * mechanism. For the first write, RSTGDP = 0xE2 while the second write requires RSTGDP =
 * 0x1D.
 */
/*@{*/
#define BP_RDC_SEMAPHORE_RSTGT_W_RSTGDP (0U) /*!< Bit position for RDC_SEMAPHORE_RSTGT_W_RSTGDP. */
#define BM_RDC_SEMAPHORE_RSTGT_W_RSTGDP (0x00FFU) /*!< Bit mask for RDC_SEMAPHORE_RSTGT_W_RSTGDP. */
#define BS_RDC_SEMAPHORE_RSTGT_W_RSTGDP (8U) /*!< Bit field size in bits for RDC_SEMAPHORE_RSTGT_W_RSTGDP. */

/*! @brief Format value for bitfield RDC_SEMAPHORE_RSTGT_W_RSTGDP. */
#define BF_RDC_SEMAPHORE_RSTGT_W_RSTGDP(v) ((uint16_t)((uint16_t)(v) << BP_RDC_SEMAPHORE_RSTGT_W_RSTGDP) & BM_RDC_SEMAPHORE_RSTGT_W_RSTGDP)

/*! @brief Set the RSTGDP field to a new value. */
#define BW_RDC_SEMAPHORE_RSTGT_W_RSTGDP(x, v) (HW_RDC_SEMAPHORE_RSTGT_W_WR(x, (HW_RDC_SEMAPHORE_RSTGT_W_RD(x) & ~BM_RDC_SEMAPHORE_RSTGT_W_RSTGDP) | BF_RDC_SEMAPHORE_RSTGT_W_RSTGDP(v)))
/*@}*/

/*!
 * @name Register RDC_SEMAPHORE_RSTGT_W, field RSTGTN[15:8] (RW)
 *
 * Reset Gate Number. This 8-bit field specifies the specific hardware gate to
 * be reset. This field is updated by the second write. If RSTGTN < 64, then reset
 * the single gate defined by RSTGTN, else reset all the gates.
 */
/*@{*/
#define BP_RDC_SEMAPHORE_RSTGT_W_RSTGTN (8U) /*!< Bit position for RDC_SEMAPHORE_RSTGT_W_RSTGTN. */
#define BM_RDC_SEMAPHORE_RSTGT_W_RSTGTN (0xFF00U) /*!< Bit mask for RDC_SEMAPHORE_RSTGT_W_RSTGTN. */
#define BS_RDC_SEMAPHORE_RSTGT_W_RSTGTN (8U) /*!< Bit field size in bits for RDC_SEMAPHORE_RSTGT_W_RSTGTN. */

/*! @brief Read current value of the RDC_SEMAPHORE_RSTGT_W_RSTGTN field. */
#define BR_RDC_SEMAPHORE_RSTGT_W_RSTGTN(x) (HW_RDC_SEMAPHORE_RSTGT_W(x).B.RSTGTN)

/*! @brief Format value for bitfield RDC_SEMAPHORE_RSTGT_W_RSTGTN. */
#define BF_RDC_SEMAPHORE_RSTGT_W_RSTGTN(v) ((uint16_t)((uint16_t)(v) << BP_RDC_SEMAPHORE_RSTGT_W_RSTGTN) & BM_RDC_SEMAPHORE_RSTGT_W_RSTGTN)

/*! @brief Set the RSTGTN field to a new value. */
#define BW_RDC_SEMAPHORE_RSTGT_W_RSTGTN(x, v) (HW_RDC_SEMAPHORE_RSTGT_W_WR(x, (HW_RDC_SEMAPHORE_RSTGT_W_RD(x) & ~BM_RDC_SEMAPHORE_RSTGT_W_RSTGTN) | BF_RDC_SEMAPHORE_RSTGT_W_RSTGTN(v)))
/*@}*/

/*
** Start of section using anonymous unions
*/

#if defined(__ARMCC_VERSION)
  #pragma push
  #pragma anon_unions
#elif defined(__GNUC__)
  /* anonymous unions are enabled by default */
#elif defined(__IAR_SYSTEMS_ICC__)
  #pragma language=extended
#else
  #error Not supported compiler type
#endif

/*******************************************************************************
 * hw_rdc_semaphore_t - module struct
 ******************************************************************************/
/*!
 * @brief All RDC_SEMAPHORE module registers.
 */
#pragma pack(1)
typedef struct _hw_rdc_semaphore
{
    __IO hw_rdc_semaphore_gaten_t GATEn[64]; /*!< [0x0] Gate Register */
    union {
        __IO hw_rdc_semaphore_rstgt_r_t RSTGT_R; /*!< [0x40] Reset Gate Read */
        __IO hw_rdc_semaphore_rstgt_w_t RSTGT_W; /*!< [0x40] Reset Gate Write */
    };
} hw_rdc_semaphore_t;
#pragma pack()

/*! @brief Macro to access all RDC_SEMAPHORE registers. */
/*! @param x RDC_SEMAPHORE module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_RDC_SEMAPHORE_REGS(RDC_SEMAPHORE1_BASE)</code>. */
#define HW_RDC_SEMAPHORE_REGS(x) (*(hw_rdc_semaphore_t *)(x))

/*
** End of section using anonymous unions
*/

#if defined(__ARMCC_VERSION)
  #pragma pop
#elif defined(__GNUC__)
  /* leave anonymous unions enabled */
#elif defined(__IAR_SYSTEMS_ICC__)
  #pragma language=default
#else
  #error Not supported compiler type
#endif

/*
 * iMX7D ROMC
 *
 * ROMC
 *
 * Registers defined in this header file:
 * - HW_ROMC_ROMPATCHnD - ROMC Data Registers
 * - HW_ROMC_ROMPATCHCNTL - ROMC Control Register
 * - HW_ROMC_ROMPATCHENH - ROMC Enable Register High
 * - HW_ROMC_ROMPATCHENL - ROMC Enable Register Low
 * - HW_ROMC_ROMPATCHnA - ROMC Address Registers
 * - HW_ROMC_ROMPATCHSR - ROMC Status Register
 *
 * - hw_romc_t - Struct containing all module registers.
 */

#define HW_ROMC_INSTANCE_COUNT (1U) /*!< Number of instances of the ROMC module. */
#define HW_ROMC (0U) /*!< Instance number for ROMC. */
#define ROMC_BASE             (0x30310000U) /*!< Base address for ROMC. */
/*! Array initializer of ROMC base addresses. */
#define ROMC_BASE_ADDRS       { ROMC_BASE }

/*******************************************************************************
 * HW_ROMC_ROMPATCHnD - ROMC Data Registers
 ******************************************************************************/

/*!
 * @brief HW_ROMC_ROMPATCHnD - ROMC Data Registers (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ROMC data registers (ROMC_ROMPATCH7D through ROMC_ROMPATCH0D) store the
 * data to use for the 8 1-word data fix events. Each register is associated with
 * an address comparator (7 through 0). When a data fixing event occurs, the
 * value in the data register corresponding to the comparator that has the address
 * match is put on the romc_hrdata[31:0] bus until romc_hready is asserted by the
 * ROM controller to terminate the access. A MUX external to the ROMC will select
 * this data over that of romc_hrdata[31:0] in returning read data to the ARM
 * core. The selection is done with the control bus rompatch_romc_hrdata_ovr[1:0]
 * with both bits asserted by the ROMC. If more than one address comparators match,
 * the highest-numbered one takes precedence, and the value in corresponding
 * data register is used for the patching event.
 */
typedef union _hw_romc_rompatchnd
{
    uint32_t U;
    struct _hw_romc_rompatchnd_bitfields
    {
        uint32_t DATAX : 32;           /*!< [31:0]  */
    } B;
} hw_romc_rompatchnd_t;

/*!
 * @name Constants and macros for entire ROMC_ROMPATCHnD register
 */
/*@{*/
#define HW_ROMC_ROMPATCHnD_COUNT (8U)

#define HW_ROMC_ROMPATCHnD_ADDR(x, n) ((uintptr_t)(x) + 0xD4U + (0x4U * (n)))

#define HW_ROMC_ROMPATCHnD(x, n) (*(__IO hw_romc_rompatchnd_t *) HW_ROMC_ROMPATCHnD_ADDR(x, n))
#define HW_ROMC_ROMPATCHnD_RD(x, n) (HW_ROMC_ROMPATCHnD(x, n).U)
#define HW_ROMC_ROMPATCHnD_WR(x, n, v) (HW_ROMC_ROMPATCHnD(x, n).U = (v))
#define HW_ROMC_ROMPATCHnD_SET(x, n, v) (HW_ROMC_ROMPATCHnD_WR(x, n, HW_ROMC_ROMPATCHnD_RD(x, n) |  (v)))
#define HW_ROMC_ROMPATCHnD_CLR(x, n, v) (HW_ROMC_ROMPATCHnD_WR(x, n, HW_ROMC_ROMPATCHnD_RD(x, n) & ~(v)))
#define HW_ROMC_ROMPATCHnD_TOG(x, n, v) (HW_ROMC_ROMPATCHnD_WR(x, n, HW_ROMC_ROMPATCHnD_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ROMC_ROMPATCHnD bitfields
 */

/*!
 * @name Register ROMC_ROMPATCHnD, field DATAX[31:0] (RW)
 *
 * Data Fix Registers - Stores the data used for 1-word data fix operations. The
 * values stored within these registers do not affect the writes to the memory
 * system. They are selected over the read data from ROM when a data fix event
 * occurs. If any part of the 1-word data fix is read, then the entire word is
 * replaced. Therefore, a byte or half-word read will cause the ROMC to replace the
 * entire word. The word is word address aligned.
 */
/*@{*/
#define BP_ROMC_ROMPATCHnD_DATAX (0U)      /*!< Bit position for ROMC_ROMPATCHnD_DATAX. */
#define BM_ROMC_ROMPATCHnD_DATAX (0xFFFFFFFFU) /*!< Bit mask for ROMC_ROMPATCHnD_DATAX. */
#define BS_ROMC_ROMPATCHnD_DATAX (32U)     /*!< Bit field size in bits for ROMC_ROMPATCHnD_DATAX. */

/*! @brief Read current value of the ROMC_ROMPATCHnD_DATAX field. */
#define BR_ROMC_ROMPATCHnD_DATAX(x, n) (HW_ROMC_ROMPATCHnD(x, n).U)

/*! @brief Format value for bitfield ROMC_ROMPATCHnD_DATAX. */
#define BF_ROMC_ROMPATCHnD_DATAX(v) ((uint32_t)((uint32_t)(v) << BP_ROMC_ROMPATCHnD_DATAX) & BM_ROMC_ROMPATCHnD_DATAX)

/*! @brief Set the DATAX field to a new value. */
#define BW_ROMC_ROMPATCHnD_DATAX(x, n, v) (HW_ROMC_ROMPATCHnD_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_ROMC_ROMPATCHCNTL - ROMC Control Register
 ******************************************************************************/

/*!
 * @brief HW_ROMC_ROMPATCHCNTL - ROMC Control Register (RW)
 *
 * Reset value: 0x08400000U
 *
 * The ROMC control register (ROMC_ROMPATCHCNTL) contains the block disable bit
 * and the data fix enable bits. The block disable bit provides a means to
 * disable the ROMC data fix and opcode patching functions, even when the address
 * comparators are enabled. The External Boot feature is not affected by this bit. The
 * eight data fix enable bits (0 through 7), when set, assign the associated
 * address comparators to data fix operations Bits 27 and 22 always read as 1s.
 */
typedef union _hw_romc_rompatchcntl
{
    uint32_t U;
    struct _hw_romc_rompatchcntl_bitfields
    {
        uint32_t DATAFIX : 8;          /*!< [7:0]  */
        uint32_t RESERVED0 : 21;       /*!< [28:8]  */
        uint32_t DIS : 1;              /*!< [29]  */
        uint32_t RESERVED1 : 2;        /*!< [31:30]  */
    } B;
} hw_romc_rompatchcntl_t;

/*!
 * @name Constants and macros for entire ROMC_ROMPATCHCNTL register
 */
/*@{*/
#define HW_ROMC_ROMPATCHCNTL_ADDR(x) ((uintptr_t)(x) + 0xF4U)

#define HW_ROMC_ROMPATCHCNTL(x)  (*(__IO hw_romc_rompatchcntl_t *) HW_ROMC_ROMPATCHCNTL_ADDR(x))
#define HW_ROMC_ROMPATCHCNTL_RD(x) (HW_ROMC_ROMPATCHCNTL(x).U)
#define HW_ROMC_ROMPATCHCNTL_WR(x, v) (HW_ROMC_ROMPATCHCNTL(x).U = (v))
#define HW_ROMC_ROMPATCHCNTL_SET(x, v) (HW_ROMC_ROMPATCHCNTL_WR(x, HW_ROMC_ROMPATCHCNTL_RD(x) |  (v)))
#define HW_ROMC_ROMPATCHCNTL_CLR(x, v) (HW_ROMC_ROMPATCHCNTL_WR(x, HW_ROMC_ROMPATCHCNTL_RD(x) & ~(v)))
#define HW_ROMC_ROMPATCHCNTL_TOG(x, v) (HW_ROMC_ROMPATCHCNTL_WR(x, HW_ROMC_ROMPATCHCNTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ROMC_ROMPATCHCNTL bitfields
 */

/*!
 * @name Register ROMC_ROMPATCHCNTL, field DATAFIX[7:0] (RW)
 *
 * Data Fix Enable - Controls the use of the first 8 address comparators for
 * 1-word data fix or for code patch routine.
 *
 * Values:
 * - 0 - Address comparator triggers a opcode patch
 * - 1 - Address comparator triggers a data fix
 */
/*@{*/
#define BP_ROMC_ROMPATCHCNTL_DATAFIX (0U)  /*!< Bit position for ROMC_ROMPATCHCNTL_DATAFIX. */
#define BM_ROMC_ROMPATCHCNTL_DATAFIX (0x000000FFU) /*!< Bit mask for ROMC_ROMPATCHCNTL_DATAFIX. */
#define BS_ROMC_ROMPATCHCNTL_DATAFIX (8U)  /*!< Bit field size in bits for ROMC_ROMPATCHCNTL_DATAFIX. */

/*! @brief Read current value of the ROMC_ROMPATCHCNTL_DATAFIX field. */
#define BR_ROMC_ROMPATCHCNTL_DATAFIX(x) (HW_ROMC_ROMPATCHCNTL(x).B.DATAFIX)

/*! @brief Format value for bitfield ROMC_ROMPATCHCNTL_DATAFIX. */
#define BF_ROMC_ROMPATCHCNTL_DATAFIX(v) ((uint32_t)((uint32_t)(v) << BP_ROMC_ROMPATCHCNTL_DATAFIX) & BM_ROMC_ROMPATCHCNTL_DATAFIX)

/*! @brief Set the DATAFIX field to a new value. */
#define BW_ROMC_ROMPATCHCNTL_DATAFIX(x, v) (HW_ROMC_ROMPATCHCNTL_WR(x, (HW_ROMC_ROMPATCHCNTL_RD(x) & ~BM_ROMC_ROMPATCHCNTL_DATAFIX) | BF_ROMC_ROMPATCHCNTL_DATAFIX(v)))
/*@}*/

/*!
 * @name Register ROMC_ROMPATCHCNTL, field DIS[29] (RW)
 *
 * ROMC Disable -- This bit, when set, disables all ROMC operations. This bit is
 * used to enable secure operations.
 *
 * Values:
 * - 0 - Does not affect any ROMC functions (default)
 * - 1 - Disable all ROMC functions: data fixing, and opcode patching
 */
/*@{*/
#define BP_ROMC_ROMPATCHCNTL_DIS (29U)     /*!< Bit position for ROMC_ROMPATCHCNTL_DIS. */
#define BM_ROMC_ROMPATCHCNTL_DIS (0x20000000U) /*!< Bit mask for ROMC_ROMPATCHCNTL_DIS. */
#define BS_ROMC_ROMPATCHCNTL_DIS (1U)      /*!< Bit field size in bits for ROMC_ROMPATCHCNTL_DIS. */

/*! @brief Read current value of the ROMC_ROMPATCHCNTL_DIS field. */
#define BR_ROMC_ROMPATCHCNTL_DIS(x) (HW_ROMC_ROMPATCHCNTL(x).B.DIS)

/*! @brief Format value for bitfield ROMC_ROMPATCHCNTL_DIS. */
#define BF_ROMC_ROMPATCHCNTL_DIS(v) ((uint32_t)((uint32_t)(v) << BP_ROMC_ROMPATCHCNTL_DIS) & BM_ROMC_ROMPATCHCNTL_DIS)

/*! @brief Set the DIS field to a new value. */
#define BW_ROMC_ROMPATCHCNTL_DIS(x, v) (HW_ROMC_ROMPATCHCNTL_WR(x, (HW_ROMC_ROMPATCHCNTL_RD(x) & ~BM_ROMC_ROMPATCHCNTL_DIS) | BF_ROMC_ROMPATCHCNTL_DIS(v)))
/*@}*/

/*******************************************************************************
 * HW_ROMC_ROMPATCHENH - ROMC Enable Register High
 ******************************************************************************/

/*!
 * @brief HW_ROMC_ROMPATCHENH - ROMC Enable Register High (RU)
 *
 * Reset value: 0x00000000U
 *
 * The ROMC enable register high (ROMC_ROMPATCHENH) and ROMC enable register low
 * (ROMC_ROMPATCHENL) control whether or not the associated address comparator
 * can trigger a opcode patch or data fix event. This implementation of the ROMC
 * only has 16 comparators, therefore ROMC_ROMPATCHENH and the upper half of
 * ROMC_OMPATCHENL are read-only. ROMC_ROMPATCHENL[15:0] are associated with
 * comparators 15 through 0. ROMC_ROMPATCHENLH[31:0] would have been associated with
 * comparators 63 through 32.
 */
typedef union _hw_romc_rompatchenh
{
    uint32_t U;
    struct _hw_romc_rompatchenh_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_romc_rompatchenh_t;

/*!
 * @name Constants and macros for entire ROMC_ROMPATCHENH register
 */
/*@{*/
#define HW_ROMC_ROMPATCHENH_ADDR(x) ((uintptr_t)(x) + 0xF8U)
#define HW_ROMC_ROMPATCHENH(x)   (*(__I hw_romc_rompatchenh_t *) HW_ROMC_ROMPATCHENH_ADDR(x))
/*@}*/

/*
 * Constants & macros for individual ROMC_ROMPATCHENH bitfields
 */

/*******************************************************************************
 * HW_ROMC_ROMPATCHENL - ROMC Enable Register Low
 ******************************************************************************/

/*!
 * @brief HW_ROMC_ROMPATCHENL - ROMC Enable Register Low (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ROMC enable register high (ROMC_ROMPATCHENH) and ROMC enable register low
 * (ROMC_ROMPATCHENL) control whether or not the associated address comparator
 * can trigger a opcode patch or data fix event. This implementation of the ROMC
 * only has 16 comparators, therefore ROMC_ROMPATCHENH and the upper half of
 * ROMC_ROMPATCHENL are read-only. ROMC_ROMPATCHENL[15:0] are associated with
 * comparators 15 through 0. ROMC_ROMPATCHENLH[31:0] would have been associated with
 * comparators 63 through 32.
 */
typedef union _hw_romc_rompatchenl
{
    uint32_t U;
    struct _hw_romc_rompatchenl_bitfields
    {
        uint32_t ENABLE : 16;          /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_romc_rompatchenl_t;

/*!
 * @name Constants and macros for entire ROMC_ROMPATCHENL register
 */
/*@{*/
#define HW_ROMC_ROMPATCHENL_ADDR(x) ((uintptr_t)(x) + 0xFCU)

#define HW_ROMC_ROMPATCHENL(x)   (*(__IO hw_romc_rompatchenl_t *) HW_ROMC_ROMPATCHENL_ADDR(x))
#define HW_ROMC_ROMPATCHENL_RD(x) (HW_ROMC_ROMPATCHENL(x).U)
#define HW_ROMC_ROMPATCHENL_WR(x, v) (HW_ROMC_ROMPATCHENL(x).U = (v))
#define HW_ROMC_ROMPATCHENL_SET(x, v) (HW_ROMC_ROMPATCHENL_WR(x, HW_ROMC_ROMPATCHENL_RD(x) |  (v)))
#define HW_ROMC_ROMPATCHENL_CLR(x, v) (HW_ROMC_ROMPATCHENL_WR(x, HW_ROMC_ROMPATCHENL_RD(x) & ~(v)))
#define HW_ROMC_ROMPATCHENL_TOG(x, v) (HW_ROMC_ROMPATCHENL_WR(x, HW_ROMC_ROMPATCHENL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ROMC_ROMPATCHENL bitfields
 */

/*!
 * @name Register ROMC_ROMPATCHENL, field ENABLE[15:0] (RW)
 *
 * Enable Address Comparator - This bit enables the corresponding address
 * comparator to trigger an event.
 *
 * Values:
 * - 0 - Address comparator disabled
 * - 1 - Address comparator enabled, ROMC will trigger a opcode patch or data
 *     fix event upon matching of the associated address
 */
/*@{*/
#define BP_ROMC_ROMPATCHENL_ENABLE (0U)    /*!< Bit position for ROMC_ROMPATCHENL_ENABLE. */
#define BM_ROMC_ROMPATCHENL_ENABLE (0x0000FFFFU) /*!< Bit mask for ROMC_ROMPATCHENL_ENABLE. */
#define BS_ROMC_ROMPATCHENL_ENABLE (16U)   /*!< Bit field size in bits for ROMC_ROMPATCHENL_ENABLE. */

/*! @brief Read current value of the ROMC_ROMPATCHENL_ENABLE field. */
#define BR_ROMC_ROMPATCHENL_ENABLE(x) (HW_ROMC_ROMPATCHENL(x).B.ENABLE)

/*! @brief Format value for bitfield ROMC_ROMPATCHENL_ENABLE. */
#define BF_ROMC_ROMPATCHENL_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_ROMC_ROMPATCHENL_ENABLE) & BM_ROMC_ROMPATCHENL_ENABLE)

/*! @brief Set the ENABLE field to a new value. */
#define BW_ROMC_ROMPATCHENL_ENABLE(x, v) (HW_ROMC_ROMPATCHENL_WR(x, (HW_ROMC_ROMPATCHENL_RD(x) & ~BM_ROMC_ROMPATCHENL_ENABLE) | BF_ROMC_ROMPATCHENL_ENABLE(v)))
/*@}*/

/*******************************************************************************
 * HW_ROMC_ROMPATCHnA - ROMC Address Registers
 ******************************************************************************/

/*!
 * @brief HW_ROMC_ROMPATCHnA - ROMC Address Registers (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ROMC address registers (ROMC_ROMPATCHA0 through ROMC_ROMPATCHA15) store
 * the memory addresses where opcode patching begins and data fixing occurs. The
 * address registers ROMC_ROMPATCHA0 through ROMC_ROMPATCHA15 are each 21 bits
 * wide and dedicated to one 4 Mbyte memory space. Bits 21 through 2 are address
 * bits, to be compared with romc_haddr[21:2] for a match; bit 1 is also an address
 * bit used for half word selection. Bit 0 is the mode bit (set to 1 for THUMB
 * mode). 1-word data fixing can only be used on the first 8 of the address
 * comparators. ROMC_ROMPATCHA0 through ROMC_ROMPATCHA15 are associated each with
 * address comparators 0 through 15.
 */
typedef union _hw_romc_rompatchna
{
    uint32_t U;
    struct _hw_romc_rompatchna_bitfields
    {
        uint32_t THUMBX : 1;           /*!< [0]  */
        uint32_t ADDRX : 22;           /*!< [22:1]  */
        uint32_t RESERVED0 : 9;        /*!< [31:23]  */
    } B;
} hw_romc_rompatchna_t;

/*!
 * @name Constants and macros for entire ROMC_ROMPATCHnA register
 */
/*@{*/
#define HW_ROMC_ROMPATCHnA_COUNT (16U)

#define HW_ROMC_ROMPATCHnA_ADDR(x, n) ((uintptr_t)(x) + 0x100U + (0x4U * (n)))

#define HW_ROMC_ROMPATCHnA(x, n) (*(__IO hw_romc_rompatchna_t *) HW_ROMC_ROMPATCHnA_ADDR(x, n))
#define HW_ROMC_ROMPATCHnA_RD(x, n) (HW_ROMC_ROMPATCHnA(x, n).U)
#define HW_ROMC_ROMPATCHnA_WR(x, n, v) (HW_ROMC_ROMPATCHnA(x, n).U = (v))
#define HW_ROMC_ROMPATCHnA_SET(x, n, v) (HW_ROMC_ROMPATCHnA_WR(x, n, HW_ROMC_ROMPATCHnA_RD(x, n) |  (v)))
#define HW_ROMC_ROMPATCHnA_CLR(x, n, v) (HW_ROMC_ROMPATCHnA_WR(x, n, HW_ROMC_ROMPATCHnA_RD(x, n) & ~(v)))
#define HW_ROMC_ROMPATCHnA_TOG(x, n, v) (HW_ROMC_ROMPATCHnA_WR(x, n, HW_ROMC_ROMPATCHnA_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ROMC_ROMPATCHnA bitfields
 */

/*!
 * @name Register ROMC_ROMPATCHnA, field THUMBX[0] (RW)
 *
 * THUMB Comparator Select - Indicates that this address will trigger a THUMB
 * opcode patch or an ARM opcode patch. If this watchpoint is selected to be a data
 * fix, then this bit is ignored as all data fixes are 1-word data fixes.
 *
 * Values:
 * - 0 - ARM patch
 * - 1 - THUMB patch (ignore if data fix)
 */
/*@{*/
#define BP_ROMC_ROMPATCHnA_THUMBX (0U)     /*!< Bit position for ROMC_ROMPATCHnA_THUMBX. */
#define BM_ROMC_ROMPATCHnA_THUMBX (0x00000001U) /*!< Bit mask for ROMC_ROMPATCHnA_THUMBX. */
#define BS_ROMC_ROMPATCHnA_THUMBX (1U)     /*!< Bit field size in bits for ROMC_ROMPATCHnA_THUMBX. */

/*! @brief Read current value of the ROMC_ROMPATCHnA_THUMBX field. */
#define BR_ROMC_ROMPATCHnA_THUMBX(x, n) (HW_ROMC_ROMPATCHnA(x, n).B.THUMBX)

/*! @brief Format value for bitfield ROMC_ROMPATCHnA_THUMBX. */
#define BF_ROMC_ROMPATCHnA_THUMBX(v) ((uint32_t)((uint32_t)(v) << BP_ROMC_ROMPATCHnA_THUMBX) & BM_ROMC_ROMPATCHnA_THUMBX)

/*! @brief Set the THUMBX field to a new value. */
#define BW_ROMC_ROMPATCHnA_THUMBX(x, n, v) (HW_ROMC_ROMPATCHnA_WR(x, n, (HW_ROMC_ROMPATCHnA_RD(x, n) & ~BM_ROMC_ROMPATCHnA_THUMBX) | BF_ROMC_ROMPATCHnA_THUMBX(v)))
/*@}*/

/*!
 * @name Register ROMC_ROMPATCHnA, field ADDRX[22:1] (RW)
 *
 * Address Comparator Registers - Indicates the memory address to be watched.
 * All 16 registers can be used for code patch address comparison. Only the first 8
 * registers can be used for a 1-word data fix address comparison. Bit 1 is
 * ignored if data fix. Only used in code patch
 */
/*@{*/
#define BP_ROMC_ROMPATCHnA_ADDRX (1U)      /*!< Bit position for ROMC_ROMPATCHnA_ADDRX. */
#define BM_ROMC_ROMPATCHnA_ADDRX (0x007FFFFEU) /*!< Bit mask for ROMC_ROMPATCHnA_ADDRX. */
#define BS_ROMC_ROMPATCHnA_ADDRX (22U)     /*!< Bit field size in bits for ROMC_ROMPATCHnA_ADDRX. */

/*! @brief Read current value of the ROMC_ROMPATCHnA_ADDRX field. */
#define BR_ROMC_ROMPATCHnA_ADDRX(x, n) (HW_ROMC_ROMPATCHnA(x, n).B.ADDRX)

/*! @brief Format value for bitfield ROMC_ROMPATCHnA_ADDRX. */
#define BF_ROMC_ROMPATCHnA_ADDRX(v) ((uint32_t)((uint32_t)(v) << BP_ROMC_ROMPATCHnA_ADDRX) & BM_ROMC_ROMPATCHnA_ADDRX)

/*! @brief Set the ADDRX field to a new value. */
#define BW_ROMC_ROMPATCHnA_ADDRX(x, n, v) (HW_ROMC_ROMPATCHnA_WR(x, n, (HW_ROMC_ROMPATCHnA_RD(x, n) & ~BM_ROMC_ROMPATCHnA_ADDRX) | BF_ROMC_ROMPATCHnA_ADDRX(v)))
/*@}*/

/*******************************************************************************
 * HW_ROMC_ROMPATCHSR - ROMC Status Register
 ******************************************************************************/

/*!
 * @brief HW_ROMC_ROMPATCHSR - ROMC Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The ROMC status register (ROMC_ROMPATCHSR) indicates the current state of the
 * ROMC and the source number of the most recent address comparator event.
 */
typedef union _hw_romc_rompatchsr
{
    uint32_t U;
    struct _hw_romc_rompatchsr_bitfields
    {
        uint32_t SOURCE : 6;           /*!< [5:0]  */
        uint32_t RESERVED0 : 11;       /*!< [16:6]  */
        uint32_t SW : 1;               /*!< [17]  */
        uint32_t RESERVED1 : 14;       /*!< [31:18]  */
    } B;
} hw_romc_rompatchsr_t;

/*!
 * @name Constants and macros for entire ROMC_ROMPATCHSR register
 */
/*@{*/
#define HW_ROMC_ROMPATCHSR_ADDR(x) ((uintptr_t)(x) + 0x208U)

#define HW_ROMC_ROMPATCHSR(x)    (*(__IO hw_romc_rompatchsr_t *) HW_ROMC_ROMPATCHSR_ADDR(x))
#define HW_ROMC_ROMPATCHSR_RD(x) (HW_ROMC_ROMPATCHSR(x).U)
#define HW_ROMC_ROMPATCHSR_WR(x, v) (HW_ROMC_ROMPATCHSR(x).U = (v))
#define HW_ROMC_ROMPATCHSR_SET(x, v) (HW_ROMC_ROMPATCHSR_WR(x, HW_ROMC_ROMPATCHSR_RD(x) |  (v)))
#define HW_ROMC_ROMPATCHSR_CLR(x, v) (HW_ROMC_ROMPATCHSR_WR(x, HW_ROMC_ROMPATCHSR_RD(x) & ~(v)))
#define HW_ROMC_ROMPATCHSR_TOG(x, v) (HW_ROMC_ROMPATCHSR_WR(x, HW_ROMC_ROMPATCHSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual ROMC_ROMPATCHSR bitfields
 */

/*!
 * @name Register ROMC_ROMPATCHSR, field SOURCE[5:0] (RO)
 *
 * ROMC Source Number - Binary encoding of the number of the address comparator
 * which has an address match in the most recent patch event on ROMC AHB. If
 * multiple matches occurred, the highest priority source number is used.
 *
 * Values:
 * - 0 - Address Comparator 0 matched
 * - 1 - Address Comparator 1 matched
 */
/*@{*/
#define BP_ROMC_ROMPATCHSR_SOURCE (0U)     /*!< Bit position for ROMC_ROMPATCHSR_SOURCE. */
#define BM_ROMC_ROMPATCHSR_SOURCE (0x0000003FU) /*!< Bit mask for ROMC_ROMPATCHSR_SOURCE. */
#define BS_ROMC_ROMPATCHSR_SOURCE (6U)     /*!< Bit field size in bits for ROMC_ROMPATCHSR_SOURCE. */

/*! @brief Read current value of the ROMC_ROMPATCHSR_SOURCE field. */
#define BR_ROMC_ROMPATCHSR_SOURCE(x) (HW_ROMC_ROMPATCHSR(x).B.SOURCE)
/*@}*/

/*!
 * @name Register ROMC_ROMPATCHSR, field SW[17] (W1C)
 *
 * ROMC AHB Multiple Address Comparator matches Indicator - Indicates that
 * multiple address comparator matches occurred. Writing a 1 to this bit will clear
 * this it.
 *
 * Values:
 * - 0 - no event or comparator collisions
 * - 1 - a collision has occurred
 */
/*@{*/
#define BP_ROMC_ROMPATCHSR_SW (17U)        /*!< Bit position for ROMC_ROMPATCHSR_SW. */
#define BM_ROMC_ROMPATCHSR_SW (0x00020000U) /*!< Bit mask for ROMC_ROMPATCHSR_SW. */
#define BS_ROMC_ROMPATCHSR_SW (1U)         /*!< Bit field size in bits for ROMC_ROMPATCHSR_SW. */

/*! @brief Read current value of the ROMC_ROMPATCHSR_SW field. */
#define BR_ROMC_ROMPATCHSR_SW(x) (HW_ROMC_ROMPATCHSR(x).B.SW)

/*! @brief Format value for bitfield ROMC_ROMPATCHSR_SW. */
#define BF_ROMC_ROMPATCHSR_SW(v) ((uint32_t)((uint32_t)(v) << BP_ROMC_ROMPATCHSR_SW) & BM_ROMC_ROMPATCHSR_SW)

/*! @brief Set the SW field to a new value. */
#define BW_ROMC_ROMPATCHSR_SW(x, v) (HW_ROMC_ROMPATCHSR_WR(x, (HW_ROMC_ROMPATCHSR_RD(x) & ~BM_ROMC_ROMPATCHSR_SW) | BF_ROMC_ROMPATCHSR_SW(v)))
/*@}*/

/*******************************************************************************
 * hw_romc_t - module struct
 ******************************************************************************/
/*!
 * @brief All ROMC module registers.
 */
#pragma pack(1)
typedef struct _hw_romc
{
    uint8_t _reserved0[212];
    __IO hw_romc_rompatchnd_t ROMPATCHnD[8]; /*!< [0xD4] ROMC Data Registers */
    __IO hw_romc_rompatchcntl_t ROMPATCHCNTL; /*!< [0xF4] ROMC Control Register */
    __I hw_romc_rompatchenh_t ROMPATCHENH; /*!< [0xF8] ROMC Enable Register High */
    __IO hw_romc_rompatchenl_t ROMPATCHENL; /*!< [0xFC] ROMC Enable Register Low */
    __IO hw_romc_rompatchna_t ROMPATCHnA[16]; /*!< [0x100] ROMC Address Registers */
    uint8_t _reserved1[200];
    __IO hw_romc_rompatchsr_t ROMPATCHSR;  /*!< [0x208] ROMC Status Register */
} hw_romc_t;
#pragma pack()

/*! @brief Macro to access all ROMC registers. */
/*! @param x ROMC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_ROMC_REGS(ROMC_BASE)</code>. */
#define HW_ROMC_REGS(x) (*(hw_romc_t *)(x))

/*
 * iMX7D SDMAARM
 *
 * SDMA
 *
 * Registers defined in this header file:
 * - HW_SDMAARM_MC0PTR - ARM platform Channel 0 Pointer
 * - HW_SDMAARM_INTR - Channel Interrupts
 * - HW_SDMAARM_STOP_STAT - Channel Stop/Channel Status
 * - HW_SDMAARM_HSTART - Channel Start
 * - HW_SDMAARM_EVTOVR - Channel Event Override
 * - HW_SDMAARM_DSPOVR - Channel BP Override
 * - HW_SDMAARM_HOSTOVR - Channel ARM platform Override
 * - HW_SDMAARM_EVTPEND - Channel Event Pending
 * - HW_SDMAARM_RESET - Reset Register
 * - HW_SDMAARM_EVTERR - DMA Request Error Register
 * - HW_SDMAARM_INTRMASK - Channel ARM platform Interrupt Mask
 * - HW_SDMAARM_PSW - Schedule Status
 * - HW_SDMAARM_EVTERRDBG - DMA Request Error Register
 * - HW_SDMAARM_CONFIG - Configuration Register
 * - HW_SDMAARM_SDMA_LOCK - SDMA LOCK
 * - HW_SDMAARM_ONCE_ENB - OnCE Enable
 * - HW_SDMAARM_ONCE_DATA - OnCE Data Register
 * - HW_SDMAARM_ONCE_INSTR - OnCE Instruction Register
 * - HW_SDMAARM_ONCE_STAT - OnCE Status Register
 * - HW_SDMAARM_ONCE_CMD - OnCE Command Register
 * - HW_SDMAARM_ILLINSTADDR - Illegal Instruction Trap Address
 * - HW_SDMAARM_CHN0ADDR - Channel 0 Boot Address
 * - HW_SDMAARM_EVT_MIRROR - DMA Requests
 * - HW_SDMAARM_EVT_MIRROR2 - DMA Requests 2
 * - HW_SDMAARM_XTRIG_CONF1 - Cross-Trigger Events Configuration Register 1
 * - HW_SDMAARM_XTRIG_CONF2 - Cross-Trigger Events Configuration Register 2
 * - HW_SDMAARM_SDMA_CHNPRIn - Channel Priority Registers
 * - HW_SDMAARM_CHNENBLn - Channel Enable RAM
 *
 * - hw_sdmaarm_t - Struct containing all module registers.
 */

#define HW_SDMAARM_INSTANCE_COUNT (1U) /*!< Number of instances of the SDMAARM module. */
#define HW_SDMAARM (0U) /*!< Instance number for SDMAARM. */
#define SDMAARM_BASE          (0x30BD0000U) /*!< Base address for SDMAARM. */
/*! Array initializer of SDMAARM base addresses. */
#define SDMAARM_BASE_ADDRS    { SDMAARM_BASE }

/*******************************************************************************
 * HW_SDMAARM_MC0PTR - ARM platform Channel 0 Pointer
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_MC0PTR - ARM platform Channel 0 Pointer (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_mc0ptr
{
    uint32_t U;
    struct _hw_sdmaarm_mc0ptr_bitfields
    {
        uint32_t MC0PTR : 32;          /*!< [31:0]  */
    } B;
} hw_sdmaarm_mc0ptr_t;

/*!
 * @name Constants and macros for entire SDMAARM_MC0PTR register
 */
/*@{*/
#define HW_SDMAARM_MC0PTR_ADDR(x) ((uintptr_t)(x) + 0x0U)

#define HW_SDMAARM_MC0PTR(x)     (*(__IO hw_sdmaarm_mc0ptr_t *) HW_SDMAARM_MC0PTR_ADDR(x))
#define HW_SDMAARM_MC0PTR_RD(x)  (HW_SDMAARM_MC0PTR(x).U)
#define HW_SDMAARM_MC0PTR_WR(x, v) (HW_SDMAARM_MC0PTR(x).U = (v))
#define HW_SDMAARM_MC0PTR_SET(x, v) (HW_SDMAARM_MC0PTR_WR(x, HW_SDMAARM_MC0PTR_RD(x) |  (v)))
#define HW_SDMAARM_MC0PTR_CLR(x, v) (HW_SDMAARM_MC0PTR_WR(x, HW_SDMAARM_MC0PTR_RD(x) & ~(v)))
#define HW_SDMAARM_MC0PTR_TOG(x, v) (HW_SDMAARM_MC0PTR_WR(x, HW_SDMAARM_MC0PTR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_MC0PTR bitfields
 */

/*!
 * @name Register SDMAARM_MC0PTR, field MC0PTR[31:0] (RW)
 *
 * Channel 0 Pointer contains the 32-bit address, in ARM platform memory, of
 * channel 0 control block (the boot channel). Appendix A fully describes the SDMA
 * Application Programming Interface (API). The ARM platform has a read/write
 * access and the SDMA has a read-only access.
 */
/*@{*/
#define BP_SDMAARM_MC0PTR_MC0PTR (0U)      /*!< Bit position for SDMAARM_MC0PTR_MC0PTR. */
#define BM_SDMAARM_MC0PTR_MC0PTR (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_MC0PTR_MC0PTR. */
#define BS_SDMAARM_MC0PTR_MC0PTR (32U)     /*!< Bit field size in bits for SDMAARM_MC0PTR_MC0PTR. */

/*! @brief Read current value of the SDMAARM_MC0PTR_MC0PTR field. */
#define BR_SDMAARM_MC0PTR_MC0PTR(x) (HW_SDMAARM_MC0PTR(x).U)

/*! @brief Format value for bitfield SDMAARM_MC0PTR_MC0PTR. */
#define BF_SDMAARM_MC0PTR_MC0PTR(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_MC0PTR_MC0PTR) & BM_SDMAARM_MC0PTR_MC0PTR)

/*! @brief Set the MC0PTR field to a new value. */
#define BW_SDMAARM_MC0PTR_MC0PTR(x, v) (HW_SDMAARM_MC0PTR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_INTR - Channel Interrupts
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_INTR - Channel Interrupts (W1C)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_intr
{
    uint32_t U;
    struct _hw_sdmaarm_intr_bitfields
    {
        uint32_t HI : 32;              /*!< [31:0]  */
    } B;
} hw_sdmaarm_intr_t;

/*!
 * @name Constants and macros for entire SDMAARM_INTR register
 */
/*@{*/
#define HW_SDMAARM_INTR_ADDR(x)  ((uintptr_t)(x) + 0x4U)

#define HW_SDMAARM_INTR(x)       (*(__IO hw_sdmaarm_intr_t *) HW_SDMAARM_INTR_ADDR(x))
#define HW_SDMAARM_INTR_RD(x)    (HW_SDMAARM_INTR(x).U)
#define HW_SDMAARM_INTR_WR(x, v) (HW_SDMAARM_INTR(x).U = (v))
#define HW_SDMAARM_INTR_SET(x, v) (HW_SDMAARM_INTR_WR(x, HW_SDMAARM_INTR_RD(x) |  (v)))
#define HW_SDMAARM_INTR_CLR(x, v) (HW_SDMAARM_INTR_WR(x, HW_SDMAARM_INTR_RD(x) & ~(v)))
#define HW_SDMAARM_INTR_TOG(x, v) (HW_SDMAARM_INTR_WR(x, HW_SDMAARM_INTR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_INTR bitfields
 */

/*!
 * @name Register SDMAARM_INTR, field HI[31:0] (W1C)
 *
 * The ARM platform Interrupts register contains the 32 HI[i] bits. If any bit
 * is set, it will cause an interrupt to the ARM platform. This register is a
 * "write-ones" register to the ARM platform. When the ARM platform sets a bit in
 * this register the corresponding HI[i] bit is cleared. The interrupt service
 * routine should clear individual channel bits when their interrupts are serviced,
 * failure to do so will cause continuous interrupts. The SDMA is responsible for
 * setting the HI[i] bit corresponding to the current channel when the
 * corresponding done instruction is executed.
 */
/*@{*/
#define BP_SDMAARM_INTR_HI   (0U)          /*!< Bit position for SDMAARM_INTR_HI. */
#define BM_SDMAARM_INTR_HI   (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_INTR_HI. */
#define BS_SDMAARM_INTR_HI   (32U)         /*!< Bit field size in bits for SDMAARM_INTR_HI. */

/*! @brief Read current value of the SDMAARM_INTR_HI field. */
#define BR_SDMAARM_INTR_HI(x) (HW_SDMAARM_INTR(x).U)

/*! @brief Format value for bitfield SDMAARM_INTR_HI. */
#define BF_SDMAARM_INTR_HI(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_INTR_HI) & BM_SDMAARM_INTR_HI)

/*! @brief Set the HI field to a new value. */
#define BW_SDMAARM_INTR_HI(x, v) (HW_SDMAARM_INTR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_STOP_STAT - Channel Stop/Channel Status
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_STOP_STAT - Channel Stop/Channel Status (W1C)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_stop_stat
{
    uint32_t U;
    struct _hw_sdmaarm_stop_stat_bitfields
    {
        uint32_t HE : 32;              /*!< [31:0]  */
    } B;
} hw_sdmaarm_stop_stat_t;

/*!
 * @name Constants and macros for entire SDMAARM_STOP_STAT register
 */
/*@{*/
#define HW_SDMAARM_STOP_STAT_ADDR(x) ((uintptr_t)(x) + 0x8U)

#define HW_SDMAARM_STOP_STAT(x)  (*(__IO hw_sdmaarm_stop_stat_t *) HW_SDMAARM_STOP_STAT_ADDR(x))
#define HW_SDMAARM_STOP_STAT_RD(x) (HW_SDMAARM_STOP_STAT(x).U)
#define HW_SDMAARM_STOP_STAT_WR(x, v) (HW_SDMAARM_STOP_STAT(x).U = (v))
#define HW_SDMAARM_STOP_STAT_SET(x, v) (HW_SDMAARM_STOP_STAT_WR(x, HW_SDMAARM_STOP_STAT_RD(x) |  (v)))
#define HW_SDMAARM_STOP_STAT_CLR(x, v) (HW_SDMAARM_STOP_STAT_WR(x, HW_SDMAARM_STOP_STAT_RD(x) & ~(v)))
#define HW_SDMAARM_STOP_STAT_TOG(x, v) (HW_SDMAARM_STOP_STAT_WR(x, HW_SDMAARM_STOP_STAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_STOP_STAT bitfields
 */

/*!
 * @name Register SDMAARM_STOP_STAT, field HE[31:0] (W1C)
 *
 * This 32-bit register gives access to the ARM platform Enable bits. There is
 * one bit for every channel. This register is a "write-ones" register to the ARM
 * platform. When the ARM platform writes 1 in bit i of this register, it clears
 * the HE[i] and HSTART[i] bits. Reading this register yields the current state
 * of the HE[i] bits.
 */
/*@{*/
#define BP_SDMAARM_STOP_STAT_HE (0U)       /*!< Bit position for SDMAARM_STOP_STAT_HE. */
#define BM_SDMAARM_STOP_STAT_HE (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_STOP_STAT_HE. */
#define BS_SDMAARM_STOP_STAT_HE (32U)      /*!< Bit field size in bits for SDMAARM_STOP_STAT_HE. */

/*! @brief Read current value of the SDMAARM_STOP_STAT_HE field. */
#define BR_SDMAARM_STOP_STAT_HE(x) (HW_SDMAARM_STOP_STAT(x).U)

/*! @brief Format value for bitfield SDMAARM_STOP_STAT_HE. */
#define BF_SDMAARM_STOP_STAT_HE(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_STOP_STAT_HE) & BM_SDMAARM_STOP_STAT_HE)

/*! @brief Set the HE field to a new value. */
#define BW_SDMAARM_STOP_STAT_HE(x, v) (HW_SDMAARM_STOP_STAT_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_HSTART - Channel Start
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_HSTART - Channel Start (W1C)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_hstart
{
    uint32_t U;
    struct _hw_sdmaarm_hstart_bitfields
    {
        uint32_t HSTART_HE : 32;       /*!< [31:0]  */
    } B;
} hw_sdmaarm_hstart_t;

/*!
 * @name Constants and macros for entire SDMAARM_HSTART register
 */
/*@{*/
#define HW_SDMAARM_HSTART_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_SDMAARM_HSTART(x)     (*(__IO hw_sdmaarm_hstart_t *) HW_SDMAARM_HSTART_ADDR(x))
#define HW_SDMAARM_HSTART_RD(x)  (HW_SDMAARM_HSTART(x).U)
#define HW_SDMAARM_HSTART_WR(x, v) (HW_SDMAARM_HSTART(x).U = (v))
#define HW_SDMAARM_HSTART_SET(x, v) (HW_SDMAARM_HSTART_WR(x, HW_SDMAARM_HSTART_RD(x) |  (v)))
#define HW_SDMAARM_HSTART_CLR(x, v) (HW_SDMAARM_HSTART_WR(x, HW_SDMAARM_HSTART_RD(x) & ~(v)))
#define HW_SDMAARM_HSTART_TOG(x, v) (HW_SDMAARM_HSTART_WR(x, HW_SDMAARM_HSTART_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_HSTART bitfields
 */

/*!
 * @name Register SDMAARM_HSTART, field HSTART_HE[31:0] (W1C)
 *
 * The HSTART_HE registers are 32 bits wide with one bit for every channel. When
 * a bit is written to 1, it enables the corresponding channel. Two physical
 * registers are accessed with that address (HSTART and HE), which enables the ARM
 * platform to trigger a channel a second time before the first trigger is
 * processed. This register is a "write-ones" register to the ARM platform. Neither
 * HSTART[i] bit can be set while the corresponding HE[i] bit is cleared. When the
 * ARM platform tries to set the HSTART[i] bit by writing a one (if the
 * corresponding HE[i] bit is clear), the bit in the HSTART[i] register will remain cleared
 * and the HE[i] bit will be set. If the corresponding HE[i] bit was already set,
 * the HSTART[i] bit will be set. The next time the SDMA channel i attempts to
 * clear the HE[i] bit by means of a done instruction, the bit in the HSTART[i]
 * register will be cleared and the HE[i] bit will take the old value of the
 * HSTART[i] bit. Reading this register yields the current state of the HSTART[i] bits.
 * This mechanism enables the ARM platform to pipeline two HSTART commands per
 * channel.
 */
/*@{*/
#define BP_SDMAARM_HSTART_HSTART_HE (0U)   /*!< Bit position for SDMAARM_HSTART_HSTART_HE. */
#define BM_SDMAARM_HSTART_HSTART_HE (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_HSTART_HSTART_HE. */
#define BS_SDMAARM_HSTART_HSTART_HE (32U)  /*!< Bit field size in bits for SDMAARM_HSTART_HSTART_HE. */

/*! @brief Read current value of the SDMAARM_HSTART_HSTART_HE field. */
#define BR_SDMAARM_HSTART_HSTART_HE(x) (HW_SDMAARM_HSTART(x).U)

/*! @brief Format value for bitfield SDMAARM_HSTART_HSTART_HE. */
#define BF_SDMAARM_HSTART_HSTART_HE(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_HSTART_HSTART_HE) & BM_SDMAARM_HSTART_HSTART_HE)

/*! @brief Set the HSTART_HE field to a new value. */
#define BW_SDMAARM_HSTART_HSTART_HE(x, v) (HW_SDMAARM_HSTART_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_EVTOVR - Channel Event Override
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_EVTOVR - Channel Event Override (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_evtovr
{
    uint32_t U;
    struct _hw_sdmaarm_evtovr_bitfields
    {
        uint32_t EO : 32;              /*!< [31:0]  */
    } B;
} hw_sdmaarm_evtovr_t;

/*!
 * @name Constants and macros for entire SDMAARM_EVTOVR register
 */
/*@{*/
#define HW_SDMAARM_EVTOVR_ADDR(x) ((uintptr_t)(x) + 0x10U)

#define HW_SDMAARM_EVTOVR(x)     (*(__IO hw_sdmaarm_evtovr_t *) HW_SDMAARM_EVTOVR_ADDR(x))
#define HW_SDMAARM_EVTOVR_RD(x)  (HW_SDMAARM_EVTOVR(x).U)
#define HW_SDMAARM_EVTOVR_WR(x, v) (HW_SDMAARM_EVTOVR(x).U = (v))
#define HW_SDMAARM_EVTOVR_SET(x, v) (HW_SDMAARM_EVTOVR_WR(x, HW_SDMAARM_EVTOVR_RD(x) |  (v)))
#define HW_SDMAARM_EVTOVR_CLR(x, v) (HW_SDMAARM_EVTOVR_WR(x, HW_SDMAARM_EVTOVR_RD(x) & ~(v)))
#define HW_SDMAARM_EVTOVR_TOG(x, v) (HW_SDMAARM_EVTOVR_WR(x, HW_SDMAARM_EVTOVR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_EVTOVR bitfields
 */

/*!
 * @name Register SDMAARM_EVTOVR, field EO[31:0] (RW)
 *
 * The Channel Event Override register contains the 32 EO[i] bits. A bit set in
 * this register causes the SDMA to ignore DMA requests when scheduling the
 * corresponding channel.
 */
/*@{*/
#define BP_SDMAARM_EVTOVR_EO (0U)          /*!< Bit position for SDMAARM_EVTOVR_EO. */
#define BM_SDMAARM_EVTOVR_EO (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_EVTOVR_EO. */
#define BS_SDMAARM_EVTOVR_EO (32U)         /*!< Bit field size in bits for SDMAARM_EVTOVR_EO. */

/*! @brief Read current value of the SDMAARM_EVTOVR_EO field. */
#define BR_SDMAARM_EVTOVR_EO(x) (HW_SDMAARM_EVTOVR(x).U)

/*! @brief Format value for bitfield SDMAARM_EVTOVR_EO. */
#define BF_SDMAARM_EVTOVR_EO(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_EVTOVR_EO) & BM_SDMAARM_EVTOVR_EO)

/*! @brief Set the EO field to a new value. */
#define BW_SDMAARM_EVTOVR_EO(x, v) (HW_SDMAARM_EVTOVR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_DSPOVR - Channel BP Override
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_DSPOVR - Channel BP Override (RW)
 *
 * Reset value: 0xFFFFFFFFU
 */
typedef union _hw_sdmaarm_dspovr
{
    uint32_t U;
    struct _hw_sdmaarm_dspovr_bitfields
    {
        uint32_t DO : 32;              /*!< [31:0]  */
    } B;
} hw_sdmaarm_dspovr_t;

/*!
 * @name Constants and macros for entire SDMAARM_DSPOVR register
 */
/*@{*/
#define HW_SDMAARM_DSPOVR_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_SDMAARM_DSPOVR(x)     (*(__IO hw_sdmaarm_dspovr_t *) HW_SDMAARM_DSPOVR_ADDR(x))
#define HW_SDMAARM_DSPOVR_RD(x)  (HW_SDMAARM_DSPOVR(x).U)
#define HW_SDMAARM_DSPOVR_WR(x, v) (HW_SDMAARM_DSPOVR(x).U = (v))
#define HW_SDMAARM_DSPOVR_SET(x, v) (HW_SDMAARM_DSPOVR_WR(x, HW_SDMAARM_DSPOVR_RD(x) |  (v)))
#define HW_SDMAARM_DSPOVR_CLR(x, v) (HW_SDMAARM_DSPOVR_WR(x, HW_SDMAARM_DSPOVR_RD(x) & ~(v)))
#define HW_SDMAARM_DSPOVR_TOG(x, v) (HW_SDMAARM_DSPOVR_WR(x, HW_SDMAARM_DSPOVR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_DSPOVR bitfields
 */

/*!
 * @name Register SDMAARM_DSPOVR, field DO[31:0] (RW)
 *
 * This register is reserved. All DO bits should be set to the reset value of 1.
 * A setting of 0 will prevent SDMA channels from starting according to the
 * condition described in Runnable Channels EvaluationThe EP register is used in
 * conjunction with several other 32-bit registers to determine the channels that are
 * runnable. .
 *
 * Values:
 * - 0 - - Reserved
 * - 1 - - Reset value.
 */
/*@{*/
#define BP_SDMAARM_DSPOVR_DO (0U)          /*!< Bit position for SDMAARM_DSPOVR_DO. */
#define BM_SDMAARM_DSPOVR_DO (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_DSPOVR_DO. */
#define BS_SDMAARM_DSPOVR_DO (32U)         /*!< Bit field size in bits for SDMAARM_DSPOVR_DO. */

/*! @brief Read current value of the SDMAARM_DSPOVR_DO field. */
#define BR_SDMAARM_DSPOVR_DO(x) (HW_SDMAARM_DSPOVR(x).U)

/*! @brief Format value for bitfield SDMAARM_DSPOVR_DO. */
#define BF_SDMAARM_DSPOVR_DO(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_DSPOVR_DO) & BM_SDMAARM_DSPOVR_DO)

/*! @brief Set the DO field to a new value. */
#define BW_SDMAARM_DSPOVR_DO(x, v) (HW_SDMAARM_DSPOVR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_HOSTOVR - Channel ARM platform Override
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_HOSTOVR - Channel ARM platform Override (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_hostovr
{
    uint32_t U;
    struct _hw_sdmaarm_hostovr_bitfields
    {
        uint32_t HO : 32;              /*!< [31:0]  */
    } B;
} hw_sdmaarm_hostovr_t;

/*!
 * @name Constants and macros for entire SDMAARM_HOSTOVR register
 */
/*@{*/
#define HW_SDMAARM_HOSTOVR_ADDR(x) ((uintptr_t)(x) + 0x18U)

#define HW_SDMAARM_HOSTOVR(x)    (*(__IO hw_sdmaarm_hostovr_t *) HW_SDMAARM_HOSTOVR_ADDR(x))
#define HW_SDMAARM_HOSTOVR_RD(x) (HW_SDMAARM_HOSTOVR(x).U)
#define HW_SDMAARM_HOSTOVR_WR(x, v) (HW_SDMAARM_HOSTOVR(x).U = (v))
#define HW_SDMAARM_HOSTOVR_SET(x, v) (HW_SDMAARM_HOSTOVR_WR(x, HW_SDMAARM_HOSTOVR_RD(x) |  (v)))
#define HW_SDMAARM_HOSTOVR_CLR(x, v) (HW_SDMAARM_HOSTOVR_WR(x, HW_SDMAARM_HOSTOVR_RD(x) & ~(v)))
#define HW_SDMAARM_HOSTOVR_TOG(x, v) (HW_SDMAARM_HOSTOVR_WR(x, HW_SDMAARM_HOSTOVR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_HOSTOVR bitfields
 */

/*!
 * @name Register SDMAARM_HOSTOVR, field HO[31:0] (RW)
 *
 * The Channel ARM platform Override register contains the 32 HO[i] bits. A bit
 * set in this register causes the SDMA to ignore the ARM platform enable bit
 * (HE) when scheduling the corresponding channel.
 */
/*@{*/
#define BP_SDMAARM_HOSTOVR_HO (0U)         /*!< Bit position for SDMAARM_HOSTOVR_HO. */
#define BM_SDMAARM_HOSTOVR_HO (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_HOSTOVR_HO. */
#define BS_SDMAARM_HOSTOVR_HO (32U)        /*!< Bit field size in bits for SDMAARM_HOSTOVR_HO. */

/*! @brief Read current value of the SDMAARM_HOSTOVR_HO field. */
#define BR_SDMAARM_HOSTOVR_HO(x) (HW_SDMAARM_HOSTOVR(x).U)

/*! @brief Format value for bitfield SDMAARM_HOSTOVR_HO. */
#define BF_SDMAARM_HOSTOVR_HO(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_HOSTOVR_HO) & BM_SDMAARM_HOSTOVR_HO)

/*! @brief Set the HO field to a new value. */
#define BW_SDMAARM_HOSTOVR_HO(x, v) (HW_SDMAARM_HOSTOVR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_EVTPEND - Channel Event Pending
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_EVTPEND - Channel Event Pending (W1C)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_evtpend
{
    uint32_t U;
    struct _hw_sdmaarm_evtpend_bitfields
    {
        uint32_t EP : 32;              /*!< [31:0]  */
    } B;
} hw_sdmaarm_evtpend_t;

/*!
 * @name Constants and macros for entire SDMAARM_EVTPEND register
 */
/*@{*/
#define HW_SDMAARM_EVTPEND_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_SDMAARM_EVTPEND(x)    (*(__IO hw_sdmaarm_evtpend_t *) HW_SDMAARM_EVTPEND_ADDR(x))
#define HW_SDMAARM_EVTPEND_RD(x) (HW_SDMAARM_EVTPEND(x).U)
#define HW_SDMAARM_EVTPEND_WR(x, v) (HW_SDMAARM_EVTPEND(x).U = (v))
#define HW_SDMAARM_EVTPEND_SET(x, v) (HW_SDMAARM_EVTPEND_WR(x, HW_SDMAARM_EVTPEND_RD(x) |  (v)))
#define HW_SDMAARM_EVTPEND_CLR(x, v) (HW_SDMAARM_EVTPEND_WR(x, HW_SDMAARM_EVTPEND_RD(x) & ~(v)))
#define HW_SDMAARM_EVTPEND_TOG(x, v) (HW_SDMAARM_EVTPEND_WR(x, HW_SDMAARM_EVTPEND_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_EVTPEND bitfields
 */

/*!
 * @name Register SDMAARM_EVTPEND, field EP[31:0] (W1C)
 *
 * The Channel Event Pending register contains the 32 EP[i] bits. Reading this
 * register enables the ARM platform to determine what channels are pending after
 * the reception of a DMA request. Setting a bit in this register causes the SDMA
 * to reevaluate scheduling as if a DMA request mapped on this channel had
 * occurred. This is useful for starting up channels, so that initialization is done
 * before awaiting the first request. The scheduler can also set bits in the
 * EVTPEND register according to the received DMA requests. The EP[i] bit may be
 * cleared by the done instruction when running the channel i script. This a
 * "write-ones" mechanism: Writing a '0' does not clear the corresponding bit.
 */
/*@{*/
#define BP_SDMAARM_EVTPEND_EP (0U)         /*!< Bit position for SDMAARM_EVTPEND_EP. */
#define BM_SDMAARM_EVTPEND_EP (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_EVTPEND_EP. */
#define BS_SDMAARM_EVTPEND_EP (32U)        /*!< Bit field size in bits for SDMAARM_EVTPEND_EP. */

/*! @brief Read current value of the SDMAARM_EVTPEND_EP field. */
#define BR_SDMAARM_EVTPEND_EP(x) (HW_SDMAARM_EVTPEND(x).U)

/*! @brief Format value for bitfield SDMAARM_EVTPEND_EP. */
#define BF_SDMAARM_EVTPEND_EP(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_EVTPEND_EP) & BM_SDMAARM_EVTPEND_EP)

/*! @brief Set the EP field to a new value. */
#define BW_SDMAARM_EVTPEND_EP(x, v) (HW_SDMAARM_EVTPEND_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_RESET - Reset Register
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_RESET - Reset Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_reset
{
    uint32_t U;
    struct _hw_sdmaarm_reset_bitfields
    {
        uint32_t RESET : 1;            /*!< [0]  */
        uint32_t RESCHED : 1;          /*!< [1]  */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_sdmaarm_reset_t;

/*!
 * @name Constants and macros for entire SDMAARM_RESET register
 */
/*@{*/
#define HW_SDMAARM_RESET_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_SDMAARM_RESET(x)      (*(__I hw_sdmaarm_reset_t *) HW_SDMAARM_RESET_ADDR(x))
#define HW_SDMAARM_RESET_RD(x)   (HW_SDMAARM_RESET(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMAARM_RESET bitfields
 */

/*!
 * @name Register SDMAARM_RESET, field RESET[0] (RO)
 *
 * When set, this bit causes the SDMA to be held in a software reset. The
 * internal reset signal is held low 16 cycles; the RESET bit is automatically cleared
 * when the internal reset signal rises.
 */
/*@{*/
#define BP_SDMAARM_RESET_RESET (0U)        /*!< Bit position for SDMAARM_RESET_RESET. */
#define BM_SDMAARM_RESET_RESET (0x00000001U) /*!< Bit mask for SDMAARM_RESET_RESET. */
#define BS_SDMAARM_RESET_RESET (1U)        /*!< Bit field size in bits for SDMAARM_RESET_RESET. */

/*! @brief Read current value of the SDMAARM_RESET_RESET field. */
#define BR_SDMAARM_RESET_RESET(x) (HW_SDMAARM_RESET(x).B.RESET)
/*@}*/

/*!
 * @name Register SDMAARM_RESET, field RESCHED[1] (RO)
 *
 * When set, this bit forces the SDMA to reschedule as if a script had executed
 * a done instruction. This enables the ARM platform to recover from a runaway
 * script on a channel by clearing its HE[i] bit via the STOP register, and then
 * forcing a reschedule via the RESCHED bit. The RESCHED bit is cleared when the
 * context switch starts.
 */
/*@{*/
#define BP_SDMAARM_RESET_RESCHED (1U)      /*!< Bit position for SDMAARM_RESET_RESCHED. */
#define BM_SDMAARM_RESET_RESCHED (0x00000002U) /*!< Bit mask for SDMAARM_RESET_RESCHED. */
#define BS_SDMAARM_RESET_RESCHED (1U)      /*!< Bit field size in bits for SDMAARM_RESET_RESCHED. */

/*! @brief Read current value of the SDMAARM_RESET_RESCHED field. */
#define BR_SDMAARM_RESET_RESCHED(x) (HW_SDMAARM_RESET(x).B.RESCHED)
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_EVTERR - DMA Request Error Register
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_EVTERR - DMA Request Error Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_evterr
{
    uint32_t U;
    struct _hw_sdmaarm_evterr_bitfields
    {
        uint32_t CHNERR : 32;          /*!< [31:0]  */
    } B;
} hw_sdmaarm_evterr_t;

/*!
 * @name Constants and macros for entire SDMAARM_EVTERR register
 */
/*@{*/
#define HW_SDMAARM_EVTERR_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_SDMAARM_EVTERR(x)     (*(__I hw_sdmaarm_evterr_t *) HW_SDMAARM_EVTERR_ADDR(x))
#define HW_SDMAARM_EVTERR_RD(x)  (HW_SDMAARM_EVTERR(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMAARM_EVTERR bitfields
 */

/*!
 * @name Register SDMAARM_EVTERR, field CHNERR[31:0] (RO)
 *
 * This register is used by the SDMA to warn the ARM platform when an incoming
 * DMA request was detected and it triggers a channel that is already pending or
 * being serviced. This probably means there is an overflow of data for that
 * channel. An interrupt is sent to the ARM platform if the corresponding channel bit
 * is set in the INTRMASK register. This is a "write-ones" register for the
 * scheduler. It is only able to set the flags. The flags are cleared when the
 * register is read by the ARM platform or during SDMA reset. The CHNERR[i] bit is set
 * when a DMA request that triggers channel i is received through the
 * corresponding input pins and the EP[i] bit is already set; the EVTERR[i] bit is unaffected
 * if the ARM platform tries to set the EP[i] bit, whereas, that EP[i] bit is
 * already set.
 */
/*@{*/
#define BP_SDMAARM_EVTERR_CHNERR (0U)      /*!< Bit position for SDMAARM_EVTERR_CHNERR. */
#define BM_SDMAARM_EVTERR_CHNERR (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_EVTERR_CHNERR. */
#define BS_SDMAARM_EVTERR_CHNERR (32U)     /*!< Bit field size in bits for SDMAARM_EVTERR_CHNERR. */

/*! @brief Read current value of the SDMAARM_EVTERR_CHNERR field. */
#define BR_SDMAARM_EVTERR_CHNERR(x) (HW_SDMAARM_EVTERR(x).U)
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_INTRMASK - Channel ARM platform Interrupt Mask
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_INTRMASK - Channel ARM platform Interrupt Mask (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_intrmask
{
    uint32_t U;
    struct _hw_sdmaarm_intrmask_bitfields
    {
        uint32_t HIMASK : 32;          /*!< [31:0]  */
    } B;
} hw_sdmaarm_intrmask_t;

/*!
 * @name Constants and macros for entire SDMAARM_INTRMASK register
 */
/*@{*/
#define HW_SDMAARM_INTRMASK_ADDR(x) ((uintptr_t)(x) + 0x2CU)

#define HW_SDMAARM_INTRMASK(x)   (*(__IO hw_sdmaarm_intrmask_t *) HW_SDMAARM_INTRMASK_ADDR(x))
#define HW_SDMAARM_INTRMASK_RD(x) (HW_SDMAARM_INTRMASK(x).U)
#define HW_SDMAARM_INTRMASK_WR(x, v) (HW_SDMAARM_INTRMASK(x).U = (v))
#define HW_SDMAARM_INTRMASK_SET(x, v) (HW_SDMAARM_INTRMASK_WR(x, HW_SDMAARM_INTRMASK_RD(x) |  (v)))
#define HW_SDMAARM_INTRMASK_CLR(x, v) (HW_SDMAARM_INTRMASK_WR(x, HW_SDMAARM_INTRMASK_RD(x) & ~(v)))
#define HW_SDMAARM_INTRMASK_TOG(x, v) (HW_SDMAARM_INTRMASK_WR(x, HW_SDMAARM_INTRMASK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_INTRMASK bitfields
 */

/*!
 * @name Register SDMAARM_INTRMASK, field HIMASK[31:0] (RW)
 *
 * The Interrupt Mask Register contains 32 interrupt generation mask bits. If
 * bit HIMASK[i] is set, the HI[i] bit is set and an interrupt is sent to the ARM
 * platform when a DMA request error is detected on channel i (for example,
 * EVTERR[i] is set).
 */
/*@{*/
#define BP_SDMAARM_INTRMASK_HIMASK (0U)    /*!< Bit position for SDMAARM_INTRMASK_HIMASK. */
#define BM_SDMAARM_INTRMASK_HIMASK (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_INTRMASK_HIMASK. */
#define BS_SDMAARM_INTRMASK_HIMASK (32U)   /*!< Bit field size in bits for SDMAARM_INTRMASK_HIMASK. */

/*! @brief Read current value of the SDMAARM_INTRMASK_HIMASK field. */
#define BR_SDMAARM_INTRMASK_HIMASK(x) (HW_SDMAARM_INTRMASK(x).U)

/*! @brief Format value for bitfield SDMAARM_INTRMASK_HIMASK. */
#define BF_SDMAARM_INTRMASK_HIMASK(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_INTRMASK_HIMASK) & BM_SDMAARM_INTRMASK_HIMASK)

/*! @brief Set the HIMASK field to a new value. */
#define BW_SDMAARM_INTRMASK_HIMASK(x, v) (HW_SDMAARM_INTRMASK_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_PSW - Schedule Status
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_PSW - Schedule Status (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_psw
{
    uint32_t U;
    struct _hw_sdmaarm_psw_bitfields
    {
        uint32_t CCR : 4;              /*!< [3:0]  */
        uint32_t CCP : 4;              /*!< [7:4]  */
        uint32_t NCR : 5;              /*!< [12:8]  */
        uint32_t NCP : 3;              /*!< [15:13]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmaarm_psw_t;

/*!
 * @name Constants and macros for entire SDMAARM_PSW register
 */
/*@{*/
#define HW_SDMAARM_PSW_ADDR(x)   ((uintptr_t)(x) + 0x30U)

#define HW_SDMAARM_PSW(x)        (*(__I hw_sdmaarm_psw_t *) HW_SDMAARM_PSW_ADDR(x))
#define HW_SDMAARM_PSW_RD(x)     (HW_SDMAARM_PSW(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMAARM_PSW bitfields
 */

/*!
 * @name Register SDMAARM_PSW, field CCR[3:0] (RO)
 *
 * The Current Channel Register indicates the number of the channel that is
 * being executed by the SDMA. SDMA. In the case that the SDMA has finished running
 * the channel and has entered sleep state, CCR will indicate the previous running
 * channel.
 */
/*@{*/
#define BP_SDMAARM_PSW_CCR   (0U)          /*!< Bit position for SDMAARM_PSW_CCR. */
#define BM_SDMAARM_PSW_CCR   (0x0000000FU) /*!< Bit mask for SDMAARM_PSW_CCR. */
#define BS_SDMAARM_PSW_CCR   (4U)          /*!< Bit field size in bits for SDMAARM_PSW_CCR. */

/*! @brief Read current value of the SDMAARM_PSW_CCR field. */
#define BR_SDMAARM_PSW_CCR(x) (HW_SDMAARM_PSW(x).B.CCR)
/*@}*/

/*!
 * @name Register SDMAARM_PSW, field CCP[7:4] (RO)
 *
 * The Current Channel Priority indicates the priority of the current active
 * channel. When the priority is 0, no channel is running: The SDMA is idle and the
 * CCR value has no meaning. In the case that the SDMA has finished running the
 * channel and has entered sleep state, CCP will indicate the priority of previous
 * running channel.
 *
 * Values:
 * - 0 - No running channel
 * - 1 - Active channel priority
 */
/*@{*/
#define BP_SDMAARM_PSW_CCP   (4U)          /*!< Bit position for SDMAARM_PSW_CCP. */
#define BM_SDMAARM_PSW_CCP   (0x000000F0U) /*!< Bit mask for SDMAARM_PSW_CCP. */
#define BS_SDMAARM_PSW_CCP   (4U)          /*!< Bit field size in bits for SDMAARM_PSW_CCP. */

/*! @brief Read current value of the SDMAARM_PSW_CCP field. */
#define BR_SDMAARM_PSW_CCP(x) (HW_SDMAARM_PSW(x).B.CCP)
/*@}*/

/*!
 * @name Register SDMAARM_PSW, field NCR[12:8] (RO)
 *
 * The Next Channel Register indicates the number of the next scheduled pending
 * channel with the highest priority.
 */
/*@{*/
#define BP_SDMAARM_PSW_NCR   (8U)          /*!< Bit position for SDMAARM_PSW_NCR. */
#define BM_SDMAARM_PSW_NCR   (0x00001F00U) /*!< Bit mask for SDMAARM_PSW_NCR. */
#define BS_SDMAARM_PSW_NCR   (5U)          /*!< Bit field size in bits for SDMAARM_PSW_NCR. */

/*! @brief Read current value of the SDMAARM_PSW_NCR field. */
#define BR_SDMAARM_PSW_NCR(x) (HW_SDMAARM_PSW(x).B.NCR)
/*@}*/

/*!
 * @name Register SDMAARM_PSW, field NCP[15:13] (RO)
 *
 * The Next Channel Priority gives the next pending channel priority. When the
 * priority is 0, it means there is no pending channel and the NCR value has no
 * meaning.
 *
 * Values:
 * - 0 - No running channel
 * - 1 - Active channel priority
 */
/*@{*/
#define BP_SDMAARM_PSW_NCP   (13U)         /*!< Bit position for SDMAARM_PSW_NCP. */
#define BM_SDMAARM_PSW_NCP   (0x0000E000U) /*!< Bit mask for SDMAARM_PSW_NCP. */
#define BS_SDMAARM_PSW_NCP   (3U)          /*!< Bit field size in bits for SDMAARM_PSW_NCP. */

/*! @brief Read current value of the SDMAARM_PSW_NCP field. */
#define BR_SDMAARM_PSW_NCP(x) (HW_SDMAARM_PSW(x).B.NCP)
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_EVTERRDBG - DMA Request Error Register
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_EVTERRDBG - DMA Request Error Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_evterrdbg
{
    uint32_t U;
    struct _hw_sdmaarm_evterrdbg_bitfields
    {
        uint32_t CHNERR : 32;          /*!< [31:0]  */
    } B;
} hw_sdmaarm_evterrdbg_t;

/*!
 * @name Constants and macros for entire SDMAARM_EVTERRDBG register
 */
/*@{*/
#define HW_SDMAARM_EVTERRDBG_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_SDMAARM_EVTERRDBG(x)  (*(__I hw_sdmaarm_evterrdbg_t *) HW_SDMAARM_EVTERRDBG_ADDR(x))
#define HW_SDMAARM_EVTERRDBG_RD(x) (HW_SDMAARM_EVTERRDBG(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMAARM_EVTERRDBG bitfields
 */

/*!
 * @name Register SDMAARM_EVTERRDBG, field CHNERR[31:0] (RO)
 *
 * This register is the same as EVTERR, except reading it does not clear its
 * contents. This address is meant to be used in debug mode. The ARM platform OnCE
 * may check this register value without modifying it.
 */
/*@{*/
#define BP_SDMAARM_EVTERRDBG_CHNERR (0U)   /*!< Bit position for SDMAARM_EVTERRDBG_CHNERR. */
#define BM_SDMAARM_EVTERRDBG_CHNERR (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_EVTERRDBG_CHNERR. */
#define BS_SDMAARM_EVTERRDBG_CHNERR (32U)  /*!< Bit field size in bits for SDMAARM_EVTERRDBG_CHNERR. */

/*! @brief Read current value of the SDMAARM_EVTERRDBG_CHNERR field. */
#define BR_SDMAARM_EVTERRDBG_CHNERR(x) (HW_SDMAARM_EVTERRDBG(x).U)
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_CONFIG - Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_CONFIG - Configuration Register (RW)
 *
 * Reset value: 0x00000003U
 */
typedef union _hw_sdmaarm_config
{
    uint32_t U;
    struct _hw_sdmaarm_config_bitfields
    {
        uint32_t CSM : 2;              /*!< [1:0]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t ACR : 1;              /*!< [4]  */
        uint32_t RESERVED1 : 6;        /*!< [10:5]  */
        uint32_t RTDOBS : 1;           /*!< [11]  */
        uint32_t DSPDMA : 1;           /*!< [12]  */
        uint32_t RESERVED2 : 19;       /*!< [31:13]  */
    } B;
} hw_sdmaarm_config_t;

/*!
 * @name Constants and macros for entire SDMAARM_CONFIG register
 */
/*@{*/
#define HW_SDMAARM_CONFIG_ADDR(x) ((uintptr_t)(x) + 0x38U)

#define HW_SDMAARM_CONFIG(x)     (*(__IO hw_sdmaarm_config_t *) HW_SDMAARM_CONFIG_ADDR(x))
#define HW_SDMAARM_CONFIG_RD(x)  (HW_SDMAARM_CONFIG(x).U)
#define HW_SDMAARM_CONFIG_WR(x, v) (HW_SDMAARM_CONFIG(x).U = (v))
#define HW_SDMAARM_CONFIG_SET(x, v) (HW_SDMAARM_CONFIG_WR(x, HW_SDMAARM_CONFIG_RD(x) |  (v)))
#define HW_SDMAARM_CONFIG_CLR(x, v) (HW_SDMAARM_CONFIG_WR(x, HW_SDMAARM_CONFIG_RD(x) & ~(v)))
#define HW_SDMAARM_CONFIG_TOG(x, v) (HW_SDMAARM_CONFIG_WR(x, HW_SDMAARM_CONFIG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_CONFIG bitfields
 */

/*!
 * @name Register SDMAARM_CONFIG, field CSM[1:0] (RW)
 *
 * Selects the Context Switch Mode. The ARM platform has a read/write access.
 * The SDMA cannot modify that register. The value at reset is 3, which selects the
 * dynamic context switch by default. That register can be modified at anytime
 * but the new context switch configuration will only be taken into account at the
 * start of the next restore phase. NOTE: The first call to SDMA's channel 0
 * Bootload script after reset should use static context switch mode to ensure the
 * context RAM for channel 0 is initialized in the channel SAVE Phase. After
 * Channel 0 is run once, then any of the dynamic context modes can be used.
 *
 * Values:
 * - 0 - static
 * - 1 - dynamic low power
 */
/*@{*/
#define BP_SDMAARM_CONFIG_CSM (0U)         /*!< Bit position for SDMAARM_CONFIG_CSM. */
#define BM_SDMAARM_CONFIG_CSM (0x00000003U) /*!< Bit mask for SDMAARM_CONFIG_CSM. */
#define BS_SDMAARM_CONFIG_CSM (2U)         /*!< Bit field size in bits for SDMAARM_CONFIG_CSM. */

/*! @brief Read current value of the SDMAARM_CONFIG_CSM field. */
#define BR_SDMAARM_CONFIG_CSM(x) (HW_SDMAARM_CONFIG(x).B.CSM)

/*! @brief Format value for bitfield SDMAARM_CONFIG_CSM. */
#define BF_SDMAARM_CONFIG_CSM(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_CONFIG_CSM) & BM_SDMAARM_CONFIG_CSM)

/*! @brief Set the CSM field to a new value. */
#define BW_SDMAARM_CONFIG_CSM(x, v) (HW_SDMAARM_CONFIG_WR(x, (HW_SDMAARM_CONFIG_RD(x) & ~BM_SDMAARM_CONFIG_CSM) | BF_SDMAARM_CONFIG_CSM(v)))
/*@}*/

/*!
 * @name Register SDMAARM_CONFIG, field ACR[4] (RW)
 *
 * ARM platform DMA / SDMA Core Clock Ratio. Selects the clock ratio between ARM
 * platform DMA interfaces (burst DMA and peripheral DMA) and the internal SDMA
 * core clock. The frequency selection is determined separately by the chip clock
 * controller. This bit has to match the configuration of the chip clock
 * controller that generates the clocks used in the SDMA.
 *
 * Values:
 * - 0 - ARM platform DMA interface frequency equals twice core frequency
 * - 1 - ARM platform DMA interface frequency equals core frequency
 */
/*@{*/
#define BP_SDMAARM_CONFIG_ACR (4U)         /*!< Bit position for SDMAARM_CONFIG_ACR. */
#define BM_SDMAARM_CONFIG_ACR (0x00000010U) /*!< Bit mask for SDMAARM_CONFIG_ACR. */
#define BS_SDMAARM_CONFIG_ACR (1U)         /*!< Bit field size in bits for SDMAARM_CONFIG_ACR. */

/*! @brief Read current value of the SDMAARM_CONFIG_ACR field. */
#define BR_SDMAARM_CONFIG_ACR(x) (HW_SDMAARM_CONFIG(x).B.ACR)

/*! @brief Format value for bitfield SDMAARM_CONFIG_ACR. */
#define BF_SDMAARM_CONFIG_ACR(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_CONFIG_ACR) & BM_SDMAARM_CONFIG_ACR)

/*! @brief Set the ACR field to a new value. */
#define BW_SDMAARM_CONFIG_ACR(x, v) (HW_SDMAARM_CONFIG_WR(x, (HW_SDMAARM_CONFIG_RD(x) & ~BM_SDMAARM_CONFIG_ACR) | BF_SDMAARM_CONFIG_ACR(v)))
/*@}*/

/*!
 * @name Register SDMAARM_CONFIG, field RTDOBS[11] (RW)
 *
 * Indicates if Real-Time Debug pins are used: They do not toggle by default in
 * order to reduce power consumption.
 *
 * Values:
 * - 0 - RTD pins disabled
 * - 1 - RTD pins enabled
 */
/*@{*/
#define BP_SDMAARM_CONFIG_RTDOBS (11U)     /*!< Bit position for SDMAARM_CONFIG_RTDOBS. */
#define BM_SDMAARM_CONFIG_RTDOBS (0x00000800U) /*!< Bit mask for SDMAARM_CONFIG_RTDOBS. */
#define BS_SDMAARM_CONFIG_RTDOBS (1U)      /*!< Bit field size in bits for SDMAARM_CONFIG_RTDOBS. */

/*! @brief Read current value of the SDMAARM_CONFIG_RTDOBS field. */
#define BR_SDMAARM_CONFIG_RTDOBS(x) (HW_SDMAARM_CONFIG(x).B.RTDOBS)

/*! @brief Format value for bitfield SDMAARM_CONFIG_RTDOBS. */
#define BF_SDMAARM_CONFIG_RTDOBS(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_CONFIG_RTDOBS) & BM_SDMAARM_CONFIG_RTDOBS)

/*! @brief Set the RTDOBS field to a new value. */
#define BW_SDMAARM_CONFIG_RTDOBS(x, v) (HW_SDMAARM_CONFIG_WR(x, (HW_SDMAARM_CONFIG_RD(x) & ~BM_SDMAARM_CONFIG_RTDOBS) | BF_SDMAARM_CONFIG_RTDOBS(v)))
/*@}*/

/*!
 * @name Register SDMAARM_CONFIG, field DSPDMA[12] (RW)
 *
 * This bit's function is reserved and should be configured as zero.
 *
 * Values:
 * - 0 - - Reset Value
 * - 1 - - Reserved
 */
/*@{*/
#define BP_SDMAARM_CONFIG_DSPDMA (12U)     /*!< Bit position for SDMAARM_CONFIG_DSPDMA. */
#define BM_SDMAARM_CONFIG_DSPDMA (0x00001000U) /*!< Bit mask for SDMAARM_CONFIG_DSPDMA. */
#define BS_SDMAARM_CONFIG_DSPDMA (1U)      /*!< Bit field size in bits for SDMAARM_CONFIG_DSPDMA. */

/*! @brief Read current value of the SDMAARM_CONFIG_DSPDMA field. */
#define BR_SDMAARM_CONFIG_DSPDMA(x) (HW_SDMAARM_CONFIG(x).B.DSPDMA)

/*! @brief Format value for bitfield SDMAARM_CONFIG_DSPDMA. */
#define BF_SDMAARM_CONFIG_DSPDMA(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_CONFIG_DSPDMA) & BM_SDMAARM_CONFIG_DSPDMA)

/*! @brief Set the DSPDMA field to a new value. */
#define BW_SDMAARM_CONFIG_DSPDMA(x, v) (HW_SDMAARM_CONFIG_WR(x, (HW_SDMAARM_CONFIG_RD(x) & ~BM_SDMAARM_CONFIG_DSPDMA) | BF_SDMAARM_CONFIG_DSPDMA(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_SDMA_LOCK - SDMA LOCK
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_SDMA_LOCK - SDMA LOCK (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_sdma_lock
{
    uint32_t U;
    struct _hw_sdmaarm_sdma_lock_bitfields
    {
        uint32_t LOCK : 1;             /*!< [0]  */
        uint32_t SRESET_LOCK_CLR : 1;  /*!< [1]  */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_sdmaarm_sdma_lock_t;

/*!
 * @name Constants and macros for entire SDMAARM_SDMA_LOCK register
 */
/*@{*/
#define HW_SDMAARM_SDMA_LOCK_ADDR(x) ((uintptr_t)(x) + 0x3CU)

#define HW_SDMAARM_SDMA_LOCK(x)  (*(__IO hw_sdmaarm_sdma_lock_t *) HW_SDMAARM_SDMA_LOCK_ADDR(x))
#define HW_SDMAARM_SDMA_LOCK_RD(x) (HW_SDMAARM_SDMA_LOCK(x).U)
#define HW_SDMAARM_SDMA_LOCK_WR(x, v) (HW_SDMAARM_SDMA_LOCK(x).U = (v))
#define HW_SDMAARM_SDMA_LOCK_SET(x, v) (HW_SDMAARM_SDMA_LOCK_WR(x, HW_SDMAARM_SDMA_LOCK_RD(x) |  (v)))
#define HW_SDMAARM_SDMA_LOCK_CLR(x, v) (HW_SDMAARM_SDMA_LOCK_WR(x, HW_SDMAARM_SDMA_LOCK_RD(x) & ~(v)))
#define HW_SDMAARM_SDMA_LOCK_TOG(x, v) (HW_SDMAARM_SDMA_LOCK_WR(x, HW_SDMAARM_SDMA_LOCK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_SDMA_LOCK bitfields
 */

/*!
 * @name Register SDMAARM_SDMA_LOCK, field LOCK[0] (RW)
 *
 * The LOCK bit is used to restrict access to update SDMA script memory through
 * ROM channel zero scripts and through the OnCE interface under ARM platform
 * control. The LOCK bit is set: The SDMA_LOCK, ONCE_ENB,CH0ADDR, and ILLINSTADDR
 * registers cannot be written. These registers can be read, but writes are
 * ignored. SDMA software executing out of ROM or RAM may check the LOCK bit in the LOCK
 * register SDMA_LOCKLock Status Register to determine if certain operations are
 * allowed, such as up-loading new scripts. Once the LOCK bit is set to 1, only
 * a reset can clear it. The LOCK bit is cleared by a hardware reset. LOCK is
 * cleared by a software reset only if SRESET_LOCK_CLR is set.
 *
 * Values:
 * - 0 - LOCK disengaged.
 * - 1 - LOCK enabled.
 */
/*@{*/
#define BP_SDMAARM_SDMA_LOCK_LOCK (0U)     /*!< Bit position for SDMAARM_SDMA_LOCK_LOCK. */
#define BM_SDMAARM_SDMA_LOCK_LOCK (0x00000001U) /*!< Bit mask for SDMAARM_SDMA_LOCK_LOCK. */
#define BS_SDMAARM_SDMA_LOCK_LOCK (1U)     /*!< Bit field size in bits for SDMAARM_SDMA_LOCK_LOCK. */

/*! @brief Read current value of the SDMAARM_SDMA_LOCK_LOCK field. */
#define BR_SDMAARM_SDMA_LOCK_LOCK(x) (HW_SDMAARM_SDMA_LOCK(x).B.LOCK)

/*! @brief Format value for bitfield SDMAARM_SDMA_LOCK_LOCK. */
#define BF_SDMAARM_SDMA_LOCK_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_SDMA_LOCK_LOCK) & BM_SDMAARM_SDMA_LOCK_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_SDMAARM_SDMA_LOCK_LOCK(x, v) (HW_SDMAARM_SDMA_LOCK_WR(x, (HW_SDMAARM_SDMA_LOCK_RD(x) & ~BM_SDMAARM_SDMA_LOCK_LOCK) | BF_SDMAARM_SDMA_LOCK_LOCK(v)))
/*@}*/

/*!
 * @name Register SDMAARM_SDMA_LOCK, field SRESET_LOCK_CLR[1] (RW)
 *
 * The SRESET_LOCK_CLR bit determine if the LOCK bit is cleared on a software
 * reset triggered by writing to the RESET register. This bit cannot be changed if
 * LOCK=1. SREST_LOCK_CLR is cleared by conditions that clear the LOCK bit.
 *
 * Values:
 * - 0 - Software Reset does not clear the LOCK bit.
 * - 1 - Software Reset clears the LOCK bit.
 */
/*@{*/
#define BP_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR (1U) /*!< Bit position for SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR. */
#define BM_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR (0x00000002U) /*!< Bit mask for SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR. */
#define BS_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR (1U) /*!< Bit field size in bits for SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR. */

/*! @brief Read current value of the SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR field. */
#define BR_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR(x) (HW_SDMAARM_SDMA_LOCK(x).B.SRESET_LOCK_CLR)

/*! @brief Format value for bitfield SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR. */
#define BF_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR) & BM_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR)

/*! @brief Set the SRESET_LOCK_CLR field to a new value. */
#define BW_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR(x, v) (HW_SDMAARM_SDMA_LOCK_WR(x, (HW_SDMAARM_SDMA_LOCK_RD(x) & ~BM_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR) | BF_SDMAARM_SDMA_LOCK_SRESET_LOCK_CLR(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_ONCE_ENB - OnCE Enable
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_ONCE_ENB - OnCE Enable (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_once_enb
{
    uint32_t U;
    struct _hw_sdmaarm_once_enb_bitfields
    {
        uint32_t ENB : 1;              /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_sdmaarm_once_enb_t;

/*!
 * @name Constants and macros for entire SDMAARM_ONCE_ENB register
 */
/*@{*/
#define HW_SDMAARM_ONCE_ENB_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_SDMAARM_ONCE_ENB(x)   (*(__IO hw_sdmaarm_once_enb_t *) HW_SDMAARM_ONCE_ENB_ADDR(x))
#define HW_SDMAARM_ONCE_ENB_RD(x) (HW_SDMAARM_ONCE_ENB(x).U)
#define HW_SDMAARM_ONCE_ENB_WR(x, v) (HW_SDMAARM_ONCE_ENB(x).U = (v))
#define HW_SDMAARM_ONCE_ENB_SET(x, v) (HW_SDMAARM_ONCE_ENB_WR(x, HW_SDMAARM_ONCE_ENB_RD(x) |  (v)))
#define HW_SDMAARM_ONCE_ENB_CLR(x, v) (HW_SDMAARM_ONCE_ENB_WR(x, HW_SDMAARM_ONCE_ENB_RD(x) & ~(v)))
#define HW_SDMAARM_ONCE_ENB_TOG(x, v) (HW_SDMAARM_ONCE_ENB_WR(x, HW_SDMAARM_ONCE_ENB_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_ONCE_ENB bitfields
 */

/*!
 * @name Register SDMAARM_ONCE_ENB, field ENB[0] (RW)
 *
 * The OnCE Enable register selects the OnCE control source: When cleared (0),
 * the OnCE registers are accessed through the JTAG interface; when set (1), the
 * OnCE registers may be accessed by the ARM platform through the addresses
 * described, as follows. After reset, the OnCE registers are accessed through the JTAG
 * interface. Writing a 1 to ENB enables the ARM platform to access the ONCE_*
 * as any other SDMA control register. When cleared (0), all the ONCE_xxx
 * registers cannot be written. The value of ENB cannot be changed if the LOCK bit in the
 * SDMA_LOCK register is set.
 */
/*@{*/
#define BP_SDMAARM_ONCE_ENB_ENB (0U)       /*!< Bit position for SDMAARM_ONCE_ENB_ENB. */
#define BM_SDMAARM_ONCE_ENB_ENB (0x00000001U) /*!< Bit mask for SDMAARM_ONCE_ENB_ENB. */
#define BS_SDMAARM_ONCE_ENB_ENB (1U)       /*!< Bit field size in bits for SDMAARM_ONCE_ENB_ENB. */

/*! @brief Read current value of the SDMAARM_ONCE_ENB_ENB field. */
#define BR_SDMAARM_ONCE_ENB_ENB(x) (HW_SDMAARM_ONCE_ENB(x).B.ENB)

/*! @brief Format value for bitfield SDMAARM_ONCE_ENB_ENB. */
#define BF_SDMAARM_ONCE_ENB_ENB(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_ONCE_ENB_ENB) & BM_SDMAARM_ONCE_ENB_ENB)

/*! @brief Set the ENB field to a new value. */
#define BW_SDMAARM_ONCE_ENB_ENB(x, v) (HW_SDMAARM_ONCE_ENB_WR(x, (HW_SDMAARM_ONCE_ENB_RD(x) & ~BM_SDMAARM_ONCE_ENB_ENB) | BF_SDMAARM_ONCE_ENB_ENB(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_ONCE_DATA - OnCE Data Register
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_ONCE_DATA - OnCE Data Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_once_data
{
    uint32_t U;
    struct _hw_sdmaarm_once_data_bitfields
    {
        uint32_t DATA : 32;            /*!< [31:0]  */
    } B;
} hw_sdmaarm_once_data_t;

/*!
 * @name Constants and macros for entire SDMAARM_ONCE_DATA register
 */
/*@{*/
#define HW_SDMAARM_ONCE_DATA_ADDR(x) ((uintptr_t)(x) + 0x44U)

#define HW_SDMAARM_ONCE_DATA(x)  (*(__IO hw_sdmaarm_once_data_t *) HW_SDMAARM_ONCE_DATA_ADDR(x))
#define HW_SDMAARM_ONCE_DATA_RD(x) (HW_SDMAARM_ONCE_DATA(x).U)
#define HW_SDMAARM_ONCE_DATA_WR(x, v) (HW_SDMAARM_ONCE_DATA(x).U = (v))
#define HW_SDMAARM_ONCE_DATA_SET(x, v) (HW_SDMAARM_ONCE_DATA_WR(x, HW_SDMAARM_ONCE_DATA_RD(x) |  (v)))
#define HW_SDMAARM_ONCE_DATA_CLR(x, v) (HW_SDMAARM_ONCE_DATA_WR(x, HW_SDMAARM_ONCE_DATA_RD(x) & ~(v)))
#define HW_SDMAARM_ONCE_DATA_TOG(x, v) (HW_SDMAARM_ONCE_DATA_WR(x, HW_SDMAARM_ONCE_DATA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_ONCE_DATA bitfields
 */

/*!
 * @name Register SDMAARM_ONCE_DATA, field DATA[31:0] (RW)
 *
 * Data register of the OnCE JTAG controller. Refer to OnCE and Real-Time
 * DebugThe On-Chip Emulation block (OnCE) is the debug interface to the SDMA. for
 * information on this register.
 */
/*@{*/
#define BP_SDMAARM_ONCE_DATA_DATA (0U)     /*!< Bit position for SDMAARM_ONCE_DATA_DATA. */
#define BM_SDMAARM_ONCE_DATA_DATA (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_ONCE_DATA_DATA. */
#define BS_SDMAARM_ONCE_DATA_DATA (32U)    /*!< Bit field size in bits for SDMAARM_ONCE_DATA_DATA. */

/*! @brief Read current value of the SDMAARM_ONCE_DATA_DATA field. */
#define BR_SDMAARM_ONCE_DATA_DATA(x) (HW_SDMAARM_ONCE_DATA(x).U)

/*! @brief Format value for bitfield SDMAARM_ONCE_DATA_DATA. */
#define BF_SDMAARM_ONCE_DATA_DATA(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_ONCE_DATA_DATA) & BM_SDMAARM_ONCE_DATA_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_SDMAARM_ONCE_DATA_DATA(x, v) (HW_SDMAARM_ONCE_DATA_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_ONCE_INSTR - OnCE Instruction Register
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_ONCE_INSTR - OnCE Instruction Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_once_instr
{
    uint32_t U;
    struct _hw_sdmaarm_once_instr_bitfields
    {
        uint32_t INSTR : 16;           /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmaarm_once_instr_t;

/*!
 * @name Constants and macros for entire SDMAARM_ONCE_INSTR register
 */
/*@{*/
#define HW_SDMAARM_ONCE_INSTR_ADDR(x) ((uintptr_t)(x) + 0x48U)

#define HW_SDMAARM_ONCE_INSTR(x) (*(__IO hw_sdmaarm_once_instr_t *) HW_SDMAARM_ONCE_INSTR_ADDR(x))
#define HW_SDMAARM_ONCE_INSTR_RD(x) (HW_SDMAARM_ONCE_INSTR(x).U)
#define HW_SDMAARM_ONCE_INSTR_WR(x, v) (HW_SDMAARM_ONCE_INSTR(x).U = (v))
#define HW_SDMAARM_ONCE_INSTR_SET(x, v) (HW_SDMAARM_ONCE_INSTR_WR(x, HW_SDMAARM_ONCE_INSTR_RD(x) |  (v)))
#define HW_SDMAARM_ONCE_INSTR_CLR(x, v) (HW_SDMAARM_ONCE_INSTR_WR(x, HW_SDMAARM_ONCE_INSTR_RD(x) & ~(v)))
#define HW_SDMAARM_ONCE_INSTR_TOG(x, v) (HW_SDMAARM_ONCE_INSTR_WR(x, HW_SDMAARM_ONCE_INSTR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_ONCE_INSTR bitfields
 */

/*!
 * @name Register SDMAARM_ONCE_INSTR, field INSTR[15:0] (RW)
 *
 * Instruction register of the OnCE JTAG controller. Refer to OnCE and Real-Time
 * DebugThe On-Chip Emulation block (OnCE) is the debug interface to the SDMA.
 * for information on this register.
 */
/*@{*/
#define BP_SDMAARM_ONCE_INSTR_INSTR (0U)   /*!< Bit position for SDMAARM_ONCE_INSTR_INSTR. */
#define BM_SDMAARM_ONCE_INSTR_INSTR (0x0000FFFFU) /*!< Bit mask for SDMAARM_ONCE_INSTR_INSTR. */
#define BS_SDMAARM_ONCE_INSTR_INSTR (16U)  /*!< Bit field size in bits for SDMAARM_ONCE_INSTR_INSTR. */

/*! @brief Read current value of the SDMAARM_ONCE_INSTR_INSTR field. */
#define BR_SDMAARM_ONCE_INSTR_INSTR(x) (HW_SDMAARM_ONCE_INSTR(x).B.INSTR)

/*! @brief Format value for bitfield SDMAARM_ONCE_INSTR_INSTR. */
#define BF_SDMAARM_ONCE_INSTR_INSTR(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_ONCE_INSTR_INSTR) & BM_SDMAARM_ONCE_INSTR_INSTR)

/*! @brief Set the INSTR field to a new value. */
#define BW_SDMAARM_ONCE_INSTR_INSTR(x, v) (HW_SDMAARM_ONCE_INSTR_WR(x, (HW_SDMAARM_ONCE_INSTR_RD(x) & ~BM_SDMAARM_ONCE_INSTR_INSTR) | BF_SDMAARM_ONCE_INSTR_INSTR(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_ONCE_STAT - OnCE Status Register
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_ONCE_STAT - OnCE Status Register (RO)
 *
 * Reset value: 0x0000E000U
 */
typedef union _hw_sdmaarm_once_stat
{
    uint32_t U;
    struct _hw_sdmaarm_once_stat_bitfields
    {
        uint32_t ECDR : 3;             /*!< [2:0]  */
        uint32_t RESERVED0 : 4;        /*!< [6:3]  */
        uint32_t MST : 1;              /*!< [7]  */
        uint32_t SWB : 1;              /*!< [8]  */
        uint32_t ODR : 1;              /*!< [9]  */
        uint32_t EDR : 1;              /*!< [10]  */
        uint32_t RCV : 1;              /*!< [11]  */
        uint32_t PST : 4;              /*!< [15:12]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmaarm_once_stat_t;

/*!
 * @name Constants and macros for entire SDMAARM_ONCE_STAT register
 */
/*@{*/
#define HW_SDMAARM_ONCE_STAT_ADDR(x) ((uintptr_t)(x) + 0x4CU)

#define HW_SDMAARM_ONCE_STAT(x)  (*(__I hw_sdmaarm_once_stat_t *) HW_SDMAARM_ONCE_STAT_ADDR(x))
#define HW_SDMAARM_ONCE_STAT_RD(x) (HW_SDMAARM_ONCE_STAT(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMAARM_ONCE_STAT bitfields
 */

/*!
 * @name Register SDMAARM_ONCE_STAT, field ECDR[2:0] (RO)
 *
 * Event Cell Debug Request. If the debug request comes from the event cell, the
 * reason for entering debug mode is given by the EDR bits. If all three bits of
 * the EDR are reset, then it did not generate any debug request. If the cell
 * did generate a debug request, then at least one of the EDR bits is set (the
 * meaning of the encoding is given below). The encoding of the EDR bits is useful to
 * find out more precisely why the debug request was generated. A debug request
 * from an event cell is generated for a specific combination of the addra_cond,
 * addrb_cond, and data_cond conditions. The value of those fields is given by
 * the EDR bits.
 *
 * Values:
 * - 0 - 1 matched addra_cond
 * - 1 - 1 matched addrb_cond
 */
/*@{*/
#define BP_SDMAARM_ONCE_STAT_ECDR (0U)     /*!< Bit position for SDMAARM_ONCE_STAT_ECDR. */
#define BM_SDMAARM_ONCE_STAT_ECDR (0x00000007U) /*!< Bit mask for SDMAARM_ONCE_STAT_ECDR. */
#define BS_SDMAARM_ONCE_STAT_ECDR (3U)     /*!< Bit field size in bits for SDMAARM_ONCE_STAT_ECDR. */

/*! @brief Read current value of the SDMAARM_ONCE_STAT_ECDR field. */
#define BR_SDMAARM_ONCE_STAT_ECDR(x) (HW_SDMAARM_ONCE_STAT(x).B.ECDR)
/*@}*/

/*!
 * @name Register SDMAARM_ONCE_STAT, field MST[7] (RO)
 *
 * This flag is raised when the OnCE is controlled from the ARM platform
 * peripheral interface.
 *
 * Values:
 * - 0 - The JTAG interface controls the OnCE.
 * - 1 - The ARM platform peripheral interface controls the OnCE.
 */
/*@{*/
#define BP_SDMAARM_ONCE_STAT_MST (7U)      /*!< Bit position for SDMAARM_ONCE_STAT_MST. */
#define BM_SDMAARM_ONCE_STAT_MST (0x00000080U) /*!< Bit mask for SDMAARM_ONCE_STAT_MST. */
#define BS_SDMAARM_ONCE_STAT_MST (1U)      /*!< Bit field size in bits for SDMAARM_ONCE_STAT_MST. */

/*! @brief Read current value of the SDMAARM_ONCE_STAT_MST field. */
#define BR_SDMAARM_ONCE_STAT_MST(x) (HW_SDMAARM_ONCE_STAT(x).B.MST)
/*@}*/

/*!
 * @name Register SDMAARM_ONCE_STAT, field SWB[8] (RO)
 *
 * This flag is raised when the SDMA has entered debug mode after a software
 * breakpoint.
 */
/*@{*/
#define BP_SDMAARM_ONCE_STAT_SWB (8U)      /*!< Bit position for SDMAARM_ONCE_STAT_SWB. */
#define BM_SDMAARM_ONCE_STAT_SWB (0x00000100U) /*!< Bit mask for SDMAARM_ONCE_STAT_SWB. */
#define BS_SDMAARM_ONCE_STAT_SWB (1U)      /*!< Bit field size in bits for SDMAARM_ONCE_STAT_SWB. */

/*! @brief Read current value of the SDMAARM_ONCE_STAT_SWB field. */
#define BR_SDMAARM_ONCE_STAT_SWB(x) (HW_SDMAARM_ONCE_STAT(x).B.SWB)
/*@}*/

/*!
 * @name Register SDMAARM_ONCE_STAT, field ODR[9] (RO)
 *
 * This flag is raised when the SDMA has entered debug mode after a OnCE debug
 * request.
 */
/*@{*/
#define BP_SDMAARM_ONCE_STAT_ODR (9U)      /*!< Bit position for SDMAARM_ONCE_STAT_ODR. */
#define BM_SDMAARM_ONCE_STAT_ODR (0x00000200U) /*!< Bit mask for SDMAARM_ONCE_STAT_ODR. */
#define BS_SDMAARM_ONCE_STAT_ODR (1U)      /*!< Bit field size in bits for SDMAARM_ONCE_STAT_ODR. */

/*! @brief Read current value of the SDMAARM_ONCE_STAT_ODR field. */
#define BR_SDMAARM_ONCE_STAT_ODR(x) (HW_SDMAARM_ONCE_STAT(x).B.ODR)
/*@}*/

/*!
 * @name Register SDMAARM_ONCE_STAT, field EDR[10] (RO)
 *
 * This flag is raised when the SDMA has entered debug mode after an external
 * debug request.
 */
/*@{*/
#define BP_SDMAARM_ONCE_STAT_EDR (10U)     /*!< Bit position for SDMAARM_ONCE_STAT_EDR. */
#define BM_SDMAARM_ONCE_STAT_EDR (0x00000400U) /*!< Bit mask for SDMAARM_ONCE_STAT_EDR. */
#define BS_SDMAARM_ONCE_STAT_EDR (1U)      /*!< Bit field size in bits for SDMAARM_ONCE_STAT_EDR. */

/*! @brief Read current value of the SDMAARM_ONCE_STAT_EDR field. */
#define BR_SDMAARM_ONCE_STAT_EDR(x) (HW_SDMAARM_ONCE_STAT(x).B.EDR)
/*@}*/

/*!
 * @name Register SDMAARM_ONCE_STAT, field RCV[11] (RO)
 *
 * After each write access to the real time buffer (RTB), the RCV bit is set.
 * This bit is cleared after execution of an rbuffer command and on a JTAG reset.
 */
/*@{*/
#define BP_SDMAARM_ONCE_STAT_RCV (11U)     /*!< Bit position for SDMAARM_ONCE_STAT_RCV. */
#define BM_SDMAARM_ONCE_STAT_RCV (0x00000800U) /*!< Bit mask for SDMAARM_ONCE_STAT_RCV. */
#define BS_SDMAARM_ONCE_STAT_RCV (1U)      /*!< Bit field size in bits for SDMAARM_ONCE_STAT_RCV. */

/*! @brief Read current value of the SDMAARM_ONCE_STAT_RCV field. */
#define BR_SDMAARM_ONCE_STAT_RCV(x) (HW_SDMAARM_ONCE_STAT(x).B.RCV)
/*@}*/

/*!
 * @name Register SDMAARM_ONCE_STAT, field PST[15:12] (RO)
 *
 * The Processor Status bits reflect the state of the SDMA RISC engine. Its
 * states are as follows: The "Program" state is the usual instruction execution
 * cycle. The "Data" state is inserted when there are wait-states during a load or a
 * store on the data bus (ld or st). The "Change of Flow" state is the second
 * cycle of any instruction that breaks the sequence of instructions (jumps and
 * channel switching instructions). The "Change of Flow in Loop" state is used when
 * an error causes a hardware loop exit. The "Debug" state means the SDMA is in
 * debug mode. The "Functional Unit" state is inserted when there are wait-states
 * during a load or a store on the functional units bus (ldf or stf). In "Sleep"
 * modes, no script is running (this is the RISC engine idle state). The "after
 * Reset" is slightly different because no context restoring phase will happen when
 * a channel is triggered: The script located at address 0 will be executed
 * (boot operation). The "in Sleep" states are the same as above except they do not
 * have any corresponding channel: They are used when entering debug mode after
 * reset. The reason is that it is necessary to return to the "Sleep after Reset"
 * state when leaving debug mode.
 *
 * Values:
 * - 0 - Program
 * - 1 - Data
 * - 10 - Change of Flow in Sleep
 * - 11 - Change Flow in Loop in Sleep
 */
/*@{*/
#define BP_SDMAARM_ONCE_STAT_PST (12U)     /*!< Bit position for SDMAARM_ONCE_STAT_PST. */
#define BM_SDMAARM_ONCE_STAT_PST (0x0000F000U) /*!< Bit mask for SDMAARM_ONCE_STAT_PST. */
#define BS_SDMAARM_ONCE_STAT_PST (4U)      /*!< Bit field size in bits for SDMAARM_ONCE_STAT_PST. */

/*! @brief Read current value of the SDMAARM_ONCE_STAT_PST field. */
#define BR_SDMAARM_ONCE_STAT_PST(x) (HW_SDMAARM_ONCE_STAT(x).B.PST)
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_ONCE_CMD - OnCE Command Register
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_ONCE_CMD - OnCE Command Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_once_cmd
{
    uint32_t U;
    struct _hw_sdmaarm_once_cmd_bitfields
    {
        uint32_t CMD : 4;              /*!< [3:0]  */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_sdmaarm_once_cmd_t;

/*!
 * @name Constants and macros for entire SDMAARM_ONCE_CMD register
 */
/*@{*/
#define HW_SDMAARM_ONCE_CMD_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_SDMAARM_ONCE_CMD(x)   (*(__IO hw_sdmaarm_once_cmd_t *) HW_SDMAARM_ONCE_CMD_ADDR(x))
#define HW_SDMAARM_ONCE_CMD_RD(x) (HW_SDMAARM_ONCE_CMD(x).U)
#define HW_SDMAARM_ONCE_CMD_WR(x, v) (HW_SDMAARM_ONCE_CMD(x).U = (v))
#define HW_SDMAARM_ONCE_CMD_SET(x, v) (HW_SDMAARM_ONCE_CMD_WR(x, HW_SDMAARM_ONCE_CMD_RD(x) |  (v)))
#define HW_SDMAARM_ONCE_CMD_CLR(x, v) (HW_SDMAARM_ONCE_CMD_WR(x, HW_SDMAARM_ONCE_CMD_RD(x) & ~(v)))
#define HW_SDMAARM_ONCE_CMD_TOG(x, v) (HW_SDMAARM_ONCE_CMD_WR(x, HW_SDMAARM_ONCE_CMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_ONCE_CMD bitfields
 */

/*!
 * @name Register SDMAARM_ONCE_CMD, field CMD[3:0] (RW)
 *
 * Writing to this register will cause the OnCE to execute the command that is
 * written. When needed, the ONCE_DATA and ONCE_INSTR registers should be loaded
 * with the correct value before writing the command to that register. For a list
 * of the OnCE commands and their usage, see OnCE and Real-Time DebugThe On-Chip
 * Emulation block (OnCE) is the debug interface to the SDMA. . 7-15 reserved
 *
 * Values:
 * - 0 - rstatus
 * - 1 - dmov
 */
/*@{*/
#define BP_SDMAARM_ONCE_CMD_CMD (0U)       /*!< Bit position for SDMAARM_ONCE_CMD_CMD. */
#define BM_SDMAARM_ONCE_CMD_CMD (0x0000000FU) /*!< Bit mask for SDMAARM_ONCE_CMD_CMD. */
#define BS_SDMAARM_ONCE_CMD_CMD (4U)       /*!< Bit field size in bits for SDMAARM_ONCE_CMD_CMD. */

/*! @brief Read current value of the SDMAARM_ONCE_CMD_CMD field. */
#define BR_SDMAARM_ONCE_CMD_CMD(x) (HW_SDMAARM_ONCE_CMD(x).B.CMD)

/*! @brief Format value for bitfield SDMAARM_ONCE_CMD_CMD. */
#define BF_SDMAARM_ONCE_CMD_CMD(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_ONCE_CMD_CMD) & BM_SDMAARM_ONCE_CMD_CMD)

/*! @brief Set the CMD field to a new value. */
#define BW_SDMAARM_ONCE_CMD_CMD(x, v) (HW_SDMAARM_ONCE_CMD_WR(x, (HW_SDMAARM_ONCE_CMD_RD(x) & ~BM_SDMAARM_ONCE_CMD_CMD) | BF_SDMAARM_ONCE_CMD_CMD(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_ILLINSTADDR - Illegal Instruction Trap Address
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_ILLINSTADDR - Illegal Instruction Trap Address (RW)
 *
 * Reset value: 0x00000001U
 */
typedef union _hw_sdmaarm_illinstaddr
{
    uint32_t U;
    struct _hw_sdmaarm_illinstaddr_bitfields
    {
        uint32_t ILLINSTADDR : 14;     /*!< [13:0]  */
        uint32_t RESERVED0 : 18;       /*!< [31:14]  */
    } B;
} hw_sdmaarm_illinstaddr_t;

/*!
 * @name Constants and macros for entire SDMAARM_ILLINSTADDR register
 */
/*@{*/
#define HW_SDMAARM_ILLINSTADDR_ADDR(x) ((uintptr_t)(x) + 0x58U)

#define HW_SDMAARM_ILLINSTADDR(x) (*(__IO hw_sdmaarm_illinstaddr_t *) HW_SDMAARM_ILLINSTADDR_ADDR(x))
#define HW_SDMAARM_ILLINSTADDR_RD(x) (HW_SDMAARM_ILLINSTADDR(x).U)
#define HW_SDMAARM_ILLINSTADDR_WR(x, v) (HW_SDMAARM_ILLINSTADDR(x).U = (v))
#define HW_SDMAARM_ILLINSTADDR_SET(x, v) (HW_SDMAARM_ILLINSTADDR_WR(x, HW_SDMAARM_ILLINSTADDR_RD(x) |  (v)))
#define HW_SDMAARM_ILLINSTADDR_CLR(x, v) (HW_SDMAARM_ILLINSTADDR_WR(x, HW_SDMAARM_ILLINSTADDR_RD(x) & ~(v)))
#define HW_SDMAARM_ILLINSTADDR_TOG(x, v) (HW_SDMAARM_ILLINSTADDR_WR(x, HW_SDMAARM_ILLINSTADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_ILLINSTADDR bitfields
 */

/*!
 * @name Register SDMAARM_ILLINSTADDR, field ILLINSTADDR[13:0] (RW)
 *
 * The Illegal Instruction Trap Address is the address where the SDMA jumps when
 * an illegal instruction is executed. It is 0x0001 after reset. The value of
 * ILLINSTADDR cannot be changed if the LOCK bit in the SDMA_LOCK register is set.
 */
/*@{*/
#define BP_SDMAARM_ILLINSTADDR_ILLINSTADDR (0U) /*!< Bit position for SDMAARM_ILLINSTADDR_ILLINSTADDR. */
#define BM_SDMAARM_ILLINSTADDR_ILLINSTADDR (0x00003FFFU) /*!< Bit mask for SDMAARM_ILLINSTADDR_ILLINSTADDR. */
#define BS_SDMAARM_ILLINSTADDR_ILLINSTADDR (14U) /*!< Bit field size in bits for SDMAARM_ILLINSTADDR_ILLINSTADDR. */

/*! @brief Read current value of the SDMAARM_ILLINSTADDR_ILLINSTADDR field. */
#define BR_SDMAARM_ILLINSTADDR_ILLINSTADDR(x) (HW_SDMAARM_ILLINSTADDR(x).B.ILLINSTADDR)

/*! @brief Format value for bitfield SDMAARM_ILLINSTADDR_ILLINSTADDR. */
#define BF_SDMAARM_ILLINSTADDR_ILLINSTADDR(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_ILLINSTADDR_ILLINSTADDR) & BM_SDMAARM_ILLINSTADDR_ILLINSTADDR)

/*! @brief Set the ILLINSTADDR field to a new value. */
#define BW_SDMAARM_ILLINSTADDR_ILLINSTADDR(x, v) (HW_SDMAARM_ILLINSTADDR_WR(x, (HW_SDMAARM_ILLINSTADDR_RD(x) & ~BM_SDMAARM_ILLINSTADDR_ILLINSTADDR) | BF_SDMAARM_ILLINSTADDR_ILLINSTADDR(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_CHN0ADDR - Channel 0 Boot Address
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_CHN0ADDR - Channel 0 Boot Address (RW)
 *
 * Reset value: 0x00000050U
 */
typedef union _hw_sdmaarm_chn0addr
{
    uint32_t U;
    struct _hw_sdmaarm_chn0addr_bitfields
    {
        uint32_t CHN0ADDR : 14;        /*!< [13:0]  */
        uint32_t SMSZ : 1;             /*!< [14]  */
        uint32_t RESERVED0 : 17;       /*!< [31:15]  */
    } B;
} hw_sdmaarm_chn0addr_t;

/*!
 * @name Constants and macros for entire SDMAARM_CHN0ADDR register
 */
/*@{*/
#define HW_SDMAARM_CHN0ADDR_ADDR(x) ((uintptr_t)(x) + 0x5CU)

#define HW_SDMAARM_CHN0ADDR(x)   (*(__IO hw_sdmaarm_chn0addr_t *) HW_SDMAARM_CHN0ADDR_ADDR(x))
#define HW_SDMAARM_CHN0ADDR_RD(x) (HW_SDMAARM_CHN0ADDR(x).U)
#define HW_SDMAARM_CHN0ADDR_WR(x, v) (HW_SDMAARM_CHN0ADDR(x).U = (v))
#define HW_SDMAARM_CHN0ADDR_SET(x, v) (HW_SDMAARM_CHN0ADDR_WR(x, HW_SDMAARM_CHN0ADDR_RD(x) |  (v)))
#define HW_SDMAARM_CHN0ADDR_CLR(x, v) (HW_SDMAARM_CHN0ADDR_WR(x, HW_SDMAARM_CHN0ADDR_RD(x) & ~(v)))
#define HW_SDMAARM_CHN0ADDR_TOG(x, v) (HW_SDMAARM_CHN0ADDR_WR(x, HW_SDMAARM_CHN0ADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_CHN0ADDR bitfields
 */

/*!
 * @name Register SDMAARM_CHN0ADDR, field CHN0ADDR[13:0] (RW)
 *
 * This 14-bit register is used by the boot code of the SDMA. After reset, it
 * points to the standard boot routine in ROM (channel 0 routine). By changing this
 * address, you can perform a boot sequence with your own routine. The very
 * first instructions of the boot code fetch the contents of this register (it is
 * also mapped in the SDMA memory space) and jump to the given address. The reset
 * value is 0x0050 (decimal 80). The value of CHN0ADDR cannot be changed if the
 * LOCK bit in the SDMA_LOCK register is set.
 */
/*@{*/
#define BP_SDMAARM_CHN0ADDR_CHN0ADDR (0U)  /*!< Bit position for SDMAARM_CHN0ADDR_CHN0ADDR. */
#define BM_SDMAARM_CHN0ADDR_CHN0ADDR (0x00003FFFU) /*!< Bit mask for SDMAARM_CHN0ADDR_CHN0ADDR. */
#define BS_SDMAARM_CHN0ADDR_CHN0ADDR (14U) /*!< Bit field size in bits for SDMAARM_CHN0ADDR_CHN0ADDR. */

/*! @brief Read current value of the SDMAARM_CHN0ADDR_CHN0ADDR field. */
#define BR_SDMAARM_CHN0ADDR_CHN0ADDR(x) (HW_SDMAARM_CHN0ADDR(x).B.CHN0ADDR)

/*! @brief Format value for bitfield SDMAARM_CHN0ADDR_CHN0ADDR. */
#define BF_SDMAARM_CHN0ADDR_CHN0ADDR(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_CHN0ADDR_CHN0ADDR) & BM_SDMAARM_CHN0ADDR_CHN0ADDR)

/*! @brief Set the CHN0ADDR field to a new value. */
#define BW_SDMAARM_CHN0ADDR_CHN0ADDR(x, v) (HW_SDMAARM_CHN0ADDR_WR(x, (HW_SDMAARM_CHN0ADDR_RD(x) & ~BM_SDMAARM_CHN0ADDR_CHN0ADDR) | BF_SDMAARM_CHN0ADDR_CHN0ADDR(v)))
/*@}*/

/*!
 * @name Register SDMAARM_CHN0ADDR, field SMSZ[14] (RW)
 *
 * The bit 14 (Scratch Memory Size) determines if scratch memory must be
 * available after every channel context. After reset, it is equal to 0, which defines a
 * RAM space of 24 words for each channel. All of this area stores the channel
 * context. By setting this bit, 32 words are reserved for every channel context,
 * which gives eight additional words that can be used by the channel script to
 * store any type of data. Those words are never erased by the context switching
 * mechanism. The value of SMSZ cannot be changed if the LOCK bit in the SDMA_LOCK
 * register is set.
 *
 * Values:
 * - 0 - 24 words per context
 * - 1 - 32 words per context
 */
/*@{*/
#define BP_SDMAARM_CHN0ADDR_SMSZ (14U)     /*!< Bit position for SDMAARM_CHN0ADDR_SMSZ. */
#define BM_SDMAARM_CHN0ADDR_SMSZ (0x00004000U) /*!< Bit mask for SDMAARM_CHN0ADDR_SMSZ. */
#define BS_SDMAARM_CHN0ADDR_SMSZ (1U)      /*!< Bit field size in bits for SDMAARM_CHN0ADDR_SMSZ. */

/*! @brief Read current value of the SDMAARM_CHN0ADDR_SMSZ field. */
#define BR_SDMAARM_CHN0ADDR_SMSZ(x) (HW_SDMAARM_CHN0ADDR(x).B.SMSZ)

/*! @brief Format value for bitfield SDMAARM_CHN0ADDR_SMSZ. */
#define BF_SDMAARM_CHN0ADDR_SMSZ(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_CHN0ADDR_SMSZ) & BM_SDMAARM_CHN0ADDR_SMSZ)

/*! @brief Set the SMSZ field to a new value. */
#define BW_SDMAARM_CHN0ADDR_SMSZ(x, v) (HW_SDMAARM_CHN0ADDR_WR(x, (HW_SDMAARM_CHN0ADDR_RD(x) & ~BM_SDMAARM_CHN0ADDR_SMSZ) | BF_SDMAARM_CHN0ADDR_SMSZ(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_EVT_MIRROR - DMA Requests
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_EVT_MIRROR - DMA Requests (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_evt_mirror
{
    uint32_t U;
    struct _hw_sdmaarm_evt_mirror_bitfields
    {
        uint32_t EVENTS : 32;          /*!< [31:0]  */
    } B;
} hw_sdmaarm_evt_mirror_t;

/*!
 * @name Constants and macros for entire SDMAARM_EVT_MIRROR register
 */
/*@{*/
#define HW_SDMAARM_EVT_MIRROR_ADDR(x) ((uintptr_t)(x) + 0x60U)

#define HW_SDMAARM_EVT_MIRROR(x) (*(__I hw_sdmaarm_evt_mirror_t *) HW_SDMAARM_EVT_MIRROR_ADDR(x))
#define HW_SDMAARM_EVT_MIRROR_RD(x) (HW_SDMAARM_EVT_MIRROR(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMAARM_EVT_MIRROR bitfields
 */

/*!
 * @name Register SDMAARM_EVT_MIRROR, field EVENTS[31:0] (RO)
 *
 * This register reflects the DMA requests received by the SDMA for events 31-0.
 * The ARM platform and the SDMA have a read-only access. There is one bit
 * associated with each of 32 DMA request events. This information may be useful
 * during debug of the blocks that generate the DMA requests. The EVT_MIRROR register
 * is cleared following read access.
 *
 * Values:
 * - 0 - DMA request event not pending
 * - 1 - DMA request event pending
 */
/*@{*/
#define BP_SDMAARM_EVT_MIRROR_EVENTS (0U)  /*!< Bit position for SDMAARM_EVT_MIRROR_EVENTS. */
#define BM_SDMAARM_EVT_MIRROR_EVENTS (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_EVT_MIRROR_EVENTS. */
#define BS_SDMAARM_EVT_MIRROR_EVENTS (32U) /*!< Bit field size in bits for SDMAARM_EVT_MIRROR_EVENTS. */

/*! @brief Read current value of the SDMAARM_EVT_MIRROR_EVENTS field. */
#define BR_SDMAARM_EVT_MIRROR_EVENTS(x) (HW_SDMAARM_EVT_MIRROR(x).U)
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_EVT_MIRROR2 - DMA Requests 2
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_EVT_MIRROR2 - DMA Requests 2 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_evt_mirror2
{
    uint32_t U;
    struct _hw_sdmaarm_evt_mirror2_bitfields
    {
        uint32_t EVENTS : 16;          /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmaarm_evt_mirror2_t;

/*!
 * @name Constants and macros for entire SDMAARM_EVT_MIRROR2 register
 */
/*@{*/
#define HW_SDMAARM_EVT_MIRROR2_ADDR(x) ((uintptr_t)(x) + 0x64U)

#define HW_SDMAARM_EVT_MIRROR2(x) (*(__I hw_sdmaarm_evt_mirror2_t *) HW_SDMAARM_EVT_MIRROR2_ADDR(x))
#define HW_SDMAARM_EVT_MIRROR2_RD(x) (HW_SDMAARM_EVT_MIRROR2(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMAARM_EVT_MIRROR2 bitfields
 */

/*!
 * @name Register SDMAARM_EVT_MIRROR2, field EVENTS[15:0] (RO)
 *
 * This register reflects the DMA requests received by the SDMA for events
 * 47-32. The ARM platform and the SDMA have a read-only access. There is one bit
 * associated with each of DMA request events. This information may be useful during
 * debug of the blocks that generate the DMA requests. The EVT_MIRROR2 register
 * is cleared following read access.
 *
 * Values:
 * - 0 - - DMA request event not pending
 */
/*@{*/
#define BP_SDMAARM_EVT_MIRROR2_EVENTS (0U) /*!< Bit position for SDMAARM_EVT_MIRROR2_EVENTS. */
#define BM_SDMAARM_EVT_MIRROR2_EVENTS (0x0000FFFFU) /*!< Bit mask for SDMAARM_EVT_MIRROR2_EVENTS. */
#define BS_SDMAARM_EVT_MIRROR2_EVENTS (16U) /*!< Bit field size in bits for SDMAARM_EVT_MIRROR2_EVENTS. */

/*! @brief Read current value of the SDMAARM_EVT_MIRROR2_EVENTS field. */
#define BR_SDMAARM_EVT_MIRROR2_EVENTS(x) (HW_SDMAARM_EVT_MIRROR2(x).B.EVENTS)
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_XTRIG_CONF1 - Cross-Trigger Events Configuration Register 1
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_XTRIG_CONF1 - Cross-Trigger Events Configuration Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_xtrig_conf1
{
    uint32_t U;
    struct _hw_sdmaarm_xtrig_conf1_bitfields
    {
        uint32_t NUM0 : 6;             /*!< [5:0]  */
        uint32_t CNF0 : 1;             /*!< [6]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t NUM1 : 6;             /*!< [13:8]  */
        uint32_t CNF1 : 1;             /*!< [14]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t NUM2 : 6;             /*!< [21:16]  */
        uint32_t CNF2 : 1;             /*!< [22]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t NUM3 : 6;             /*!< [29:24]  */
        uint32_t CNF3 : 1;             /*!< [30]  */
        uint32_t RESERVED3 : 1;        /*!< [31]  */
    } B;
} hw_sdmaarm_xtrig_conf1_t;

/*!
 * @name Constants and macros for entire SDMAARM_XTRIG_CONF1 register
 */
/*@{*/
#define HW_SDMAARM_XTRIG_CONF1_ADDR(x) ((uintptr_t)(x) + 0x70U)

#define HW_SDMAARM_XTRIG_CONF1(x) (*(__IO hw_sdmaarm_xtrig_conf1_t *) HW_SDMAARM_XTRIG_CONF1_ADDR(x))
#define HW_SDMAARM_XTRIG_CONF1_RD(x) (HW_SDMAARM_XTRIG_CONF1(x).U)
#define HW_SDMAARM_XTRIG_CONF1_WR(x, v) (HW_SDMAARM_XTRIG_CONF1(x).U = (v))
#define HW_SDMAARM_XTRIG_CONF1_SET(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, HW_SDMAARM_XTRIG_CONF1_RD(x) |  (v)))
#define HW_SDMAARM_XTRIG_CONF1_CLR(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, HW_SDMAARM_XTRIG_CONF1_RD(x) & ~(v)))
#define HW_SDMAARM_XTRIG_CONF1_TOG(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, HW_SDMAARM_XTRIG_CONF1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_XTRIG_CONF1 bitfields
 */

/*!
 * @name Register SDMAARM_XTRIG_CONF1, field NUM0[5:0] (RW)
 *
 * Contains the number of the DMA request or channel that triggers the pulse on
 * the cross-trigger event line number i.
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF1_NUM0 (0U)   /*!< Bit position for SDMAARM_XTRIG_CONF1_NUM0. */
#define BM_SDMAARM_XTRIG_CONF1_NUM0 (0x0000003FU) /*!< Bit mask for SDMAARM_XTRIG_CONF1_NUM0. */
#define BS_SDMAARM_XTRIG_CONF1_NUM0 (6U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF1_NUM0. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF1_NUM0 field. */
#define BR_SDMAARM_XTRIG_CONF1_NUM0(x) (HW_SDMAARM_XTRIG_CONF1(x).B.NUM0)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF1_NUM0. */
#define BF_SDMAARM_XTRIG_CONF1_NUM0(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF1_NUM0) & BM_SDMAARM_XTRIG_CONF1_NUM0)

/*! @brief Set the NUM0 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF1_NUM0(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, (HW_SDMAARM_XTRIG_CONF1_RD(x) & ~BM_SDMAARM_XTRIG_CONF1_NUM0) | BF_SDMAARM_XTRIG_CONF1_NUM0(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF1, field CNF0[6] (RW)
 *
 * Configuration of the SDMA event line number i that is connected to the
 * cross-trigger. It determines whether the event line pulse is generated by receiving
 * a DMA request or by starting a channel script execution.
 *
 * Values:
 * - 0 - channel
 * - 1 - DMA request
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF1_CNF0 (6U)   /*!< Bit position for SDMAARM_XTRIG_CONF1_CNF0. */
#define BM_SDMAARM_XTRIG_CONF1_CNF0 (0x00000040U) /*!< Bit mask for SDMAARM_XTRIG_CONF1_CNF0. */
#define BS_SDMAARM_XTRIG_CONF1_CNF0 (1U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF1_CNF0. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF1_CNF0 field. */
#define BR_SDMAARM_XTRIG_CONF1_CNF0(x) (HW_SDMAARM_XTRIG_CONF1(x).B.CNF0)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF1_CNF0. */
#define BF_SDMAARM_XTRIG_CONF1_CNF0(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF1_CNF0) & BM_SDMAARM_XTRIG_CONF1_CNF0)

/*! @brief Set the CNF0 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF1_CNF0(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, (HW_SDMAARM_XTRIG_CONF1_RD(x) & ~BM_SDMAARM_XTRIG_CONF1_CNF0) | BF_SDMAARM_XTRIG_CONF1_CNF0(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF1, field NUM1[13:8] (RW)
 *
 * Contains the number of the DMA request or channel that triggers the pulse on
 * the cross-trigger event line number i.
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF1_NUM1 (8U)   /*!< Bit position for SDMAARM_XTRIG_CONF1_NUM1. */
#define BM_SDMAARM_XTRIG_CONF1_NUM1 (0x00003F00U) /*!< Bit mask for SDMAARM_XTRIG_CONF1_NUM1. */
#define BS_SDMAARM_XTRIG_CONF1_NUM1 (6U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF1_NUM1. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF1_NUM1 field. */
#define BR_SDMAARM_XTRIG_CONF1_NUM1(x) (HW_SDMAARM_XTRIG_CONF1(x).B.NUM1)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF1_NUM1. */
#define BF_SDMAARM_XTRIG_CONF1_NUM1(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF1_NUM1) & BM_SDMAARM_XTRIG_CONF1_NUM1)

/*! @brief Set the NUM1 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF1_NUM1(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, (HW_SDMAARM_XTRIG_CONF1_RD(x) & ~BM_SDMAARM_XTRIG_CONF1_NUM1) | BF_SDMAARM_XTRIG_CONF1_NUM1(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF1, field CNF1[14] (RW)
 *
 * Configuration of the SDMA event line number i that is connected to the
 * cross-trigger. It determines whether the event line pulse is generated by receiving
 * a DMA request or by starting a channel script execution.
 *
 * Values:
 * - 0 - channel
 * - 1 - DMA request
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF1_CNF1 (14U)  /*!< Bit position for SDMAARM_XTRIG_CONF1_CNF1. */
#define BM_SDMAARM_XTRIG_CONF1_CNF1 (0x00004000U) /*!< Bit mask for SDMAARM_XTRIG_CONF1_CNF1. */
#define BS_SDMAARM_XTRIG_CONF1_CNF1 (1U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF1_CNF1. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF1_CNF1 field. */
#define BR_SDMAARM_XTRIG_CONF1_CNF1(x) (HW_SDMAARM_XTRIG_CONF1(x).B.CNF1)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF1_CNF1. */
#define BF_SDMAARM_XTRIG_CONF1_CNF1(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF1_CNF1) & BM_SDMAARM_XTRIG_CONF1_CNF1)

/*! @brief Set the CNF1 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF1_CNF1(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, (HW_SDMAARM_XTRIG_CONF1_RD(x) & ~BM_SDMAARM_XTRIG_CONF1_CNF1) | BF_SDMAARM_XTRIG_CONF1_CNF1(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF1, field NUM2[21:16] (RW)
 *
 * Contains the number of the DMA request or channel that triggers the pulse on
 * the cross-trigger event line number i.
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF1_NUM2 (16U)  /*!< Bit position for SDMAARM_XTRIG_CONF1_NUM2. */
#define BM_SDMAARM_XTRIG_CONF1_NUM2 (0x003F0000U) /*!< Bit mask for SDMAARM_XTRIG_CONF1_NUM2. */
#define BS_SDMAARM_XTRIG_CONF1_NUM2 (6U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF1_NUM2. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF1_NUM2 field. */
#define BR_SDMAARM_XTRIG_CONF1_NUM2(x) (HW_SDMAARM_XTRIG_CONF1(x).B.NUM2)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF1_NUM2. */
#define BF_SDMAARM_XTRIG_CONF1_NUM2(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF1_NUM2) & BM_SDMAARM_XTRIG_CONF1_NUM2)

/*! @brief Set the NUM2 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF1_NUM2(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, (HW_SDMAARM_XTRIG_CONF1_RD(x) & ~BM_SDMAARM_XTRIG_CONF1_NUM2) | BF_SDMAARM_XTRIG_CONF1_NUM2(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF1, field CNF2[22] (RW)
 *
 * Configuration of the SDMA event line number i that is connected to the
 * cross-trigger. It determines whether the event line pulse is generated by receiving
 * a DMA request or by starting a channel script execution.
 *
 * Values:
 * - 0 - channel
 * - 1 - DMA request
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF1_CNF2 (22U)  /*!< Bit position for SDMAARM_XTRIG_CONF1_CNF2. */
#define BM_SDMAARM_XTRIG_CONF1_CNF2 (0x00400000U) /*!< Bit mask for SDMAARM_XTRIG_CONF1_CNF2. */
#define BS_SDMAARM_XTRIG_CONF1_CNF2 (1U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF1_CNF2. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF1_CNF2 field. */
#define BR_SDMAARM_XTRIG_CONF1_CNF2(x) (HW_SDMAARM_XTRIG_CONF1(x).B.CNF2)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF1_CNF2. */
#define BF_SDMAARM_XTRIG_CONF1_CNF2(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF1_CNF2) & BM_SDMAARM_XTRIG_CONF1_CNF2)

/*! @brief Set the CNF2 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF1_CNF2(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, (HW_SDMAARM_XTRIG_CONF1_RD(x) & ~BM_SDMAARM_XTRIG_CONF1_CNF2) | BF_SDMAARM_XTRIG_CONF1_CNF2(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF1, field NUM3[29:24] (RW)
 *
 * Contains the number of the DMA request or channel that triggers the pulse on
 * the cross-trigger event line number i.
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF1_NUM3 (24U)  /*!< Bit position for SDMAARM_XTRIG_CONF1_NUM3. */
#define BM_SDMAARM_XTRIG_CONF1_NUM3 (0x3F000000U) /*!< Bit mask for SDMAARM_XTRIG_CONF1_NUM3. */
#define BS_SDMAARM_XTRIG_CONF1_NUM3 (6U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF1_NUM3. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF1_NUM3 field. */
#define BR_SDMAARM_XTRIG_CONF1_NUM3(x) (HW_SDMAARM_XTRIG_CONF1(x).B.NUM3)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF1_NUM3. */
#define BF_SDMAARM_XTRIG_CONF1_NUM3(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF1_NUM3) & BM_SDMAARM_XTRIG_CONF1_NUM3)

/*! @brief Set the NUM3 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF1_NUM3(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, (HW_SDMAARM_XTRIG_CONF1_RD(x) & ~BM_SDMAARM_XTRIG_CONF1_NUM3) | BF_SDMAARM_XTRIG_CONF1_NUM3(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF1, field CNF3[30] (RW)
 *
 * Configuration of the SDMA event line number i that is connected to the
 * cross-trigger. It determines whether the event line pulse is generated by the
 * reception of a DMA request or by the starting of a channel script execution.
 *
 * Values:
 * - 0 - channel
 * - 1 - DMA request
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF1_CNF3 (30U)  /*!< Bit position for SDMAARM_XTRIG_CONF1_CNF3. */
#define BM_SDMAARM_XTRIG_CONF1_CNF3 (0x40000000U) /*!< Bit mask for SDMAARM_XTRIG_CONF1_CNF3. */
#define BS_SDMAARM_XTRIG_CONF1_CNF3 (1U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF1_CNF3. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF1_CNF3 field. */
#define BR_SDMAARM_XTRIG_CONF1_CNF3(x) (HW_SDMAARM_XTRIG_CONF1(x).B.CNF3)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF1_CNF3. */
#define BF_SDMAARM_XTRIG_CONF1_CNF3(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF1_CNF3) & BM_SDMAARM_XTRIG_CONF1_CNF3)

/*! @brief Set the CNF3 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF1_CNF3(x, v) (HW_SDMAARM_XTRIG_CONF1_WR(x, (HW_SDMAARM_XTRIG_CONF1_RD(x) & ~BM_SDMAARM_XTRIG_CONF1_CNF3) | BF_SDMAARM_XTRIG_CONF1_CNF3(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_XTRIG_CONF2 - Cross-Trigger Events Configuration Register 2
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_XTRIG_CONF2 - Cross-Trigger Events Configuration Register 2 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_xtrig_conf2
{
    uint32_t U;
    struct _hw_sdmaarm_xtrig_conf2_bitfields
    {
        uint32_t NUM4 : 6;             /*!< [5:0]  */
        uint32_t CNF4 : 1;             /*!< [6]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t NUM5 : 6;             /*!< [13:8]  */
        uint32_t CNF5 : 1;             /*!< [14]  */
        uint32_t RESERVED1 : 1;        /*!< [15]  */
        uint32_t NUM6 : 6;             /*!< [21:16]  */
        uint32_t CNF6 : 1;             /*!< [22]  */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t NUM7 : 6;             /*!< [29:24]  */
        uint32_t CNF7 : 1;             /*!< [30]  */
        uint32_t RESERVED3 : 1;        /*!< [31]  */
    } B;
} hw_sdmaarm_xtrig_conf2_t;

/*!
 * @name Constants and macros for entire SDMAARM_XTRIG_CONF2 register
 */
/*@{*/
#define HW_SDMAARM_XTRIG_CONF2_ADDR(x) ((uintptr_t)(x) + 0x74U)

#define HW_SDMAARM_XTRIG_CONF2(x) (*(__IO hw_sdmaarm_xtrig_conf2_t *) HW_SDMAARM_XTRIG_CONF2_ADDR(x))
#define HW_SDMAARM_XTRIG_CONF2_RD(x) (HW_SDMAARM_XTRIG_CONF2(x).U)
#define HW_SDMAARM_XTRIG_CONF2_WR(x, v) (HW_SDMAARM_XTRIG_CONF2(x).U = (v))
#define HW_SDMAARM_XTRIG_CONF2_SET(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, HW_SDMAARM_XTRIG_CONF2_RD(x) |  (v)))
#define HW_SDMAARM_XTRIG_CONF2_CLR(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, HW_SDMAARM_XTRIG_CONF2_RD(x) & ~(v)))
#define HW_SDMAARM_XTRIG_CONF2_TOG(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, HW_SDMAARM_XTRIG_CONF2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_XTRIG_CONF2 bitfields
 */

/*!
 * @name Register SDMAARM_XTRIG_CONF2, field NUM4[5:0] (RW)
 *
 * Contains the number of the DMA request or channel that triggers the pulse on
 * the cross-trigger event line number i.
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF2_NUM4 (0U)   /*!< Bit position for SDMAARM_XTRIG_CONF2_NUM4. */
#define BM_SDMAARM_XTRIG_CONF2_NUM4 (0x0000003FU) /*!< Bit mask for SDMAARM_XTRIG_CONF2_NUM4. */
#define BS_SDMAARM_XTRIG_CONF2_NUM4 (6U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF2_NUM4. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF2_NUM4 field. */
#define BR_SDMAARM_XTRIG_CONF2_NUM4(x) (HW_SDMAARM_XTRIG_CONF2(x).B.NUM4)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF2_NUM4. */
#define BF_SDMAARM_XTRIG_CONF2_NUM4(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF2_NUM4) & BM_SDMAARM_XTRIG_CONF2_NUM4)

/*! @brief Set the NUM4 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF2_NUM4(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, (HW_SDMAARM_XTRIG_CONF2_RD(x) & ~BM_SDMAARM_XTRIG_CONF2_NUM4) | BF_SDMAARM_XTRIG_CONF2_NUM4(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF2, field CNF4[6] (RW)
 *
 * Configuration of the SDMA event line number i that is connected to the
 * cross-trigger. It determines whether the event line pulse is generated by receiving
 * a DMA request or by starting a channel script execution.
 *
 * Values:
 * - 0 - channel
 * - 1 - DMA request
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF2_CNF4 (6U)   /*!< Bit position for SDMAARM_XTRIG_CONF2_CNF4. */
#define BM_SDMAARM_XTRIG_CONF2_CNF4 (0x00000040U) /*!< Bit mask for SDMAARM_XTRIG_CONF2_CNF4. */
#define BS_SDMAARM_XTRIG_CONF2_CNF4 (1U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF2_CNF4. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF2_CNF4 field. */
#define BR_SDMAARM_XTRIG_CONF2_CNF4(x) (HW_SDMAARM_XTRIG_CONF2(x).B.CNF4)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF2_CNF4. */
#define BF_SDMAARM_XTRIG_CONF2_CNF4(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF2_CNF4) & BM_SDMAARM_XTRIG_CONF2_CNF4)

/*! @brief Set the CNF4 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF2_CNF4(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, (HW_SDMAARM_XTRIG_CONF2_RD(x) & ~BM_SDMAARM_XTRIG_CONF2_CNF4) | BF_SDMAARM_XTRIG_CONF2_CNF4(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF2, field NUM5[13:8] (RW)
 *
 * Contains the number of the DMA request or channel that triggers the pulse on
 * the cross-trigger event line number i.
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF2_NUM5 (8U)   /*!< Bit position for SDMAARM_XTRIG_CONF2_NUM5. */
#define BM_SDMAARM_XTRIG_CONF2_NUM5 (0x00003F00U) /*!< Bit mask for SDMAARM_XTRIG_CONF2_NUM5. */
#define BS_SDMAARM_XTRIG_CONF2_NUM5 (6U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF2_NUM5. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF2_NUM5 field. */
#define BR_SDMAARM_XTRIG_CONF2_NUM5(x) (HW_SDMAARM_XTRIG_CONF2(x).B.NUM5)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF2_NUM5. */
#define BF_SDMAARM_XTRIG_CONF2_NUM5(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF2_NUM5) & BM_SDMAARM_XTRIG_CONF2_NUM5)

/*! @brief Set the NUM5 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF2_NUM5(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, (HW_SDMAARM_XTRIG_CONF2_RD(x) & ~BM_SDMAARM_XTRIG_CONF2_NUM5) | BF_SDMAARM_XTRIG_CONF2_NUM5(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF2, field CNF5[14] (RW)
 *
 * Configuration of the SDMA event line number i that is connected to the
 * cross-trigger. It determines whether the event line pulse is generated by receiving
 * a DMA request or by starting a channel script execution
 *
 * Values:
 * - 0 - channel
 * - 1 - DMA request
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF2_CNF5 (14U)  /*!< Bit position for SDMAARM_XTRIG_CONF2_CNF5. */
#define BM_SDMAARM_XTRIG_CONF2_CNF5 (0x00004000U) /*!< Bit mask for SDMAARM_XTRIG_CONF2_CNF5. */
#define BS_SDMAARM_XTRIG_CONF2_CNF5 (1U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF2_CNF5. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF2_CNF5 field. */
#define BR_SDMAARM_XTRIG_CONF2_CNF5(x) (HW_SDMAARM_XTRIG_CONF2(x).B.CNF5)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF2_CNF5. */
#define BF_SDMAARM_XTRIG_CONF2_CNF5(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF2_CNF5) & BM_SDMAARM_XTRIG_CONF2_CNF5)

/*! @brief Set the CNF5 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF2_CNF5(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, (HW_SDMAARM_XTRIG_CONF2_RD(x) & ~BM_SDMAARM_XTRIG_CONF2_CNF5) | BF_SDMAARM_XTRIG_CONF2_CNF5(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF2, field NUM6[21:16] (RW)
 *
 * Contains the number of the DMA request or channel that triggers the pulse on
 * the cross-trigger event line number i.
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF2_NUM6 (16U)  /*!< Bit position for SDMAARM_XTRIG_CONF2_NUM6. */
#define BM_SDMAARM_XTRIG_CONF2_NUM6 (0x003F0000U) /*!< Bit mask for SDMAARM_XTRIG_CONF2_NUM6. */
#define BS_SDMAARM_XTRIG_CONF2_NUM6 (6U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF2_NUM6. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF2_NUM6 field. */
#define BR_SDMAARM_XTRIG_CONF2_NUM6(x) (HW_SDMAARM_XTRIG_CONF2(x).B.NUM6)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF2_NUM6. */
#define BF_SDMAARM_XTRIG_CONF2_NUM6(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF2_NUM6) & BM_SDMAARM_XTRIG_CONF2_NUM6)

/*! @brief Set the NUM6 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF2_NUM6(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, (HW_SDMAARM_XTRIG_CONF2_RD(x) & ~BM_SDMAARM_XTRIG_CONF2_NUM6) | BF_SDMAARM_XTRIG_CONF2_NUM6(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF2, field CNF6[22] (RW)
 *
 * Configuration of the SDMA event line number i that is connected to the
 * cross-trigger. It determines whether the event line pulse is generated by receiving
 * a DMA request or by starting a channel script execution.
 *
 * Values:
 * - 0 - channel
 * - 1 - DMA request
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF2_CNF6 (22U)  /*!< Bit position for SDMAARM_XTRIG_CONF2_CNF6. */
#define BM_SDMAARM_XTRIG_CONF2_CNF6 (0x00400000U) /*!< Bit mask for SDMAARM_XTRIG_CONF2_CNF6. */
#define BS_SDMAARM_XTRIG_CONF2_CNF6 (1U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF2_CNF6. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF2_CNF6 field. */
#define BR_SDMAARM_XTRIG_CONF2_CNF6(x) (HW_SDMAARM_XTRIG_CONF2(x).B.CNF6)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF2_CNF6. */
#define BF_SDMAARM_XTRIG_CONF2_CNF6(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF2_CNF6) & BM_SDMAARM_XTRIG_CONF2_CNF6)

/*! @brief Set the CNF6 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF2_CNF6(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, (HW_SDMAARM_XTRIG_CONF2_RD(x) & ~BM_SDMAARM_XTRIG_CONF2_CNF6) | BF_SDMAARM_XTRIG_CONF2_CNF6(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF2, field NUM7[29:24] (RW)
 *
 * Contains the number of the DMA request or channel that triggers the pulse on
 * the cross-trigger event line number i.
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF2_NUM7 (24U)  /*!< Bit position for SDMAARM_XTRIG_CONF2_NUM7. */
#define BM_SDMAARM_XTRIG_CONF2_NUM7 (0x3F000000U) /*!< Bit mask for SDMAARM_XTRIG_CONF2_NUM7. */
#define BS_SDMAARM_XTRIG_CONF2_NUM7 (6U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF2_NUM7. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF2_NUM7 field. */
#define BR_SDMAARM_XTRIG_CONF2_NUM7(x) (HW_SDMAARM_XTRIG_CONF2(x).B.NUM7)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF2_NUM7. */
#define BF_SDMAARM_XTRIG_CONF2_NUM7(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF2_NUM7) & BM_SDMAARM_XTRIG_CONF2_NUM7)

/*! @brief Set the NUM7 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF2_NUM7(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, (HW_SDMAARM_XTRIG_CONF2_RD(x) & ~BM_SDMAARM_XTRIG_CONF2_NUM7) | BF_SDMAARM_XTRIG_CONF2_NUM7(v)))
/*@}*/

/*!
 * @name Register SDMAARM_XTRIG_CONF2, field CNF7[30] (RW)
 *
 * Configuration of the SDMA event line number i that is connected to the
 * cross-trigger. It determines whether the event line pulse is generated by receiving
 * a DMA request or by starting a channel script execution.
 *
 * Values:
 * - 0 - channel
 * - 1 - DMA request
 */
/*@{*/
#define BP_SDMAARM_XTRIG_CONF2_CNF7 (30U)  /*!< Bit position for SDMAARM_XTRIG_CONF2_CNF7. */
#define BM_SDMAARM_XTRIG_CONF2_CNF7 (0x40000000U) /*!< Bit mask for SDMAARM_XTRIG_CONF2_CNF7. */
#define BS_SDMAARM_XTRIG_CONF2_CNF7 (1U)   /*!< Bit field size in bits for SDMAARM_XTRIG_CONF2_CNF7. */

/*! @brief Read current value of the SDMAARM_XTRIG_CONF2_CNF7 field. */
#define BR_SDMAARM_XTRIG_CONF2_CNF7(x) (HW_SDMAARM_XTRIG_CONF2(x).B.CNF7)

/*! @brief Format value for bitfield SDMAARM_XTRIG_CONF2_CNF7. */
#define BF_SDMAARM_XTRIG_CONF2_CNF7(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_XTRIG_CONF2_CNF7) & BM_SDMAARM_XTRIG_CONF2_CNF7)

/*! @brief Set the CNF7 field to a new value. */
#define BW_SDMAARM_XTRIG_CONF2_CNF7(x, v) (HW_SDMAARM_XTRIG_CONF2_WR(x, (HW_SDMAARM_XTRIG_CONF2_RD(x) & ~BM_SDMAARM_XTRIG_CONF2_CNF7) | BF_SDMAARM_XTRIG_CONF2_CNF7(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_SDMA_CHNPRIn - Channel Priority Registers
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_SDMA_CHNPRIn - Channel Priority Registers (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_sdma_chnprin
{
    uint32_t U;
    struct _hw_sdmaarm_sdma_chnprin_bitfields
    {
        uint32_t CHNPRIn : 3;          /*!< [2:0]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_sdmaarm_sdma_chnprin_t;

/*!
 * @name Constants and macros for entire SDMAARM_SDMA_CHNPRIn register
 */
/*@{*/
#define HW_SDMAARM_SDMA_CHNPRIn_COUNT (32U)

#define HW_SDMAARM_SDMA_CHNPRIn_ADDR(x, n) ((uintptr_t)(x) + 0x100U + (0x4U * (n)))

#define HW_SDMAARM_SDMA_CHNPRIn(x, n) (*(__IO hw_sdmaarm_sdma_chnprin_t *) HW_SDMAARM_SDMA_CHNPRIn_ADDR(x, n))
#define HW_SDMAARM_SDMA_CHNPRIn_RD(x, n) (HW_SDMAARM_SDMA_CHNPRIn(x, n).U)
#define HW_SDMAARM_SDMA_CHNPRIn_WR(x, n, v) (HW_SDMAARM_SDMA_CHNPRIn(x, n).U = (v))
#define HW_SDMAARM_SDMA_CHNPRIn_SET(x, n, v) (HW_SDMAARM_SDMA_CHNPRIn_WR(x, n, HW_SDMAARM_SDMA_CHNPRIn_RD(x, n) |  (v)))
#define HW_SDMAARM_SDMA_CHNPRIn_CLR(x, n, v) (HW_SDMAARM_SDMA_CHNPRIn_WR(x, n, HW_SDMAARM_SDMA_CHNPRIn_RD(x, n) & ~(v)))
#define HW_SDMAARM_SDMA_CHNPRIn_TOG(x, n, v) (HW_SDMAARM_SDMA_CHNPRIn_WR(x, n, HW_SDMAARM_SDMA_CHNPRIn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_SDMA_CHNPRIn bitfields
 */

/*!
 * @name Register SDMAARM_SDMA_CHNPRIn, field CHNPRIn[2:0] (RW)
 *
 * This contains the priority of channel number n. Useful values are between 1
 * and 7; 0 is reserved by the SDMA hardware to determine when there is no pending
 * channel. Reset value is 0, which prevents the channels from starting.
 */
/*@{*/
#define BP_SDMAARM_SDMA_CHNPRIn_CHNPRIn (0U) /*!< Bit position for SDMAARM_SDMA_CHNPRIn_CHNPRIn. */
#define BM_SDMAARM_SDMA_CHNPRIn_CHNPRIn (0x00000007U) /*!< Bit mask for SDMAARM_SDMA_CHNPRIn_CHNPRIn. */
#define BS_SDMAARM_SDMA_CHNPRIn_CHNPRIn (3U) /*!< Bit field size in bits for SDMAARM_SDMA_CHNPRIn_CHNPRIn. */

/*! @brief Read current value of the SDMAARM_SDMA_CHNPRIn_CHNPRIn field. */
#define BR_SDMAARM_SDMA_CHNPRIn_CHNPRIn(x, n) (HW_SDMAARM_SDMA_CHNPRIn(x, n).B.CHNPRIn)

/*! @brief Format value for bitfield SDMAARM_SDMA_CHNPRIn_CHNPRIn. */
#define BF_SDMAARM_SDMA_CHNPRIn_CHNPRIn(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_SDMA_CHNPRIn_CHNPRIn) & BM_SDMAARM_SDMA_CHNPRIn_CHNPRIn)

/*! @brief Set the CHNPRIn field to a new value. */
#define BW_SDMAARM_SDMA_CHNPRIn_CHNPRIn(x, n, v) (HW_SDMAARM_SDMA_CHNPRIn_WR(x, n, (HW_SDMAARM_SDMA_CHNPRIn_RD(x, n) & ~BM_SDMAARM_SDMA_CHNPRIn_CHNPRIn) | BF_SDMAARM_SDMA_CHNPRIn_CHNPRIn(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMAARM_CHNENBLn - Channel Enable RAM
 ******************************************************************************/

/*!
 * @brief HW_SDMAARM_CHNENBLn - Channel Enable RAM (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmaarm_chnenbln
{
    uint32_t U;
    struct _hw_sdmaarm_chnenbln_bitfields
    {
        uint32_t ENBLn : 32;           /*!< [31:0]  */
    } B;
} hw_sdmaarm_chnenbln_t;

/*!
 * @name Constants and macros for entire SDMAARM_CHNENBLn register
 */
/*@{*/
#define HW_SDMAARM_CHNENBLn_COUNT (48U)

#define HW_SDMAARM_CHNENBLn_ADDR(x, n) ((uintptr_t)(x) + 0x200U + (0x4U * (n)))

#define HW_SDMAARM_CHNENBLn(x, n) (*(__IO hw_sdmaarm_chnenbln_t *) HW_SDMAARM_CHNENBLn_ADDR(x, n))
#define HW_SDMAARM_CHNENBLn_RD(x, n) (HW_SDMAARM_CHNENBLn(x, n).U)
#define HW_SDMAARM_CHNENBLn_WR(x, n, v) (HW_SDMAARM_CHNENBLn(x, n).U = (v))
#define HW_SDMAARM_CHNENBLn_SET(x, n, v) (HW_SDMAARM_CHNENBLn_WR(x, n, HW_SDMAARM_CHNENBLn_RD(x, n) |  (v)))
#define HW_SDMAARM_CHNENBLn_CLR(x, n, v) (HW_SDMAARM_CHNENBLn_WR(x, n, HW_SDMAARM_CHNENBLn_RD(x, n) & ~(v)))
#define HW_SDMAARM_CHNENBLn_TOG(x, n, v) (HW_SDMAARM_CHNENBLn_WR(x, n, HW_SDMAARM_CHNENBLn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMAARM_CHNENBLn bitfields
 */

/*!
 * @name Register SDMAARM_CHNENBLn, field ENBLn[31:0] (RW)
 *
 * This 32-bit value selects the channels that are triggered by the DMA request
 * number n. If ENBLn[i] is set to 1, bit EP[i] will be set when the DMA request
 * n is received. These 48 32-bit registers are physically located in a RAM, with
 * no known reset value. It is thus essential for the ARM platform to program
 * them before any DMA request is triggered to the SDMA, otherwise an unpredictable
 * combination of channels may be started.
 */
/*@{*/
#define BP_SDMAARM_CHNENBLn_ENBLn (0U)     /*!< Bit position for SDMAARM_CHNENBLn_ENBLn. */
#define BM_SDMAARM_CHNENBLn_ENBLn (0xFFFFFFFFU) /*!< Bit mask for SDMAARM_CHNENBLn_ENBLn. */
#define BS_SDMAARM_CHNENBLn_ENBLn (32U)    /*!< Bit field size in bits for SDMAARM_CHNENBLn_ENBLn. */

/*! @brief Read current value of the SDMAARM_CHNENBLn_ENBLn field. */
#define BR_SDMAARM_CHNENBLn_ENBLn(x, n) (HW_SDMAARM_CHNENBLn(x, n).U)

/*! @brief Format value for bitfield SDMAARM_CHNENBLn_ENBLn. */
#define BF_SDMAARM_CHNENBLn_ENBLn(v) ((uint32_t)((uint32_t)(v) << BP_SDMAARM_CHNENBLn_ENBLn) & BM_SDMAARM_CHNENBLn_ENBLn)

/*! @brief Set the ENBLn field to a new value. */
#define BW_SDMAARM_CHNENBLn_ENBLn(x, n, v) (HW_SDMAARM_CHNENBLn_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * hw_sdmaarm_t - module struct
 ******************************************************************************/
/*!
 * @brief All SDMAARM module registers.
 */
#pragma pack(1)
typedef struct _hw_sdmaarm
{
    __IO hw_sdmaarm_mc0ptr_t MC0PTR;       /*!< [0x0] ARM platform Channel 0 Pointer */
    __IO hw_sdmaarm_intr_t INTR;           /*!< [0x4] Channel Interrupts */
    __IO hw_sdmaarm_stop_stat_t STOP_STAT; /*!< [0x8] Channel Stop/Channel Status */
    __IO hw_sdmaarm_hstart_t HSTART;       /*!< [0xC] Channel Start */
    __IO hw_sdmaarm_evtovr_t EVTOVR;       /*!< [0x10] Channel Event Override */
    __IO hw_sdmaarm_dspovr_t DSPOVR;       /*!< [0x14] Channel BP Override */
    __IO hw_sdmaarm_hostovr_t HOSTOVR;     /*!< [0x18] Channel ARM platform Override */
    __IO hw_sdmaarm_evtpend_t EVTPEND;     /*!< [0x1C] Channel Event Pending */
    uint8_t _reserved0[4];
    __I hw_sdmaarm_reset_t RESET;          /*!< [0x24] Reset Register */
    __I hw_sdmaarm_evterr_t EVTERR;        /*!< [0x28] DMA Request Error Register */
    __IO hw_sdmaarm_intrmask_t INTRMASK;   /*!< [0x2C] Channel ARM platform Interrupt Mask */
    __I hw_sdmaarm_psw_t PSW;              /*!< [0x30] Schedule Status */
    __I hw_sdmaarm_evterrdbg_t EVTERRDBG;  /*!< [0x34] DMA Request Error Register */
    __IO hw_sdmaarm_config_t CONFIG;       /*!< [0x38] Configuration Register */
    __IO hw_sdmaarm_sdma_lock_t SDMA_LOCK; /*!< [0x3C] SDMA LOCK */
    __IO hw_sdmaarm_once_enb_t ONCE_ENB;   /*!< [0x40] OnCE Enable */
    __IO hw_sdmaarm_once_data_t ONCE_DATA; /*!< [0x44] OnCE Data Register */
    __IO hw_sdmaarm_once_instr_t ONCE_INSTR; /*!< [0x48] OnCE Instruction Register */
    __I hw_sdmaarm_once_stat_t ONCE_STAT;  /*!< [0x4C] OnCE Status Register */
    __IO hw_sdmaarm_once_cmd_t ONCE_CMD;   /*!< [0x50] OnCE Command Register */
    uint8_t _reserved1[4];
    __IO hw_sdmaarm_illinstaddr_t ILLINSTADDR; /*!< [0x58] Illegal Instruction Trap Address */
    __IO hw_sdmaarm_chn0addr_t CHN0ADDR;   /*!< [0x5C] Channel 0 Boot Address */
    __I hw_sdmaarm_evt_mirror_t EVT_MIRROR; /*!< [0x60] DMA Requests */
    __I hw_sdmaarm_evt_mirror2_t EVT_MIRROR2; /*!< [0x64] DMA Requests 2 */
    uint8_t _reserved2[8];
    __IO hw_sdmaarm_xtrig_conf1_t XTRIG_CONF1; /*!< [0x70] Cross-Trigger Events Configuration Register 1 */
    __IO hw_sdmaarm_xtrig_conf2_t XTRIG_CONF2; /*!< [0x74] Cross-Trigger Events Configuration Register 2 */
    uint8_t _reserved3[136];
    __IO hw_sdmaarm_sdma_chnprin_t SDMA_CHNPRIn[32]; /*!< [0x100] Channel Priority Registers */
    uint8_t _reserved4[128];
    __IO hw_sdmaarm_chnenbln_t CHNENBLn[48]; /*!< [0x200] Channel Enable RAM */
} hw_sdmaarm_t;
#pragma pack()

/*! @brief Macro to access all SDMAARM registers. */
/*! @param x SDMAARM module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_SDMAARM_REGS(SDMAARM_BASE)</code>. */
#define HW_SDMAARM_REGS(x) (*(hw_sdmaarm_t *)(x))

/*
 * iMX7D SDMABP
 *
 * SDMA
 *
 * Registers defined in this header file:
 * - HW_SDMABP_DC0PTR - Channel 0 Pointer
 * - HW_SDMABP_INTR - Channel Interrupts
 * - HW_SDMABP_STOP_STAT - Channel Stop/Channel Status
 * - HW_SDMABP_DSTART - Channel Start
 * - HW_SDMABP_EVTERR - DMA Request Error Register
 * - HW_SDMABP_INTRMASK - Channel DSP Interrupt Mask
 * - HW_SDMABP_EVTERRDBG - DMA Request Error Register
 *
 * - hw_sdmabp_t - Struct containing all module registers.
 */

#define HW_SDMABP_INSTANCE_COUNT (1U) /*!< Number of instances of the SDMABP module. */
#define HW_SDMABP (0U) /*!< Instance number for SDMABP. */
#define SDMABP_BASE           (0x30BD0000U) /*!< Base address for SDMABP. */
/*! Array initializer of SDMABP base addresses. */
#define SDMABP_BASE_ADDRS     { SDMABP_BASE }

/*******************************************************************************
 * HW_SDMABP_DC0PTR - Channel 0 Pointer
 ******************************************************************************/

/*!
 * @brief HW_SDMABP_DC0PTR - Channel 0 Pointer (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmabp_dc0ptr
{
    uint32_t U;
    struct _hw_sdmabp_dc0ptr_bitfields
    {
        uint32_t DC0PTR : 32;          /*!< [31:0]  */
    } B;
} hw_sdmabp_dc0ptr_t;

/*!
 * @name Constants and macros for entire SDMABP_DC0PTR register
 */
/*@{*/
#define HW_SDMABP_DC0PTR_ADDR(x) ((uintptr_t)(x) + 0x0U)

#define HW_SDMABP_DC0PTR(x)      (*(__IO hw_sdmabp_dc0ptr_t *) HW_SDMABP_DC0PTR_ADDR(x))
#define HW_SDMABP_DC0PTR_RD(x)   (HW_SDMABP_DC0PTR(x).U)
#define HW_SDMABP_DC0PTR_WR(x, v) (HW_SDMABP_DC0PTR(x).U = (v))
#define HW_SDMABP_DC0PTR_SET(x, v) (HW_SDMABP_DC0PTR_WR(x, HW_SDMABP_DC0PTR_RD(x) |  (v)))
#define HW_SDMABP_DC0PTR_CLR(x, v) (HW_SDMABP_DC0PTR_WR(x, HW_SDMABP_DC0PTR_RD(x) & ~(v)))
#define HW_SDMABP_DC0PTR_TOG(x, v) (HW_SDMABP_DC0PTR_WR(x, HW_SDMABP_DC0PTR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMABP_DC0PTR bitfields
 */

/*!
 * @name Register SDMABP_DC0PTR, field DC0PTR[31:0] (RW)
 *
 * Channel 0 Pointer contains the 32-bit address, in BP memory, of the array of
 * channel control blocks starting with the one for channel 0 (the control
 * channel). This register should be initialized by the BP before it enables a channel
 * (for example, channel 0). See the API document SDMA Scripts User Manual for
 * the use of this register. The BP has a read/write access and the SDMA has a
 * read-only access.
 */
/*@{*/
#define BP_SDMABP_DC0PTR_DC0PTR (0U)       /*!< Bit position for SDMABP_DC0PTR_DC0PTR. */
#define BM_SDMABP_DC0PTR_DC0PTR (0xFFFFFFFFU) /*!< Bit mask for SDMABP_DC0PTR_DC0PTR. */
#define BS_SDMABP_DC0PTR_DC0PTR (32U)      /*!< Bit field size in bits for SDMABP_DC0PTR_DC0PTR. */

/*! @brief Read current value of the SDMABP_DC0PTR_DC0PTR field. */
#define BR_SDMABP_DC0PTR_DC0PTR(x) (HW_SDMABP_DC0PTR(x).U)

/*! @brief Format value for bitfield SDMABP_DC0PTR_DC0PTR. */
#define BF_SDMABP_DC0PTR_DC0PTR(v) ((uint32_t)((uint32_t)(v) << BP_SDMABP_DC0PTR_DC0PTR) & BM_SDMABP_DC0PTR_DC0PTR)

/*! @brief Set the DC0PTR field to a new value. */
#define BW_SDMABP_DC0PTR_DC0PTR(x, v) (HW_SDMABP_DC0PTR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMABP_INTR - Channel Interrupts
 ******************************************************************************/

/*!
 * @brief HW_SDMABP_INTR - Channel Interrupts (W1C)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmabp_intr
{
    uint32_t U;
    struct _hw_sdmabp_intr_bitfields
    {
        uint32_t DI : 32;              /*!< [31:0]  */
    } B;
} hw_sdmabp_intr_t;

/*!
 * @name Constants and macros for entire SDMABP_INTR register
 */
/*@{*/
#define HW_SDMABP_INTR_ADDR(x)   ((uintptr_t)(x) + 0x4U)

#define HW_SDMABP_INTR(x)        (*(__IO hw_sdmabp_intr_t *) HW_SDMABP_INTR_ADDR(x))
#define HW_SDMABP_INTR_RD(x)     (HW_SDMABP_INTR(x).U)
#define HW_SDMABP_INTR_WR(x, v)  (HW_SDMABP_INTR(x).U = (v))
#define HW_SDMABP_INTR_SET(x, v) (HW_SDMABP_INTR_WR(x, HW_SDMABP_INTR_RD(x) |  (v)))
#define HW_SDMABP_INTR_CLR(x, v) (HW_SDMABP_INTR_WR(x, HW_SDMABP_INTR_RD(x) & ~(v)))
#define HW_SDMABP_INTR_TOG(x, v) (HW_SDMABP_INTR_WR(x, HW_SDMABP_INTR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMABP_INTR bitfields
 */

/*!
 * @name Register SDMABP_INTR, field DI[31:0] (W1C)
 *
 * The BP Interrupts register contains the 32 DI[i] bits. If any bit is set, it
 * will cause an interrupt to the BP. This register is a "write-ones" register to
 * the BP. When the BP sets a bit in this register, the corresponding DI[i] bit
 * is cleared. The interrupt service routine should clear individual channel bits
 * when their interrupts are serviced; failure to do so will cause continuous
 * interrupts. The SDMA is responsible for setting the DI[i] bit corresponding to
 * the current channel when the corresponding done instruction is executed.
 */
/*@{*/
#define BP_SDMABP_INTR_DI    (0U)          /*!< Bit position for SDMABP_INTR_DI. */
#define BM_SDMABP_INTR_DI    (0xFFFFFFFFU) /*!< Bit mask for SDMABP_INTR_DI. */
#define BS_SDMABP_INTR_DI    (32U)         /*!< Bit field size in bits for SDMABP_INTR_DI. */

/*! @brief Read current value of the SDMABP_INTR_DI field. */
#define BR_SDMABP_INTR_DI(x) (HW_SDMABP_INTR(x).U)

/*! @brief Format value for bitfield SDMABP_INTR_DI. */
#define BF_SDMABP_INTR_DI(v) ((uint32_t)((uint32_t)(v) << BP_SDMABP_INTR_DI) & BM_SDMABP_INTR_DI)

/*! @brief Set the DI field to a new value. */
#define BW_SDMABP_INTR_DI(x, v) (HW_SDMABP_INTR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMABP_STOP_STAT - Channel Stop/Channel Status
 ******************************************************************************/

/*!
 * @brief HW_SDMABP_STOP_STAT - Channel Stop/Channel Status (W1C)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmabp_stop_stat
{
    uint32_t U;
    struct _hw_sdmabp_stop_stat_bitfields
    {
        uint32_t DE : 32;              /*!< [31:0]  */
    } B;
} hw_sdmabp_stop_stat_t;

/*!
 * @name Constants and macros for entire SDMABP_STOP_STAT register
 */
/*@{*/
#define HW_SDMABP_STOP_STAT_ADDR(x) ((uintptr_t)(x) + 0x8U)

#define HW_SDMABP_STOP_STAT(x)   (*(__IO hw_sdmabp_stop_stat_t *) HW_SDMABP_STOP_STAT_ADDR(x))
#define HW_SDMABP_STOP_STAT_RD(x) (HW_SDMABP_STOP_STAT(x).U)
#define HW_SDMABP_STOP_STAT_WR(x, v) (HW_SDMABP_STOP_STAT(x).U = (v))
#define HW_SDMABP_STOP_STAT_SET(x, v) (HW_SDMABP_STOP_STAT_WR(x, HW_SDMABP_STOP_STAT_RD(x) |  (v)))
#define HW_SDMABP_STOP_STAT_CLR(x, v) (HW_SDMABP_STOP_STAT_WR(x, HW_SDMABP_STOP_STAT_RD(x) & ~(v)))
#define HW_SDMABP_STOP_STAT_TOG(x, v) (HW_SDMABP_STOP_STAT_WR(x, HW_SDMABP_STOP_STAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMABP_STOP_STAT bitfields
 */

/*!
 * @name Register SDMABP_STOP_STAT, field DE[31:0] (W1C)
 *
 * This 32-bit register gives access to the BP (DSP) Enable bits, DE. There is
 * one bit for every channel. This register is a "write-ones" register to the BP.
 * When the BP writes 1 in bit i of this register, it clears the DE[i] and
 * DSTART[i] bits. Reading this register yields the current state of the DE[i] bits.
 */
/*@{*/
#define BP_SDMABP_STOP_STAT_DE (0U)        /*!< Bit position for SDMABP_STOP_STAT_DE. */
#define BM_SDMABP_STOP_STAT_DE (0xFFFFFFFFU) /*!< Bit mask for SDMABP_STOP_STAT_DE. */
#define BS_SDMABP_STOP_STAT_DE (32U)       /*!< Bit field size in bits for SDMABP_STOP_STAT_DE. */

/*! @brief Read current value of the SDMABP_STOP_STAT_DE field. */
#define BR_SDMABP_STOP_STAT_DE(x) (HW_SDMABP_STOP_STAT(x).U)

/*! @brief Format value for bitfield SDMABP_STOP_STAT_DE. */
#define BF_SDMABP_STOP_STAT_DE(v) ((uint32_t)((uint32_t)(v) << BP_SDMABP_STOP_STAT_DE) & BM_SDMABP_STOP_STAT_DE)

/*! @brief Set the DE field to a new value. */
#define BW_SDMABP_STOP_STAT_DE(x, v) (HW_SDMABP_STOP_STAT_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMABP_DSTART - Channel Start
 ******************************************************************************/

/*!
 * @brief HW_SDMABP_DSTART - Channel Start (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmabp_dstart
{
    uint32_t U;
    struct _hw_sdmabp_dstart_bitfields
    {
        uint32_t DSTART_DE : 32;       /*!< [31:0]  */
    } B;
} hw_sdmabp_dstart_t;

/*!
 * @name Constants and macros for entire SDMABP_DSTART register
 */
/*@{*/
#define HW_SDMABP_DSTART_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_SDMABP_DSTART(x)      (*(__I hw_sdmabp_dstart_t *) HW_SDMABP_DSTART_ADDR(x))
#define HW_SDMABP_DSTART_RD(x)   (HW_SDMABP_DSTART(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMABP_DSTART bitfields
 */

/*!
 * @name Register SDMABP_DSTART, field DSTART_DE[31:0] (RO)
 *
 * The DSTART_DE registers are 32 bits wide with one bit for every channel. When
 * a bit is written to 1, it enables the corresponding channel. Two physical
 * registers are accessed with that address (DSTART and DE), which enables the BP to
 * trigger a channel a second time before the first trigger was processed. This
 * register is a "write-ones" register to the BP. Neither DSTART[i] bit can be
 * set while the corresponding DE[i] bit is cleared. When the BP tries to set the
 * DSTART[i] bit by writing a one (if the corresponding DE[i] bit is clear), the
 * bit in the DSTART[i] register will remain cleared and the DE[i] bit will be
 * set. If the corresponding DE[i] bit was already set, the DSTART[i] bit will be
 * set. The next time the SDMA channel i attempts to clear the DE[i] bit by means
 * of a done instruction, the bit in the DSTART[i] register will be cleared and
 * the DE[i] bit will take the old value of the DSTART[i] bit. Reading this
 * register yields the current state of the DSTART[i] bits. This mechanism enables the
 * BP to pipeline two DSTART commands per channel.
 */
/*@{*/
#define BP_SDMABP_DSTART_DSTART_DE (0U)    /*!< Bit position for SDMABP_DSTART_DSTART_DE. */
#define BM_SDMABP_DSTART_DSTART_DE (0xFFFFFFFFU) /*!< Bit mask for SDMABP_DSTART_DSTART_DE. */
#define BS_SDMABP_DSTART_DSTART_DE (32U)   /*!< Bit field size in bits for SDMABP_DSTART_DSTART_DE. */

/*! @brief Read current value of the SDMABP_DSTART_DSTART_DE field. */
#define BR_SDMABP_DSTART_DSTART_DE(x) (HW_SDMABP_DSTART(x).U)
/*@}*/

/*******************************************************************************
 * HW_SDMABP_EVTERR - DMA Request Error Register
 ******************************************************************************/

/*!
 * @brief HW_SDMABP_EVTERR - DMA Request Error Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmabp_evterr
{
    uint32_t U;
    struct _hw_sdmabp_evterr_bitfields
    {
        uint32_t CHNERR : 32;          /*!< [31:0]  */
    } B;
} hw_sdmabp_evterr_t;

/*!
 * @name Constants and macros for entire SDMABP_EVTERR register
 */
/*@{*/
#define HW_SDMABP_EVTERR_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_SDMABP_EVTERR(x)      (*(__I hw_sdmabp_evterr_t *) HW_SDMABP_EVTERR_ADDR(x))
#define HW_SDMABP_EVTERR_RD(x)   (HW_SDMABP_EVTERR(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMABP_EVTERR bitfields
 */

/*!
 * @name Register SDMABP_EVTERR, field CHNERR[31:0] (RO)
 *
 * This register is used by the SDMA to warn the BP when an incoming DMA request
 * was detected; it then triggers a channel that is already pending or being
 * serviced, which may mean there is an overflow of data for that channel. An
 * interrupt is sent to the BP if the corresponding channel bit is set in the INTRMASK
 * register. This is a "write-ones" register for the scheduler. It is only able
 * to set the flags. The flags are cleared when the register is read by the BP or
 * during an SDMA reset. The CHNERR[i] bit is set when a DMA request that
 * triggers channel i is received through the corresponding input pins and the EP[i] bit
 * is already set. The EVTERR[i] bit is unaffected if the BP tries to set the
 * EP[i] bit when that EP[i] bit is already set.
 */
/*@{*/
#define BP_SDMABP_EVTERR_CHNERR (0U)       /*!< Bit position for SDMABP_EVTERR_CHNERR. */
#define BM_SDMABP_EVTERR_CHNERR (0xFFFFFFFFU) /*!< Bit mask for SDMABP_EVTERR_CHNERR. */
#define BS_SDMABP_EVTERR_CHNERR (32U)      /*!< Bit field size in bits for SDMABP_EVTERR_CHNERR. */

/*! @brief Read current value of the SDMABP_EVTERR_CHNERR field. */
#define BR_SDMABP_EVTERR_CHNERR(x) (HW_SDMABP_EVTERR(x).U)
/*@}*/

/*******************************************************************************
 * HW_SDMABP_INTRMASK - Channel DSP Interrupt Mask
 ******************************************************************************/

/*!
 * @brief HW_SDMABP_INTRMASK - Channel DSP Interrupt Mask (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmabp_intrmask
{
    uint32_t U;
    struct _hw_sdmabp_intrmask_bitfields
    {
        uint32_t DIMASK : 32;          /*!< [31:0]  */
    } B;
} hw_sdmabp_intrmask_t;

/*!
 * @name Constants and macros for entire SDMABP_INTRMASK register
 */
/*@{*/
#define HW_SDMABP_INTRMASK_ADDR(x) ((uintptr_t)(x) + 0x2CU)

#define HW_SDMABP_INTRMASK(x)    (*(__IO hw_sdmabp_intrmask_t *) HW_SDMABP_INTRMASK_ADDR(x))
#define HW_SDMABP_INTRMASK_RD(x) (HW_SDMABP_INTRMASK(x).U)
#define HW_SDMABP_INTRMASK_WR(x, v) (HW_SDMABP_INTRMASK(x).U = (v))
#define HW_SDMABP_INTRMASK_SET(x, v) (HW_SDMABP_INTRMASK_WR(x, HW_SDMABP_INTRMASK_RD(x) |  (v)))
#define HW_SDMABP_INTRMASK_CLR(x, v) (HW_SDMABP_INTRMASK_WR(x, HW_SDMABP_INTRMASK_RD(x) & ~(v)))
#define HW_SDMABP_INTRMASK_TOG(x, v) (HW_SDMABP_INTRMASK_WR(x, HW_SDMABP_INTRMASK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMABP_INTRMASK bitfields
 */

/*!
 * @name Register SDMABP_INTRMASK, field DIMASK[31:0] (RW)
 *
 * The Interrupt Mask Register contains 32 interrupt generation mask bits. If
 * bit DIMASK[i] is set, the DI[i] bit is set and an interrupt is sent to the BP
 * when a DMA request error is detected on channel i (for example, EVTERR[i] is
 * set).
 */
/*@{*/
#define BP_SDMABP_INTRMASK_DIMASK (0U)     /*!< Bit position for SDMABP_INTRMASK_DIMASK. */
#define BM_SDMABP_INTRMASK_DIMASK (0xFFFFFFFFU) /*!< Bit mask for SDMABP_INTRMASK_DIMASK. */
#define BS_SDMABP_INTRMASK_DIMASK (32U)    /*!< Bit field size in bits for SDMABP_INTRMASK_DIMASK. */

/*! @brief Read current value of the SDMABP_INTRMASK_DIMASK field. */
#define BR_SDMABP_INTRMASK_DIMASK(x) (HW_SDMABP_INTRMASK(x).U)

/*! @brief Format value for bitfield SDMABP_INTRMASK_DIMASK. */
#define BF_SDMABP_INTRMASK_DIMASK(v) ((uint32_t)((uint32_t)(v) << BP_SDMABP_INTRMASK_DIMASK) & BM_SDMABP_INTRMASK_DIMASK)

/*! @brief Set the DIMASK field to a new value. */
#define BW_SDMABP_INTRMASK_DIMASK(x, v) (HW_SDMABP_INTRMASK_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMABP_EVTERRDBG - DMA Request Error Register
 ******************************************************************************/

/*!
 * @brief HW_SDMABP_EVTERRDBG - DMA Request Error Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmabp_evterrdbg
{
    uint32_t U;
    struct _hw_sdmabp_evterrdbg_bitfields
    {
        uint32_t CHNERR : 32;          /*!< [31:0]  */
    } B;
} hw_sdmabp_evterrdbg_t;

/*!
 * @name Constants and macros for entire SDMABP_EVTERRDBG register
 */
/*@{*/
#define HW_SDMABP_EVTERRDBG_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_SDMABP_EVTERRDBG(x)   (*(__I hw_sdmabp_evterrdbg_t *) HW_SDMABP_EVTERRDBG_ADDR(x))
#define HW_SDMABP_EVTERRDBG_RD(x) (HW_SDMABP_EVTERRDBG(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMABP_EVTERRDBG bitfields
 */

/*!
 * @name Register SDMABP_EVTERRDBG, field CHNERR[31:0] (RO)
 *
 * This register is the same as EVTERR except reading it does not clear its
 * contents. This address is meant to be used in debug mode. The BP OnCE may check
 * this register value without modifying it.
 */
/*@{*/
#define BP_SDMABP_EVTERRDBG_CHNERR (0U)    /*!< Bit position for SDMABP_EVTERRDBG_CHNERR. */
#define BM_SDMABP_EVTERRDBG_CHNERR (0xFFFFFFFFU) /*!< Bit mask for SDMABP_EVTERRDBG_CHNERR. */
#define BS_SDMABP_EVTERRDBG_CHNERR (32U)   /*!< Bit field size in bits for SDMABP_EVTERRDBG_CHNERR. */

/*! @brief Read current value of the SDMABP_EVTERRDBG_CHNERR field. */
#define BR_SDMABP_EVTERRDBG_CHNERR(x) (HW_SDMABP_EVTERRDBG(x).U)
/*@}*/

/*******************************************************************************
 * hw_sdmabp_t - module struct
 ******************************************************************************/
/*!
 * @brief All SDMABP module registers.
 */
#pragma pack(1)
typedef struct _hw_sdmabp
{
    __IO hw_sdmabp_dc0ptr_t DC0PTR;        /*!< [0x0] Channel 0 Pointer */
    __IO hw_sdmabp_intr_t INTR;            /*!< [0x4] Channel Interrupts */
    __IO hw_sdmabp_stop_stat_t STOP_STAT;  /*!< [0x8] Channel Stop/Channel Status */
    __I hw_sdmabp_dstart_t DSTART;         /*!< [0xC] Channel Start */
    uint8_t _reserved0[24];
    __I hw_sdmabp_evterr_t EVTERR;         /*!< [0x28] DMA Request Error Register */
    __IO hw_sdmabp_intrmask_t INTRMASK;    /*!< [0x2C] Channel DSP Interrupt Mask */
    uint8_t _reserved1[4];
    __I hw_sdmabp_evterrdbg_t EVTERRDBG;   /*!< [0x34] DMA Request Error Register */
} hw_sdmabp_t;
#pragma pack()

/*! @brief Macro to access all SDMABP registers. */
/*! @param x SDMABP module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_SDMABP_REGS(SDMABP_BASE)</code>. */
#define HW_SDMABP_REGS(x) (*(hw_sdmabp_t *)(x))

/*
 * iMX7D SDMACORE
 *
 * SDMA
 *
 * Registers defined in this header file:
 * - HW_SDMACORE_MC0PTR - ARM platform Channel 0 Pointer
 * - HW_SDMACORE_CCPTR - Current Channel Pointer
 * - HW_SDMACORE_CCR - Current Channel Register
 * - HW_SDMACORE_NCR - Highest Pending Channel Register
 * - HW_SDMACORE_EVENTS - External DMA Requests Mirror
 * - HW_SDMACORE_CCPRI - Current Channel Priority
 * - HW_SDMACORE_NCPRI - Next Channel Priority
 * - HW_SDMACORE_ECOUNT - OnCE Event Cell Counter
 * - HW_SDMACORE_ECTL - OnCE Event Cell Control Register
 * - HW_SDMACORE_EAA - OnCE Event Address Register A
 * - HW_SDMACORE_EAB - OnCE Event Cell Address Register B
 * - HW_SDMACORE_EAM - OnCE Event Cell Address Mask
 * - HW_SDMACORE_ED - OnCE Event Cell Data Register
 * - HW_SDMACORE_EDM - OnCE Event Cell Data Mask
 * - HW_SDMACORE_RTB - OnCE Real-Time Buffer
 * - HW_SDMACORE_TB - OnCE Trace Buffer
 * - HW_SDMACORE_OSTAT - OnCE Status
 * - HW_SDMACORE_MCHN0ADDR - Channel 0 Boot Address
 * - HW_SDMACORE_ENDIANNESS - ENDIAN Status Register
 * - HW_SDMACORE_SDMA_LOCK - Lock Status Register
 * - HW_SDMACORE_EVENTS2 - External DMA Requests Mirror #2
 *
 * - hw_sdmacore_t - Struct containing all module registers.
 */

#define HW_SDMACORE_INSTANCE_COUNT (1U) /*!< Number of instances of the SDMACORE module. */
#define HW_SDMACORE (0U) /*!< Instance number for SDMACORE. */
#define SDMACORE_BASE         (0x30BD0000U) /*!< Base address for SDMACORE. */
/*! Array initializer of SDMACORE base addresses. */
#define SDMACORE_BASE_ADDRS   { SDMACORE_BASE }

/*******************************************************************************
 * HW_SDMACORE_MC0PTR - ARM platform Channel 0 Pointer
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_MC0PTR - ARM platform Channel 0 Pointer (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_mc0ptr
{
    uint32_t U;
    struct _hw_sdmacore_mc0ptr_bitfields
    {
        uint32_t MC0PTR : 32;          /*!< [31:0]  */
    } B;
} hw_sdmacore_mc0ptr_t;

/*!
 * @name Constants and macros for entire SDMACORE_MC0PTR register
 */
/*@{*/
#define HW_SDMACORE_MC0PTR_ADDR(x) ((uintptr_t)(x) + 0x0U)

#define HW_SDMACORE_MC0PTR(x)    (*(__I hw_sdmacore_mc0ptr_t *) HW_SDMACORE_MC0PTR_ADDR(x))
#define HW_SDMACORE_MC0PTR_RD(x) (HW_SDMACORE_MC0PTR(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_MC0PTR bitfields
 */

/*!
 * @name Register SDMACORE_MC0PTR, field MC0PTR[31:0] (RO)
 *
 * Contains the address-in the ARM platform memory space-of the initial SDMA
 * context and scripts that are loaded by the SDMA boot script running on channel 0.
 */
/*@{*/
#define BP_SDMACORE_MC0PTR_MC0PTR (0U)     /*!< Bit position for SDMACORE_MC0PTR_MC0PTR. */
#define BM_SDMACORE_MC0PTR_MC0PTR (0xFFFFFFFFU) /*!< Bit mask for SDMACORE_MC0PTR_MC0PTR. */
#define BS_SDMACORE_MC0PTR_MC0PTR (32U)    /*!< Bit field size in bits for SDMACORE_MC0PTR_MC0PTR. */

/*! @brief Read current value of the SDMACORE_MC0PTR_MC0PTR field. */
#define BR_SDMACORE_MC0PTR_MC0PTR(x) (HW_SDMACORE_MC0PTR(x).U)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_CCPTR - Current Channel Pointer
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_CCPTR - Current Channel Pointer (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_ccptr
{
    uint32_t U;
    struct _hw_sdmacore_ccptr_bitfields
    {
        uint32_t CCPTR : 16;           /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmacore_ccptr_t;

/*!
 * @name Constants and macros for entire SDMACORE_CCPTR register
 */
/*@{*/
#define HW_SDMACORE_CCPTR_ADDR(x) ((uintptr_t)(x) + 0x8U)

#define HW_SDMACORE_CCPTR(x)     (*(__I hw_sdmacore_ccptr_t *) HW_SDMACORE_CCPTR_ADDR(x))
#define HW_SDMACORE_CCPTR_RD(x)  (HW_SDMACORE_CCPTR(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_CCPTR bitfields
 */

/*!
 * @name Register SDMACORE_CCPTR, field CCPTR[15:0] (RO)
 *
 * Contains the start address of the context data for the current channel: Its
 * value is CONTEXT_BASE + 24* CCR or CONTEXT_BASE + 32* CCR where CONTEXT_BASE =
 * 0x0800. The value 24 or 32 is selected according to the programmed channel
 * scratch RAM size in the register shown in CHN0ADDRChannel 0 Boot Address .
 */
/*@{*/
#define BP_SDMACORE_CCPTR_CCPTR (0U)       /*!< Bit position for SDMACORE_CCPTR_CCPTR. */
#define BM_SDMACORE_CCPTR_CCPTR (0x0000FFFFU) /*!< Bit mask for SDMACORE_CCPTR_CCPTR. */
#define BS_SDMACORE_CCPTR_CCPTR (16U)      /*!< Bit field size in bits for SDMACORE_CCPTR_CCPTR. */

/*! @brief Read current value of the SDMACORE_CCPTR_CCPTR field. */
#define BR_SDMACORE_CCPTR_CCPTR(x) (HW_SDMACORE_CCPTR(x).B.CCPTR)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_CCR - Current Channel Register
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_CCR - Current Channel Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_ccr
{
    uint32_t U;
    struct _hw_sdmacore_ccr_bitfields
    {
        uint32_t CCR : 5;              /*!< [4:0]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_sdmacore_ccr_t;

/*!
 * @name Constants and macros for entire SDMACORE_CCR register
 */
/*@{*/
#define HW_SDMACORE_CCR_ADDR(x)  ((uintptr_t)(x) + 0xCU)

#define HW_SDMACORE_CCR(x)       (*(__I hw_sdmacore_ccr_t *) HW_SDMACORE_CCR_ADDR(x))
#define HW_SDMACORE_CCR_RD(x)    (HW_SDMACORE_CCR(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_CCR bitfields
 */

/*!
 * @name Register SDMACORE_CCR, field CCR[4:0] (RO)
 *
 * Contains the number of the current running channel whose context is
 * installed. In the case that the SDMA has finished running the channel and has entered
 * sleep state, CCR will indicate the previous running channel. The PST bits in
 * the OSTAT register indicate when the SDMA is in sleep state.
 */
/*@{*/
#define BP_SDMACORE_CCR_CCR  (0U)          /*!< Bit position for SDMACORE_CCR_CCR. */
#define BM_SDMACORE_CCR_CCR  (0x0000001FU) /*!< Bit mask for SDMACORE_CCR_CCR. */
#define BS_SDMACORE_CCR_CCR  (5U)          /*!< Bit field size in bits for SDMACORE_CCR_CCR. */

/*! @brief Read current value of the SDMACORE_CCR_CCR field. */
#define BR_SDMACORE_CCR_CCR(x) (HW_SDMACORE_CCR(x).B.CCR)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_NCR - Highest Pending Channel Register
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_NCR - Highest Pending Channel Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_ncr
{
    uint32_t U;
    struct _hw_sdmacore_ncr_bitfields
    {
        uint32_t NCR : 5;              /*!< [4:0]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_sdmacore_ncr_t;

/*!
 * @name Constants and macros for entire SDMACORE_NCR register
 */
/*@{*/
#define HW_SDMACORE_NCR_ADDR(x)  ((uintptr_t)(x) + 0x10U)

#define HW_SDMACORE_NCR(x)       (*(__I hw_sdmacore_ncr_t *) HW_SDMACORE_NCR_ADDR(x))
#define HW_SDMACORE_NCR_RD(x)    (HW_SDMACORE_NCR(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_NCR bitfields
 */

/*!
 * @name Register SDMACORE_NCR, field NCR[4:0] (RO)
 *
 * Contains the number of the pending channel that the scheduler has selected to
 * run next.
 */
/*@{*/
#define BP_SDMACORE_NCR_NCR  (0U)          /*!< Bit position for SDMACORE_NCR_NCR. */
#define BM_SDMACORE_NCR_NCR  (0x0000001FU) /*!< Bit mask for SDMACORE_NCR_NCR. */
#define BS_SDMACORE_NCR_NCR  (5U)          /*!< Bit field size in bits for SDMACORE_NCR_NCR. */

/*! @brief Read current value of the SDMACORE_NCR_NCR field. */
#define BR_SDMACORE_NCR_NCR(x) (HW_SDMACORE_NCR(x).B.NCR)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_EVENTS - External DMA Requests Mirror
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_EVENTS - External DMA Requests Mirror (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register is very useful in the case of DMA requests that are active when
 * a peripheral FIFO level is above the programmed watermark. The activation of
 * the DMA request (rising edge) is detected by the SDMA logic and it can enable
 * one or several channels. One of the channels accesses the peripheral and reads
 * or writes a number of data that matches the watermark level (for example, if
 * the watermark is four words, the channel reads or writes four words). If the
 * channel is effectively executed long after the DMA request was received,
 * reading or writing the watermark number of data may not be sufficient to reset the
 * DMA request (for example, if the FIFO watermark is four and at the channel
 * execution it already contains nine pieces of data). This means no new rising edge
 * may be detected by the SDMA, although there still remains transfers to
 * perform. Therefore, if the channel were terminated at that time, it would not be
 * restarted, causing potential overrun or underrun of the peripheral. The proposed
 * mechanism is for the channel to check this register after it has performed the
 * "watermark" number of accesses to the peripheral. If the bit for the DMA
 * request that triggers this channel is set, it means there is still another
 * watermark number of data to transfer. This goes on until the bit is cleared. The same
 * script can be used for multiple channels that require this behavior. The
 * script can determine its channel number from the CCR register and infer the
 * corresponding DMA request bit to check. It needs a reference table that is coherent
 * with the request-channel matrix that the ARM platform programmed.
 */
typedef union _hw_sdmacore_events
{
    uint32_t U;
    struct _hw_sdmacore_events_bitfields
    {
        uint32_t EVENTS : 32;          /*!< [31:0]  */
    } B;
} hw_sdmacore_events_t;

/*!
 * @name Constants and macros for entire SDMACORE_EVENTS register
 */
/*@{*/
#define HW_SDMACORE_EVENTS_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_SDMACORE_EVENTS(x)    (*(__I hw_sdmacore_events_t *) HW_SDMACORE_EVENTS_ADDR(x))
#define HW_SDMACORE_EVENTS_RD(x) (HW_SDMACORE_EVENTS(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_EVENTS bitfields
 */

/*!
 * @name Register SDMACORE_EVENTS, field EVENTS[31:0] (RO)
 *
 * Reflects the status of the SDMA's external DMA requests. It is meant to allow
 * any channel to monitor the states of these SDMA inputs. This register
 * displays EVENTS 0-31. The EVENTS2 register displays events 32-47.
 */
/*@{*/
#define BP_SDMACORE_EVENTS_EVENTS (0U)     /*!< Bit position for SDMACORE_EVENTS_EVENTS. */
#define BM_SDMACORE_EVENTS_EVENTS (0xFFFFFFFFU) /*!< Bit mask for SDMACORE_EVENTS_EVENTS. */
#define BS_SDMACORE_EVENTS_EVENTS (32U)    /*!< Bit field size in bits for SDMACORE_EVENTS_EVENTS. */

/*! @brief Read current value of the SDMACORE_EVENTS_EVENTS field. */
#define BR_SDMACORE_EVENTS_EVENTS(x) (HW_SDMACORE_EVENTS(x).U)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_CCPRI - Current Channel Priority
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_CCPRI - Current Channel Priority (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_ccpri
{
    uint32_t U;
    struct _hw_sdmacore_ccpri_bitfields
    {
        uint32_t CCPRI : 3;            /*!< [2:0]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_sdmacore_ccpri_t;

/*!
 * @name Constants and macros for entire SDMACORE_CCPRI register
 */
/*@{*/
#define HW_SDMACORE_CCPRI_ADDR(x) ((uintptr_t)(x) + 0x18U)

#define HW_SDMACORE_CCPRI(x)     (*(__I hw_sdmacore_ccpri_t *) HW_SDMACORE_CCPRI_ADDR(x))
#define HW_SDMACORE_CCPRI_RD(x)  (HW_SDMACORE_CCPRI(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_CCPRI bitfields
 */

/*!
 * @name Register SDMACORE_CCPRI, field CCPRI[2:0] (RO)
 *
 * Contains the 3-bit priority of the channel whose context is installed. It is
 * 0 when no channel is running. 1-7 current channel priority
 *
 * Values:
 * - 0 - no running channel
 */
/*@{*/
#define BP_SDMACORE_CCPRI_CCPRI (0U)       /*!< Bit position for SDMACORE_CCPRI_CCPRI. */
#define BM_SDMACORE_CCPRI_CCPRI (0x00000007U) /*!< Bit mask for SDMACORE_CCPRI_CCPRI. */
#define BS_SDMACORE_CCPRI_CCPRI (3U)       /*!< Bit field size in bits for SDMACORE_CCPRI_CCPRI. */

/*! @brief Read current value of the SDMACORE_CCPRI_CCPRI field. */
#define BR_SDMACORE_CCPRI_CCPRI(x) (HW_SDMACORE_CCPRI(x).B.CCPRI)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_NCPRI - Next Channel Priority
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_NCPRI - Next Channel Priority (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_ncpri
{
    uint32_t U;
    struct _hw_sdmacore_ncpri_bitfields
    {
        uint32_t NCPRI : 3;            /*!< [2:0]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_sdmacore_ncpri_t;

/*!
 * @name Constants and macros for entire SDMACORE_NCPRI register
 */
/*@{*/
#define HW_SDMACORE_NCPRI_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_SDMACORE_NCPRI(x)     (*(__I hw_sdmacore_ncpri_t *) HW_SDMACORE_NCPRI_ADDR(x))
#define HW_SDMACORE_NCPRI_RD(x)  (HW_SDMACORE_NCPRI(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_NCPRI bitfields
 */

/*!
 * @name Register SDMACORE_NCPRI, field NCPRI[2:0] (RO)
 *
 * Contains the 3-bit priority of the channel the scheduler has selected to run
 * next. It is 0 when no other channel is pending.
 */
/*@{*/
#define BP_SDMACORE_NCPRI_NCPRI (0U)       /*!< Bit position for SDMACORE_NCPRI_NCPRI. */
#define BM_SDMACORE_NCPRI_NCPRI (0x00000007U) /*!< Bit mask for SDMACORE_NCPRI_NCPRI. */
#define BS_SDMACORE_NCPRI_NCPRI (3U)       /*!< Bit field size in bits for SDMACORE_NCPRI_NCPRI. */

/*! @brief Read current value of the SDMACORE_NCPRI_NCPRI field. */
#define BR_SDMACORE_NCPRI_NCPRI(x) (HW_SDMACORE_NCPRI(x).B.NCPRI)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_ECOUNT - OnCE Event Cell Counter
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_ECOUNT - OnCE Event Cell Counter (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_ecount
{
    uint32_t U;
    struct _hw_sdmacore_ecount_bitfields
    {
        uint32_t ECOUNT : 16;          /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmacore_ecount_t;

/*!
 * @name Constants and macros for entire SDMACORE_ECOUNT register
 */
/*@{*/
#define HW_SDMACORE_ECOUNT_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_SDMACORE_ECOUNT(x)    (*(__IO hw_sdmacore_ecount_t *) HW_SDMACORE_ECOUNT_ADDR(x))
#define HW_SDMACORE_ECOUNT_RD(x) (HW_SDMACORE_ECOUNT(x).U)
#define HW_SDMACORE_ECOUNT_WR(x, v) (HW_SDMACORE_ECOUNT(x).U = (v))
#define HW_SDMACORE_ECOUNT_SET(x, v) (HW_SDMACORE_ECOUNT_WR(x, HW_SDMACORE_ECOUNT_RD(x) |  (v)))
#define HW_SDMACORE_ECOUNT_CLR(x, v) (HW_SDMACORE_ECOUNT_WR(x, HW_SDMACORE_ECOUNT_RD(x) & ~(v)))
#define HW_SDMACORE_ECOUNT_TOG(x, v) (HW_SDMACORE_ECOUNT_WR(x, HW_SDMACORE_ECOUNT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMACORE_ECOUNT bitfields
 */

/*!
 * @name Register SDMACORE_ECOUNT, field ECOUNT[15:0] (RW)
 *
 * The event cell counter contains the number of times minus one that an event
 * detection must occur before generating a debug request. This register should be
 * written before any attempt to use the event detection counter during an event
 * detection process. The counter is cleared on a JTAG reset.
 */
/*@{*/
#define BP_SDMACORE_ECOUNT_ECOUNT (0U)     /*!< Bit position for SDMACORE_ECOUNT_ECOUNT. */
#define BM_SDMACORE_ECOUNT_ECOUNT (0x0000FFFFU) /*!< Bit mask for SDMACORE_ECOUNT_ECOUNT. */
#define BS_SDMACORE_ECOUNT_ECOUNT (16U)    /*!< Bit field size in bits for SDMACORE_ECOUNT_ECOUNT. */

/*! @brief Read current value of the SDMACORE_ECOUNT_ECOUNT field. */
#define BR_SDMACORE_ECOUNT_ECOUNT(x) (HW_SDMACORE_ECOUNT(x).B.ECOUNT)

/*! @brief Format value for bitfield SDMACORE_ECOUNT_ECOUNT. */
#define BF_SDMACORE_ECOUNT_ECOUNT(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ECOUNT_ECOUNT) & BM_SDMACORE_ECOUNT_ECOUNT)

/*! @brief Set the ECOUNT field to a new value. */
#define BW_SDMACORE_ECOUNT_ECOUNT(x, v) (HW_SDMACORE_ECOUNT_WR(x, (HW_SDMACORE_ECOUNT_RD(x) & ~BM_SDMACORE_ECOUNT_ECOUNT) | BF_SDMACORE_ECOUNT_ECOUNT(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_ECTL - OnCE Event Cell Control Register
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_ECTL - OnCE Event Cell Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_ectl
{
    uint32_t U;
    struct _hw_sdmacore_ectl_bitfields
    {
        uint32_t ATS : 2;              /*!< [1:0]  */
        uint32_t AATC : 2;             /*!< [3:2]  */
        uint32_t ABTC : 2;             /*!< [5:4]  */
        uint32_t ATC : 2;              /*!< [7:6]  */
        uint32_t DTC : 2;              /*!< [9:8]  */
        uint32_t ECTC : 2;             /*!< [11:10]  */
        uint32_t CNT : 1;              /*!< [12]  */
        uint32_t EN : 1;               /*!< [13]  */
        uint32_t RESERVED0 : 18;       /*!< [31:14]  */
    } B;
} hw_sdmacore_ectl_t;

/*!
 * @name Constants and macros for entire SDMACORE_ECTL register
 */
/*@{*/
#define HW_SDMACORE_ECTL_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_SDMACORE_ECTL(x)      (*(__IO hw_sdmacore_ectl_t *) HW_SDMACORE_ECTL_ADDR(x))
#define HW_SDMACORE_ECTL_RD(x)   (HW_SDMACORE_ECTL(x).U)
#define HW_SDMACORE_ECTL_WR(x, v) (HW_SDMACORE_ECTL(x).U = (v))
#define HW_SDMACORE_ECTL_SET(x, v) (HW_SDMACORE_ECTL_WR(x, HW_SDMACORE_ECTL_RD(x) |  (v)))
#define HW_SDMACORE_ECTL_CLR(x, v) (HW_SDMACORE_ECTL_WR(x, HW_SDMACORE_ECTL_RD(x) & ~(v)))
#define HW_SDMACORE_ECTL_TOG(x, v) (HW_SDMACORE_ECTL_WR(x, HW_SDMACORE_ECTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMACORE_ECTL bitfields
 */

/*!
 * @name Register SDMACORE_ECTL, field ATS[1:0] (RW)
 *
 * The access type select bits define the memory access type required on the
 * SDMA memory bus.
 *
 * Values:
 * - 00 - read ONLY
 * - 01 - write ONLY
 * - 10 - read or write
 * - 11 - -
 */
/*@{*/
#define BP_SDMACORE_ECTL_ATS (0U)          /*!< Bit position for SDMACORE_ECTL_ATS. */
#define BM_SDMACORE_ECTL_ATS (0x00000003U) /*!< Bit mask for SDMACORE_ECTL_ATS. */
#define BS_SDMACORE_ECTL_ATS (2U)          /*!< Bit field size in bits for SDMACORE_ECTL_ATS. */

/*! @brief Read current value of the SDMACORE_ECTL_ATS field. */
#define BR_SDMACORE_ECTL_ATS(x) (HW_SDMACORE_ECTL(x).B.ATS)

/*! @brief Format value for bitfield SDMACORE_ECTL_ATS. */
#define BF_SDMACORE_ECTL_ATS(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ECTL_ATS) & BM_SDMACORE_ECTL_ATS)

/*! @brief Set the ATS field to a new value. */
#define BW_SDMACORE_ECTL_ATS(x, v) (HW_SDMACORE_ECTL_WR(x, (HW_SDMACORE_ECTL_RD(x) & ~BM_SDMACORE_ECTL_ATS) | BF_SDMACORE_ECTL_ATS(v)))
/*@}*/

/*!
 * @name Register SDMACORE_ECTL, field AATC[3:2] (RW)
 *
 * The Address A Trigger Condition (AATC) controls the operations performed by
 * address comparator A. All operations are performed on unsigned values. This
 * comparator A outputs the addressA condition.
 *
 * Values:
 * - 00 - equal
 * - 01 - not equal
 * - 10 - greater than
 * - 11 - less than
 */
/*@{*/
#define BP_SDMACORE_ECTL_AATC (2U)         /*!< Bit position for SDMACORE_ECTL_AATC. */
#define BM_SDMACORE_ECTL_AATC (0x0000000CU) /*!< Bit mask for SDMACORE_ECTL_AATC. */
#define BS_SDMACORE_ECTL_AATC (2U)         /*!< Bit field size in bits for SDMACORE_ECTL_AATC. */

/*! @brief Read current value of the SDMACORE_ECTL_AATC field. */
#define BR_SDMACORE_ECTL_AATC(x) (HW_SDMACORE_ECTL(x).B.AATC)

/*! @brief Format value for bitfield SDMACORE_ECTL_AATC. */
#define BF_SDMACORE_ECTL_AATC(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ECTL_AATC) & BM_SDMACORE_ECTL_AATC)

/*! @brief Set the AATC field to a new value. */
#define BW_SDMACORE_ECTL_AATC(x, v) (HW_SDMACORE_ECTL_WR(x, (HW_SDMACORE_ECTL_RD(x) & ~BM_SDMACORE_ECTL_AATC) | BF_SDMACORE_ECTL_AATC(v)))
/*@}*/

/*!
 * @name Register SDMACORE_ECTL, field ABTC[5:4] (RW)
 *
 * The Address B Trigger Condition (ABTC) controls the operations performed by
 * address comparator B. All operations are performed on unsigned values. This
 * comparator B outputs the addressB condition.
 *
 * Values:
 * - 00 - equal
 * - 01 - not equal
 * - 10 - greater than
 * - 11 - less than
 */
/*@{*/
#define BP_SDMACORE_ECTL_ABTC (4U)         /*!< Bit position for SDMACORE_ECTL_ABTC. */
#define BM_SDMACORE_ECTL_ABTC (0x00000030U) /*!< Bit mask for SDMACORE_ECTL_ABTC. */
#define BS_SDMACORE_ECTL_ABTC (2U)         /*!< Bit field size in bits for SDMACORE_ECTL_ABTC. */

/*! @brief Read current value of the SDMACORE_ECTL_ABTC field. */
#define BR_SDMACORE_ECTL_ABTC(x) (HW_SDMACORE_ECTL(x).B.ABTC)

/*! @brief Format value for bitfield SDMACORE_ECTL_ABTC. */
#define BF_SDMACORE_ECTL_ABTC(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ECTL_ABTC) & BM_SDMACORE_ECTL_ABTC)

/*! @brief Set the ABTC field to a new value. */
#define BW_SDMACORE_ECTL_ABTC(x, v) (HW_SDMACORE_ECTL_WR(x, (HW_SDMACORE_ECTL_RD(x) & ~BM_SDMACORE_ECTL_ABTC) | BF_SDMACORE_ECTL_ABTC(v)))
/*@}*/

/*!
 * @name Register SDMACORE_ECTL, field ATC[7:6] (RW)
 *
 * The address trigger condition bits select how the two address conditions
 * (addressA and addressB) are combined to define the global address matching
 * condition. The supported combinations are described, as follows.
 *
 * Values:
 * - 00 - addressA ONLY
 * - 01 - addrA AND addrB
 * - 10 - addrA OR addrB
 * - 11 - reserved
 */
/*@{*/
#define BP_SDMACORE_ECTL_ATC (6U)          /*!< Bit position for SDMACORE_ECTL_ATC. */
#define BM_SDMACORE_ECTL_ATC (0x000000C0U) /*!< Bit mask for SDMACORE_ECTL_ATC. */
#define BS_SDMACORE_ECTL_ATC (2U)          /*!< Bit field size in bits for SDMACORE_ECTL_ATC. */

/*! @brief Read current value of the SDMACORE_ECTL_ATC field. */
#define BR_SDMACORE_ECTL_ATC(x) (HW_SDMACORE_ECTL(x).B.ATC)

/*! @brief Format value for bitfield SDMACORE_ECTL_ATC. */
#define BF_SDMACORE_ECTL_ATC(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ECTL_ATC) & BM_SDMACORE_ECTL_ATC)

/*! @brief Set the ATC field to a new value. */
#define BW_SDMACORE_ECTL_ATC(x, v) (HW_SDMACORE_ECTL_WR(x, (HW_SDMACORE_ECTL_RD(x) & ~BM_SDMACORE_ECTL_ATC) | BF_SDMACORE_ECTL_ATC(v)))
/*@}*/

/*!
 * @name Register SDMACORE_ECTL, field DTC[9:8] (RW)
 *
 * The data trigger condition bits define when data is considered matching after
 * comparison with the data register of the event detection unit. The operations
 * are performed on unsigned values.
 *
 * Values:
 * - 00 - equal
 * - 01 - not equal
 * - 10 - greater than
 * - 11 - less than
 */
/*@{*/
#define BP_SDMACORE_ECTL_DTC (8U)          /*!< Bit position for SDMACORE_ECTL_DTC. */
#define BM_SDMACORE_ECTL_DTC (0x00000300U) /*!< Bit mask for SDMACORE_ECTL_DTC. */
#define BS_SDMACORE_ECTL_DTC (2U)          /*!< Bit field size in bits for SDMACORE_ECTL_DTC. */

/*! @brief Read current value of the SDMACORE_ECTL_DTC field. */
#define BR_SDMACORE_ECTL_DTC(x) (HW_SDMACORE_ECTL(x).B.DTC)

/*! @brief Format value for bitfield SDMACORE_ECTL_DTC. */
#define BF_SDMACORE_ECTL_DTC(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ECTL_DTC) & BM_SDMACORE_ECTL_DTC)

/*! @brief Set the DTC field to a new value. */
#define BW_SDMACORE_ECTL_DTC(x, v) (HW_SDMACORE_ECTL_WR(x, (HW_SDMACORE_ECTL_RD(x) & ~BM_SDMACORE_ECTL_DTC) | BF_SDMACORE_ECTL_DTC(v)))
/*@}*/

/*!
 * @name Register SDMACORE_ECTL, field ECTC[11:10] (RW)
 *
 * The event cell trigger condition bits select the combination of address and
 * data matching conditions that generate the final address/data condition. During
 * program execution, if this event cell trigger condition goes to 1, a debug
 * request is sent to the SDMA. The EN bit must be set to enable the debug request
 * generation.
 *
 * Values:
 * - 00 - address ONLY
 * - 01 - data ONLY
 * - 10 - address AND data
 * - 11 - address OR data
 */
/*@{*/
#define BP_SDMACORE_ECTL_ECTC (10U)        /*!< Bit position for SDMACORE_ECTL_ECTC. */
#define BM_SDMACORE_ECTL_ECTC (0x00000C00U) /*!< Bit mask for SDMACORE_ECTL_ECTC. */
#define BS_SDMACORE_ECTL_ECTC (2U)         /*!< Bit field size in bits for SDMACORE_ECTL_ECTC. */

/*! @brief Read current value of the SDMACORE_ECTL_ECTC field. */
#define BR_SDMACORE_ECTL_ECTC(x) (HW_SDMACORE_ECTL(x).B.ECTC)

/*! @brief Format value for bitfield SDMACORE_ECTL_ECTC. */
#define BF_SDMACORE_ECTL_ECTC(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ECTL_ECTC) & BM_SDMACORE_ECTL_ECTC)

/*! @brief Set the ECTC field to a new value. */
#define BW_SDMACORE_ECTL_ECTC(x, v) (HW_SDMACORE_ECTL_WR(x, (HW_SDMACORE_ECTL_RD(x) & ~BM_SDMACORE_ECTL_ECTC) | BF_SDMACORE_ECTL_ECTC(v)))
/*@}*/

/*!
 * @name Register SDMACORE_ECTL, field CNT[12] (RW)
 *
 * Event Counter Enable. The event counter enable bit determines if the cell
 * counter is used during the event detection. In order to use the event counter
 * during an event detection process, the event cell counter register should be
 * loaded with a value equal to the number of times minus one that an event occurs
 * before a debug request is sent. After every event detection, the counter is
 * decreased. When the counter reaches the value 0, the event detection cell sends a
 * debug request to the core. The event counter register should be written and
 * the EN bit should be set before each new event detection process uses the event
 * counter.
 *
 * Values:
 * - 0 - Counter is disabled.
 * - 1 - Counter is enabled.
 */
/*@{*/
#define BP_SDMACORE_ECTL_CNT (12U)         /*!< Bit position for SDMACORE_ECTL_CNT. */
#define BM_SDMACORE_ECTL_CNT (0x00001000U) /*!< Bit mask for SDMACORE_ECTL_CNT. */
#define BS_SDMACORE_ECTL_CNT (1U)          /*!< Bit field size in bits for SDMACORE_ECTL_CNT. */

/*! @brief Read current value of the SDMACORE_ECTL_CNT field. */
#define BR_SDMACORE_ECTL_CNT(x) (HW_SDMACORE_ECTL(x).B.CNT)

/*! @brief Format value for bitfield SDMACORE_ECTL_CNT. */
#define BF_SDMACORE_ECTL_CNT(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ECTL_CNT) & BM_SDMACORE_ECTL_CNT)

/*! @brief Set the CNT field to a new value. */
#define BW_SDMACORE_ECTL_CNT(x, v) (HW_SDMACORE_ECTL_WR(x, (HW_SDMACORE_ECTL_RD(x) & ~BM_SDMACORE_ECTL_CNT) | BF_SDMACORE_ECTL_CNT(v)))
/*@}*/

/*!
 * @name Register SDMACORE_ECTL, field EN[13] (RW)
 *
 * Event Cell Enable. If the EN bit is set, the event cell is allowed to
 * generate debug requests (the cell is awakened). If it is cleared, the event detection
 * unit is disabled and no hardware breakpoint is generated, but matching
 * conditions are still reflected on the emulation pin.
 *
 * Values:
 * - 0 - Cell is disabled.
 * - 1 - Cell is enabled.
 */
/*@{*/
#define BP_SDMACORE_ECTL_EN  (13U)         /*!< Bit position for SDMACORE_ECTL_EN. */
#define BM_SDMACORE_ECTL_EN  (0x00002000U) /*!< Bit mask for SDMACORE_ECTL_EN. */
#define BS_SDMACORE_ECTL_EN  (1U)          /*!< Bit field size in bits for SDMACORE_ECTL_EN. */

/*! @brief Read current value of the SDMACORE_ECTL_EN field. */
#define BR_SDMACORE_ECTL_EN(x) (HW_SDMACORE_ECTL(x).B.EN)

/*! @brief Format value for bitfield SDMACORE_ECTL_EN. */
#define BF_SDMACORE_ECTL_EN(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ECTL_EN) & BM_SDMACORE_ECTL_EN)

/*! @brief Set the EN field to a new value. */
#define BW_SDMACORE_ECTL_EN(x, v) (HW_SDMACORE_ECTL_WR(x, (HW_SDMACORE_ECTL_RD(x) & ~BM_SDMACORE_ECTL_EN) | BF_SDMACORE_ECTL_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_EAA - OnCE Event Address Register A
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_EAA - OnCE Event Address Register A (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_eaa
{
    uint32_t U;
    struct _hw_sdmacore_eaa_bitfields
    {
        uint32_t EAA : 16;             /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmacore_eaa_t;

/*!
 * @name Constants and macros for entire SDMACORE_EAA register
 */
/*@{*/
#define HW_SDMACORE_EAA_ADDR(x)  ((uintptr_t)(x) + 0x28U)

#define HW_SDMACORE_EAA(x)       (*(__IO hw_sdmacore_eaa_t *) HW_SDMACORE_EAA_ADDR(x))
#define HW_SDMACORE_EAA_RD(x)    (HW_SDMACORE_EAA(x).U)
#define HW_SDMACORE_EAA_WR(x, v) (HW_SDMACORE_EAA(x).U = (v))
#define HW_SDMACORE_EAA_SET(x, v) (HW_SDMACORE_EAA_WR(x, HW_SDMACORE_EAA_RD(x) |  (v)))
#define HW_SDMACORE_EAA_CLR(x, v) (HW_SDMACORE_EAA_WR(x, HW_SDMACORE_EAA_RD(x) & ~(v)))
#define HW_SDMACORE_EAA_TOG(x, v) (HW_SDMACORE_EAA_WR(x, HW_SDMACORE_EAA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMACORE_EAA bitfields
 */

/*!
 * @name Register SDMACORE_EAA, field EAA[15:0] (RW)
 *
 * Event Cell Address Register A computes an address A condition. It is cleared
 * on a JTAG reset.
 */
/*@{*/
#define BP_SDMACORE_EAA_EAA  (0U)          /*!< Bit position for SDMACORE_EAA_EAA. */
#define BM_SDMACORE_EAA_EAA  (0x0000FFFFU) /*!< Bit mask for SDMACORE_EAA_EAA. */
#define BS_SDMACORE_EAA_EAA  (16U)         /*!< Bit field size in bits for SDMACORE_EAA_EAA. */

/*! @brief Read current value of the SDMACORE_EAA_EAA field. */
#define BR_SDMACORE_EAA_EAA(x) (HW_SDMACORE_EAA(x).B.EAA)

/*! @brief Format value for bitfield SDMACORE_EAA_EAA. */
#define BF_SDMACORE_EAA_EAA(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_EAA_EAA) & BM_SDMACORE_EAA_EAA)

/*! @brief Set the EAA field to a new value. */
#define BW_SDMACORE_EAA_EAA(x, v) (HW_SDMACORE_EAA_WR(x, (HW_SDMACORE_EAA_RD(x) & ~BM_SDMACORE_EAA_EAA) | BF_SDMACORE_EAA_EAA(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_EAB - OnCE Event Cell Address Register B
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_EAB - OnCE Event Cell Address Register B (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_eab
{
    uint32_t U;
    struct _hw_sdmacore_eab_bitfields
    {
        uint32_t EAB : 16;             /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmacore_eab_t;

/*!
 * @name Constants and macros for entire SDMACORE_EAB register
 */
/*@{*/
#define HW_SDMACORE_EAB_ADDR(x)  ((uintptr_t)(x) + 0x2CU)

#define HW_SDMACORE_EAB(x)       (*(__IO hw_sdmacore_eab_t *) HW_SDMACORE_EAB_ADDR(x))
#define HW_SDMACORE_EAB_RD(x)    (HW_SDMACORE_EAB(x).U)
#define HW_SDMACORE_EAB_WR(x, v) (HW_SDMACORE_EAB(x).U = (v))
#define HW_SDMACORE_EAB_SET(x, v) (HW_SDMACORE_EAB_WR(x, HW_SDMACORE_EAB_RD(x) |  (v)))
#define HW_SDMACORE_EAB_CLR(x, v) (HW_SDMACORE_EAB_WR(x, HW_SDMACORE_EAB_RD(x) & ~(v)))
#define HW_SDMACORE_EAB_TOG(x, v) (HW_SDMACORE_EAB_WR(x, HW_SDMACORE_EAB_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMACORE_EAB bitfields
 */

/*!
 * @name Register SDMACORE_EAB, field EAB[15:0] (RW)
 *
 * Event Cell Address Register B computes an address B condition. It is cleared
 * on a JTAG reset.
 */
/*@{*/
#define BP_SDMACORE_EAB_EAB  (0U)          /*!< Bit position for SDMACORE_EAB_EAB. */
#define BM_SDMACORE_EAB_EAB  (0x0000FFFFU) /*!< Bit mask for SDMACORE_EAB_EAB. */
#define BS_SDMACORE_EAB_EAB  (16U)         /*!< Bit field size in bits for SDMACORE_EAB_EAB. */

/*! @brief Read current value of the SDMACORE_EAB_EAB field. */
#define BR_SDMACORE_EAB_EAB(x) (HW_SDMACORE_EAB(x).B.EAB)

/*! @brief Format value for bitfield SDMACORE_EAB_EAB. */
#define BF_SDMACORE_EAB_EAB(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_EAB_EAB) & BM_SDMACORE_EAB_EAB)

/*! @brief Set the EAB field to a new value. */
#define BW_SDMACORE_EAB_EAB(x, v) (HW_SDMACORE_EAB_WR(x, (HW_SDMACORE_EAB_RD(x) & ~BM_SDMACORE_EAB_EAB) | BF_SDMACORE_EAB_EAB(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_EAM - OnCE Event Cell Address Mask
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_EAM - OnCE Event Cell Address Mask (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_eam
{
    uint32_t U;
    struct _hw_sdmacore_eam_bitfields
    {
        uint32_t EAM : 16;             /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmacore_eam_t;

/*!
 * @name Constants and macros for entire SDMACORE_EAM register
 */
/*@{*/
#define HW_SDMACORE_EAM_ADDR(x)  ((uintptr_t)(x) + 0x30U)

#define HW_SDMACORE_EAM(x)       (*(__IO hw_sdmacore_eam_t *) HW_SDMACORE_EAM_ADDR(x))
#define HW_SDMACORE_EAM_RD(x)    (HW_SDMACORE_EAM(x).U)
#define HW_SDMACORE_EAM_WR(x, v) (HW_SDMACORE_EAM(x).U = (v))
#define HW_SDMACORE_EAM_SET(x, v) (HW_SDMACORE_EAM_WR(x, HW_SDMACORE_EAM_RD(x) |  (v)))
#define HW_SDMACORE_EAM_CLR(x, v) (HW_SDMACORE_EAM_WR(x, HW_SDMACORE_EAM_RD(x) & ~(v)))
#define HW_SDMACORE_EAM_TOG(x, v) (HW_SDMACORE_EAM_WR(x, HW_SDMACORE_EAM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMACORE_EAM bitfields
 */

/*!
 * @name Register SDMACORE_EAM, field EAM[15:0] (RW)
 *
 * The Event Cell Address Mask contains a user-defined address mask value. This
 * mask is applied to the address value latched from the memory address bus
 * before performing the address comparison. There is a common address mask value for
 * both address comparators. If bit i of this register is set, then bit i of the
 * address value latched from the memory bus does not influence the result of the
 * address comparison. The register is cleared on a JTAG reset.
 */
/*@{*/
#define BP_SDMACORE_EAM_EAM  (0U)          /*!< Bit position for SDMACORE_EAM_EAM. */
#define BM_SDMACORE_EAM_EAM  (0x0000FFFFU) /*!< Bit mask for SDMACORE_EAM_EAM. */
#define BS_SDMACORE_EAM_EAM  (16U)         /*!< Bit field size in bits for SDMACORE_EAM_EAM. */

/*! @brief Read current value of the SDMACORE_EAM_EAM field. */
#define BR_SDMACORE_EAM_EAM(x) (HW_SDMACORE_EAM(x).B.EAM)

/*! @brief Format value for bitfield SDMACORE_EAM_EAM. */
#define BF_SDMACORE_EAM_EAM(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_EAM_EAM) & BM_SDMACORE_EAM_EAM)

/*! @brief Set the EAM field to a new value. */
#define BW_SDMACORE_EAM_EAM(x, v) (HW_SDMACORE_EAM_WR(x, (HW_SDMACORE_EAM_RD(x) & ~BM_SDMACORE_EAM_EAM) | BF_SDMACORE_EAM_EAM(v)))
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_ED - OnCE Event Cell Data Register
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_ED - OnCE Event Cell Data Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_ed
{
    uint32_t U;
    struct _hw_sdmacore_ed_bitfields
    {
        uint32_t ED : 32;              /*!< [31:0]  */
    } B;
} hw_sdmacore_ed_t;

/*!
 * @name Constants and macros for entire SDMACORE_ED register
 */
/*@{*/
#define HW_SDMACORE_ED_ADDR(x)   ((uintptr_t)(x) + 0x34U)

#define HW_SDMACORE_ED(x)        (*(__IO hw_sdmacore_ed_t *) HW_SDMACORE_ED_ADDR(x))
#define HW_SDMACORE_ED_RD(x)     (HW_SDMACORE_ED(x).U)
#define HW_SDMACORE_ED_WR(x, v)  (HW_SDMACORE_ED(x).U = (v))
#define HW_SDMACORE_ED_SET(x, v) (HW_SDMACORE_ED_WR(x, HW_SDMACORE_ED_RD(x) |  (v)))
#define HW_SDMACORE_ED_CLR(x, v) (HW_SDMACORE_ED_WR(x, HW_SDMACORE_ED_RD(x) & ~(v)))
#define HW_SDMACORE_ED_TOG(x, v) (HW_SDMACORE_ED_WR(x, HW_SDMACORE_ED_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMACORE_ED bitfields
 */

/*!
 * @name Register SDMACORE_ED, field ED[31:0] (RW)
 *
 * The event cell data register contains a user defined data value. This data
 * value is an input for the data comparator which generates the data condition. It
 * is cleared on a JTAG reset.
 */
/*@{*/
#define BP_SDMACORE_ED_ED    (0U)          /*!< Bit position for SDMACORE_ED_ED. */
#define BM_SDMACORE_ED_ED    (0xFFFFFFFFU) /*!< Bit mask for SDMACORE_ED_ED. */
#define BS_SDMACORE_ED_ED    (32U)         /*!< Bit field size in bits for SDMACORE_ED_ED. */

/*! @brief Read current value of the SDMACORE_ED_ED field. */
#define BR_SDMACORE_ED_ED(x) (HW_SDMACORE_ED(x).U)

/*! @brief Format value for bitfield SDMACORE_ED_ED. */
#define BF_SDMACORE_ED_ED(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_ED_ED) & BM_SDMACORE_ED_ED)

/*! @brief Set the ED field to a new value. */
#define BW_SDMACORE_ED_ED(x, v) (HW_SDMACORE_ED_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_EDM - OnCE Event Cell Data Mask
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_EDM - OnCE Event Cell Data Mask (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_edm
{
    uint32_t U;
    struct _hw_sdmacore_edm_bitfields
    {
        uint32_t EDM : 32;             /*!< [31:0]  */
    } B;
} hw_sdmacore_edm_t;

/*!
 * @name Constants and macros for entire SDMACORE_EDM register
 */
/*@{*/
#define HW_SDMACORE_EDM_ADDR(x)  ((uintptr_t)(x) + 0x38U)

#define HW_SDMACORE_EDM(x)       (*(__IO hw_sdmacore_edm_t *) HW_SDMACORE_EDM_ADDR(x))
#define HW_SDMACORE_EDM_RD(x)    (HW_SDMACORE_EDM(x).U)
#define HW_SDMACORE_EDM_WR(x, v) (HW_SDMACORE_EDM(x).U = (v))
#define HW_SDMACORE_EDM_SET(x, v) (HW_SDMACORE_EDM_WR(x, HW_SDMACORE_EDM_RD(x) |  (v)))
#define HW_SDMACORE_EDM_CLR(x, v) (HW_SDMACORE_EDM_WR(x, HW_SDMACORE_EDM_RD(x) & ~(v)))
#define HW_SDMACORE_EDM_TOG(x, v) (HW_SDMACORE_EDM_WR(x, HW_SDMACORE_EDM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMACORE_EDM bitfields
 */

/*!
 * @name Register SDMACORE_EDM, field EDM[31:0] (RW)
 *
 * The event cell data mask register contains the user-defined data mask value.
 * This mask is applied to the data value latched from the memory bus before
 * performing the data comparison. Setting bit i of the event cell data mask register
 * means that bit i of the data value latched from the address bus does not
 * influence the result of the data comparison. The data mask is cleared on a JTAG
 * reset.
 */
/*@{*/
#define BP_SDMACORE_EDM_EDM  (0U)          /*!< Bit position for SDMACORE_EDM_EDM. */
#define BM_SDMACORE_EDM_EDM  (0xFFFFFFFFU) /*!< Bit mask for SDMACORE_EDM_EDM. */
#define BS_SDMACORE_EDM_EDM  (32U)         /*!< Bit field size in bits for SDMACORE_EDM_EDM. */

/*! @brief Read current value of the SDMACORE_EDM_EDM field. */
#define BR_SDMACORE_EDM_EDM(x) (HW_SDMACORE_EDM(x).U)

/*! @brief Format value for bitfield SDMACORE_EDM_EDM. */
#define BF_SDMACORE_EDM_EDM(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_EDM_EDM) & BM_SDMACORE_EDM_EDM)

/*! @brief Set the EDM field to a new value. */
#define BW_SDMACORE_EDM_EDM(x, v) (HW_SDMACORE_EDM_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_RTB - OnCE Real-Time Buffer
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_RTB - OnCE Real-Time Buffer (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_rtb
{
    uint32_t U;
    struct _hw_sdmacore_rtb_bitfields
    {
        uint32_t RTB : 32;             /*!< [31:0]  */
    } B;
} hw_sdmacore_rtb_t;

/*!
 * @name Constants and macros for entire SDMACORE_RTB register
 */
/*@{*/
#define HW_SDMACORE_RTB_ADDR(x)  ((uintptr_t)(x) + 0x3CU)

#define HW_SDMACORE_RTB(x)       (*(__IO hw_sdmacore_rtb_t *) HW_SDMACORE_RTB_ADDR(x))
#define HW_SDMACORE_RTB_RD(x)    (HW_SDMACORE_RTB(x).U)
#define HW_SDMACORE_RTB_WR(x, v) (HW_SDMACORE_RTB(x).U = (v))
#define HW_SDMACORE_RTB_SET(x, v) (HW_SDMACORE_RTB_WR(x, HW_SDMACORE_RTB_RD(x) |  (v)))
#define HW_SDMACORE_RTB_CLR(x, v) (HW_SDMACORE_RTB_WR(x, HW_SDMACORE_RTB_RD(x) & ~(v)))
#define HW_SDMACORE_RTB_TOG(x, v) (HW_SDMACORE_RTB_WR(x, HW_SDMACORE_RTB_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SDMACORE_RTB bitfields
 */

/*!
 * @name Register SDMACORE_RTB, field RTB[31:0] (RW)
 *
 * The Real Time Buffer register stores and retrieves run time information
 * without putting the SDMA in debug mode. Writing to that register triggers a pulse
 * on a specific real-time debug pin whose connection depends on the chip
 * implementation. The RTB value can be accessed by the OnCE under ARM platform or JTAG
 * control using the rbuffer command.
 */
/*@{*/
#define BP_SDMACORE_RTB_RTB  (0U)          /*!< Bit position for SDMACORE_RTB_RTB. */
#define BM_SDMACORE_RTB_RTB  (0xFFFFFFFFU) /*!< Bit mask for SDMACORE_RTB_RTB. */
#define BS_SDMACORE_RTB_RTB  (32U)         /*!< Bit field size in bits for SDMACORE_RTB_RTB. */

/*! @brief Read current value of the SDMACORE_RTB_RTB field. */
#define BR_SDMACORE_RTB_RTB(x) (HW_SDMACORE_RTB(x).U)

/*! @brief Format value for bitfield SDMACORE_RTB_RTB. */
#define BF_SDMACORE_RTB_RTB(v) ((uint32_t)((uint32_t)(v) << BP_SDMACORE_RTB_RTB) & BM_SDMACORE_RTB_RTB)

/*! @brief Set the RTB field to a new value. */
#define BW_SDMACORE_RTB_RTB(x, v) (HW_SDMACORE_RTB_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_TB - OnCE Trace Buffer
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_TB - OnCE Trace Buffer (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_tb
{
    uint32_t U;
    struct _hw_sdmacore_tb_bitfields
    {
        uint32_t CHFADDR : 14;         /*!< [13:0]  */
        uint32_t TADDR : 14;           /*!< [27:14]  */
        uint32_t TBF : 1;              /*!< [28]  */
        uint32_t RESERVED0 : 3;        /*!< [31:29]  */
    } B;
} hw_sdmacore_tb_t;

/*!
 * @name Constants and macros for entire SDMACORE_TB register
 */
/*@{*/
#define HW_SDMACORE_TB_ADDR(x)   ((uintptr_t)(x) + 0x40U)

#define HW_SDMACORE_TB(x)        (*(__I hw_sdmacore_tb_t *) HW_SDMACORE_TB_ADDR(x))
#define HW_SDMACORE_TB_RD(x)     (HW_SDMACORE_TB(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_TB bitfields
 */

/*!
 * @name Register SDMACORE_TB, field CHFADDR[13:0] (RO)
 *
 * The change of flow address is the address where the change of flow is taken
 * when executing a change of flow instruction.
 */
/*@{*/
#define BP_SDMACORE_TB_CHFADDR (0U)        /*!< Bit position for SDMACORE_TB_CHFADDR. */
#define BM_SDMACORE_TB_CHFADDR (0x00003FFFU) /*!< Bit mask for SDMACORE_TB_CHFADDR. */
#define BS_SDMACORE_TB_CHFADDR (14U)       /*!< Bit field size in bits for SDMACORE_TB_CHFADDR. */

/*! @brief Read current value of the SDMACORE_TB_CHFADDR field. */
#define BR_SDMACORE_TB_CHFADDR(x) (HW_SDMACORE_TB(x).B.CHFADDR)
/*@}*/

/*!
 * @name Register SDMACORE_TB, field TADDR[27:14] (RO)
 *
 * The target address is the address taken after the execution of the change of
 * flow instruction.
 */
/*@{*/
#define BP_SDMACORE_TB_TADDR (14U)         /*!< Bit position for SDMACORE_TB_TADDR. */
#define BM_SDMACORE_TB_TADDR (0x0FFFC000U) /*!< Bit mask for SDMACORE_TB_TADDR. */
#define BS_SDMACORE_TB_TADDR (14U)         /*!< Bit field size in bits for SDMACORE_TB_TADDR. */

/*! @brief Read current value of the SDMACORE_TB_TADDR field. */
#define BR_SDMACORE_TB_TADDR(x) (HW_SDMACORE_TB(x).B.TADDR)
/*@}*/

/*!
 * @name Register SDMACORE_TB, field TBF[28] (RO)
 *
 * The Trace Buffer Flag is set when the buffer contains the addresses of a
 * valid change of flow. The contents of the buffer should be ignored otherwise.
 *
 * Values:
 * - 0 - Invalid information
 * - 1 - Valid information
 */
/*@{*/
#define BP_SDMACORE_TB_TBF   (28U)         /*!< Bit position for SDMACORE_TB_TBF. */
#define BM_SDMACORE_TB_TBF   (0x10000000U) /*!< Bit mask for SDMACORE_TB_TBF. */
#define BS_SDMACORE_TB_TBF   (1U)          /*!< Bit field size in bits for SDMACORE_TB_TBF. */

/*! @brief Read current value of the SDMACORE_TB_TBF field. */
#define BR_SDMACORE_TB_TBF(x) (HW_SDMACORE_TB(x).B.TBF)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_OSTAT - OnCE Status
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_OSTAT - OnCE Status (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_ostat
{
    uint32_t U;
    struct _hw_sdmacore_ostat_bitfields
    {
        uint32_t ECDR : 3;             /*!< [2:0]  */
        uint32_t RESERVED0 : 4;        /*!< [6:3]  */
        uint32_t MST : 1;              /*!< [7]  */
        uint32_t SWB : 1;              /*!< [8]  */
        uint32_t ODR : 1;              /*!< [9]  */
        uint32_t EDR : 1;              /*!< [10]  */
        uint32_t RCV : 1;              /*!< [11]  */
        uint32_t PST : 4;              /*!< [15:12]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmacore_ostat_t;

/*!
 * @name Constants and macros for entire SDMACORE_OSTAT register
 */
/*@{*/
#define HW_SDMACORE_OSTAT_ADDR(x) ((uintptr_t)(x) + 0x44U)

#define HW_SDMACORE_OSTAT(x)     (*(__I hw_sdmacore_ostat_t *) HW_SDMACORE_OSTAT_ADDR(x))
#define HW_SDMACORE_OSTAT_RD(x)  (HW_SDMACORE_OSTAT(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_OSTAT bitfields
 */

/*!
 * @name Register SDMACORE_OSTAT, field ECDR[2:0] (RO)
 *
 * Event Cell Debug Request. If the debug request comes from the event cell, the
 * reason for entering debug mode is given by the EDR bits. The encoding of the
 * EDR bits is useful to find out more precisely why the debug request was
 * generated. A debug request from an event cell is generated for a specific
 * combination of the addressA, addressB, and data conditions; the value of those fields is
 * given by the EDR bits. If all three bits of the EDR are reset, then it did
 * not generate any debug request. If the cell did generate a debug request, then
 * at least one EDR bit is set; the meaning of the encoding is as follows:
 *
 * Values:
 * - 0 - 1 matched addressA condition
 * - 1 - 1 matched addressB condition
 */
/*@{*/
#define BP_SDMACORE_OSTAT_ECDR (0U)        /*!< Bit position for SDMACORE_OSTAT_ECDR. */
#define BM_SDMACORE_OSTAT_ECDR (0x00000007U) /*!< Bit mask for SDMACORE_OSTAT_ECDR. */
#define BS_SDMACORE_OSTAT_ECDR (3U)        /*!< Bit field size in bits for SDMACORE_OSTAT_ECDR. */

/*! @brief Read current value of the SDMACORE_OSTAT_ECDR field. */
#define BR_SDMACORE_OSTAT_ECDR(x) (HW_SDMACORE_OSTAT(x).B.ECDR)
/*@}*/

/*!
 * @name Register SDMACORE_OSTAT, field MST[7] (RO)
 *
 * This flag is raised when the OnCE is controlled from the ARM platform
 * peripheral interface.
 *
 * Values:
 * - 0 - JTAG interface controls the OnCE.
 * - 1 - ARM platform peripheral interface controls the OnCE.
 */
/*@{*/
#define BP_SDMACORE_OSTAT_MST (7U)         /*!< Bit position for SDMACORE_OSTAT_MST. */
#define BM_SDMACORE_OSTAT_MST (0x00000080U) /*!< Bit mask for SDMACORE_OSTAT_MST. */
#define BS_SDMACORE_OSTAT_MST (1U)         /*!< Bit field size in bits for SDMACORE_OSTAT_MST. */

/*! @brief Read current value of the SDMACORE_OSTAT_MST field. */
#define BR_SDMACORE_OSTAT_MST(x) (HW_SDMACORE_OSTAT(x).B.MST)
/*@}*/

/*!
 * @name Register SDMACORE_OSTAT, field SWB[8] (RO)
 *
 * This flag is raised when the SDMA has entered debug mode after a software
 * breakpoint.
 */
/*@{*/
#define BP_SDMACORE_OSTAT_SWB (8U)         /*!< Bit position for SDMACORE_OSTAT_SWB. */
#define BM_SDMACORE_OSTAT_SWB (0x00000100U) /*!< Bit mask for SDMACORE_OSTAT_SWB. */
#define BS_SDMACORE_OSTAT_SWB (1U)         /*!< Bit field size in bits for SDMACORE_OSTAT_SWB. */

/*! @brief Read current value of the SDMACORE_OSTAT_SWB field. */
#define BR_SDMACORE_OSTAT_SWB(x) (HW_SDMACORE_OSTAT(x).B.SWB)
/*@}*/

/*!
 * @name Register SDMACORE_OSTAT, field ODR[9] (RO)
 *
 * This flag is raised when the SDMA has entered debug mode after a OnCE debug
 * request.
 */
/*@{*/
#define BP_SDMACORE_OSTAT_ODR (9U)         /*!< Bit position for SDMACORE_OSTAT_ODR. */
#define BM_SDMACORE_OSTAT_ODR (0x00000200U) /*!< Bit mask for SDMACORE_OSTAT_ODR. */
#define BS_SDMACORE_OSTAT_ODR (1U)         /*!< Bit field size in bits for SDMACORE_OSTAT_ODR. */

/*! @brief Read current value of the SDMACORE_OSTAT_ODR field. */
#define BR_SDMACORE_OSTAT_ODR(x) (HW_SDMACORE_OSTAT(x).B.ODR)
/*@}*/

/*!
 * @name Register SDMACORE_OSTAT, field EDR[10] (RO)
 *
 * This flag is raised when the SDMA has entered debug mode after an external
 * debug request.
 */
/*@{*/
#define BP_SDMACORE_OSTAT_EDR (10U)        /*!< Bit position for SDMACORE_OSTAT_EDR. */
#define BM_SDMACORE_OSTAT_EDR (0x00000400U) /*!< Bit mask for SDMACORE_OSTAT_EDR. */
#define BS_SDMACORE_OSTAT_EDR (1U)         /*!< Bit field size in bits for SDMACORE_OSTAT_EDR. */

/*! @brief Read current value of the SDMACORE_OSTAT_EDR field. */
#define BR_SDMACORE_OSTAT_EDR(x) (HW_SDMACORE_OSTAT(x).B.EDR)
/*@}*/

/*!
 * @name Register SDMACORE_OSTAT, field RCV[11] (RO)
 *
 * After each write access to the real time buffer (RTB), the RCV bit is set.
 * This bit is cleared after execution of an rbuffer command and on a JTAG reset.
 */
/*@{*/
#define BP_SDMACORE_OSTAT_RCV (11U)        /*!< Bit position for SDMACORE_OSTAT_RCV. */
#define BM_SDMACORE_OSTAT_RCV (0x00000800U) /*!< Bit mask for SDMACORE_OSTAT_RCV. */
#define BS_SDMACORE_OSTAT_RCV (1U)         /*!< Bit field size in bits for SDMACORE_OSTAT_RCV. */

/*! @brief Read current value of the SDMACORE_OSTAT_RCV field. */
#define BR_SDMACORE_OSTAT_RCV(x) (HW_SDMACORE_OSTAT(x).B.RCV)
/*@}*/

/*!
 * @name Register SDMACORE_OSTAT, field PST[15:12] (RO)
 *
 * The Processor Status bits reflect the state of the SDMA RISC engine. The
 * "Program" state is the usual instruction execution cycle. The "Data" state is
 * inserted when there are wait-states during a load or a store on the data bus (ld
 * or st). The "Change of Flow" state is the second cycle of any instruction that
 * breaks the sequence of instructions (jumps and channel-switching
 * instructions). The "Change of Flow in Loop" state is used when an error causes a hardware
 * loop exit. The "Debug" state means the SDMA is in debug mode. The "Functional
 * Unit" state is inserted when there are wait-states during a load or a store on
 * the functional units bus (ldf or stf). In "Sleep" modes, no script is running
 * (this is the RISC engine idle state). The "after Reset" is slightly different
 * because no context restoring phase will happen when a channel is triggered:
 * The script located at address 0 will be executed (boot operation). The "in
 * Sleep" states are the same as above except they do not have any corresponding
 * channel. They are used when entering debug mode after reset; the reason is that it
 * is necessary to return to the "Sleep after Reset" state when leaving debug
 * mode.
 *
 * Values:
 * - 0 - Program
 * - 1 - Data
 * - 10 - Change of Flow in Sleep
 * - 11 - Change Flow Loop Sleep
 */
/*@{*/
#define BP_SDMACORE_OSTAT_PST (12U)        /*!< Bit position for SDMACORE_OSTAT_PST. */
#define BM_SDMACORE_OSTAT_PST (0x0000F000U) /*!< Bit mask for SDMACORE_OSTAT_PST. */
#define BS_SDMACORE_OSTAT_PST (4U)         /*!< Bit field size in bits for SDMACORE_OSTAT_PST. */

/*! @brief Read current value of the SDMACORE_OSTAT_PST field. */
#define BR_SDMACORE_OSTAT_PST(x) (HW_SDMACORE_OSTAT(x).B.PST)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_MCHN0ADDR - Channel 0 Boot Address
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_MCHN0ADDR - Channel 0 Boot Address (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_mchn0addr
{
    uint32_t U;
    struct _hw_sdmacore_mchn0addr_bitfields
    {
        uint32_t CHN0ADDR : 14;        /*!< [13:0]  */
        uint32_t SMSZ : 1;             /*!< [14]  */
        uint32_t RESERVED0 : 17;       /*!< [31:15]  */
    } B;
} hw_sdmacore_mchn0addr_t;

/*!
 * @name Constants and macros for entire SDMACORE_MCHN0ADDR register
 */
/*@{*/
#define HW_SDMACORE_MCHN0ADDR_ADDR(x) ((uintptr_t)(x) + 0x48U)

#define HW_SDMACORE_MCHN0ADDR(x) (*(__I hw_sdmacore_mchn0addr_t *) HW_SDMACORE_MCHN0ADDR_ADDR(x))
#define HW_SDMACORE_MCHN0ADDR_RD(x) (HW_SDMACORE_MCHN0ADDR(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_MCHN0ADDR bitfields
 */

/*!
 * @name Register SDMACORE_MCHN0ADDR, field CHN0ADDR[13:0] (RO)
 *
 * Contains the address of the channel 0 routine programmed by the ARM platform;
 * it is loaded into a general register at the very start of the boot and the
 * SDMA jumps to the address it contains. By default, it points to the standard
 * boot routine in ROM.
 */
/*@{*/
#define BP_SDMACORE_MCHN0ADDR_CHN0ADDR (0U) /*!< Bit position for SDMACORE_MCHN0ADDR_CHN0ADDR. */
#define BM_SDMACORE_MCHN0ADDR_CHN0ADDR (0x00003FFFU) /*!< Bit mask for SDMACORE_MCHN0ADDR_CHN0ADDR. */
#define BS_SDMACORE_MCHN0ADDR_CHN0ADDR (14U) /*!< Bit field size in bits for SDMACORE_MCHN0ADDR_CHN0ADDR. */

/*! @brief Read current value of the SDMACORE_MCHN0ADDR_CHN0ADDR field. */
#define BR_SDMACORE_MCHN0ADDR_CHN0ADDR(x) (HW_SDMACORE_MCHN0ADDR(x).B.CHN0ADDR)
/*@}*/

/*!
 * @name Register SDMACORE_MCHN0ADDR, field SMSZ[14] (RO)
 *
 * The bit 14 (Scratch Memory Size) determines if scratch memory must be
 * available after every channel context. After reset, it is equal to 0, which defines a
 * RAM space of 24 words for each channel. All of this area stores the channel
 * context. By setting this bit, 32 words are reserved for every channel context,
 * which gives eight additional words that can be used by the channel script to
 * store any type of data. Those words are never erased by the context switching
 * mechanism.
 *
 * Values:
 * - 0 - 24 words per context
 * - 1 - 32 words per context
 */
/*@{*/
#define BP_SDMACORE_MCHN0ADDR_SMSZ (14U)   /*!< Bit position for SDMACORE_MCHN0ADDR_SMSZ. */
#define BM_SDMACORE_MCHN0ADDR_SMSZ (0x00004000U) /*!< Bit mask for SDMACORE_MCHN0ADDR_SMSZ. */
#define BS_SDMACORE_MCHN0ADDR_SMSZ (1U)    /*!< Bit field size in bits for SDMACORE_MCHN0ADDR_SMSZ. */

/*! @brief Read current value of the SDMACORE_MCHN0ADDR_SMSZ field. */
#define BR_SDMACORE_MCHN0ADDR_SMSZ(x) (HW_SDMACORE_MCHN0ADDR(x).B.SMSZ)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_ENDIANNESS - ENDIAN Status Register
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_ENDIANNESS - ENDIAN Status Register (RO)
 *
 * Reset value: 0x00000001U
 */
typedef union _hw_sdmacore_endianness
{
    uint32_t U;
    struct _hw_sdmacore_endianness_bitfields
    {
        uint32_t APEND : 1;            /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_sdmacore_endianness_t;

/*!
 * @name Constants and macros for entire SDMACORE_ENDIANNESS register
 */
/*@{*/
#define HW_SDMACORE_ENDIANNESS_ADDR(x) ((uintptr_t)(x) + 0x4CU)

#define HW_SDMACORE_ENDIANNESS(x) (*(__I hw_sdmacore_endianness_t *) HW_SDMACORE_ENDIANNESS_ADDR(x))
#define HW_SDMACORE_ENDIANNESS_RD(x) (HW_SDMACORE_ENDIANNESS(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_ENDIANNESS bitfields
 */

/*!
 * @name Register SDMACORE_ENDIANNESS, field APEND[0] (RO)
 *
 * APEND indicates the endian mode of the Peripheral and Burst DMA interfaces.
 * This bit is tied to logic '1' indicating little-endian mode.
 *
 * Values:
 * - 0 - - ARM platform is in big-endian mode
 * - 1 - - ARM platform is in little-endian mode
 */
/*@{*/
#define BP_SDMACORE_ENDIANNESS_APEND (0U)  /*!< Bit position for SDMACORE_ENDIANNESS_APEND. */
#define BM_SDMACORE_ENDIANNESS_APEND (0x00000001U) /*!< Bit mask for SDMACORE_ENDIANNESS_APEND. */
#define BS_SDMACORE_ENDIANNESS_APEND (1U)  /*!< Bit field size in bits for SDMACORE_ENDIANNESS_APEND. */

/*! @brief Read current value of the SDMACORE_ENDIANNESS_APEND field. */
#define BR_SDMACORE_ENDIANNESS_APEND(x) (HW_SDMACORE_ENDIANNESS(x).B.APEND)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_SDMA_LOCK - Lock Status Register
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_SDMA_LOCK - Lock Status Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_sdma_lock
{
    uint32_t U;
    struct _hw_sdmacore_sdma_lock_bitfields
    {
        uint32_t LOCK : 1;             /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_sdmacore_sdma_lock_t;

/*!
 * @name Constants and macros for entire SDMACORE_SDMA_LOCK register
 */
/*@{*/
#define HW_SDMACORE_SDMA_LOCK_ADDR(x) ((uintptr_t)(x) + 0x54U)

#define HW_SDMACORE_SDMA_LOCK(x) (*(__I hw_sdmacore_sdma_lock_t *) HW_SDMACORE_SDMA_LOCK_ADDR(x))
#define HW_SDMACORE_SDMA_LOCK_RD(x) (HW_SDMACORE_SDMA_LOCK(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_SDMA_LOCK bitfields
 */

/*!
 * @name Register SDMACORE_SDMA_LOCK, field LOCK[0] (RO)
 *
 * The LOCK bit reports the value of the LOCK bit in the SDMA_LOCK status
 * register. SDMA software may use this value to determine if certain operations such
 * as loading of new scripts is allowed.
 *
 * Values:
 * - 0 - - LOCK bit clear
 * - 1 - - LOCK bit set
 */
/*@{*/
#define BP_SDMACORE_SDMA_LOCK_LOCK (0U)    /*!< Bit position for SDMACORE_SDMA_LOCK_LOCK. */
#define BM_SDMACORE_SDMA_LOCK_LOCK (0x00000001U) /*!< Bit mask for SDMACORE_SDMA_LOCK_LOCK. */
#define BS_SDMACORE_SDMA_LOCK_LOCK (1U)    /*!< Bit field size in bits for SDMACORE_SDMA_LOCK_LOCK. */

/*! @brief Read current value of the SDMACORE_SDMA_LOCK_LOCK field. */
#define BR_SDMACORE_SDMA_LOCK_LOCK(x) (HW_SDMACORE_SDMA_LOCK(x).B.LOCK)
/*@}*/

/*******************************************************************************
 * HW_SDMACORE_EVENTS2 - External DMA Requests Mirror #2
 ******************************************************************************/

/*!
 * @brief HW_SDMACORE_EVENTS2 - External DMA Requests Mirror #2 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sdmacore_events2
{
    uint32_t U;
    struct _hw_sdmacore_events2_bitfields
    {
        uint32_t EVENTS : 16;          /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sdmacore_events2_t;

/*!
 * @name Constants and macros for entire SDMACORE_EVENTS2 register
 */
/*@{*/
#define HW_SDMACORE_EVENTS2_ADDR(x) ((uintptr_t)(x) + 0x58U)

#define HW_SDMACORE_EVENTS2(x)   (*(__I hw_sdmacore_events2_t *) HW_SDMACORE_EVENTS2_ADDR(x))
#define HW_SDMACORE_EVENTS2_RD(x) (HW_SDMACORE_EVENTS2(x).U)
/*@}*/

/*
 * Constants & macros for individual SDMACORE_EVENTS2 bitfields
 */

/*!
 * @name Register SDMACORE_EVENTS2, field EVENTS[15:0] (RO)
 *
 * Reflects the status of the SDMA's external DMA requests. It is meant to allow
 * any channel to monitor the states of these SDMA inputs. This register
 * displays EVENTS 32-47. The separate EVENTS register displays events 0-31.
 */
/*@{*/
#define BP_SDMACORE_EVENTS2_EVENTS (0U)    /*!< Bit position for SDMACORE_EVENTS2_EVENTS. */
#define BM_SDMACORE_EVENTS2_EVENTS (0x0000FFFFU) /*!< Bit mask for SDMACORE_EVENTS2_EVENTS. */
#define BS_SDMACORE_EVENTS2_EVENTS (16U)   /*!< Bit field size in bits for SDMACORE_EVENTS2_EVENTS. */

/*! @brief Read current value of the SDMACORE_EVENTS2_EVENTS field. */
#define BR_SDMACORE_EVENTS2_EVENTS(x) (HW_SDMACORE_EVENTS2(x).B.EVENTS)
/*@}*/

/*******************************************************************************
 * hw_sdmacore_t - module struct
 ******************************************************************************/
/*!
 * @brief All SDMACORE module registers.
 */
#pragma pack(1)
typedef struct _hw_sdmacore
{
    __I hw_sdmacore_mc0ptr_t MC0PTR;       /*!< [0x0] ARM platform Channel 0 Pointer */
    uint8_t _reserved0[4];
    __I hw_sdmacore_ccptr_t CCPTR;         /*!< [0x8] Current Channel Pointer */
    __I hw_sdmacore_ccr_t CCR;             /*!< [0xC] Current Channel Register */
    __I hw_sdmacore_ncr_t NCR;             /*!< [0x10] Highest Pending Channel Register */
    __I hw_sdmacore_events_t EVENTS;       /*!< [0x14] External DMA Requests Mirror */
    __I hw_sdmacore_ccpri_t CCPRI;         /*!< [0x18] Current Channel Priority */
    __I hw_sdmacore_ncpri_t NCPRI;         /*!< [0x1C] Next Channel Priority */
    __IO hw_sdmacore_ecount_t ECOUNT;      /*!< [0x20] OnCE Event Cell Counter */
    __IO hw_sdmacore_ectl_t ECTL;          /*!< [0x24] OnCE Event Cell Control Register */
    __IO hw_sdmacore_eaa_t EAA;            /*!< [0x28] OnCE Event Address Register A */
    __IO hw_sdmacore_eab_t EAB;            /*!< [0x2C] OnCE Event Cell Address Register B */
    __IO hw_sdmacore_eam_t EAM;            /*!< [0x30] OnCE Event Cell Address Mask */
    __IO hw_sdmacore_ed_t ED;              /*!< [0x34] OnCE Event Cell Data Register */
    __IO hw_sdmacore_edm_t EDM;            /*!< [0x38] OnCE Event Cell Data Mask */
    __IO hw_sdmacore_rtb_t RTB;            /*!< [0x3C] OnCE Real-Time Buffer */
    __I hw_sdmacore_tb_t TB;               /*!< [0x40] OnCE Trace Buffer */
    __I hw_sdmacore_ostat_t OSTAT;         /*!< [0x44] OnCE Status */
    __I hw_sdmacore_mchn0addr_t MCHN0ADDR; /*!< [0x48] Channel 0 Boot Address */
    __I hw_sdmacore_endianness_t ENDIANNESS; /*!< [0x4C] ENDIAN Status Register */
    uint8_t _reserved1[4];
    __I hw_sdmacore_sdma_lock_t SDMA_LOCK; /*!< [0x54] Lock Status Register */
    __I hw_sdmacore_events2_t EVENTS2;     /*!< [0x58] External DMA Requests Mirror #2 */
} hw_sdmacore_t;
#pragma pack()

/*! @brief Macro to access all SDMACORE registers. */
/*! @param x SDMACORE module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_SDMACORE_REGS(SDMACORE_BASE)</code>. */
#define HW_SDMACORE_REGS(x) (*(hw_sdmacore_t *)(x))

/*
 * iMX7D SEMA4
 *
 * IPS_Semaphores
 *
 * Registers defined in this header file:
 * - HW_SEMA4_Gate00 - Semaphores Gate 0 Register
 * - HW_SEMA4_Gate01 - Semaphores Gate 1 Register
 * - HW_SEMA4_Gate02 - Semaphores Gate 2 Register
 * - HW_SEMA4_Gate03 - Semaphores Gate 3 Register
 * - HW_SEMA4_Gate04 - Semaphores Gate 4 Register
 * - HW_SEMA4_Gate05 - Semaphores Gate 5 Register
 * - HW_SEMA4_Gate06 - Semaphores Gate 6 Register
 * - HW_SEMA4_Gate07 - Semaphores Gate 7 Register
 * - HW_SEMA4_Gate08 - Semaphores Gate 8 Register
 * - HW_SEMA4_Gate09 - Semaphores Gate 9 Register
 * - HW_SEMA4_Gate10 - Semaphores Gate 10 Register
 * - HW_SEMA4_Gate11 - Semaphores Gate 11 Register
 * - HW_SEMA4_Gate12 - Semaphores Gate 12 Register
 * - HW_SEMA4_Gate13 - Semaphores Gate 13 Register
 * - HW_SEMA4_Gate14 - Semaphores Gate 14 Register
 * - HW_SEMA4_Gate15 - Semaphores Gate 15 Register
 * - HW_SEMA4_CPnINE - Semaphores Processor n IRQ Notification Enable
 * - HW_SEMA4_CPnNTF - Semaphores Processor n IRQ Notification
 * - HW_SEMA4_RSTGT - Semaphores (Secure) Reset Gate n
 * - HW_SEMA4_RSTNTF - Semaphores (Secure) Reset IRQ Notification
 *
 * - hw_sema4_t - Struct containing all module registers.
 */

#define HW_SEMA4_INSTANCE_COUNT (1U) /*!< Number of instances of the SEMA4 module. */
#define HW_SEMA4 (0U) /*!< Instance number for SEMA4. */
#define SEMA4_BASE            (0x30AC0000U) /*!< Base address for SEMA4. */
/*! Array initializer of SEMA4 base addresses. */
#define SEMA4_BASE_ADDRS      { SEMA4_BASE }

/*******************************************************************************
 * HW_SEMA4_Gate00 - Semaphores Gate 0 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate00 - Semaphores Gate 0 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate00
{
    uint8_t U;
    struct _hw_sema4_gate00_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate00_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate00 register
 */
/*@{*/
#define HW_SEMA4_Gate00_ADDR(x)  ((uintptr_t)(x) + 0x0U)

#define HW_SEMA4_Gate00(x)       (*(__IO hw_sema4_gate00_t *) HW_SEMA4_Gate00_ADDR(x))
#define HW_SEMA4_Gate00_RD(x)    (HW_SEMA4_Gate00(x).U)
#define HW_SEMA4_Gate00_WR(x, v) (HW_SEMA4_Gate00(x).U = (v))
#define HW_SEMA4_Gate00_SET(x, v) (HW_SEMA4_Gate00_WR(x, HW_SEMA4_Gate00_RD(x) |  (v)))
#define HW_SEMA4_Gate00_CLR(x, v) (HW_SEMA4_Gate00_WR(x, HW_SEMA4_Gate00_RD(x) & ~(v)))
#define HW_SEMA4_Gate00_TOG(x, v) (HW_SEMA4_Gate00_WR(x, HW_SEMA4_Gate00_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate00 bitfields
 */

/*!
 * @name Register SEMA4_Gate00, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate00_GTFSM (0U)         /*!< Bit position for SEMA4_Gate00_GTFSM. */
#define BM_SEMA4_Gate00_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate00_GTFSM. */
#define BS_SEMA4_Gate00_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate00_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate00_GTFSM field. */
#define BR_SEMA4_Gate00_GTFSM(x) (HW_SEMA4_Gate00(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate00_GTFSM. */
#define BF_SEMA4_Gate00_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate00_GTFSM) & BM_SEMA4_Gate00_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate00_GTFSM(x, v) (HW_SEMA4_Gate00_WR(x, (HW_SEMA4_Gate00_RD(x) & ~BM_SEMA4_Gate00_GTFSM) | BF_SEMA4_Gate00_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate01 - Semaphores Gate 1 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate01 - Semaphores Gate 1 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate01
{
    uint8_t U;
    struct _hw_sema4_gate01_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate01_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate01 register
 */
/*@{*/
#define HW_SEMA4_Gate01_ADDR(x)  ((uintptr_t)(x) + 0x1U)

#define HW_SEMA4_Gate01(x)       (*(__IO hw_sema4_gate01_t *) HW_SEMA4_Gate01_ADDR(x))
#define HW_SEMA4_Gate01_RD(x)    (HW_SEMA4_Gate01(x).U)
#define HW_SEMA4_Gate01_WR(x, v) (HW_SEMA4_Gate01(x).U = (v))
#define HW_SEMA4_Gate01_SET(x, v) (HW_SEMA4_Gate01_WR(x, HW_SEMA4_Gate01_RD(x) |  (v)))
#define HW_SEMA4_Gate01_CLR(x, v) (HW_SEMA4_Gate01_WR(x, HW_SEMA4_Gate01_RD(x) & ~(v)))
#define HW_SEMA4_Gate01_TOG(x, v) (HW_SEMA4_Gate01_WR(x, HW_SEMA4_Gate01_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate01 bitfields
 */

/*!
 * @name Register SEMA4_Gate01, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate01_GTFSM (0U)         /*!< Bit position for SEMA4_Gate01_GTFSM. */
#define BM_SEMA4_Gate01_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate01_GTFSM. */
#define BS_SEMA4_Gate01_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate01_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate01_GTFSM field. */
#define BR_SEMA4_Gate01_GTFSM(x) (HW_SEMA4_Gate01(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate01_GTFSM. */
#define BF_SEMA4_Gate01_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate01_GTFSM) & BM_SEMA4_Gate01_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate01_GTFSM(x, v) (HW_SEMA4_Gate01_WR(x, (HW_SEMA4_Gate01_RD(x) & ~BM_SEMA4_Gate01_GTFSM) | BF_SEMA4_Gate01_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate02 - Semaphores Gate 2 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate02 - Semaphores Gate 2 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate02
{
    uint8_t U;
    struct _hw_sema4_gate02_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate02_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate02 register
 */
/*@{*/
#define HW_SEMA4_Gate02_ADDR(x)  ((uintptr_t)(x) + 0x2U)

#define HW_SEMA4_Gate02(x)       (*(__IO hw_sema4_gate02_t *) HW_SEMA4_Gate02_ADDR(x))
#define HW_SEMA4_Gate02_RD(x)    (HW_SEMA4_Gate02(x).U)
#define HW_SEMA4_Gate02_WR(x, v) (HW_SEMA4_Gate02(x).U = (v))
#define HW_SEMA4_Gate02_SET(x, v) (HW_SEMA4_Gate02_WR(x, HW_SEMA4_Gate02_RD(x) |  (v)))
#define HW_SEMA4_Gate02_CLR(x, v) (HW_SEMA4_Gate02_WR(x, HW_SEMA4_Gate02_RD(x) & ~(v)))
#define HW_SEMA4_Gate02_TOG(x, v) (HW_SEMA4_Gate02_WR(x, HW_SEMA4_Gate02_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate02 bitfields
 */

/*!
 * @name Register SEMA4_Gate02, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate02_GTFSM (0U)         /*!< Bit position for SEMA4_Gate02_GTFSM. */
#define BM_SEMA4_Gate02_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate02_GTFSM. */
#define BS_SEMA4_Gate02_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate02_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate02_GTFSM field. */
#define BR_SEMA4_Gate02_GTFSM(x) (HW_SEMA4_Gate02(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate02_GTFSM. */
#define BF_SEMA4_Gate02_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate02_GTFSM) & BM_SEMA4_Gate02_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate02_GTFSM(x, v) (HW_SEMA4_Gate02_WR(x, (HW_SEMA4_Gate02_RD(x) & ~BM_SEMA4_Gate02_GTFSM) | BF_SEMA4_Gate02_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate03 - Semaphores Gate 3 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate03 - Semaphores Gate 3 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate03
{
    uint8_t U;
    struct _hw_sema4_gate03_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate03_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate03 register
 */
/*@{*/
#define HW_SEMA4_Gate03_ADDR(x)  ((uintptr_t)(x) + 0x3U)

#define HW_SEMA4_Gate03(x)       (*(__IO hw_sema4_gate03_t *) HW_SEMA4_Gate03_ADDR(x))
#define HW_SEMA4_Gate03_RD(x)    (HW_SEMA4_Gate03(x).U)
#define HW_SEMA4_Gate03_WR(x, v) (HW_SEMA4_Gate03(x).U = (v))
#define HW_SEMA4_Gate03_SET(x, v) (HW_SEMA4_Gate03_WR(x, HW_SEMA4_Gate03_RD(x) |  (v)))
#define HW_SEMA4_Gate03_CLR(x, v) (HW_SEMA4_Gate03_WR(x, HW_SEMA4_Gate03_RD(x) & ~(v)))
#define HW_SEMA4_Gate03_TOG(x, v) (HW_SEMA4_Gate03_WR(x, HW_SEMA4_Gate03_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate03 bitfields
 */

/*!
 * @name Register SEMA4_Gate03, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate03_GTFSM (0U)         /*!< Bit position for SEMA4_Gate03_GTFSM. */
#define BM_SEMA4_Gate03_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate03_GTFSM. */
#define BS_SEMA4_Gate03_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate03_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate03_GTFSM field. */
#define BR_SEMA4_Gate03_GTFSM(x) (HW_SEMA4_Gate03(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate03_GTFSM. */
#define BF_SEMA4_Gate03_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate03_GTFSM) & BM_SEMA4_Gate03_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate03_GTFSM(x, v) (HW_SEMA4_Gate03_WR(x, (HW_SEMA4_Gate03_RD(x) & ~BM_SEMA4_Gate03_GTFSM) | BF_SEMA4_Gate03_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate04 - Semaphores Gate 4 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate04 - Semaphores Gate 4 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate04
{
    uint8_t U;
    struct _hw_sema4_gate04_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate04_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate04 register
 */
/*@{*/
#define HW_SEMA4_Gate04_ADDR(x)  ((uintptr_t)(x) + 0x4U)

#define HW_SEMA4_Gate04(x)       (*(__IO hw_sema4_gate04_t *) HW_SEMA4_Gate04_ADDR(x))
#define HW_SEMA4_Gate04_RD(x)    (HW_SEMA4_Gate04(x).U)
#define HW_SEMA4_Gate04_WR(x, v) (HW_SEMA4_Gate04(x).U = (v))
#define HW_SEMA4_Gate04_SET(x, v) (HW_SEMA4_Gate04_WR(x, HW_SEMA4_Gate04_RD(x) |  (v)))
#define HW_SEMA4_Gate04_CLR(x, v) (HW_SEMA4_Gate04_WR(x, HW_SEMA4_Gate04_RD(x) & ~(v)))
#define HW_SEMA4_Gate04_TOG(x, v) (HW_SEMA4_Gate04_WR(x, HW_SEMA4_Gate04_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate04 bitfields
 */

/*!
 * @name Register SEMA4_Gate04, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate04_GTFSM (0U)         /*!< Bit position for SEMA4_Gate04_GTFSM. */
#define BM_SEMA4_Gate04_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate04_GTFSM. */
#define BS_SEMA4_Gate04_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate04_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate04_GTFSM field. */
#define BR_SEMA4_Gate04_GTFSM(x) (HW_SEMA4_Gate04(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate04_GTFSM. */
#define BF_SEMA4_Gate04_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate04_GTFSM) & BM_SEMA4_Gate04_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate04_GTFSM(x, v) (HW_SEMA4_Gate04_WR(x, (HW_SEMA4_Gate04_RD(x) & ~BM_SEMA4_Gate04_GTFSM) | BF_SEMA4_Gate04_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate05 - Semaphores Gate 5 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate05 - Semaphores Gate 5 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate05
{
    uint8_t U;
    struct _hw_sema4_gate05_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate05_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate05 register
 */
/*@{*/
#define HW_SEMA4_Gate05_ADDR(x)  ((uintptr_t)(x) + 0x5U)

#define HW_SEMA4_Gate05(x)       (*(__IO hw_sema4_gate05_t *) HW_SEMA4_Gate05_ADDR(x))
#define HW_SEMA4_Gate05_RD(x)    (HW_SEMA4_Gate05(x).U)
#define HW_SEMA4_Gate05_WR(x, v) (HW_SEMA4_Gate05(x).U = (v))
#define HW_SEMA4_Gate05_SET(x, v) (HW_SEMA4_Gate05_WR(x, HW_SEMA4_Gate05_RD(x) |  (v)))
#define HW_SEMA4_Gate05_CLR(x, v) (HW_SEMA4_Gate05_WR(x, HW_SEMA4_Gate05_RD(x) & ~(v)))
#define HW_SEMA4_Gate05_TOG(x, v) (HW_SEMA4_Gate05_WR(x, HW_SEMA4_Gate05_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate05 bitfields
 */

/*!
 * @name Register SEMA4_Gate05, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate05_GTFSM (0U)         /*!< Bit position for SEMA4_Gate05_GTFSM. */
#define BM_SEMA4_Gate05_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate05_GTFSM. */
#define BS_SEMA4_Gate05_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate05_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate05_GTFSM field. */
#define BR_SEMA4_Gate05_GTFSM(x) (HW_SEMA4_Gate05(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate05_GTFSM. */
#define BF_SEMA4_Gate05_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate05_GTFSM) & BM_SEMA4_Gate05_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate05_GTFSM(x, v) (HW_SEMA4_Gate05_WR(x, (HW_SEMA4_Gate05_RD(x) & ~BM_SEMA4_Gate05_GTFSM) | BF_SEMA4_Gate05_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate06 - Semaphores Gate 6 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate06 - Semaphores Gate 6 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate06
{
    uint8_t U;
    struct _hw_sema4_gate06_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate06_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate06 register
 */
/*@{*/
#define HW_SEMA4_Gate06_ADDR(x)  ((uintptr_t)(x) + 0x6U)

#define HW_SEMA4_Gate06(x)       (*(__IO hw_sema4_gate06_t *) HW_SEMA4_Gate06_ADDR(x))
#define HW_SEMA4_Gate06_RD(x)    (HW_SEMA4_Gate06(x).U)
#define HW_SEMA4_Gate06_WR(x, v) (HW_SEMA4_Gate06(x).U = (v))
#define HW_SEMA4_Gate06_SET(x, v) (HW_SEMA4_Gate06_WR(x, HW_SEMA4_Gate06_RD(x) |  (v)))
#define HW_SEMA4_Gate06_CLR(x, v) (HW_SEMA4_Gate06_WR(x, HW_SEMA4_Gate06_RD(x) & ~(v)))
#define HW_SEMA4_Gate06_TOG(x, v) (HW_SEMA4_Gate06_WR(x, HW_SEMA4_Gate06_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate06 bitfields
 */

/*!
 * @name Register SEMA4_Gate06, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate06_GTFSM (0U)         /*!< Bit position for SEMA4_Gate06_GTFSM. */
#define BM_SEMA4_Gate06_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate06_GTFSM. */
#define BS_SEMA4_Gate06_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate06_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate06_GTFSM field. */
#define BR_SEMA4_Gate06_GTFSM(x) (HW_SEMA4_Gate06(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate06_GTFSM. */
#define BF_SEMA4_Gate06_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate06_GTFSM) & BM_SEMA4_Gate06_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate06_GTFSM(x, v) (HW_SEMA4_Gate06_WR(x, (HW_SEMA4_Gate06_RD(x) & ~BM_SEMA4_Gate06_GTFSM) | BF_SEMA4_Gate06_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate07 - Semaphores Gate 7 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate07 - Semaphores Gate 7 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate07
{
    uint8_t U;
    struct _hw_sema4_gate07_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate07_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate07 register
 */
/*@{*/
#define HW_SEMA4_Gate07_ADDR(x)  ((uintptr_t)(x) + 0x7U)

#define HW_SEMA4_Gate07(x)       (*(__IO hw_sema4_gate07_t *) HW_SEMA4_Gate07_ADDR(x))
#define HW_SEMA4_Gate07_RD(x)    (HW_SEMA4_Gate07(x).U)
#define HW_SEMA4_Gate07_WR(x, v) (HW_SEMA4_Gate07(x).U = (v))
#define HW_SEMA4_Gate07_SET(x, v) (HW_SEMA4_Gate07_WR(x, HW_SEMA4_Gate07_RD(x) |  (v)))
#define HW_SEMA4_Gate07_CLR(x, v) (HW_SEMA4_Gate07_WR(x, HW_SEMA4_Gate07_RD(x) & ~(v)))
#define HW_SEMA4_Gate07_TOG(x, v) (HW_SEMA4_Gate07_WR(x, HW_SEMA4_Gate07_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate07 bitfields
 */

/*!
 * @name Register SEMA4_Gate07, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate07_GTFSM (0U)         /*!< Bit position for SEMA4_Gate07_GTFSM. */
#define BM_SEMA4_Gate07_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate07_GTFSM. */
#define BS_SEMA4_Gate07_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate07_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate07_GTFSM field. */
#define BR_SEMA4_Gate07_GTFSM(x) (HW_SEMA4_Gate07(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate07_GTFSM. */
#define BF_SEMA4_Gate07_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate07_GTFSM) & BM_SEMA4_Gate07_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate07_GTFSM(x, v) (HW_SEMA4_Gate07_WR(x, (HW_SEMA4_Gate07_RD(x) & ~BM_SEMA4_Gate07_GTFSM) | BF_SEMA4_Gate07_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate08 - Semaphores Gate 8 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate08 - Semaphores Gate 8 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate08
{
    uint8_t U;
    struct _hw_sema4_gate08_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate08_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate08 register
 */
/*@{*/
#define HW_SEMA4_Gate08_ADDR(x)  ((uintptr_t)(x) + 0x8U)

#define HW_SEMA4_Gate08(x)       (*(__IO hw_sema4_gate08_t *) HW_SEMA4_Gate08_ADDR(x))
#define HW_SEMA4_Gate08_RD(x)    (HW_SEMA4_Gate08(x).U)
#define HW_SEMA4_Gate08_WR(x, v) (HW_SEMA4_Gate08(x).U = (v))
#define HW_SEMA4_Gate08_SET(x, v) (HW_SEMA4_Gate08_WR(x, HW_SEMA4_Gate08_RD(x) |  (v)))
#define HW_SEMA4_Gate08_CLR(x, v) (HW_SEMA4_Gate08_WR(x, HW_SEMA4_Gate08_RD(x) & ~(v)))
#define HW_SEMA4_Gate08_TOG(x, v) (HW_SEMA4_Gate08_WR(x, HW_SEMA4_Gate08_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate08 bitfields
 */

/*!
 * @name Register SEMA4_Gate08, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate08_GTFSM (0U)         /*!< Bit position for SEMA4_Gate08_GTFSM. */
#define BM_SEMA4_Gate08_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate08_GTFSM. */
#define BS_SEMA4_Gate08_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate08_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate08_GTFSM field. */
#define BR_SEMA4_Gate08_GTFSM(x) (HW_SEMA4_Gate08(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate08_GTFSM. */
#define BF_SEMA4_Gate08_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate08_GTFSM) & BM_SEMA4_Gate08_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate08_GTFSM(x, v) (HW_SEMA4_Gate08_WR(x, (HW_SEMA4_Gate08_RD(x) & ~BM_SEMA4_Gate08_GTFSM) | BF_SEMA4_Gate08_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate09 - Semaphores Gate 9 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate09 - Semaphores Gate 9 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate09
{
    uint8_t U;
    struct _hw_sema4_gate09_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate09_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate09 register
 */
/*@{*/
#define HW_SEMA4_Gate09_ADDR(x)  ((uintptr_t)(x) + 0x9U)

#define HW_SEMA4_Gate09(x)       (*(__IO hw_sema4_gate09_t *) HW_SEMA4_Gate09_ADDR(x))
#define HW_SEMA4_Gate09_RD(x)    (HW_SEMA4_Gate09(x).U)
#define HW_SEMA4_Gate09_WR(x, v) (HW_SEMA4_Gate09(x).U = (v))
#define HW_SEMA4_Gate09_SET(x, v) (HW_SEMA4_Gate09_WR(x, HW_SEMA4_Gate09_RD(x) |  (v)))
#define HW_SEMA4_Gate09_CLR(x, v) (HW_SEMA4_Gate09_WR(x, HW_SEMA4_Gate09_RD(x) & ~(v)))
#define HW_SEMA4_Gate09_TOG(x, v) (HW_SEMA4_Gate09_WR(x, HW_SEMA4_Gate09_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate09 bitfields
 */

/*!
 * @name Register SEMA4_Gate09, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate09_GTFSM (0U)         /*!< Bit position for SEMA4_Gate09_GTFSM. */
#define BM_SEMA4_Gate09_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate09_GTFSM. */
#define BS_SEMA4_Gate09_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate09_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate09_GTFSM field. */
#define BR_SEMA4_Gate09_GTFSM(x) (HW_SEMA4_Gate09(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate09_GTFSM. */
#define BF_SEMA4_Gate09_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate09_GTFSM) & BM_SEMA4_Gate09_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate09_GTFSM(x, v) (HW_SEMA4_Gate09_WR(x, (HW_SEMA4_Gate09_RD(x) & ~BM_SEMA4_Gate09_GTFSM) | BF_SEMA4_Gate09_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate10 - Semaphores Gate 10 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate10 - Semaphores Gate 10 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate10
{
    uint8_t U;
    struct _hw_sema4_gate10_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate10_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate10 register
 */
/*@{*/
#define HW_SEMA4_Gate10_ADDR(x)  ((uintptr_t)(x) + 0xAU)

#define HW_SEMA4_Gate10(x)       (*(__IO hw_sema4_gate10_t *) HW_SEMA4_Gate10_ADDR(x))
#define HW_SEMA4_Gate10_RD(x)    (HW_SEMA4_Gate10(x).U)
#define HW_SEMA4_Gate10_WR(x, v) (HW_SEMA4_Gate10(x).U = (v))
#define HW_SEMA4_Gate10_SET(x, v) (HW_SEMA4_Gate10_WR(x, HW_SEMA4_Gate10_RD(x) |  (v)))
#define HW_SEMA4_Gate10_CLR(x, v) (HW_SEMA4_Gate10_WR(x, HW_SEMA4_Gate10_RD(x) & ~(v)))
#define HW_SEMA4_Gate10_TOG(x, v) (HW_SEMA4_Gate10_WR(x, HW_SEMA4_Gate10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate10 bitfields
 */

/*!
 * @name Register SEMA4_Gate10, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate10_GTFSM (0U)         /*!< Bit position for SEMA4_Gate10_GTFSM. */
#define BM_SEMA4_Gate10_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate10_GTFSM. */
#define BS_SEMA4_Gate10_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate10_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate10_GTFSM field. */
#define BR_SEMA4_Gate10_GTFSM(x) (HW_SEMA4_Gate10(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate10_GTFSM. */
#define BF_SEMA4_Gate10_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate10_GTFSM) & BM_SEMA4_Gate10_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate10_GTFSM(x, v) (HW_SEMA4_Gate10_WR(x, (HW_SEMA4_Gate10_RD(x) & ~BM_SEMA4_Gate10_GTFSM) | BF_SEMA4_Gate10_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate11 - Semaphores Gate 11 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate11 - Semaphores Gate 11 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate11
{
    uint8_t U;
    struct _hw_sema4_gate11_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate11_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate11 register
 */
/*@{*/
#define HW_SEMA4_Gate11_ADDR(x)  ((uintptr_t)(x) + 0xBU)

#define HW_SEMA4_Gate11(x)       (*(__IO hw_sema4_gate11_t *) HW_SEMA4_Gate11_ADDR(x))
#define HW_SEMA4_Gate11_RD(x)    (HW_SEMA4_Gate11(x).U)
#define HW_SEMA4_Gate11_WR(x, v) (HW_SEMA4_Gate11(x).U = (v))
#define HW_SEMA4_Gate11_SET(x, v) (HW_SEMA4_Gate11_WR(x, HW_SEMA4_Gate11_RD(x) |  (v)))
#define HW_SEMA4_Gate11_CLR(x, v) (HW_SEMA4_Gate11_WR(x, HW_SEMA4_Gate11_RD(x) & ~(v)))
#define HW_SEMA4_Gate11_TOG(x, v) (HW_SEMA4_Gate11_WR(x, HW_SEMA4_Gate11_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate11 bitfields
 */

/*!
 * @name Register SEMA4_Gate11, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate11_GTFSM (0U)         /*!< Bit position for SEMA4_Gate11_GTFSM. */
#define BM_SEMA4_Gate11_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate11_GTFSM. */
#define BS_SEMA4_Gate11_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate11_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate11_GTFSM field. */
#define BR_SEMA4_Gate11_GTFSM(x) (HW_SEMA4_Gate11(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate11_GTFSM. */
#define BF_SEMA4_Gate11_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate11_GTFSM) & BM_SEMA4_Gate11_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate11_GTFSM(x, v) (HW_SEMA4_Gate11_WR(x, (HW_SEMA4_Gate11_RD(x) & ~BM_SEMA4_Gate11_GTFSM) | BF_SEMA4_Gate11_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate12 - Semaphores Gate 12 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate12 - Semaphores Gate 12 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate12
{
    uint8_t U;
    struct _hw_sema4_gate12_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate12_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate12 register
 */
/*@{*/
#define HW_SEMA4_Gate12_ADDR(x)  ((uintptr_t)(x) + 0xCU)

#define HW_SEMA4_Gate12(x)       (*(__IO hw_sema4_gate12_t *) HW_SEMA4_Gate12_ADDR(x))
#define HW_SEMA4_Gate12_RD(x)    (HW_SEMA4_Gate12(x).U)
#define HW_SEMA4_Gate12_WR(x, v) (HW_SEMA4_Gate12(x).U = (v))
#define HW_SEMA4_Gate12_SET(x, v) (HW_SEMA4_Gate12_WR(x, HW_SEMA4_Gate12_RD(x) |  (v)))
#define HW_SEMA4_Gate12_CLR(x, v) (HW_SEMA4_Gate12_WR(x, HW_SEMA4_Gate12_RD(x) & ~(v)))
#define HW_SEMA4_Gate12_TOG(x, v) (HW_SEMA4_Gate12_WR(x, HW_SEMA4_Gate12_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate12 bitfields
 */

/*!
 * @name Register SEMA4_Gate12, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate12_GTFSM (0U)         /*!< Bit position for SEMA4_Gate12_GTFSM. */
#define BM_SEMA4_Gate12_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate12_GTFSM. */
#define BS_SEMA4_Gate12_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate12_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate12_GTFSM field. */
#define BR_SEMA4_Gate12_GTFSM(x) (HW_SEMA4_Gate12(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate12_GTFSM. */
#define BF_SEMA4_Gate12_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate12_GTFSM) & BM_SEMA4_Gate12_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate12_GTFSM(x, v) (HW_SEMA4_Gate12_WR(x, (HW_SEMA4_Gate12_RD(x) & ~BM_SEMA4_Gate12_GTFSM) | BF_SEMA4_Gate12_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate13 - Semaphores Gate 13 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate13 - Semaphores Gate 13 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate13
{
    uint8_t U;
    struct _hw_sema4_gate13_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate13_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate13 register
 */
/*@{*/
#define HW_SEMA4_Gate13_ADDR(x)  ((uintptr_t)(x) + 0xDU)

#define HW_SEMA4_Gate13(x)       (*(__IO hw_sema4_gate13_t *) HW_SEMA4_Gate13_ADDR(x))
#define HW_SEMA4_Gate13_RD(x)    (HW_SEMA4_Gate13(x).U)
#define HW_SEMA4_Gate13_WR(x, v) (HW_SEMA4_Gate13(x).U = (v))
#define HW_SEMA4_Gate13_SET(x, v) (HW_SEMA4_Gate13_WR(x, HW_SEMA4_Gate13_RD(x) |  (v)))
#define HW_SEMA4_Gate13_CLR(x, v) (HW_SEMA4_Gate13_WR(x, HW_SEMA4_Gate13_RD(x) & ~(v)))
#define HW_SEMA4_Gate13_TOG(x, v) (HW_SEMA4_Gate13_WR(x, HW_SEMA4_Gate13_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate13 bitfields
 */

/*!
 * @name Register SEMA4_Gate13, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate13_GTFSM (0U)         /*!< Bit position for SEMA4_Gate13_GTFSM. */
#define BM_SEMA4_Gate13_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate13_GTFSM. */
#define BS_SEMA4_Gate13_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate13_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate13_GTFSM field. */
#define BR_SEMA4_Gate13_GTFSM(x) (HW_SEMA4_Gate13(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate13_GTFSM. */
#define BF_SEMA4_Gate13_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate13_GTFSM) & BM_SEMA4_Gate13_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate13_GTFSM(x, v) (HW_SEMA4_Gate13_WR(x, (HW_SEMA4_Gate13_RD(x) & ~BM_SEMA4_Gate13_GTFSM) | BF_SEMA4_Gate13_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate14 - Semaphores Gate 14 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate14 - Semaphores Gate 14 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate14
{
    uint8_t U;
    struct _hw_sema4_gate14_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate14_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate14 register
 */
/*@{*/
#define HW_SEMA4_Gate14_ADDR(x)  ((uintptr_t)(x) + 0xEU)

#define HW_SEMA4_Gate14(x)       (*(__IO hw_sema4_gate14_t *) HW_SEMA4_Gate14_ADDR(x))
#define HW_SEMA4_Gate14_RD(x)    (HW_SEMA4_Gate14(x).U)
#define HW_SEMA4_Gate14_WR(x, v) (HW_SEMA4_Gate14(x).U = (v))
#define HW_SEMA4_Gate14_SET(x, v) (HW_SEMA4_Gate14_WR(x, HW_SEMA4_Gate14_RD(x) |  (v)))
#define HW_SEMA4_Gate14_CLR(x, v) (HW_SEMA4_Gate14_WR(x, HW_SEMA4_Gate14_RD(x) & ~(v)))
#define HW_SEMA4_Gate14_TOG(x, v) (HW_SEMA4_Gate14_WR(x, HW_SEMA4_Gate14_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate14 bitfields
 */

/*!
 * @name Register SEMA4_Gate14, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate14_GTFSM (0U)         /*!< Bit position for SEMA4_Gate14_GTFSM. */
#define BM_SEMA4_Gate14_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate14_GTFSM. */
#define BS_SEMA4_Gate14_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate14_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate14_GTFSM field. */
#define BR_SEMA4_Gate14_GTFSM(x) (HW_SEMA4_Gate14(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate14_GTFSM. */
#define BF_SEMA4_Gate14_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate14_GTFSM) & BM_SEMA4_Gate14_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate14_GTFSM(x, v) (HW_SEMA4_Gate14_WR(x, (HW_SEMA4_Gate14_RD(x) & ~BM_SEMA4_Gate14_GTFSM) | BF_SEMA4_Gate14_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_Gate15 - Semaphores Gate 15 Register
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_Gate15 - Semaphores Gate 15 Register (RW)
 *
 * Reset value: 0x00U
 *
 * Each semaphore gate is implemented in a 2-bit finite state machine,
 * right-justified in a byte data structure. The hardware uses the bus master number in
 * conjunction with the data patterns to validate all attempted write operations.
 * Only processor bus masters can modify the gate registers. Once locked, a gate
 * can (and must) be opened (unlocked) by the locking processor core. Multiple
 * gate values can be read in a single access, but only a single gate can be updated
 * via a write operation at a time. 16- and 32-bit writes to multiple gates are
 * allowed, but the write data operand must only update the state of a single
 * gate. A byte write data value of 0x03 is defined as "no operation" and does not
 * affect the state of the corresponding gate register. Attempts to write multiple
 * gates in a single aligned access with a size larger than an 8-bit (byte)
 * reference generate an error termination and do not allow any gate state changes
 */
typedef union _hw_sema4_gate15
{
    uint8_t U;
    struct _hw_sema4_gate15_bitfields
    {
        uint8_t GTFSM : 2;             /*!< [1:0] Gate Finite State Machine. */
        uint8_t RESERVED0 : 6;         /*!< [7:2]  */
    } B;
} hw_sema4_gate15_t;

/*!
 * @name Constants and macros for entire SEMA4_Gate15 register
 */
/*@{*/
#define HW_SEMA4_Gate15_ADDR(x)  ((uintptr_t)(x) + 0xFU)

#define HW_SEMA4_Gate15(x)       (*(__IO hw_sema4_gate15_t *) HW_SEMA4_Gate15_ADDR(x))
#define HW_SEMA4_Gate15_RD(x)    (HW_SEMA4_Gate15(x).U)
#define HW_SEMA4_Gate15_WR(x, v) (HW_SEMA4_Gate15(x).U = (v))
#define HW_SEMA4_Gate15_SET(x, v) (HW_SEMA4_Gate15_WR(x, HW_SEMA4_Gate15_RD(x) |  (v)))
#define HW_SEMA4_Gate15_CLR(x, v) (HW_SEMA4_Gate15_WR(x, HW_SEMA4_Gate15_RD(x) & ~(v)))
#define HW_SEMA4_Gate15_TOG(x, v) (HW_SEMA4_Gate15_WR(x, HW_SEMA4_Gate15_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_Gate15 bitfields
 */

/*!
 * @name Register SEMA4_Gate15, field GTFSM[1:0] (RW)
 *
 * Gate Finite State Machine. The hardware gate is maintained in a 3-state
 * implementation-unlocked, locked by processor 0 or locked by processor 1. For more
 * details, see SEMA4_GATEn Operation . The state of the gate reflects the last
 * processor that locked it, which can be useful during system debug.
 *
 * Values:
 * - 00 - The gate is unlocked (free).
 * - 01 - The gate has been locked by processor 0.
 * - 10 - The gate has been locked by processor 1.
 * - 11 - This state encoding is never used and therefore reserved. Attempted
 *     writes of 0x03 are treated as "no operation" and do not affect the gate
 *     state machine.
 */
/*@{*/
#define BP_SEMA4_Gate15_GTFSM (0U)         /*!< Bit position for SEMA4_Gate15_GTFSM. */
#define BM_SEMA4_Gate15_GTFSM (0x03U)      /*!< Bit mask for SEMA4_Gate15_GTFSM. */
#define BS_SEMA4_Gate15_GTFSM (2U)         /*!< Bit field size in bits for SEMA4_Gate15_GTFSM. */

/*! @brief Read current value of the SEMA4_Gate15_GTFSM field. */
#define BR_SEMA4_Gate15_GTFSM(x) (HW_SEMA4_Gate15(x).B.GTFSM)

/*! @brief Format value for bitfield SEMA4_Gate15_GTFSM. */
#define BF_SEMA4_Gate15_GTFSM(v) ((uint8_t)((uint8_t)(v) << BP_SEMA4_Gate15_GTFSM) & BM_SEMA4_Gate15_GTFSM)

/*! @brief Set the GTFSM field to a new value. */
#define BW_SEMA4_Gate15_GTFSM(x, v) (HW_SEMA4_Gate15_WR(x, (HW_SEMA4_Gate15_RD(x) & ~BM_SEMA4_Gate15_GTFSM) | BF_SEMA4_Gate15_GTFSM(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_CPnINE - Semaphores Processor n IRQ Notification Enable
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_CPnINE - Semaphores Processor n IRQ Notification Enable (RW)
 *
 * Reset value: 0x0000U
 *
 * The application of a hardware semaphore module provides an opportunity for
 * implementation of helpful system-level features. An example is an optional
 * mechanism to generate a processor interrupt after a failed lock attempt. Recall
 * traditional software gate functions execute a spin-wait loop in an effort to
 * obtain and lock the referenced gate. With this module, the processor that fails in
 * the lock attempt could continue with other tasks and allow a properly-enabled
 * notification interrupt to return its execution to the original lock function.
 * The optional notification interrupt function consists of two registers for
 * each processor: an interrupt notification enable register (SEMA4_CPnINE) and the
 * interrupt request register (SEMA4_CPnNTF). To support implementations with
 * more than 16 gates, these registers can be referenced with aligned 16- or 32-bit
 * accesses. For the SEMA4_CPnINE registers, unimplemented bits read as zeroes,
 * and writes are ignored.
 */
typedef union _hw_sema4_cpnine
{
    uint16_t U;
    struct _hw_sema4_cpnine_bitfields
    {
        uint16_t INE7 : 1;             /*!< [0] Interrupt Request Notification Enable 7.
                                        * This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 7. */
        uint16_t INE6 : 1;             /*!< [1] Interrupt Request Notification Enable 6.
                                        * This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 6. */
        uint16_t INE5 : 1;             /*!< [2] Interrupt Request Notification Enable 5.
                                        * This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 5. */
        uint16_t INE4 : 1;             /*!< [3] Interrupt Request Notification Enable 4.
                                        * This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 4. */
        uint16_t INE3 : 1;             /*!< [4]  */
        uint16_t INE2 : 1;             /*!< [5]  */
        uint16_t INE1 : 1;             /*!< [6]  */
        uint16_t INE0 : 1;             /*!< [7]  */
        uint16_t INE15 : 1;            /*!< [8] Interrupt Request Notification Enable
                                        * 15. This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 15. */
        uint16_t INE14 : 1;            /*!< [9] Interrupt Request Notification Enable
                                        * 14. This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 14. */
        uint16_t INE13 : 1;            /*!< [10] Interrupt Request Notification Enable
                                        * 13. This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 13. */
        uint16_t INE12 : 1;            /*!< [11] Interrupt Request Notification Enable
                                        * 12. This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 12. */
        uint16_t INE11 : 1;            /*!< [12] Interrupt Request Notification Enable
                                        * 11. This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 11. */
        uint16_t INE10 : 1;            /*!< [13] Interrupt Request Notification Enable
                                        * 10. This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 10. */
        uint16_t INE9 : 1;             /*!< [14] Interrupt Request Notification Enable 9.
                                        * This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 9. */
        uint16_t INE8 : 1;             /*!< [15] Interrupt Request Notification Enable 8.
                                        * This field is a bitmap to enable the generation of an interrupt
                                        * notification from a failed attempt to lock gate 8. */
    } B;
} hw_sema4_cpnine_t;

/*!
 * @name Constants and macros for entire SEMA4_CPnINE register
 */
/*@{*/
#define HW_SEMA4_CPnINE_COUNT (2U)

#define HW_SEMA4_CPnINE_ADDR(x, n) ((uintptr_t)(x) + 0x40U + (0x8U * (n)))

#define HW_SEMA4_CPnINE(x, n)    (*(__IO hw_sema4_cpnine_t *) HW_SEMA4_CPnINE_ADDR(x, n))
#define HW_SEMA4_CPnINE_RD(x, n) (HW_SEMA4_CPnINE(x, n).U)
#define HW_SEMA4_CPnINE_WR(x, n, v) (HW_SEMA4_CPnINE(x, n).U = (v))
#define HW_SEMA4_CPnINE_SET(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, HW_SEMA4_CPnINE_RD(x, n) |  (v)))
#define HW_SEMA4_CPnINE_CLR(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, HW_SEMA4_CPnINE_RD(x, n) & ~(v)))
#define HW_SEMA4_CPnINE_TOG(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, HW_SEMA4_CPnINE_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_CPnINE bitfields
 */

/*!
 * @name Register SEMA4_CPnINE, field INE7[0] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE7 (0U)          /*!< Bit position for SEMA4_CPnINE_INE7. */
#define BM_SEMA4_CPnINE_INE7 (0x0001U)     /*!< Bit mask for SEMA4_CPnINE_INE7. */
#define BS_SEMA4_CPnINE_INE7 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE7. */

/*! @brief Read current value of the SEMA4_CPnINE_INE7 field. */
#define BR_SEMA4_CPnINE_INE7(x, n) (HW_SEMA4_CPnINE(x, n).B.INE7)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE7. */
#define BF_SEMA4_CPnINE_INE7(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE7) & BM_SEMA4_CPnINE_INE7)

/*! @brief Set the INE7 field to a new value. */
#define BW_SEMA4_CPnINE_INE7(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE7) | BF_SEMA4_CPnINE_INE7(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE6[1] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE6 (1U)          /*!< Bit position for SEMA4_CPnINE_INE6. */
#define BM_SEMA4_CPnINE_INE6 (0x0002U)     /*!< Bit mask for SEMA4_CPnINE_INE6. */
#define BS_SEMA4_CPnINE_INE6 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE6. */

/*! @brief Read current value of the SEMA4_CPnINE_INE6 field. */
#define BR_SEMA4_CPnINE_INE6(x, n) (HW_SEMA4_CPnINE(x, n).B.INE6)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE6. */
#define BF_SEMA4_CPnINE_INE6(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE6) & BM_SEMA4_CPnINE_INE6)

/*! @brief Set the INE6 field to a new value. */
#define BW_SEMA4_CPnINE_INE6(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE6) | BF_SEMA4_CPnINE_INE6(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE5[2] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE5 (2U)          /*!< Bit position for SEMA4_CPnINE_INE5. */
#define BM_SEMA4_CPnINE_INE5 (0x0004U)     /*!< Bit mask for SEMA4_CPnINE_INE5. */
#define BS_SEMA4_CPnINE_INE5 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE5. */

/*! @brief Read current value of the SEMA4_CPnINE_INE5 field. */
#define BR_SEMA4_CPnINE_INE5(x, n) (HW_SEMA4_CPnINE(x, n).B.INE5)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE5. */
#define BF_SEMA4_CPnINE_INE5(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE5) & BM_SEMA4_CPnINE_INE5)

/*! @brief Set the INE5 field to a new value. */
#define BW_SEMA4_CPnINE_INE5(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE5) | BF_SEMA4_CPnINE_INE5(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE4[3] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE4 (3U)          /*!< Bit position for SEMA4_CPnINE_INE4. */
#define BM_SEMA4_CPnINE_INE4 (0x0008U)     /*!< Bit mask for SEMA4_CPnINE_INE4. */
#define BS_SEMA4_CPnINE_INE4 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE4. */

/*! @brief Read current value of the SEMA4_CPnINE_INE4 field. */
#define BR_SEMA4_CPnINE_INE4(x, n) (HW_SEMA4_CPnINE(x, n).B.INE4)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE4. */
#define BF_SEMA4_CPnINE_INE4(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE4) & BM_SEMA4_CPnINE_INE4)

/*! @brief Set the INE4 field to a new value. */
#define BW_SEMA4_CPnINE_INE4(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE4) | BF_SEMA4_CPnINE_INE4(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE3[4] (RW)
 *
 * Interrupt Request Notification Enable 3. This field is a bitmap to enable the
 * generation of an interrupt notification from a failed attempt to lock gate 3.
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE3 (4U)          /*!< Bit position for SEMA4_CPnINE_INE3. */
#define BM_SEMA4_CPnINE_INE3 (0x0010U)     /*!< Bit mask for SEMA4_CPnINE_INE3. */
#define BS_SEMA4_CPnINE_INE3 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE3. */

/*! @brief Read current value of the SEMA4_CPnINE_INE3 field. */
#define BR_SEMA4_CPnINE_INE3(x, n) (HW_SEMA4_CPnINE(x, n).B.INE3)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE3. */
#define BF_SEMA4_CPnINE_INE3(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE3) & BM_SEMA4_CPnINE_INE3)

/*! @brief Set the INE3 field to a new value. */
#define BW_SEMA4_CPnINE_INE3(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE3) | BF_SEMA4_CPnINE_INE3(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE2[5] (RW)
 *
 * Interrupt Request Notification Enable 2. This field is a bitmap to enable the
 * generation of an interrupt notification from a failed attempt to lock gate 2.
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE2 (5U)          /*!< Bit position for SEMA4_CPnINE_INE2. */
#define BM_SEMA4_CPnINE_INE2 (0x0020U)     /*!< Bit mask for SEMA4_CPnINE_INE2. */
#define BS_SEMA4_CPnINE_INE2 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE2. */

/*! @brief Read current value of the SEMA4_CPnINE_INE2 field. */
#define BR_SEMA4_CPnINE_INE2(x, n) (HW_SEMA4_CPnINE(x, n).B.INE2)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE2. */
#define BF_SEMA4_CPnINE_INE2(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE2) & BM_SEMA4_CPnINE_INE2)

/*! @brief Set the INE2 field to a new value. */
#define BW_SEMA4_CPnINE_INE2(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE2) | BF_SEMA4_CPnINE_INE2(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE1[6] (RW)
 *
 * Interrupt Request Notification Enable 1. This field is a bitmap to enable the
 * generation of an interrupt notification from a failed attempt to lock gate 1.
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE1 (6U)          /*!< Bit position for SEMA4_CPnINE_INE1. */
#define BM_SEMA4_CPnINE_INE1 (0x0040U)     /*!< Bit mask for SEMA4_CPnINE_INE1. */
#define BS_SEMA4_CPnINE_INE1 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE1. */

/*! @brief Read current value of the SEMA4_CPnINE_INE1 field. */
#define BR_SEMA4_CPnINE_INE1(x, n) (HW_SEMA4_CPnINE(x, n).B.INE1)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE1. */
#define BF_SEMA4_CPnINE_INE1(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE1) & BM_SEMA4_CPnINE_INE1)

/*! @brief Set the INE1 field to a new value. */
#define BW_SEMA4_CPnINE_INE1(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE1) | BF_SEMA4_CPnINE_INE1(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE0[7] (RW)
 *
 * Interrupt Request Notification Enable 0. This field is a bitmap to enable the
 * generation of an interrupt notification from a failed attempt to lock gate 0.
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE0 (7U)          /*!< Bit position for SEMA4_CPnINE_INE0. */
#define BM_SEMA4_CPnINE_INE0 (0x0080U)     /*!< Bit mask for SEMA4_CPnINE_INE0. */
#define BS_SEMA4_CPnINE_INE0 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE0. */

/*! @brief Read current value of the SEMA4_CPnINE_INE0 field. */
#define BR_SEMA4_CPnINE_INE0(x, n) (HW_SEMA4_CPnINE(x, n).B.INE0)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE0. */
#define BF_SEMA4_CPnINE_INE0(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE0) & BM_SEMA4_CPnINE_INE0)

/*! @brief Set the INE0 field to a new value. */
#define BW_SEMA4_CPnINE_INE0(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE0) | BF_SEMA4_CPnINE_INE0(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE15[8] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE15 (8U)         /*!< Bit position for SEMA4_CPnINE_INE15. */
#define BM_SEMA4_CPnINE_INE15 (0x0100U)    /*!< Bit mask for SEMA4_CPnINE_INE15. */
#define BS_SEMA4_CPnINE_INE15 (1U)         /*!< Bit field size in bits for SEMA4_CPnINE_INE15. */

/*! @brief Read current value of the SEMA4_CPnINE_INE15 field. */
#define BR_SEMA4_CPnINE_INE15(x, n) (HW_SEMA4_CPnINE(x, n).B.INE15)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE15. */
#define BF_SEMA4_CPnINE_INE15(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE15) & BM_SEMA4_CPnINE_INE15)

/*! @brief Set the INE15 field to a new value. */
#define BW_SEMA4_CPnINE_INE15(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE15) | BF_SEMA4_CPnINE_INE15(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE14[9] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE14 (9U)         /*!< Bit position for SEMA4_CPnINE_INE14. */
#define BM_SEMA4_CPnINE_INE14 (0x0200U)    /*!< Bit mask for SEMA4_CPnINE_INE14. */
#define BS_SEMA4_CPnINE_INE14 (1U)         /*!< Bit field size in bits for SEMA4_CPnINE_INE14. */

/*! @brief Read current value of the SEMA4_CPnINE_INE14 field. */
#define BR_SEMA4_CPnINE_INE14(x, n) (HW_SEMA4_CPnINE(x, n).B.INE14)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE14. */
#define BF_SEMA4_CPnINE_INE14(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE14) & BM_SEMA4_CPnINE_INE14)

/*! @brief Set the INE14 field to a new value. */
#define BW_SEMA4_CPnINE_INE14(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE14) | BF_SEMA4_CPnINE_INE14(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE13[10] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE13 (10U)        /*!< Bit position for SEMA4_CPnINE_INE13. */
#define BM_SEMA4_CPnINE_INE13 (0x0400U)    /*!< Bit mask for SEMA4_CPnINE_INE13. */
#define BS_SEMA4_CPnINE_INE13 (1U)         /*!< Bit field size in bits for SEMA4_CPnINE_INE13. */

/*! @brief Read current value of the SEMA4_CPnINE_INE13 field. */
#define BR_SEMA4_CPnINE_INE13(x, n) (HW_SEMA4_CPnINE(x, n).B.INE13)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE13. */
#define BF_SEMA4_CPnINE_INE13(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE13) & BM_SEMA4_CPnINE_INE13)

/*! @brief Set the INE13 field to a new value. */
#define BW_SEMA4_CPnINE_INE13(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE13) | BF_SEMA4_CPnINE_INE13(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE12[11] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE12 (11U)        /*!< Bit position for SEMA4_CPnINE_INE12. */
#define BM_SEMA4_CPnINE_INE12 (0x0800U)    /*!< Bit mask for SEMA4_CPnINE_INE12. */
#define BS_SEMA4_CPnINE_INE12 (1U)         /*!< Bit field size in bits for SEMA4_CPnINE_INE12. */

/*! @brief Read current value of the SEMA4_CPnINE_INE12 field. */
#define BR_SEMA4_CPnINE_INE12(x, n) (HW_SEMA4_CPnINE(x, n).B.INE12)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE12. */
#define BF_SEMA4_CPnINE_INE12(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE12) & BM_SEMA4_CPnINE_INE12)

/*! @brief Set the INE12 field to a new value. */
#define BW_SEMA4_CPnINE_INE12(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE12) | BF_SEMA4_CPnINE_INE12(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE11[12] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE11 (12U)        /*!< Bit position for SEMA4_CPnINE_INE11. */
#define BM_SEMA4_CPnINE_INE11 (0x1000U)    /*!< Bit mask for SEMA4_CPnINE_INE11. */
#define BS_SEMA4_CPnINE_INE11 (1U)         /*!< Bit field size in bits for SEMA4_CPnINE_INE11. */

/*! @brief Read current value of the SEMA4_CPnINE_INE11 field. */
#define BR_SEMA4_CPnINE_INE11(x, n) (HW_SEMA4_CPnINE(x, n).B.INE11)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE11. */
#define BF_SEMA4_CPnINE_INE11(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE11) & BM_SEMA4_CPnINE_INE11)

/*! @brief Set the INE11 field to a new value. */
#define BW_SEMA4_CPnINE_INE11(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE11) | BF_SEMA4_CPnINE_INE11(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE10[13] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE10 (13U)        /*!< Bit position for SEMA4_CPnINE_INE10. */
#define BM_SEMA4_CPnINE_INE10 (0x2000U)    /*!< Bit mask for SEMA4_CPnINE_INE10. */
#define BS_SEMA4_CPnINE_INE10 (1U)         /*!< Bit field size in bits for SEMA4_CPnINE_INE10. */

/*! @brief Read current value of the SEMA4_CPnINE_INE10 field. */
#define BR_SEMA4_CPnINE_INE10(x, n) (HW_SEMA4_CPnINE(x, n).B.INE10)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE10. */
#define BF_SEMA4_CPnINE_INE10(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE10) & BM_SEMA4_CPnINE_INE10)

/*! @brief Set the INE10 field to a new value. */
#define BW_SEMA4_CPnINE_INE10(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE10) | BF_SEMA4_CPnINE_INE10(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE9[14] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE9 (14U)         /*!< Bit position for SEMA4_CPnINE_INE9. */
#define BM_SEMA4_CPnINE_INE9 (0x4000U)     /*!< Bit mask for SEMA4_CPnINE_INE9. */
#define BS_SEMA4_CPnINE_INE9 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE9. */

/*! @brief Read current value of the SEMA4_CPnINE_INE9 field. */
#define BR_SEMA4_CPnINE_INE9(x, n) (HW_SEMA4_CPnINE(x, n).B.INE9)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE9. */
#define BF_SEMA4_CPnINE_INE9(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE9) & BM_SEMA4_CPnINE_INE9)

/*! @brief Set the INE9 field to a new value. */
#define BW_SEMA4_CPnINE_INE9(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE9) | BF_SEMA4_CPnINE_INE9(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnINE, field INE8[15] (RW)
 *
 * Values:
 * - 0 - The generation of the notification interrupt is disabled.
 * - 1 - The generation of the notification interrupt is enabled.
 */
/*@{*/
#define BP_SEMA4_CPnINE_INE8 (15U)         /*!< Bit position for SEMA4_CPnINE_INE8. */
#define BM_SEMA4_CPnINE_INE8 (0x8000U)     /*!< Bit mask for SEMA4_CPnINE_INE8. */
#define BS_SEMA4_CPnINE_INE8 (1U)          /*!< Bit field size in bits for SEMA4_CPnINE_INE8. */

/*! @brief Read current value of the SEMA4_CPnINE_INE8 field. */
#define BR_SEMA4_CPnINE_INE8(x, n) (HW_SEMA4_CPnINE(x, n).B.INE8)

/*! @brief Format value for bitfield SEMA4_CPnINE_INE8. */
#define BF_SEMA4_CPnINE_INE8(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnINE_INE8) & BM_SEMA4_CPnINE_INE8)

/*! @brief Set the INE8 field to a new value. */
#define BW_SEMA4_CPnINE_INE8(x, n, v) (HW_SEMA4_CPnINE_WR(x, n, (HW_SEMA4_CPnINE_RD(x, n) & ~BM_SEMA4_CPnINE_INE8) | BF_SEMA4_CPnINE_INE8(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_CPnNTF - Semaphores Processor n IRQ Notification
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_CPnNTF - Semaphores Processor n IRQ Notification (RW)
 *
 * Reset value: 0x0000U
 *
 * The Semaphores module optionally allows the processor that fails in the lock
 * attempt to continue with other tasks and allow a properly-enabled notification
 * interrupt to return its execution to the original lock function rather than
 * simply execute in a spin-wait loop. The optional notification interrupt
 * mechanism consists of two registers for each processor: an interrupt notification
 * enable register (SEMA4_CPnINE) and the read-only notification interrupt request
 * register (SEMA4_CPnNTF). To support implementations with more than 16 gates,
 * these registers can be referenced with aligned 16- or 32-bit accesses. For the
 * SEMA4_CPnNTF registers, unimplemented bits read as zeroes. The notification
 * interrupt is generated via a unique finite state machine, one per hardware gate.
 * This machine operates in the following manner: When an attempted lock fails,
 * the FSM enters a first state where it waits until the gate is unlocked. Once
 * unlocked, the FSM enters a second state where it generates an interrupt request
 * to the "failed lock" processor. When the "failed lock" processor succeeds in
 * locking the gate, the IRQ is automatically negated and the FSM returns to the
 * idle state. However, if the other processor again locks the gate, the FSM
 * returns to the first state, negates the interrupt request, and then waits for the
 * gate to be unlocked (again). The notification interrupt request is implemented
 * in a 3-bit, 5-state machine, where tw specific states are encoded and
 * program-visible as SEMA4_CP0NTF[GNn] and SEMA4_CP1NTF[GNn].
 */
typedef union _hw_sema4_cpnntf
{
    uint16_t U;
    struct _hw_sema4_cpnntf_bitfields
    {
        uint16_t GN7 : 1;              /*!< [0]  */
        uint16_t GN6 : 1;              /*!< [1]  */
        uint16_t GN5 : 1;              /*!< [2]  */
        uint16_t GN4 : 1;              /*!< [3]  */
        uint16_t GN3 : 1;              /*!< [4]  */
        uint16_t GN2 : 1;              /*!< [5]  */
        uint16_t GN1 : 1;              /*!< [6]  */
        uint16_t GN0 : 1;              /*!< [7]  */
        uint16_t GN15 : 1;             /*!< [8]  */
        uint16_t GN14 : 1;             /*!< [9]  */
        uint16_t GN13 : 1;             /*!< [10]  */
        uint16_t GN12 : 1;             /*!< [11]  */
        uint16_t GN11 : 1;             /*!< [12]  */
        uint16_t GN10 : 1;             /*!< [13]  */
        uint16_t GN9 : 1;              /*!< [14]  */
        uint16_t GN8 : 1;              /*!< [15]  */
    } B;
} hw_sema4_cpnntf_t;

/*!
 * @name Constants and macros for entire SEMA4_CPnNTF register
 */
/*@{*/
#define HW_SEMA4_CPnNTF_COUNT (2U)

#define HW_SEMA4_CPnNTF_ADDR(x, n) ((uintptr_t)(x) + 0x80U + (0x8U * (n)))

#define HW_SEMA4_CPnNTF(x, n)    (*(__IO hw_sema4_cpnntf_t *) HW_SEMA4_CPnNTF_ADDR(x, n))
#define HW_SEMA4_CPnNTF_RD(x, n) (HW_SEMA4_CPnNTF(x, n).U)
#define HW_SEMA4_CPnNTF_WR(x, n, v) (HW_SEMA4_CPnNTF(x, n).U = (v))
#define HW_SEMA4_CPnNTF_SET(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, HW_SEMA4_CPnNTF_RD(x, n) |  (v)))
#define HW_SEMA4_CPnNTF_CLR(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, HW_SEMA4_CPnNTF_RD(x, n) & ~(v)))
#define HW_SEMA4_CPnNTF_TOG(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, HW_SEMA4_CPnNTF_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_CPnNTF bitfields
 */

/*!
 * @name Register SEMA4_CPnNTF, field GN7[0] (RW)
 *
 * Gate 7 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 7. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN7  (0U)          /*!< Bit position for SEMA4_CPnNTF_GN7. */
#define BM_SEMA4_CPnNTF_GN7  (0x0001U)     /*!< Bit mask for SEMA4_CPnNTF_GN7. */
#define BS_SEMA4_CPnNTF_GN7  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN7. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN7 field. */
#define BR_SEMA4_CPnNTF_GN7(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN7)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN7. */
#define BF_SEMA4_CPnNTF_GN7(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN7) & BM_SEMA4_CPnNTF_GN7)

/*! @brief Set the GN7 field to a new value. */
#define BW_SEMA4_CPnNTF_GN7(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN7) | BF_SEMA4_CPnNTF_GN7(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN6[1] (RW)
 *
 * Gate 6 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 6. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN6  (1U)          /*!< Bit position for SEMA4_CPnNTF_GN6. */
#define BM_SEMA4_CPnNTF_GN6  (0x0002U)     /*!< Bit mask for SEMA4_CPnNTF_GN6. */
#define BS_SEMA4_CPnNTF_GN6  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN6. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN6 field. */
#define BR_SEMA4_CPnNTF_GN6(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN6)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN6. */
#define BF_SEMA4_CPnNTF_GN6(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN6) & BM_SEMA4_CPnNTF_GN6)

/*! @brief Set the GN6 field to a new value. */
#define BW_SEMA4_CPnNTF_GN6(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN6) | BF_SEMA4_CPnNTF_GN6(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN5[2] (RW)
 *
 * Gate 5 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 5. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN5  (2U)          /*!< Bit position for SEMA4_CPnNTF_GN5. */
#define BM_SEMA4_CPnNTF_GN5  (0x0004U)     /*!< Bit mask for SEMA4_CPnNTF_GN5. */
#define BS_SEMA4_CPnNTF_GN5  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN5. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN5 field. */
#define BR_SEMA4_CPnNTF_GN5(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN5)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN5. */
#define BF_SEMA4_CPnNTF_GN5(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN5) & BM_SEMA4_CPnNTF_GN5)

/*! @brief Set the GN5 field to a new value. */
#define BW_SEMA4_CPnNTF_GN5(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN5) | BF_SEMA4_CPnNTF_GN5(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN4[3] (RW)
 *
 * Gate 4 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 4. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN4  (3U)          /*!< Bit position for SEMA4_CPnNTF_GN4. */
#define BM_SEMA4_CPnNTF_GN4  (0x0008U)     /*!< Bit mask for SEMA4_CPnNTF_GN4. */
#define BS_SEMA4_CPnNTF_GN4  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN4. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN4 field. */
#define BR_SEMA4_CPnNTF_GN4(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN4)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN4. */
#define BF_SEMA4_CPnNTF_GN4(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN4) & BM_SEMA4_CPnNTF_GN4)

/*! @brief Set the GN4 field to a new value. */
#define BW_SEMA4_CPnNTF_GN4(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN4) | BF_SEMA4_CPnNTF_GN4(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN3[4] (RW)
 *
 * Gate 3 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 3. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN3  (4U)          /*!< Bit position for SEMA4_CPnNTF_GN3. */
#define BM_SEMA4_CPnNTF_GN3  (0x0010U)     /*!< Bit mask for SEMA4_CPnNTF_GN3. */
#define BS_SEMA4_CPnNTF_GN3  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN3. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN3 field. */
#define BR_SEMA4_CPnNTF_GN3(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN3)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN3. */
#define BF_SEMA4_CPnNTF_GN3(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN3) & BM_SEMA4_CPnNTF_GN3)

/*! @brief Set the GN3 field to a new value. */
#define BW_SEMA4_CPnNTF_GN3(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN3) | BF_SEMA4_CPnNTF_GN3(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN2[5] (RW)
 *
 * Gate 2 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 2. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN2  (5U)          /*!< Bit position for SEMA4_CPnNTF_GN2. */
#define BM_SEMA4_CPnNTF_GN2  (0x0020U)     /*!< Bit mask for SEMA4_CPnNTF_GN2. */
#define BS_SEMA4_CPnNTF_GN2  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN2. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN2 field. */
#define BR_SEMA4_CPnNTF_GN2(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN2)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN2. */
#define BF_SEMA4_CPnNTF_GN2(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN2) & BM_SEMA4_CPnNTF_GN2)

/*! @brief Set the GN2 field to a new value. */
#define BW_SEMA4_CPnNTF_GN2(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN2) | BF_SEMA4_CPnNTF_GN2(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN1[6] (RW)
 *
 * Gate 1 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 1. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN1  (6U)          /*!< Bit position for SEMA4_CPnNTF_GN1. */
#define BM_SEMA4_CPnNTF_GN1  (0x0040U)     /*!< Bit mask for SEMA4_CPnNTF_GN1. */
#define BS_SEMA4_CPnNTF_GN1  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN1. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN1 field. */
#define BR_SEMA4_CPnNTF_GN1(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN1)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN1. */
#define BF_SEMA4_CPnNTF_GN1(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN1) & BM_SEMA4_CPnNTF_GN1)

/*! @brief Set the GN1 field to a new value. */
#define BW_SEMA4_CPnNTF_GN1(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN1) | BF_SEMA4_CPnNTF_GN1(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN0[7] (RW)
 *
 * Gate 0 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 0. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN0  (7U)          /*!< Bit position for SEMA4_CPnNTF_GN0. */
#define BM_SEMA4_CPnNTF_GN0  (0x0080U)     /*!< Bit mask for SEMA4_CPnNTF_GN0. */
#define BS_SEMA4_CPnNTF_GN0  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN0. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN0 field. */
#define BR_SEMA4_CPnNTF_GN0(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN0)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN0. */
#define BF_SEMA4_CPnNTF_GN0(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN0) & BM_SEMA4_CPnNTF_GN0)

/*! @brief Set the GN0 field to a new value. */
#define BW_SEMA4_CPnNTF_GN0(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN0) | BF_SEMA4_CPnNTF_GN0(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN15[8] (RW)
 *
 * Gate 15 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 15. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN15 (8U)          /*!< Bit position for SEMA4_CPnNTF_GN15. */
#define BM_SEMA4_CPnNTF_GN15 (0x0100U)     /*!< Bit mask for SEMA4_CPnNTF_GN15. */
#define BS_SEMA4_CPnNTF_GN15 (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN15. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN15 field. */
#define BR_SEMA4_CPnNTF_GN15(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN15)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN15. */
#define BF_SEMA4_CPnNTF_GN15(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN15) & BM_SEMA4_CPnNTF_GN15)

/*! @brief Set the GN15 field to a new value. */
#define BW_SEMA4_CPnNTF_GN15(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN15) | BF_SEMA4_CPnNTF_GN15(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN14[9] (RW)
 *
 * Gate 14 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 14. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN14 (9U)          /*!< Bit position for SEMA4_CPnNTF_GN14. */
#define BM_SEMA4_CPnNTF_GN14 (0x0200U)     /*!< Bit mask for SEMA4_CPnNTF_GN14. */
#define BS_SEMA4_CPnNTF_GN14 (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN14. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN14 field. */
#define BR_SEMA4_CPnNTF_GN14(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN14)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN14. */
#define BF_SEMA4_CPnNTF_GN14(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN14) & BM_SEMA4_CPnNTF_GN14)

/*! @brief Set the GN14 field to a new value. */
#define BW_SEMA4_CPnNTF_GN14(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN14) | BF_SEMA4_CPnNTF_GN14(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN13[10] (RW)
 *
 * Gate 13 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 13. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN13 (10U)         /*!< Bit position for SEMA4_CPnNTF_GN13. */
#define BM_SEMA4_CPnNTF_GN13 (0x0400U)     /*!< Bit mask for SEMA4_CPnNTF_GN13. */
#define BS_SEMA4_CPnNTF_GN13 (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN13. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN13 field. */
#define BR_SEMA4_CPnNTF_GN13(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN13)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN13. */
#define BF_SEMA4_CPnNTF_GN13(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN13) & BM_SEMA4_CPnNTF_GN13)

/*! @brief Set the GN13 field to a new value. */
#define BW_SEMA4_CPnNTF_GN13(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN13) | BF_SEMA4_CPnNTF_GN13(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN12[11] (RW)
 *
 * Gate 12 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 12. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN12 (11U)         /*!< Bit position for SEMA4_CPnNTF_GN12. */
#define BM_SEMA4_CPnNTF_GN12 (0x0800U)     /*!< Bit mask for SEMA4_CPnNTF_GN12. */
#define BS_SEMA4_CPnNTF_GN12 (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN12. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN12 field. */
#define BR_SEMA4_CPnNTF_GN12(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN12)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN12. */
#define BF_SEMA4_CPnNTF_GN12(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN12) & BM_SEMA4_CPnNTF_GN12)

/*! @brief Set the GN12 field to a new value. */
#define BW_SEMA4_CPnNTF_GN12(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN12) | BF_SEMA4_CPnNTF_GN12(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN11[12] (RW)
 *
 * Gate 11 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 11. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN11 (12U)         /*!< Bit position for SEMA4_CPnNTF_GN11. */
#define BM_SEMA4_CPnNTF_GN11 (0x1000U)     /*!< Bit mask for SEMA4_CPnNTF_GN11. */
#define BS_SEMA4_CPnNTF_GN11 (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN11. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN11 field. */
#define BR_SEMA4_CPnNTF_GN11(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN11)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN11. */
#define BF_SEMA4_CPnNTF_GN11(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN11) & BM_SEMA4_CPnNTF_GN11)

/*! @brief Set the GN11 field to a new value. */
#define BW_SEMA4_CPnNTF_GN11(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN11) | BF_SEMA4_CPnNTF_GN11(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN10[13] (RW)
 *
 * Gate 10 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 10. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN10 (13U)         /*!< Bit position for SEMA4_CPnNTF_GN10. */
#define BM_SEMA4_CPnNTF_GN10 (0x2000U)     /*!< Bit mask for SEMA4_CPnNTF_GN10. */
#define BS_SEMA4_CPnNTF_GN10 (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN10. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN10 field. */
#define BR_SEMA4_CPnNTF_GN10(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN10)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN10. */
#define BF_SEMA4_CPnNTF_GN10(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN10) & BM_SEMA4_CPnNTF_GN10)

/*! @brief Set the GN10 field to a new value. */
#define BW_SEMA4_CPnNTF_GN10(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN10) | BF_SEMA4_CPnNTF_GN10(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN9[14] (RW)
 *
 * Gate 9 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 9. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN9  (14U)         /*!< Bit position for SEMA4_CPnNTF_GN9. */
#define BM_SEMA4_CPnNTF_GN9  (0x4000U)     /*!< Bit mask for SEMA4_CPnNTF_GN9. */
#define BS_SEMA4_CPnNTF_GN9  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN9. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN9 field. */
#define BR_SEMA4_CPnNTF_GN9(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN9)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN9. */
#define BF_SEMA4_CPnNTF_GN9(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN9) & BM_SEMA4_CPnNTF_GN9)

/*! @brief Set the GN9 field to a new value. */
#define BW_SEMA4_CPnNTF_GN9(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN9) | BF_SEMA4_CPnNTF_GN9(v)))
/*@}*/

/*!
 * @name Register SEMA4_CPnNTF, field GN8[15] (RW)
 *
 * Gate 8 Notification. This read-only field is a bitmap of the interrupt
 * request notification from a failed attempt to lock gate 8. For more details, see
 * SEMA4_CPnNTF Operation .
 */
/*@{*/
#define BP_SEMA4_CPnNTF_GN8  (15U)         /*!< Bit position for SEMA4_CPnNTF_GN8. */
#define BM_SEMA4_CPnNTF_GN8  (0x8000U)     /*!< Bit mask for SEMA4_CPnNTF_GN8. */
#define BS_SEMA4_CPnNTF_GN8  (1U)          /*!< Bit field size in bits for SEMA4_CPnNTF_GN8. */

/*! @brief Read current value of the SEMA4_CPnNTF_GN8 field. */
#define BR_SEMA4_CPnNTF_GN8(x, n) (HW_SEMA4_CPnNTF(x, n).B.GN8)

/*! @brief Format value for bitfield SEMA4_CPnNTF_GN8. */
#define BF_SEMA4_CPnNTF_GN8(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_CPnNTF_GN8) & BM_SEMA4_CPnNTF_GN8)

/*! @brief Set the GN8 field to a new value. */
#define BW_SEMA4_CPnNTF_GN8(x, n, v) (HW_SEMA4_CPnNTF_WR(x, n, (HW_SEMA4_CPnNTF_RD(x, n) & ~BM_SEMA4_CPnNTF_GN8) | BF_SEMA4_CPnNTF_GN8(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_RSTGT - Semaphores (Secure) Reset Gate n
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_RSTGT - Semaphores (Secure) Reset Gate n (RW)
 *
 * Reset value: 0x0000U
 *
 * Although the intent of the hardware gate implementation specifies a protocol
 * where the locking processor must unlock the gate, it is recognized that system
 * operation may require a reset function to re-initialize the state of any
 * gate(s) without requiring a system-level reset. To support this special gate reset
 * requirement, the Semaphores module implements a "secure" reset mechanism
 * which allows a hardware gate (or all the gates) to be initialized by following a
 * specific dual-write access pattern. Using a technique similar to that required
 * for the servicing of a software watchdog timer, the secure gate reset requires
 * two consecutive writes with predefined data patterns from the same processor
 * to force the clearing of the specified gate(s). The required access pattern
 * is: A processor performs a 16-bit write to the SEMA4_RSTGT memory location. The
 * most significant byte (SEMA4_RSTGT[RSTGDP]) must be 0xe2; the least
 * significant byte is a "don't_care" for this reference. The same processor then performs
 * a second 16-bit write to the SEMA4_RSTGT location. For this write, the upper
 * byte (SEMA4_RSTGT[RSTGDP]) is the logical complement of the first data pattern
 * (0x1d) and the lower byte (SEMA4_RSTGT[RSTGTN]) specifies the gate(s) to be
 * reset. This gate field can specify a single gate be cleared, or that all gates
 * are cleared. Reads of the SEMA4_RSTGT location return information on the 2-bit
 * state machine (SEMA4_RSTGT[RSTGSM]) which implements this function, the bus
 * master performing the reset (SEMA4_RSTGT[RSTGMS]) and the gate number(s) last
 * cleared (SEMA4_RSTGT[RSTGTN]). Reads of the SEMA4_RSTGT register do not affect
 * the secure reset finite state machine in any manner.
 */
typedef union _hw_sema4_rstgt
{
    uint16_t U;
    struct _hw_sema4_rstgt_bitfields
    {
        uint16_t RSTGSM_RSTGMS_RSTGDP : 8; /*!< [7:0]  */
        uint16_t RSTGTN : 8;           /*!< [15:8]  */
    } B;
} hw_sema4_rstgt_t;

/*!
 * @name Constants and macros for entire SEMA4_RSTGT register
 */
/*@{*/
#define HW_SEMA4_RSTGT_ADDR(x)   ((uintptr_t)(x) + 0x100U)

#define HW_SEMA4_RSTGT(x)        (*(__IO hw_sema4_rstgt_t *) HW_SEMA4_RSTGT_ADDR(x))
#define HW_SEMA4_RSTGT_RD(x)     (HW_SEMA4_RSTGT(x).U)
#define HW_SEMA4_RSTGT_WR(x, v)  (HW_SEMA4_RSTGT(x).U = (v))
#define HW_SEMA4_RSTGT_SET(x, v) (HW_SEMA4_RSTGT_WR(x, HW_SEMA4_RSTGT_RD(x) |  (v)))
#define HW_SEMA4_RSTGT_CLR(x, v) (HW_SEMA4_RSTGT_WR(x, HW_SEMA4_RSTGT_RD(x) & ~(v)))
#define HW_SEMA4_RSTGT_TOG(x, v) (HW_SEMA4_RSTGT_WR(x, HW_SEMA4_RSTGT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_RSTGT bitfields
 */

/*!
 * @name Register SEMA4_RSTGT, field RSTGSM_RSTGMS_RSTGDP[7:0] (RW)
 *
 * This field contains subfields that vary depending on whether it is being read
 * or written. Sub-fields indicated as having read access are valid only for
 * read operations. Sub-fields indicated as having write access are valid only for
 * write operations. Bit numbering in the descriptions begins with the most
 * significant bit numbered 0. See the following table for details. Access Sub-Field
 * Description Read-Only 7-6 Reserved Reserved. Always reads 0. 5-4 RSTGSM Reset
 * Gate Finite State Machine. Reads of the SEMA4_RSTGT register return the encoded
 * state machine value. The reset state machine is maintained in a 2-bit, 3-state
 * implementation, defined as: 00 Idle, waiting for the first data pattern
 * write. 01 Waiting for the second data pattern write. 10 The 2-write sequence has
 * completed. Generate the specified gate reset(s). After the reset is performed,
 * this machine returns to the idle (waiting for first data pattern write) state.
 * Note that the RSTGSM = 0b10 state is valid for only a single machine cycle, so
 * it is impossible for a read to return this value 11 This state encoding is
 * never used and therefore reserved. 3 Reserved Reserved. Always reads 0. 2-0
 * RSTGMS Reset Gate Bus Master. This 3-bit read-only field records the logical
 * number of the bus master performing the gate reset function. The reset function
 * requires that the two consecutive writes to this register be initiated by the
 * same bus master to succeed. This field is updated each time a write to this
 * register occurs. The association between system bus master port numbers, the
 * associated bus master device and the logical processor number is SoC-specific. See
 * the chip configuration chapter for this information. Write-Only 7-0 RSTGDP
 * Reset Gate Data Pattern. This write-only field is accessed with the specified data
 * patterns on the two consecutive writes to enable the gate reset mechanism.
 * For the first write, RSTGDP = 0xe2 while the second write requires RSTGDP = 0x1d.
 */
/*@{*/
#define BP_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP (0U) /*!< Bit position for SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP. */
#define BM_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP (0x00FFU) /*!< Bit mask for SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP. */
#define BS_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP (8U) /*!< Bit field size in bits for SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP. */

/*! @brief Read current value of the SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP field. */
#define BR_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP(x) (HW_SEMA4_RSTGT(x).B.RSTGSM_RSTGMS_RSTGDP)

/*! @brief Format value for bitfield SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP. */
#define BF_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP) & BM_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP)

/*! @brief Set the RSTGSM_RSTGMS_RSTGDP field to a new value. */
#define BW_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP(x, v) (HW_SEMA4_RSTGT_WR(x, (HW_SEMA4_RSTGT_RD(x) & ~BM_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP) | BF_SEMA4_RSTGT_RSTGSM_RSTGMS_RSTGDP(v)))
/*@}*/

/*!
 * @name Register SEMA4_RSTGT, field RSTGTN[15:8] (RW)
 *
 * Reset Gate Number. This 8-bit field specifies the specific hardware gate to
 * be reset. This field is updated by the second write. If RSTGTN < 64, then reset
 * the single gate defined by RSTGTN, else reset all the gates. The
 * corresponding secure IRQ notification state machine(s) are also reset.
 */
/*@{*/
#define BP_SEMA4_RSTGT_RSTGTN (8U)         /*!< Bit position for SEMA4_RSTGT_RSTGTN. */
#define BM_SEMA4_RSTGT_RSTGTN (0xFF00U)    /*!< Bit mask for SEMA4_RSTGT_RSTGTN. */
#define BS_SEMA4_RSTGT_RSTGTN (8U)         /*!< Bit field size in bits for SEMA4_RSTGT_RSTGTN. */

/*! @brief Read current value of the SEMA4_RSTGT_RSTGTN field. */
#define BR_SEMA4_RSTGT_RSTGTN(x) (HW_SEMA4_RSTGT(x).B.RSTGTN)

/*! @brief Format value for bitfield SEMA4_RSTGT_RSTGTN. */
#define BF_SEMA4_RSTGT_RSTGTN(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_RSTGT_RSTGTN) & BM_SEMA4_RSTGT_RSTGTN)

/*! @brief Set the RSTGTN field to a new value. */
#define BW_SEMA4_RSTGT_RSTGTN(x, v) (HW_SEMA4_RSTGT_WR(x, (HW_SEMA4_RSTGT_RD(x) & ~BM_SEMA4_RSTGT_RSTGTN) | BF_SEMA4_RSTGT_RSTGTN(v)))
/*@}*/

/*******************************************************************************
 * HW_SEMA4_RSTNTF - Semaphores (Secure) Reset IRQ Notification
 ******************************************************************************/

/*!
 * @brief HW_SEMA4_RSTNTF - Semaphores (Secure) Reset IRQ Notification (RW)
 *
 * Reset value: 0x0000U
 *
 * As with the case of the secure reset function and the hardware gates, it is
 * recognized that system operation may require a reset function to re-initialize
 * the state of the IRQ notification logic without requiring a system-level
 * reset. To support this special notification reset requirement, the Semaphores
 * module implements a "secure" reset mechanism which allows an IRQ notification (or
 * all the notifications) to be initialized by following a specific dual-write
 * access pattern. When successful, the specified IRQ notification state machine(s)
 * are reset. Using a technique similar to that required for the servicing of a
 * software watchdog timer, the secure reset mechanism requires two consecutive
 * writes with predefined data patterns from the same processor to force the
 * clearing of the IRQ notification(s). The required access pattern is: A processor
 * performs a 16-bit write to the SEMA4_RSTNTF memory location. The most significant
 * byte (SEMA4_RSTNTF[RSTNDP]) must be 0x47; the least significant byte is a
 * "don't_care" for this reference. The same processor then performs a second 16-bit
 * write to the SEMA4_RSTNTF location. For this write, the upper byte
 * (SEMA4_RSTNTF[RSTNDP]) is the logical complement of the first data pattern (0xb8) and
 * the lower byte (SEMA4_RSTNTF[RSTNTN]) specifies the notification(s) to be reset.
 * This field can specify a single notification be cleared, or that all
 * notifications are cleared. Reads of the SEMA4_RSTNTF location return information on
 * the 2-bit state machine (SEMA4_RSTNTF[RSTNSM]) which implements this function,
 * the bus master performing the reset (SEMA4_RSTNTF[RSTNMS]) and the notification
 * number(s) last cleared (SEMA4_RSTNTF[RSTNTN]). Reads of the SEMA4_RSTNTF
 * register do not affect the secure reset finite state machine in any manner.
 */
typedef union _hw_sema4_rstntf
{
    uint16_t U;
    struct _hw_sema4_rstntf_bitfields
    {
        uint16_t RSTNSM_RSTNMS_RSTNDP : 8; /*!< [7:0]  */
        uint16_t RSTNTN : 8;           /*!< [15:8]  */
    } B;
} hw_sema4_rstntf_t;

/*!
 * @name Constants and macros for entire SEMA4_RSTNTF register
 */
/*@{*/
#define HW_SEMA4_RSTNTF_ADDR(x)  ((uintptr_t)(x) + 0x104U)

#define HW_SEMA4_RSTNTF(x)       (*(__IO hw_sema4_rstntf_t *) HW_SEMA4_RSTNTF_ADDR(x))
#define HW_SEMA4_RSTNTF_RD(x)    (HW_SEMA4_RSTNTF(x).U)
#define HW_SEMA4_RSTNTF_WR(x, v) (HW_SEMA4_RSTNTF(x).U = (v))
#define HW_SEMA4_RSTNTF_SET(x, v) (HW_SEMA4_RSTNTF_WR(x, HW_SEMA4_RSTNTF_RD(x) |  (v)))
#define HW_SEMA4_RSTNTF_CLR(x, v) (HW_SEMA4_RSTNTF_WR(x, HW_SEMA4_RSTNTF_RD(x) & ~(v)))
#define HW_SEMA4_RSTNTF_TOG(x, v) (HW_SEMA4_RSTNTF_WR(x, HW_SEMA4_RSTNTF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SEMA4_RSTNTF bitfields
 */

/*!
 * @name Register SEMA4_RSTNTF, field RSTNSM_RSTNMS_RSTNDP[7:0] (RW)
 *
 * This field contains subfields that vary depending on whether it is being read
 * or written. Sub-fields indicated as having read access are valid only for
 * read operations. Sub-fields indicated as having write access are valid only for
 * write operations. Bit numbering in the descriptions begins with the most
 * significant bit numbered 0. See the following table for details. Access Sub-Field
 * Description Read-Only 7-6 Reserved Reserved. Always reads 0. 5-4 RSTNSM Reset
 * Notification Finite State Machine. Reads of the SEMA4_RSTNTF register return the
 * encoded state machine value. The reset state machine is maintained in a
 * 2-bit, 3-state implementation, defined as: 00 Idle, waiting for the first data
 * pattern write. 01 Waiting for the second data pattern write. 10 The 2-write
 * sequence has completed. Generate the specified notification reset(s). After the
 * reset is performed, this machine returns to the idle (waiting for first data
 * pattern write) state. Note the RSTNSM = 10 state is valid for only a single machine
 * cycle, so it is impossible for a read to return this value. 11 This state
 * encoding is never used and therefore reserved.. 3 Reserved Reserved. Always reads
 * 0. 2-0 RSTNMS Reset Notification Bus Master. This 3-bit read-only field
 * records the logical number of the bus master performing the notification reset
 * function. The reset function requires that the two consecutive writes to this
 * register be initiated by the same bus master to succeed. This field is updated
 * each time a write to this register occurs. The association between system bus
 * master port numbers, the associated bus master device and the logical processor
 * number is SoC-specific. See the chip configuration chapter for this
 * information. Write-Only 7-0 RSTNDP Reset Notification Data Pattern. This write-only field
 * is accessed with the specified data patterns on the two consecutive writes to
 * enable the notification reset mechanism. For the first write, RSTNDP = 0x47
 * while the second write requires RSTNDP = 0xb8.
 */
/*@{*/
#define BP_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP (0U) /*!< Bit position for SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP. */
#define BM_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP (0x00FFU) /*!< Bit mask for SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP. */
#define BS_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP (8U) /*!< Bit field size in bits for SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP. */

/*! @brief Read current value of the SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP field. */
#define BR_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP(x) (HW_SEMA4_RSTNTF(x).B.RSTNSM_RSTNMS_RSTNDP)

/*! @brief Format value for bitfield SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP. */
#define BF_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP) & BM_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP)

/*! @brief Set the RSTNSM_RSTNMS_RSTNDP field to a new value. */
#define BW_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP(x, v) (HW_SEMA4_RSTNTF_WR(x, (HW_SEMA4_RSTNTF_RD(x) & ~BM_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP) | BF_SEMA4_RSTNTF_RSTNSM_RSTNMS_RSTNDP(v)))
/*@}*/

/*!
 * @name Register SEMA4_RSTNTF, field RSTNTN[15:8] (RW)
 *
 * Reset Notification Number. This 8-bit field specifies the specific IRQ
 * notification state machine to be reset. This field is updated by the second write.
 * If RSTNTN < 64, then reset the single IRQ notification machine defined by
 * RSTNTN, else reset all the notifications.
 */
/*@{*/
#define BP_SEMA4_RSTNTF_RSTNTN (8U)        /*!< Bit position for SEMA4_RSTNTF_RSTNTN. */
#define BM_SEMA4_RSTNTF_RSTNTN (0xFF00U)   /*!< Bit mask for SEMA4_RSTNTF_RSTNTN. */
#define BS_SEMA4_RSTNTF_RSTNTN (8U)        /*!< Bit field size in bits for SEMA4_RSTNTF_RSTNTN. */

/*! @brief Read current value of the SEMA4_RSTNTF_RSTNTN field. */
#define BR_SEMA4_RSTNTF_RSTNTN(x) (HW_SEMA4_RSTNTF(x).B.RSTNTN)

/*! @brief Format value for bitfield SEMA4_RSTNTF_RSTNTN. */
#define BF_SEMA4_RSTNTF_RSTNTN(v) ((uint16_t)((uint16_t)(v) << BP_SEMA4_RSTNTF_RSTNTN) & BM_SEMA4_RSTNTF_RSTNTN)

/*! @brief Set the RSTNTN field to a new value. */
#define BW_SEMA4_RSTNTF_RSTNTN(x, v) (HW_SEMA4_RSTNTF_WR(x, (HW_SEMA4_RSTNTF_RD(x) & ~BM_SEMA4_RSTNTF_RSTNTN) | BF_SEMA4_RSTNTF_RSTNTN(v)))
/*@}*/

/*******************************************************************************
 * hw_sema4_t - module struct
 ******************************************************************************/
/*!
 * @brief All SEMA4 module registers.
 */
#pragma pack(1)
typedef struct _hw_sema4
{
    __IO hw_sema4_gate00_t Gate00;         /*!< [0x0] Semaphores Gate 0 Register */
    __IO hw_sema4_gate01_t Gate01;         /*!< [0x1] Semaphores Gate 1 Register */
    __IO hw_sema4_gate02_t Gate02;         /*!< [0x2] Semaphores Gate 2 Register */
    __IO hw_sema4_gate03_t Gate03;         /*!< [0x3] Semaphores Gate 3 Register */
    __IO hw_sema4_gate04_t Gate04;         /*!< [0x4] Semaphores Gate 4 Register */
    __IO hw_sema4_gate05_t Gate05;         /*!< [0x5] Semaphores Gate 5 Register */
    __IO hw_sema4_gate06_t Gate06;         /*!< [0x6] Semaphores Gate 6 Register */
    __IO hw_sema4_gate07_t Gate07;         /*!< [0x7] Semaphores Gate 7 Register */
    __IO hw_sema4_gate08_t Gate08;         /*!< [0x8] Semaphores Gate 8 Register */
    __IO hw_sema4_gate09_t Gate09;         /*!< [0x9] Semaphores Gate 9 Register */
    __IO hw_sema4_gate10_t Gate10;         /*!< [0xA] Semaphores Gate 10 Register */
    __IO hw_sema4_gate11_t Gate11;         /*!< [0xB] Semaphores Gate 11 Register */
    __IO hw_sema4_gate12_t Gate12;         /*!< [0xC] Semaphores Gate 12 Register */
    __IO hw_sema4_gate13_t Gate13;         /*!< [0xD] Semaphores Gate 13 Register */
    __IO hw_sema4_gate14_t Gate14;         /*!< [0xE] Semaphores Gate 14 Register */
    __IO hw_sema4_gate15_t Gate15;         /*!< [0xF] Semaphores Gate 15 Register */
    uint8_t _reserved0[48];
    struct {
        __IO hw_sema4_cpnine_t CPnINE;     /*!< [0x40] Semaphores Processor n IRQ Notification Enable */
        uint8_t _reserved0[6];
    } CPINE[2];
    uint8_t _reserved1[48];
    struct {
        __IO hw_sema4_cpnntf_t CPnNTF;     /*!< [0x80] Semaphores Processor n IRQ Notification */
        uint8_t _reserved0[6];
    } CPNTF[2];
    uint8_t _reserved2[112];
    __IO hw_sema4_rstgt_t RSTGT;           /*!< [0x100] Semaphores (Secure) Reset Gate n */
    uint8_t _reserved3[2];
    __IO hw_sema4_rstntf_t RSTNTF;         /*!< [0x104] Semaphores (Secure) Reset IRQ Notification */
} hw_sema4_t;
#pragma pack()

/*! @brief Macro to access all SEMA4 registers. */
/*! @param x SEMA4 module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_SEMA4_REGS(SEMA4_BASE)</code>. */
#define HW_SEMA4_REGS(x) (*(hw_sema4_t *)(x))

/*
 * iMX7D SIM
 *
 * SIM
 *
 * Registers defined in this header file:
 * - HW_SIM_PORT1_CNTL - SIM Port1 Control Register
 * - HW_SIM_SETUP - SIM Setup Register
 * - HW_SIM_PORT1_DETECT - SIM Port 1 Detect Register
 * - HW_SIM_XMT_BUF - SIM Transmit Buffer Register
 * - HW_SIM_RCV_BUF - SIM Receive Buffer Register
 * - HW_SIM_PORT0_CNTL - SIM Port0 Control Register
 * - HW_SIM_CNTL - SIM Control Register
 * - HW_SIM_CLK_PRESCALER - SIM Clock Prescaler Register
 * - HW_SIM_RCV_THRESHOLD - SIM Receive Threshold Register
 * - HW_SIM_ENABLE - SIM Enable Register
 * - HW_SIM_XMT_STATUS - SIM Transmit Status Register
 * - HW_SIM_RCV_STATUS - SIM Receive Status Register
 * - HW_SIM_INT_MASK - SIM Interrupt Mask Register
 * - HW_SIM_PORT0_DETECT - SIM Port0 Detect Register
 * - HW_SIM_DATA_FORMAT - SIM Data Format Register
 * - HW_SIM_XMT_THRESHOLD - SIM Transmit Threshold Register
 * - HW_SIM_GUARD_CNTL - SIM Transmit Guard Control Register
 * - HW_SIM_OD_CONFIG - SIM Open Drain Configuration Control Register
 * - HW_SIM_RESET_CNTL - SIM Reset Control Register
 * - HW_SIM_CHAR_WAIT - SIM Character Wait Time Register
 * - HW_SIM_GPCNT - SIM General Purpose Counter Register
 * - HW_SIM_DIVISOR - SIM Divisor Register
 * - HW_SIM_BWT - SIM Block Wait Time Register
 * - HW_SIM_BGT - SIM Block Guard Time Register
 * - HW_SIM_BWT_H - SIM Block Wait Time Register HIGH
 * - HW_SIM_XMT_FIFO_STAT - SIM Transmit FIFO Status Register
 * - HW_SIM_RCV_FIFO_CNT - SIM Receive FIFO Counter Register
 * - HW_SIM_RCV_FIFO_WPTR - SIM Receive FIFO Write Pointer Register
 * - HW_SIM_RCV_FIFO_RPTR - SIM Receive FIFO Read Pointer Register
 *
 * - hw_sim_t - Struct containing all module registers.
 */

#define HW_SIM_INSTANCE_COUNT (2U) /*!< Number of instances of the SIM module. */
#define HW_SIM1 (0U) /*!< Instance number for SIM1. */
#define HW_SIM2 (1U) /*!< Instance number for SIM2. */
#define SIM1_BASE             (0x30B90000U) /*!< Base address for SIM1. */
#define SIM2_BASE             (0x30BA0000U) /*!< Base address for SIM2. */
/*! Array initializer of SIM base addresses. */
#define SIM_BASE_ADDRS        { SIM1_BASE, SIM2_BASE }

/*******************************************************************************
 * HW_SIM_PORT1_CNTL - SIM Port1 Control Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_PORT1_CNTL - SIM Port1 Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * See the figure below for illustration of valid bits in the SIM Port1 Control
 * Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_port1_cntl
{
    uint32_t U;
    struct _hw_sim_port1_cntl_bitfields
    {
        uint32_t SAPD1 : 1;            /*!< [0]  */
        uint32_t SVEN1 : 1;            /*!< [1]  */
        uint32_t STEN1 : 1;            /*!< [2]  */
        uint32_t SRST1 : 1;            /*!< [3]  */
        uint32_t SCEN1 : 1;            /*!< [4]  */
        uint32_t SCSP1 : 1;            /*!< [5]  */
        uint32_t VOLT3_1 : 1;          /*!< [6]  */
        uint32_t SFPD1 : 1;            /*!< [7]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_sim_port1_cntl_t;

/*!
 * @name Constants and macros for entire SIM_PORT1_CNTL register
 */
/*@{*/
#define HW_SIM_PORT1_CNTL_ADDR(x) ((uintptr_t)(x) + 0x0U)

#define HW_SIM_PORT1_CNTL(x)     (*(__IO hw_sim_port1_cntl_t *) HW_SIM_PORT1_CNTL_ADDR(x))
#define HW_SIM_PORT1_CNTL_RD(x)  (HW_SIM_PORT1_CNTL(x).U)
#define HW_SIM_PORT1_CNTL_WR(x, v) (HW_SIM_PORT1_CNTL(x).U = (v))
#define HW_SIM_PORT1_CNTL_SET(x, v) (HW_SIM_PORT1_CNTL_WR(x, HW_SIM_PORT1_CNTL_RD(x) |  (v)))
#define HW_SIM_PORT1_CNTL_CLR(x, v) (HW_SIM_PORT1_CNTL_WR(x, HW_SIM_PORT1_CNTL_RD(x) & ~(v)))
#define HW_SIM_PORT1_CNTL_TOG(x, v) (HW_SIM_PORT1_CNTL_WR(x, HW_SIM_PORT1_CNTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_PORT1_CNTL bitfields
 */

/*!
 * @name Register SIM_PORT1_CNTL, field SAPD1[0] (RW)
 *
 * SIM card Auto Power Down Port 1. Used to enable/disable the auto power down
 * function for port 1. It will be forced low at the end of the auto power down
 * sequence.
 *
 * Values:
 * - 0 - Auto power down Port 1 disabled (default)
 * - 1 - Auto power down Port 1 enabled
 */
/*@{*/
#define BP_SIM_PORT1_CNTL_SAPD1 (0U)       /*!< Bit position for SIM_PORT1_CNTL_SAPD1. */
#define BM_SIM_PORT1_CNTL_SAPD1 (0x00000001U) /*!< Bit mask for SIM_PORT1_CNTL_SAPD1. */
#define BS_SIM_PORT1_CNTL_SAPD1 (1U)       /*!< Bit field size in bits for SIM_PORT1_CNTL_SAPD1. */

/*! @brief Read current value of the SIM_PORT1_CNTL_SAPD1 field. */
#define BR_SIM_PORT1_CNTL_SAPD1(x) (HW_SIM_PORT1_CNTL(x).B.SAPD1)

/*! @brief Format value for bitfield SIM_PORT1_CNTL_SAPD1. */
#define BF_SIM_PORT1_CNTL_SAPD1(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT1_CNTL_SAPD1) & BM_SIM_PORT1_CNTL_SAPD1)

/*! @brief Set the SAPD1 field to a new value. */
#define BW_SIM_PORT1_CNTL_SAPD1(x, v) (HW_SIM_PORT1_CNTL_WR(x, (HW_SIM_PORT1_CNTL_RD(x) & ~BM_SIM_PORT1_CNTL_SAPD1) | BF_SIM_PORT1_CNTL_SAPD1(v)))
/*@}*/

/*!
 * @name Register SIM_PORT1_CNTL, field SVEN1[1] (RW)
 *
 * SIM card Vcc Enable Port 1. Used to control the state of the SVEN1 pin on SIM
 * card port 1. The SVEN1 pin controls the SIM card VCC enable in the power
 * management chip. It can be forced low by hardware during the auto power down
 * sequence.
 *
 * Values:
 * - 0 - SIM card Voltage Port 1 disabled (default)
 * - 1 - SIM card Voltage Port 1 enabled
 */
/*@{*/
#define BP_SIM_PORT1_CNTL_SVEN1 (1U)       /*!< Bit position for SIM_PORT1_CNTL_SVEN1. */
#define BM_SIM_PORT1_CNTL_SVEN1 (0x00000002U) /*!< Bit mask for SIM_PORT1_CNTL_SVEN1. */
#define BS_SIM_PORT1_CNTL_SVEN1 (1U)       /*!< Bit field size in bits for SIM_PORT1_CNTL_SVEN1. */

/*! @brief Read current value of the SIM_PORT1_CNTL_SVEN1 field. */
#define BR_SIM_PORT1_CNTL_SVEN1(x) (HW_SIM_PORT1_CNTL(x).B.SVEN1)

/*! @brief Format value for bitfield SIM_PORT1_CNTL_SVEN1. */
#define BF_SIM_PORT1_CNTL_SVEN1(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT1_CNTL_SVEN1) & BM_SIM_PORT1_CNTL_SVEN1)

/*! @brief Set the SVEN1 field to a new value. */
#define BW_SIM_PORT1_CNTL_SVEN1(x, v) (HW_SIM_PORT1_CNTL_WR(x, (HW_SIM_PORT1_CNTL_RD(x) & ~BM_SIM_PORT1_CNTL_SVEN1) | BF_SIM_PORT1_CNTL_SVEN1(v)))
/*@}*/

/*!
 * @name Register SIM_PORT1_CNTL, field STEN1[2] (RW)
 *
 * SIM card Transmit Enable Port 1. Used to enable/disable the XMT data to the
 * SIM card. It can be forced low by hardware during the auto power down sequence.
 *
 * Values:
 * - 0 - Port1 Transmit Data is forced to zero (default)
 * - 1 - Port 1 Transmit Data controlled by SIM module
 */
/*@{*/
#define BP_SIM_PORT1_CNTL_STEN1 (2U)       /*!< Bit position for SIM_PORT1_CNTL_STEN1. */
#define BM_SIM_PORT1_CNTL_STEN1 (0x00000004U) /*!< Bit mask for SIM_PORT1_CNTL_STEN1. */
#define BS_SIM_PORT1_CNTL_STEN1 (1U)       /*!< Bit field size in bits for SIM_PORT1_CNTL_STEN1. */

/*! @brief Read current value of the SIM_PORT1_CNTL_STEN1 field. */
#define BR_SIM_PORT1_CNTL_STEN1(x) (HW_SIM_PORT1_CNTL(x).B.STEN1)

/*! @brief Format value for bitfield SIM_PORT1_CNTL_STEN1. */
#define BF_SIM_PORT1_CNTL_STEN1(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT1_CNTL_STEN1) & BM_SIM_PORT1_CNTL_STEN1)

/*! @brief Set the STEN1 field to a new value. */
#define BW_SIM_PORT1_CNTL_STEN1(x, v) (HW_SIM_PORT1_CNTL_WR(x, (HW_SIM_PORT1_CNTL_RD(x) & ~BM_SIM_PORT1_CNTL_STEN1) | BF_SIM_PORT1_CNTL_STEN1(v)))
/*@}*/

/*!
 * @name Register SIM_PORT1_CNTL, field SRST1[3] (RW)
 *
 * SIM card Reset. Used to control state of reset line to the SIM card. It can
 * be forced low by hardware during the auto power down sequence. SIM card reset
 * signals are active low.
 *
 * Values:
 * - 0 - SIM Card reset Port1 inactive (default)
 * - 1 - SIM Card reset Port1 active
 */
/*@{*/
#define BP_SIM_PORT1_CNTL_SRST1 (3U)       /*!< Bit position for SIM_PORT1_CNTL_SRST1. */
#define BM_SIM_PORT1_CNTL_SRST1 (0x00000008U) /*!< Bit mask for SIM_PORT1_CNTL_SRST1. */
#define BS_SIM_PORT1_CNTL_SRST1 (1U)       /*!< Bit field size in bits for SIM_PORT1_CNTL_SRST1. */

/*! @brief Read current value of the SIM_PORT1_CNTL_SRST1 field. */
#define BR_SIM_PORT1_CNTL_SRST1(x) (HW_SIM_PORT1_CNTL(x).B.SRST1)

/*! @brief Format value for bitfield SIM_PORT1_CNTL_SRST1. */
#define BF_SIM_PORT1_CNTL_SRST1(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT1_CNTL_SRST1) & BM_SIM_PORT1_CNTL_SRST1)

/*! @brief Set the SRST1 field to a new value. */
#define BW_SIM_PORT1_CNTL_SRST1(x, v) (HW_SIM_PORT1_CNTL_WR(x, (HW_SIM_PORT1_CNTL_RD(x) & ~BM_SIM_PORT1_CNTL_SRST1) | BF_SIM_PORT1_CNTL_SRST1(v)))
/*@}*/

/*!
 * @name Register SIM_PORT1_CNTL, field SCEN1[4] (RW)
 *
 * SIM card Clock Enable Port 1. Used to enable/disable the clock to the SIM
 * card. It can be forced low by hardware during the auto power down sequence.
 *
 * Values:
 * - 0 - SIM Card Clock Disabled Port1
 * - 1 - SIM Card Clock Enabled Port1
 */
/*@{*/
#define BP_SIM_PORT1_CNTL_SCEN1 (4U)       /*!< Bit position for SIM_PORT1_CNTL_SCEN1. */
#define BM_SIM_PORT1_CNTL_SCEN1 (0x00000010U) /*!< Bit mask for SIM_PORT1_CNTL_SCEN1. */
#define BS_SIM_PORT1_CNTL_SCEN1 (1U)       /*!< Bit field size in bits for SIM_PORT1_CNTL_SCEN1. */

/*! @brief Read current value of the SIM_PORT1_CNTL_SCEN1 field. */
#define BR_SIM_PORT1_CNTL_SCEN1(x) (HW_SIM_PORT1_CNTL(x).B.SCEN1)

/*! @brief Format value for bitfield SIM_PORT1_CNTL_SCEN1. */
#define BF_SIM_PORT1_CNTL_SCEN1(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT1_CNTL_SCEN1) & BM_SIM_PORT1_CNTL_SCEN1)

/*! @brief Set the SCEN1 field to a new value. */
#define BW_SIM_PORT1_CNTL_SCEN1(x, v) (HW_SIM_PORT1_CNTL_WR(x, (HW_SIM_PORT1_CNTL_RD(x) & ~BM_SIM_PORT1_CNTL_SCEN1) | BF_SIM_PORT1_CNTL_SCEN1(v)))
/*@}*/

/*!
 * @name Register SIM_PORT1_CNTL, field SCSP1[5] (RW)
 *
 * SIM Card Clock Stop Polarity Port1. Used to control the polarity of the idle
 * SIM clock when the clock is disabled by SCEN1. It will be forced low by
 * hardware during the auto power down sequence. This forces the clock be a logic 0
 * when stopped by auto power down as required by ISO 7816 spec.
 *
 * Values:
 * - 0 - Clock is logic 0 when stopped by SCEN1
 * - 1 - Clock is logic 1 when stopped by SCEN1
 */
/*@{*/
#define BP_SIM_PORT1_CNTL_SCSP1 (5U)       /*!< Bit position for SIM_PORT1_CNTL_SCSP1. */
#define BM_SIM_PORT1_CNTL_SCSP1 (0x00000020U) /*!< Bit mask for SIM_PORT1_CNTL_SCSP1. */
#define BS_SIM_PORT1_CNTL_SCSP1 (1U)       /*!< Bit field size in bits for SIM_PORT1_CNTL_SCSP1. */

/*! @brief Read current value of the SIM_PORT1_CNTL_SCSP1 field. */
#define BR_SIM_PORT1_CNTL_SCSP1(x) (HW_SIM_PORT1_CNTL(x).B.SCSP1)

/*! @brief Format value for bitfield SIM_PORT1_CNTL_SCSP1. */
#define BF_SIM_PORT1_CNTL_SCSP1(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT1_CNTL_SCSP1) & BM_SIM_PORT1_CNTL_SCSP1)

/*! @brief Set the SCSP1 field to a new value. */
#define BW_SIM_PORT1_CNTL_SCSP1(x, v) (HW_SIM_PORT1_CNTL_WR(x, (HW_SIM_PORT1_CNTL_RD(x) & ~BM_SIM_PORT1_CNTL_SCSP1) | BF_SIM_PORT1_CNTL_SCSP1(v)))
/*@}*/

/*!
 * @name Register SIM_PORT1_CNTL, field VOLT3_1[6] (RW)
 *
 * External one wire interface for SIM Card port1. Used to configure the Port 1
 * transmit pin as bi-directional. This allows the Port 1 Receive pin to be
 * re-used as General Purpose I/O. This operation is restricted to bi-directional data
 * SIM cards only. This bit should not be changed while the receiver or
 * transmitter is enabled!
 *
 * Values:
 * - 0 - Port1 uses both rcv and xmt pins
 * - 1 - Port1 XMT pin bidirectional. Port1 RCV PIN unused
 */
/*@{*/
#define BP_SIM_PORT1_CNTL_VOLT3_1 (6U)     /*!< Bit position for SIM_PORT1_CNTL_VOLT3_1. */
#define BM_SIM_PORT1_CNTL_VOLT3_1 (0x00000040U) /*!< Bit mask for SIM_PORT1_CNTL_VOLT3_1. */
#define BS_SIM_PORT1_CNTL_VOLT3_1 (1U)     /*!< Bit field size in bits for SIM_PORT1_CNTL_VOLT3_1. */

/*! @brief Read current value of the SIM_PORT1_CNTL_VOLT3_1 field. */
#define BR_SIM_PORT1_CNTL_VOLT3_1(x) (HW_SIM_PORT1_CNTL(x).B.VOLT3_1)

/*! @brief Format value for bitfield SIM_PORT1_CNTL_VOLT3_1. */
#define BF_SIM_PORT1_CNTL_VOLT3_1(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT1_CNTL_VOLT3_1) & BM_SIM_PORT1_CNTL_VOLT3_1)

/*! @brief Set the VOLT3_1 field to a new value. */
#define BW_SIM_PORT1_CNTL_VOLT3_1(x, v) (HW_SIM_PORT1_CNTL_WR(x, (HW_SIM_PORT1_CNTL_RD(x) & ~BM_SIM_PORT1_CNTL_VOLT3_1) | BF_SIM_PORT1_CNTL_VOLT3_1(v)))
/*@}*/

/*!
 * @name Register SIM_PORT1_CNTL, field SFPD1[7] (WO)
 *
 * Auto Power Down port1. Writing a "1" to this location will start the auto
 * power down sequence for port 1. This bit will autoclear. A read of this bit will
 * give a "0".
 *
 * Values:
 * - 0 - No effect
 * - 1 - Start Auto Power down
 */
/*@{*/
#define BP_SIM_PORT1_CNTL_SFPD1 (7U)       /*!< Bit position for SIM_PORT1_CNTL_SFPD1. */
#define BM_SIM_PORT1_CNTL_SFPD1 (0x00000080U) /*!< Bit mask for SIM_PORT1_CNTL_SFPD1. */
#define BS_SIM_PORT1_CNTL_SFPD1 (1U)       /*!< Bit field size in bits for SIM_PORT1_CNTL_SFPD1. */

/*! @brief Format value for bitfield SIM_PORT1_CNTL_SFPD1. */
#define BF_SIM_PORT1_CNTL_SFPD1(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT1_CNTL_SFPD1) & BM_SIM_PORT1_CNTL_SFPD1)
/*@}*/

/*******************************************************************************
 * HW_SIM_SETUP - SIM Setup Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_SETUP - SIM Setup Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * See the figure below for illustration of valid bits in the SIM Setup Register
 * and the table below for description of the bit fields.
 */
typedef union _hw_sim_setup
{
    uint32_t U;
    struct _hw_sim_setup_bitfields
    {
        uint32_t AMODE : 1;            /*!< [0]  */
        uint32_t SPS : 1;              /*!< [1]  */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_sim_setup_t;

/*!
 * @name Constants and macros for entire SIM_SETUP register
 */
/*@{*/
#define HW_SIM_SETUP_ADDR(x)     ((uintptr_t)(x) + 0x4U)

#define HW_SIM_SETUP(x)          (*(__IO hw_sim_setup_t *) HW_SIM_SETUP_ADDR(x))
#define HW_SIM_SETUP_RD(x)       (HW_SIM_SETUP(x).U)
#define HW_SIM_SETUP_WR(x, v)    (HW_SIM_SETUP(x).U = (v))
#define HW_SIM_SETUP_SET(x, v)   (HW_SIM_SETUP_WR(x, HW_SIM_SETUP_RD(x) |  (v)))
#define HW_SIM_SETUP_CLR(x, v)   (HW_SIM_SETUP_WR(x, HW_SIM_SETUP_RD(x) & ~(v)))
#define HW_SIM_SETUP_TOG(x, v)   (HW_SIM_SETUP_WR(x, HW_SIM_SETUP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_SETUP bitfields
 */

/*!
 * @name Register SIM_SETUP, field AMODE[0] (RW)
 *
 * Alternate SIM Card Mode enable. Enables an alternate SIM module to control
 * SIM card Port 1. The SPS bit must be 0 to give the alternate SIM module control.
 *
 * Values:
 * - 0 - Alternate Port Disabled (default)
 * - 1 - Alternate Port Enabled
 */
/*@{*/
#define BP_SIM_SETUP_AMODE   (0U)          /*!< Bit position for SIM_SETUP_AMODE. */
#define BM_SIM_SETUP_AMODE   (0x00000001U) /*!< Bit mask for SIM_SETUP_AMODE. */
#define BS_SIM_SETUP_AMODE   (1U)          /*!< Bit field size in bits for SIM_SETUP_AMODE. */

/*! @brief Read current value of the SIM_SETUP_AMODE field. */
#define BR_SIM_SETUP_AMODE(x) (HW_SIM_SETUP(x).B.AMODE)

/*! @brief Format value for bitfield SIM_SETUP_AMODE. */
#define BF_SIM_SETUP_AMODE(v) ((uint32_t)((uint32_t)(v) << BP_SIM_SETUP_AMODE) & BM_SIM_SETUP_AMODE)

/*! @brief Set the AMODE field to a new value. */
#define BW_SIM_SETUP_AMODE(x, v) (HW_SIM_SETUP_WR(x, (HW_SIM_SETUP_RD(x) & ~BM_SIM_SETUP_AMODE) | BF_SIM_SETUP_AMODE(v)))
/*@}*/

/*!
 * @name Register SIM_SETUP, field SPS[1] (RW)
 *
 * SIM card Port Select. Controls which port the SIM interface uses. The AMODE
 * bit must be zero when the SPS bit is set to 1.
 *
 * Values:
 * - 0 - Port 0 Enabled (default)
 * - 1 - Port 1 Enabled
 */
/*@{*/
#define BP_SIM_SETUP_SPS     (1U)          /*!< Bit position for SIM_SETUP_SPS. */
#define BM_SIM_SETUP_SPS     (0x00000002U) /*!< Bit mask for SIM_SETUP_SPS. */
#define BS_SIM_SETUP_SPS     (1U)          /*!< Bit field size in bits for SIM_SETUP_SPS. */

/*! @brief Read current value of the SIM_SETUP_SPS field. */
#define BR_SIM_SETUP_SPS(x)  (HW_SIM_SETUP(x).B.SPS)

/*! @brief Format value for bitfield SIM_SETUP_SPS. */
#define BF_SIM_SETUP_SPS(v)  ((uint32_t)((uint32_t)(v) << BP_SIM_SETUP_SPS) & BM_SIM_SETUP_SPS)

/*! @brief Set the SPS field to a new value. */
#define BW_SIM_SETUP_SPS(x, v) (HW_SIM_SETUP_WR(x, (HW_SIM_SETUP_RD(x) & ~BM_SIM_SETUP_SPS) | BF_SIM_SETUP_SPS(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_PORT1_DETECT - SIM Port 1 Detect Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_PORT1_DETECT - SIM Port 1 Detect Register (RW)
 *
 * Reset value: 0x00000001U
 *
 * See the figure below for illustration of valid bits in the SIM Port1 Detect
 * Register and the table below for description of the bit fields. Summary: spds1
 * determines which edge transition of the SIMPD1 pin is used for SIM card
 * presence detection. Presence detection can be used to determine if the card has been
 * inserted or removed. The occurrence of the SIMPD1 edge specified by spds1
 * will cause the following: sdi1 to be set; if the sdim1 mask is clear, an
 * interrupt on SIMIRQ_N; and if sapd1 in the PORT1_CNTL register is set, an auto power
 * down sequence to begin. If SIM card insertion is expected, sapd1 can be set low
 * to avoid the auto power down sequence. There is no auto power up sequence.
 * The bit spdp1 can be used to determine the current state of the SIMPD1 pin.
 */
typedef union _hw_sim_port1_detect
{
    uint32_t U;
    struct _hw_sim_port1_detect_bitfields
    {
        uint32_t SDIM1 : 1;            /*!< [0]  */
        uint32_t SDI1 : 1;             /*!< [1]  */
        uint32_t SPDP1 : 1;            /*!< [2]  */
        uint32_t SPDS1 : 1;            /*!< [3]  */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_sim_port1_detect_t;

/*!
 * @name Constants and macros for entire SIM_PORT1_DETECT register
 */
/*@{*/
#define HW_SIM_PORT1_DETECT_ADDR(x) ((uintptr_t)(x) + 0x8U)

#define HW_SIM_PORT1_DETECT(x)   (*(__IO hw_sim_port1_detect_t *) HW_SIM_PORT1_DETECT_ADDR(x))
#define HW_SIM_PORT1_DETECT_RD(x) (HW_SIM_PORT1_DETECT(x).U)
#define HW_SIM_PORT1_DETECT_WR(x, v) (HW_SIM_PORT1_DETECT(x).U = (v))
#define HW_SIM_PORT1_DETECT_SET(x, v) (HW_SIM_PORT1_DETECT_WR(x, HW_SIM_PORT1_DETECT_RD(x) |  (v)))
#define HW_SIM_PORT1_DETECT_CLR(x, v) (HW_SIM_PORT1_DETECT_WR(x, HW_SIM_PORT1_DETECT_RD(x) & ~(v)))
#define HW_SIM_PORT1_DETECT_TOG(x, v) (HW_SIM_PORT1_DETECT_WR(x, HW_SIM_PORT1_DETECT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_PORT1_DETECT bitfields
 */

/*!
 * @name Register SIM_PORT1_DETECT, field SDIM1[0] (RW)
 *
 * SIM Detect Interrupt Mask Port 1. Interrupt mask for the sdi1 interrupt flag.
 *
 * Values:
 * - 0 - SDI1 enabled
 * - 1 - SDI1 masked (default)
 */
/*@{*/
#define BP_SIM_PORT1_DETECT_SDIM1 (0U)     /*!< Bit position for SIM_PORT1_DETECT_SDIM1. */
#define BM_SIM_PORT1_DETECT_SDIM1 (0x00000001U) /*!< Bit mask for SIM_PORT1_DETECT_SDIM1. */
#define BS_SIM_PORT1_DETECT_SDIM1 (1U)     /*!< Bit field size in bits for SIM_PORT1_DETECT_SDIM1. */

/*! @brief Read current value of the SIM_PORT1_DETECT_SDIM1 field. */
#define BR_SIM_PORT1_DETECT_SDIM1(x) (HW_SIM_PORT1_DETECT(x).B.SDIM1)

/*! @brief Format value for bitfield SIM_PORT1_DETECT_SDIM1. */
#define BF_SIM_PORT1_DETECT_SDIM1(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT1_DETECT_SDIM1) & BM_SIM_PORT1_DETECT_SDIM1)

/*! @brief Set the SDIM1 field to a new value. */
#define BW_SIM_PORT1_DETECT_SDIM1(x, v) (HW_SIM_PORT1_DETECT_WR(x, (HW_SIM_PORT1_DETECT_RD(x) & ~(BM_SIM_PORT1_DETECT_SDIM1 | BM_SIM_PORT1_DETECT_SDI1)) | BF_SIM_PORT1_DETECT_SDIM1(v)))
/*@}*/

/*!
 * @name Register SIM_PORT1_DETECT, field SDI1[1] (W1C)
 *
 * SIM Detect Interrupt Flag Port 1. Status flag to indicate the insertion or
 * removal of a SIM card has been detected on port 1. Can create an interrupt to
 * the MCU if SDIM1 is low. Write a "1" to this bit to clear.
 *
 * Values:
 * - 0 - No insertion or removal of SIM card detected on Port 1(default)
 * - 1 - Insertion or removal of SIM card detected on Port 1
 */
/*@{*/
#define BP_SIM_PORT1_DETECT_SDI1 (1U)      /*!< Bit position for SIM_PORT1_DETECT_SDI1. */
#define BM_SIM_PORT1_DETECT_SDI1 (0x00000002U) /*!< Bit mask for SIM_PORT1_DETECT_SDI1. */
#define BS_SIM_PORT1_DETECT_SDI1 (1U)      /*!< Bit field size in bits for SIM_PORT1_DETECT_SDI1. */

/*! @brief Read current value of the SIM_PORT1_DETECT_SDI1 field. */
#define BR_SIM_PORT1_DETECT_SDI1(x) (HW_SIM_PORT1_DETECT(x).B.SDI1)

/*! @brief Format value for bitfield SIM_PORT1_DETECT_SDI1. */
#define BF_SIM_PORT1_DETECT_SDI1(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT1_DETECT_SDI1) & BM_SIM_PORT1_DETECT_SDI1)

/*! @brief Set the SDI1 field to a new value. */
#define BW_SIM_PORT1_DETECT_SDI1(x, v) (HW_SIM_PORT1_DETECT_WR(x, (HW_SIM_PORT1_DETECT_RD(x) & ~BM_SIM_PORT1_DETECT_SDI1) | BF_SIM_PORT1_DETECT_SDI1(v)))
/*@}*/

/*!
 * @name Register SIM_PORT1_DETECT, field SPDP1[2] (RO)
 *
 * SIMPD1 input pin status. This bit reflects the state of the SIMPD1 pin. It is
 * not a latched register bit, but instead a synchronized version of the state
 * of the SIMPD1 pin itself.
 *
 * Values:
 * - 0 - SIMPD1 pin is logic low
 * - 1 - SIMPD1 pin is logic high
 */
/*@{*/
#define BP_SIM_PORT1_DETECT_SPDP1 (2U)     /*!< Bit position for SIM_PORT1_DETECT_SPDP1. */
#define BM_SIM_PORT1_DETECT_SPDP1 (0x00000004U) /*!< Bit mask for SIM_PORT1_DETECT_SPDP1. */
#define BS_SIM_PORT1_DETECT_SPDP1 (1U)     /*!< Bit field size in bits for SIM_PORT1_DETECT_SPDP1. */

/*! @brief Read current value of the SIM_PORT1_DETECT_SPDP1 field. */
#define BR_SIM_PORT1_DETECT_SPDP1(x) (HW_SIM_PORT1_DETECT(x).B.SPDP1)
/*@}*/

/*!
 * @name Register SIM_PORT1_DETECT, field SPDS1[3] (RW)
 *
 * SIM Presence Detect Select Port 1. Controls which edge of the SIMPD1 pin is
 * used to detect the presence of the SIM card.
 *
 * Values:
 * - 0 - Falling edge of SIMPD1 Input (default)
 * - 1 - Rising edge of SIMPD1 Input
 */
/*@{*/
#define BP_SIM_PORT1_DETECT_SPDS1 (3U)     /*!< Bit position for SIM_PORT1_DETECT_SPDS1. */
#define BM_SIM_PORT1_DETECT_SPDS1 (0x00000008U) /*!< Bit mask for SIM_PORT1_DETECT_SPDS1. */
#define BS_SIM_PORT1_DETECT_SPDS1 (1U)     /*!< Bit field size in bits for SIM_PORT1_DETECT_SPDS1. */

/*! @brief Read current value of the SIM_PORT1_DETECT_SPDS1 field. */
#define BR_SIM_PORT1_DETECT_SPDS1(x) (HW_SIM_PORT1_DETECT(x).B.SPDS1)

/*! @brief Format value for bitfield SIM_PORT1_DETECT_SPDS1. */
#define BF_SIM_PORT1_DETECT_SPDS1(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT1_DETECT_SPDS1) & BM_SIM_PORT1_DETECT_SPDS1)

/*! @brief Set the SPDS1 field to a new value. */
#define BW_SIM_PORT1_DETECT_SPDS1(x, v) (HW_SIM_PORT1_DETECT_WR(x, (HW_SIM_PORT1_DETECT_RD(x) & ~(BM_SIM_PORT1_DETECT_SPDS1 | BM_SIM_PORT1_DETECT_SDI1)) | BF_SIM_PORT1_DETECT_SPDS1(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_XMT_BUF - SIM Transmit Buffer Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_XMT_BUF - SIM Transmit Buffer Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * See the figure below for illustration of valid bits in the SIM Transmit
 * Buffer Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_xmt_buf
{
    uint32_t U;
    struct _hw_sim_xmt_buf_bitfields
    {
        uint32_t XMT : 8;              /*!< [7:0]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_sim_xmt_buf_t;

/*!
 * @name Constants and macros for entire SIM_XMT_BUF register
 */
/*@{*/
#define HW_SIM_XMT_BUF_ADDR(x)   ((uintptr_t)(x) + 0xCU)

#define HW_SIM_XMT_BUF(x)        (*(__IO hw_sim_xmt_buf_t *) HW_SIM_XMT_BUF_ADDR(x))
#define HW_SIM_XMT_BUF_RD(x)     (HW_SIM_XMT_BUF(x).U)
#define HW_SIM_XMT_BUF_WR(x, v)  (HW_SIM_XMT_BUF(x).U = (v))
#define HW_SIM_XMT_BUF_SET(x, v) (HW_SIM_XMT_BUF_WR(x, HW_SIM_XMT_BUF_RD(x) |  (v)))
#define HW_SIM_XMT_BUF_CLR(x, v) (HW_SIM_XMT_BUF_WR(x, HW_SIM_XMT_BUF_RD(x) & ~(v)))
#define HW_SIM_XMT_BUF_TOG(x, v) (HW_SIM_XMT_BUF_WR(x, HW_SIM_XMT_BUF_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_XMT_BUF bitfields
 */

/*!
 * @name Register SIM_XMT_BUF, field XMT[7:0] (RW)
 *
 * Transmit Buffer. Write to the next available location in the transmit buffer.
 */
/*@{*/
#define BP_SIM_XMT_BUF_XMT   (0U)          /*!< Bit position for SIM_XMT_BUF_XMT. */
#define BM_SIM_XMT_BUF_XMT   (0x000000FFU) /*!< Bit mask for SIM_XMT_BUF_XMT. */
#define BS_SIM_XMT_BUF_XMT   (8U)          /*!< Bit field size in bits for SIM_XMT_BUF_XMT. */

/*! @brief Read current value of the SIM_XMT_BUF_XMT field. */
#define BR_SIM_XMT_BUF_XMT(x) (HW_SIM_XMT_BUF(x).B.XMT)

/*! @brief Format value for bitfield SIM_XMT_BUF_XMT. */
#define BF_SIM_XMT_BUF_XMT(v) ((uint32_t)((uint32_t)(v) << BP_SIM_XMT_BUF_XMT) & BM_SIM_XMT_BUF_XMT)

/*! @brief Set the XMT field to a new value. */
#define BW_SIM_XMT_BUF_XMT(x, v) (HW_SIM_XMT_BUF_WR(x, (HW_SIM_XMT_BUF_RD(x) & ~BM_SIM_XMT_BUF_XMT) | BF_SIM_XMT_BUF_XMT(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_RCV_BUF - SIM Receive Buffer Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_RCV_BUF - SIM Receive Buffer Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * See the figure below for illustration of valid bits in the SIM Receive Buffer
 * Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_rcv_buf
{
    uint32_t U;
    struct _hw_sim_rcv_buf_bitfields
    {
        uint32_t RCV : 8;              /*!< [7:0]  */
        uint32_t PE : 1;               /*!< [8]  */
        uint32_t FE : 1;               /*!< [9]  */
        uint32_t CWT : 1;              /*!< [10]  */
        uint32_t RESERVED0 : 21;       /*!< [31:11]  */
    } B;
} hw_sim_rcv_buf_t;

/*!
 * @name Constants and macros for entire SIM_RCV_BUF register
 */
/*@{*/
#define HW_SIM_RCV_BUF_ADDR(x)   ((uintptr_t)(x) + 0x10U)

#define HW_SIM_RCV_BUF(x)        (*(__I hw_sim_rcv_buf_t *) HW_SIM_RCV_BUF_ADDR(x))
#define HW_SIM_RCV_BUF_RD(x)     (HW_SIM_RCV_BUF(x).U)
/*@}*/

/*
 * Constants & macros for individual SIM_RCV_BUF bitfields
 */

/*!
 * @name Register SIM_RCV_BUF, field RCV[7:0] (RO)
 *
 * Receive buffer. Read from the next location in the receive buffer.
 */
/*@{*/
#define BP_SIM_RCV_BUF_RCV   (0U)          /*!< Bit position for SIM_RCV_BUF_RCV. */
#define BM_SIM_RCV_BUF_RCV   (0x000000FFU) /*!< Bit mask for SIM_RCV_BUF_RCV. */
#define BS_SIM_RCV_BUF_RCV   (8U)          /*!< Bit field size in bits for SIM_RCV_BUF_RCV. */

/*! @brief Read current value of the SIM_RCV_BUF_RCV field. */
#define BR_SIM_RCV_BUF_RCV(x) (HW_SIM_RCV_BUF(x).B.RCV)
/*@}*/

/*!
 * @name Register SIM_RCV_BUF, field PE[8] (RO)
 *
 * Parity Error flag. The PE flag indicates whether a parity error was detected
 * during the reception of the corresponding byte read in the RCV field. The PE
 * flag cannot create an interrupt. It need not be cleared since it will be
 * overwritten by the next byte received into that location of the FIFO. A parity error
 * can create a NACK pulse.
 *
 * Values:
 * - 0 - Byte contains no parity error (default)
 * - 1 - Byte contains a parity error
 */
/*@{*/
#define BP_SIM_RCV_BUF_PE    (8U)          /*!< Bit position for SIM_RCV_BUF_PE. */
#define BM_SIM_RCV_BUF_PE    (0x00000100U) /*!< Bit mask for SIM_RCV_BUF_PE. */
#define BS_SIM_RCV_BUF_PE    (1U)          /*!< Bit field size in bits for SIM_RCV_BUF_PE. */

/*! @brief Read current value of the SIM_RCV_BUF_PE field. */
#define BR_SIM_RCV_BUF_PE(x) (HW_SIM_RCV_BUF(x).B.PE)
/*@}*/

/*!
 * @name Register SIM_RCV_BUF, field FE[9] (RO)
 *
 * Frame Error flag. The FE flag indicates whether a frame error was detected
 * during the reception of the corresponding byte read in the RCV field. The FE
 * flag cannot create an interrupt. It need not be cleared since it will be
 * overwritten by the next byte received into that location of the FIFO.
 *
 * Values:
 * - 0 - Byte contains no framing error (default)
 * - 1 - Byte contains a framing error
 */
/*@{*/
#define BP_SIM_RCV_BUF_FE    (9U)          /*!< Bit position for SIM_RCV_BUF_FE. */
#define BM_SIM_RCV_BUF_FE    (0x00000200U) /*!< Bit mask for SIM_RCV_BUF_FE. */
#define BS_SIM_RCV_BUF_FE    (1U)          /*!< Bit field size in bits for SIM_RCV_BUF_FE. */

/*! @brief Read current value of the SIM_RCV_BUF_FE field. */
#define BR_SIM_RCV_BUF_FE(x) (HW_SIM_RCV_BUF(x).B.FE)
/*@}*/

/*!
 * @name Register SIM_RCV_BUF, field CWT[10] (RO)
 *
 * CWT flag. The CWT indicates that this byte was late. It is not necessary to
 * clear the byte since it is overwritten by the next byte received into that
 * location of the FIFO.
 *
 * Values:
 * - 0 - Byte was on time
 * - 1 - Byte was late
 */
/*@{*/
#define BP_SIM_RCV_BUF_CWT   (10U)         /*!< Bit position for SIM_RCV_BUF_CWT. */
#define BM_SIM_RCV_BUF_CWT   (0x00000400U) /*!< Bit mask for SIM_RCV_BUF_CWT. */
#define BS_SIM_RCV_BUF_CWT   (1U)          /*!< Bit field size in bits for SIM_RCV_BUF_CWT. */

/*! @brief Read current value of the SIM_RCV_BUF_CWT field. */
#define BR_SIM_RCV_BUF_CWT(x) (HW_SIM_RCV_BUF(x).B.CWT)
/*@}*/

/*******************************************************************************
 * HW_SIM_PORT0_CNTL - SIM Port0 Control Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_PORT0_CNTL - SIM Port0 Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * See the figure below for illustration of valid bits in the SIM Port0 Control
 * Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_port0_cntl
{
    uint32_t U;
    struct _hw_sim_port0_cntl_bitfields
    {
        uint32_t SAPD0 : 1;            /*!< [0]  */
        uint32_t SVEN0 : 1;            /*!< [1]  */
        uint32_t STEN0 : 1;            /*!< [2]  */
        uint32_t SRST0 : 1;            /*!< [3]  */
        uint32_t SCEN0 : 1;            /*!< [4]  */
        uint32_t SCSP0 : 1;            /*!< [5]  */
        uint32_t VOLT3_0 : 1;          /*!< [6]  */
        uint32_t SFPD0 : 1;            /*!< [7]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_sim_port0_cntl_t;

/*!
 * @name Constants and macros for entire SIM_PORT0_CNTL register
 */
/*@{*/
#define HW_SIM_PORT0_CNTL_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_SIM_PORT0_CNTL(x)     (*(__IO hw_sim_port0_cntl_t *) HW_SIM_PORT0_CNTL_ADDR(x))
#define HW_SIM_PORT0_CNTL_RD(x)  (HW_SIM_PORT0_CNTL(x).U)
#define HW_SIM_PORT0_CNTL_WR(x, v) (HW_SIM_PORT0_CNTL(x).U = (v))
#define HW_SIM_PORT0_CNTL_SET(x, v) (HW_SIM_PORT0_CNTL_WR(x, HW_SIM_PORT0_CNTL_RD(x) |  (v)))
#define HW_SIM_PORT0_CNTL_CLR(x, v) (HW_SIM_PORT0_CNTL_WR(x, HW_SIM_PORT0_CNTL_RD(x) & ~(v)))
#define HW_SIM_PORT0_CNTL_TOG(x, v) (HW_SIM_PORT0_CNTL_WR(x, HW_SIM_PORT0_CNTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_PORT0_CNTL bitfields
 */

/*!
 * @name Register SIM_PORT0_CNTL, field SAPD0[0] (RW)
 *
 * SIM card Auto Power Down Port 0. Used to enable/disable the auto power down
 * function for port 0. It will be forced low at the end of the auto power down
 * sequence.
 *
 * Values:
 * - 0 - Auto power down Port 0 disabled (default)
 * - 1 - Auto power down Port 0 enabled
 */
/*@{*/
#define BP_SIM_PORT0_CNTL_SAPD0 (0U)       /*!< Bit position for SIM_PORT0_CNTL_SAPD0. */
#define BM_SIM_PORT0_CNTL_SAPD0 (0x00000001U) /*!< Bit mask for SIM_PORT0_CNTL_SAPD0. */
#define BS_SIM_PORT0_CNTL_SAPD0 (1U)       /*!< Bit field size in bits for SIM_PORT0_CNTL_SAPD0. */

/*! @brief Read current value of the SIM_PORT0_CNTL_SAPD0 field. */
#define BR_SIM_PORT0_CNTL_SAPD0(x) (HW_SIM_PORT0_CNTL(x).B.SAPD0)

/*! @brief Format value for bitfield SIM_PORT0_CNTL_SAPD0. */
#define BF_SIM_PORT0_CNTL_SAPD0(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT0_CNTL_SAPD0) & BM_SIM_PORT0_CNTL_SAPD0)

/*! @brief Set the SAPD0 field to a new value. */
#define BW_SIM_PORT0_CNTL_SAPD0(x, v) (HW_SIM_PORT0_CNTL_WR(x, (HW_SIM_PORT0_CNTL_RD(x) & ~BM_SIM_PORT0_CNTL_SAPD0) | BF_SIM_PORT0_CNTL_SAPD0(v)))
/*@}*/

/*!
 * @name Register SIM_PORT0_CNTL, field SVEN0[1] (RW)
 *
 * SIM card VCC Enable Port 0. Used to control the state of the SVEN0 pin on SIM
 * card port 0. The SVEN0 pin controls the SIM card VCC enable in the power
 * management chip. It can be forced low by hardware during the auto power down
 * sequence.
 *
 * Values:
 * - 0 - SIM card Voltage Port 0 disabled (default)
 * - 1 - SIM card Voltage Port 0 enabled
 */
/*@{*/
#define BP_SIM_PORT0_CNTL_SVEN0 (1U)       /*!< Bit position for SIM_PORT0_CNTL_SVEN0. */
#define BM_SIM_PORT0_CNTL_SVEN0 (0x00000002U) /*!< Bit mask for SIM_PORT0_CNTL_SVEN0. */
#define BS_SIM_PORT0_CNTL_SVEN0 (1U)       /*!< Bit field size in bits for SIM_PORT0_CNTL_SVEN0. */

/*! @brief Read current value of the SIM_PORT0_CNTL_SVEN0 field. */
#define BR_SIM_PORT0_CNTL_SVEN0(x) (HW_SIM_PORT0_CNTL(x).B.SVEN0)

/*! @brief Format value for bitfield SIM_PORT0_CNTL_SVEN0. */
#define BF_SIM_PORT0_CNTL_SVEN0(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT0_CNTL_SVEN0) & BM_SIM_PORT0_CNTL_SVEN0)

/*! @brief Set the SVEN0 field to a new value. */
#define BW_SIM_PORT0_CNTL_SVEN0(x, v) (HW_SIM_PORT0_CNTL_WR(x, (HW_SIM_PORT0_CNTL_RD(x) & ~BM_SIM_PORT0_CNTL_SVEN0) | BF_SIM_PORT0_CNTL_SVEN0(v)))
/*@}*/

/*!
 * @name Register SIM_PORT0_CNTL, field STEN0[2] (RW)
 *
 * SIM card Transmit Enable Port 0. Used to enable/disable the XMT data to the
 * SIM card. It can be forced low by hardware during the auto power down sequence.
 *
 * Values:
 * - 0 - Port0 Transmit Data is forced to zero (default)
 * - 1 - Port 0 Transmit Data controlled by SIM module
 */
/*@{*/
#define BP_SIM_PORT0_CNTL_STEN0 (2U)       /*!< Bit position for SIM_PORT0_CNTL_STEN0. */
#define BM_SIM_PORT0_CNTL_STEN0 (0x00000004U) /*!< Bit mask for SIM_PORT0_CNTL_STEN0. */
#define BS_SIM_PORT0_CNTL_STEN0 (1U)       /*!< Bit field size in bits for SIM_PORT0_CNTL_STEN0. */

/*! @brief Read current value of the SIM_PORT0_CNTL_STEN0 field. */
#define BR_SIM_PORT0_CNTL_STEN0(x) (HW_SIM_PORT0_CNTL(x).B.STEN0)

/*! @brief Format value for bitfield SIM_PORT0_CNTL_STEN0. */
#define BF_SIM_PORT0_CNTL_STEN0(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT0_CNTL_STEN0) & BM_SIM_PORT0_CNTL_STEN0)

/*! @brief Set the STEN0 field to a new value. */
#define BW_SIM_PORT0_CNTL_STEN0(x, v) (HW_SIM_PORT0_CNTL_WR(x, (HW_SIM_PORT0_CNTL_RD(x) & ~BM_SIM_PORT0_CNTL_STEN0) | BF_SIM_PORT0_CNTL_STEN0(v)))
/*@}*/

/*!
 * @name Register SIM_PORT0_CNTL, field SRST0[3] (RW)
 *
 * SIM card Reset. Used to control state of reset line to the SIM card. It can
 * be forced low by hardware during the auto power down sequence. SIM card reset
 * signals are active low.
 *
 * Values:
 * - 0 - SIM Card reset Port0 inactive (default)
 * - 1 - SIM Card reset Port0 active
 */
/*@{*/
#define BP_SIM_PORT0_CNTL_SRST0 (3U)       /*!< Bit position for SIM_PORT0_CNTL_SRST0. */
#define BM_SIM_PORT0_CNTL_SRST0 (0x00000008U) /*!< Bit mask for SIM_PORT0_CNTL_SRST0. */
#define BS_SIM_PORT0_CNTL_SRST0 (1U)       /*!< Bit field size in bits for SIM_PORT0_CNTL_SRST0. */

/*! @brief Read current value of the SIM_PORT0_CNTL_SRST0 field. */
#define BR_SIM_PORT0_CNTL_SRST0(x) (HW_SIM_PORT0_CNTL(x).B.SRST0)

/*! @brief Format value for bitfield SIM_PORT0_CNTL_SRST0. */
#define BF_SIM_PORT0_CNTL_SRST0(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT0_CNTL_SRST0) & BM_SIM_PORT0_CNTL_SRST0)

/*! @brief Set the SRST0 field to a new value. */
#define BW_SIM_PORT0_CNTL_SRST0(x, v) (HW_SIM_PORT0_CNTL_WR(x, (HW_SIM_PORT0_CNTL_RD(x) & ~BM_SIM_PORT0_CNTL_SRST0) | BF_SIM_PORT0_CNTL_SRST0(v)))
/*@}*/

/*!
 * @name Register SIM_PORT0_CNTL, field SCEN0[4] (RW)
 *
 * SIM card Clock Enable Port 0. Used to enable/disable the clock to the SIM
 * card. It can be forced low by hardware during the auto power down sequence.
 *
 * Values:
 * - 0 - SIM Card Clock Disabled Port 0
 * - 1 - SIM Card Clock Enabled Port 0
 */
/*@{*/
#define BP_SIM_PORT0_CNTL_SCEN0 (4U)       /*!< Bit position for SIM_PORT0_CNTL_SCEN0. */
#define BM_SIM_PORT0_CNTL_SCEN0 (0x00000010U) /*!< Bit mask for SIM_PORT0_CNTL_SCEN0. */
#define BS_SIM_PORT0_CNTL_SCEN0 (1U)       /*!< Bit field size in bits for SIM_PORT0_CNTL_SCEN0. */

/*! @brief Read current value of the SIM_PORT0_CNTL_SCEN0 field. */
#define BR_SIM_PORT0_CNTL_SCEN0(x) (HW_SIM_PORT0_CNTL(x).B.SCEN0)

/*! @brief Format value for bitfield SIM_PORT0_CNTL_SCEN0. */
#define BF_SIM_PORT0_CNTL_SCEN0(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT0_CNTL_SCEN0) & BM_SIM_PORT0_CNTL_SCEN0)

/*! @brief Set the SCEN0 field to a new value. */
#define BW_SIM_PORT0_CNTL_SCEN0(x, v) (HW_SIM_PORT0_CNTL_WR(x, (HW_SIM_PORT0_CNTL_RD(x) & ~BM_SIM_PORT0_CNTL_SCEN0) | BF_SIM_PORT0_CNTL_SCEN0(v)))
/*@}*/

/*!
 * @name Register SIM_PORT0_CNTL, field SCSP0[5] (RW)
 *
 * SIM Card Clock Stop Polarity port0. Used to control the polarity of the idle
 * SIM clock when the clock is disabled by SCEN0. It will be forced low by
 * hardware during the auto power down sequence. This forces the clock to be a logic 0
 * when stopped by auto power down as required by ISO 7816 spec.
 *
 * Values:
 * - 0 - Clock is logic 0 when stopped by scen0
 * - 1 - Clock is logic 1 when stopped by scen0
 */
/*@{*/
#define BP_SIM_PORT0_CNTL_SCSP0 (5U)       /*!< Bit position for SIM_PORT0_CNTL_SCSP0. */
#define BM_SIM_PORT0_CNTL_SCSP0 (0x00000020U) /*!< Bit mask for SIM_PORT0_CNTL_SCSP0. */
#define BS_SIM_PORT0_CNTL_SCSP0 (1U)       /*!< Bit field size in bits for SIM_PORT0_CNTL_SCSP0. */

/*! @brief Read current value of the SIM_PORT0_CNTL_SCSP0 field. */
#define BR_SIM_PORT0_CNTL_SCSP0(x) (HW_SIM_PORT0_CNTL(x).B.SCSP0)

/*! @brief Format value for bitfield SIM_PORT0_CNTL_SCSP0. */
#define BF_SIM_PORT0_CNTL_SCSP0(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT0_CNTL_SCSP0) & BM_SIM_PORT0_CNTL_SCSP0)

/*! @brief Set the SCSP0 field to a new value. */
#define BW_SIM_PORT0_CNTL_SCSP0(x, v) (HW_SIM_PORT0_CNTL_WR(x, (HW_SIM_PORT0_CNTL_RD(x) & ~BM_SIM_PORT0_CNTL_SCSP0) | BF_SIM_PORT0_CNTL_SCSP0(v)))
/*@}*/

/*!
 * @name Register SIM_PORT0_CNTL, field VOLT3_0[6] (RW)
 *
 * External one wire interface for SIM Card port0. Used to configure the Port 0
 * transmit pin as bi-directional. Only bi-directional data SIM cards are
 * supported. Hence user should program this bit to 1. This bit should not be changed
 * while the receiver or transmitter is enabled!
 *
 * Values:
 * - 1 - Port0 XMT pin bidirectional. Port0 rcv pin unused
 */
/*@{*/
#define BP_SIM_PORT0_CNTL_VOLT3_0 (6U)     /*!< Bit position for SIM_PORT0_CNTL_VOLT3_0. */
#define BM_SIM_PORT0_CNTL_VOLT3_0 (0x00000040U) /*!< Bit mask for SIM_PORT0_CNTL_VOLT3_0. */
#define BS_SIM_PORT0_CNTL_VOLT3_0 (1U)     /*!< Bit field size in bits for SIM_PORT0_CNTL_VOLT3_0. */

/*! @brief Read current value of the SIM_PORT0_CNTL_VOLT3_0 field. */
#define BR_SIM_PORT0_CNTL_VOLT3_0(x) (HW_SIM_PORT0_CNTL(x).B.VOLT3_0)

/*! @brief Format value for bitfield SIM_PORT0_CNTL_VOLT3_0. */
#define BF_SIM_PORT0_CNTL_VOLT3_0(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT0_CNTL_VOLT3_0) & BM_SIM_PORT0_CNTL_VOLT3_0)

/*! @brief Set the VOLT3_0 field to a new value. */
#define BW_SIM_PORT0_CNTL_VOLT3_0(x, v) (HW_SIM_PORT0_CNTL_WR(x, (HW_SIM_PORT0_CNTL_RD(x) & ~BM_SIM_PORT0_CNTL_VOLT3_0) | BF_SIM_PORT0_CNTL_VOLT3_0(v)))
/*@}*/

/*!
 * @name Register SIM_PORT0_CNTL, field SFPD0[7] (WO)
 *
 * Auto Power Down port0. Writing a "1" to this location will start the auto
 * power down sequence for port 0. This bit will autoclear.A read of this bit will
 * give a "0".
 *
 * Values:
 * - 0 - No effect
 * - 1 - Start Auto Power down
 */
/*@{*/
#define BP_SIM_PORT0_CNTL_SFPD0 (7U)       /*!< Bit position for SIM_PORT0_CNTL_SFPD0. */
#define BM_SIM_PORT0_CNTL_SFPD0 (0x00000080U) /*!< Bit mask for SIM_PORT0_CNTL_SFPD0. */
#define BS_SIM_PORT0_CNTL_SFPD0 (1U)       /*!< Bit field size in bits for SIM_PORT0_CNTL_SFPD0. */

/*! @brief Format value for bitfield SIM_PORT0_CNTL_SFPD0. */
#define BF_SIM_PORT0_CNTL_SFPD0(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT0_CNTL_SFPD0) & BM_SIM_PORT0_CNTL_SFPD0)
/*@}*/

/*******************************************************************************
 * HW_SIM_CNTL - SIM Control Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_CNTL - SIM Control Register (RW)
 *
 * Reset value: 0x00000006U
 *
 * See the figure below for illustration of valid bits in the SIM Control
 * Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_cntl
{
    uint32_t U;
    struct _hw_sim_cntl_bitfields
    {
        uint32_t RESERVED0 : 1;        /*!< [0]  */
        uint32_t ICM : 1;              /*!< [1]  */
        uint32_t ANACK : 1;            /*!< [2]  */
        uint32_t ONACK : 1;            /*!< [3]  */
        uint32_t RESERVED1 : 1;        /*!< [4]  */
        uint32_t Sample12 : 1;         /*!< [5]  */
        uint32_t baud_sel : 3;         /*!< [8:6]  */
        uint32_t gpcnt_clk_sel : 2;    /*!< [10:9]  */
        uint32_t CWTEN : 1;            /*!< [11]  */
        uint32_t LRCEN : 1;            /*!< [12]  */
        uint32_t CRCEN : 1;            /*!< [13]  */
        uint32_t xmt_crc_lrc : 1;      /*!< [14]  */
        uint32_t BWTEN : 1;            /*!< [15]  */
        uint32_t RESERVED2 : 16;       /*!< [31:16]  */
    } B;
} hw_sim_cntl_t;

/*!
 * @name Constants and macros for entire SIM_CNTL register
 */
/*@{*/
#define HW_SIM_CNTL_ADDR(x)      ((uintptr_t)(x) + 0x18U)

#define HW_SIM_CNTL(x)           (*(__IO hw_sim_cntl_t *) HW_SIM_CNTL_ADDR(x))
#define HW_SIM_CNTL_RD(x)        (HW_SIM_CNTL(x).U)
#define HW_SIM_CNTL_WR(x, v)     (HW_SIM_CNTL(x).U = (v))
#define HW_SIM_CNTL_SET(x, v)    (HW_SIM_CNTL_WR(x, HW_SIM_CNTL_RD(x) |  (v)))
#define HW_SIM_CNTL_CLR(x, v)    (HW_SIM_CNTL_WR(x, HW_SIM_CNTL_RD(x) & ~(v)))
#define HW_SIM_CNTL_TOG(x, v)    (HW_SIM_CNTL_WR(x, HW_SIM_CNTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_CNTL bitfields
 */

/*!
 * @name Register SIM_CNTL, field ICM[1] (RW)
 *
 * Initial Character Mode. Enables initial character mode. Will be automatically
 * cleared by hardware once a valid initial character is received.
 *
 * Values:
 * - 0 - Initial Character Mode disabled
 * - 1 - Initial Character Mode enabled (default)
 */
/*@{*/
#define BP_SIM_CNTL_ICM      (1U)          /*!< Bit position for SIM_CNTL_ICM. */
#define BM_SIM_CNTL_ICM      (0x00000002U) /*!< Bit mask for SIM_CNTL_ICM. */
#define BS_SIM_CNTL_ICM      (1U)          /*!< Bit field size in bits for SIM_CNTL_ICM. */

/*! @brief Read current value of the SIM_CNTL_ICM field. */
#define BR_SIM_CNTL_ICM(x)   (HW_SIM_CNTL(x).B.ICM)

/*! @brief Format value for bitfield SIM_CNTL_ICM. */
#define BF_SIM_CNTL_ICM(v)   ((uint32_t)((uint32_t)(v) << BP_SIM_CNTL_ICM) & BM_SIM_CNTL_ICM)

/*! @brief Set the ICM field to a new value. */
#define BW_SIM_CNTL_ICM(x, v) (HW_SIM_CNTL_WR(x, (HW_SIM_CNTL_RD(x) & ~BM_SIM_CNTL_ICM) | BF_SIM_CNTL_ICM(v)))
/*@}*/

/*!
 * @name Register SIM_CNTL, field ANACK[2] (RW)
 *
 * Automatic NACK Enable. Enables nack generation for parity errors or invalid
 * initial characters when in ICM mode.
 *
 * Values:
 * - 0 - NACK generation on errors disabled
 * - 1 - NACK generation on errors enabled (default)
 */
/*@{*/
#define BP_SIM_CNTL_ANACK    (2U)          /*!< Bit position for SIM_CNTL_ANACK. */
#define BM_SIM_CNTL_ANACK    (0x00000004U) /*!< Bit mask for SIM_CNTL_ANACK. */
#define BS_SIM_CNTL_ANACK    (1U)          /*!< Bit field size in bits for SIM_CNTL_ANACK. */

/*! @brief Read current value of the SIM_CNTL_ANACK field. */
#define BR_SIM_CNTL_ANACK(x) (HW_SIM_CNTL(x).B.ANACK)

/*! @brief Format value for bitfield SIM_CNTL_ANACK. */
#define BF_SIM_CNTL_ANACK(v) ((uint32_t)((uint32_t)(v) << BP_SIM_CNTL_ANACK) & BM_SIM_CNTL_ANACK)

/*! @brief Set the ANACK field to a new value. */
#define BW_SIM_CNTL_ANACK(x, v) (HW_SIM_CNTL_WR(x, (HW_SIM_CNTL_RD(x) & ~BM_SIM_CNTL_ANACK) | BF_SIM_CNTL_ANACK(v)))
/*@}*/

/*!
 * @name Register SIM_CNTL, field ONACK[3] (RW)
 *
 * Overrun NACK Enable. Enables overrun NACK generation.
 *
 * Values:
 * - 0 - NACK generation on overrun is disabled (default)
 * - 1 - NACK generation on overrun is enabled
 */
/*@{*/
#define BP_SIM_CNTL_ONACK    (3U)          /*!< Bit position for SIM_CNTL_ONACK. */
#define BM_SIM_CNTL_ONACK    (0x00000008U) /*!< Bit mask for SIM_CNTL_ONACK. */
#define BS_SIM_CNTL_ONACK    (1U)          /*!< Bit field size in bits for SIM_CNTL_ONACK. */

/*! @brief Read current value of the SIM_CNTL_ONACK field. */
#define BR_SIM_CNTL_ONACK(x) (HW_SIM_CNTL(x).B.ONACK)

/*! @brief Format value for bitfield SIM_CNTL_ONACK. */
#define BF_SIM_CNTL_ONACK(v) ((uint32_t)((uint32_t)(v) << BP_SIM_CNTL_ONACK) & BM_SIM_CNTL_ONACK)

/*! @brief Set the ONACK field to a new value. */
#define BW_SIM_CNTL_ONACK(x, v) (HW_SIM_CNTL_WR(x, (HW_SIM_CNTL_RD(x) & ~BM_SIM_CNTL_ONACK) | BF_SIM_CNTL_ONACK(v)))
/*@}*/

/*!
 * @name Register SIM_CNTL, field Sample12[5] (RW)
 *
 * Sample12. Set the third stage divider. This sets the corresponding sample
 * rate which is the number of times a bit being received is sampled.
 *
 * Values:
 * - 0 - divide by 8(default)
 * - 1 - divide by 12
 */
/*@{*/
#define BP_SIM_CNTL_Sample12 (5U)          /*!< Bit position for SIM_CNTL_Sample12. */
#define BM_SIM_CNTL_Sample12 (0x00000020U) /*!< Bit mask for SIM_CNTL_Sample12. */
#define BS_SIM_CNTL_Sample12 (1U)          /*!< Bit field size in bits for SIM_CNTL_Sample12. */

/*! @brief Read current value of the SIM_CNTL_Sample12 field. */
#define BR_SIM_CNTL_Sample12(x) (HW_SIM_CNTL(x).B.Sample12)

/*! @brief Format value for bitfield SIM_CNTL_Sample12. */
#define BF_SIM_CNTL_Sample12(v) ((uint32_t)((uint32_t)(v) << BP_SIM_CNTL_Sample12) & BM_SIM_CNTL_Sample12)

/*! @brief Set the Sample12 field to a new value. */
#define BW_SIM_CNTL_Sample12(x, v) (HW_SIM_CNTL_WR(x, (HW_SIM_CNTL_RD(x) & ~BM_SIM_CNTL_Sample12) | BF_SIM_CNTL_Sample12(v)))
/*@}*/

/*!
 * @name Register SIM_CNTL, field baud_sel[8:6] (RW)
 *
 * SIM Baud Rate Select. Selects the asynchronous baud rate divisor of the clock
 * When set to "111", the divisor is set to the value programmed in the DIVISOR
 * register. This allows for more flexible baud rate determination.
 *
 * Values:
 * - 000 - 31 (512/1 Fi/Di)
 * - 001 - 32 (512/2 Fi/Di)
 * - 010 - 16 (512/4 Fi/Di)
 * - 011 - 8 (512/8 Fi/Di)
 * - 100 - 4 (512/16 Fi/Di)
 * - 101 - 2 (512/32 Fi/Di)
 * - 110 - 1 (512/64 Fi/Di)
 * - 111 - DIVISOR Reg
 */
/*@{*/
#define BP_SIM_CNTL_baud_sel (6U)          /*!< Bit position for SIM_CNTL_baud_sel. */
#define BM_SIM_CNTL_baud_sel (0x000001C0U) /*!< Bit mask for SIM_CNTL_baud_sel. */
#define BS_SIM_CNTL_baud_sel (3U)          /*!< Bit field size in bits for SIM_CNTL_baud_sel. */

/*! @brief Read current value of the SIM_CNTL_baud_sel field. */
#define BR_SIM_CNTL_baud_sel(x) (HW_SIM_CNTL(x).B.baud_sel)

/*! @brief Format value for bitfield SIM_CNTL_baud_sel. */
#define BF_SIM_CNTL_baud_sel(v) ((uint32_t)((uint32_t)(v) << BP_SIM_CNTL_baud_sel) & BM_SIM_CNTL_baud_sel)

/*! @brief Set the baud_sel field to a new value. */
#define BW_SIM_CNTL_baud_sel(x, v) (HW_SIM_CNTL_WR(x, (HW_SIM_CNTL_RD(x) & ~BM_SIM_CNTL_baud_sel) | BF_SIM_CNTL_baud_sel(v)))
/*@}*/

/*!
 * @name Register SIM_CNTL, field gpcnt_clk_sel[10:9] (RW)
 *
 * General Purpose Counter Clock Select. Selects which clock source is used by
 * SIM Module general purpose counter. The only way to reset the counter is to set
 * these bits to zero. The counter will begin counting as soon as the clock
 * input is selected and the clocks are enabled. These input clocks are enabled
 * through other register bits of the SIM module (KILL_CLOCK, RCV_EN, and XMT_EN
 * respectively).
 *
 * Values:
 * - 00 - Disabled / Reset
 * - 01 - Card Clock
 * - 10 - Receive Clock
 * - 11 - ETU Clock (transmit clock)
 */
/*@{*/
#define BP_SIM_CNTL_gpcnt_clk_sel (9U)     /*!< Bit position for SIM_CNTL_gpcnt_clk_sel. */
#define BM_SIM_CNTL_gpcnt_clk_sel (0x00000600U) /*!< Bit mask for SIM_CNTL_gpcnt_clk_sel. */
#define BS_SIM_CNTL_gpcnt_clk_sel (2U)     /*!< Bit field size in bits for SIM_CNTL_gpcnt_clk_sel. */

/*! @brief Read current value of the SIM_CNTL_gpcnt_clk_sel field. */
#define BR_SIM_CNTL_gpcnt_clk_sel(x) (HW_SIM_CNTL(x).B.gpcnt_clk_sel)

/*! @brief Format value for bitfield SIM_CNTL_gpcnt_clk_sel. */
#define BF_SIM_CNTL_gpcnt_clk_sel(v) ((uint32_t)((uint32_t)(v) << BP_SIM_CNTL_gpcnt_clk_sel) & BM_SIM_CNTL_gpcnt_clk_sel)

/*! @brief Set the gpcnt_clk_sel field to a new value. */
#define BW_SIM_CNTL_gpcnt_clk_sel(x, v) (HW_SIM_CNTL_WR(x, (HW_SIM_CNTL_RD(x) & ~BM_SIM_CNTL_gpcnt_clk_sel) | BF_SIM_CNTL_gpcnt_clk_sel(v)))
/*@}*/

/*!
 * @name Register SIM_CNTL, field CWTEN[11] (RW)
 *
 * Character Wait Time Counter Enable. Enables the character wait time counter.
 * Clearing this bit resets the counter to zero.
 *
 * Values:
 * - 0 - Character Wait time Counter off (default)
 * - 1 - Character Wait time counter on
 */
/*@{*/
#define BP_SIM_CNTL_CWTEN    (11U)         /*!< Bit position for SIM_CNTL_CWTEN. */
#define BM_SIM_CNTL_CWTEN    (0x00000800U) /*!< Bit mask for SIM_CNTL_CWTEN. */
#define BS_SIM_CNTL_CWTEN    (1U)          /*!< Bit field size in bits for SIM_CNTL_CWTEN. */

/*! @brief Read current value of the SIM_CNTL_CWTEN field. */
#define BR_SIM_CNTL_CWTEN(x) (HW_SIM_CNTL(x).B.CWTEN)

/*! @brief Format value for bitfield SIM_CNTL_CWTEN. */
#define BF_SIM_CNTL_CWTEN(v) ((uint32_t)((uint32_t)(v) << BP_SIM_CNTL_CWTEN) & BM_SIM_CNTL_CWTEN)

/*! @brief Set the CWTEN field to a new value. */
#define BW_SIM_CNTL_CWTEN(x, v) (HW_SIM_CNTL_WR(x, (HW_SIM_CNTL_RD(x) & ~BM_SIM_CNTL_CWTEN) | BF_SIM_CNTL_CWTEN(v)))
/*@}*/

/*!
 * @name Register SIM_CNTL, field LRCEN[12] (RW)
 *
 * LRC Enable. This bit enables the calculation of the 8-bit LRC value for both
 * receiver and transmitter. The result of the calculation is continuously
 * compared to zero and reflected in the lrcok bit in the RCV_STAT register. Clearing
 * this bit resets the current LRC value in the SIM hardware.
 *
 * Values:
 * - 0 - 8-bit Linear Redundancy Checking disabled (default)
 * - 1 - 8-bit Linear Redundancy Checking enabled
 */
/*@{*/
#define BP_SIM_CNTL_LRCEN    (12U)         /*!< Bit position for SIM_CNTL_LRCEN. */
#define BM_SIM_CNTL_LRCEN    (0x00001000U) /*!< Bit mask for SIM_CNTL_LRCEN. */
#define BS_SIM_CNTL_LRCEN    (1U)          /*!< Bit field size in bits for SIM_CNTL_LRCEN. */

/*! @brief Read current value of the SIM_CNTL_LRCEN field. */
#define BR_SIM_CNTL_LRCEN(x) (HW_SIM_CNTL(x).B.LRCEN)

/*! @brief Format value for bitfield SIM_CNTL_LRCEN. */
#define BF_SIM_CNTL_LRCEN(v) ((uint32_t)((uint32_t)(v) << BP_SIM_CNTL_LRCEN) & BM_SIM_CNTL_LRCEN)

/*! @brief Set the LRCEN field to a new value. */
#define BW_SIM_CNTL_LRCEN(x, v) (HW_SIM_CNTL_WR(x, (HW_SIM_CNTL_RD(x) & ~BM_SIM_CNTL_LRCEN) | BF_SIM_CNTL_LRCEN(v)))
/*@}*/

/*!
 * @name Register SIM_CNTL, field CRCEN[13] (RW)
 *
 * CRC Enable. This bit enables the calculation of the 16-bit CRC value for both
 * receiver and transmitter. The result of the calculation is continuously
 * compared to the expected remainder and reflected in the crcok bit in the RCV_STAT
 * register. Clearing this bit resets the current CRC residual value in the SIM
 * hardware.
 *
 * Values:
 * - 0 - 16-bit Cyclic Redundancy Checking disabled (default)
 * - 1 - 16-bit Cyclic Redundancy Checking enabled
 */
/*@{*/
#define BP_SIM_CNTL_CRCEN    (13U)         /*!< Bit position for SIM_CNTL_CRCEN. */
#define BM_SIM_CNTL_CRCEN    (0x00002000U) /*!< Bit mask for SIM_CNTL_CRCEN. */
#define BS_SIM_CNTL_CRCEN    (1U)          /*!< Bit field size in bits for SIM_CNTL_CRCEN. */

/*! @brief Read current value of the SIM_CNTL_CRCEN field. */
#define BR_SIM_CNTL_CRCEN(x) (HW_SIM_CNTL(x).B.CRCEN)

/*! @brief Format value for bitfield SIM_CNTL_CRCEN. */
#define BF_SIM_CNTL_CRCEN(v) ((uint32_t)((uint32_t)(v) << BP_SIM_CNTL_CRCEN) & BM_SIM_CNTL_CRCEN)

/*! @brief Set the CRCEN field to a new value. */
#define BW_SIM_CNTL_CRCEN(x, v) (HW_SIM_CNTL_WR(x, (HW_SIM_CNTL_RD(x) & ~BM_SIM_CNTL_CRCEN) | BF_SIM_CNTL_CRCEN(v)))
/*@}*/

/*!
 * @name Register SIM_CNTL, field xmt_crc_lrc[14] (RW)
 *
 * Transmit CRC or LRC. This bit specifies whether or not to transmit the
 * redundancy checking data at the end of a transmission (that is, when the FIFO
 * becomes empty).
 *
 * Values:
 * - 0 - No Redundancy check info transmitted (default)
 * - 1 - Transmit LRC or CRC info when FIFO empties (whichever is enabled)
 */
/*@{*/
#define BP_SIM_CNTL_xmt_crc_lrc (14U)      /*!< Bit position for SIM_CNTL_xmt_crc_lrc. */
#define BM_SIM_CNTL_xmt_crc_lrc (0x00004000U) /*!< Bit mask for SIM_CNTL_xmt_crc_lrc. */
#define BS_SIM_CNTL_xmt_crc_lrc (1U)       /*!< Bit field size in bits for SIM_CNTL_xmt_crc_lrc. */

/*! @brief Read current value of the SIM_CNTL_xmt_crc_lrc field. */
#define BR_SIM_CNTL_xmt_crc_lrc(x) (HW_SIM_CNTL(x).B.xmt_crc_lrc)

/*! @brief Format value for bitfield SIM_CNTL_xmt_crc_lrc. */
#define BF_SIM_CNTL_xmt_crc_lrc(v) ((uint32_t)((uint32_t)(v) << BP_SIM_CNTL_xmt_crc_lrc) & BM_SIM_CNTL_xmt_crc_lrc)

/*! @brief Set the xmt_crc_lrc field to a new value. */
#define BW_SIM_CNTL_xmt_crc_lrc(x, v) (HW_SIM_CNTL_WR(x, (HW_SIM_CNTL_RD(x) & ~BM_SIM_CNTL_xmt_crc_lrc) | BF_SIM_CNTL_xmt_crc_lrc(v)))
/*@}*/

/*!
 * @name Register SIM_CNTL, field BWTEN[15] (RW)
 *
 * Block wait time enable. Writing a "1" to this bit will enable the bwt and bgt
 * functions. The bwt and bgt functions can then be individually selected using
 * the interrupt mask.
 *
 * Values:
 * - 0 - Disable BWT, BGT
 * - 1 - Enable BWT, BGT
 */
/*@{*/
#define BP_SIM_CNTL_BWTEN    (15U)         /*!< Bit position for SIM_CNTL_BWTEN. */
#define BM_SIM_CNTL_BWTEN    (0x00008000U) /*!< Bit mask for SIM_CNTL_BWTEN. */
#define BS_SIM_CNTL_BWTEN    (1U)          /*!< Bit field size in bits for SIM_CNTL_BWTEN. */

/*! @brief Read current value of the SIM_CNTL_BWTEN field. */
#define BR_SIM_CNTL_BWTEN(x) (HW_SIM_CNTL(x).B.BWTEN)

/*! @brief Format value for bitfield SIM_CNTL_BWTEN. */
#define BF_SIM_CNTL_BWTEN(v) ((uint32_t)((uint32_t)(v) << BP_SIM_CNTL_BWTEN) & BM_SIM_CNTL_BWTEN)

/*! @brief Set the BWTEN field to a new value. */
#define BW_SIM_CNTL_BWTEN(x, v) (HW_SIM_CNTL_WR(x, (HW_SIM_CNTL_RD(x) & ~BM_SIM_CNTL_BWTEN) | BF_SIM_CNTL_BWTEN(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_CLK_PRESCALER - SIM Clock Prescaler Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_CLK_PRESCALER - SIM Clock Prescaler Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * See the figure below for illustration of valid bits in the SIM Clock
 * Prescaler Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_clk_prescaler
{
    uint32_t U;
    struct _hw_sim_clk_prescaler_bitfields
    {
        uint32_t CLK_PRESCALER : 8;    /*!< [7:0]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_sim_clk_prescaler_t;

/*!
 * @name Constants and macros for entire SIM_CLK_PRESCALER register
 */
/*@{*/
#define HW_SIM_CLK_PRESCALER_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_SIM_CLK_PRESCALER(x)  (*(__IO hw_sim_clk_prescaler_t *) HW_SIM_CLK_PRESCALER_ADDR(x))
#define HW_SIM_CLK_PRESCALER_RD(x) (HW_SIM_CLK_PRESCALER(x).U)
#define HW_SIM_CLK_PRESCALER_WR(x, v) (HW_SIM_CLK_PRESCALER(x).U = (v))
#define HW_SIM_CLK_PRESCALER_SET(x, v) (HW_SIM_CLK_PRESCALER_WR(x, HW_SIM_CLK_PRESCALER_RD(x) |  (v)))
#define HW_SIM_CLK_PRESCALER_CLR(x, v) (HW_SIM_CLK_PRESCALER_WR(x, HW_SIM_CLK_PRESCALER_RD(x) & ~(v)))
#define HW_SIM_CLK_PRESCALER_TOG(x, v) (HW_SIM_CLK_PRESCALER_WR(x, HW_SIM_CLK_PRESCALER_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_CLK_PRESCALER bitfields
 */

/*!
 * @name Register SIM_CLK_PRESCALER, field CLK_PRESCALER[7:0] (RW)
 *
 * Clock prescaler divisor register. The value written to this register will
 * determine the first stage divider setting. If the ipg_perclk is 66Mhz, a typical
 * setting would be 0x0e. This would set the SIM card clock to 66Mhz/14 = 4.7Mhz.
 * The duty cycle of divided clock will be between 45% and 55% according to
 * ISO7816 requirement. For the odd divider factor (2K+1), the duty cycle will be
 * K/(2K+1) and (K+1)/(2k+1). So for 0x03, the duty cycle is 33%-66%. For 0x05, the
 * duty cycle is 40%-60%. For 0x07, the duty cycle is 43%-57%, and for 0x09, the
 * duty cycle is 44%-56%. For all other values, the clock duty cycle can meet the
 * ISO7816 requirement. Not all values are listed
 *
 * Values:
 * - 0 - ~0x02 ipg_perclk/ 2
 * - 11 - ipg_perclk / 3
 * - 100 - ipg_perclk / 4
 * - 101 - ipg_perclk / 5
 * - 110 - ipg_perclk / 6
 * - 11111101 - ipg_perclk / 253
 * - 11111110 - ipg_perclk / 254
 * - 11111111 - ipg_perclk / 255
 */
/*@{*/
#define BP_SIM_CLK_PRESCALER_CLK_PRESCALER (0U) /*!< Bit position for SIM_CLK_PRESCALER_CLK_PRESCALER. */
#define BM_SIM_CLK_PRESCALER_CLK_PRESCALER (0x000000FFU) /*!< Bit mask for SIM_CLK_PRESCALER_CLK_PRESCALER. */
#define BS_SIM_CLK_PRESCALER_CLK_PRESCALER (8U) /*!< Bit field size in bits for SIM_CLK_PRESCALER_CLK_PRESCALER. */

/*! @brief Read current value of the SIM_CLK_PRESCALER_CLK_PRESCALER field. */
#define BR_SIM_CLK_PRESCALER_CLK_PRESCALER(x) (HW_SIM_CLK_PRESCALER(x).B.CLK_PRESCALER)

/*! @brief Format value for bitfield SIM_CLK_PRESCALER_CLK_PRESCALER. */
#define BF_SIM_CLK_PRESCALER_CLK_PRESCALER(v) ((uint32_t)((uint32_t)(v) << BP_SIM_CLK_PRESCALER_CLK_PRESCALER) & BM_SIM_CLK_PRESCALER_CLK_PRESCALER)

/*! @brief Set the CLK_PRESCALER field to a new value. */
#define BW_SIM_CLK_PRESCALER_CLK_PRESCALER(x, v) (HW_SIM_CLK_PRESCALER_WR(x, (HW_SIM_CLK_PRESCALER_RD(x) & ~BM_SIM_CLK_PRESCALER_CLK_PRESCALER) | BF_SIM_CLK_PRESCALER_CLK_PRESCALER(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_RCV_THRESHOLD - SIM Receive Threshold Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_RCV_THRESHOLD - SIM Receive Threshold Register (RW)
 *
 * Reset value: 0x00000001U
 *
 * See the figure below for illustration of valid bits in the SIM Receive
 * Threshold Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_rcv_threshold
{
    uint32_t U;
    struct _hw_sim_rcv_threshold_bitfields
    {
        uint32_t RDT : 9;              /*!< [8:0]  */
        uint32_t RTH : 4;              /*!< [12:9]  */
        uint32_t RESERVED0 : 19;       /*!< [31:13]  */
    } B;
} hw_sim_rcv_threshold_t;

/*!
 * @name Constants and macros for entire SIM_RCV_THRESHOLD register
 */
/*@{*/
#define HW_SIM_RCV_THRESHOLD_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_SIM_RCV_THRESHOLD(x)  (*(__IO hw_sim_rcv_threshold_t *) HW_SIM_RCV_THRESHOLD_ADDR(x))
#define HW_SIM_RCV_THRESHOLD_RD(x) (HW_SIM_RCV_THRESHOLD(x).U)
#define HW_SIM_RCV_THRESHOLD_WR(x, v) (HW_SIM_RCV_THRESHOLD(x).U = (v))
#define HW_SIM_RCV_THRESHOLD_SET(x, v) (HW_SIM_RCV_THRESHOLD_WR(x, HW_SIM_RCV_THRESHOLD_RD(x) |  (v)))
#define HW_SIM_RCV_THRESHOLD_CLR(x, v) (HW_SIM_RCV_THRESHOLD_WR(x, HW_SIM_RCV_THRESHOLD_RD(x) & ~(v)))
#define HW_SIM_RCV_THRESHOLD_TOG(x, v) (HW_SIM_RCV_THRESHOLD_WR(x, HW_SIM_RCV_THRESHOLD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_RCV_THRESHOLD bitfields
 */

/*!
 * @name Register SIM_RCV_THRESHOLD, field RDT[8:0] (RW)
 *
 * Receive Data Threshold. Determines the number of unread bytes that must exist
 * in the FIFO to trigger the receive data register full (RDRF) interrupt flag.
 * If the number of unread bytes in the receive FIFO is greater than or equal to
 * the value in RDT, the RDRF flag in the RCV_STATUS register will be set. A
 * value of zero indicates that there must be 288 unread bytes in the FIFO to trigger
 * RDRF. If a value of more than 288 is entered in this register, the register
 * value will remain 288.
 */
/*@{*/
#define BP_SIM_RCV_THRESHOLD_RDT (0U)      /*!< Bit position for SIM_RCV_THRESHOLD_RDT. */
#define BM_SIM_RCV_THRESHOLD_RDT (0x000001FFU) /*!< Bit mask for SIM_RCV_THRESHOLD_RDT. */
#define BS_SIM_RCV_THRESHOLD_RDT (9U)      /*!< Bit field size in bits for SIM_RCV_THRESHOLD_RDT. */

/*! @brief Read current value of the SIM_RCV_THRESHOLD_RDT field. */
#define BR_SIM_RCV_THRESHOLD_RDT(x) (HW_SIM_RCV_THRESHOLD(x).B.RDT)

/*! @brief Format value for bitfield SIM_RCV_THRESHOLD_RDT. */
#define BF_SIM_RCV_THRESHOLD_RDT(v) ((uint32_t)((uint32_t)(v) << BP_SIM_RCV_THRESHOLD_RDT) & BM_SIM_RCV_THRESHOLD_RDT)

/*! @brief Set the RDT field to a new value. */
#define BW_SIM_RCV_THRESHOLD_RDT(x, v) (HW_SIM_RCV_THRESHOLD_WR(x, (HW_SIM_RCV_THRESHOLD_RD(x) & ~BM_SIM_RCV_THRESHOLD_RDT) | BF_SIM_RCV_THRESHOLD_RDT(v)))
/*@}*/

/*!
 * @name Register SIM_RCV_THRESHOLD, field RTH[12:9] (RW)
 *
 * Receive Nack Threshold. Used to specify the number of consecutive NACK's
 * transmitted by the SIM module, for a given character, before the receive threshold
 * error (RTE) flag is triggered. A value of 0 indicates that RTE is never set.
 * When a valid character is received by the SIM, the internal counter keeping
 * track of the NACK count resets to zero for the subsequent byte being received.
 * If the ANACK bit is clear in the CNTL register, RTH has no effect.
 */
/*@{*/
#define BP_SIM_RCV_THRESHOLD_RTH (9U)      /*!< Bit position for SIM_RCV_THRESHOLD_RTH. */
#define BM_SIM_RCV_THRESHOLD_RTH (0x00001E00U) /*!< Bit mask for SIM_RCV_THRESHOLD_RTH. */
#define BS_SIM_RCV_THRESHOLD_RTH (4U)      /*!< Bit field size in bits for SIM_RCV_THRESHOLD_RTH. */

/*! @brief Read current value of the SIM_RCV_THRESHOLD_RTH field. */
#define BR_SIM_RCV_THRESHOLD_RTH(x) (HW_SIM_RCV_THRESHOLD(x).B.RTH)

/*! @brief Format value for bitfield SIM_RCV_THRESHOLD_RTH. */
#define BF_SIM_RCV_THRESHOLD_RTH(v) ((uint32_t)((uint32_t)(v) << BP_SIM_RCV_THRESHOLD_RTH) & BM_SIM_RCV_THRESHOLD_RTH)

/*! @brief Set the RTH field to a new value. */
#define BW_SIM_RCV_THRESHOLD_RTH(x, v) (HW_SIM_RCV_THRESHOLD_WR(x, (HW_SIM_RCV_THRESHOLD_RD(x) & ~BM_SIM_RCV_THRESHOLD_RTH) | BF_SIM_RCV_THRESHOLD_RTH(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_ENABLE - SIM Enable Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_ENABLE - SIM Enable Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * See the figure below for illustration of valid bits in the SIM Enable
 * Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_enable
{
    uint32_t U;
    struct _hw_sim_enable_bitfields
    {
        uint32_t RCV_EN : 1;           /*!< [0]  */
        uint32_t XMT_EN : 1;           /*!< [1]  */
        uint32_t RXDMA_EN : 1;         /*!< [2]  */
        uint32_t TXDMA_EN : 1;         /*!< [3]  */
        uint32_t NACK_DD_EN : 1;       /*!< [4]  */
        uint32_t ESTOP_EN : 1;         /*!< [5]  */
        uint32_t ESTOP_EXE : 1;        /*!< [6]  */
        uint32_t RXCL : 1;             /*!< [7]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_sim_enable_t;

/*!
 * @name Constants and macros for entire SIM_ENABLE register
 */
/*@{*/
#define HW_SIM_ENABLE_ADDR(x)    ((uintptr_t)(x) + 0x24U)

#define HW_SIM_ENABLE(x)         (*(__IO hw_sim_enable_t *) HW_SIM_ENABLE_ADDR(x))
#define HW_SIM_ENABLE_RD(x)      (HW_SIM_ENABLE(x).U)
#define HW_SIM_ENABLE_WR(x, v)   (HW_SIM_ENABLE(x).U = (v))
#define HW_SIM_ENABLE_SET(x, v)  (HW_SIM_ENABLE_WR(x, HW_SIM_ENABLE_RD(x) |  (v)))
#define HW_SIM_ENABLE_CLR(x, v)  (HW_SIM_ENABLE_WR(x, HW_SIM_ENABLE_RD(x) & ~(v)))
#define HW_SIM_ENABLE_TOG(x, v)  (HW_SIM_ENABLE_WR(x, HW_SIM_ENABLE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_ENABLE bitfields
 */

/*!
 * @name Register SIM_ENABLE, field RCV_EN[0] (RW)
 *
 * SIM Receiver Enable. Used to enable/disable the SIM receive state machine.
 * The RCV_EN bit should be left high whenever the SIM module is in use. The SIM
 * module has an automatic receive mode operation that disables the reception of
 * characters when the transmitter is operational. Once the transmitter has
 * completed sending the last character, the receiver is automatically enabled. This bit
 * also enables the RCV_CLK input to the General Purpose Counter.
 *
 * Values:
 * - 0 - SIM Receiver disabled (default)
 * - 1 - SIM Receiver enabled
 */
/*@{*/
#define BP_SIM_ENABLE_RCV_EN (0U)          /*!< Bit position for SIM_ENABLE_RCV_EN. */
#define BM_SIM_ENABLE_RCV_EN (0x00000001U) /*!< Bit mask for SIM_ENABLE_RCV_EN. */
#define BS_SIM_ENABLE_RCV_EN (1U)          /*!< Bit field size in bits for SIM_ENABLE_RCV_EN. */

/*! @brief Read current value of the SIM_ENABLE_RCV_EN field. */
#define BR_SIM_ENABLE_RCV_EN(x) (HW_SIM_ENABLE(x).B.RCV_EN)

/*! @brief Format value for bitfield SIM_ENABLE_RCV_EN. */
#define BF_SIM_ENABLE_RCV_EN(v) ((uint32_t)((uint32_t)(v) << BP_SIM_ENABLE_RCV_EN) & BM_SIM_ENABLE_RCV_EN)

/*! @brief Set the RCV_EN field to a new value. */
#define BW_SIM_ENABLE_RCV_EN(x, v) (HW_SIM_ENABLE_WR(x, (HW_SIM_ENABLE_RD(x) & ~BM_SIM_ENABLE_RCV_EN) | BF_SIM_ENABLE_RCV_EN(v)))
/*@}*/

/*!
 * @name Register SIM_ENABLE, field XMT_EN[1] (RW)
 *
 * SIM Transmit Enable. Used to enable/disable the SIM transmit state machine.
 * When the SIM is being used to receive data, XMT_EN should be deasserted. This
 * bit also enables the xmt_clk and rcv_clk inputs to the General Purpose Counter.
 * Setting this bit (transition from 0 to 1) will reset the CRC and LRC values.
 *
 * Values:
 * - 0 - SIM Transmitter disabled (default)
 * - 1 - SIM Transmitter enabled
 */
/*@{*/
#define BP_SIM_ENABLE_XMT_EN (1U)          /*!< Bit position for SIM_ENABLE_XMT_EN. */
#define BM_SIM_ENABLE_XMT_EN (0x00000002U) /*!< Bit mask for SIM_ENABLE_XMT_EN. */
#define BS_SIM_ENABLE_XMT_EN (1U)          /*!< Bit field size in bits for SIM_ENABLE_XMT_EN. */

/*! @brief Read current value of the SIM_ENABLE_XMT_EN field. */
#define BR_SIM_ENABLE_XMT_EN(x) (HW_SIM_ENABLE(x).B.XMT_EN)

/*! @brief Format value for bitfield SIM_ENABLE_XMT_EN. */
#define BF_SIM_ENABLE_XMT_EN(v) ((uint32_t)((uint32_t)(v) << BP_SIM_ENABLE_XMT_EN) & BM_SIM_ENABLE_XMT_EN)

/*! @brief Set the XMT_EN field to a new value. */
#define BW_SIM_ENABLE_XMT_EN(x, v) (HW_SIM_ENABLE_WR(x, (HW_SIM_ENABLE_RD(x) & ~BM_SIM_ENABLE_XMT_EN) | BF_SIM_ENABLE_XMT_EN(v)))
/*@}*/

/*!
 * @name Register SIM_ENABLE, field RXDMA_EN[2] (RW)
 *
 * Receiver DMA Enable. This bit allows SIM to request for DMA transfers. When
 * enabled, DMA requests are generated when when the number of bytes in the
 * receive FIFO is more than or equal to the value programed in the RDT[8:0] in the
 * RCV_THRESHOLD register and RCV_EN is set
 *
 * Values:
 * - 0 - SIM Receiver DMA request disabled.
 * - 1 - SIM Receiver DMA request enabled.
 */
/*@{*/
#define BP_SIM_ENABLE_RXDMA_EN (2U)        /*!< Bit position for SIM_ENABLE_RXDMA_EN. */
#define BM_SIM_ENABLE_RXDMA_EN (0x00000004U) /*!< Bit mask for SIM_ENABLE_RXDMA_EN. */
#define BS_SIM_ENABLE_RXDMA_EN (1U)        /*!< Bit field size in bits for SIM_ENABLE_RXDMA_EN. */

/*! @brief Read current value of the SIM_ENABLE_RXDMA_EN field. */
#define BR_SIM_ENABLE_RXDMA_EN(x) (HW_SIM_ENABLE(x).B.RXDMA_EN)

/*! @brief Format value for bitfield SIM_ENABLE_RXDMA_EN. */
#define BF_SIM_ENABLE_RXDMA_EN(v) ((uint32_t)((uint32_t)(v) << BP_SIM_ENABLE_RXDMA_EN) & BM_SIM_ENABLE_RXDMA_EN)

/*! @brief Set the RXDMA_EN field to a new value. */
#define BW_SIM_ENABLE_RXDMA_EN(x, v) (HW_SIM_ENABLE_WR(x, (HW_SIM_ENABLE_RD(x) & ~BM_SIM_ENABLE_RXDMA_EN) | BF_SIM_ENABLE_RXDMA_EN(v)))
/*@}*/

/*!
 * @name Register SIM_ENABLE, field TXDMA_EN[3] (RW)
 *
 * Transmitter DMA Enable. This bit allows SIM to request for DMA transfers.
 * When enabled, DMA requests are generated when the number of bytes in the transmit
 * FIFO is less than or equal to the value programmed in the tdt[3:0] bits in
 * the XMT_THRESHOLD register and XMT_EN is set.
 *
 * Values:
 * - 0 - SIM Transmitter DMA requests disabled.
 * - 1 - SIM Transmitter DMA requests enabled.
 */
/*@{*/
#define BP_SIM_ENABLE_TXDMA_EN (3U)        /*!< Bit position for SIM_ENABLE_TXDMA_EN. */
#define BM_SIM_ENABLE_TXDMA_EN (0x00000008U) /*!< Bit mask for SIM_ENABLE_TXDMA_EN. */
#define BS_SIM_ENABLE_TXDMA_EN (1U)        /*!< Bit field size in bits for SIM_ENABLE_TXDMA_EN. */

/*! @brief Read current value of the SIM_ENABLE_TXDMA_EN field. */
#define BR_SIM_ENABLE_TXDMA_EN(x) (HW_SIM_ENABLE(x).B.TXDMA_EN)

/*! @brief Format value for bitfield SIM_ENABLE_TXDMA_EN. */
#define BF_SIM_ENABLE_TXDMA_EN(v) ((uint32_t)((uint32_t)(v) << BP_SIM_ENABLE_TXDMA_EN) & BM_SIM_ENABLE_TXDMA_EN)

/*! @brief Set the TXDMA_EN field to a new value. */
#define BW_SIM_ENABLE_TXDMA_EN(x, v) (HW_SIM_ENABLE_WR(x, (HW_SIM_ENABLE_RD(x) & ~BM_SIM_ENABLE_TXDMA_EN) | BF_SIM_ENABLE_TXDMA_EN(v)))
/*@}*/

/*!
 * @name Register SIM_ENABLE, field NACK_DD_EN[4] (RW)
 *
 * NACK delay detection enable. Used to enable/disable the function of NACK
 * delay detection. The SIM receive state machine will detect the NACK signal at the
 * 16th phase and use the values of12th, 14th and 15th sample point, if enable
 * this bit. This function is used for the test case NACK signal send at 10.7 ETUs
 * from the falling edge of start signal.
 *
 * Values:
 * - 0 - Disable the delay detection function.
 * - 1 - Enable the delay detection function.
 */
/*@{*/
#define BP_SIM_ENABLE_NACK_DD_EN (4U)      /*!< Bit position for SIM_ENABLE_NACK_DD_EN. */
#define BM_SIM_ENABLE_NACK_DD_EN (0x00000010U) /*!< Bit mask for SIM_ENABLE_NACK_DD_EN. */
#define BS_SIM_ENABLE_NACK_DD_EN (1U)      /*!< Bit field size in bits for SIM_ENABLE_NACK_DD_EN. */

/*! @brief Read current value of the SIM_ENABLE_NACK_DD_EN field. */
#define BR_SIM_ENABLE_NACK_DD_EN(x) (HW_SIM_ENABLE(x).B.NACK_DD_EN)

/*! @brief Format value for bitfield SIM_ENABLE_NACK_DD_EN. */
#define BF_SIM_ENABLE_NACK_DD_EN(v) ((uint32_t)((uint32_t)(v) << BP_SIM_ENABLE_NACK_DD_EN) & BM_SIM_ENABLE_NACK_DD_EN)

/*! @brief Set the NACK_DD_EN field to a new value. */
#define BW_SIM_ENABLE_NACK_DD_EN(x, v) (HW_SIM_ENABLE_WR(x, (HW_SIM_ENABLE_RD(x) & ~BM_SIM_ENABLE_NACK_DD_EN) | BF_SIM_ENABLE_NACK_DD_EN(v)))
/*@}*/

/*!
 * @name Register SIM_ENABLE, field ESTOP_EN[5] (RW)
 *
 * Enforce reception early stop enable. Used to early stop the SIM receive state
 * machine. The state machine will stop earliey than 10.8 ETUs when 11 ETUs mode
 * or earlier than 11.8 ETUs when non 11 ETUs mode, if enable this bit. This
 * function is used for the test case tramsmission stop at 10.8 ETUs from the
 * falling edge of start signal. This bit should be set to 1 when receive data, and set
 * to 0 when transmit data.
 *
 * Values:
 * - 0 - Disable the enforce reception early stop function.
 * - 1 - Enable the enforce reception early stop function.
 */
/*@{*/
#define BP_SIM_ENABLE_ESTOP_EN (5U)        /*!< Bit position for SIM_ENABLE_ESTOP_EN. */
#define BM_SIM_ENABLE_ESTOP_EN (0x00000020U) /*!< Bit mask for SIM_ENABLE_ESTOP_EN. */
#define BS_SIM_ENABLE_ESTOP_EN (1U)        /*!< Bit field size in bits for SIM_ENABLE_ESTOP_EN. */

/*! @brief Read current value of the SIM_ENABLE_ESTOP_EN field. */
#define BR_SIM_ENABLE_ESTOP_EN(x) (HW_SIM_ENABLE(x).B.ESTOP_EN)

/*! @brief Format value for bitfield SIM_ENABLE_ESTOP_EN. */
#define BF_SIM_ENABLE_ESTOP_EN(v) ((uint32_t)((uint32_t)(v) << BP_SIM_ENABLE_ESTOP_EN) & BM_SIM_ENABLE_ESTOP_EN)

/*! @brief Set the ESTOP_EN field to a new value. */
#define BW_SIM_ENABLE_ESTOP_EN(x, v) (HW_SIM_ENABLE_WR(x, (HW_SIM_ENABLE_RD(x) & ~BM_SIM_ENABLE_ESTOP_EN) | BF_SIM_ENABLE_ESTOP_EN(v)))
/*@}*/

/*!
 * @name Register SIM_ENABLE, field ESTOP_EXE[6] (RW)
 *
 * Enforce reception early stop execution. Used to execute the function of
 * enforce reception early stop when ESTOP_EN bit set to 1. If this bit is 0 the early
 * stop function can't be executed when NACK signal occur.
 *
 * Values:
 * - 0 - Enforce reception early stop function will be executed without NACK.
 * - 1 - Enforce reception early stop function will be executed at all times.
 */
/*@{*/
#define BP_SIM_ENABLE_ESTOP_EXE (6U)       /*!< Bit position for SIM_ENABLE_ESTOP_EXE. */
#define BM_SIM_ENABLE_ESTOP_EXE (0x00000040U) /*!< Bit mask for SIM_ENABLE_ESTOP_EXE. */
#define BS_SIM_ENABLE_ESTOP_EXE (1U)       /*!< Bit field size in bits for SIM_ENABLE_ESTOP_EXE. */

/*! @brief Read current value of the SIM_ENABLE_ESTOP_EXE field. */
#define BR_SIM_ENABLE_ESTOP_EXE(x) (HW_SIM_ENABLE(x).B.ESTOP_EXE)

/*! @brief Format value for bitfield SIM_ENABLE_ESTOP_EXE. */
#define BF_SIM_ENABLE_ESTOP_EXE(v) ((uint32_t)((uint32_t)(v) << BP_SIM_ENABLE_ESTOP_EXE) & BM_SIM_ENABLE_ESTOP_EXE)

/*! @brief Set the ESTOP_EXE field to a new value. */
#define BW_SIM_ENABLE_ESTOP_EXE(x, v) (HW_SIM_ENABLE_WR(x, (HW_SIM_ENABLE_RD(x) & ~BM_SIM_ENABLE_ESTOP_EXE) | BF_SIM_ENABLE_ESTOP_EXE(v)))
/*@}*/

/*!
 * @name Register SIM_ENABLE, field RXCL[7] (RW)
 *
 * Reception data latch disable. Used to disable/enable the cross clock domain
 * synchronization operation of reception data in SIM receive state machine.
 *
 * Values:
 * - 0 - Enable the synchronization operation.
 * - 1 - Disable the synchronization operation.
 */
/*@{*/
#define BP_SIM_ENABLE_RXCL   (7U)          /*!< Bit position for SIM_ENABLE_RXCL. */
#define BM_SIM_ENABLE_RXCL   (0x00000080U) /*!< Bit mask for SIM_ENABLE_RXCL. */
#define BS_SIM_ENABLE_RXCL   (1U)          /*!< Bit field size in bits for SIM_ENABLE_RXCL. */

/*! @brief Read current value of the SIM_ENABLE_RXCL field. */
#define BR_SIM_ENABLE_RXCL(x) (HW_SIM_ENABLE(x).B.RXCL)

/*! @brief Format value for bitfield SIM_ENABLE_RXCL. */
#define BF_SIM_ENABLE_RXCL(v) ((uint32_t)((uint32_t)(v) << BP_SIM_ENABLE_RXCL) & BM_SIM_ENABLE_RXCL)

/*! @brief Set the RXCL field to a new value. */
#define BW_SIM_ENABLE_RXCL(x, v) (HW_SIM_ENABLE_WR(x, (HW_SIM_ENABLE_RD(x) & ~BM_SIM_ENABLE_RXCL) | BF_SIM_ENABLE_RXCL(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_XMT_STATUS - SIM Transmit Status Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_XMT_STATUS - SIM Transmit Status Register (RW)
 *
 * Reset value: 0x000000B8U
 *
 * See the figure below for illustration of valid bits in the SIM Transmit
 * Status Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_xmt_status
{
    uint32_t U;
    struct _hw_sim_xmt_status_bitfields
    {
        uint32_t XTE : 1;              /*!< [0]  */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t TFE : 1;              /*!< [3]  */
        uint32_t ETC : 1;              /*!< [4]  */
        uint32_t TC : 1;               /*!< [5]  */
        uint32_t TFO : 1;              /*!< [6]  */
        uint32_t TDTF : 1;             /*!< [7]  */
        uint32_t GPCNT : 1;            /*!< [8]  */
        uint32_t RESERVED1 : 23;       /*!< [31:9]  */
    } B;
} hw_sim_xmt_status_t;

/*!
 * @name Constants and macros for entire SIM_XMT_STATUS register
 */
/*@{*/
#define HW_SIM_XMT_STATUS_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_SIM_XMT_STATUS(x)     (*(__IO hw_sim_xmt_status_t *) HW_SIM_XMT_STATUS_ADDR(x))
#define HW_SIM_XMT_STATUS_RD(x)  (HW_SIM_XMT_STATUS(x).U)
#define HW_SIM_XMT_STATUS_WR(x, v) (HW_SIM_XMT_STATUS(x).U = (v))
#define HW_SIM_XMT_STATUS_SET(x, v) (HW_SIM_XMT_STATUS_WR(x, HW_SIM_XMT_STATUS_RD(x) |  (v)))
#define HW_SIM_XMT_STATUS_CLR(x, v) (HW_SIM_XMT_STATUS_WR(x, HW_SIM_XMT_STATUS_RD(x) & ~(v)))
#define HW_SIM_XMT_STATUS_TOG(x, v) (HW_SIM_XMT_STATUS_WR(x, HW_SIM_XMT_STATUS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_XMT_STATUS bitfields
 */

/*!
 * @name Register SIM_XMT_STATUS, field XTE[0] (W1C)
 *
 * Transmit NACK Threshold Error. Used to indicate the transmit NACK threshold
 * has been reached. When XTE is high, no further transmissions will be done until
 * the XTE flag is cleared. Any data transmissions still pending in the transmit
 * FIFO will be aborted, and the TC, ETC, and TFE flags will be set. The XTE
 * flag will create an interrupt if XTM in the IMT_MASK register is low. The XTE bit
 * is a write-one-to-clear bit.
 *
 * Values:
 * - 0 - Transmit NACK threshold has not been reached (default)
 * - 1 - Transmit NACK threshold reached; transmitter frozen
 */
/*@{*/
#define BP_SIM_XMT_STATUS_XTE (0U)         /*!< Bit position for SIM_XMT_STATUS_XTE. */
#define BM_SIM_XMT_STATUS_XTE (0x00000001U) /*!< Bit mask for SIM_XMT_STATUS_XTE. */
#define BS_SIM_XMT_STATUS_XTE (1U)         /*!< Bit field size in bits for SIM_XMT_STATUS_XTE. */

/*! @brief Read current value of the SIM_XMT_STATUS_XTE field. */
#define BR_SIM_XMT_STATUS_XTE(x) (HW_SIM_XMT_STATUS(x).B.XTE)

/*! @brief Format value for bitfield SIM_XMT_STATUS_XTE. */
#define BF_SIM_XMT_STATUS_XTE(v) ((uint32_t)((uint32_t)(v) << BP_SIM_XMT_STATUS_XTE) & BM_SIM_XMT_STATUS_XTE)

/*! @brief Set the XTE field to a new value. */
#define BW_SIM_XMT_STATUS_XTE(x, v) (HW_SIM_XMT_STATUS_WR(x, (HW_SIM_XMT_STATUS_RD(x) & ~(BM_SIM_XMT_STATUS_XTE | BM_SIM_XMT_STATUS_TFE | BM_SIM_XMT_STATUS_ETC | BM_SIM_XMT_STATUS_TC | BM_SIM_XMT_STATUS_TFO | BM_SIM_XMT_STATUS_TDTF | BM_SIM_XMT_STATUS_GPCNT)) | BF_SIM_XMT_STATUS_XTE(v)))
/*@}*/

/*!
 * @name Register SIM_XMT_STATUS, field TFE[3] (W1C)
 *
 * Transmit FIFO Empty. Used to indicate that the SIM transmit FIFO has emptied.
 * This bit will be set when the last byte in the transmit FIFO has been
 * transferred to the SIM transmitter shift register. The TFE flag will create an
 * interrupt if TFEIM in the INT_MASK register is low. The TFE bit is a
 * write-one-to-clear bit.
 *
 * Values:
 * - 0 - Transmit FIFO is not empty
 * - 1 - Transmit FIFO is empty (default)
 */
/*@{*/
#define BP_SIM_XMT_STATUS_TFE (3U)         /*!< Bit position for SIM_XMT_STATUS_TFE. */
#define BM_SIM_XMT_STATUS_TFE (0x00000008U) /*!< Bit mask for SIM_XMT_STATUS_TFE. */
#define BS_SIM_XMT_STATUS_TFE (1U)         /*!< Bit field size in bits for SIM_XMT_STATUS_TFE. */

/*! @brief Read current value of the SIM_XMT_STATUS_TFE field. */
#define BR_SIM_XMT_STATUS_TFE(x) (HW_SIM_XMT_STATUS(x).B.TFE)

/*! @brief Format value for bitfield SIM_XMT_STATUS_TFE. */
#define BF_SIM_XMT_STATUS_TFE(v) ((uint32_t)((uint32_t)(v) << BP_SIM_XMT_STATUS_TFE) & BM_SIM_XMT_STATUS_TFE)

/*! @brief Set the TFE field to a new value. */
#define BW_SIM_XMT_STATUS_TFE(x, v) (HW_SIM_XMT_STATUS_WR(x, (HW_SIM_XMT_STATUS_RD(x) & ~(BM_SIM_XMT_STATUS_TFE | BM_SIM_XMT_STATUS_XTE | BM_SIM_XMT_STATUS_ETC | BM_SIM_XMT_STATUS_TC | BM_SIM_XMT_STATUS_TFO | BM_SIM_XMT_STATUS_TDTF | BM_SIM_XMT_STATUS_GPCNT)) | BF_SIM_XMT_STATUS_TFE(v)))
/*@}*/

/*!
 * @name Register SIM_XMT_STATUS, field ETC[4] (W1C)
 *
 * Early Transmit Complete. Used to indicate that the SIM transmitter has
 * finished sending the current byte and the transmit FIFO is empty. This bit differs
 * from the tc bit in that it is set before the guard time of the last byte has
 * elapsed. The ETC flag will create an interrupt if ETCIM in the INT_MASK register
 * is low. The ETC bit is a write-one-to-clear bit.
 *
 * Values:
 * - 0 - Transmit pending or in progress
 * - 1 - Transmit complete (default)
 */
/*@{*/
#define BP_SIM_XMT_STATUS_ETC (4U)         /*!< Bit position for SIM_XMT_STATUS_ETC. */
#define BM_SIM_XMT_STATUS_ETC (0x00000010U) /*!< Bit mask for SIM_XMT_STATUS_ETC. */
#define BS_SIM_XMT_STATUS_ETC (1U)         /*!< Bit field size in bits for SIM_XMT_STATUS_ETC. */

/*! @brief Read current value of the SIM_XMT_STATUS_ETC field. */
#define BR_SIM_XMT_STATUS_ETC(x) (HW_SIM_XMT_STATUS(x).B.ETC)

/*! @brief Format value for bitfield SIM_XMT_STATUS_ETC. */
#define BF_SIM_XMT_STATUS_ETC(v) ((uint32_t)((uint32_t)(v) << BP_SIM_XMT_STATUS_ETC) & BM_SIM_XMT_STATUS_ETC)

/*! @brief Set the ETC field to a new value. */
#define BW_SIM_XMT_STATUS_ETC(x, v) (HW_SIM_XMT_STATUS_WR(x, (HW_SIM_XMT_STATUS_RD(x) & ~(BM_SIM_XMT_STATUS_ETC | BM_SIM_XMT_STATUS_XTE | BM_SIM_XMT_STATUS_TFE | BM_SIM_XMT_STATUS_TC | BM_SIM_XMT_STATUS_TFO | BM_SIM_XMT_STATUS_TDTF | BM_SIM_XMT_STATUS_GPCNT)) | BF_SIM_XMT_STATUS_ETC(v)))
/*@}*/

/*!
 * @name Register SIM_XMT_STATUS, field TC[5] (W1C)
 *
 * Transmit Complete. Used to indicate whether the SIM transmitter is ready for
 * a new transmission. The tc flag becomes set after the guard time has expired
 * for the last byte in the transmit FIFO. The tc flag will create an interrupt if
 * tcim in the INT_MASK register is low. The tc bit is a write-one-to-clear bit.
 *
 * Values:
 * - 0 - Transmit pending or in progress
 * - 1 - Transmit complete (default)
 */
/*@{*/
#define BP_SIM_XMT_STATUS_TC (5U)          /*!< Bit position for SIM_XMT_STATUS_TC. */
#define BM_SIM_XMT_STATUS_TC (0x00000020U) /*!< Bit mask for SIM_XMT_STATUS_TC. */
#define BS_SIM_XMT_STATUS_TC (1U)          /*!< Bit field size in bits for SIM_XMT_STATUS_TC. */

/*! @brief Read current value of the SIM_XMT_STATUS_TC field. */
#define BR_SIM_XMT_STATUS_TC(x) (HW_SIM_XMT_STATUS(x).B.TC)

/*! @brief Format value for bitfield SIM_XMT_STATUS_TC. */
#define BF_SIM_XMT_STATUS_TC(v) ((uint32_t)((uint32_t)(v) << BP_SIM_XMT_STATUS_TC) & BM_SIM_XMT_STATUS_TC)

/*! @brief Set the TC field to a new value. */
#define BW_SIM_XMT_STATUS_TC(x, v) (HW_SIM_XMT_STATUS_WR(x, (HW_SIM_XMT_STATUS_RD(x) & ~(BM_SIM_XMT_STATUS_TC | BM_SIM_XMT_STATUS_XTE | BM_SIM_XMT_STATUS_TFE | BM_SIM_XMT_STATUS_ETC | BM_SIM_XMT_STATUS_TFO | BM_SIM_XMT_STATUS_TDTF | BM_SIM_XMT_STATUS_GPCNT)) | BF_SIM_XMT_STATUS_TC(v)))
/*@}*/

/*!
 * @name Register SIM_XMT_STATUS, field TFO[6] (W1C)
 *
 * Transmit FIFO Overfill Error. Used to indicate when the Transmit FIFO has
 * been written with more than 16 bytes. The tfo bit can only be cleared by setting
 * the flush_xmt or soft_reset bit in the RESET_CNTL register.
 *
 * Values:
 * - 0 - No transmit FIFO overfill error has occurred (default).
 * - 1 - A Transmit FIFO overfill error has occurred.
 */
/*@{*/
#define BP_SIM_XMT_STATUS_TFO (6U)         /*!< Bit position for SIM_XMT_STATUS_TFO. */
#define BM_SIM_XMT_STATUS_TFO (0x00000040U) /*!< Bit mask for SIM_XMT_STATUS_TFO. */
#define BS_SIM_XMT_STATUS_TFO (1U)         /*!< Bit field size in bits for SIM_XMT_STATUS_TFO. */

/*! @brief Read current value of the SIM_XMT_STATUS_TFO field. */
#define BR_SIM_XMT_STATUS_TFO(x) (HW_SIM_XMT_STATUS(x).B.TFO)

/*! @brief Format value for bitfield SIM_XMT_STATUS_TFO. */
#define BF_SIM_XMT_STATUS_TFO(v) ((uint32_t)((uint32_t)(v) << BP_SIM_XMT_STATUS_TFO) & BM_SIM_XMT_STATUS_TFO)

/*! @brief Set the TFO field to a new value. */
#define BW_SIM_XMT_STATUS_TFO(x, v) (HW_SIM_XMT_STATUS_WR(x, (HW_SIM_XMT_STATUS_RD(x) & ~(BM_SIM_XMT_STATUS_TFO | BM_SIM_XMT_STATUS_XTE | BM_SIM_XMT_STATUS_TFE | BM_SIM_XMT_STATUS_ETC | BM_SIM_XMT_STATUS_TC | BM_SIM_XMT_STATUS_TDTF | BM_SIM_XMT_STATUS_GPCNT)) | BF_SIM_XMT_STATUS_TFO(v)))
/*@}*/

/*!
 * @name Register SIM_XMT_STATUS, field TDTF[7] (W1C)
 *
 * Transmit Data Threshold Flag. Used to indicate when the number of bytes in
 * the transmit FIFO is less than or equal to the value programmed in the tdt[3:0]
 * bits in the XMT_THRESHOLD register.
 *
 * Values:
 * - 0 - Number of bytes in FIFO is greater than tdt[3:0], or bit has been
 *     cleared.
 * - 1 - Number of bytes in FIFO is less than or equal to tdt[3:0] (default)
 */
/*@{*/
#define BP_SIM_XMT_STATUS_TDTF (7U)        /*!< Bit position for SIM_XMT_STATUS_TDTF. */
#define BM_SIM_XMT_STATUS_TDTF (0x00000080U) /*!< Bit mask for SIM_XMT_STATUS_TDTF. */
#define BS_SIM_XMT_STATUS_TDTF (1U)        /*!< Bit field size in bits for SIM_XMT_STATUS_TDTF. */

/*! @brief Read current value of the SIM_XMT_STATUS_TDTF field. */
#define BR_SIM_XMT_STATUS_TDTF(x) (HW_SIM_XMT_STATUS(x).B.TDTF)

/*! @brief Format value for bitfield SIM_XMT_STATUS_TDTF. */
#define BF_SIM_XMT_STATUS_TDTF(v) ((uint32_t)((uint32_t)(v) << BP_SIM_XMT_STATUS_TDTF) & BM_SIM_XMT_STATUS_TDTF)

/*! @brief Set the TDTF field to a new value. */
#define BW_SIM_XMT_STATUS_TDTF(x, v) (HW_SIM_XMT_STATUS_WR(x, (HW_SIM_XMT_STATUS_RD(x) & ~(BM_SIM_XMT_STATUS_TDTF | BM_SIM_XMT_STATUS_XTE | BM_SIM_XMT_STATUS_TFE | BM_SIM_XMT_STATUS_ETC | BM_SIM_XMT_STATUS_TC | BM_SIM_XMT_STATUS_TFO | BM_SIM_XMT_STATUS_GPCNT)) | BF_SIM_XMT_STATUS_TDTF(v)))
/*@}*/

/*!
 * @name Register SIM_XMT_STATUS, field GPCNT[8] (W1C)
 *
 * General purpose Counter Flag. Used to indicate when the General purpose
 * counter has reached the value in the GPCNT register.
 *
 * Values:
 * - 0 - GPCNT time not reached, or bit has been cleared. (default).
 * - 1 - General Purpose counter has reached the GPCNT value.
 */
/*@{*/
#define BP_SIM_XMT_STATUS_GPCNT (8U)       /*!< Bit position for SIM_XMT_STATUS_GPCNT. */
#define BM_SIM_XMT_STATUS_GPCNT (0x00000100U) /*!< Bit mask for SIM_XMT_STATUS_GPCNT. */
#define BS_SIM_XMT_STATUS_GPCNT (1U)       /*!< Bit field size in bits for SIM_XMT_STATUS_GPCNT. */

/*! @brief Read current value of the SIM_XMT_STATUS_GPCNT field. */
#define BR_SIM_XMT_STATUS_GPCNT(x) (HW_SIM_XMT_STATUS(x).B.GPCNT)

/*! @brief Format value for bitfield SIM_XMT_STATUS_GPCNT. */
#define BF_SIM_XMT_STATUS_GPCNT(v) ((uint32_t)((uint32_t)(v) << BP_SIM_XMT_STATUS_GPCNT) & BM_SIM_XMT_STATUS_GPCNT)

/*! @brief Set the GPCNT field to a new value. */
#define BW_SIM_XMT_STATUS_GPCNT(x, v) (HW_SIM_XMT_STATUS_WR(x, (HW_SIM_XMT_STATUS_RD(x) & ~(BM_SIM_XMT_STATUS_GPCNT | BM_SIM_XMT_STATUS_XTE | BM_SIM_XMT_STATUS_TFE | BM_SIM_XMT_STATUS_ETC | BM_SIM_XMT_STATUS_TC | BM_SIM_XMT_STATUS_TFO | BM_SIM_XMT_STATUS_TDTF)) | BF_SIM_XMT_STATUS_GPCNT(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_RCV_STATUS - SIM Receive Status Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_RCV_STATUS - SIM Receive Status Register (RW)
 *
 * Reset value: 0x00000042U
 *
 * See the figure below for illustration of valid bits in the SIM Receive Status
 * Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_rcv_status
{
    uint32_t U;
    struct _hw_sim_rcv_status_bitfields
    {
        uint32_t OEF : 1;              /*!< [0]  */
        uint32_t RFE : 1;              /*!< [1]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t RFD : 1;              /*!< [4]  */
        uint32_t RDRF : 1;             /*!< [5]  */
        uint32_t LRCOK : 1;            /*!< [6]  */
        uint32_t CRCOK : 1;            /*!< [7]  */
        uint32_t CWT : 1;              /*!< [8]  */
        uint32_t RTE : 1;              /*!< [9]  */
        uint32_t BWT : 1;              /*!< [10]  */
        uint32_t BGT : 1;              /*!< [11]  */
        uint32_t RESERVED1 : 20;       /*!< [31:12]  */
    } B;
} hw_sim_rcv_status_t;

/*!
 * @name Constants and macros for entire SIM_RCV_STATUS register
 */
/*@{*/
#define HW_SIM_RCV_STATUS_ADDR(x) ((uintptr_t)(x) + 0x2CU)

#define HW_SIM_RCV_STATUS(x)     (*(__IO hw_sim_rcv_status_t *) HW_SIM_RCV_STATUS_ADDR(x))
#define HW_SIM_RCV_STATUS_RD(x)  (HW_SIM_RCV_STATUS(x).U)
#define HW_SIM_RCV_STATUS_WR(x, v) (HW_SIM_RCV_STATUS(x).U = (v))
#define HW_SIM_RCV_STATUS_SET(x, v) (HW_SIM_RCV_STATUS_WR(x, HW_SIM_RCV_STATUS_RD(x) |  (v)))
#define HW_SIM_RCV_STATUS_CLR(x, v) (HW_SIM_RCV_STATUS_WR(x, HW_SIM_RCV_STATUS_RD(x) & ~(v)))
#define HW_SIM_RCV_STATUS_TOG(x, v) (HW_SIM_RCV_STATUS_WR(x, HW_SIM_RCV_STATUS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_RCV_STATUS bitfields
 */

/*!
 * @name Register SIM_RCV_STATUS, field OEF[0] (W1C)
 *
 * Overrun Error Flag. Used to indicate that the SIM was unable to store
 * received data due to already having 288 unread bytes in the FIFO. It does not
 * necessarily indicate that data has been lost. If the ONACK control bit in the CNTL
 * register is set, there will be a NACK pulse generated on bytes that would
 * otherwise cause a loss of data due to a full FIFO. These bytes should be
 * retransmitted by the SIM card which implies that no data has actually been lost. In this
 * case, the OEF flag is just an indicator that this situation has occurred which
 * may be helpful in system debug. For the case where ONACK is not set, a set
 * OEF flag does indicate a loss of data since all bytes received with the OEF flag
 * set will indeed be lost (including the byte that caused the bit to be set).
 * The OEF flag will cause an interrupt if the oim bit in the INT_MASK register.
 * The OEF flag is a write-one-to-clear bit.
 *
 * Values:
 * - 0 - No overrun error has occurred (default).
 * - 1 - A byte was received when the received FIFO was already full.
 */
/*@{*/
#define BP_SIM_RCV_STATUS_OEF (0U)         /*!< Bit position for SIM_RCV_STATUS_OEF. */
#define BM_SIM_RCV_STATUS_OEF (0x00000001U) /*!< Bit mask for SIM_RCV_STATUS_OEF. */
#define BS_SIM_RCV_STATUS_OEF (1U)         /*!< Bit field size in bits for SIM_RCV_STATUS_OEF. */

/*! @brief Read current value of the SIM_RCV_STATUS_OEF field. */
#define BR_SIM_RCV_STATUS_OEF(x) (HW_SIM_RCV_STATUS(x).B.OEF)

/*! @brief Format value for bitfield SIM_RCV_STATUS_OEF. */
#define BF_SIM_RCV_STATUS_OEF(v) ((uint32_t)((uint32_t)(v) << BP_SIM_RCV_STATUS_OEF) & BM_SIM_RCV_STATUS_OEF)

/*! @brief Set the OEF field to a new value. */
#define BW_SIM_RCV_STATUS_OEF(x, v) (HW_SIM_RCV_STATUS_WR(x, (HW_SIM_RCV_STATUS_RD(x) & ~(BM_SIM_RCV_STATUS_OEF | BM_SIM_RCV_STATUS_RFE | BM_SIM_RCV_STATUS_RDRF | BM_SIM_RCV_STATUS_CWT | BM_SIM_RCV_STATUS_RTE | BM_SIM_RCV_STATUS_BWT | BM_SIM_RCV_STATUS_BGT)) | BF_SIM_RCV_STATUS_OEF(v)))
/*@}*/

/*!
 * @name Register SIM_RCV_STATUS, field RFE[1] (W1C)
 *
 * Receive FIFO Empty. Used to indicate that the SIM receive FIFO has emptied.
 * This bit will be set when the last byte in the receive FIFO has been
 * transferred to the IPS bus. The RFE flag will create an interrupt if RFEIM in the
 * INT_MASK register is low. The RFE bit is a write-one-to-clear bit.
 *
 * Values:
 * - 0 - Receive FIFO is not empty
 * - 1 - Receive FIFO is empty (default)
 */
/*@{*/
#define BP_SIM_RCV_STATUS_RFE (1U)         /*!< Bit position for SIM_RCV_STATUS_RFE. */
#define BM_SIM_RCV_STATUS_RFE (0x00000002U) /*!< Bit mask for SIM_RCV_STATUS_RFE. */
#define BS_SIM_RCV_STATUS_RFE (1U)         /*!< Bit field size in bits for SIM_RCV_STATUS_RFE. */

/*! @brief Read current value of the SIM_RCV_STATUS_RFE field. */
#define BR_SIM_RCV_STATUS_RFE(x) (HW_SIM_RCV_STATUS(x).B.RFE)

/*! @brief Format value for bitfield SIM_RCV_STATUS_RFE. */
#define BF_SIM_RCV_STATUS_RFE(v) ((uint32_t)((uint32_t)(v) << BP_SIM_RCV_STATUS_RFE) & BM_SIM_RCV_STATUS_RFE)

/*! @brief Set the RFE field to a new value. */
#define BW_SIM_RCV_STATUS_RFE(x, v) (HW_SIM_RCV_STATUS_WR(x, (HW_SIM_RCV_STATUS_RD(x) & ~(BM_SIM_RCV_STATUS_RFE | BM_SIM_RCV_STATUS_OEF | BM_SIM_RCV_STATUS_RDRF | BM_SIM_RCV_STATUS_CWT | BM_SIM_RCV_STATUS_RTE | BM_SIM_RCV_STATUS_BWT | BM_SIM_RCV_STATUS_BGT)) | BF_SIM_RCV_STATUS_RFE(v)))
/*@}*/

/*!
 * @name Register SIM_RCV_STATUS, field RFD[4] (RO)
 *
 * Receive FIFO has unread Data. Used to indicate that there is at least one
 * unread byte in the receive data FIFO. Can only be cleared by reading all bytes
 * out of the receive FIFO. The RFD bit cannot be used to create an interrupt.
 * Normally, the SIM triggers the interrupt with RDRF and software uses rfd to read
 * all of the bytes out of the receive FIFO.
 *
 * Values:
 * - 0 - There are no unread bytes in the receive FIFO (default).
 * - 1 - There is at least one unread byte in the receiver FIFO.
 */
/*@{*/
#define BP_SIM_RCV_STATUS_RFD (4U)         /*!< Bit position for SIM_RCV_STATUS_RFD. */
#define BM_SIM_RCV_STATUS_RFD (0x00000010U) /*!< Bit mask for SIM_RCV_STATUS_RFD. */
#define BS_SIM_RCV_STATUS_RFD (1U)         /*!< Bit field size in bits for SIM_RCV_STATUS_RFD. */

/*! @brief Read current value of the SIM_RCV_STATUS_RFD field. */
#define BR_SIM_RCV_STATUS_RFD(x) (HW_SIM_RCV_STATUS(x).B.RFD)
/*@}*/

/*!
 * @name Register SIM_RCV_STATUS, field RDRF[5] (W1C)
 *
 * Receive Data Register Full. Used to indicate when the number of bytes in the
 * receive FIFO is more than or equal to the value programed in the RDT[8:0] in
 * the RCV_THRESHOLD register.
 *
 * Values:
 * - 0 - Number of unread bytes in receive buffer < value set by RDT[8:0]
 *     (default), or bit has been cleared.
 * - 1 - Number of unread bytes in receive buffer >= value set by RDT[8:0].
 */
/*@{*/
#define BP_SIM_RCV_STATUS_RDRF (5U)        /*!< Bit position for SIM_RCV_STATUS_RDRF. */
#define BM_SIM_RCV_STATUS_RDRF (0x00000020U) /*!< Bit mask for SIM_RCV_STATUS_RDRF. */
#define BS_SIM_RCV_STATUS_RDRF (1U)        /*!< Bit field size in bits for SIM_RCV_STATUS_RDRF. */

/*! @brief Read current value of the SIM_RCV_STATUS_RDRF field. */
#define BR_SIM_RCV_STATUS_RDRF(x) (HW_SIM_RCV_STATUS(x).B.RDRF)

/*! @brief Format value for bitfield SIM_RCV_STATUS_RDRF. */
#define BF_SIM_RCV_STATUS_RDRF(v) ((uint32_t)((uint32_t)(v) << BP_SIM_RCV_STATUS_RDRF) & BM_SIM_RCV_STATUS_RDRF)

/*! @brief Set the RDRF field to a new value. */
#define BW_SIM_RCV_STATUS_RDRF(x, v) (HW_SIM_RCV_STATUS_WR(x, (HW_SIM_RCV_STATUS_RD(x) & ~(BM_SIM_RCV_STATUS_RDRF | BM_SIM_RCV_STATUS_OEF | BM_SIM_RCV_STATUS_RFE | BM_SIM_RCV_STATUS_CWT | BM_SIM_RCV_STATUS_RTE | BM_SIM_RCV_STATUS_BWT | BM_SIM_RCV_STATUS_BGT)) | BF_SIM_RCV_STATUS_RDRF(v)))
/*@}*/

/*!
 * @name Register SIM_RCV_STATUS, field LRCOK[6] (RO)
 *
 * Linear Redundancy Check Okay flag. Used to indicate when the calculated 8-bit
 * LRC value is zero value for the current input data stream. The value is
 * calculated across all received characters from the point the LRCEN bit is set in
 * the CNTL register. The current LRC residual can be reset by three mechanisms:
 * Clear LRCEN bit in CNTL register Set XMT_EN bit in ENABLE register Automatically
 * by hardware when ETC flag is set at the end of a transmission.
 *
 * Values:
 * - 0 - Current LRC value does not match remainder.
 * - 1 - Current calculated LRC value matches the expected result (that is,
 *     zero).
 */
/*@{*/
#define BP_SIM_RCV_STATUS_LRCOK (6U)       /*!< Bit position for SIM_RCV_STATUS_LRCOK. */
#define BM_SIM_RCV_STATUS_LRCOK (0x00000040U) /*!< Bit mask for SIM_RCV_STATUS_LRCOK. */
#define BS_SIM_RCV_STATUS_LRCOK (1U)       /*!< Bit field size in bits for SIM_RCV_STATUS_LRCOK. */

/*! @brief Read current value of the SIM_RCV_STATUS_LRCOK field. */
#define BR_SIM_RCV_STATUS_LRCOK(x) (HW_SIM_RCV_STATUS(x).B.LRCOK)
/*@}*/

/*!
 * @name Register SIM_RCV_STATUS, field CRCOK[7] (RO)
 *
 * Cyclic Redundancy Check Okay flag. Used to indicate when the calculated
 * 16-bit CRC value matches the expected value for the current input data stream. The
 * value is calculated across all received characters from the point the CRCEN
 * bit is set in the CNTL register. The current CRC residual can be reset by three
 * mechanisms: Clear CRCEN bit in CNTL register Set XMT_EN bit in ENABLE register
 * Automatically by hardware when ETC flag is set at the end of a transmission.
 *
 * Values:
 * - 0 - Current CRC value does not match remainder.
 * - 1 - Current calculated CRC value matches the expected result.
 */
/*@{*/
#define BP_SIM_RCV_STATUS_CRCOK (7U)       /*!< Bit position for SIM_RCV_STATUS_CRCOK. */
#define BM_SIM_RCV_STATUS_CRCOK (0x00000080U) /*!< Bit mask for SIM_RCV_STATUS_CRCOK. */
#define BS_SIM_RCV_STATUS_CRCOK (1U)       /*!< Bit field size in bits for SIM_RCV_STATUS_CRCOK. */

/*! @brief Read current value of the SIM_RCV_STATUS_CRCOK field. */
#define BR_SIM_RCV_STATUS_CRCOK(x) (HW_SIM_RCV_STATUS(x).B.CRCOK)
/*@}*/

/*!
 * @name Register SIM_RCV_STATUS, field CWT[8] (W1C)
 *
 * Character Wait Time Counter Flag. Used to indicate when the time between
 * received characters is equal to or greater than the value programmed in the
 * CHAR_WAIT register.
 *
 * Values:
 * - 0 - No CWT violation has occurred (default).
 * - 1 - Time between two consecutive characters exceeded the value in CHAR_WAIT.
 */
/*@{*/
#define BP_SIM_RCV_STATUS_CWT (8U)         /*!< Bit position for SIM_RCV_STATUS_CWT. */
#define BM_SIM_RCV_STATUS_CWT (0x00000100U) /*!< Bit mask for SIM_RCV_STATUS_CWT. */
#define BS_SIM_RCV_STATUS_CWT (1U)         /*!< Bit field size in bits for SIM_RCV_STATUS_CWT. */

/*! @brief Read current value of the SIM_RCV_STATUS_CWT field. */
#define BR_SIM_RCV_STATUS_CWT(x) (HW_SIM_RCV_STATUS(x).B.CWT)

/*! @brief Format value for bitfield SIM_RCV_STATUS_CWT. */
#define BF_SIM_RCV_STATUS_CWT(v) ((uint32_t)((uint32_t)(v) << BP_SIM_RCV_STATUS_CWT) & BM_SIM_RCV_STATUS_CWT)

/*! @brief Set the CWT field to a new value. */
#define BW_SIM_RCV_STATUS_CWT(x, v) (HW_SIM_RCV_STATUS_WR(x, (HW_SIM_RCV_STATUS_RD(x) & ~(BM_SIM_RCV_STATUS_CWT | BM_SIM_RCV_STATUS_OEF | BM_SIM_RCV_STATUS_RFE | BM_SIM_RCV_STATUS_RDRF | BM_SIM_RCV_STATUS_RTE | BM_SIM_RCV_STATUS_BWT | BM_SIM_RCV_STATUS_BGT)) | BF_SIM_RCV_STATUS_CWT(v)))
/*@}*/

/*!
 * @name Register SIM_RCV_STATUS, field RTE[9] (W1C)
 *
 * Receive NACK threshold error flag. Used to indicate whether the number of
 * consecutive NACKs generated by the SIM module in response to receive parity
 * errors, for the byte being received, equals the value programmed in the RTH[3:0] in
 * the RCV_THRESHOLD register. This bit would never be set unless the ANACK bit
 * is set in the CNTL register. The SAPDx bit in the PORTx_CNTL resister must be
 * set to enable the threshold error to trigger the auto power down sequence. RTE
 * is a write-one-to-clear bit. Clearing this bit also resets the internal
 * counter for consecutive NACKs being transmitted for a given byte.
 *
 * Values:
 * - 0 - Number of NACKs generated by the receiver is less than the value
 *     programmed in RTH[3:0]
 * - 1 - Number of NACKs generated by the receiver is equal to the value
 *     programmed in RTH[3:0]
 */
/*@{*/
#define BP_SIM_RCV_STATUS_RTE (9U)         /*!< Bit position for SIM_RCV_STATUS_RTE. */
#define BM_SIM_RCV_STATUS_RTE (0x00000200U) /*!< Bit mask for SIM_RCV_STATUS_RTE. */
#define BS_SIM_RCV_STATUS_RTE (1U)         /*!< Bit field size in bits for SIM_RCV_STATUS_RTE. */

/*! @brief Read current value of the SIM_RCV_STATUS_RTE field. */
#define BR_SIM_RCV_STATUS_RTE(x) (HW_SIM_RCV_STATUS(x).B.RTE)

/*! @brief Format value for bitfield SIM_RCV_STATUS_RTE. */
#define BF_SIM_RCV_STATUS_RTE(v) ((uint32_t)((uint32_t)(v) << BP_SIM_RCV_STATUS_RTE) & BM_SIM_RCV_STATUS_RTE)

/*! @brief Set the RTE field to a new value. */
#define BW_SIM_RCV_STATUS_RTE(x, v) (HW_SIM_RCV_STATUS_WR(x, (HW_SIM_RCV_STATUS_RD(x) & ~(BM_SIM_RCV_STATUS_RTE | BM_SIM_RCV_STATUS_OEF | BM_SIM_RCV_STATUS_RFE | BM_SIM_RCV_STATUS_RDRF | BM_SIM_RCV_STATUS_CWT | BM_SIM_RCV_STATUS_BWT | BM_SIM_RCV_STATUS_BGT)) | BF_SIM_RCV_STATUS_RTE(v)))
/*@}*/

/*!
 * @name Register SIM_RCV_STATUS, field BWT[10] (W1C)
 *
 * Block wait time error flag. Used to indicate if the block wait time has been
 * exceeded. The threshold is set by the block wait time registers.
 *
 * Values:
 * - 0 - Block wait time not exceeded.
 * - 1 - Block wait time was exceeded.
 */
/*@{*/
#define BP_SIM_RCV_STATUS_BWT (10U)        /*!< Bit position for SIM_RCV_STATUS_BWT. */
#define BM_SIM_RCV_STATUS_BWT (0x00000400U) /*!< Bit mask for SIM_RCV_STATUS_BWT. */
#define BS_SIM_RCV_STATUS_BWT (1U)         /*!< Bit field size in bits for SIM_RCV_STATUS_BWT. */

/*! @brief Read current value of the SIM_RCV_STATUS_BWT field. */
#define BR_SIM_RCV_STATUS_BWT(x) (HW_SIM_RCV_STATUS(x).B.BWT)

/*! @brief Format value for bitfield SIM_RCV_STATUS_BWT. */
#define BF_SIM_RCV_STATUS_BWT(v) ((uint32_t)((uint32_t)(v) << BP_SIM_RCV_STATUS_BWT) & BM_SIM_RCV_STATUS_BWT)

/*! @brief Set the BWT field to a new value. */
#define BW_SIM_RCV_STATUS_BWT(x, v) (HW_SIM_RCV_STATUS_WR(x, (HW_SIM_RCV_STATUS_RD(x) & ~(BM_SIM_RCV_STATUS_BWT | BM_SIM_RCV_STATUS_OEF | BM_SIM_RCV_STATUS_RFE | BM_SIM_RCV_STATUS_RDRF | BM_SIM_RCV_STATUS_CWT | BM_SIM_RCV_STATUS_RTE | BM_SIM_RCV_STATUS_BGT)) | BF_SIM_RCV_STATUS_BWT(v)))
/*@}*/

/*!
 * @name Register SIM_RCV_STATUS, field BGT[11] (W1C)
 *
 * Block guard time error flag. Used to indicate if the block guard time was too
 * small. The threshold is set by the block guard time register.
 *
 * Values:
 * - 0 - Block guard time was sufficient.
 * - 1 - Block guard time was too small.
 */
/*@{*/
#define BP_SIM_RCV_STATUS_BGT (11U)        /*!< Bit position for SIM_RCV_STATUS_BGT. */
#define BM_SIM_RCV_STATUS_BGT (0x00000800U) /*!< Bit mask for SIM_RCV_STATUS_BGT. */
#define BS_SIM_RCV_STATUS_BGT (1U)         /*!< Bit field size in bits for SIM_RCV_STATUS_BGT. */

/*! @brief Read current value of the SIM_RCV_STATUS_BGT field. */
#define BR_SIM_RCV_STATUS_BGT(x) (HW_SIM_RCV_STATUS(x).B.BGT)

/*! @brief Format value for bitfield SIM_RCV_STATUS_BGT. */
#define BF_SIM_RCV_STATUS_BGT(v) ((uint32_t)((uint32_t)(v) << BP_SIM_RCV_STATUS_BGT) & BM_SIM_RCV_STATUS_BGT)

/*! @brief Set the BGT field to a new value. */
#define BW_SIM_RCV_STATUS_BGT(x, v) (HW_SIM_RCV_STATUS_WR(x, (HW_SIM_RCV_STATUS_RD(x) & ~(BM_SIM_RCV_STATUS_BGT | BM_SIM_RCV_STATUS_OEF | BM_SIM_RCV_STATUS_RFE | BM_SIM_RCV_STATUS_RDRF | BM_SIM_RCV_STATUS_CWT | BM_SIM_RCV_STATUS_RTE | BM_SIM_RCV_STATUS_BWT)) | BF_SIM_RCV_STATUS_BGT(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_INT_MASK - SIM Interrupt Mask Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_INT_MASK - SIM Interrupt Mask Register (RW)
 *
 * Reset value: 0x00003FFFU
 *
 * See the figure below for illustration of valid bits in the SIM Interrupt Mask
 * Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_int_mask
{
    uint32_t U;
    struct _hw_sim_int_mask_bitfields
    {
        uint32_t RIM : 1;              /*!< [0]  */
        uint32_t TCIM : 1;             /*!< [1]  */
        uint32_t OIM : 1;              /*!< [2]  */
        uint32_t ETCIM : 1;            /*!< [3]  */
        uint32_t TFEIM : 1;            /*!< [4]  */
        uint32_t XTM : 1;              /*!< [5]  */
        uint32_t TFOM : 1;             /*!< [6]  */
        uint32_t TDTFM : 1;            /*!< [7]  */
        uint32_t GPCNTM : 1;           /*!< [8]  */
        uint32_t CWTM : 1;             /*!< [9]  */
        uint32_t RTM : 1;              /*!< [10]  */
        uint32_t BWTM : 1;             /*!< [11]  */
        uint32_t BGTM : 1;             /*!< [12]  */
        uint32_t RFEM : 1;             /*!< [13]  */
        uint32_t RESERVED0 : 18;       /*!< [31:14]  */
    } B;
} hw_sim_int_mask_t;

/*!
 * @name Constants and macros for entire SIM_INT_MASK register
 */
/*@{*/
#define HW_SIM_INT_MASK_ADDR(x)  ((uintptr_t)(x) + 0x30U)

#define HW_SIM_INT_MASK(x)       (*(__IO hw_sim_int_mask_t *) HW_SIM_INT_MASK_ADDR(x))
#define HW_SIM_INT_MASK_RD(x)    (HW_SIM_INT_MASK(x).U)
#define HW_SIM_INT_MASK_WR(x, v) (HW_SIM_INT_MASK(x).U = (v))
#define HW_SIM_INT_MASK_SET(x, v) (HW_SIM_INT_MASK_WR(x, HW_SIM_INT_MASK_RD(x) |  (v)))
#define HW_SIM_INT_MASK_CLR(x, v) (HW_SIM_INT_MASK_WR(x, HW_SIM_INT_MASK_RD(x) & ~(v)))
#define HW_SIM_INT_MASK_TOG(x, v) (HW_SIM_INT_MASK_WR(x, HW_SIM_INT_MASK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_INT_MASK bitfields
 */

/*!
 * @name Register SIM_INT_MASK, field RIM[0] (RW)
 *
 * Receive Interrupt Mask. Used to enable/disable the ability of the RDRF flag
 * in the RCV_STATUS register to generate SIM interrupts.
 *
 * Values:
 * - 0 - RDRF interrupt enabled
 * - 1 - RDRF interrupt masked (default)
 */
/*@{*/
#define BP_SIM_INT_MASK_RIM  (0U)          /*!< Bit position for SIM_INT_MASK_RIM. */
#define BM_SIM_INT_MASK_RIM  (0x00000001U) /*!< Bit mask for SIM_INT_MASK_RIM. */
#define BS_SIM_INT_MASK_RIM  (1U)          /*!< Bit field size in bits for SIM_INT_MASK_RIM. */

/*! @brief Read current value of the SIM_INT_MASK_RIM field. */
#define BR_SIM_INT_MASK_RIM(x) (HW_SIM_INT_MASK(x).B.RIM)

/*! @brief Format value for bitfield SIM_INT_MASK_RIM. */
#define BF_SIM_INT_MASK_RIM(v) ((uint32_t)((uint32_t)(v) << BP_SIM_INT_MASK_RIM) & BM_SIM_INT_MASK_RIM)

/*! @brief Set the RIM field to a new value. */
#define BW_SIM_INT_MASK_RIM(x, v) (HW_SIM_INT_MASK_WR(x, (HW_SIM_INT_MASK_RD(x) & ~BM_SIM_INT_MASK_RIM) | BF_SIM_INT_MASK_RIM(v)))
/*@}*/

/*!
 * @name Register SIM_INT_MASK, field TCIM[1] (RW)
 *
 * Transmit Complete Interrupt Mask. Used to enable/disable the ability of the
 * TC flag in the XMT_STATUS register to generate SIM interrupts.
 *
 * Values:
 * - 0 - TC interrupt enabled
 * - 1 - TC interrupt masked (default)
 */
/*@{*/
#define BP_SIM_INT_MASK_TCIM (1U)          /*!< Bit position for SIM_INT_MASK_TCIM. */
#define BM_SIM_INT_MASK_TCIM (0x00000002U) /*!< Bit mask for SIM_INT_MASK_TCIM. */
#define BS_SIM_INT_MASK_TCIM (1U)          /*!< Bit field size in bits for SIM_INT_MASK_TCIM. */

/*! @brief Read current value of the SIM_INT_MASK_TCIM field. */
#define BR_SIM_INT_MASK_TCIM(x) (HW_SIM_INT_MASK(x).B.TCIM)

/*! @brief Format value for bitfield SIM_INT_MASK_TCIM. */
#define BF_SIM_INT_MASK_TCIM(v) ((uint32_t)((uint32_t)(v) << BP_SIM_INT_MASK_TCIM) & BM_SIM_INT_MASK_TCIM)

/*! @brief Set the TCIM field to a new value. */
#define BW_SIM_INT_MASK_TCIM(x, v) (HW_SIM_INT_MASK_WR(x, (HW_SIM_INT_MASK_RD(x) & ~BM_SIM_INT_MASK_TCIM) | BF_SIM_INT_MASK_TCIM(v)))
/*@}*/

/*!
 * @name Register SIM_INT_MASK, field OIM[2] (RW)
 *
 * Overrun Interrupt Mask. Used to enable/disable the ability of the OEF flag in
 * the RCV_STATUS register to generate SIM interrupts.
 *
 * Values:
 * - 0 - OEF interrupt enabled
 * - 1 - OEF interrupt masked (default)
 */
/*@{*/
#define BP_SIM_INT_MASK_OIM  (2U)          /*!< Bit position for SIM_INT_MASK_OIM. */
#define BM_SIM_INT_MASK_OIM  (0x00000004U) /*!< Bit mask for SIM_INT_MASK_OIM. */
#define BS_SIM_INT_MASK_OIM  (1U)          /*!< Bit field size in bits for SIM_INT_MASK_OIM. */

/*! @brief Read current value of the SIM_INT_MASK_OIM field. */
#define BR_SIM_INT_MASK_OIM(x) (HW_SIM_INT_MASK(x).B.OIM)

/*! @brief Format value for bitfield SIM_INT_MASK_OIM. */
#define BF_SIM_INT_MASK_OIM(v) ((uint32_t)((uint32_t)(v) << BP_SIM_INT_MASK_OIM) & BM_SIM_INT_MASK_OIM)

/*! @brief Set the OIM field to a new value. */
#define BW_SIM_INT_MASK_OIM(x, v) (HW_SIM_INT_MASK_WR(x, (HW_SIM_INT_MASK_RD(x) & ~BM_SIM_INT_MASK_OIM) | BF_SIM_INT_MASK_OIM(v)))
/*@}*/

/*!
 * @name Register SIM_INT_MASK, field ETCIM[3] (RW)
 *
 * Early Transmit Complete Interrupt Mask. Used to enable/disable the ability of
 * the ETC flag in the XMT_STATUS register to generate SIM interrupts.
 *
 * Values:
 * - 0 - ETC interrupt enabled
 * - 1 - ETC interrupt masked (default)
 */
/*@{*/
#define BP_SIM_INT_MASK_ETCIM (3U)         /*!< Bit position for SIM_INT_MASK_ETCIM. */
#define BM_SIM_INT_MASK_ETCIM (0x00000008U) /*!< Bit mask for SIM_INT_MASK_ETCIM. */
#define BS_SIM_INT_MASK_ETCIM (1U)         /*!< Bit field size in bits for SIM_INT_MASK_ETCIM. */

/*! @brief Read current value of the SIM_INT_MASK_ETCIM field. */
#define BR_SIM_INT_MASK_ETCIM(x) (HW_SIM_INT_MASK(x).B.ETCIM)

/*! @brief Format value for bitfield SIM_INT_MASK_ETCIM. */
#define BF_SIM_INT_MASK_ETCIM(v) ((uint32_t)((uint32_t)(v) << BP_SIM_INT_MASK_ETCIM) & BM_SIM_INT_MASK_ETCIM)

/*! @brief Set the ETCIM field to a new value. */
#define BW_SIM_INT_MASK_ETCIM(x, v) (HW_SIM_INT_MASK_WR(x, (HW_SIM_INT_MASK_RD(x) & ~BM_SIM_INT_MASK_ETCIM) | BF_SIM_INT_MASK_ETCIM(v)))
/*@}*/

/*!
 * @name Register SIM_INT_MASK, field TFEIM[4] (RW)
 *
 * Transmit FIFO Empty Interrupt Mask. Used to enable/disable the ability of the
 * TFE flag in the XMT_STATUS register to generate SIM interrupts.
 *
 * Values:
 * - 0 - TFE interrupt enabled
 * - 1 - TFE interrupt masked (default)
 */
/*@{*/
#define BP_SIM_INT_MASK_TFEIM (4U)         /*!< Bit position for SIM_INT_MASK_TFEIM. */
#define BM_SIM_INT_MASK_TFEIM (0x00000010U) /*!< Bit mask for SIM_INT_MASK_TFEIM. */
#define BS_SIM_INT_MASK_TFEIM (1U)         /*!< Bit field size in bits for SIM_INT_MASK_TFEIM. */

/*! @brief Read current value of the SIM_INT_MASK_TFEIM field. */
#define BR_SIM_INT_MASK_TFEIM(x) (HW_SIM_INT_MASK(x).B.TFEIM)

/*! @brief Format value for bitfield SIM_INT_MASK_TFEIM. */
#define BF_SIM_INT_MASK_TFEIM(v) ((uint32_t)((uint32_t)(v) << BP_SIM_INT_MASK_TFEIM) & BM_SIM_INT_MASK_TFEIM)

/*! @brief Set the TFEIM field to a new value. */
#define BW_SIM_INT_MASK_TFEIM(x, v) (HW_SIM_INT_MASK_WR(x, (HW_SIM_INT_MASK_RD(x) & ~BM_SIM_INT_MASK_TFEIM) | BF_SIM_INT_MASK_TFEIM(v)))
/*@}*/

/*!
 * @name Register SIM_INT_MASK, field XTM[5] (RW)
 *
 * Transmit Threshold Interrupt Mask. Used to enable/disable the ability of the
 * XTE flag in the XMT_STATUS register to generate SIM interrupts
 *
 * Values:
 * - 0 - XTE interrupt enabled
 * - 1 - XTE interrupt masked (default)
 */
/*@{*/
#define BP_SIM_INT_MASK_XTM  (5U)          /*!< Bit position for SIM_INT_MASK_XTM. */
#define BM_SIM_INT_MASK_XTM  (0x00000020U) /*!< Bit mask for SIM_INT_MASK_XTM. */
#define BS_SIM_INT_MASK_XTM  (1U)          /*!< Bit field size in bits for SIM_INT_MASK_XTM. */

/*! @brief Read current value of the SIM_INT_MASK_XTM field. */
#define BR_SIM_INT_MASK_XTM(x) (HW_SIM_INT_MASK(x).B.XTM)

/*! @brief Format value for bitfield SIM_INT_MASK_XTM. */
#define BF_SIM_INT_MASK_XTM(v) ((uint32_t)((uint32_t)(v) << BP_SIM_INT_MASK_XTM) & BM_SIM_INT_MASK_XTM)

/*! @brief Set the XTM field to a new value. */
#define BW_SIM_INT_MASK_XTM(x, v) (HW_SIM_INT_MASK_WR(x, (HW_SIM_INT_MASK_RD(x) & ~BM_SIM_INT_MASK_XTM) | BF_SIM_INT_MASK_XTM(v)))
/*@}*/

/*!
 * @name Register SIM_INT_MASK, field TFOM[6] (RW)
 *
 * Transmit FIFO Overfill Error Interrupt Mask. Used to enable/disable the
 * ability of the TFO flag in the XMT_STATUS register to generate SIM interrupts.
 *
 * Values:
 * - 0 - TFO interrupt enabled
 * - 1 - TFO interrupt masked (default)
 */
/*@{*/
#define BP_SIM_INT_MASK_TFOM (6U)          /*!< Bit position for SIM_INT_MASK_TFOM. */
#define BM_SIM_INT_MASK_TFOM (0x00000040U) /*!< Bit mask for SIM_INT_MASK_TFOM. */
#define BS_SIM_INT_MASK_TFOM (1U)          /*!< Bit field size in bits for SIM_INT_MASK_TFOM. */

/*! @brief Read current value of the SIM_INT_MASK_TFOM field. */
#define BR_SIM_INT_MASK_TFOM(x) (HW_SIM_INT_MASK(x).B.TFOM)

/*! @brief Format value for bitfield SIM_INT_MASK_TFOM. */
#define BF_SIM_INT_MASK_TFOM(v) ((uint32_t)((uint32_t)(v) << BP_SIM_INT_MASK_TFOM) & BM_SIM_INT_MASK_TFOM)

/*! @brief Set the TFOM field to a new value. */
#define BW_SIM_INT_MASK_TFOM(x, v) (HW_SIM_INT_MASK_WR(x, (HW_SIM_INT_MASK_RD(x) & ~BM_SIM_INT_MASK_TFOM) | BF_SIM_INT_MASK_TFOM(v)))
/*@}*/

/*!
 * @name Register SIM_INT_MASK, field TDTFM[7] (RW)
 *
 * Transmit Data Threshold Interrupt Mask. Used to enable/disable the ability of
 * the TDTF flag in the XMT_STATUS register to generate SIM interrupts.
 *
 * Values:
 * - 0 - TDTF interrupt enabled
 * - 1 - TDTF interrupt masked (default)
 */
/*@{*/
#define BP_SIM_INT_MASK_TDTFM (7U)         /*!< Bit position for SIM_INT_MASK_TDTFM. */
#define BM_SIM_INT_MASK_TDTFM (0x00000080U) /*!< Bit mask for SIM_INT_MASK_TDTFM. */
#define BS_SIM_INT_MASK_TDTFM (1U)         /*!< Bit field size in bits for SIM_INT_MASK_TDTFM. */

/*! @brief Read current value of the SIM_INT_MASK_TDTFM field. */
#define BR_SIM_INT_MASK_TDTFM(x) (HW_SIM_INT_MASK(x).B.TDTFM)

/*! @brief Format value for bitfield SIM_INT_MASK_TDTFM. */
#define BF_SIM_INT_MASK_TDTFM(v) ((uint32_t)((uint32_t)(v) << BP_SIM_INT_MASK_TDTFM) & BM_SIM_INT_MASK_TDTFM)

/*! @brief Set the TDTFM field to a new value. */
#define BW_SIM_INT_MASK_TDTFM(x, v) (HW_SIM_INT_MASK_WR(x, (HW_SIM_INT_MASK_RD(x) & ~BM_SIM_INT_MASK_TDTFM) | BF_SIM_INT_MASK_TDTFM(v)))
/*@}*/

/*!
 * @name Register SIM_INT_MASK, field GPCNTM[8] (RW)
 *
 * General Purpose Counter Interrupt Mask. Used to enable/disable the ability of
 * the GPCNT flag in the XMT_STATUS register to generate SIM interrupts.
 *
 * Values:
 * - 0 - GPCNT interrupt enabled
 * - 1 - GPCNT interrupt masked (default)
 */
/*@{*/
#define BP_SIM_INT_MASK_GPCNTM (8U)        /*!< Bit position for SIM_INT_MASK_GPCNTM. */
#define BM_SIM_INT_MASK_GPCNTM (0x00000100U) /*!< Bit mask for SIM_INT_MASK_GPCNTM. */
#define BS_SIM_INT_MASK_GPCNTM (1U)        /*!< Bit field size in bits for SIM_INT_MASK_GPCNTM. */

/*! @brief Read current value of the SIM_INT_MASK_GPCNTM field. */
#define BR_SIM_INT_MASK_GPCNTM(x) (HW_SIM_INT_MASK(x).B.GPCNTM)

/*! @brief Format value for bitfield SIM_INT_MASK_GPCNTM. */
#define BF_SIM_INT_MASK_GPCNTM(v) ((uint32_t)((uint32_t)(v) << BP_SIM_INT_MASK_GPCNTM) & BM_SIM_INT_MASK_GPCNTM)

/*! @brief Set the GPCNTM field to a new value. */
#define BW_SIM_INT_MASK_GPCNTM(x, v) (HW_SIM_INT_MASK_WR(x, (HW_SIM_INT_MASK_RD(x) & ~BM_SIM_INT_MASK_GPCNTM) | BF_SIM_INT_MASK_GPCNTM(v)))
/*@}*/

/*!
 * @name Register SIM_INT_MASK, field CWTM[9] (RW)
 *
 * Character Wait Time Interrupt Mask. Used to enable/disable the ability of the
 * CWT flag in the RCV_STATUS register to generate SIM interrupts.
 *
 * Values:
 * - 0 - CWT interrupt enabled
 * - 1 - CWT interrupt masked (default)
 */
/*@{*/
#define BP_SIM_INT_MASK_CWTM (9U)          /*!< Bit position for SIM_INT_MASK_CWTM. */
#define BM_SIM_INT_MASK_CWTM (0x00000200U) /*!< Bit mask for SIM_INT_MASK_CWTM. */
#define BS_SIM_INT_MASK_CWTM (1U)          /*!< Bit field size in bits for SIM_INT_MASK_CWTM. */

/*! @brief Read current value of the SIM_INT_MASK_CWTM field. */
#define BR_SIM_INT_MASK_CWTM(x) (HW_SIM_INT_MASK(x).B.CWTM)

/*! @brief Format value for bitfield SIM_INT_MASK_CWTM. */
#define BF_SIM_INT_MASK_CWTM(v) ((uint32_t)((uint32_t)(v) << BP_SIM_INT_MASK_CWTM) & BM_SIM_INT_MASK_CWTM)

/*! @brief Set the CWTM field to a new value. */
#define BW_SIM_INT_MASK_CWTM(x, v) (HW_SIM_INT_MASK_WR(x, (HW_SIM_INT_MASK_RD(x) & ~BM_SIM_INT_MASK_CWTM) | BF_SIM_INT_MASK_CWTM(v)))
/*@}*/

/*!
 * @name Register SIM_INT_MASK, field RTM[10] (RW)
 *
 * Receive Nack threshold interrupt mask. Used to enable/disable the ability of
 * the RTE flag in the RCV_STATUS register to generate SIM interrupts.
 *
 * Values:
 * - 0 - RTE interrupt enabled
 * - 1 - RTE interrupt masked (default)
 */
/*@{*/
#define BP_SIM_INT_MASK_RTM  (10U)         /*!< Bit position for SIM_INT_MASK_RTM. */
#define BM_SIM_INT_MASK_RTM  (0x00000400U) /*!< Bit mask for SIM_INT_MASK_RTM. */
#define BS_SIM_INT_MASK_RTM  (1U)          /*!< Bit field size in bits for SIM_INT_MASK_RTM. */

/*! @brief Read current value of the SIM_INT_MASK_RTM field. */
#define BR_SIM_INT_MASK_RTM(x) (HW_SIM_INT_MASK(x).B.RTM)

/*! @brief Format value for bitfield SIM_INT_MASK_RTM. */
#define BF_SIM_INT_MASK_RTM(v) ((uint32_t)((uint32_t)(v) << BP_SIM_INT_MASK_RTM) & BM_SIM_INT_MASK_RTM)

/*! @brief Set the RTM field to a new value. */
#define BW_SIM_INT_MASK_RTM(x, v) (HW_SIM_INT_MASK_WR(x, (HW_SIM_INT_MASK_RD(x) & ~BM_SIM_INT_MASK_RTM) | BF_SIM_INT_MASK_RTM(v)))
/*@}*/

/*!
 * @name Register SIM_INT_MASK, field BWTM[11] (RW)
 *
 * Block wait time interrupt mask. Used to enable/disable the ability of the bwt
 * flag in the RCV_STATUS register to generate SIM interrupts.
 *
 * Values:
 * - 0 - BWT interrupt enabled
 * - 1 - BWT interrupt masked (default)
 */
/*@{*/
#define BP_SIM_INT_MASK_BWTM (11U)         /*!< Bit position for SIM_INT_MASK_BWTM. */
#define BM_SIM_INT_MASK_BWTM (0x00000800U) /*!< Bit mask for SIM_INT_MASK_BWTM. */
#define BS_SIM_INT_MASK_BWTM (1U)          /*!< Bit field size in bits for SIM_INT_MASK_BWTM. */

/*! @brief Read current value of the SIM_INT_MASK_BWTM field. */
#define BR_SIM_INT_MASK_BWTM(x) (HW_SIM_INT_MASK(x).B.BWTM)

/*! @brief Format value for bitfield SIM_INT_MASK_BWTM. */
#define BF_SIM_INT_MASK_BWTM(v) ((uint32_t)((uint32_t)(v) << BP_SIM_INT_MASK_BWTM) & BM_SIM_INT_MASK_BWTM)

/*! @brief Set the BWTM field to a new value. */
#define BW_SIM_INT_MASK_BWTM(x, v) (HW_SIM_INT_MASK_WR(x, (HW_SIM_INT_MASK_RD(x) & ~BM_SIM_INT_MASK_BWTM) | BF_SIM_INT_MASK_BWTM(v)))
/*@}*/

/*!
 * @name Register SIM_INT_MASK, field BGTM[12] (RW)
 *
 * Block guard time interrupt mask. Used to enable/disable the ability of the
 * bgt flag in the RCV_STATUS register to generate SIM interrupts.
 *
 * Values:
 * - 0 - BGT interrupt enabled
 * - 1 - BGT interrupt masked (default)
 */
/*@{*/
#define BP_SIM_INT_MASK_BGTM (12U)         /*!< Bit position for SIM_INT_MASK_BGTM. */
#define BM_SIM_INT_MASK_BGTM (0x00001000U) /*!< Bit mask for SIM_INT_MASK_BGTM. */
#define BS_SIM_INT_MASK_BGTM (1U)          /*!< Bit field size in bits for SIM_INT_MASK_BGTM. */

/*! @brief Read current value of the SIM_INT_MASK_BGTM field. */
#define BR_SIM_INT_MASK_BGTM(x) (HW_SIM_INT_MASK(x).B.BGTM)

/*! @brief Format value for bitfield SIM_INT_MASK_BGTM. */
#define BF_SIM_INT_MASK_BGTM(v) ((uint32_t)((uint32_t)(v) << BP_SIM_INT_MASK_BGTM) & BM_SIM_INT_MASK_BGTM)

/*! @brief Set the BGTM field to a new value. */
#define BW_SIM_INT_MASK_BGTM(x, v) (HW_SIM_INT_MASK_WR(x, (HW_SIM_INT_MASK_RD(x) & ~BM_SIM_INT_MASK_BGTM) | BF_SIM_INT_MASK_BGTM(v)))
/*@}*/

/*!
 * @name Register SIM_INT_MASK, field RFEM[13] (RW)
 *
 * Receive fifo empty interrupt mask. Used to enable/disable the ability of the
 * RFE flag in the RCV_STATUS register to generate SIM interrupts.
 *
 * Values:
 * - 0 - RFE interrupt enabled
 * - 1 - RFE interrupt masked (default)
 */
/*@{*/
#define BP_SIM_INT_MASK_RFEM (13U)         /*!< Bit position for SIM_INT_MASK_RFEM. */
#define BM_SIM_INT_MASK_RFEM (0x00002000U) /*!< Bit mask for SIM_INT_MASK_RFEM. */
#define BS_SIM_INT_MASK_RFEM (1U)          /*!< Bit field size in bits for SIM_INT_MASK_RFEM. */

/*! @brief Read current value of the SIM_INT_MASK_RFEM field. */
#define BR_SIM_INT_MASK_RFEM(x) (HW_SIM_INT_MASK(x).B.RFEM)

/*! @brief Format value for bitfield SIM_INT_MASK_RFEM. */
#define BF_SIM_INT_MASK_RFEM(v) ((uint32_t)((uint32_t)(v) << BP_SIM_INT_MASK_RFEM) & BM_SIM_INT_MASK_RFEM)

/*! @brief Set the RFEM field to a new value. */
#define BW_SIM_INT_MASK_RFEM(x, v) (HW_SIM_INT_MASK_WR(x, (HW_SIM_INT_MASK_RD(x) & ~BM_SIM_INT_MASK_RFEM) | BF_SIM_INT_MASK_RFEM(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_PORT0_DETECT - SIM Port0 Detect Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_PORT0_DETECT - SIM Port0 Detect Register (RW)
 *
 * Reset value: 0x00000001U
 *
 * See the figure below for illustration of valid bits in the SIM Port0 Detect
 * Register and the table below for description of the bit fields. SPDS0
 * determines which edge transition of the SIMPD0 pin is used for SIM card presence
 * detection. Presence detection can be used to determine if the card has been inserted
 * or removed. The occurrence of the SIMPD0 edge, specified by SPDS0, will cause
 * the following: SDI0 to be set If the SDIM0 mask is clear, an interrupt to
 * occur on SIMIRQ_N If SAPD0 in the PORT0_CNTL register is set, auto power down
 * sequence will begin If a SIM card insertion is expected, SAPD0 can be set low to
 * avoid the auto power down sequence. There is no auto power up sequence. SPDP0
 * can be used to determine the current state of the SIMPD0 pin.
 */
typedef union _hw_sim_port0_detect
{
    uint32_t U;
    struct _hw_sim_port0_detect_bitfields
    {
        uint32_t SDIM0 : 1;            /*!< [0]  */
        uint32_t SDI0 : 1;             /*!< [1]  */
        uint32_t SPDP0 : 1;            /*!< [2]  */
        uint32_t SPDS0 : 1;            /*!< [3]  */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_sim_port0_detect_t;

/*!
 * @name Constants and macros for entire SIM_PORT0_DETECT register
 */
/*@{*/
#define HW_SIM_PORT0_DETECT_ADDR(x) ((uintptr_t)(x) + 0x3CU)

#define HW_SIM_PORT0_DETECT(x)   (*(__IO hw_sim_port0_detect_t *) HW_SIM_PORT0_DETECT_ADDR(x))
#define HW_SIM_PORT0_DETECT_RD(x) (HW_SIM_PORT0_DETECT(x).U)
#define HW_SIM_PORT0_DETECT_WR(x, v) (HW_SIM_PORT0_DETECT(x).U = (v))
#define HW_SIM_PORT0_DETECT_SET(x, v) (HW_SIM_PORT0_DETECT_WR(x, HW_SIM_PORT0_DETECT_RD(x) |  (v)))
#define HW_SIM_PORT0_DETECT_CLR(x, v) (HW_SIM_PORT0_DETECT_WR(x, HW_SIM_PORT0_DETECT_RD(x) & ~(v)))
#define HW_SIM_PORT0_DETECT_TOG(x, v) (HW_SIM_PORT0_DETECT_WR(x, HW_SIM_PORT0_DETECT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_PORT0_DETECT bitfields
 */

/*!
 * @name Register SIM_PORT0_DETECT, field SDIM0[0] (RW)
 *
 * SIM Detect Interrupt Mask Port 0. Interrupt mask for the SDI0 interrupt flag.
 *
 * Values:
 * - 0 - sdi0 enabled
 * - 1 - sdi0 masked (default)
 */
/*@{*/
#define BP_SIM_PORT0_DETECT_SDIM0 (0U)     /*!< Bit position for SIM_PORT0_DETECT_SDIM0. */
#define BM_SIM_PORT0_DETECT_SDIM0 (0x00000001U) /*!< Bit mask for SIM_PORT0_DETECT_SDIM0. */
#define BS_SIM_PORT0_DETECT_SDIM0 (1U)     /*!< Bit field size in bits for SIM_PORT0_DETECT_SDIM0. */

/*! @brief Read current value of the SIM_PORT0_DETECT_SDIM0 field. */
#define BR_SIM_PORT0_DETECT_SDIM0(x) (HW_SIM_PORT0_DETECT(x).B.SDIM0)

/*! @brief Format value for bitfield SIM_PORT0_DETECT_SDIM0. */
#define BF_SIM_PORT0_DETECT_SDIM0(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT0_DETECT_SDIM0) & BM_SIM_PORT0_DETECT_SDIM0)

/*! @brief Set the SDIM0 field to a new value. */
#define BW_SIM_PORT0_DETECT_SDIM0(x, v) (HW_SIM_PORT0_DETECT_WR(x, (HW_SIM_PORT0_DETECT_RD(x) & ~(BM_SIM_PORT0_DETECT_SDIM0 | BM_SIM_PORT0_DETECT_SDI0)) | BF_SIM_PORT0_DETECT_SDIM0(v)))
/*@}*/

/*!
 * @name Register SIM_PORT0_DETECT, field SDI0[1] (W1C)
 *
 * SIM Detect Interrupt flag Port 0. Status flag to indicate the insertion or
 * removal of a SIM card has been detected on port 0. Can create an interrupt to
 * the MCU if SDIM0 is low. Write a "1" to this bit to clear.
 *
 * Values:
 * - 0 - No insertion or removal of SIM card detected on Port 0 (default)
 * - 1 - Insertion or removal of SIM card detected on Port 0
 */
/*@{*/
#define BP_SIM_PORT0_DETECT_SDI0 (1U)      /*!< Bit position for SIM_PORT0_DETECT_SDI0. */
#define BM_SIM_PORT0_DETECT_SDI0 (0x00000002U) /*!< Bit mask for SIM_PORT0_DETECT_SDI0. */
#define BS_SIM_PORT0_DETECT_SDI0 (1U)      /*!< Bit field size in bits for SIM_PORT0_DETECT_SDI0. */

/*! @brief Read current value of the SIM_PORT0_DETECT_SDI0 field. */
#define BR_SIM_PORT0_DETECT_SDI0(x) (HW_SIM_PORT0_DETECT(x).B.SDI0)

/*! @brief Format value for bitfield SIM_PORT0_DETECT_SDI0. */
#define BF_SIM_PORT0_DETECT_SDI0(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT0_DETECT_SDI0) & BM_SIM_PORT0_DETECT_SDI0)

/*! @brief Set the SDI0 field to a new value. */
#define BW_SIM_PORT0_DETECT_SDI0(x, v) (HW_SIM_PORT0_DETECT_WR(x, (HW_SIM_PORT0_DETECT_RD(x) & ~BM_SIM_PORT0_DETECT_SDI0) | BF_SIM_PORT0_DETECT_SDI0(v)))
/*@}*/

/*!
 * @name Register SIM_PORT0_DETECT, field SPDP0[2] (RO)
 *
 * SIMPD0 input pin status. This bit reflects the state of the SIMPD0 pin. It is
 * not a latched register bit, but instead a synchronized version of the state
 * of the SIMPD0 pin itself.
 *
 * Values:
 * - 0 - SIMPD0 pin is logic low
 * - 1 - SIMPD0 pin is logic high
 */
/*@{*/
#define BP_SIM_PORT0_DETECT_SPDP0 (2U)     /*!< Bit position for SIM_PORT0_DETECT_SPDP0. */
#define BM_SIM_PORT0_DETECT_SPDP0 (0x00000004U) /*!< Bit mask for SIM_PORT0_DETECT_SPDP0. */
#define BS_SIM_PORT0_DETECT_SPDP0 (1U)     /*!< Bit field size in bits for SIM_PORT0_DETECT_SPDP0. */

/*! @brief Read current value of the SIM_PORT0_DETECT_SPDP0 field. */
#define BR_SIM_PORT0_DETECT_SPDP0(x) (HW_SIM_PORT0_DETECT(x).B.SPDP0)
/*@}*/

/*!
 * @name Register SIM_PORT0_DETECT, field SPDS0[3] (RW)
 *
 * SIM Presence Detect Select Port 0. Controls which edge of the SIMPD0 pin is
 * used to detect the presence of the SIM card.
 *
 * Values:
 * - 0 - Falling edge of SIMPD0 Input (default)
 * - 1 - Rising edge of SIMPD0 Input
 */
/*@{*/
#define BP_SIM_PORT0_DETECT_SPDS0 (3U)     /*!< Bit position for SIM_PORT0_DETECT_SPDS0. */
#define BM_SIM_PORT0_DETECT_SPDS0 (0x00000008U) /*!< Bit mask for SIM_PORT0_DETECT_SPDS0. */
#define BS_SIM_PORT0_DETECT_SPDS0 (1U)     /*!< Bit field size in bits for SIM_PORT0_DETECT_SPDS0. */

/*! @brief Read current value of the SIM_PORT0_DETECT_SPDS0 field. */
#define BR_SIM_PORT0_DETECT_SPDS0(x) (HW_SIM_PORT0_DETECT(x).B.SPDS0)

/*! @brief Format value for bitfield SIM_PORT0_DETECT_SPDS0. */
#define BF_SIM_PORT0_DETECT_SPDS0(v) ((uint32_t)((uint32_t)(v) << BP_SIM_PORT0_DETECT_SPDS0) & BM_SIM_PORT0_DETECT_SPDS0)

/*! @brief Set the SPDS0 field to a new value. */
#define BW_SIM_PORT0_DETECT_SPDS0(x, v) (HW_SIM_PORT0_DETECT_WR(x, (HW_SIM_PORT0_DETECT_RD(x) & ~(BM_SIM_PORT0_DETECT_SPDS0 | BM_SIM_PORT0_DETECT_SDI0)) | BF_SIM_PORT0_DETECT_SPDS0(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_DATA_FORMAT - SIM Data Format Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_DATA_FORMAT - SIM Data Format Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * See the figure below for illustration of valid bits in the SIM Data Format
 * Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_data_format
{
    uint32_t U;
    struct _hw_sim_data_format_bitfields
    {
        uint32_t IC : 1;               /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_sim_data_format_t;

/*!
 * @name Constants and macros for entire SIM_DATA_FORMAT register
 */
/*@{*/
#define HW_SIM_DATA_FORMAT_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_SIM_DATA_FORMAT(x)    (*(__IO hw_sim_data_format_t *) HW_SIM_DATA_FORMAT_ADDR(x))
#define HW_SIM_DATA_FORMAT_RD(x) (HW_SIM_DATA_FORMAT(x).U)
#define HW_SIM_DATA_FORMAT_WR(x, v) (HW_SIM_DATA_FORMAT(x).U = (v))
#define HW_SIM_DATA_FORMAT_SET(x, v) (HW_SIM_DATA_FORMAT_WR(x, HW_SIM_DATA_FORMAT_RD(x) |  (v)))
#define HW_SIM_DATA_FORMAT_CLR(x, v) (HW_SIM_DATA_FORMAT_WR(x, HW_SIM_DATA_FORMAT_RD(x) & ~(v)))
#define HW_SIM_DATA_FORMAT_TOG(x, v) (HW_SIM_DATA_FORMAT_WR(x, HW_SIM_DATA_FORMAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_DATA_FORMAT bitfields
 */

/*!
 * @name Register SIM_DATA_FORMAT, field IC[0] (RW)
 *
 * Inverse Convention. Used to configure the SIM to use either inverse
 * convention or direct convention for its data format. The IC bit can be controlled by
 * software, but it is normally set by hardware as a result of the interpretation
 * of the initial character when in ICM mode.
 *
 * Values:
 * - 0 - Direction convention transfers enabled (default).
 * - 1 - Inverse convention transfers enabled.
 */
/*@{*/
#define BP_SIM_DATA_FORMAT_IC (0U)         /*!< Bit position for SIM_DATA_FORMAT_IC. */
#define BM_SIM_DATA_FORMAT_IC (0x00000001U) /*!< Bit mask for SIM_DATA_FORMAT_IC. */
#define BS_SIM_DATA_FORMAT_IC (1U)         /*!< Bit field size in bits for SIM_DATA_FORMAT_IC. */

/*! @brief Read current value of the SIM_DATA_FORMAT_IC field. */
#define BR_SIM_DATA_FORMAT_IC(x) (HW_SIM_DATA_FORMAT(x).B.IC)

/*! @brief Format value for bitfield SIM_DATA_FORMAT_IC. */
#define BF_SIM_DATA_FORMAT_IC(v) ((uint32_t)((uint32_t)(v) << BP_SIM_DATA_FORMAT_IC) & BM_SIM_DATA_FORMAT_IC)

/*! @brief Set the IC field to a new value. */
#define BW_SIM_DATA_FORMAT_IC(x, v) (HW_SIM_DATA_FORMAT_WR(x, (HW_SIM_DATA_FORMAT_RD(x) & ~BM_SIM_DATA_FORMAT_IC) | BF_SIM_DATA_FORMAT_IC(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_XMT_THRESHOLD - SIM Transmit Threshold Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_XMT_THRESHOLD - SIM Transmit Threshold Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * See the figure below for illustration of valid bits in the SIM Transmit
 * Threshold Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_xmt_threshold
{
    uint32_t U;
    struct _hw_sim_xmt_threshold_bitfields
    {
        uint32_t TDT : 4;              /*!< [3:0]  */
        uint32_t XTH : 4;              /*!< [7:4]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_sim_xmt_threshold_t;

/*!
 * @name Constants and macros for entire SIM_XMT_THRESHOLD register
 */
/*@{*/
#define HW_SIM_XMT_THRESHOLD_ADDR(x) ((uintptr_t)(x) + 0x44U)

#define HW_SIM_XMT_THRESHOLD(x)  (*(__IO hw_sim_xmt_threshold_t *) HW_SIM_XMT_THRESHOLD_ADDR(x))
#define HW_SIM_XMT_THRESHOLD_RD(x) (HW_SIM_XMT_THRESHOLD(x).U)
#define HW_SIM_XMT_THRESHOLD_WR(x, v) (HW_SIM_XMT_THRESHOLD(x).U = (v))
#define HW_SIM_XMT_THRESHOLD_SET(x, v) (HW_SIM_XMT_THRESHOLD_WR(x, HW_SIM_XMT_THRESHOLD_RD(x) |  (v)))
#define HW_SIM_XMT_THRESHOLD_CLR(x, v) (HW_SIM_XMT_THRESHOLD_WR(x, HW_SIM_XMT_THRESHOLD_RD(x) & ~(v)))
#define HW_SIM_XMT_THRESHOLD_TOG(x, v) (HW_SIM_XMT_THRESHOLD_WR(x, HW_SIM_XMT_THRESHOLD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_XMT_THRESHOLD bitfields
 */

/*!
 * @name Register SIM_XMT_THRESHOLD, field TDT[3:0] (RW)
 *
 * Transmit Data Threshold. Used to set the threshold value for the Transmit
 * FIFO at which the TDTF bit in the XMT_STATUS register will be set. When the
 * number of bytes in the Transmit FIFO is less than or equal to TDT[3:0], TDTF will
 * be set.
 */
/*@{*/
#define BP_SIM_XMT_THRESHOLD_TDT (0U)      /*!< Bit position for SIM_XMT_THRESHOLD_TDT. */
#define BM_SIM_XMT_THRESHOLD_TDT (0x0000000FU) /*!< Bit mask for SIM_XMT_THRESHOLD_TDT. */
#define BS_SIM_XMT_THRESHOLD_TDT (4U)      /*!< Bit field size in bits for SIM_XMT_THRESHOLD_TDT. */

/*! @brief Read current value of the SIM_XMT_THRESHOLD_TDT field. */
#define BR_SIM_XMT_THRESHOLD_TDT(x) (HW_SIM_XMT_THRESHOLD(x).B.TDT)

/*! @brief Format value for bitfield SIM_XMT_THRESHOLD_TDT. */
#define BF_SIM_XMT_THRESHOLD_TDT(v) ((uint32_t)((uint32_t)(v) << BP_SIM_XMT_THRESHOLD_TDT) & BM_SIM_XMT_THRESHOLD_TDT)

/*! @brief Set the TDT field to a new value. */
#define BW_SIM_XMT_THRESHOLD_TDT(x, v) (HW_SIM_XMT_THRESHOLD_WR(x, (HW_SIM_XMT_THRESHOLD_RD(x) & ~BM_SIM_XMT_THRESHOLD_TDT) | BF_SIM_XMT_THRESHOLD_TDT(v)))
/*@}*/

/*!
 * @name Register SIM_XMT_THRESHOLD, field XTH[7:4] (RW)
 *
 * XTH[3:0] Transmit NACK Threshold. Used to set the NACK threshold for the
 * transmitter. Once the threshold number set by XTH has been reached for the current
 * byte being transmitted, the error flag XTE in the XMT_STATUS register will be
 * set. Setting of XTE causes the remaining transmissions queued in the transmit
 * FIFO to be aborted and no more transmissions to occur until software clears
 * XTE. To trigger XTE, a given byte being transmitted must reach the XTH
 * threshold itself. Transmit NACKs accumulated on one byte are not carried over to the
 * next.
 *
 * Values:
 * - 0 - XTE will never be set; retransmission after NACK reception is disabled.
 * - 1 - XTE will be set after 1 nack is received; 0 retransmissions occurs.
 * - 10 - XTE will be set after 2 nacks are received; at most 1 retransmission
 *     occurs.
 * - 11 - XTE will be set after 3 nacks are received; at most 2 retransmissions
 *     occurs.
 * - 1111 - XTE will be set after 15 nacks are received; at most 14
 *     retransmissions occurs.
 */
/*@{*/
#define BP_SIM_XMT_THRESHOLD_XTH (4U)      /*!< Bit position for SIM_XMT_THRESHOLD_XTH. */
#define BM_SIM_XMT_THRESHOLD_XTH (0x000000F0U) /*!< Bit mask for SIM_XMT_THRESHOLD_XTH. */
#define BS_SIM_XMT_THRESHOLD_XTH (4U)      /*!< Bit field size in bits for SIM_XMT_THRESHOLD_XTH. */

/*! @brief Read current value of the SIM_XMT_THRESHOLD_XTH field. */
#define BR_SIM_XMT_THRESHOLD_XTH(x) (HW_SIM_XMT_THRESHOLD(x).B.XTH)

/*! @brief Format value for bitfield SIM_XMT_THRESHOLD_XTH. */
#define BF_SIM_XMT_THRESHOLD_XTH(v) ((uint32_t)((uint32_t)(v) << BP_SIM_XMT_THRESHOLD_XTH) & BM_SIM_XMT_THRESHOLD_XTH)

/*! @brief Set the XTH field to a new value. */
#define BW_SIM_XMT_THRESHOLD_XTH(x, v) (HW_SIM_XMT_THRESHOLD_WR(x, (HW_SIM_XMT_THRESHOLD_RD(x) & ~BM_SIM_XMT_THRESHOLD_XTH) | BF_SIM_XMT_THRESHOLD_XTH(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_GUARD_CNTL - SIM Transmit Guard Control Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_GUARD_CNTL - SIM Transmit Guard Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * See the figure below for illustration of valid bits in the SIM Transmit Guard
 * Control Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_guard_cntl
{
    uint32_t U;
    struct _hw_sim_guard_cntl_bitfields
    {
        uint32_t GETU : 8;             /*!< [7:0]  */
        uint32_t RCVR11 : 1;           /*!< [8]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_sim_guard_cntl_t;

/*!
 * @name Constants and macros for entire SIM_GUARD_CNTL register
 */
/*@{*/
#define HW_SIM_GUARD_CNTL_ADDR(x) ((uintptr_t)(x) + 0x48U)

#define HW_SIM_GUARD_CNTL(x)     (*(__IO hw_sim_guard_cntl_t *) HW_SIM_GUARD_CNTL_ADDR(x))
#define HW_SIM_GUARD_CNTL_RD(x)  (HW_SIM_GUARD_CNTL(x).U)
#define HW_SIM_GUARD_CNTL_WR(x, v) (HW_SIM_GUARD_CNTL(x).U = (v))
#define HW_SIM_GUARD_CNTL_SET(x, v) (HW_SIM_GUARD_CNTL_WR(x, HW_SIM_GUARD_CNTL_RD(x) |  (v)))
#define HW_SIM_GUARD_CNTL_CLR(x, v) (HW_SIM_GUARD_CNTL_WR(x, HW_SIM_GUARD_CNTL_RD(x) & ~(v)))
#define HW_SIM_GUARD_CNTL_TOG(x, v) (HW_SIM_GUARD_CNTL_WR(x, HW_SIM_GUARD_CNTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_GUARD_CNTL bitfields
 */

/*!
 * @name Register SIM_GUARD_CNTL, field GETU[7:0] (RW)
 *
 * Transmit Guard ETUs. Used to control the number of additional Elementary Time
 * Units (ETUs) inserted between bytes transmitted by the SIM transmitter. An
 * ETU is equivalent to one bit time at the given baud rate (for example, the
 * length of a START bit). The guard time has no effect on the SIM receiver. A value
 * of 0x00 inserts no additional ETUs, while a value of 0xFE inserts 254
 * additional ETUs. A value of 0xFF subtracts one ETU by reducing the number of STOP bits
 * from two to one.
 */
/*@{*/
#define BP_SIM_GUARD_CNTL_GETU (0U)        /*!< Bit position for SIM_GUARD_CNTL_GETU. */
#define BM_SIM_GUARD_CNTL_GETU (0x000000FFU) /*!< Bit mask for SIM_GUARD_CNTL_GETU. */
#define BS_SIM_GUARD_CNTL_GETU (8U)        /*!< Bit field size in bits for SIM_GUARD_CNTL_GETU. */

/*! @brief Read current value of the SIM_GUARD_CNTL_GETU field. */
#define BR_SIM_GUARD_CNTL_GETU(x) (HW_SIM_GUARD_CNTL(x).B.GETU)

/*! @brief Format value for bitfield SIM_GUARD_CNTL_GETU. */
#define BF_SIM_GUARD_CNTL_GETU(v) ((uint32_t)((uint32_t)(v) << BP_SIM_GUARD_CNTL_GETU) & BM_SIM_GUARD_CNTL_GETU)

/*! @brief Set the GETU field to a new value. */
#define BW_SIM_GUARD_CNTL_GETU(x, v) (HW_SIM_GUARD_CNTL_WR(x, (HW_SIM_GUARD_CNTL_RD(x) & ~BM_SIM_GUARD_CNTL_GETU) | BF_SIM_GUARD_CNTL_GETU(v)))
/*@}*/

/*!
 * @name Register SIM_GUARD_CNTL, field RCVR11[8] (RW)
 *
 * Receiver use 11 ETUs. Used to configure the SIM module receiver for 11 ETU
 * operation (that is, 1 Stop bit). This bit is provided for support of T=1 cards.
 *
 * Values:
 * - 0 - Receiver configured for 12 ETU operation (default)
 * - 1 - Receiver configured for 11 ETU operation
 */
/*@{*/
#define BP_SIM_GUARD_CNTL_RCVR11 (8U)      /*!< Bit position for SIM_GUARD_CNTL_RCVR11. */
#define BM_SIM_GUARD_CNTL_RCVR11 (0x00000100U) /*!< Bit mask for SIM_GUARD_CNTL_RCVR11. */
#define BS_SIM_GUARD_CNTL_RCVR11 (1U)      /*!< Bit field size in bits for SIM_GUARD_CNTL_RCVR11. */

/*! @brief Read current value of the SIM_GUARD_CNTL_RCVR11 field. */
#define BR_SIM_GUARD_CNTL_RCVR11(x) (HW_SIM_GUARD_CNTL(x).B.RCVR11)

/*! @brief Format value for bitfield SIM_GUARD_CNTL_RCVR11. */
#define BF_SIM_GUARD_CNTL_RCVR11(v) ((uint32_t)((uint32_t)(v) << BP_SIM_GUARD_CNTL_RCVR11) & BM_SIM_GUARD_CNTL_RCVR11)

/*! @brief Set the RCVR11 field to a new value. */
#define BW_SIM_GUARD_CNTL_RCVR11(x, v) (HW_SIM_GUARD_CNTL_WR(x, (HW_SIM_GUARD_CNTL_RD(x) & ~BM_SIM_GUARD_CNTL_RCVR11) | BF_SIM_GUARD_CNTL_RCVR11(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_OD_CONFIG - SIM Open Drain Configuration Control Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_OD_CONFIG - SIM Open Drain Configuration Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * See the figure below for illustration of valid bits in the SIM Open Drain
 * Configuration Control Register and the table below for description of the bit
 * fields.
 */
typedef union _hw_sim_od_config
{
    uint32_t U;
    struct _hw_sim_od_config_bitfields
    {
        uint32_t OD_P0 : 1;            /*!< [0]  */
        uint32_t OD_P1 : 1;            /*!< [1]  */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_sim_od_config_t;

/*!
 * @name Constants and macros for entire SIM_OD_CONFIG register
 */
/*@{*/
#define HW_SIM_OD_CONFIG_ADDR(x) ((uintptr_t)(x) + 0x4CU)

#define HW_SIM_OD_CONFIG(x)      (*(__IO hw_sim_od_config_t *) HW_SIM_OD_CONFIG_ADDR(x))
#define HW_SIM_OD_CONFIG_RD(x)   (HW_SIM_OD_CONFIG(x).U)
#define HW_SIM_OD_CONFIG_WR(x, v) (HW_SIM_OD_CONFIG(x).U = (v))
#define HW_SIM_OD_CONFIG_SET(x, v) (HW_SIM_OD_CONFIG_WR(x, HW_SIM_OD_CONFIG_RD(x) |  (v)))
#define HW_SIM_OD_CONFIG_CLR(x, v) (HW_SIM_OD_CONFIG_WR(x, HW_SIM_OD_CONFIG_RD(x) & ~(v)))
#define HW_SIM_OD_CONFIG_TOG(x, v) (HW_SIM_OD_CONFIG_WR(x, HW_SIM_OD_CONFIG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_OD_CONFIG bitfields
 */

/*!
 * @name Register SIM_OD_CONFIG, field OD_P0[0] (RW)
 *
 * Open Drain control for Port 0. Used to control whether the XMT data line on
 * port 0 is open-drain.
 *
 * Values:
 * - 0 - XMT pin on port 0 is push-pull (default).
 * - 1 - XMT pin on port 0 is open-drain.
 */
/*@{*/
#define BP_SIM_OD_CONFIG_OD_P0 (0U)        /*!< Bit position for SIM_OD_CONFIG_OD_P0. */
#define BM_SIM_OD_CONFIG_OD_P0 (0x00000001U) /*!< Bit mask for SIM_OD_CONFIG_OD_P0. */
#define BS_SIM_OD_CONFIG_OD_P0 (1U)        /*!< Bit field size in bits for SIM_OD_CONFIG_OD_P0. */

/*! @brief Read current value of the SIM_OD_CONFIG_OD_P0 field. */
#define BR_SIM_OD_CONFIG_OD_P0(x) (HW_SIM_OD_CONFIG(x).B.OD_P0)

/*! @brief Format value for bitfield SIM_OD_CONFIG_OD_P0. */
#define BF_SIM_OD_CONFIG_OD_P0(v) ((uint32_t)((uint32_t)(v) << BP_SIM_OD_CONFIG_OD_P0) & BM_SIM_OD_CONFIG_OD_P0)

/*! @brief Set the OD_P0 field to a new value. */
#define BW_SIM_OD_CONFIG_OD_P0(x, v) (HW_SIM_OD_CONFIG_WR(x, (HW_SIM_OD_CONFIG_RD(x) & ~BM_SIM_OD_CONFIG_OD_P0) | BF_SIM_OD_CONFIG_OD_P0(v)))
/*@}*/

/*!
 * @name Register SIM_OD_CONFIG, field OD_P1[1] (RW)
 *
 * Open Drain control for Port 1. Used to control whether the XMT data line on
 * port 1 is open-drain. If AMODE bit in SETUP register is set, this bit will have
 * no effect.
 *
 * Values:
 * - 0 - XMT pin on port 1 is push-pull (default).
 * - 1 - XMT pin on port 1 is open-drain.
 */
/*@{*/
#define BP_SIM_OD_CONFIG_OD_P1 (1U)        /*!< Bit position for SIM_OD_CONFIG_OD_P1. */
#define BM_SIM_OD_CONFIG_OD_P1 (0x00000002U) /*!< Bit mask for SIM_OD_CONFIG_OD_P1. */
#define BS_SIM_OD_CONFIG_OD_P1 (1U)        /*!< Bit field size in bits for SIM_OD_CONFIG_OD_P1. */

/*! @brief Read current value of the SIM_OD_CONFIG_OD_P1 field. */
#define BR_SIM_OD_CONFIG_OD_P1(x) (HW_SIM_OD_CONFIG(x).B.OD_P1)

/*! @brief Format value for bitfield SIM_OD_CONFIG_OD_P1. */
#define BF_SIM_OD_CONFIG_OD_P1(v) ((uint32_t)((uint32_t)(v) << BP_SIM_OD_CONFIG_OD_P1) & BM_SIM_OD_CONFIG_OD_P1)

/*! @brief Set the OD_P1 field to a new value. */
#define BW_SIM_OD_CONFIG_OD_P1(x, v) (HW_SIM_OD_CONFIG_WR(x, (HW_SIM_OD_CONFIG_RD(x) & ~BM_SIM_OD_CONFIG_OD_P1) | BF_SIM_OD_CONFIG_OD_P1(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_RESET_CNTL - SIM Reset Control Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_RESET_CNTL - SIM Reset Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * See the figure below for illustration of valid bits in the SIM Reset Control
 * Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_reset_cntl
{
    uint32_t U;
    struct _hw_sim_reset_cntl_bitfields
    {
        uint32_t FLUSH_RCV : 1;        /*!< [0]  */
        uint32_t FLUSH_XMT : 1;        /*!< [1]  */
        uint32_t SOFT_RST : 1;         /*!< [2]  */
        uint32_t KILL_CLOCK : 1;       /*!< [3]  */
        uint32_t DOZE : 1;             /*!< [4]  */
        uint32_t STOP : 1;             /*!< [5]  */
        uint32_t RESERVED0 : 26;       /*!< [31:6]  */
    } B;
} hw_sim_reset_cntl_t;

/*!
 * @name Constants and macros for entire SIM_RESET_CNTL register
 */
/*@{*/
#define HW_SIM_RESET_CNTL_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_SIM_RESET_CNTL(x)     (*(__IO hw_sim_reset_cntl_t *) HW_SIM_RESET_CNTL_ADDR(x))
#define HW_SIM_RESET_CNTL_RD(x)  (HW_SIM_RESET_CNTL(x).U)
#define HW_SIM_RESET_CNTL_WR(x, v) (HW_SIM_RESET_CNTL(x).U = (v))
#define HW_SIM_RESET_CNTL_SET(x, v) (HW_SIM_RESET_CNTL_WR(x, HW_SIM_RESET_CNTL_RD(x) |  (v)))
#define HW_SIM_RESET_CNTL_CLR(x, v) (HW_SIM_RESET_CNTL_WR(x, HW_SIM_RESET_CNTL_RD(x) & ~(v)))
#define HW_SIM_RESET_CNTL_TOG(x, v) (HW_SIM_RESET_CNTL_WR(x, HW_SIM_RESET_CNTL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_RESET_CNTL bitfields
 */

/*!
 * @name Register SIM_RESET_CNTL, field FLUSH_RCV[0] (RW)
 *
 * Flush Receiver. This bit operates as a SIM receiver reset. The transmit
 * portion of the SIM module is not affected. The software must clear this bit before
 * the SIM receiver can operate.
 *
 * Values:
 * - 0 - SIM Receiver normal operation (default).
 * - 1 - SIM Receiver held in Reset.
 */
/*@{*/
#define BP_SIM_RESET_CNTL_FLUSH_RCV (0U)   /*!< Bit position for SIM_RESET_CNTL_FLUSH_RCV. */
#define BM_SIM_RESET_CNTL_FLUSH_RCV (0x00000001U) /*!< Bit mask for SIM_RESET_CNTL_FLUSH_RCV. */
#define BS_SIM_RESET_CNTL_FLUSH_RCV (1U)   /*!< Bit field size in bits for SIM_RESET_CNTL_FLUSH_RCV. */

/*! @brief Read current value of the SIM_RESET_CNTL_FLUSH_RCV field. */
#define BR_SIM_RESET_CNTL_FLUSH_RCV(x) (HW_SIM_RESET_CNTL(x).B.FLUSH_RCV)

/*! @brief Format value for bitfield SIM_RESET_CNTL_FLUSH_RCV. */
#define BF_SIM_RESET_CNTL_FLUSH_RCV(v) ((uint32_t)((uint32_t)(v) << BP_SIM_RESET_CNTL_FLUSH_RCV) & BM_SIM_RESET_CNTL_FLUSH_RCV)

/*! @brief Set the FLUSH_RCV field to a new value. */
#define BW_SIM_RESET_CNTL_FLUSH_RCV(x, v) (HW_SIM_RESET_CNTL_WR(x, (HW_SIM_RESET_CNTL_RD(x) & ~BM_SIM_RESET_CNTL_FLUSH_RCV) | BF_SIM_RESET_CNTL_FLUSH_RCV(v)))
/*@}*/

/*!
 * @name Register SIM_RESET_CNTL, field FLUSH_XMT[1] (RW)
 *
 * Flush Transmitter. This bit operates as a SIM transmitter reset. The receive
 * portion of the SIM module is not affected. The software must clear this bit
 * before the SIM transmitter can operate.
 *
 * Values:
 * - 0 - SIM Transmitter normal operation (default).
 * - 1 - SIM Transmitter held in Reset.
 */
/*@{*/
#define BP_SIM_RESET_CNTL_FLUSH_XMT (1U)   /*!< Bit position for SIM_RESET_CNTL_FLUSH_XMT. */
#define BM_SIM_RESET_CNTL_FLUSH_XMT (0x00000002U) /*!< Bit mask for SIM_RESET_CNTL_FLUSH_XMT. */
#define BS_SIM_RESET_CNTL_FLUSH_XMT (1U)   /*!< Bit field size in bits for SIM_RESET_CNTL_FLUSH_XMT. */

/*! @brief Read current value of the SIM_RESET_CNTL_FLUSH_XMT field. */
#define BR_SIM_RESET_CNTL_FLUSH_XMT(x) (HW_SIM_RESET_CNTL(x).B.FLUSH_XMT)

/*! @brief Format value for bitfield SIM_RESET_CNTL_FLUSH_XMT. */
#define BF_SIM_RESET_CNTL_FLUSH_XMT(v) ((uint32_t)((uint32_t)(v) << BP_SIM_RESET_CNTL_FLUSH_XMT) & BM_SIM_RESET_CNTL_FLUSH_XMT)

/*! @brief Set the FLUSH_XMT field to a new value. */
#define BW_SIM_RESET_CNTL_FLUSH_XMT(x, v) (HW_SIM_RESET_CNTL_WR(x, (HW_SIM_RESET_CNTL_RD(x) & ~BM_SIM_RESET_CNTL_FLUSH_XMT) | BF_SIM_RESET_CNTL_FLUSH_XMT(v)))
/*@}*/

/*!
 * @name Register SIM_RESET_CNTL, field SOFT_RST[2] (WO)
 *
 * Software Reset. Used to reset the entire SIM module. This acts the same as a
 * hardware reset for the SIM module. This bit is self-clearing. Software should
 * allow a minimum of 4 reference clock cycles (CKIH) before attempting to access
 * the SIM module after a software reset.
 *
 * Values:
 * - 0 - SIM Normal operation (default).
 * - 1 - SIM held in Reset.
 */
/*@{*/
#define BP_SIM_RESET_CNTL_SOFT_RST (2U)    /*!< Bit position for SIM_RESET_CNTL_SOFT_RST. */
#define BM_SIM_RESET_CNTL_SOFT_RST (0x00000004U) /*!< Bit mask for SIM_RESET_CNTL_SOFT_RST. */
#define BS_SIM_RESET_CNTL_SOFT_RST (1U)    /*!< Bit field size in bits for SIM_RESET_CNTL_SOFT_RST. */

/*! @brief Format value for bitfield SIM_RESET_CNTL_SOFT_RST. */
#define BF_SIM_RESET_CNTL_SOFT_RST(v) ((uint32_t)((uint32_t)(v) << BP_SIM_RESET_CNTL_SOFT_RST) & BM_SIM_RESET_CNTL_SOFT_RST)
/*@}*/

/*!
 * @name Register SIM_RESET_CNTL, field KILL_CLOCK[3] (RW)
 *
 * Kill SIM Clock. Used to enable/disable the SIM clock input to the SIM module.
 * This bit will gate all SIM clocks including the SIM card clock regardless of
 * the state of the STOP bit described above.
 *
 * Values:
 * - 0 - SIM input clock enabled (default).
 * - 1 - SIM input clock disabled.
 */
/*@{*/
#define BP_SIM_RESET_CNTL_KILL_CLOCK (3U)  /*!< Bit position for SIM_RESET_CNTL_KILL_CLOCK. */
#define BM_SIM_RESET_CNTL_KILL_CLOCK (0x00000008U) /*!< Bit mask for SIM_RESET_CNTL_KILL_CLOCK. */
#define BS_SIM_RESET_CNTL_KILL_CLOCK (1U)  /*!< Bit field size in bits for SIM_RESET_CNTL_KILL_CLOCK. */

/*! @brief Read current value of the SIM_RESET_CNTL_KILL_CLOCK field. */
#define BR_SIM_RESET_CNTL_KILL_CLOCK(x) (HW_SIM_RESET_CNTL(x).B.KILL_CLOCK)

/*! @brief Format value for bitfield SIM_RESET_CNTL_KILL_CLOCK. */
#define BF_SIM_RESET_CNTL_KILL_CLOCK(v) ((uint32_t)((uint32_t)(v) << BP_SIM_RESET_CNTL_KILL_CLOCK) & BM_SIM_RESET_CNTL_KILL_CLOCK)

/*! @brief Set the KILL_CLOCK field to a new value. */
#define BW_SIM_RESET_CNTL_KILL_CLOCK(x, v) (HW_SIM_RESET_CNTL_WR(x, (HW_SIM_RESET_CNTL_RD(x) & ~BM_SIM_RESET_CNTL_KILL_CLOCK) | BF_SIM_RESET_CNTL_KILL_CLOCK(v)))
/*@}*/

/*!
 * @name Register SIM_RESET_CNTL, field DOZE[4] (RW)
 *
 * DOZE. Used to configure the operation of the SIM module when a processor DOZE
 * instruction is executed.
 *
 * Values:
 * - 0 - DOZE instruction has no effect on SIM module (default).
 * - 1 - DOZE instruction will cause SIM module to gate SIM clocks when the
 *     transmit FIFO is empty.
 */
/*@{*/
#define BP_SIM_RESET_CNTL_DOZE (4U)        /*!< Bit position for SIM_RESET_CNTL_DOZE. */
#define BM_SIM_RESET_CNTL_DOZE (0x00000010U) /*!< Bit mask for SIM_RESET_CNTL_DOZE. */
#define BS_SIM_RESET_CNTL_DOZE (1U)        /*!< Bit field size in bits for SIM_RESET_CNTL_DOZE. */

/*! @brief Read current value of the SIM_RESET_CNTL_DOZE field. */
#define BR_SIM_RESET_CNTL_DOZE(x) (HW_SIM_RESET_CNTL(x).B.DOZE)

/*! @brief Format value for bitfield SIM_RESET_CNTL_DOZE. */
#define BF_SIM_RESET_CNTL_DOZE(v) ((uint32_t)((uint32_t)(v) << BP_SIM_RESET_CNTL_DOZE) & BM_SIM_RESET_CNTL_DOZE)

/*! @brief Set the DOZE field to a new value. */
#define BW_SIM_RESET_CNTL_DOZE(x, v) (HW_SIM_RESET_CNTL_WR(x, (HW_SIM_RESET_CNTL_RD(x) & ~BM_SIM_RESET_CNTL_DOZE) | BF_SIM_RESET_CNTL_DOZE(v)))
/*@}*/

/*!
 * @name Register SIM_RESET_CNTL, field STOP[5] (RW)
 *
 * STOP. Used to configure the operation of the SIM module when a processor STOP
 * instruction is executed. This bit is added to provide support for SIM cards
 * that do not allow the SIM Card clock to be stopped while power is applied.
 *
 * Values:
 * - 0 - STOP instruction shuts down all SIM clocks (default).
 * - 1 - STOP instruction shuts down all clocks except for the BAUD_CLK (clock
 *     provided to SIM Card).
 */
/*@{*/
#define BP_SIM_RESET_CNTL_STOP (5U)        /*!< Bit position for SIM_RESET_CNTL_STOP. */
#define BM_SIM_RESET_CNTL_STOP (0x00000020U) /*!< Bit mask for SIM_RESET_CNTL_STOP. */
#define BS_SIM_RESET_CNTL_STOP (1U)        /*!< Bit field size in bits for SIM_RESET_CNTL_STOP. */

/*! @brief Read current value of the SIM_RESET_CNTL_STOP field. */
#define BR_SIM_RESET_CNTL_STOP(x) (HW_SIM_RESET_CNTL(x).B.STOP)

/*! @brief Format value for bitfield SIM_RESET_CNTL_STOP. */
#define BF_SIM_RESET_CNTL_STOP(v) ((uint32_t)((uint32_t)(v) << BP_SIM_RESET_CNTL_STOP) & BM_SIM_RESET_CNTL_STOP)

/*! @brief Set the STOP field to a new value. */
#define BW_SIM_RESET_CNTL_STOP(x, v) (HW_SIM_RESET_CNTL_WR(x, (HW_SIM_RESET_CNTL_RD(x) & ~BM_SIM_RESET_CNTL_STOP) | BF_SIM_RESET_CNTL_STOP(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_CHAR_WAIT - SIM Character Wait Time Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_CHAR_WAIT - SIM Character Wait Time Register (RW)
 *
 * Reset value: 0x0000FFFFU
 *
 * See the figure below for illustration of valid bits in the SIM Character Wait
 * Time Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_char_wait
{
    uint32_t U;
    struct _hw_sim_char_wait_bitfields
    {
        uint32_t CWT : 16;             /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sim_char_wait_t;

/*!
 * @name Constants and macros for entire SIM_CHAR_WAIT register
 */
/*@{*/
#define HW_SIM_CHAR_WAIT_ADDR(x) ((uintptr_t)(x) + 0x54U)

#define HW_SIM_CHAR_WAIT(x)      (*(__IO hw_sim_char_wait_t *) HW_SIM_CHAR_WAIT_ADDR(x))
#define HW_SIM_CHAR_WAIT_RD(x)   (HW_SIM_CHAR_WAIT(x).U)
#define HW_SIM_CHAR_WAIT_WR(x, v) (HW_SIM_CHAR_WAIT(x).U = (v))
#define HW_SIM_CHAR_WAIT_SET(x, v) (HW_SIM_CHAR_WAIT_WR(x, HW_SIM_CHAR_WAIT_RD(x) |  (v)))
#define HW_SIM_CHAR_WAIT_CLR(x, v) (HW_SIM_CHAR_WAIT_WR(x, HW_SIM_CHAR_WAIT_RD(x) & ~(v)))
#define HW_SIM_CHAR_WAIT_TOG(x, v) (HW_SIM_CHAR_WAIT_WR(x, HW_SIM_CHAR_WAIT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_CHAR_WAIT bitfields
 */

/*!
 * @name Register SIM_CHAR_WAIT, field CWT[15:0] (RW)
 *
 * Character Wait Time. The value written to this register will specify the
 * number of ETU times allowed between characters. Default is 0xFFFF
 */
/*@{*/
#define BP_SIM_CHAR_WAIT_CWT (0U)          /*!< Bit position for SIM_CHAR_WAIT_CWT. */
#define BM_SIM_CHAR_WAIT_CWT (0x0000FFFFU) /*!< Bit mask for SIM_CHAR_WAIT_CWT. */
#define BS_SIM_CHAR_WAIT_CWT (16U)         /*!< Bit field size in bits for SIM_CHAR_WAIT_CWT. */

/*! @brief Read current value of the SIM_CHAR_WAIT_CWT field. */
#define BR_SIM_CHAR_WAIT_CWT(x) (HW_SIM_CHAR_WAIT(x).B.CWT)

/*! @brief Format value for bitfield SIM_CHAR_WAIT_CWT. */
#define BF_SIM_CHAR_WAIT_CWT(v) ((uint32_t)((uint32_t)(v) << BP_SIM_CHAR_WAIT_CWT) & BM_SIM_CHAR_WAIT_CWT)

/*! @brief Set the CWT field to a new value. */
#define BW_SIM_CHAR_WAIT_CWT(x, v) (HW_SIM_CHAR_WAIT_WR(x, (HW_SIM_CHAR_WAIT_RD(x) & ~BM_SIM_CHAR_WAIT_CWT) | BF_SIM_CHAR_WAIT_CWT(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_GPCNT - SIM General Purpose Counter Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_GPCNT - SIM General Purpose Counter Register (RW)
 *
 * Reset value: 0x0000FFFFU
 *
 * See the figure below for illustration of valid bits in the SIM General
 * Purpose Counter Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_gpcnt
{
    uint32_t U;
    struct _hw_sim_gpcnt_bitfields
    {
        uint32_t GPCNT : 16;           /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sim_gpcnt_t;

/*!
 * @name Constants and macros for entire SIM_GPCNT register
 */
/*@{*/
#define HW_SIM_GPCNT_ADDR(x)     ((uintptr_t)(x) + 0x58U)

#define HW_SIM_GPCNT(x)          (*(__IO hw_sim_gpcnt_t *) HW_SIM_GPCNT_ADDR(x))
#define HW_SIM_GPCNT_RD(x)       (HW_SIM_GPCNT(x).U)
#define HW_SIM_GPCNT_WR(x, v)    (HW_SIM_GPCNT(x).U = (v))
#define HW_SIM_GPCNT_SET(x, v)   (HW_SIM_GPCNT_WR(x, HW_SIM_GPCNT_RD(x) |  (v)))
#define HW_SIM_GPCNT_CLR(x, v)   (HW_SIM_GPCNT_WR(x, HW_SIM_GPCNT_RD(x) & ~(v)))
#define HW_SIM_GPCNT_TOG(x, v)   (HW_SIM_GPCNT_WR(x, HW_SIM_GPCNT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_GPCNT bitfields
 */

/*!
 * @name Register SIM_GPCNT, field GPCNT[15:0] (RW)
 *
 * General Purpose Counter. The value written to this register will be used to
 * compare to the general purpose counter in the SIM module. Once the General
 * purpose counter reaches this value, the GPCNT flag in the XMT_STATUS register will
 * be set. This counter is intended to be used for any events that must be
 * monitored for duration based on the card clock, receiver sample rate, or ETU rate
 * (transmit clock). Example: ATR arrival time and ATR duration. Default is 0xFFFF
 */
/*@{*/
#define BP_SIM_GPCNT_GPCNT   (0U)          /*!< Bit position for SIM_GPCNT_GPCNT. */
#define BM_SIM_GPCNT_GPCNT   (0x0000FFFFU) /*!< Bit mask for SIM_GPCNT_GPCNT. */
#define BS_SIM_GPCNT_GPCNT   (16U)         /*!< Bit field size in bits for SIM_GPCNT_GPCNT. */

/*! @brief Read current value of the SIM_GPCNT_GPCNT field. */
#define BR_SIM_GPCNT_GPCNT(x) (HW_SIM_GPCNT(x).B.GPCNT)

/*! @brief Format value for bitfield SIM_GPCNT_GPCNT. */
#define BF_SIM_GPCNT_GPCNT(v) ((uint32_t)((uint32_t)(v) << BP_SIM_GPCNT_GPCNT) & BM_SIM_GPCNT_GPCNT)

/*! @brief Set the GPCNT field to a new value. */
#define BW_SIM_GPCNT_GPCNT(x, v) (HW_SIM_GPCNT_WR(x, (HW_SIM_GPCNT_RD(x) & ~BM_SIM_GPCNT_GPCNT) | BF_SIM_GPCNT_GPCNT(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_DIVISOR - SIM Divisor Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_DIVISOR - SIM Divisor Register (RW)
 *
 * Reset value: 0x000000FFU
 *
 * See the figure below for illustration of valid bits in the SIM Divisor
 * Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_divisor
{
    uint32_t U;
    struct _hw_sim_divisor_bitfields
    {
        uint32_t DIVISOR : 8;          /*!< [7:0]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_sim_divisor_t;

/*!
 * @name Constants and macros for entire SIM_DIVISOR register
 */
/*@{*/
#define HW_SIM_DIVISOR_ADDR(x)   ((uintptr_t)(x) + 0x5CU)

#define HW_SIM_DIVISOR(x)        (*(__IO hw_sim_divisor_t *) HW_SIM_DIVISOR_ADDR(x))
#define HW_SIM_DIVISOR_RD(x)     (HW_SIM_DIVISOR(x).U)
#define HW_SIM_DIVISOR_WR(x, v)  (HW_SIM_DIVISOR(x).U = (v))
#define HW_SIM_DIVISOR_SET(x, v) (HW_SIM_DIVISOR_WR(x, HW_SIM_DIVISOR_RD(x) |  (v)))
#define HW_SIM_DIVISOR_CLR(x, v) (HW_SIM_DIVISOR_WR(x, HW_SIM_DIVISOR_RD(x) & ~(v)))
#define HW_SIM_DIVISOR_TOG(x, v) (HW_SIM_DIVISOR_WR(x, HW_SIM_DIVISOR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_DIVISOR bitfields
 */

/*!
 * @name Register SIM_DIVISOR, field DIVISOR[7:0] (RW)
 *
 * DIVISOR Register. The value written to this register will be used to generate
 * the SIM Receive clock. The BAUD_SEL[2:0] bits in the CNTL register must be
 * set to '111' in order to control the divisor value using the DIVISOR register.
 * Default is 0xFF
 */
/*@{*/
#define BP_SIM_DIVISOR_DIVISOR (0U)        /*!< Bit position for SIM_DIVISOR_DIVISOR. */
#define BM_SIM_DIVISOR_DIVISOR (0x000000FFU) /*!< Bit mask for SIM_DIVISOR_DIVISOR. */
#define BS_SIM_DIVISOR_DIVISOR (8U)        /*!< Bit field size in bits for SIM_DIVISOR_DIVISOR. */

/*! @brief Read current value of the SIM_DIVISOR_DIVISOR field. */
#define BR_SIM_DIVISOR_DIVISOR(x) (HW_SIM_DIVISOR(x).B.DIVISOR)

/*! @brief Format value for bitfield SIM_DIVISOR_DIVISOR. */
#define BF_SIM_DIVISOR_DIVISOR(v) ((uint32_t)((uint32_t)(v) << BP_SIM_DIVISOR_DIVISOR) & BM_SIM_DIVISOR_DIVISOR)

/*! @brief Set the DIVISOR field to a new value. */
#define BW_SIM_DIVISOR_DIVISOR(x, v) (HW_SIM_DIVISOR_WR(x, (HW_SIM_DIVISOR_RD(x) & ~BM_SIM_DIVISOR_DIVISOR) | BF_SIM_DIVISOR_DIVISOR(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_BWT - SIM Block Wait Time Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_BWT - SIM Block Wait Time Register (RW)
 *
 * Reset value: 0x0000FFFFU
 *
 * See the figure below for illustration of valid bits in the SIM Block Wait
 * Time Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_bwt
{
    uint32_t U;
    struct _hw_sim_bwt_bitfields
    {
        uint32_t BWT : 16;             /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sim_bwt_t;

/*!
 * @name Constants and macros for entire SIM_BWT register
 */
/*@{*/
#define HW_SIM_BWT_ADDR(x)       ((uintptr_t)(x) + 0x60U)

#define HW_SIM_BWT(x)            (*(__IO hw_sim_bwt_t *) HW_SIM_BWT_ADDR(x))
#define HW_SIM_BWT_RD(x)         (HW_SIM_BWT(x).U)
#define HW_SIM_BWT_WR(x, v)      (HW_SIM_BWT(x).U = (v))
#define HW_SIM_BWT_SET(x, v)     (HW_SIM_BWT_WR(x, HW_SIM_BWT_RD(x) |  (v)))
#define HW_SIM_BWT_CLR(x, v)     (HW_SIM_BWT_WR(x, HW_SIM_BWT_RD(x) & ~(v)))
#define HW_SIM_BWT_TOG(x, v)     (HW_SIM_BWT_WR(x, HW_SIM_BWT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_BWT bitfields
 */

/*!
 * @name Register SIM_BWT, field BWT[15:0] (RW)
 *
 * BWT Register 16 LSB. The value in this register is the block wait time 16
 * LSB. The time from START bit of last byte sent from the SIM module to the START
 * bit of the first byte sent from the SmartCard must be less than the value
 * formed by the 32-bit register composed by BWT_H and BWT registers. If it is not,
 * then the BWT flag will be set. Default is 0xFFFF
 */
/*@{*/
#define BP_SIM_BWT_BWT       (0U)          /*!< Bit position for SIM_BWT_BWT. */
#define BM_SIM_BWT_BWT       (0x0000FFFFU) /*!< Bit mask for SIM_BWT_BWT. */
#define BS_SIM_BWT_BWT       (16U)         /*!< Bit field size in bits for SIM_BWT_BWT. */

/*! @brief Read current value of the SIM_BWT_BWT field. */
#define BR_SIM_BWT_BWT(x)    (HW_SIM_BWT(x).B.BWT)

/*! @brief Format value for bitfield SIM_BWT_BWT. */
#define BF_SIM_BWT_BWT(v)    ((uint32_t)((uint32_t)(v) << BP_SIM_BWT_BWT) & BM_SIM_BWT_BWT)

/*! @brief Set the BWT field to a new value. */
#define BW_SIM_BWT_BWT(x, v) (HW_SIM_BWT_WR(x, (HW_SIM_BWT_RD(x) & ~BM_SIM_BWT_BWT) | BF_SIM_BWT_BWT(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_BGT - SIM Block Guard Time Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_BGT - SIM Block Guard Time Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * See the figure below for illustration of valid bits in the SIM Block Guard
 * Time Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_bgt
{
    uint32_t U;
    struct _hw_sim_bgt_bitfields
    {
        uint32_t BGT : 16;             /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sim_bgt_t;

/*!
 * @name Constants and macros for entire SIM_BGT register
 */
/*@{*/
#define HW_SIM_BGT_ADDR(x)       ((uintptr_t)(x) + 0x64U)

#define HW_SIM_BGT(x)            (*(__IO hw_sim_bgt_t *) HW_SIM_BGT_ADDR(x))
#define HW_SIM_BGT_RD(x)         (HW_SIM_BGT(x).U)
#define HW_SIM_BGT_WR(x, v)      (HW_SIM_BGT(x).U = (v))
#define HW_SIM_BGT_SET(x, v)     (HW_SIM_BGT_WR(x, HW_SIM_BGT_RD(x) |  (v)))
#define HW_SIM_BGT_CLR(x, v)     (HW_SIM_BGT_WR(x, HW_SIM_BGT_RD(x) & ~(v)))
#define HW_SIM_BGT_TOG(x, v)     (HW_SIM_BGT_WR(x, HW_SIM_BGT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_BGT bitfields
 */

/*!
 * @name Register SIM_BGT, field BGT[15:0] (RW)
 *
 * BGT Register. The value in this register is the block guard time. Time from
 * START bit of last byte sent from the SIM module to the START bit of the first
 * byte sent from the SmartCard must be greater than this value. If it is not,
 * then the BGT flag will be set. Default is 0x0000
 */
/*@{*/
#define BP_SIM_BGT_BGT       (0U)          /*!< Bit position for SIM_BGT_BGT. */
#define BM_SIM_BGT_BGT       (0x0000FFFFU) /*!< Bit mask for SIM_BGT_BGT. */
#define BS_SIM_BGT_BGT       (16U)         /*!< Bit field size in bits for SIM_BGT_BGT. */

/*! @brief Read current value of the SIM_BGT_BGT field. */
#define BR_SIM_BGT_BGT(x)    (HW_SIM_BGT(x).B.BGT)

/*! @brief Format value for bitfield SIM_BGT_BGT. */
#define BF_SIM_BGT_BGT(v)    ((uint32_t)((uint32_t)(v) << BP_SIM_BGT_BGT) & BM_SIM_BGT_BGT)

/*! @brief Set the BGT field to a new value. */
#define BW_SIM_BGT_BGT(x, v) (HW_SIM_BGT_WR(x, (HW_SIM_BGT_RD(x) & ~BM_SIM_BGT_BGT) | BF_SIM_BGT_BGT(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_BWT_H - SIM Block Wait Time Register HIGH
 ******************************************************************************/

/*!
 * @brief HW_SIM_BWT_H - SIM Block Wait Time Register HIGH (RW)
 *
 * Reset value: 0x0000FFFFU
 *
 * See the figure below for illustration of valid bits in the SIM Block Wait
 * Time Register HIGH and the table below for description of the bit fields.
 */
typedef union _hw_sim_bwt_h
{
    uint32_t U;
    struct _hw_sim_bwt_h_bitfields
    {
        uint32_t BWT_H : 16;           /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_sim_bwt_h_t;

/*!
 * @name Constants and macros for entire SIM_BWT_H register
 */
/*@{*/
#define HW_SIM_BWT_H_ADDR(x)     ((uintptr_t)(x) + 0x68U)

#define HW_SIM_BWT_H(x)          (*(__IO hw_sim_bwt_h_t *) HW_SIM_BWT_H_ADDR(x))
#define HW_SIM_BWT_H_RD(x)       (HW_SIM_BWT_H(x).U)
#define HW_SIM_BWT_H_WR(x, v)    (HW_SIM_BWT_H(x).U = (v))
#define HW_SIM_BWT_H_SET(x, v)   (HW_SIM_BWT_H_WR(x, HW_SIM_BWT_H_RD(x) |  (v)))
#define HW_SIM_BWT_H_CLR(x, v)   (HW_SIM_BWT_H_WR(x, HW_SIM_BWT_H_RD(x) & ~(v)))
#define HW_SIM_BWT_H_TOG(x, v)   (HW_SIM_BWT_H_WR(x, HW_SIM_BWT_H_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SIM_BWT_H bitfields
 */

/*!
 * @name Register SIM_BWT_H, field BWT_H[15:0] (RW)
 *
 * BWT Register 16 MSB. The value in this register is the block wait time 16
 * MSB. The time from START bit of last byte sent from the SIM module to the START
 * bit of the first byte sent from the SmartCard must be less than the value
 * formed by the 32-bit register composed by BWT_H and BWT registers. If it is not,
 * then the BWT flag is set. Default is 0xFFFF
 */
/*@{*/
#define BP_SIM_BWT_H_BWT_H   (0U)          /*!< Bit position for SIM_BWT_H_BWT_H. */
#define BM_SIM_BWT_H_BWT_H   (0x0000FFFFU) /*!< Bit mask for SIM_BWT_H_BWT_H. */
#define BS_SIM_BWT_H_BWT_H   (16U)         /*!< Bit field size in bits for SIM_BWT_H_BWT_H. */

/*! @brief Read current value of the SIM_BWT_H_BWT_H field. */
#define BR_SIM_BWT_H_BWT_H(x) (HW_SIM_BWT_H(x).B.BWT_H)

/*! @brief Format value for bitfield SIM_BWT_H_BWT_H. */
#define BF_SIM_BWT_H_BWT_H(v) ((uint32_t)((uint32_t)(v) << BP_SIM_BWT_H_BWT_H) & BM_SIM_BWT_H_BWT_H)

/*! @brief Set the BWT_H field to a new value. */
#define BW_SIM_BWT_H_BWT_H(x, v) (HW_SIM_BWT_H_WR(x, (HW_SIM_BWT_H_RD(x) & ~BM_SIM_BWT_H_BWT_H) | BF_SIM_BWT_H_BWT_H(v)))
/*@}*/

/*******************************************************************************
 * HW_SIM_XMT_FIFO_STAT - SIM Transmit FIFO Status Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_XMT_FIFO_STAT - SIM Transmit FIFO Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * See the figure below for illustration of valid bits in the SIM Transmit FIFO
 * Status Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_xmt_fifo_stat
{
    uint32_t U;
    struct _hw_sim_xmt_fifo_stat_bitfields
    {
        uint32_t XMT_RPTR : 4;         /*!< [3:0]  */
        uint32_t XMT_WPTR : 4;         /*!< [7:4]  */
        uint32_t XMT_CNT : 4;          /*!< [11:8]  */
        uint32_t RESERVED0 : 20;       /*!< [31:12]  */
    } B;
} hw_sim_xmt_fifo_stat_t;

/*!
 * @name Constants and macros for entire SIM_XMT_FIFO_STAT register
 */
/*@{*/
#define HW_SIM_XMT_FIFO_STAT_ADDR(x) ((uintptr_t)(x) + 0x6CU)

#define HW_SIM_XMT_FIFO_STAT(x)  (*(__I hw_sim_xmt_fifo_stat_t *) HW_SIM_XMT_FIFO_STAT_ADDR(x))
#define HW_SIM_XMT_FIFO_STAT_RD(x) (HW_SIM_XMT_FIFO_STAT(x).U)
/*@}*/

/*
 * Constants & macros for individual SIM_XMT_FIFO_STAT bitfields
 */

/*!
 * @name Register SIM_XMT_FIFO_STAT, field XMT_RPTR[3:0] (RO)
 *
 * These bits indicate the transmit FIFO Read Pointer.
 */
/*@{*/
#define BP_SIM_XMT_FIFO_STAT_XMT_RPTR (0U) /*!< Bit position for SIM_XMT_FIFO_STAT_XMT_RPTR. */
#define BM_SIM_XMT_FIFO_STAT_XMT_RPTR (0x0000000FU) /*!< Bit mask for SIM_XMT_FIFO_STAT_XMT_RPTR. */
#define BS_SIM_XMT_FIFO_STAT_XMT_RPTR (4U) /*!< Bit field size in bits for SIM_XMT_FIFO_STAT_XMT_RPTR. */

/*! @brief Read current value of the SIM_XMT_FIFO_STAT_XMT_RPTR field. */
#define BR_SIM_XMT_FIFO_STAT_XMT_RPTR(x) (HW_SIM_XMT_FIFO_STAT(x).B.XMT_RPTR)
/*@}*/

/*!
 * @name Register SIM_XMT_FIFO_STAT, field XMT_WPTR[7:4] (RO)
 *
 * These bits indicate the transmit FIFO Write Pointer.
 */
/*@{*/
#define BP_SIM_XMT_FIFO_STAT_XMT_WPTR (4U) /*!< Bit position for SIM_XMT_FIFO_STAT_XMT_WPTR. */
#define BM_SIM_XMT_FIFO_STAT_XMT_WPTR (0x000000F0U) /*!< Bit mask for SIM_XMT_FIFO_STAT_XMT_WPTR. */
#define BS_SIM_XMT_FIFO_STAT_XMT_WPTR (4U) /*!< Bit field size in bits for SIM_XMT_FIFO_STAT_XMT_WPTR. */

/*! @brief Read current value of the SIM_XMT_FIFO_STAT_XMT_WPTR field. */
#define BR_SIM_XMT_FIFO_STAT_XMT_WPTR(x) (HW_SIM_XMT_FIFO_STAT(x).B.XMT_WPTR)
/*@}*/

/*!
 * @name Register SIM_XMT_FIFO_STAT, field XMT_CNT[11:8] (RO)
 *
 * These bits indicate the number of Bytes in the transmit FIFO. '0' value means
 * FIFO is empty or full.
 */
/*@{*/
#define BP_SIM_XMT_FIFO_STAT_XMT_CNT (8U)  /*!< Bit position for SIM_XMT_FIFO_STAT_XMT_CNT. */
#define BM_SIM_XMT_FIFO_STAT_XMT_CNT (0x00000F00U) /*!< Bit mask for SIM_XMT_FIFO_STAT_XMT_CNT. */
#define BS_SIM_XMT_FIFO_STAT_XMT_CNT (4U)  /*!< Bit field size in bits for SIM_XMT_FIFO_STAT_XMT_CNT. */

/*! @brief Read current value of the SIM_XMT_FIFO_STAT_XMT_CNT field. */
#define BR_SIM_XMT_FIFO_STAT_XMT_CNT(x) (HW_SIM_XMT_FIFO_STAT(x).B.XMT_CNT)
/*@}*/

/*******************************************************************************
 * HW_SIM_RCV_FIFO_CNT - SIM Receive FIFO Counter Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_RCV_FIFO_CNT - SIM Receive FIFO Counter Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * See the figure below for illustration of valid bits in the SIM Receiver FIFO
 * Counter Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_rcv_fifo_cnt
{
    uint32_t U;
    struct _hw_sim_rcv_fifo_cnt_bitfields
    {
        uint32_t RCV_CNT : 9;          /*!< [8:0]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_sim_rcv_fifo_cnt_t;

/*!
 * @name Constants and macros for entire SIM_RCV_FIFO_CNT register
 */
/*@{*/
#define HW_SIM_RCV_FIFO_CNT_ADDR(x) ((uintptr_t)(x) + 0x70U)

#define HW_SIM_RCV_FIFO_CNT(x)   (*(__I hw_sim_rcv_fifo_cnt_t *) HW_SIM_RCV_FIFO_CNT_ADDR(x))
#define HW_SIM_RCV_FIFO_CNT_RD(x) (HW_SIM_RCV_FIFO_CNT(x).U)
/*@}*/

/*
 * Constants & macros for individual SIM_RCV_FIFO_CNT bitfields
 */

/*!
 * @name Register SIM_RCV_FIFO_CNT, field RCV_CNT[8:0] (RO)
 *
 * These bits indicate the number of Byte can be written into the receive FIFO.
 * 0 value means FIFO is empty or full.
 */
/*@{*/
#define BP_SIM_RCV_FIFO_CNT_RCV_CNT (0U)   /*!< Bit position for SIM_RCV_FIFO_CNT_RCV_CNT. */
#define BM_SIM_RCV_FIFO_CNT_RCV_CNT (0x000001FFU) /*!< Bit mask for SIM_RCV_FIFO_CNT_RCV_CNT. */
#define BS_SIM_RCV_FIFO_CNT_RCV_CNT (9U)   /*!< Bit field size in bits for SIM_RCV_FIFO_CNT_RCV_CNT. */

/*! @brief Read current value of the SIM_RCV_FIFO_CNT_RCV_CNT field. */
#define BR_SIM_RCV_FIFO_CNT_RCV_CNT(x) (HW_SIM_RCV_FIFO_CNT(x).B.RCV_CNT)
/*@}*/

/*******************************************************************************
 * HW_SIM_RCV_FIFO_WPTR - SIM Receive FIFO Write Pointer Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_RCV_FIFO_WPTR - SIM Receive FIFO Write Pointer Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * See the figure below for illustration of valid bits in the SIM Receive FIFO
 * Write Pointer Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_rcv_fifo_wptr
{
    uint32_t U;
    struct _hw_sim_rcv_fifo_wptr_bitfields
    {
        uint32_t RCV_WPTR : 9;         /*!< [8:0]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_sim_rcv_fifo_wptr_t;

/*!
 * @name Constants and macros for entire SIM_RCV_FIFO_WPTR register
 */
/*@{*/
#define HW_SIM_RCV_FIFO_WPTR_ADDR(x) ((uintptr_t)(x) + 0x74U)

#define HW_SIM_RCV_FIFO_WPTR(x)  (*(__I hw_sim_rcv_fifo_wptr_t *) HW_SIM_RCV_FIFO_WPTR_ADDR(x))
#define HW_SIM_RCV_FIFO_WPTR_RD(x) (HW_SIM_RCV_FIFO_WPTR(x).U)
/*@}*/

/*
 * Constants & macros for individual SIM_RCV_FIFO_WPTR bitfields
 */

/*!
 * @name Register SIM_RCV_FIFO_WPTR, field RCV_WPTR[8:0] (RO)
 *
 * These bits indicate the receive FIFO Write pointer.
 */
/*@{*/
#define BP_SIM_RCV_FIFO_WPTR_RCV_WPTR (0U) /*!< Bit position for SIM_RCV_FIFO_WPTR_RCV_WPTR. */
#define BM_SIM_RCV_FIFO_WPTR_RCV_WPTR (0x000001FFU) /*!< Bit mask for SIM_RCV_FIFO_WPTR_RCV_WPTR. */
#define BS_SIM_RCV_FIFO_WPTR_RCV_WPTR (9U) /*!< Bit field size in bits for SIM_RCV_FIFO_WPTR_RCV_WPTR. */

/*! @brief Read current value of the SIM_RCV_FIFO_WPTR_RCV_WPTR field. */
#define BR_SIM_RCV_FIFO_WPTR_RCV_WPTR(x) (HW_SIM_RCV_FIFO_WPTR(x).B.RCV_WPTR)
/*@}*/

/*******************************************************************************
 * HW_SIM_RCV_FIFO_RPTR - SIM Receive FIFO Read Pointer Register
 ******************************************************************************/

/*!
 * @brief HW_SIM_RCV_FIFO_RPTR - SIM Receive FIFO Read Pointer Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * See the figure below for illustration of valid bits in the SIM Receive FIFO
 * Read Pointer Register and the table below for description of the bit fields.
 */
typedef union _hw_sim_rcv_fifo_rptr
{
    uint32_t U;
    struct _hw_sim_rcv_fifo_rptr_bitfields
    {
        uint32_t RCV_RPTR : 9;         /*!< [8:0]  */
        uint32_t RESERVED0 : 23;       /*!< [31:9]  */
    } B;
} hw_sim_rcv_fifo_rptr_t;

/*!
 * @name Constants and macros for entire SIM_RCV_FIFO_RPTR register
 */
/*@{*/
#define HW_SIM_RCV_FIFO_RPTR_ADDR(x) ((uintptr_t)(x) + 0x78U)

#define HW_SIM_RCV_FIFO_RPTR(x)  (*(__I hw_sim_rcv_fifo_rptr_t *) HW_SIM_RCV_FIFO_RPTR_ADDR(x))
#define HW_SIM_RCV_FIFO_RPTR_RD(x) (HW_SIM_RCV_FIFO_RPTR(x).U)
/*@}*/

/*
 * Constants & macros for individual SIM_RCV_FIFO_RPTR bitfields
 */

/*!
 * @name Register SIM_RCV_FIFO_RPTR, field RCV_RPTR[8:0] (RO)
 *
 * These bits indicate the receiver FIFO read pointer.
 */
/*@{*/
#define BP_SIM_RCV_FIFO_RPTR_RCV_RPTR (0U) /*!< Bit position for SIM_RCV_FIFO_RPTR_RCV_RPTR. */
#define BM_SIM_RCV_FIFO_RPTR_RCV_RPTR (0x000001FFU) /*!< Bit mask for SIM_RCV_FIFO_RPTR_RCV_RPTR. */
#define BS_SIM_RCV_FIFO_RPTR_RCV_RPTR (9U) /*!< Bit field size in bits for SIM_RCV_FIFO_RPTR_RCV_RPTR. */

/*! @brief Read current value of the SIM_RCV_FIFO_RPTR_RCV_RPTR field. */
#define BR_SIM_RCV_FIFO_RPTR_RCV_RPTR(x) (HW_SIM_RCV_FIFO_RPTR(x).B.RCV_RPTR)
/*@}*/

/*******************************************************************************
 * hw_sim_t - module struct
 ******************************************************************************/
/*!
 * @brief All SIM module registers.
 */
#pragma pack(1)
typedef struct _hw_sim
{
    __IO hw_sim_port1_cntl_t PORT1_CNTL;   /*!< [0x0] SIM Port1 Control Register */
    __IO hw_sim_setup_t SETUP;             /*!< [0x4] SIM Setup Register */
    __IO hw_sim_port1_detect_t PORT1_DETECT; /*!< [0x8] SIM Port 1 Detect Register */
    __IO hw_sim_xmt_buf_t XMT_BUF;         /*!< [0xC] SIM Transmit Buffer Register */
    __I hw_sim_rcv_buf_t RCV_BUF;          /*!< [0x10] SIM Receive Buffer Register */
    __IO hw_sim_port0_cntl_t PORT0_CNTL;   /*!< [0x14] SIM Port0 Control Register */
    __IO hw_sim_cntl_t CNTL;               /*!< [0x18] SIM Control Register */
    __IO hw_sim_clk_prescaler_t CLK_PRESCALER; /*!< [0x1C] SIM Clock Prescaler Register */
    __IO hw_sim_rcv_threshold_t RCV_THRESHOLD; /*!< [0x20] SIM Receive Threshold Register */
    __IO hw_sim_enable_t ENABLE;           /*!< [0x24] SIM Enable Register */
    __IO hw_sim_xmt_status_t XMT_STATUS;   /*!< [0x28] SIM Transmit Status Register */
    __IO hw_sim_rcv_status_t RCV_STATUS;   /*!< [0x2C] SIM Receive Status Register */
    __IO hw_sim_int_mask_t INT_MASK;       /*!< [0x30] SIM Interrupt Mask Register */
    uint8_t _reserved0[8];
    __IO hw_sim_port0_detect_t PORT0_DETECT; /*!< [0x3C] SIM Port0 Detect Register */
    __IO hw_sim_data_format_t DATA_FORMAT; /*!< [0x40] SIM Data Format Register */
    __IO hw_sim_xmt_threshold_t XMT_THRESHOLD; /*!< [0x44] SIM Transmit Threshold Register */
    __IO hw_sim_guard_cntl_t GUARD_CNTL;   /*!< [0x48] SIM Transmit Guard Control Register */
    __IO hw_sim_od_config_t OD_CONFIG;     /*!< [0x4C] SIM Open Drain Configuration Control Register */
    __IO hw_sim_reset_cntl_t RESET_CNTL;   /*!< [0x50] SIM Reset Control Register */
    __IO hw_sim_char_wait_t CHAR_WAIT;     /*!< [0x54] SIM Character Wait Time Register */
    __IO hw_sim_gpcnt_t GPCNT;             /*!< [0x58] SIM General Purpose Counter Register */
    __IO hw_sim_divisor_t DIVISOR;         /*!< [0x5C] SIM Divisor Register */
    __IO hw_sim_bwt_t BWT;                 /*!< [0x60] SIM Block Wait Time Register */
    __IO hw_sim_bgt_t BGT;                 /*!< [0x64] SIM Block Guard Time Register */
    __IO hw_sim_bwt_h_t BWT_H;             /*!< [0x68] SIM Block Wait Time Register HIGH */
    __I hw_sim_xmt_fifo_stat_t XMT_FIFO_STAT; /*!< [0x6C] SIM Transmit FIFO Status Register */
    __I hw_sim_rcv_fifo_cnt_t RCV_FIFO_CNT; /*!< [0x70] SIM Receive FIFO Counter Register */
    __I hw_sim_rcv_fifo_wptr_t RCV_FIFO_WPTR; /*!< [0x74] SIM Receive FIFO Write Pointer Register */
    __I hw_sim_rcv_fifo_rptr_t RCV_FIFO_RPTR; /*!< [0x78] SIM Receive FIFO Read Pointer Register */
} hw_sim_t;
#pragma pack()

/*! @brief Macro to access all SIM registers. */
/*! @param x SIM module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_SIM_REGS(SIM1_BASE)</code>. */
#define HW_SIM_REGS(x) (*(hw_sim_t *)(x))

/*
 * iMX7D SJC
 *
 * System JTAG Controller (SJC)
 *
 * Registers defined in this header file:
 * - HW_SJC_GPUSR1 - General Purpose Unsecured Status Register 1
 * - HW_SJC_GPUSR2 - General Purpose Unsecured Status Register 2
 * - HW_SJC_GPUSR3 - General Purpose Unsecured Status Register 3
 * - HW_SJC_GPSSR - General Purpose Secured Status Register
 * - HW_SJC_DCR - Debug Control Register
 * - HW_SJC_SSR - Security Status Register
 * - HW_SJC_GPCCR - General Purpose Clocks Control Register
 *
 * - hw_sjc_t - Struct containing all module registers.
 */

#define HW_SJC_INSTANCE_COUNT (1U) /*!< Number of instances of the SJC module. */
#define HW_SJC (0U) /*!< Instance number for SJC. */
#define SJC_BASE              (0x0U) /*!< Base address for SJC. */
/*! Array initializer of SJC base addresses. */
#define SJC_BASE_ADDRS        { SJC_BASE }

/*******************************************************************************
 * HW_SJC_GPUSR1 - General Purpose Unsecured Status Register 1
 ******************************************************************************/

/*!
 * @brief HW_SJC_GPUSR1 - General Purpose Unsecured Status Register 1 (RO)
 *
 * Reset value: 0x00000000U
 *
 * The General Purpose Unsecured Status Register 1 is a read only register used
 * to check the status of the different Cores and of the PLL. The rest of its
 * bits are for general purpose use.
 */
typedef union _hw_sjc_gpusr1
{
    uint32_t U;
    struct _hw_sjc_gpusr1_bitfields
    {
        uint32_t A_DBG : 1;            /*!< [0]  */
        uint32_t A_WFI : 1;            /*!< [1]  */
        uint32_t S_STAT : 3;           /*!< [4:2]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t PLL_LOCK : 1;         /*!< [8]  */
        uint32_t RESERVED1 : 23;       /*!< [31:9]  */
    } B;
} hw_sjc_gpusr1_t;

/*!
 * @name Constants and macros for entire SJC_GPUSR1 register
 */
/*@{*/
#define HW_SJC_GPUSR1_ADDR(x)    ((uintptr_t)(x) + 0x0U)

#define HW_SJC_GPUSR1(x)         (*(__I hw_sjc_gpusr1_t *) HW_SJC_GPUSR1_ADDR(x))
#define HW_SJC_GPUSR1_RD(x)      (HW_SJC_GPUSR1(x).U)
/*@}*/

/*
 * Constants & macros for individual SJC_GPUSR1 bitfields
 */

/*!
 * @name Register SJC_GPUSR1, field A_DBG[0] (RO)
 *
 * ARM core debug status bit Bit 0 is the ARM core DBGACK (debug acknowledge)
 * DBGACK can be overwritten in the ARM core DCR to force a particular DBGACK
 * value. Consequently interpretation of the DBGACK value is highly dependent on the
 * debug sequence. When this bit is HIGH, ARM core is in debug.
 */
/*@{*/
#define BP_SJC_GPUSR1_A_DBG  (0U)          /*!< Bit position for SJC_GPUSR1_A_DBG. */
#define BM_SJC_GPUSR1_A_DBG  (0x00000001U) /*!< Bit mask for SJC_GPUSR1_A_DBG. */
#define BS_SJC_GPUSR1_A_DBG  (1U)          /*!< Bit field size in bits for SJC_GPUSR1_A_DBG. */

/*! @brief Read current value of the SJC_GPUSR1_A_DBG field. */
#define BR_SJC_GPUSR1_A_DBG(x) (HW_SJC_GPUSR1(x).B.A_DBG)
/*@}*/

/*!
 * @name Register SJC_GPUSR1, field A_WFI[1] (RO)
 *
 * ARM core wait-for interrupt bit Bit 1 is the ARM core standbywfi (stand by
 * wait-for interrupt). When this bit is HIGH, ARM core is in wait for interrupt
 * mode.
 */
/*@{*/
#define BP_SJC_GPUSR1_A_WFI  (1U)          /*!< Bit position for SJC_GPUSR1_A_WFI. */
#define BM_SJC_GPUSR1_A_WFI  (0x00000002U) /*!< Bit mask for SJC_GPUSR1_A_WFI. */
#define BS_SJC_GPUSR1_A_WFI  (1U)          /*!< Bit field size in bits for SJC_GPUSR1_A_WFI. */

/*! @brief Read current value of the SJC_GPUSR1_A_WFI field. */
#define BR_SJC_GPUSR1_A_WFI(x) (HW_SJC_GPUSR1(x).B.A_WFI)
/*@}*/

/*!
 * @name Register SJC_GPUSR1, field S_STAT[4:2] (RO)
 *
 * 3 LSBits of SDMA core statusH.
 */
/*@{*/
#define BP_SJC_GPUSR1_S_STAT (2U)          /*!< Bit position for SJC_GPUSR1_S_STAT. */
#define BM_SJC_GPUSR1_S_STAT (0x0000001CU) /*!< Bit mask for SJC_GPUSR1_S_STAT. */
#define BS_SJC_GPUSR1_S_STAT (3U)          /*!< Bit field size in bits for SJC_GPUSR1_S_STAT. */

/*! @brief Read current value of the SJC_GPUSR1_S_STAT field. */
#define BR_SJC_GPUSR1_S_STAT(x) (HW_SJC_GPUSR1(x).B.S_STAT)
/*@}*/

/*!
 * @name Register SJC_GPUSR1, field PLL_LOCK[8] (RO)
 *
 * PLL_LOCK A Combined PLL-Lock flag indicator, for all the PLL's.
 */
/*@{*/
#define BP_SJC_GPUSR1_PLL_LOCK (8U)        /*!< Bit position for SJC_GPUSR1_PLL_LOCK. */
#define BM_SJC_GPUSR1_PLL_LOCK (0x00000100U) /*!< Bit mask for SJC_GPUSR1_PLL_LOCK. */
#define BS_SJC_GPUSR1_PLL_LOCK (1U)        /*!< Bit field size in bits for SJC_GPUSR1_PLL_LOCK. */

/*! @brief Read current value of the SJC_GPUSR1_PLL_LOCK field. */
#define BR_SJC_GPUSR1_PLL_LOCK(x) (HW_SJC_GPUSR1(x).B.PLL_LOCK)
/*@}*/

/*******************************************************************************
 * HW_SJC_GPUSR2 - General Purpose Unsecured Status Register 2
 ******************************************************************************/

/*!
 * @brief HW_SJC_GPUSR2 - General Purpose Unsecured Status Register 2 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sjc_gpusr2
{
    uint32_t U;
    struct _hw_sjc_gpusr2_bitfields
    {
        uint32_t STBYWFI : 4;          /*!< [3:0]  */
        uint32_t S_STAT : 4;           /*!< [7:4]  */
        uint32_t STBYWFE : 4;          /*!< [11:8]  */
        uint32_t RESERVED0 : 20;       /*!< [31:12]  */
    } B;
} hw_sjc_gpusr2_t;

/*!
 * @name Constants and macros for entire SJC_GPUSR2 register
 */
/*@{*/
#define HW_SJC_GPUSR2_ADDR(x)    ((uintptr_t)(x) + 0x4U)

#define HW_SJC_GPUSR2(x)         (*(__I hw_sjc_gpusr2_t *) HW_SJC_GPUSR2_ADDR(x))
#define HW_SJC_GPUSR2_RD(x)      (HW_SJC_GPUSR2(x).U)
/*@}*/

/*
 * Constants & macros for individual SJC_GPUSR2 bitfields
 */

/*!
 * @name Register SJC_GPUSR2, field STBYWFI[3:0] (RO)
 *
 * STBYWFI[3:0] These bits provide status of "Standby Wait-For-Interrupt" state
 * of all ARM cores.
 */
/*@{*/
#define BP_SJC_GPUSR2_STBYWFI (0U)         /*!< Bit position for SJC_GPUSR2_STBYWFI. */
#define BM_SJC_GPUSR2_STBYWFI (0x0000000FU) /*!< Bit mask for SJC_GPUSR2_STBYWFI. */
#define BS_SJC_GPUSR2_STBYWFI (4U)         /*!< Bit field size in bits for SJC_GPUSR2_STBYWFI. */

/*! @brief Read current value of the SJC_GPUSR2_STBYWFI field. */
#define BR_SJC_GPUSR2_STBYWFI(x) (HW_SJC_GPUSR2(x).B.STBYWFI)
/*@}*/

/*!
 * @name Register SJC_GPUSR2, field S_STAT[7:4] (RO)
 *
 * S_STAT[3:0] SDMA debug status bits: debug_core_state[3:0]
 */
/*@{*/
#define BP_SJC_GPUSR2_S_STAT (4U)          /*!< Bit position for SJC_GPUSR2_S_STAT. */
#define BM_SJC_GPUSR2_S_STAT (0x000000F0U) /*!< Bit mask for SJC_GPUSR2_S_STAT. */
#define BS_SJC_GPUSR2_S_STAT (4U)          /*!< Bit field size in bits for SJC_GPUSR2_S_STAT. */

/*! @brief Read current value of the SJC_GPUSR2_S_STAT field. */
#define BR_SJC_GPUSR2_S_STAT(x) (HW_SJC_GPUSR2(x).B.S_STAT)
/*@}*/

/*!
 * @name Register SJC_GPUSR2, field STBYWFE[11:8] (RO)
 *
 * STBYWFE[3:0] Reflecting the "Standby Wait For Event" signals of all cores.
 */
/*@{*/
#define BP_SJC_GPUSR2_STBYWFE (8U)         /*!< Bit position for SJC_GPUSR2_STBYWFE. */
#define BM_SJC_GPUSR2_STBYWFE (0x00000F00U) /*!< Bit mask for SJC_GPUSR2_STBYWFE. */
#define BS_SJC_GPUSR2_STBYWFE (4U)         /*!< Bit field size in bits for SJC_GPUSR2_STBYWFE. */

/*! @brief Read current value of the SJC_GPUSR2_STBYWFE field. */
#define BR_SJC_GPUSR2_STBYWFE(x) (HW_SJC_GPUSR2(x).B.STBYWFE)
/*@}*/

/*******************************************************************************
 * HW_SJC_GPUSR3 - General Purpose Unsecured Status Register 3
 ******************************************************************************/

/*!
 * @brief HW_SJC_GPUSR3 - General Purpose Unsecured Status Register 3 (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_sjc_gpusr3
{
    uint32_t U;
    struct _hw_sjc_gpusr3_bitfields
    {
        uint32_t IPG_WAIT : 1;         /*!< [0]  */
        uint32_t IPG_STOP : 1;         /*!< [1]  */
        uint32_t SYS_WAIT : 1;         /*!< [2]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_sjc_gpusr3_t;

/*!
 * @name Constants and macros for entire SJC_GPUSR3 register
 */
/*@{*/
#define HW_SJC_GPUSR3_ADDR(x)    ((uintptr_t)(x) + 0x8U)

#define HW_SJC_GPUSR3(x)         (*(__I hw_sjc_gpusr3_t *) HW_SJC_GPUSR3_ADDR(x))
#define HW_SJC_GPUSR3_RD(x)      (HW_SJC_GPUSR3(x).U)
/*@}*/

/*
 * Constants & macros for individual SJC_GPUSR3 bitfields
 */

/*!
 * @name Register SJC_GPUSR3, field IPG_WAIT[0] (RO)
 *
 * IPG_WAIT CCM's "ipg_wait" signal indication
 */
/*@{*/
#define BP_SJC_GPUSR3_IPG_WAIT (0U)        /*!< Bit position for SJC_GPUSR3_IPG_WAIT. */
#define BM_SJC_GPUSR3_IPG_WAIT (0x00000001U) /*!< Bit mask for SJC_GPUSR3_IPG_WAIT. */
#define BS_SJC_GPUSR3_IPG_WAIT (1U)        /*!< Bit field size in bits for SJC_GPUSR3_IPG_WAIT. */

/*! @brief Read current value of the SJC_GPUSR3_IPG_WAIT field. */
#define BR_SJC_GPUSR3_IPG_WAIT(x) (HW_SJC_GPUSR3(x).B.IPG_WAIT)
/*@}*/

/*!
 * @name Register SJC_GPUSR3, field IPG_STOP[1] (RO)
 *
 * IPG_STOP CCM's "ipg_stop" signal indication
 */
/*@{*/
#define BP_SJC_GPUSR3_IPG_STOP (1U)        /*!< Bit position for SJC_GPUSR3_IPG_STOP. */
#define BM_SJC_GPUSR3_IPG_STOP (0x00000002U) /*!< Bit mask for SJC_GPUSR3_IPG_STOP. */
#define BS_SJC_GPUSR3_IPG_STOP (1U)        /*!< Bit field size in bits for SJC_GPUSR3_IPG_STOP. */

/*! @brief Read current value of the SJC_GPUSR3_IPG_STOP field. */
#define BR_SJC_GPUSR3_IPG_STOP(x) (HW_SJC_GPUSR3(x).B.IPG_STOP)
/*@}*/

/*!
 * @name Register SJC_GPUSR3, field SYS_WAIT[2] (RO)
 *
 * System In wait Indication on System in wait mode (from CCM).
 */
/*@{*/
#define BP_SJC_GPUSR3_SYS_WAIT (2U)        /*!< Bit position for SJC_GPUSR3_SYS_WAIT. */
#define BM_SJC_GPUSR3_SYS_WAIT (0x00000004U) /*!< Bit mask for SJC_GPUSR3_SYS_WAIT. */
#define BS_SJC_GPUSR3_SYS_WAIT (1U)        /*!< Bit field size in bits for SJC_GPUSR3_SYS_WAIT. */

/*! @brief Read current value of the SJC_GPUSR3_SYS_WAIT field. */
#define BR_SJC_GPUSR3_SYS_WAIT(x) (HW_SJC_GPUSR3(x).B.SYS_WAIT)
/*@}*/

/*******************************************************************************
 * HW_SJC_GPSSR - General Purpose Secured Status Register
 ******************************************************************************/

/*!
 * @brief HW_SJC_GPSSR - General Purpose Secured Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The General Purpose Secured Status Register is a read-only register used to
 * check the status of the different critical information in the SoC. This
 * register cannot be accessed in secure modes.
 */
typedef union _hw_sjc_gpssr
{
    uint32_t U;
    struct _hw_sjc_gpssr_bitfields
    {
        uint32_t GPSSR : 32;           /*!< [31:0]  */
    } B;
} hw_sjc_gpssr_t;

/*!
 * @name Constants and macros for entire SJC_GPSSR register
 */
/*@{*/
#define HW_SJC_GPSSR_ADDR(x)     ((uintptr_t)(x) + 0xCU)

#define HW_SJC_GPSSR(x)          (*(__I hw_sjc_gpssr_t *) HW_SJC_GPSSR_ADDR(x))
#define HW_SJC_GPSSR_RD(x)       (HW_SJC_GPSSR(x).U)
/*@}*/

/*
 * Constants & macros for individual SJC_GPSSR bitfields
 */

/*!
 * @name Register SJC_GPSSR, field GPSSR[31:0] (RO)
 *
 * General Purpose Secured Status Register Register is used for testing and
 * debug.
 */
/*@{*/
#define BP_SJC_GPSSR_GPSSR   (0U)          /*!< Bit position for SJC_GPSSR_GPSSR. */
#define BM_SJC_GPSSR_GPSSR   (0xFFFFFFFFU) /*!< Bit mask for SJC_GPSSR_GPSSR. */
#define BS_SJC_GPSSR_GPSSR   (32U)         /*!< Bit field size in bits for SJC_GPSSR_GPSSR. */

/*! @brief Read current value of the SJC_GPSSR_GPSSR field. */
#define BR_SJC_GPSSR_GPSSR(x) (HW_SJC_GPSSR(x).U)
/*@}*/

/*******************************************************************************
 * HW_SJC_DCR - Debug Control Register
 ******************************************************************************/

/*!
 * @brief HW_SJC_DCR - Debug Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to control propagation of debug request from DE_B pad
 * to the cores and debug signals from internal logic to the DE_B pad.
 */
typedef union _hw_sjc_dcr
{
    uint32_t U;
    struct _hw_sjc_dcr_bitfields
    {
        uint32_t DE_TO_ARM : 1;        /*!< [0]  */
        uint32_t DE_TO_SDMA : 1;       /*!< [1]  */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t DEBUG_OBS : 1;        /*!< [3]  */
        uint32_t RESERVED1 : 1;        /*!< [4]  */
        uint32_t DIRECT_SDMA_REQ_EN : 1; /*!< [5]  */
        uint32_t DIRECT_ARM_REQ_EN : 1; /*!< [6]  */
        uint32_t RESERVED2 : 25;       /*!< [31:7]  */
    } B;
} hw_sjc_dcr_t;

/*!
 * @name Constants and macros for entire SJC_DCR register
 */
/*@{*/
#define HW_SJC_DCR_ADDR(x)       ((uintptr_t)(x) + 0x10U)

#define HW_SJC_DCR(x)            (*(__IO hw_sjc_dcr_t *) HW_SJC_DCR_ADDR(x))
#define HW_SJC_DCR_RD(x)         (HW_SJC_DCR(x).U)
#define HW_SJC_DCR_WR(x, v)      (HW_SJC_DCR(x).U = (v))
#define HW_SJC_DCR_SET(x, v)     (HW_SJC_DCR_WR(x, HW_SJC_DCR_RD(x) |  (v)))
#define HW_SJC_DCR_CLR(x, v)     (HW_SJC_DCR_WR(x, HW_SJC_DCR_RD(x) & ~(v)))
#define HW_SJC_DCR_TOG(x, v)     (HW_SJC_DCR_WR(x, HW_SJC_DCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SJC_DCR bitfields
 */

/*!
 * @name Register SJC_DCR, field DE_TO_ARM[0] (RW)
 *
 * ARM platform debug request input propagation This bit controls the
 * propagation of debug request to ARM platform ("dbgreq"), when the JTAG state machine is
 * put in "ENTER_DEBUG" IR instruction.
 *
 * Values:
 * - 0 - Disable propagation of debug request to ARM platform
 * - 1 - Enable propagation of debug request to ARM platform
 */
/*@{*/
#define BP_SJC_DCR_DE_TO_ARM (0U)          /*!< Bit position for SJC_DCR_DE_TO_ARM. */
#define BM_SJC_DCR_DE_TO_ARM (0x00000001U) /*!< Bit mask for SJC_DCR_DE_TO_ARM. */
#define BS_SJC_DCR_DE_TO_ARM (1U)          /*!< Bit field size in bits for SJC_DCR_DE_TO_ARM. */

/*! @brief Read current value of the SJC_DCR_DE_TO_ARM field. */
#define BR_SJC_DCR_DE_TO_ARM(x) (HW_SJC_DCR(x).B.DE_TO_ARM)

/*! @brief Format value for bitfield SJC_DCR_DE_TO_ARM. */
#define BF_SJC_DCR_DE_TO_ARM(v) ((uint32_t)((uint32_t)(v) << BP_SJC_DCR_DE_TO_ARM) & BM_SJC_DCR_DE_TO_ARM)

/*! @brief Set the DE_TO_ARM field to a new value. */
#define BW_SJC_DCR_DE_TO_ARM(x, v) (HW_SJC_DCR_WR(x, (HW_SJC_DCR_RD(x) & ~BM_SJC_DCR_DE_TO_ARM) | BF_SJC_DCR_DE_TO_ARM(v)))
/*@}*/

/*!
 * @name Register SJC_DCR, field DE_TO_SDMA[1] (RW)
 *
 * SDMA debug request input propagation This bit controls the propagation of
 * debug request to SDMA, when the JTAG state machine is put in "ENTER_DEBUG" IR
 * instruction..
 *
 * Values:
 * - 0 - Disable propagation of debug request to SDMA
 * - 1 - Enable propagation of debug request to SDMA
 */
/*@{*/
#define BP_SJC_DCR_DE_TO_SDMA (1U)         /*!< Bit position for SJC_DCR_DE_TO_SDMA. */
#define BM_SJC_DCR_DE_TO_SDMA (0x00000002U) /*!< Bit mask for SJC_DCR_DE_TO_SDMA. */
#define BS_SJC_DCR_DE_TO_SDMA (1U)         /*!< Bit field size in bits for SJC_DCR_DE_TO_SDMA. */

/*! @brief Read current value of the SJC_DCR_DE_TO_SDMA field. */
#define BR_SJC_DCR_DE_TO_SDMA(x) (HW_SJC_DCR(x).B.DE_TO_SDMA)

/*! @brief Format value for bitfield SJC_DCR_DE_TO_SDMA. */
#define BF_SJC_DCR_DE_TO_SDMA(v) ((uint32_t)((uint32_t)(v) << BP_SJC_DCR_DE_TO_SDMA) & BM_SJC_DCR_DE_TO_SDMA)

/*! @brief Set the DE_TO_SDMA field to a new value. */
#define BW_SJC_DCR_DE_TO_SDMA(x, v) (HW_SJC_DCR_WR(x, (HW_SJC_DCR_RD(x) & ~BM_SJC_DCR_DE_TO_SDMA) | BF_SJC_DCR_DE_TO_SDMA(v)))
/*@}*/

/*!
 * @name Register SJC_DCR, field DEBUG_OBS[3] (RW)
 *
 * Debug observability This bit controls the propagation of the "system debug"
 * input to SJC (driven by the ECT logic), to the DE_B pad. (This logic can be
 * used to pass debug acknowledge event from ECT out to the PAD, for example). The
 * SJC's "system_debug" input is tied to logic HIGH value, therefore, set of
 * "debug_obs" bit, will result in unconditional assertion of DE_B pad.
 *
 * Values:
 * - 0 - Disable propagation of system debug to DE_B pin
 * - 1 - Unconditional assertion of pad DE_B
 */
/*@{*/
#define BP_SJC_DCR_DEBUG_OBS (3U)          /*!< Bit position for SJC_DCR_DEBUG_OBS. */
#define BM_SJC_DCR_DEBUG_OBS (0x00000008U) /*!< Bit mask for SJC_DCR_DEBUG_OBS. */
#define BS_SJC_DCR_DEBUG_OBS (1U)          /*!< Bit field size in bits for SJC_DCR_DEBUG_OBS. */

/*! @brief Read current value of the SJC_DCR_DEBUG_OBS field. */
#define BR_SJC_DCR_DEBUG_OBS(x) (HW_SJC_DCR(x).B.DEBUG_OBS)

/*! @brief Format value for bitfield SJC_DCR_DEBUG_OBS. */
#define BF_SJC_DCR_DEBUG_OBS(v) ((uint32_t)((uint32_t)(v) << BP_SJC_DCR_DEBUG_OBS) & BM_SJC_DCR_DEBUG_OBS)

/*! @brief Set the DEBUG_OBS field to a new value. */
#define BW_SJC_DCR_DEBUG_OBS(x, v) (HW_SJC_DCR_WR(x, (HW_SJC_DCR_RD(x) & ~BM_SJC_DCR_DEBUG_OBS) | BF_SJC_DCR_DEBUG_OBS(v)))
/*@}*/

/*!
 * @name Register SJC_DCR, field DIRECT_SDMA_REQ_EN[5] (RW)
 *
 * Debug enable of the sdma debug request This bit controls the propagation of
 * debug request DE_B to the sdma.
 *
 * Values:
 * - 0 - Disable propagation of system debug to (DE_B pin) to sdma.
 * - 1 - Enable propagation of system debug to (DE_B pin) to sdma.
 */
/*@{*/
#define BP_SJC_DCR_DIRECT_SDMA_REQ_EN (5U) /*!< Bit position for SJC_DCR_DIRECT_SDMA_REQ_EN. */
#define BM_SJC_DCR_DIRECT_SDMA_REQ_EN (0x00000020U) /*!< Bit mask for SJC_DCR_DIRECT_SDMA_REQ_EN. */
#define BS_SJC_DCR_DIRECT_SDMA_REQ_EN (1U) /*!< Bit field size in bits for SJC_DCR_DIRECT_SDMA_REQ_EN. */

/*! @brief Read current value of the SJC_DCR_DIRECT_SDMA_REQ_EN field. */
#define BR_SJC_DCR_DIRECT_SDMA_REQ_EN(x) (HW_SJC_DCR(x).B.DIRECT_SDMA_REQ_EN)

/*! @brief Format value for bitfield SJC_DCR_DIRECT_SDMA_REQ_EN. */
#define BF_SJC_DCR_DIRECT_SDMA_REQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_SJC_DCR_DIRECT_SDMA_REQ_EN) & BM_SJC_DCR_DIRECT_SDMA_REQ_EN)

/*! @brief Set the DIRECT_SDMA_REQ_EN field to a new value. */
#define BW_SJC_DCR_DIRECT_SDMA_REQ_EN(x, v) (HW_SJC_DCR_WR(x, (HW_SJC_DCR_RD(x) & ~BM_SJC_DCR_DIRECT_SDMA_REQ_EN) | BF_SJC_DCR_DIRECT_SDMA_REQ_EN(v)))
/*@}*/

/*!
 * @name Register SJC_DCR, field DIRECT_ARM_REQ_EN[6] (RW)
 *
 * Pass Debug Enable event from DE_B pin to ARM platform debug request
 * signal(s). This bit controls the propagation of debug request DE_B to the Arm platform.
 *
 * Values:
 * - 0 - Disable propagation of system debug to (DE_B pin) to Arm platform.
 * - 1 - Enable propagation of system debug to (DE_B pin) to Arm platform.
 */
/*@{*/
#define BP_SJC_DCR_DIRECT_ARM_REQ_EN (6U)  /*!< Bit position for SJC_DCR_DIRECT_ARM_REQ_EN. */
#define BM_SJC_DCR_DIRECT_ARM_REQ_EN (0x00000040U) /*!< Bit mask for SJC_DCR_DIRECT_ARM_REQ_EN. */
#define BS_SJC_DCR_DIRECT_ARM_REQ_EN (1U)  /*!< Bit field size in bits for SJC_DCR_DIRECT_ARM_REQ_EN. */

/*! @brief Read current value of the SJC_DCR_DIRECT_ARM_REQ_EN field. */
#define BR_SJC_DCR_DIRECT_ARM_REQ_EN(x) (HW_SJC_DCR(x).B.DIRECT_ARM_REQ_EN)

/*! @brief Format value for bitfield SJC_DCR_DIRECT_ARM_REQ_EN. */
#define BF_SJC_DCR_DIRECT_ARM_REQ_EN(v) ((uint32_t)((uint32_t)(v) << BP_SJC_DCR_DIRECT_ARM_REQ_EN) & BM_SJC_DCR_DIRECT_ARM_REQ_EN)

/*! @brief Set the DIRECT_ARM_REQ_EN field to a new value. */
#define BW_SJC_DCR_DIRECT_ARM_REQ_EN(x, v) (HW_SJC_DCR_WR(x, (HW_SJC_DCR_RD(x) & ~BM_SJC_DCR_DIRECT_ARM_REQ_EN) | BF_SJC_DCR_DIRECT_ARM_REQ_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_SJC_SSR - Security Status Register
 ******************************************************************************/

/*!
 * @brief HW_SJC_SSR - Security Status Register (RO)
 *
 * Reset value: 0x00000100U
 */
typedef union _hw_sjc_ssr
{
    uint32_t U;
    struct _hw_sjc_ssr_bitfields
    {
        uint32_t KTF : 1;              /*!< [0]  */
        uint32_t KTA : 1;              /*!< [1]  */
        uint32_t SWF : 1;              /*!< [2]  */
        uint32_t SWE : 1;              /*!< [3]  */
        uint32_t EBF : 1;              /*!< [4]  */
        uint32_t EBG : 1;              /*!< [5]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t FT : 1;               /*!< [8]  */
        uint32_t SJM : 2;              /*!< [10:9]  */
        uint32_t RSSTAT : 2;           /*!< [12:11]  */
        uint32_t RESERVED1 : 1;        /*!< [13]  */
        uint32_t BOOTIND : 1;          /*!< [14]  */
        uint32_t RESERVED2 : 17;       /*!< [31:15]  */
    } B;
} hw_sjc_ssr_t;

/*!
 * @name Constants and macros for entire SJC_SSR register
 */
/*@{*/
#define HW_SJC_SSR_ADDR(x)       ((uintptr_t)(x) + 0x14U)

#define HW_SJC_SSR(x)            (*(__I hw_sjc_ssr_t *) HW_SJC_SSR_ADDR(x))
#define HW_SJC_SSR_RD(x)         (HW_SJC_SSR(x).U)
/*@}*/

/*
 * Constants & macros for individual SJC_SSR bitfields
 */

/*!
 * @name Register SJC_SSR, field KTF[0] (RO)
 *
 * Kill Trace Enable fuse value
 *
 * Values:
 * - 0 - (intact) - kill trace is never active
 * - 1 - (burned) - kill trace functionality enabled
 */
/*@{*/
#define BP_SJC_SSR_KTF       (0U)          /*!< Bit position for SJC_SSR_KTF. */
#define BM_SJC_SSR_KTF       (0x00000001U) /*!< Bit mask for SJC_SSR_KTF. */
#define BS_SJC_SSR_KTF       (1U)          /*!< Bit field size in bits for SJC_SSR_KTF. */

/*! @brief Read current value of the SJC_SSR_KTF field. */
#define BR_SJC_SSR_KTF(x)    (HW_SJC_SSR(x).B.KTF)
/*@}*/

/*!
 * @name Register SJC_SSR, field KTA[1] (RO)
 *
 * Kill Trace is active
 *
 * Values:
 * - 1 - active
 * - 0 - not active
 */
/*@{*/
#define BP_SJC_SSR_KTA       (1U)          /*!< Bit position for SJC_SSR_KTA. */
#define BM_SJC_SSR_KTA       (0x00000002U) /*!< Bit mask for SJC_SSR_KTA. */
#define BS_SJC_SSR_KTA       (1U)          /*!< Bit field size in bits for SJC_SSR_KTA. */

/*! @brief Read current value of the SJC_SSR_KTA field. */
#define BR_SJC_SSR_KTA(x)    (HW_SJC_SSR(x).B.KTA)
/*@}*/

/*!
 * @name Register SJC_SSR, field SWF[2] (RO)
 *
 * Software JTAG enable fuse Status of the no SW disable JTAG fuse
 *
 * Values:
 * - 0 - (intact) - SW enable possible
 * - 1 - (intact) - no SW enable possible
 */
/*@{*/
#define BP_SJC_SSR_SWF       (2U)          /*!< Bit position for SJC_SSR_SWF. */
#define BM_SJC_SSR_SWF       (0x00000004U) /*!< Bit mask for SJC_SSR_SWF. */
#define BS_SJC_SSR_SWF       (1U)          /*!< Bit field size in bits for SJC_SSR_SWF. */

/*! @brief Read current value of the SJC_SSR_SWF field. */
#define BR_SJC_SSR_SWF(x)    (HW_SJC_SSR(x).B.SWF)
/*@}*/

/*!
 * @name Register SJC_SSR, field SWE[3] (RO)
 *
 * SW enable SW JTAG enable status
 *
 * Values:
 * - 1 - enabled
 * - 0 - disabled
 */
/*@{*/
#define BP_SJC_SSR_SWE       (3U)          /*!< Bit position for SJC_SSR_SWE. */
#define BM_SJC_SSR_SWE       (0x00000008U) /*!< Bit mask for SJC_SSR_SWE. */
#define BS_SJC_SSR_SWE       (1U)          /*!< Bit field size in bits for SJC_SSR_SWE. */

/*! @brief Read current value of the SJC_SSR_SWE field. */
#define BR_SJC_SSR_SWE(x)    (HW_SJC_SSR(x).B.SWE)
/*@}*/

/*!
 * @name Register SJC_SSR, field EBF[4] (RO)
 *
 * External Boot fuse Status of the external boot disable fuse
 *
 * Values:
 * - 0 - (intact) - external boot is allowed
 * - 1 - (burned) - external boot is disabled
 */
/*@{*/
#define BP_SJC_SSR_EBF       (4U)          /*!< Bit position for SJC_SSR_EBF. */
#define BM_SJC_SSR_EBF       (0x00000010U) /*!< Bit mask for SJC_SSR_EBF. */
#define BS_SJC_SSR_EBF       (1U)          /*!< Bit field size in bits for SJC_SSR_EBF. */

/*! @brief Read current value of the SJC_SSR_EBF field. */
#define BR_SJC_SSR_EBF(x)    (HW_SJC_SSR(x).B.EBF)
/*@}*/

/*!
 * @name Register SJC_SSR, field EBG[5] (RO)
 *
 * External boot granted External boot enabled, requested and granted
 *
 * Values:
 * - 1 - granted
 * - 0 - not granted
 */
/*@{*/
#define BP_SJC_SSR_EBG       (5U)          /*!< Bit position for SJC_SSR_EBG. */
#define BM_SJC_SSR_EBG       (0x00000020U) /*!< Bit mask for SJC_SSR_EBG. */
#define BS_SJC_SSR_EBG       (1U)          /*!< Bit field size in bits for SJC_SSR_EBG. */

/*! @brief Read current value of the SJC_SSR_EBG field. */
#define BR_SJC_SSR_EBG(x)    (HW_SJC_SSR(x).B.EBG)
/*@}*/

/*!
 * @name Register SJC_SSR, field FT[8] (RO)
 *
 * Fuse type Fuse type bit - e-fuse or laser fuse
 *
 * Values:
 * - 0 - E-fuse technology
 * - 1 - Laser fuse technology
 */
/*@{*/
#define BP_SJC_SSR_FT        (8U)          /*!< Bit position for SJC_SSR_FT. */
#define BM_SJC_SSR_FT        (0x00000100U) /*!< Bit mask for SJC_SSR_FT. */
#define BS_SJC_SSR_FT        (1U)          /*!< Bit field size in bits for SJC_SSR_FT. */

/*! @brief Read current value of the SJC_SSR_FT field. */
#define BR_SJC_SSR_FT(x)     (HW_SJC_SSR(x).B.FT)
/*@}*/

/*!
 * @name Register SJC_SSR, field SJM[10:9] (RO)
 *
 * SJC Secure mode Secure JTAG mode, as set by external fuses.
 *
 * Values:
 * - 00 - No debug (#1)
 * - 01 - Secure JTAG (#2)
 * - 10 - Reserved
 * - 11 - JTAG enabled (#3)
 */
/*@{*/
#define BP_SJC_SSR_SJM       (9U)          /*!< Bit position for SJC_SSR_SJM. */
#define BM_SJC_SSR_SJM       (0x00000600U) /*!< Bit mask for SJC_SSR_SJM. */
#define BS_SJC_SSR_SJM       (2U)          /*!< Bit field size in bits for SJC_SSR_SJM. */

/*! @brief Read current value of the SJC_SSR_SJM field. */
#define BR_SJC_SSR_SJM(x)    (HW_SJC_SSR(x).B.SJM)
/*@}*/

/*!
 * @name Register SJC_SSR, field RSSTAT[12:11] (RO)
 *
 * Response status Response status bits
 *
 * Values:
 * - 00 - Response wasn't entered
 * - 01 - Response was entered but not verified
 * - 10 - Response was entered and is incorrect
 * - 11 - Response is correct
 */
/*@{*/
#define BP_SJC_SSR_RSSTAT    (11U)         /*!< Bit position for SJC_SSR_RSSTAT. */
#define BM_SJC_SSR_RSSTAT    (0x00001800U) /*!< Bit mask for SJC_SSR_RSSTAT. */
#define BS_SJC_SSR_RSSTAT    (2U)          /*!< Bit field size in bits for SJC_SSR_RSSTAT. */

/*! @brief Read current value of the SJC_SSR_RSSTAT field. */
#define BR_SJC_SSR_RSSTAT(x) (HW_SJC_SSR(x).B.RSSTAT)
/*@}*/

/*!
 * @name Register SJC_SSR, field BOOTIND[14] (RO)
 *
 * Boot Indication Inverted Internal Boot indication, i.e inverse of SRC:
 * "src_int_boot" signal
 */
/*@{*/
#define BP_SJC_SSR_BOOTIND   (14U)         /*!< Bit position for SJC_SSR_BOOTIND. */
#define BM_SJC_SSR_BOOTIND   (0x00004000U) /*!< Bit mask for SJC_SSR_BOOTIND. */
#define BS_SJC_SSR_BOOTIND   (1U)          /*!< Bit field size in bits for SJC_SSR_BOOTIND. */

/*! @brief Read current value of the SJC_SSR_BOOTIND field. */
#define BR_SJC_SSR_BOOTIND(x) (HW_SJC_SSR(x).B.BOOTIND)
/*@}*/

/*******************************************************************************
 * HW_SJC_GPCCR - General Purpose Clocks Control Register
 ******************************************************************************/

/*!
 * @brief HW_SJC_GPCCR - General Purpose Clocks Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to configure clock related modes in SOC, see System
 * Configuration chapter for more information. Those bits are directly connected to
 * JTAG outputs. Bit 0 of GPCCR controls SDMA clocks invocation. When out of
 * reset, the SDMA is in sleep mode with no SDMA clock running. Unlike events, debug
 * requests does not wake SDMA if it is in sleep mode. The debug request is
 * recognized by the SDMA only when it exits sleep mode upon reception of an event. To
 * be able to enter debug mode even if no event is triggered, the SDMA clock on
 * bit needs to be set prior to sending the debug request (clear at reset).
 */
typedef union _hw_sjc_gpccr
{
    uint32_t U;
    struct _hw_sjc_gpccr_bitfields
    {
        uint32_t SCLKR : 1;            /*!< [0]  */
        uint32_t ACLKOFFDIS : 1;       /*!< [1]  */
        uint32_t RESERVED0 : 30;       /*!< [31:2]  */
    } B;
} hw_sjc_gpccr_t;

/*!
 * @name Constants and macros for entire SJC_GPCCR register
 */
/*@{*/
#define HW_SJC_GPCCR_ADDR(x)     ((uintptr_t)(x) + 0x18U)

#define HW_SJC_GPCCR(x)          (*(__IO hw_sjc_gpccr_t *) HW_SJC_GPCCR_ADDR(x))
#define HW_SJC_GPCCR_RD(x)       (HW_SJC_GPCCR(x).U)
#define HW_SJC_GPCCR_WR(x, v)    (HW_SJC_GPCCR(x).U = (v))
#define HW_SJC_GPCCR_SET(x, v)   (HW_SJC_GPCCR_WR(x, HW_SJC_GPCCR_RD(x) |  (v)))
#define HW_SJC_GPCCR_CLR(x, v)   (HW_SJC_GPCCR_WR(x, HW_SJC_GPCCR_RD(x) & ~(v)))
#define HW_SJC_GPCCR_TOG(x, v)   (HW_SJC_GPCCR_WR(x, HW_SJC_GPCCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SJC_GPCCR bitfields
 */

/*!
 * @name Register SJC_GPCCR, field SCLKR[0] (RW)
 *
 * SDMA Clock ON Register - This bit forces the clock on of the SDMA
 */
/*@{*/
#define BP_SJC_GPCCR_SCLKR   (0U)          /*!< Bit position for SJC_GPCCR_SCLKR. */
#define BM_SJC_GPCCR_SCLKR   (0x00000001U) /*!< Bit mask for SJC_GPCCR_SCLKR. */
#define BS_SJC_GPCCR_SCLKR   (1U)          /*!< Bit field size in bits for SJC_GPCCR_SCLKR. */

/*! @brief Read current value of the SJC_GPCCR_SCLKR field. */
#define BR_SJC_GPCCR_SCLKR(x) (HW_SJC_GPCCR(x).B.SCLKR)

/*! @brief Format value for bitfield SJC_GPCCR_SCLKR. */
#define BF_SJC_GPCCR_SCLKR(v) ((uint32_t)((uint32_t)(v) << BP_SJC_GPCCR_SCLKR) & BM_SJC_GPCCR_SCLKR)

/*! @brief Set the SCLKR field to a new value. */
#define BW_SJC_GPCCR_SCLKR(x, v) (HW_SJC_GPCCR_WR(x, (HW_SJC_GPCCR_RD(x) & ~BM_SJC_GPCCR_SCLKR) | BF_SJC_GPCCR_SCLKR(v)))
/*@}*/

/*!
 * @name Register SJC_GPCCR, field ACLKOFFDIS[1] (RW)
 *
 * Disable/prevent ARM platform clock/power shutdown
 */
/*@{*/
#define BP_SJC_GPCCR_ACLKOFFDIS (1U)       /*!< Bit position for SJC_GPCCR_ACLKOFFDIS. */
#define BM_SJC_GPCCR_ACLKOFFDIS (0x00000002U) /*!< Bit mask for SJC_GPCCR_ACLKOFFDIS. */
#define BS_SJC_GPCCR_ACLKOFFDIS (1U)       /*!< Bit field size in bits for SJC_GPCCR_ACLKOFFDIS. */

/*! @brief Read current value of the SJC_GPCCR_ACLKOFFDIS field. */
#define BR_SJC_GPCCR_ACLKOFFDIS(x) (HW_SJC_GPCCR(x).B.ACLKOFFDIS)

/*! @brief Format value for bitfield SJC_GPCCR_ACLKOFFDIS. */
#define BF_SJC_GPCCR_ACLKOFFDIS(v) ((uint32_t)((uint32_t)(v) << BP_SJC_GPCCR_ACLKOFFDIS) & BM_SJC_GPCCR_ACLKOFFDIS)

/*! @brief Set the ACLKOFFDIS field to a new value. */
#define BW_SJC_GPCCR_ACLKOFFDIS(x, v) (HW_SJC_GPCCR_WR(x, (HW_SJC_GPCCR_RD(x) & ~BM_SJC_GPCCR_ACLKOFFDIS) | BF_SJC_GPCCR_ACLKOFFDIS(v)))
/*@}*/

/*******************************************************************************
 * hw_sjc_t - module struct
 ******************************************************************************/
/*!
 * @brief All SJC module registers.
 */
#pragma pack(1)
typedef struct _hw_sjc
{
    __I hw_sjc_gpusr1_t GPUSR1;            /*!< [0x0] General Purpose Unsecured Status Register 1 */
    __I hw_sjc_gpusr2_t GPUSR2;            /*!< [0x4] General Purpose Unsecured Status Register 2 */
    __I hw_sjc_gpusr3_t GPUSR3;            /*!< [0x8] General Purpose Unsecured Status Register 3 */
    __I hw_sjc_gpssr_t GPSSR;              /*!< [0xC] General Purpose Secured Status Register */
    __IO hw_sjc_dcr_t DCR;                 /*!< [0x10] Debug Control Register */
    __I hw_sjc_ssr_t SSR;                  /*!< [0x14] Security Status Register */
    __IO hw_sjc_gpccr_t GPCCR;             /*!< [0x18] General Purpose Clocks Control Register */
} hw_sjc_t;
#pragma pack()

/*! @brief Macro to access all SJC registers. */
/*! @param x SJC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_SJC_REGS(SJC_BASE)</code>. */
#define HW_SJC_REGS(x) (*(hw_sjc_t *)(x))

/*
 * iMX7D SNVS
 *
 * Secure Non-Volatile Storage (SNVS)
 *
 * Registers defined in this header file:
 * - HW_SNVS_HPLR - SNVS_HP Lock Register
 * - HW_SNVS_HPCOMR - SNVS_HP Command Register
 * - HW_SNVS_HPCR - SNVS_HP Control Register
 * - HW_SNVS_HPSR - SNVS_HP Status Register
 * - HW_SNVS_HPRTCMR - SNVS_HP Real Time Counter MSB Register
 * - HW_SNVS_HPRTCLR - SNVS_HP Real Time Counter LSB Register
 * - HW_SNVS_HPTAMR - SNVS_HP Time Alarm MSB Register
 * - HW_SNVS_HPTALR - SNVS_HP Time Alarm LSB Register
 * - HW_SNVS_LPLR - SNVS_LP Lock Register
 * - HW_SNVS_LPCR - SNVS_LP Control Register
 * - HW_SNVS_LPSR - SNVS_LP Status Register
 * - HW_SNVS_LPSMCMR - SNVS_LP Secure Monotonic Counter MSB Register
 * - HW_SNVS_LPSMCLR - SNVS_LP Secure Monotonic Counter LSB Register
 * - HW_SNVS_LPGPR - SNVS_LP General Purpose Register
 * - HW_SNVS_HPVIDR1 - SNVS_HP Version ID Register 1
 * - HW_SNVS_HPVIDR2 - SNVS_HP Version ID Register 2
 *
 * - hw_snvs_t - Struct containing all module registers.
 */

#define HW_SNVS_INSTANCE_COUNT (1U) /*!< Number of instances of the SNVS module. */
#define HW_SNVS (0U) /*!< Instance number for SNVS. */
#define SNVS_BASE             (0x30370000U) /*!< Base address for SNVS. */
/*! Array initializer of SNVS base addresses. */
#define SNVS_BASE_ADDRS       { SNVS_BASE }

/*******************************************************************************
 * HW_SNVS_HPLR - SNVS_HP Lock Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPLR - SNVS_HP Lock Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_HP Lock Register contains lock bits for the SNVS registers. This is
 * a privileged write register.
 */
typedef union _hw_snvs_hplr
{
    uint32_t U;
    struct _hw_snvs_hplr_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t MC_SL : 1;            /*!< [4]  */
        uint32_t GPR_SL : 1;           /*!< [5]  */
        uint32_t RESERVED1 : 26;       /*!< [31:6]  */
    } B;
} hw_snvs_hplr_t;

/*!
 * @name Constants and macros for entire SNVS_HPLR register
 */
/*@{*/
#define HW_SNVS_HPLR_ADDR(x)     ((uintptr_t)(x) + 0x0U)

#define HW_SNVS_HPLR(x)          (*(__IO hw_snvs_hplr_t *) HW_SNVS_HPLR_ADDR(x))
#define HW_SNVS_HPLR_RD(x)       (HW_SNVS_HPLR(x).U)
#define HW_SNVS_HPLR_WR(x, v)    (HW_SNVS_HPLR(x).U = (v))
#define HW_SNVS_HPLR_SET(x, v)   (HW_SNVS_HPLR_WR(x, HW_SNVS_HPLR_RD(x) |  (v)))
#define HW_SNVS_HPLR_CLR(x, v)   (HW_SNVS_HPLR_WR(x, HW_SNVS_HPLR_RD(x) & ~(v)))
#define HW_SNVS_HPLR_TOG(x, v)   (HW_SNVS_HPLR_WR(x, HW_SNVS_HPLR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_HPLR bitfields
 */

/*!
 * @name Register SNVS_HPLR, field MC_SL[4] (RW)
 *
 * Monotonic Counter Soft Lock When set, prevents any writes (increments) to the
 * MC Registers and MC_ENV bit. Once set, this bit can only be reset by the
 * system reset.
 *
 * Values:
 * - 0 - Write access (increment) is allowed
 * - 1 - Write access (increment) is not allowed
 */
/*@{*/
#define BP_SNVS_HPLR_MC_SL   (4U)          /*!< Bit position for SNVS_HPLR_MC_SL. */
#define BM_SNVS_HPLR_MC_SL   (0x00000010U) /*!< Bit mask for SNVS_HPLR_MC_SL. */
#define BS_SNVS_HPLR_MC_SL   (1U)          /*!< Bit field size in bits for SNVS_HPLR_MC_SL. */

/*! @brief Read current value of the SNVS_HPLR_MC_SL field. */
#define BR_SNVS_HPLR_MC_SL(x) (HW_SNVS_HPLR(x).B.MC_SL)

/*! @brief Format value for bitfield SNVS_HPLR_MC_SL. */
#define BF_SNVS_HPLR_MC_SL(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPLR_MC_SL) & BM_SNVS_HPLR_MC_SL)

/*! @brief Set the MC_SL field to a new value. */
#define BW_SNVS_HPLR_MC_SL(x, v) (HW_SNVS_HPLR_WR(x, (HW_SNVS_HPLR_RD(x) & ~BM_SNVS_HPLR_MC_SL) | BF_SNVS_HPLR_MC_SL(v)))
/*@}*/

/*!
 * @name Register SNVS_HPLR, field GPR_SL[5] (RW)
 *
 * General Purpose Register Soft Lock When set, prevents any writes to the GPR.
 * Once set, this bit can only be reset by the system reset.
 *
 * Values:
 * - 0 - Write access is allowed
 * - 1 - Write access is not allowed
 */
/*@{*/
#define BP_SNVS_HPLR_GPR_SL  (5U)          /*!< Bit position for SNVS_HPLR_GPR_SL. */
#define BM_SNVS_HPLR_GPR_SL  (0x00000020U) /*!< Bit mask for SNVS_HPLR_GPR_SL. */
#define BS_SNVS_HPLR_GPR_SL  (1U)          /*!< Bit field size in bits for SNVS_HPLR_GPR_SL. */

/*! @brief Read current value of the SNVS_HPLR_GPR_SL field. */
#define BR_SNVS_HPLR_GPR_SL(x) (HW_SNVS_HPLR(x).B.GPR_SL)

/*! @brief Format value for bitfield SNVS_HPLR_GPR_SL. */
#define BF_SNVS_HPLR_GPR_SL(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPLR_GPR_SL) & BM_SNVS_HPLR_GPR_SL)

/*! @brief Set the GPR_SL field to a new value. */
#define BW_SNVS_HPLR_GPR_SL(x, v) (HW_SNVS_HPLR_WR(x, (HW_SNVS_HPLR_RD(x) & ~BM_SNVS_HPLR_GPR_SL) | BF_SNVS_HPLR_GPR_SL(v)))
/*@}*/

/*******************************************************************************
 * HW_SNVS_HPCOMR - SNVS_HP Command Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPCOMR - SNVS_HP Command Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_HP Command Register contains the command, configuration, and control
 * bits for the SNVS block. This is a privileged write register.
 */
typedef union _hw_snvs_hpcomr
{
    uint32_t U;
    struct _hw_snvs_hpcomr_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t LP_SWR : 1;           /*!< [4]  */
        uint32_t LP_SWR_DIS : 1;       /*!< [5]  */
        uint32_t RESERVED1 : 25;       /*!< [30:6]  */
        uint32_t NPSWA_EN : 1;         /*!< [31]  */
    } B;
} hw_snvs_hpcomr_t;

/*!
 * @name Constants and macros for entire SNVS_HPCOMR register
 */
/*@{*/
#define HW_SNVS_HPCOMR_ADDR(x)   ((uintptr_t)(x) + 0x4U)

#define HW_SNVS_HPCOMR(x)        (*(__IO hw_snvs_hpcomr_t *) HW_SNVS_HPCOMR_ADDR(x))
#define HW_SNVS_HPCOMR_RD(x)     (HW_SNVS_HPCOMR(x).U)
#define HW_SNVS_HPCOMR_WR(x, v)  (HW_SNVS_HPCOMR(x).U = (v))
#define HW_SNVS_HPCOMR_SET(x, v) (HW_SNVS_HPCOMR_WR(x, HW_SNVS_HPCOMR_RD(x) |  (v)))
#define HW_SNVS_HPCOMR_CLR(x, v) (HW_SNVS_HPCOMR_WR(x, HW_SNVS_HPCOMR_RD(x) & ~(v)))
#define HW_SNVS_HPCOMR_TOG(x, v) (HW_SNVS_HPCOMR_WR(x, HW_SNVS_HPCOMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_HPCOMR bitfields
 */

/*!
 * @name Register SNVS_HPCOMR, field LP_SWR[4] (WO)
 *
 * LP Software Reset When set, it resets the SNVS_LP section. This bit cannot be
 * set when the LP_SWR_DIS bit is set. This self-clearing bit is always read as
 * zero.
 *
 * Values:
 * - 0 - No Action
 * - 1 - Reset LP section
 */
/*@{*/
#define BP_SNVS_HPCOMR_LP_SWR (4U)         /*!< Bit position for SNVS_HPCOMR_LP_SWR. */
#define BM_SNVS_HPCOMR_LP_SWR (0x00000010U) /*!< Bit mask for SNVS_HPCOMR_LP_SWR. */
#define BS_SNVS_HPCOMR_LP_SWR (1U)         /*!< Bit field size in bits for SNVS_HPCOMR_LP_SWR. */

/*! @brief Format value for bitfield SNVS_HPCOMR_LP_SWR. */
#define BF_SNVS_HPCOMR_LP_SWR(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCOMR_LP_SWR) & BM_SNVS_HPCOMR_LP_SWR)
/*@}*/

/*!
 * @name Register SNVS_HPCOMR, field LP_SWR_DIS[5] (RW)
 *
 * LP Software Reset Disable When set, disables the LP software reset. Once set,
 * this bit can only be reset by the system reset.
 *
 * Values:
 * - 0 - LP software reset is enabled
 * - 1 - LP software reset is disabled
 */
/*@{*/
#define BP_SNVS_HPCOMR_LP_SWR_DIS (5U)     /*!< Bit position for SNVS_HPCOMR_LP_SWR_DIS. */
#define BM_SNVS_HPCOMR_LP_SWR_DIS (0x00000020U) /*!< Bit mask for SNVS_HPCOMR_LP_SWR_DIS. */
#define BS_SNVS_HPCOMR_LP_SWR_DIS (1U)     /*!< Bit field size in bits for SNVS_HPCOMR_LP_SWR_DIS. */

/*! @brief Read current value of the SNVS_HPCOMR_LP_SWR_DIS field. */
#define BR_SNVS_HPCOMR_LP_SWR_DIS(x) (HW_SNVS_HPCOMR(x).B.LP_SWR_DIS)

/*! @brief Format value for bitfield SNVS_HPCOMR_LP_SWR_DIS. */
#define BF_SNVS_HPCOMR_LP_SWR_DIS(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCOMR_LP_SWR_DIS) & BM_SNVS_HPCOMR_LP_SWR_DIS)

/*! @brief Set the LP_SWR_DIS field to a new value. */
#define BW_SNVS_HPCOMR_LP_SWR_DIS(x, v) (HW_SNVS_HPCOMR_WR(x, (HW_SNVS_HPCOMR_RD(x) & ~BM_SNVS_HPCOMR_LP_SWR_DIS) | BF_SNVS_HPCOMR_LP_SWR_DIS(v)))
/*@}*/

/*!
 * @name Register SNVS_HPCOMR, field NPSWA_EN[31] (RW)
 *
 * Non-Privileged Software Access Enable When set, allows non-privileged
 * software to access all SNVS registers, including those that are privileged software
 * read/write access only. 0 Only privileged software can access privileged
 * registers 1 Any software can access privileged registers
 */
/*@{*/
#define BP_SNVS_HPCOMR_NPSWA_EN (31U)      /*!< Bit position for SNVS_HPCOMR_NPSWA_EN. */
#define BM_SNVS_HPCOMR_NPSWA_EN (0x80000000U) /*!< Bit mask for SNVS_HPCOMR_NPSWA_EN. */
#define BS_SNVS_HPCOMR_NPSWA_EN (1U)       /*!< Bit field size in bits for SNVS_HPCOMR_NPSWA_EN. */

/*! @brief Read current value of the SNVS_HPCOMR_NPSWA_EN field. */
#define BR_SNVS_HPCOMR_NPSWA_EN(x) (HW_SNVS_HPCOMR(x).B.NPSWA_EN)

/*! @brief Format value for bitfield SNVS_HPCOMR_NPSWA_EN. */
#define BF_SNVS_HPCOMR_NPSWA_EN(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCOMR_NPSWA_EN) & BM_SNVS_HPCOMR_NPSWA_EN)

/*! @brief Set the NPSWA_EN field to a new value. */
#define BW_SNVS_HPCOMR_NPSWA_EN(x, v) (HW_SNVS_HPCOMR_WR(x, (HW_SNVS_HPCOMR_RD(x) & ~BM_SNVS_HPCOMR_NPSWA_EN) | BF_SNVS_HPCOMR_NPSWA_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_SNVS_HPCR - SNVS_HP Control Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPCR - SNVS_HP Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_HP Control Register contains various control bits of the HP section
 * of SNVS .
 */
typedef union _hw_snvs_hpcr
{
    uint32_t U;
    struct _hw_snvs_hpcr_bitfields
    {
        uint32_t RTC_EN : 1;           /*!< [0]  */
        uint32_t HPTA_EN : 1;          /*!< [1]  */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t PI_EN : 1;            /*!< [3]  */
        uint32_t PI_FREQ : 4;          /*!< [7:4]  */
        uint32_t HPCALB_EN : 1;        /*!< [8]  */
        uint32_t RESERVED1 : 1;        /*!< [9]  */
        uint32_t HPCALB_VAL : 5;       /*!< [14:10]  */
        uint32_t RESERVED2 : 9;        /*!< [23:15]  */
        uint32_t BTN_CONFIG : 3;       /*!< [26:24]  */
        uint32_t BTN_MASK : 1;         /*!< [27]  */
        uint32_t RESERVED3 : 4;        /*!< [31:28]  */
    } B;
} hw_snvs_hpcr_t;

/*!
 * @name Constants and macros for entire SNVS_HPCR register
 */
/*@{*/
#define HW_SNVS_HPCR_ADDR(x)     ((uintptr_t)(x) + 0x8U)

#define HW_SNVS_HPCR(x)          (*(__IO hw_snvs_hpcr_t *) HW_SNVS_HPCR_ADDR(x))
#define HW_SNVS_HPCR_RD(x)       (HW_SNVS_HPCR(x).U)
#define HW_SNVS_HPCR_WR(x, v)    (HW_SNVS_HPCR(x).U = (v))
#define HW_SNVS_HPCR_SET(x, v)   (HW_SNVS_HPCR_WR(x, HW_SNVS_HPCR_RD(x) |  (v)))
#define HW_SNVS_HPCR_CLR(x, v)   (HW_SNVS_HPCR_WR(x, HW_SNVS_HPCR_RD(x) & ~(v)))
#define HW_SNVS_HPCR_TOG(x, v)   (HW_SNVS_HPCR_WR(x, HW_SNVS_HPCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_HPCR bitfields
 */

/*!
 * @name Register SNVS_HPCR, field RTC_EN[0] (RW)
 *
 * HP Real Time Counter Enable
 *
 * Values:
 * - 0 - RTC is disabled
 * - 1 - RTC is enabled
 */
/*@{*/
#define BP_SNVS_HPCR_RTC_EN  (0U)          /*!< Bit position for SNVS_HPCR_RTC_EN. */
#define BM_SNVS_HPCR_RTC_EN  (0x00000001U) /*!< Bit mask for SNVS_HPCR_RTC_EN. */
#define BS_SNVS_HPCR_RTC_EN  (1U)          /*!< Bit field size in bits for SNVS_HPCR_RTC_EN. */

/*! @brief Read current value of the SNVS_HPCR_RTC_EN field. */
#define BR_SNVS_HPCR_RTC_EN(x) (HW_SNVS_HPCR(x).B.RTC_EN)

/*! @brief Format value for bitfield SNVS_HPCR_RTC_EN. */
#define BF_SNVS_HPCR_RTC_EN(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCR_RTC_EN) & BM_SNVS_HPCR_RTC_EN)

/*! @brief Set the RTC_EN field to a new value. */
#define BW_SNVS_HPCR_RTC_EN(x, v) (HW_SNVS_HPCR_WR(x, (HW_SNVS_HPCR_RD(x) & ~BM_SNVS_HPCR_RTC_EN) | BF_SNVS_HPCR_RTC_EN(v)))
/*@}*/

/*!
 * @name Register SNVS_HPCR, field HPTA_EN[1] (RW)
 *
 * HP Time Alarm Enable When set, the time alarm interrupt is generated if the
 * value in the HP Time Alarm Registers is equal to the value of the HP Real Time
 * Counter.
 *
 * Values:
 * - 0 - HP Time Alarm Interrupt is disabled
 * - 1 - HP Time Alarm Interrupt is enabled
 */
/*@{*/
#define BP_SNVS_HPCR_HPTA_EN (1U)          /*!< Bit position for SNVS_HPCR_HPTA_EN. */
#define BM_SNVS_HPCR_HPTA_EN (0x00000002U) /*!< Bit mask for SNVS_HPCR_HPTA_EN. */
#define BS_SNVS_HPCR_HPTA_EN (1U)          /*!< Bit field size in bits for SNVS_HPCR_HPTA_EN. */

/*! @brief Read current value of the SNVS_HPCR_HPTA_EN field. */
#define BR_SNVS_HPCR_HPTA_EN(x) (HW_SNVS_HPCR(x).B.HPTA_EN)

/*! @brief Format value for bitfield SNVS_HPCR_HPTA_EN. */
#define BF_SNVS_HPCR_HPTA_EN(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCR_HPTA_EN) & BM_SNVS_HPCR_HPTA_EN)

/*! @brief Set the HPTA_EN field to a new value. */
#define BW_SNVS_HPCR_HPTA_EN(x, v) (HW_SNVS_HPCR_WR(x, (HW_SNVS_HPCR_RD(x) & ~BM_SNVS_HPCR_HPTA_EN) | BF_SNVS_HPCR_HPTA_EN(v)))
/*@}*/

/*!
 * @name Register SNVS_HPCR, field PI_EN[3] (RW)
 *
 * HP Periodic Interrupt Enable The periodic interrupt can be generated only if
 * the HP Real Time Counter is enabled.
 *
 * Values:
 * - 0 - HP Periodic Interrupt is disabled
 * - 1 - HP Periodic Interrupt is enabled
 */
/*@{*/
#define BP_SNVS_HPCR_PI_EN   (3U)          /*!< Bit position for SNVS_HPCR_PI_EN. */
#define BM_SNVS_HPCR_PI_EN   (0x00000008U) /*!< Bit mask for SNVS_HPCR_PI_EN. */
#define BS_SNVS_HPCR_PI_EN   (1U)          /*!< Bit field size in bits for SNVS_HPCR_PI_EN. */

/*! @brief Read current value of the SNVS_HPCR_PI_EN field. */
#define BR_SNVS_HPCR_PI_EN(x) (HW_SNVS_HPCR(x).B.PI_EN)

/*! @brief Format value for bitfield SNVS_HPCR_PI_EN. */
#define BF_SNVS_HPCR_PI_EN(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCR_PI_EN) & BM_SNVS_HPCR_PI_EN)

/*! @brief Set the PI_EN field to a new value. */
#define BW_SNVS_HPCR_PI_EN(x, v) (HW_SNVS_HPCR_WR(x, (HW_SNVS_HPCR_RD(x) & ~BM_SNVS_HPCR_PI_EN) | BF_SNVS_HPCR_PI_EN(v)))
/*@}*/

/*!
 * @name Register SNVS_HPCR, field PI_FREQ[7:4] (RW)
 *
 * Periodic Interrupt Frequency Defines frequency of the periodic interrupt. The
 * interrupt is generated when a zero-to-one or one-to-zero transition occurs on
 * the selected bit of the HP Real Time Counter and Real Time Counter and
 * Periodic Interrupt are both enabled (RTC_EN and PI_EN are set). It is recommended to
 * program this field when Periodic Interrupt is disabled (PI_EN is not set).
 * The possible frequencies are:
 *
 * Values:
 * - 0000 - - bit 0 of the RTC is selected as a source of the periodic interrupt
 * - 0001 - - bit 1 of the RTC is selected as a source of the periodic interrupt
 * - 0010 - - bit 2 of the RTC is selected as a source of the periodic interrupt
 * - 0011 - - bit 3 of the RTC is selected as a source of the periodic interrupt
 * - 0100 - - bit 4 of the RTC is selected as a source of the periodic interrupt
 * - 0101 - - bit 5 of the RTC is selected as a source of the periodic interrupt
 * - 0110 - - bit 6 of the RTC is selected as a source of the periodic interrupt
 * - 0111 - - bit 7 of the RTC is selected as a source of the periodic interrupt
 * - 1000 - - bit 8 of the RTC is selected as a source of the periodic interrupt
 * - 1001 - - bit 9 of the RTC is selected as a source of the periodic interrupt
 * - 1010 - - bit 10 of the RTC is selected as a source of the periodic interrupt
 * - 1011 - - bit 11 of the RTC is selected as a source of the periodic interrupt
 * - 1100 - - bit 12 of the RTC is selected as a source of the periodic interrupt
 * - 1101 - - bit 13 of the RTC is selected as a source of the periodic interrupt
 * - 1110 - - bit 14 of the RTC is selected as a source of the periodic interrupt
 * - 1111 - - bit 15 of the RTC is selected as a source of the periodic interrupt
 */
/*@{*/
#define BP_SNVS_HPCR_PI_FREQ (4U)          /*!< Bit position for SNVS_HPCR_PI_FREQ. */
#define BM_SNVS_HPCR_PI_FREQ (0x000000F0U) /*!< Bit mask for SNVS_HPCR_PI_FREQ. */
#define BS_SNVS_HPCR_PI_FREQ (4U)          /*!< Bit field size in bits for SNVS_HPCR_PI_FREQ. */

/*! @brief Read current value of the SNVS_HPCR_PI_FREQ field. */
#define BR_SNVS_HPCR_PI_FREQ(x) (HW_SNVS_HPCR(x).B.PI_FREQ)

/*! @brief Format value for bitfield SNVS_HPCR_PI_FREQ. */
#define BF_SNVS_HPCR_PI_FREQ(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCR_PI_FREQ) & BM_SNVS_HPCR_PI_FREQ)

/*! @brief Set the PI_FREQ field to a new value. */
#define BW_SNVS_HPCR_PI_FREQ(x, v) (HW_SNVS_HPCR_WR(x, (HW_SNVS_HPCR_RD(x) & ~BM_SNVS_HPCR_PI_FREQ) | BF_SNVS_HPCR_PI_FREQ(v)))
/*@}*/

/*!
 * @name Register SNVS_HPCR, field HPCALB_EN[8] (RW)
 *
 * HP Real Time Counter Calibration Enabled Indicates that the time calibration
 * mechanism is enabled.
 *
 * Values:
 * - 0 - HP Timer calibration disabled
 * - 1 - HP Timer calibration enabled
 */
/*@{*/
#define BP_SNVS_HPCR_HPCALB_EN (8U)        /*!< Bit position for SNVS_HPCR_HPCALB_EN. */
#define BM_SNVS_HPCR_HPCALB_EN (0x00000100U) /*!< Bit mask for SNVS_HPCR_HPCALB_EN. */
#define BS_SNVS_HPCR_HPCALB_EN (1U)        /*!< Bit field size in bits for SNVS_HPCR_HPCALB_EN. */

/*! @brief Read current value of the SNVS_HPCR_HPCALB_EN field. */
#define BR_SNVS_HPCR_HPCALB_EN(x) (HW_SNVS_HPCR(x).B.HPCALB_EN)

/*! @brief Format value for bitfield SNVS_HPCR_HPCALB_EN. */
#define BF_SNVS_HPCR_HPCALB_EN(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCR_HPCALB_EN) & BM_SNVS_HPCR_HPCALB_EN)

/*! @brief Set the HPCALB_EN field to a new value. */
#define BW_SNVS_HPCR_HPCALB_EN(x, v) (HW_SNVS_HPCR_WR(x, (HW_SNVS_HPCR_RD(x) & ~BM_SNVS_HPCR_HPCALB_EN) | BF_SNVS_HPCR_HPCALB_EN(v)))
/*@}*/

/*!
 * @name Register SNVS_HPCR, field HPCALB_VAL[14:10] (RW)
 *
 * HP Calibration Value Defines signed calibration value for the HP Real Time
 * Counter. This field can be programmed only when RTC Calibration is disabled
 * (HPCALB_EN is not set). This is a 5-bit 2's complement value, hence the allowable
 * calibration values are in the range from -16 to +15 counts per 32768 ticks of
 * the counter.
 *
 * Values:
 * - 00000 - +0 counts per each 32768 ticks of the counter
 * - 00001 - +1 counts per each 32768 ticks of the counter
 * - 00010 - +2 counts per each 32768 ticks of the counter
 * - 01111 - +15 counts per each 32768 ticks of the counter
 * - 10000 - -16 counts per each 32768 ticks of the counter
 * - 10001 - -15 counts per each 32768 ticks of the counter
 * - 11110 - -2 counts per each 32768 ticks of the counter
 * - 11111 - -1 counts per each 32768 ticks of the counter
 */
/*@{*/
#define BP_SNVS_HPCR_HPCALB_VAL (10U)      /*!< Bit position for SNVS_HPCR_HPCALB_VAL. */
#define BM_SNVS_HPCR_HPCALB_VAL (0x00007C00U) /*!< Bit mask for SNVS_HPCR_HPCALB_VAL. */
#define BS_SNVS_HPCR_HPCALB_VAL (5U)       /*!< Bit field size in bits for SNVS_HPCR_HPCALB_VAL. */

/*! @brief Read current value of the SNVS_HPCR_HPCALB_VAL field. */
#define BR_SNVS_HPCR_HPCALB_VAL(x) (HW_SNVS_HPCR(x).B.HPCALB_VAL)

/*! @brief Format value for bitfield SNVS_HPCR_HPCALB_VAL. */
#define BF_SNVS_HPCR_HPCALB_VAL(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCR_HPCALB_VAL) & BM_SNVS_HPCR_HPCALB_VAL)

/*! @brief Set the HPCALB_VAL field to a new value. */
#define BW_SNVS_HPCR_HPCALB_VAL(x, v) (HW_SNVS_HPCR_WR(x, (HW_SNVS_HPCR_RD(x) & ~BM_SNVS_HPCR_HPCALB_VAL) | BF_SNVS_HPCR_HPCALB_VAL(v)))
/*@}*/

/*!
 * @name Register SNVS_HPCR, field BTN_CONFIG[26:24] (RW)
 *
 * Button Configuration. This field is used to configure which feature of the
 * button (BTN) input signal constitutes "active". 000: Button signal is active low
 * 001: Button signal is active high 010: Button signal is active on the rising
 * edge 011: Button signal is active on the falling edge 100: Button signal is
 * active on any edge All other patterns are reserved.
 */
/*@{*/
#define BP_SNVS_HPCR_BTN_CONFIG (24U)      /*!< Bit position for SNVS_HPCR_BTN_CONFIG. */
#define BM_SNVS_HPCR_BTN_CONFIG (0x07000000U) /*!< Bit mask for SNVS_HPCR_BTN_CONFIG. */
#define BS_SNVS_HPCR_BTN_CONFIG (3U)       /*!< Bit field size in bits for SNVS_HPCR_BTN_CONFIG. */

/*! @brief Read current value of the SNVS_HPCR_BTN_CONFIG field. */
#define BR_SNVS_HPCR_BTN_CONFIG(x) (HW_SNVS_HPCR(x).B.BTN_CONFIG)

/*! @brief Format value for bitfield SNVS_HPCR_BTN_CONFIG. */
#define BF_SNVS_HPCR_BTN_CONFIG(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCR_BTN_CONFIG) & BM_SNVS_HPCR_BTN_CONFIG)

/*! @brief Set the BTN_CONFIG field to a new value. */
#define BW_SNVS_HPCR_BTN_CONFIG(x, v) (HW_SNVS_HPCR_WR(x, (HW_SNVS_HPCR_RD(x) & ~BM_SNVS_HPCR_BTN_CONFIG) | BF_SNVS_HPCR_BTN_CONFIG(v)))
/*@}*/

/*!
 * @name Register SNVS_HPCR, field BTN_MASK[27] (RW)
 *
 * Button interrupt mask. This bit is used to mask the ipi_snvs_btn_int_b
 * (button) interrupt request. 0: Interrupt disabled 1: Interrupt enabled
 */
/*@{*/
#define BP_SNVS_HPCR_BTN_MASK (27U)        /*!< Bit position for SNVS_HPCR_BTN_MASK. */
#define BM_SNVS_HPCR_BTN_MASK (0x08000000U) /*!< Bit mask for SNVS_HPCR_BTN_MASK. */
#define BS_SNVS_HPCR_BTN_MASK (1U)         /*!< Bit field size in bits for SNVS_HPCR_BTN_MASK. */

/*! @brief Read current value of the SNVS_HPCR_BTN_MASK field. */
#define BR_SNVS_HPCR_BTN_MASK(x) (HW_SNVS_HPCR(x).B.BTN_MASK)

/*! @brief Format value for bitfield SNVS_HPCR_BTN_MASK. */
#define BF_SNVS_HPCR_BTN_MASK(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPCR_BTN_MASK) & BM_SNVS_HPCR_BTN_MASK)

/*! @brief Set the BTN_MASK field to a new value. */
#define BW_SNVS_HPCR_BTN_MASK(x, v) (HW_SNVS_HPCR_WR(x, (HW_SNVS_HPCR_RD(x) & ~BM_SNVS_HPCR_BTN_MASK) | BF_SNVS_HPCR_BTN_MASK(v)))
/*@}*/

/*******************************************************************************
 * HW_SNVS_HPSR - SNVS_HP Status Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPSR - SNVS_HP Status Register (RW)
 *
 * Reset value: 0x80000000U
 *
 * The HP Status Register reflects the internal state of the SNVS.
 */
typedef union _hw_snvs_hpsr
{
    uint32_t U;
    struct _hw_snvs_hpsr_bitfields
    {
        uint32_t RESERVED0 : 6;        /*!< [5:0]  */
        uint32_t BTN : 1;              /*!< [6]  */
        uint32_t BI : 1;               /*!< [7]  */
        uint32_t RESERVED1 : 24;       /*!< [31:8]  */
    } B;
} hw_snvs_hpsr_t;

/*!
 * @name Constants and macros for entire SNVS_HPSR register
 */
/*@{*/
#define HW_SNVS_HPSR_ADDR(x)     ((uintptr_t)(x) + 0x14U)

#define HW_SNVS_HPSR(x)          (*(__IO hw_snvs_hpsr_t *) HW_SNVS_HPSR_ADDR(x))
#define HW_SNVS_HPSR_RD(x)       (HW_SNVS_HPSR(x).U)
#define HW_SNVS_HPSR_WR(x, v)    (HW_SNVS_HPSR(x).U = (v))
#define HW_SNVS_HPSR_SET(x, v)   (HW_SNVS_HPSR_WR(x, HW_SNVS_HPSR_RD(x) |  (v)))
#define HW_SNVS_HPSR_CLR(x, v)   (HW_SNVS_HPSR_WR(x, HW_SNVS_HPSR_RD(x) & ~(v)))
#define HW_SNVS_HPSR_TOG(x, v)   (HW_SNVS_HPSR_WR(x, HW_SNVS_HPSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_HPSR bitfields
 */

/*!
 * @name Register SNVS_HPSR, field BTN[6] (RO)
 *
 * Value of the BTN input. This is the external button used for PMIC control. 0:
 * BTN not pressed 1: BTN pressed
 */
/*@{*/
#define BP_SNVS_HPSR_BTN     (6U)          /*!< Bit position for SNVS_HPSR_BTN. */
#define BM_SNVS_HPSR_BTN     (0x00000040U) /*!< Bit mask for SNVS_HPSR_BTN. */
#define BS_SNVS_HPSR_BTN     (1U)          /*!< Bit field size in bits for SNVS_HPSR_BTN. */

/*! @brief Read current value of the SNVS_HPSR_BTN field. */
#define BR_SNVS_HPSR_BTN(x)  (HW_SNVS_HPSR(x).B.BTN)
/*@}*/

/*!
 * @name Register SNVS_HPSR, field BI[7] (W1C)
 *
 * Button Interrupt. Signal ipi_snvs_btn_int_b was asserted.
 */
/*@{*/
#define BP_SNVS_HPSR_BI      (7U)          /*!< Bit position for SNVS_HPSR_BI. */
#define BM_SNVS_HPSR_BI      (0x00000080U) /*!< Bit mask for SNVS_HPSR_BI. */
#define BS_SNVS_HPSR_BI      (1U)          /*!< Bit field size in bits for SNVS_HPSR_BI. */

/*! @brief Read current value of the SNVS_HPSR_BI field. */
#define BR_SNVS_HPSR_BI(x)   (HW_SNVS_HPSR(x).B.BI)

/*! @brief Format value for bitfield SNVS_HPSR_BI. */
#define BF_SNVS_HPSR_BI(v)   ((uint32_t)((uint32_t)(v) << BP_SNVS_HPSR_BI) & BM_SNVS_HPSR_BI)

/*! @brief Set the BI field to a new value. */
#define BW_SNVS_HPSR_BI(x, v) (HW_SNVS_HPSR_WR(x, (HW_SNVS_HPSR_RD(x) & ~BM_SNVS_HPSR_BI) | BF_SNVS_HPSR_BI(v)))
/*@}*/

/*******************************************************************************
 * HW_SNVS_HPRTCMR - SNVS_HP Real Time Counter MSB Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPRTCMR - SNVS_HP Real Time Counter MSB Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_HP Real Time Counter MSB register contains the most significant bits
 * of the HP Real Time Counter.
 */
typedef union _hw_snvs_hprtcmr
{
    uint32_t U;
    struct _hw_snvs_hprtcmr_bitfields
    {
        uint32_t RTC : 32;             /*!< [31:0]  */
    } B;
} hw_snvs_hprtcmr_t;

/*!
 * @name Constants and macros for entire SNVS_HPRTCMR register
 */
/*@{*/
#define HW_SNVS_HPRTCMR_ADDR(x)  ((uintptr_t)(x) + 0x24U)

#define HW_SNVS_HPRTCMR(x)       (*(__IO hw_snvs_hprtcmr_t *) HW_SNVS_HPRTCMR_ADDR(x))
#define HW_SNVS_HPRTCMR_RD(x)    (HW_SNVS_HPRTCMR(x).U)
#define HW_SNVS_HPRTCMR_WR(x, v) (HW_SNVS_HPRTCMR(x).U = (v))
#define HW_SNVS_HPRTCMR_SET(x, v) (HW_SNVS_HPRTCMR_WR(x, HW_SNVS_HPRTCMR_RD(x) |  (v)))
#define HW_SNVS_HPRTCMR_CLR(x, v) (HW_SNVS_HPRTCMR_WR(x, HW_SNVS_HPRTCMR_RD(x) & ~(v)))
#define HW_SNVS_HPRTCMR_TOG(x, v) (HW_SNVS_HPRTCMR_WR(x, HW_SNVS_HPRTCMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_HPRTCMR bitfields
 */

/*!
 * @name Register SNVS_HPRTCMR, field RTC[31:0] (RW)
 *
 * HP Real Time Counter Most significant 32 bits. This register can be
 * programmed only when RTC is not active (RTC_EN bit is not set).
 */
/*@{*/
#define BP_SNVS_HPRTCMR_RTC  (0U)          /*!< Bit position for SNVS_HPRTCMR_RTC. */
#define BM_SNVS_HPRTCMR_RTC  (0xFFFFFFFFU) /*!< Bit mask for SNVS_HPRTCMR_RTC. */
#define BS_SNVS_HPRTCMR_RTC  (32U)         /*!< Bit field size in bits for SNVS_HPRTCMR_RTC. */

/*! @brief Read current value of the SNVS_HPRTCMR_RTC field. */
#define BR_SNVS_HPRTCMR_RTC(x) (HW_SNVS_HPRTCMR(x).U)

/*! @brief Format value for bitfield SNVS_HPRTCMR_RTC. */
#define BF_SNVS_HPRTCMR_RTC(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPRTCMR_RTC) & BM_SNVS_HPRTCMR_RTC)

/*! @brief Set the RTC field to a new value. */
#define BW_SNVS_HPRTCMR_RTC(x, v) (HW_SNVS_HPRTCMR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SNVS_HPRTCLR - SNVS_HP Real Time Counter LSB Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPRTCLR - SNVS_HP Real Time Counter LSB Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_HP Real Time Counter LSB register contains the 32 least significant
 * bits of the HP real time counter.
 */
typedef union _hw_snvs_hprtclr
{
    uint32_t U;
    struct _hw_snvs_hprtclr_bitfields
    {
        uint32_t RTC : 32;             /*!< [31:0]  */
    } B;
} hw_snvs_hprtclr_t;

/*!
 * @name Constants and macros for entire SNVS_HPRTCLR register
 */
/*@{*/
#define HW_SNVS_HPRTCLR_ADDR(x)  ((uintptr_t)(x) + 0x28U)

#define HW_SNVS_HPRTCLR(x)       (*(__IO hw_snvs_hprtclr_t *) HW_SNVS_HPRTCLR_ADDR(x))
#define HW_SNVS_HPRTCLR_RD(x)    (HW_SNVS_HPRTCLR(x).U)
#define HW_SNVS_HPRTCLR_WR(x, v) (HW_SNVS_HPRTCLR(x).U = (v))
#define HW_SNVS_HPRTCLR_SET(x, v) (HW_SNVS_HPRTCLR_WR(x, HW_SNVS_HPRTCLR_RD(x) |  (v)))
#define HW_SNVS_HPRTCLR_CLR(x, v) (HW_SNVS_HPRTCLR_WR(x, HW_SNVS_HPRTCLR_RD(x) & ~(v)))
#define HW_SNVS_HPRTCLR_TOG(x, v) (HW_SNVS_HPRTCLR_WR(x, HW_SNVS_HPRTCLR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_HPRTCLR bitfields
 */

/*!
 * @name Register SNVS_HPRTCLR, field RTC[31:0] (RW)
 *
 * HP Real Time Counter Least significant 32 bits. This register can be
 * programmed only when RTC is not active (RTC_EN bit is not set).
 */
/*@{*/
#define BP_SNVS_HPRTCLR_RTC  (0U)          /*!< Bit position for SNVS_HPRTCLR_RTC. */
#define BM_SNVS_HPRTCLR_RTC  (0xFFFFFFFFU) /*!< Bit mask for SNVS_HPRTCLR_RTC. */
#define BS_SNVS_HPRTCLR_RTC  (32U)         /*!< Bit field size in bits for SNVS_HPRTCLR_RTC. */

/*! @brief Read current value of the SNVS_HPRTCLR_RTC field. */
#define BR_SNVS_HPRTCLR_RTC(x) (HW_SNVS_HPRTCLR(x).U)

/*! @brief Format value for bitfield SNVS_HPRTCLR_RTC. */
#define BF_SNVS_HPRTCLR_RTC(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPRTCLR_RTC) & BM_SNVS_HPRTCLR_RTC)

/*! @brief Set the RTC field to a new value. */
#define BW_SNVS_HPRTCLR_RTC(x, v) (HW_SNVS_HPRTCLR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SNVS_HPTAMR - SNVS_HP Time Alarm MSB Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPTAMR - SNVS_HP Time Alarm MSB Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_HP Time Alarm MSB register contains the most significant bits of the
 * SNVS_HP Time Alarm value.
 */
typedef union _hw_snvs_hptamr
{
    uint32_t U;
    struct _hw_snvs_hptamr_bitfields
    {
        uint32_t HPTA : 15;            /*!< [14:0]  */
        uint32_t RESERVED0 : 17;       /*!< [31:15]  */
    } B;
} hw_snvs_hptamr_t;

/*!
 * @name Constants and macros for entire SNVS_HPTAMR register
 */
/*@{*/
#define HW_SNVS_HPTAMR_ADDR(x)   ((uintptr_t)(x) + 0x2CU)

#define HW_SNVS_HPTAMR(x)        (*(__IO hw_snvs_hptamr_t *) HW_SNVS_HPTAMR_ADDR(x))
#define HW_SNVS_HPTAMR_RD(x)     (HW_SNVS_HPTAMR(x).U)
#define HW_SNVS_HPTAMR_WR(x, v)  (HW_SNVS_HPTAMR(x).U = (v))
#define HW_SNVS_HPTAMR_SET(x, v) (HW_SNVS_HPTAMR_WR(x, HW_SNVS_HPTAMR_RD(x) |  (v)))
#define HW_SNVS_HPTAMR_CLR(x, v) (HW_SNVS_HPTAMR_WR(x, HW_SNVS_HPTAMR_RD(x) & ~(v)))
#define HW_SNVS_HPTAMR_TOG(x, v) (HW_SNVS_HPTAMR_WR(x, HW_SNVS_HPTAMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_HPTAMR bitfields
 */

/*!
 * @name Register SNVS_HPTAMR, field HPTA[14:0] (RW)
 *
 * HP Time Alarm Most significant 15 bits. This register can be programmed only
 * when HP time alarm is disabled (HPTA_EN bit is not set).
 */
/*@{*/
#define BP_SNVS_HPTAMR_HPTA  (0U)          /*!< Bit position for SNVS_HPTAMR_HPTA. */
#define BM_SNVS_HPTAMR_HPTA  (0x00007FFFU) /*!< Bit mask for SNVS_HPTAMR_HPTA. */
#define BS_SNVS_HPTAMR_HPTA  (15U)         /*!< Bit field size in bits for SNVS_HPTAMR_HPTA. */

/*! @brief Read current value of the SNVS_HPTAMR_HPTA field. */
#define BR_SNVS_HPTAMR_HPTA(x) (HW_SNVS_HPTAMR(x).B.HPTA)

/*! @brief Format value for bitfield SNVS_HPTAMR_HPTA. */
#define BF_SNVS_HPTAMR_HPTA(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPTAMR_HPTA) & BM_SNVS_HPTAMR_HPTA)

/*! @brief Set the HPTA field to a new value. */
#define BW_SNVS_HPTAMR_HPTA(x, v) (HW_SNVS_HPTAMR_WR(x, (HW_SNVS_HPTAMR_RD(x) & ~BM_SNVS_HPTAMR_HPTA) | BF_SNVS_HPTAMR_HPTA(v)))
/*@}*/

/*******************************************************************************
 * HW_SNVS_HPTALR - SNVS_HP Time Alarm LSB Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPTALR - SNVS_HP Time Alarm LSB Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_HP Time Alarm LSB register contains the 32 least significant bits of
 * the SNVS_HP Time Alarm value.
 */
typedef union _hw_snvs_hptalr
{
    uint32_t U;
    struct _hw_snvs_hptalr_bitfields
    {
        uint32_t HPTA : 32;            /*!< [31:0]  */
    } B;
} hw_snvs_hptalr_t;

/*!
 * @name Constants and macros for entire SNVS_HPTALR register
 */
/*@{*/
#define HW_SNVS_HPTALR_ADDR(x)   ((uintptr_t)(x) + 0x30U)

#define HW_SNVS_HPTALR(x)        (*(__IO hw_snvs_hptalr_t *) HW_SNVS_HPTALR_ADDR(x))
#define HW_SNVS_HPTALR_RD(x)     (HW_SNVS_HPTALR(x).U)
#define HW_SNVS_HPTALR_WR(x, v)  (HW_SNVS_HPTALR(x).U = (v))
#define HW_SNVS_HPTALR_SET(x, v) (HW_SNVS_HPTALR_WR(x, HW_SNVS_HPTALR_RD(x) |  (v)))
#define HW_SNVS_HPTALR_CLR(x, v) (HW_SNVS_HPTALR_WR(x, HW_SNVS_HPTALR_RD(x) & ~(v)))
#define HW_SNVS_HPTALR_TOG(x, v) (HW_SNVS_HPTALR_WR(x, HW_SNVS_HPTALR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_HPTALR bitfields
 */

/*!
 * @name Register SNVS_HPTALR, field HPTA[31:0] (RW)
 *
 * HP Time Alarm Least significant bits. This register can be programmed only
 * when HP time alarm is disabled (HPTA_EN bit is not set).
 */
/*@{*/
#define BP_SNVS_HPTALR_HPTA  (0U)          /*!< Bit position for SNVS_HPTALR_HPTA. */
#define BM_SNVS_HPTALR_HPTA  (0xFFFFFFFFU) /*!< Bit mask for SNVS_HPTALR_HPTA. */
#define BS_SNVS_HPTALR_HPTA  (32U)         /*!< Bit field size in bits for SNVS_HPTALR_HPTA. */

/*! @brief Read current value of the SNVS_HPTALR_HPTA field. */
#define BR_SNVS_HPTALR_HPTA(x) (HW_SNVS_HPTALR(x).U)

/*! @brief Format value for bitfield SNVS_HPTALR_HPTA. */
#define BF_SNVS_HPTALR_HPTA(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_HPTALR_HPTA) & BM_SNVS_HPTALR_HPTA)

/*! @brief Set the HPTA field to a new value. */
#define BW_SNVS_HPTALR_HPTA(x, v) (HW_SNVS_HPTALR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SNVS_LPLR - SNVS_LP Lock Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_LPLR - SNVS_LP Lock Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_LP Lock Register contains lock bits for the SNVS_LP registers.
 */
typedef union _hw_snvs_lplr
{
    uint32_t U;
    struct _hw_snvs_lplr_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t MC_HL : 1;            /*!< [4]  */
        uint32_t GPR_HL : 1;           /*!< [5]  */
        uint32_t RESERVED1 : 26;       /*!< [31:6]  */
    } B;
} hw_snvs_lplr_t;

/*!
 * @name Constants and macros for entire SNVS_LPLR register
 */
/*@{*/
#define HW_SNVS_LPLR_ADDR(x)     ((uintptr_t)(x) + 0x34U)

#define HW_SNVS_LPLR(x)          (*(__IO hw_snvs_lplr_t *) HW_SNVS_LPLR_ADDR(x))
#define HW_SNVS_LPLR_RD(x)       (HW_SNVS_LPLR(x).U)
#define HW_SNVS_LPLR_WR(x, v)    (HW_SNVS_LPLR(x).U = (v))
#define HW_SNVS_LPLR_SET(x, v)   (HW_SNVS_LPLR_WR(x, HW_SNVS_LPLR_RD(x) |  (v)))
#define HW_SNVS_LPLR_CLR(x, v)   (HW_SNVS_LPLR_WR(x, HW_SNVS_LPLR_RD(x) & ~(v)))
#define HW_SNVS_LPLR_TOG(x, v)   (HW_SNVS_LPLR_WR(x, HW_SNVS_LPLR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_LPLR bitfields
 */

/*!
 * @name Register SNVS_LPLR, field MC_HL[4] (RW)
 *
 * Monotonic Counter Hard Lock When set, prevents any writes (increments) to the
 * MC Registers and MC_ENV bit. Once set, this bit can only be reset by the LP
 * POR.
 *
 * Values:
 * - 0 - Write access (increment) is allowed.
 * - 1 - Write access (increment) is not allowed.
 */
/*@{*/
#define BP_SNVS_LPLR_MC_HL   (4U)          /*!< Bit position for SNVS_LPLR_MC_HL. */
#define BM_SNVS_LPLR_MC_HL   (0x00000010U) /*!< Bit mask for SNVS_LPLR_MC_HL. */
#define BS_SNVS_LPLR_MC_HL   (1U)          /*!< Bit field size in bits for SNVS_LPLR_MC_HL. */

/*! @brief Read current value of the SNVS_LPLR_MC_HL field. */
#define BR_SNVS_LPLR_MC_HL(x) (HW_SNVS_LPLR(x).B.MC_HL)

/*! @brief Format value for bitfield SNVS_LPLR_MC_HL. */
#define BF_SNVS_LPLR_MC_HL(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPLR_MC_HL) & BM_SNVS_LPLR_MC_HL)

/*! @brief Set the MC_HL field to a new value. */
#define BW_SNVS_LPLR_MC_HL(x, v) (HW_SNVS_LPLR_WR(x, (HW_SNVS_LPLR_RD(x) & ~BM_SNVS_LPLR_MC_HL) | BF_SNVS_LPLR_MC_HL(v)))
/*@}*/

/*!
 * @name Register SNVS_LPLR, field GPR_HL[5] (RW)
 *
 * General Purpose Register Hard Lock When set, prevents any writes to the GPR.
 * Once set, this bit can only be reset by the LP POR.
 *
 * Values:
 * - 0 - Write access is allowed.
 * - 1 - Write access is not allowed.
 */
/*@{*/
#define BP_SNVS_LPLR_GPR_HL  (5U)          /*!< Bit position for SNVS_LPLR_GPR_HL. */
#define BM_SNVS_LPLR_GPR_HL  (0x00000020U) /*!< Bit mask for SNVS_LPLR_GPR_HL. */
#define BS_SNVS_LPLR_GPR_HL  (1U)          /*!< Bit field size in bits for SNVS_LPLR_GPR_HL. */

/*! @brief Read current value of the SNVS_LPLR_GPR_HL field. */
#define BR_SNVS_LPLR_GPR_HL(x) (HW_SNVS_LPLR(x).B.GPR_HL)

/*! @brief Format value for bitfield SNVS_LPLR_GPR_HL. */
#define BF_SNVS_LPLR_GPR_HL(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPLR_GPR_HL) & BM_SNVS_LPLR_GPR_HL)

/*! @brief Set the GPR_HL field to a new value. */
#define BW_SNVS_LPLR_GPR_HL(x, v) (HW_SNVS_LPLR_WR(x, (HW_SNVS_LPLR_RD(x) & ~BM_SNVS_LPLR_GPR_HL) | BF_SNVS_LPLR_GPR_HL(v)))
/*@}*/

/*******************************************************************************
 * HW_SNVS_LPCR - SNVS_LP Control Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_LPCR - SNVS_LP Control Register (RW)
 *
 * Reset value: 0x00000020U
 *
 * The SNVS_LP Control Register contains various control bits of the LP section
 * of SNVS.
 */
typedef union _hw_snvs_lpcr
{
    uint32_t U;
    struct _hw_snvs_lpcr_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t MC_ENV : 1;           /*!< [2]  */
        uint32_t RESERVED1 : 2;        /*!< [4:3]  */
        uint32_t DP_EN : 1;            /*!< [5]  */
        uint32_t TOP : 1;              /*!< [6]  */
        uint32_t PWR_GLITCH_EN : 1;    /*!< [7]  */
        uint32_t RESERVED2 : 8;        /*!< [15:8]  */
        uint32_t BTN_PRESS_TIME : 2;   /*!< [17:16]  */
        uint32_t DEBOUNCE : 2;         /*!< [19:18]  */
        uint32_t ON_TIME : 2;          /*!< [21:20]  */
        uint32_t PK_EN : 1;            /*!< [22]  */
        uint32_t PK_OVERRIDE : 1;      /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_snvs_lpcr_t;

/*!
 * @name Constants and macros for entire SNVS_LPCR register
 */
/*@{*/
#define HW_SNVS_LPCR_ADDR(x)     ((uintptr_t)(x) + 0x38U)

#define HW_SNVS_LPCR(x)          (*(__IO hw_snvs_lpcr_t *) HW_SNVS_LPCR_ADDR(x))
#define HW_SNVS_LPCR_RD(x)       (HW_SNVS_LPCR(x).U)
#define HW_SNVS_LPCR_WR(x, v)    (HW_SNVS_LPCR(x).U = (v))
#define HW_SNVS_LPCR_SET(x, v)   (HW_SNVS_LPCR_WR(x, HW_SNVS_LPCR_RD(x) |  (v)))
#define HW_SNVS_LPCR_CLR(x, v)   (HW_SNVS_LPCR_WR(x, HW_SNVS_LPCR_RD(x) & ~(v)))
#define HW_SNVS_LPCR_TOG(x, v)   (HW_SNVS_LPCR_WR(x, HW_SNVS_LPCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_LPCR bitfields
 */

/*!
 * @name Register SNVS_LPCR, field MC_ENV[2] (RW)
 *
 * Monotonic Counter Enable and Valid When set, the MC can be incremented (by
 * write transaction to the LPSMCMR or LPSMCLR). This bit cannot be changed once
 * MC_SL or MC_HL bit is set.
 *
 * Values:
 * - 0 - MC is disabled or invalid.
 * - 1 - MC is enabled and valid.
 */
/*@{*/
#define BP_SNVS_LPCR_MC_ENV  (2U)          /*!< Bit position for SNVS_LPCR_MC_ENV. */
#define BM_SNVS_LPCR_MC_ENV  (0x00000004U) /*!< Bit mask for SNVS_LPCR_MC_ENV. */
#define BS_SNVS_LPCR_MC_ENV  (1U)          /*!< Bit field size in bits for SNVS_LPCR_MC_ENV. */

/*! @brief Read current value of the SNVS_LPCR_MC_ENV field. */
#define BR_SNVS_LPCR_MC_ENV(x) (HW_SNVS_LPCR(x).B.MC_ENV)

/*! @brief Format value for bitfield SNVS_LPCR_MC_ENV. */
#define BF_SNVS_LPCR_MC_ENV(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPCR_MC_ENV) & BM_SNVS_LPCR_MC_ENV)

/*! @brief Set the MC_ENV field to a new value. */
#define BW_SNVS_LPCR_MC_ENV(x, v) (HW_SNVS_LPCR_WR(x, (HW_SNVS_LPCR_RD(x) & ~BM_SNVS_LPCR_MC_ENV) | BF_SNVS_LPCR_MC_ENV(v)))
/*@}*/

/*!
 * @name Register SNVS_LPCR, field DP_EN[5] (RW)
 *
 * Dumb PMIC Enabled When set, software can control the system power. When
 * cleared, the system requires a Smart PMIC to automatically turn power off.
 *
 * Values:
 * - 0 - Smart PMIC enabled.
 * - 1 - Dumb PMIC enabled.
 */
/*@{*/
#define BP_SNVS_LPCR_DP_EN   (5U)          /*!< Bit position for SNVS_LPCR_DP_EN. */
#define BM_SNVS_LPCR_DP_EN   (0x00000020U) /*!< Bit mask for SNVS_LPCR_DP_EN. */
#define BS_SNVS_LPCR_DP_EN   (1U)          /*!< Bit field size in bits for SNVS_LPCR_DP_EN. */

/*! @brief Read current value of the SNVS_LPCR_DP_EN field. */
#define BR_SNVS_LPCR_DP_EN(x) (HW_SNVS_LPCR(x).B.DP_EN)

/*! @brief Format value for bitfield SNVS_LPCR_DP_EN. */
#define BF_SNVS_LPCR_DP_EN(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPCR_DP_EN) & BM_SNVS_LPCR_DP_EN)

/*! @brief Set the DP_EN field to a new value. */
#define BW_SNVS_LPCR_DP_EN(x, v) (HW_SNVS_LPCR_WR(x, (HW_SNVS_LPCR_RD(x) & ~BM_SNVS_LPCR_DP_EN) | BF_SNVS_LPCR_DP_EN(v)))
/*@}*/

/*!
 * @name Register SNVS_LPCR, field TOP[6] (RW)
 *
 * Turn off System Power Asserting this bit causes a signal to be sent to the
 * Power Management IC to turn off the system power. This bit will clear once power
 * is off. This bit is only valid when the Dumb PMIC is enabled.
 *
 * Values:
 * - 0 - Leave system power on.
 * - 1 - Turn off system power.
 */
/*@{*/
#define BP_SNVS_LPCR_TOP     (6U)          /*!< Bit position for SNVS_LPCR_TOP. */
#define BM_SNVS_LPCR_TOP     (0x00000040U) /*!< Bit mask for SNVS_LPCR_TOP. */
#define BS_SNVS_LPCR_TOP     (1U)          /*!< Bit field size in bits for SNVS_LPCR_TOP. */

/*! @brief Read current value of the SNVS_LPCR_TOP field. */
#define BR_SNVS_LPCR_TOP(x)  (HW_SNVS_LPCR(x).B.TOP)

/*! @brief Format value for bitfield SNVS_LPCR_TOP. */
#define BF_SNVS_LPCR_TOP(v)  ((uint32_t)((uint32_t)(v) << BP_SNVS_LPCR_TOP) & BM_SNVS_LPCR_TOP)

/*! @brief Set the TOP field to a new value. */
#define BW_SNVS_LPCR_TOP(x, v) (HW_SNVS_LPCR_WR(x, (HW_SNVS_LPCR_RD(x) & ~BM_SNVS_LPCR_TOP) | BF_SNVS_LPCR_TOP(v)))
/*@}*/

/*!
 * @name Register SNVS_LPCR, field PWR_GLITCH_EN[7] (RW)
 *
 * By default the detection of a power glitch does not cause the pmic_en_b
 * signal to be asserted. Setting the Power Glitch Enable bit to 1 enables the power
 * glitch event for the PMIC. 0 - disabled 1 - enabled
 */
/*@{*/
#define BP_SNVS_LPCR_PWR_GLITCH_EN (7U)    /*!< Bit position for SNVS_LPCR_PWR_GLITCH_EN. */
#define BM_SNVS_LPCR_PWR_GLITCH_EN (0x00000080U) /*!< Bit mask for SNVS_LPCR_PWR_GLITCH_EN. */
#define BS_SNVS_LPCR_PWR_GLITCH_EN (1U)    /*!< Bit field size in bits for SNVS_LPCR_PWR_GLITCH_EN. */

/*! @brief Read current value of the SNVS_LPCR_PWR_GLITCH_EN field. */
#define BR_SNVS_LPCR_PWR_GLITCH_EN(x) (HW_SNVS_LPCR(x).B.PWR_GLITCH_EN)

/*! @brief Format value for bitfield SNVS_LPCR_PWR_GLITCH_EN. */
#define BF_SNVS_LPCR_PWR_GLITCH_EN(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPCR_PWR_GLITCH_EN) & BM_SNVS_LPCR_PWR_GLITCH_EN)

/*! @brief Set the PWR_GLITCH_EN field to a new value. */
#define BW_SNVS_LPCR_PWR_GLITCH_EN(x, v) (HW_SNVS_LPCR_WR(x, (HW_SNVS_LPCR_RD(x) & ~BM_SNVS_LPCR_PWR_GLITCH_EN) | BF_SNVS_LPCR_PWR_GLITCH_EN(v)))
/*@}*/

/*!
 * @name Register SNVS_LPCR, field BTN_PRESS_TIME[17:16] (RW)
 *
 * Button press time out values for PMIC Logic. 00 : 5 secs 01 : 10 secs 10 : 15
 * secs 11 : long press disabled (pmic_en_b will not be asserted regardlessof
 * how long BTN is asserted)
 */
/*@{*/
#define BP_SNVS_LPCR_BTN_PRESS_TIME (16U)  /*!< Bit position for SNVS_LPCR_BTN_PRESS_TIME. */
#define BM_SNVS_LPCR_BTN_PRESS_TIME (0x00030000U) /*!< Bit mask for SNVS_LPCR_BTN_PRESS_TIME. */
#define BS_SNVS_LPCR_BTN_PRESS_TIME (2U)   /*!< Bit field size in bits for SNVS_LPCR_BTN_PRESS_TIME. */

/*! @brief Read current value of the SNVS_LPCR_BTN_PRESS_TIME field. */
#define BR_SNVS_LPCR_BTN_PRESS_TIME(x) (HW_SNVS_LPCR(x).B.BTN_PRESS_TIME)

/*! @brief Format value for bitfield SNVS_LPCR_BTN_PRESS_TIME. */
#define BF_SNVS_LPCR_BTN_PRESS_TIME(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPCR_BTN_PRESS_TIME) & BM_SNVS_LPCR_BTN_PRESS_TIME)

/*! @brief Set the BTN_PRESS_TIME field to a new value. */
#define BW_SNVS_LPCR_BTN_PRESS_TIME(x, v) (HW_SNVS_LPCR_WR(x, (HW_SNVS_LPCR_RD(x) & ~BM_SNVS_LPCR_BTN_PRESS_TIME) | BF_SNVS_LPCR_BTN_PRESS_TIME(v)))
/*@}*/

/*!
 * @name Register SNVS_LPCR, field DEBOUNCE[19:18] (RW)
 *
 * This field configures the amount of debounce time for the BTN input signal.
 * 00: 50msec debounce 01: 100msec debounce 10: 500msec debounce 11: 0msec debounce
 */
/*@{*/
#define BP_SNVS_LPCR_DEBOUNCE (18U)        /*!< Bit position for SNVS_LPCR_DEBOUNCE. */
#define BM_SNVS_LPCR_DEBOUNCE (0x000C0000U) /*!< Bit mask for SNVS_LPCR_DEBOUNCE. */
#define BS_SNVS_LPCR_DEBOUNCE (2U)         /*!< Bit field size in bits for SNVS_LPCR_DEBOUNCE. */

/*! @brief Read current value of the SNVS_LPCR_DEBOUNCE field. */
#define BR_SNVS_LPCR_DEBOUNCE(x) (HW_SNVS_LPCR(x).B.DEBOUNCE)

/*! @brief Format value for bitfield SNVS_LPCR_DEBOUNCE. */
#define BF_SNVS_LPCR_DEBOUNCE(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPCR_DEBOUNCE) & BM_SNVS_LPCR_DEBOUNCE)

/*! @brief Set the DEBOUNCE field to a new value. */
#define BW_SNVS_LPCR_DEBOUNCE(x, v) (HW_SNVS_LPCR_WR(x, (HW_SNVS_LPCR_RD(x) & ~BM_SNVS_LPCR_DEBOUNCE) | BF_SNVS_LPCR_DEBOUNCE(v)))
/*@}*/

/*!
 * @name Register SNVS_LPCR, field ON_TIME[21:20] (RW)
 *
 * The ON_TIME field is used to configure the period of time after BTN is
 * asserted before pmic_en_b is asserted to turn on the SoCpower. 00: 500msec off->on
 * transition time 01: 50msec off->on transition time 10: 100msec off->on
 * transition time 11: 0msec off->on transition time
 */
/*@{*/
#define BP_SNVS_LPCR_ON_TIME (20U)         /*!< Bit position for SNVS_LPCR_ON_TIME. */
#define BM_SNVS_LPCR_ON_TIME (0x00300000U) /*!< Bit mask for SNVS_LPCR_ON_TIME. */
#define BS_SNVS_LPCR_ON_TIME (2U)          /*!< Bit field size in bits for SNVS_LPCR_ON_TIME. */

/*! @brief Read current value of the SNVS_LPCR_ON_TIME field. */
#define BR_SNVS_LPCR_ON_TIME(x) (HW_SNVS_LPCR(x).B.ON_TIME)

/*! @brief Format value for bitfield SNVS_LPCR_ON_TIME. */
#define BF_SNVS_LPCR_ON_TIME(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPCR_ON_TIME) & BM_SNVS_LPCR_ON_TIME)

/*! @brief Set the ON_TIME field to a new value. */
#define BW_SNVS_LPCR_ON_TIME(x, v) (HW_SNVS_LPCR_WR(x, (HW_SNVS_LPCR_RD(x) & ~BM_SNVS_LPCR_ON_TIME) | BF_SNVS_LPCR_ON_TIME(v)))
/*@}*/

/*!
 * @name Register SNVS_LPCR, field PK_EN[22] (RW)
 *
 * PMIC On Request Enable. The value written to PK_EN will be asserted on output
 * signal snvs_lp_pk_en. That signal is used to turn off the pullup/pulldown
 * circuitry in the PMIC I/O pad.
 */
/*@{*/
#define BP_SNVS_LPCR_PK_EN   (22U)         /*!< Bit position for SNVS_LPCR_PK_EN. */
#define BM_SNVS_LPCR_PK_EN   (0x00400000U) /*!< Bit mask for SNVS_LPCR_PK_EN. */
#define BS_SNVS_LPCR_PK_EN   (1U)          /*!< Bit field size in bits for SNVS_LPCR_PK_EN. */

/*! @brief Read current value of the SNVS_LPCR_PK_EN field. */
#define BR_SNVS_LPCR_PK_EN(x) (HW_SNVS_LPCR(x).B.PK_EN)

/*! @brief Format value for bitfield SNVS_LPCR_PK_EN. */
#define BF_SNVS_LPCR_PK_EN(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPCR_PK_EN) & BM_SNVS_LPCR_PK_EN)

/*! @brief Set the PK_EN field to a new value. */
#define BW_SNVS_LPCR_PK_EN(x, v) (HW_SNVS_LPCR_WR(x, (HW_SNVS_LPCR_RD(x) & ~BM_SNVS_LPCR_PK_EN) | BF_SNVS_LPCR_PK_EN(v)))
/*@}*/

/*!
 * @name Register SNVS_LPCR, field PK_OVERRIDE[23] (RW)
 *
 * PMIC On Request Override. The value written to PK_OVERRIDE will be asserted
 * on output signal snvs_lp_pk_override. That signal is used to override the IOMUX
 * control for the PMIC I/O pad.
 */
/*@{*/
#define BP_SNVS_LPCR_PK_OVERRIDE (23U)     /*!< Bit position for SNVS_LPCR_PK_OVERRIDE. */
#define BM_SNVS_LPCR_PK_OVERRIDE (0x00800000U) /*!< Bit mask for SNVS_LPCR_PK_OVERRIDE. */
#define BS_SNVS_LPCR_PK_OVERRIDE (1U)      /*!< Bit field size in bits for SNVS_LPCR_PK_OVERRIDE. */

/*! @brief Read current value of the SNVS_LPCR_PK_OVERRIDE field. */
#define BR_SNVS_LPCR_PK_OVERRIDE(x) (HW_SNVS_LPCR(x).B.PK_OVERRIDE)

/*! @brief Format value for bitfield SNVS_LPCR_PK_OVERRIDE. */
#define BF_SNVS_LPCR_PK_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPCR_PK_OVERRIDE) & BM_SNVS_LPCR_PK_OVERRIDE)

/*! @brief Set the PK_OVERRIDE field to a new value. */
#define BW_SNVS_LPCR_PK_OVERRIDE(x, v) (HW_SNVS_LPCR_WR(x, (HW_SNVS_LPCR_RD(x) & ~BM_SNVS_LPCR_PK_OVERRIDE) | BF_SNVS_LPCR_PK_OVERRIDE(v)))
/*@}*/

/*******************************************************************************
 * HW_SNVS_LPSR - SNVS_LP Status Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_LPSR - SNVS_LP Status Register (RW)
 *
 * Reset value: 0x00000008U
 *
 * The SNVS_LP Status Register reflects the internal state and behavior of the
 * SNVS_LP.
 */
typedef union _hw_snvs_lpsr
{
    uint32_t U;
    struct _hw_snvs_lpsr_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t MCR : 1;              /*!< [2]  */
        uint32_t RESERVED1 : 14;       /*!< [16:3]  */
        uint32_t EO : 1;               /*!< [17]  */
        uint32_t SPO : 1;              /*!< [18]  */
        uint32_t RESERVED2 : 13;       /*!< [31:19]  */
    } B;
} hw_snvs_lpsr_t;

/*!
 * @name Constants and macros for entire SNVS_LPSR register
 */
/*@{*/
#define HW_SNVS_LPSR_ADDR(x)     ((uintptr_t)(x) + 0x4CU)

#define HW_SNVS_LPSR(x)          (*(__IO hw_snvs_lpsr_t *) HW_SNVS_LPSR_ADDR(x))
#define HW_SNVS_LPSR_RD(x)       (HW_SNVS_LPSR(x).U)
#define HW_SNVS_LPSR_WR(x, v)    (HW_SNVS_LPSR(x).U = (v))
#define HW_SNVS_LPSR_SET(x, v)   (HW_SNVS_LPSR_WR(x, HW_SNVS_LPSR_RD(x) |  (v)))
#define HW_SNVS_LPSR_CLR(x, v)   (HW_SNVS_LPSR_WR(x, HW_SNVS_LPSR_RD(x) & ~(v)))
#define HW_SNVS_LPSR_TOG(x, v)   (HW_SNVS_LPSR_WR(x, HW_SNVS_LPSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_LPSR bitfields
 */

/*!
 * @name Register SNVS_LPSR, field MCR[2] (W1C)
 *
 * Monotonic Counter Rollover.
 *
 * Values:
 * - 0 - MC has not reached its maximum value.
 * - 1 - MC has reached its maximum value.
 */
/*@{*/
#define BP_SNVS_LPSR_MCR     (2U)          /*!< Bit position for SNVS_LPSR_MCR. */
#define BM_SNVS_LPSR_MCR     (0x00000004U) /*!< Bit mask for SNVS_LPSR_MCR. */
#define BS_SNVS_LPSR_MCR     (1U)          /*!< Bit field size in bits for SNVS_LPSR_MCR. */

/*! @brief Read current value of the SNVS_LPSR_MCR field. */
#define BR_SNVS_LPSR_MCR(x)  (HW_SNVS_LPSR(x).B.MCR)

/*! @brief Format value for bitfield SNVS_LPSR_MCR. */
#define BF_SNVS_LPSR_MCR(v)  ((uint32_t)((uint32_t)(v) << BP_SNVS_LPSR_MCR) & BM_SNVS_LPSR_MCR)

/*! @brief Set the MCR field to a new value. */
#define BW_SNVS_LPSR_MCR(x, v) (HW_SNVS_LPSR_WR(x, (HW_SNVS_LPSR_RD(x) & ~(BM_SNVS_LPSR_MCR | BM_SNVS_LPSR_EO | BM_SNVS_LPSR_SPO)) | BF_SNVS_LPSR_MCR(v)))
/*@}*/

/*!
 * @name Register SNVS_LPSR, field EO[17] (W1C)
 *
 * Emergency Off This bit is set when a power off is requested.
 *
 * Values:
 * - 0 - Emergency off was not detected.
 * - 1 - Emergency off was detected.
 */
/*@{*/
#define BP_SNVS_LPSR_EO      (17U)         /*!< Bit position for SNVS_LPSR_EO. */
#define BM_SNVS_LPSR_EO      (0x00020000U) /*!< Bit mask for SNVS_LPSR_EO. */
#define BS_SNVS_LPSR_EO      (1U)          /*!< Bit field size in bits for SNVS_LPSR_EO. */

/*! @brief Read current value of the SNVS_LPSR_EO field. */
#define BR_SNVS_LPSR_EO(x)   (HW_SNVS_LPSR(x).B.EO)

/*! @brief Format value for bitfield SNVS_LPSR_EO. */
#define BF_SNVS_LPSR_EO(v)   ((uint32_t)((uint32_t)(v) << BP_SNVS_LPSR_EO) & BM_SNVS_LPSR_EO)

/*! @brief Set the EO field to a new value. */
#define BW_SNVS_LPSR_EO(x, v) (HW_SNVS_LPSR_WR(x, (HW_SNVS_LPSR_RD(x) & ~(BM_SNVS_LPSR_EO | BM_SNVS_LPSR_MCR | BM_SNVS_LPSR_SPO)) | BF_SNVS_LPSR_EO(v)))
/*@}*/

/*!
 * @name Register SNVS_LPSR, field SPO[18] (W1C)
 *
 * Set Power Off The SPO bit is set when the set_pwr_off_irq interrupt is
 * triggered, which happens when software writes a 1 to the TOP bit in the LPCR or when
 * the power button is pressed longer than the configured debounce time. Writing
 * to the SPO bit will clear the set_pwr_off_irq interrupt.
 *
 * Values:
 * - 0 - Emergency Off was not detected.
 * - 1 - Emergency Off was detected..
 */
/*@{*/
#define BP_SNVS_LPSR_SPO     (18U)         /*!< Bit position for SNVS_LPSR_SPO. */
#define BM_SNVS_LPSR_SPO     (0x00040000U) /*!< Bit mask for SNVS_LPSR_SPO. */
#define BS_SNVS_LPSR_SPO     (1U)          /*!< Bit field size in bits for SNVS_LPSR_SPO. */

/*! @brief Read current value of the SNVS_LPSR_SPO field. */
#define BR_SNVS_LPSR_SPO(x)  (HW_SNVS_LPSR(x).B.SPO)

/*! @brief Format value for bitfield SNVS_LPSR_SPO. */
#define BF_SNVS_LPSR_SPO(v)  ((uint32_t)((uint32_t)(v) << BP_SNVS_LPSR_SPO) & BM_SNVS_LPSR_SPO)

/*! @brief Set the SPO field to a new value. */
#define BW_SNVS_LPSR_SPO(x, v) (HW_SNVS_LPSR_WR(x, (HW_SNVS_LPSR_RD(x) & ~(BM_SNVS_LPSR_SPO | BM_SNVS_LPSR_MCR | BM_SNVS_LPSR_EO)) | BF_SNVS_LPSR_SPO(v)))
/*@}*/

/*******************************************************************************
 * HW_SNVS_LPSMCMR - SNVS_LP Secure Monotonic Counter MSB Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_LPSMCMR - SNVS_LP Secure Monotonic Counter MSB Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_LP Secure Monotonic Counter MSB Register contains the monotonic
 * counter era bits and the most significant 16 bits of the monotonic counter. The
 * monotonic counter is incremented by one if there is a write command to the
 * LPSMCMR or LPSMCLR register.
 */
typedef union _hw_snvs_lpsmcmr
{
    uint32_t U;
    struct _hw_snvs_lpsmcmr_bitfields
    {
        uint32_t MON_COUNTER : 16;     /*!< [15:0]  */
        uint32_t MC_ERA_BITS : 16;     /*!< [31:16]  */
    } B;
} hw_snvs_lpsmcmr_t;

/*!
 * @name Constants and macros for entire SNVS_LPSMCMR register
 */
/*@{*/
#define HW_SNVS_LPSMCMR_ADDR(x)  ((uintptr_t)(x) + 0x5CU)

#define HW_SNVS_LPSMCMR(x)       (*(__IO hw_snvs_lpsmcmr_t *) HW_SNVS_LPSMCMR_ADDR(x))
#define HW_SNVS_LPSMCMR_RD(x)    (HW_SNVS_LPSMCMR(x).U)
#define HW_SNVS_LPSMCMR_WR(x, v) (HW_SNVS_LPSMCMR(x).U = (v))
#define HW_SNVS_LPSMCMR_SET(x, v) (HW_SNVS_LPSMCMR_WR(x, HW_SNVS_LPSMCMR_RD(x) |  (v)))
#define HW_SNVS_LPSMCMR_CLR(x, v) (HW_SNVS_LPSMCMR_WR(x, HW_SNVS_LPSMCMR_RD(x) & ~(v)))
#define HW_SNVS_LPSMCMR_TOG(x, v) (HW_SNVS_LPSMCMR_WR(x, HW_SNVS_LPSMCMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_LPSMCMR bitfields
 */

/*!
 * @name Register SNVS_LPSMCMR, field MON_COUNTER[15:0] (RW)
 *
 * Monotonic Counter Most Significant 16 Bits The MC is incremented by one when:
 * A write transaction to the LPSMCMR or LPSMCLR register is detected. The
 * MC_ENV bit is set. MC_SL and MC_HL bits are not set.
 */
/*@{*/
#define BP_SNVS_LPSMCMR_MON_COUNTER (0U)   /*!< Bit position for SNVS_LPSMCMR_MON_COUNTER. */
#define BM_SNVS_LPSMCMR_MON_COUNTER (0x0000FFFFU) /*!< Bit mask for SNVS_LPSMCMR_MON_COUNTER. */
#define BS_SNVS_LPSMCMR_MON_COUNTER (16U)  /*!< Bit field size in bits for SNVS_LPSMCMR_MON_COUNTER. */

/*! @brief Read current value of the SNVS_LPSMCMR_MON_COUNTER field. */
#define BR_SNVS_LPSMCMR_MON_COUNTER(x) (HW_SNVS_LPSMCMR(x).B.MON_COUNTER)

/*! @brief Format value for bitfield SNVS_LPSMCMR_MON_COUNTER. */
#define BF_SNVS_LPSMCMR_MON_COUNTER(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPSMCMR_MON_COUNTER) & BM_SNVS_LPSMCMR_MON_COUNTER)

/*! @brief Set the MON_COUNTER field to a new value. */
#define BW_SNVS_LPSMCMR_MON_COUNTER(x, v) (HW_SNVS_LPSMCMR_WR(x, (HW_SNVS_LPSMCMR_RD(x) & ~BM_SNVS_LPSMCMR_MON_COUNTER) | BF_SNVS_LPSMCMR_MON_COUNTER(v)))
/*@}*/

/*!
 * @name Register SNVS_LPSMCMR, field MC_ERA_BITS[31:16] (RW)
 *
 * Monotonic Counter Era Bits These bits are inputs to the module and typically
 * connect to fuses.
 */
/*@{*/
#define BP_SNVS_LPSMCMR_MC_ERA_BITS (16U)  /*!< Bit position for SNVS_LPSMCMR_MC_ERA_BITS. */
#define BM_SNVS_LPSMCMR_MC_ERA_BITS (0xFFFF0000U) /*!< Bit mask for SNVS_LPSMCMR_MC_ERA_BITS. */
#define BS_SNVS_LPSMCMR_MC_ERA_BITS (16U)  /*!< Bit field size in bits for SNVS_LPSMCMR_MC_ERA_BITS. */

/*! @brief Read current value of the SNVS_LPSMCMR_MC_ERA_BITS field. */
#define BR_SNVS_LPSMCMR_MC_ERA_BITS(x) (HW_SNVS_LPSMCMR(x).B.MC_ERA_BITS)

/*! @brief Format value for bitfield SNVS_LPSMCMR_MC_ERA_BITS. */
#define BF_SNVS_LPSMCMR_MC_ERA_BITS(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPSMCMR_MC_ERA_BITS) & BM_SNVS_LPSMCMR_MC_ERA_BITS)

/*! @brief Set the MC_ERA_BITS field to a new value. */
#define BW_SNVS_LPSMCMR_MC_ERA_BITS(x, v) (HW_SNVS_LPSMCMR_WR(x, (HW_SNVS_LPSMCMR_RD(x) & ~BM_SNVS_LPSMCMR_MC_ERA_BITS) | BF_SNVS_LPSMCMR_MC_ERA_BITS(v)))
/*@}*/

/*******************************************************************************
 * HW_SNVS_LPSMCLR - SNVS_LP Secure Monotonic Counter LSB Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_LPSMCLR - SNVS_LP Secure Monotonic Counter LSB Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_LP Secure Monotonic Counter LSB Register contains the 32 least
 * significant bits of the monotonic counter. The MC is incremented by one if there is
 * a write command to the LPSMCMR or LPSMCLR register.
 */
typedef union _hw_snvs_lpsmclr
{
    uint32_t U;
    struct _hw_snvs_lpsmclr_bitfields
    {
        uint32_t MON_COUNTER : 32;     /*!< [31:0]  */
    } B;
} hw_snvs_lpsmclr_t;

/*!
 * @name Constants and macros for entire SNVS_LPSMCLR register
 */
/*@{*/
#define HW_SNVS_LPSMCLR_ADDR(x)  ((uintptr_t)(x) + 0x60U)

#define HW_SNVS_LPSMCLR(x)       (*(__IO hw_snvs_lpsmclr_t *) HW_SNVS_LPSMCLR_ADDR(x))
#define HW_SNVS_LPSMCLR_RD(x)    (HW_SNVS_LPSMCLR(x).U)
#define HW_SNVS_LPSMCLR_WR(x, v) (HW_SNVS_LPSMCLR(x).U = (v))
#define HW_SNVS_LPSMCLR_SET(x, v) (HW_SNVS_LPSMCLR_WR(x, HW_SNVS_LPSMCLR_RD(x) |  (v)))
#define HW_SNVS_LPSMCLR_CLR(x, v) (HW_SNVS_LPSMCLR_WR(x, HW_SNVS_LPSMCLR_RD(x) & ~(v)))
#define HW_SNVS_LPSMCLR_TOG(x, v) (HW_SNVS_LPSMCLR_WR(x, HW_SNVS_LPSMCLR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_LPSMCLR bitfields
 */

/*!
 * @name Register SNVS_LPSMCLR, field MON_COUNTER[31:0] (RW)
 *
 * Monotonic Counter bits The MC is incremented by one when: A write transaction
 * to the LPSMCMR or LPSMCLR Register is detected. The MC_ENV bit is set. MC_SL
 * and MC_HL bits are not set.
 */
/*@{*/
#define BP_SNVS_LPSMCLR_MON_COUNTER (0U)   /*!< Bit position for SNVS_LPSMCLR_MON_COUNTER. */
#define BM_SNVS_LPSMCLR_MON_COUNTER (0xFFFFFFFFU) /*!< Bit mask for SNVS_LPSMCLR_MON_COUNTER. */
#define BS_SNVS_LPSMCLR_MON_COUNTER (32U)  /*!< Bit field size in bits for SNVS_LPSMCLR_MON_COUNTER. */

/*! @brief Read current value of the SNVS_LPSMCLR_MON_COUNTER field. */
#define BR_SNVS_LPSMCLR_MON_COUNTER(x) (HW_SNVS_LPSMCLR(x).U)

/*! @brief Format value for bitfield SNVS_LPSMCLR_MON_COUNTER. */
#define BF_SNVS_LPSMCLR_MON_COUNTER(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPSMCLR_MON_COUNTER) & BM_SNVS_LPSMCLR_MON_COUNTER)

/*! @brief Set the MON_COUNTER field to a new value. */
#define BW_SNVS_LPSMCLR_MON_COUNTER(x, v) (HW_SNVS_LPSMCLR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SNVS_LPGPR - SNVS_LP General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_SNVS_LPGPR - SNVS_LP General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The SNVS_LP General Purpose Register is a 32-bit read/write register located
 * in the low power domain. Since LPGPR is located in the battery-backed power
 * domain, LPGPR can be used by any application for retaining data during an SoC
 * power-down mode. LPGPR will be automatically zeroized when a tamper event
 * occurs, unless GPR zeroization is disabled via the GPR_Z_DIS bit in the LP Control
 * Register.
 */
typedef union _hw_snvs_lpgpr
{
    uint32_t U;
    struct _hw_snvs_lpgpr_bitfields
    {
        uint32_t GPR : 32;             /*!< [31:0]  */
    } B;
} hw_snvs_lpgpr_t;

/*!
 * @name Constants and macros for entire SNVS_LPGPR register
 */
/*@{*/
#define HW_SNVS_LPGPR_ADDR(x)    ((uintptr_t)(x) + 0x68U)

#define HW_SNVS_LPGPR(x)         (*(__IO hw_snvs_lpgpr_t *) HW_SNVS_LPGPR_ADDR(x))
#define HW_SNVS_LPGPR_RD(x)      (HW_SNVS_LPGPR(x).U)
#define HW_SNVS_LPGPR_WR(x, v)   (HW_SNVS_LPGPR(x).U = (v))
#define HW_SNVS_LPGPR_SET(x, v)  (HW_SNVS_LPGPR_WR(x, HW_SNVS_LPGPR_RD(x) |  (v)))
#define HW_SNVS_LPGPR_CLR(x, v)  (HW_SNVS_LPGPR_WR(x, HW_SNVS_LPGPR_RD(x) & ~(v)))
#define HW_SNVS_LPGPR_TOG(x, v)  (HW_SNVS_LPGPR_WR(x, HW_SNVS_LPGPR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SNVS_LPGPR bitfields
 */

/*!
 * @name Register SNVS_LPGPR, field GPR[31:0] (RW)
 *
 * General Purpose Register When GPR_SL or GPR_HL bit is set, the register
 * cannot be programmed.
 */
/*@{*/
#define BP_SNVS_LPGPR_GPR    (0U)          /*!< Bit position for SNVS_LPGPR_GPR. */
#define BM_SNVS_LPGPR_GPR    (0xFFFFFFFFU) /*!< Bit mask for SNVS_LPGPR_GPR. */
#define BS_SNVS_LPGPR_GPR    (32U)         /*!< Bit field size in bits for SNVS_LPGPR_GPR. */

/*! @brief Read current value of the SNVS_LPGPR_GPR field. */
#define BR_SNVS_LPGPR_GPR(x) (HW_SNVS_LPGPR(x).U)

/*! @brief Format value for bitfield SNVS_LPGPR_GPR. */
#define BF_SNVS_LPGPR_GPR(v) ((uint32_t)((uint32_t)(v) << BP_SNVS_LPGPR_GPR) & BM_SNVS_LPGPR_GPR)

/*! @brief Set the GPR field to a new value. */
#define BW_SNVS_LPGPR_GPR(x, v) (HW_SNVS_LPGPR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SNVS_HPVIDR1 - SNVS_HP Version ID Register 1
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPVIDR1 - SNVS_HP Version ID Register 1 (RO)
 *
 * Reset value: 0x003E0300U
 *
 * The SNVS_HP Version ID Register 1 is a read-only register that contains the
 * current version of the SNVS . The version consists of a module ID, a major
 * version number, and a minor version number.
 */
typedef union _hw_snvs_hpvidr1
{
    uint32_t U;
    struct _hw_snvs_hpvidr1_bitfields
    {
        uint32_t MINOR_REV : 8;        /*!< [7:0]  */
        uint32_t MAJOR_REV : 8;        /*!< [15:8]  */
        uint32_t IP_ID : 16;           /*!< [31:16]  */
    } B;
} hw_snvs_hpvidr1_t;

/*!
 * @name Constants and macros for entire SNVS_HPVIDR1 register
 */
/*@{*/
#define HW_SNVS_HPVIDR1_ADDR(x)  ((uintptr_t)(x) + 0xBF8U)

#define HW_SNVS_HPVIDR1(x)       (*(__I hw_snvs_hpvidr1_t *) HW_SNVS_HPVIDR1_ADDR(x))
#define HW_SNVS_HPVIDR1_RD(x)    (HW_SNVS_HPVIDR1(x).U)
/*@}*/

/*
 * Constants & macros for individual SNVS_HPVIDR1 bitfields
 */

/*!
 * @name Register SNVS_HPVIDR1, field MINOR_REV[7:0] (RO)
 *
 * SNVS block minor version number
 */
/*@{*/
#define BP_SNVS_HPVIDR1_MINOR_REV (0U)     /*!< Bit position for SNVS_HPVIDR1_MINOR_REV. */
#define BM_SNVS_HPVIDR1_MINOR_REV (0x000000FFU) /*!< Bit mask for SNVS_HPVIDR1_MINOR_REV. */
#define BS_SNVS_HPVIDR1_MINOR_REV (8U)     /*!< Bit field size in bits for SNVS_HPVIDR1_MINOR_REV. */

/*! @brief Read current value of the SNVS_HPVIDR1_MINOR_REV field. */
#define BR_SNVS_HPVIDR1_MINOR_REV(x) (HW_SNVS_HPVIDR1(x).B.MINOR_REV)
/*@}*/

/*!
 * @name Register SNVS_HPVIDR1, field MAJOR_REV[15:8] (RO)
 *
 * SNVS block major version number
 */
/*@{*/
#define BP_SNVS_HPVIDR1_MAJOR_REV (8U)     /*!< Bit position for SNVS_HPVIDR1_MAJOR_REV. */
#define BM_SNVS_HPVIDR1_MAJOR_REV (0x0000FF00U) /*!< Bit mask for SNVS_HPVIDR1_MAJOR_REV. */
#define BS_SNVS_HPVIDR1_MAJOR_REV (8U)     /*!< Bit field size in bits for SNVS_HPVIDR1_MAJOR_REV. */

/*! @brief Read current value of the SNVS_HPVIDR1_MAJOR_REV field. */
#define BR_SNVS_HPVIDR1_MAJOR_REV(x) (HW_SNVS_HPVIDR1(x).B.MAJOR_REV)
/*@}*/

/*!
 * @name Register SNVS_HPVIDR1, field IP_ID[31:16] (RO)
 *
 * SNVS block ID
 */
/*@{*/
#define BP_SNVS_HPVIDR1_IP_ID (16U)        /*!< Bit position for SNVS_HPVIDR1_IP_ID. */
#define BM_SNVS_HPVIDR1_IP_ID (0xFFFF0000U) /*!< Bit mask for SNVS_HPVIDR1_IP_ID. */
#define BS_SNVS_HPVIDR1_IP_ID (16U)        /*!< Bit field size in bits for SNVS_HPVIDR1_IP_ID. */

/*! @brief Read current value of the SNVS_HPVIDR1_IP_ID field. */
#define BR_SNVS_HPVIDR1_IP_ID(x) (HW_SNVS_HPVIDR1(x).B.IP_ID)
/*@}*/

/*******************************************************************************
 * HW_SNVS_HPVIDR2 - SNVS_HP Version ID Register 2
 ******************************************************************************/

/*!
 * @brief HW_SNVS_HPVIDR2 - SNVS_HP Version ID Register 2 (RO)
 *
 * Reset value: 0x03000000U
 *
 * The SNVS_HP Version ID Register 2 is a read-only register that indicates the
 * current version of the SNVS. Version ID register 2 consists of the following
 * fields: integration options, ECO revision, and configuration options.
 */
typedef union _hw_snvs_hpvidr2
{
    uint32_t U;
    struct _hw_snvs_hpvidr2_bitfields
    {
        uint32_t CONFIG_OPT : 8;       /*!< [7:0]  */
        uint32_t ECO_REV : 8;          /*!< [15:8]  */
        uint32_t INTG_OPT : 8;         /*!< [23:16]  */
        uint32_t IP_ERA : 8;           /*!< [31:24] Era of the IP design */
    } B;
} hw_snvs_hpvidr2_t;

/*!
 * @name Constants and macros for entire SNVS_HPVIDR2 register
 */
/*@{*/
#define HW_SNVS_HPVIDR2_ADDR(x)  ((uintptr_t)(x) + 0xBFCU)

#define HW_SNVS_HPVIDR2(x)       (*(__I hw_snvs_hpvidr2_t *) HW_SNVS_HPVIDR2_ADDR(x))
#define HW_SNVS_HPVIDR2_RD(x)    (HW_SNVS_HPVIDR2(x).U)
/*@}*/

/*
 * Constants & macros for individual SNVS_HPVIDR2 bitfields
 */

/*!
 * @name Register SNVS_HPVIDR2, field CONFIG_OPT[7:0] (RO)
 *
 * SNVS Configuration Option
 */
/*@{*/
#define BP_SNVS_HPVIDR2_CONFIG_OPT (0U)    /*!< Bit position for SNVS_HPVIDR2_CONFIG_OPT. */
#define BM_SNVS_HPVIDR2_CONFIG_OPT (0x000000FFU) /*!< Bit mask for SNVS_HPVIDR2_CONFIG_OPT. */
#define BS_SNVS_HPVIDR2_CONFIG_OPT (8U)    /*!< Bit field size in bits for SNVS_HPVIDR2_CONFIG_OPT. */

/*! @brief Read current value of the SNVS_HPVIDR2_CONFIG_OPT field. */
#define BR_SNVS_HPVIDR2_CONFIG_OPT(x) (HW_SNVS_HPVIDR2(x).B.CONFIG_OPT)
/*@}*/

/*!
 * @name Register SNVS_HPVIDR2, field ECO_REV[15:8] (RO)
 *
 * SNVS ECO Revision
 */
/*@{*/
#define BP_SNVS_HPVIDR2_ECO_REV (8U)       /*!< Bit position for SNVS_HPVIDR2_ECO_REV. */
#define BM_SNVS_HPVIDR2_ECO_REV (0x0000FF00U) /*!< Bit mask for SNVS_HPVIDR2_ECO_REV. */
#define BS_SNVS_HPVIDR2_ECO_REV (8U)       /*!< Bit field size in bits for SNVS_HPVIDR2_ECO_REV. */

/*! @brief Read current value of the SNVS_HPVIDR2_ECO_REV field. */
#define BR_SNVS_HPVIDR2_ECO_REV(x) (HW_SNVS_HPVIDR2(x).B.ECO_REV)
/*@}*/

/*!
 * @name Register SNVS_HPVIDR2, field INTG_OPT[23:16] (RO)
 *
 * SNVS Integration Option
 */
/*@{*/
#define BP_SNVS_HPVIDR2_INTG_OPT (16U)     /*!< Bit position for SNVS_HPVIDR2_INTG_OPT. */
#define BM_SNVS_HPVIDR2_INTG_OPT (0x00FF0000U) /*!< Bit mask for SNVS_HPVIDR2_INTG_OPT. */
#define BS_SNVS_HPVIDR2_INTG_OPT (8U)      /*!< Bit field size in bits for SNVS_HPVIDR2_INTG_OPT. */

/*! @brief Read current value of the SNVS_HPVIDR2_INTG_OPT field. */
#define BR_SNVS_HPVIDR2_INTG_OPT(x) (HW_SNVS_HPVIDR2(x).B.INTG_OPT)
/*@}*/

/*!
 * @name Register SNVS_HPVIDR2, field IP_ERA[31:24] (RO)
 *
 * 00h - Era 1 or 2 03h - Era 3 04h - Era 4 05h - Era 5
 */
/*@{*/
#define BP_SNVS_HPVIDR2_IP_ERA (24U)       /*!< Bit position for SNVS_HPVIDR2_IP_ERA. */
#define BM_SNVS_HPVIDR2_IP_ERA (0xFF000000U) /*!< Bit mask for SNVS_HPVIDR2_IP_ERA. */
#define BS_SNVS_HPVIDR2_IP_ERA (8U)        /*!< Bit field size in bits for SNVS_HPVIDR2_IP_ERA. */

/*! @brief Read current value of the SNVS_HPVIDR2_IP_ERA field. */
#define BR_SNVS_HPVIDR2_IP_ERA(x) (HW_SNVS_HPVIDR2(x).B.IP_ERA)
/*@}*/

/*******************************************************************************
 * hw_snvs_t - module struct
 ******************************************************************************/
/*!
 * @brief All SNVS module registers.
 */
#pragma pack(1)
typedef struct _hw_snvs
{
    __IO hw_snvs_hplr_t HPLR;              /*!< [0x0] SNVS_HP Lock Register */
    __IO hw_snvs_hpcomr_t HPCOMR;          /*!< [0x4] SNVS_HP Command Register */
    __IO hw_snvs_hpcr_t HPCR;              /*!< [0x8] SNVS_HP Control Register */
    uint8_t _reserved0[8];
    __IO hw_snvs_hpsr_t HPSR;              /*!< [0x14] SNVS_HP Status Register */
    uint8_t _reserved1[12];
    __IO hw_snvs_hprtcmr_t HPRTCMR;        /*!< [0x24] SNVS_HP Real Time Counter MSB Register */
    __IO hw_snvs_hprtclr_t HPRTCLR;        /*!< [0x28] SNVS_HP Real Time Counter LSB Register */
    __IO hw_snvs_hptamr_t HPTAMR;          /*!< [0x2C] SNVS_HP Time Alarm MSB Register */
    __IO hw_snvs_hptalr_t HPTALR;          /*!< [0x30] SNVS_HP Time Alarm LSB Register */
    __IO hw_snvs_lplr_t LPLR;              /*!< [0x34] SNVS_LP Lock Register */
    __IO hw_snvs_lpcr_t LPCR;              /*!< [0x38] SNVS_LP Control Register */
    uint8_t _reserved2[16];
    __IO hw_snvs_lpsr_t LPSR;              /*!< [0x4C] SNVS_LP Status Register */
    uint8_t _reserved3[12];
    __IO hw_snvs_lpsmcmr_t LPSMCMR;        /*!< [0x5C] SNVS_LP Secure Monotonic Counter MSB Register */
    __IO hw_snvs_lpsmclr_t LPSMCLR;        /*!< [0x60] SNVS_LP Secure Monotonic Counter LSB Register */
    uint8_t _reserved4[4];
    __IO hw_snvs_lpgpr_t LPGPR;            /*!< [0x68] SNVS_LP General Purpose Register */
    uint8_t _reserved5[2956];
    __I hw_snvs_hpvidr1_t HPVIDR1;         /*!< [0xBF8] SNVS_HP Version ID Register 1 */
    __I hw_snvs_hpvidr2_t HPVIDR2;         /*!< [0xBFC] SNVS_HP Version ID Register 2 */
} hw_snvs_t;
#pragma pack()

/*! @brief Macro to access all SNVS registers. */
/*! @param x SNVS module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_SNVS_REGS(SNVS_BASE)</code>. */
#define HW_SNVS_REGS(x) (*(hw_snvs_t *)(x))

/*
 * iMX7D SPBA
 *
 * Temperature Monitor
 *
 * Registers defined in this header file:
 * - HW_SPBA_PRRn - Peripheral Rights Register
 *
 * - hw_spba_t - Struct containing all module registers.
 */

#define HW_SPBA_INSTANCE_COUNT (1U) /*!< Number of instances of the SPBA module. */
#define HW_SPBA (0U) /*!< Instance number for SPBA. */
#define SPBA_BASE             (0x308F0000U) /*!< Base address for SPBA. */
/*! Array initializer of SPBA base addresses. */
#define SPBA_BASE_ADDRS       { SPBA_BASE }

/*******************************************************************************
 * HW_SPBA_PRRn - Peripheral Rights Register
 ******************************************************************************/

/*!
 * @brief HW_SPBA_PRRn - Peripheral Rights Register (RW)
 *
 * Reset value: 0x00000007U
 *
 * This register controls master ownership and access for a peripheral.
 */
typedef union _hw_spba_prrn
{
    uint32_t U;
    struct _hw_spba_prrn_bitfields
    {
        uint32_t RARA : 1;             /*!< [0]  */
        uint32_t RARB : 1;             /*!< [1]  */
        uint32_t RARC : 1;             /*!< [2]  */
        uint32_t RESERVED0 : 13;       /*!< [15:3]  */
        uint32_t ROI : 2;              /*!< [17:16]  */
        uint32_t RESERVED1 : 12;       /*!< [29:18]  */
        uint32_t RMO : 2;              /*!< [31:30]  */
    } B;
} hw_spba_prrn_t;

/*!
 * @name Constants and macros for entire SPBA_PRRn register
 */
/*@{*/
#define HW_SPBA_PRRn_COUNT (32U)

#define HW_SPBA_PRRn_ADDR(x, n)  ((uintptr_t)(x) + 0x0U + (0x4U * (n)))

#define HW_SPBA_PRRn(x, n)       (*(__IO hw_spba_prrn_t *) HW_SPBA_PRRn_ADDR(x, n))
#define HW_SPBA_PRRn_RD(x, n)    (HW_SPBA_PRRn(x, n).U)
#define HW_SPBA_PRRn_WR(x, n, v) (HW_SPBA_PRRn(x, n).U = (v))
#define HW_SPBA_PRRn_SET(x, n, v) (HW_SPBA_PRRn_WR(x, n, HW_SPBA_PRRn_RD(x, n) |  (v)))
#define HW_SPBA_PRRn_CLR(x, n, v) (HW_SPBA_PRRn_WR(x, n, HW_SPBA_PRRn_RD(x, n) & ~(v)))
#define HW_SPBA_PRRn_TOG(x, n, v) (HW_SPBA_PRRn_WR(x, n, HW_SPBA_PRRn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SPBA_PRRn bitfields
 */

/*!
 * @name Register SPBA_PRRn, field RARA[0] (RW)
 *
 * Resource Access Right. Control and Status bit for master A. This field
 * indicates whether master A can access the peripheral. From 0 up to 3 masters can
 * have permission to access a resource (all the master can be granted on a
 * peripheral, but only one access at a time will be granted by SPBA).
 *
 * Values:
 * - 0 - Access to peripheral is not allowed.
 * - 1 - Access to peripheral is granted.
 */
/*@{*/
#define BP_SPBA_PRRn_RARA    (0U)          /*!< Bit position for SPBA_PRRn_RARA. */
#define BM_SPBA_PRRn_RARA    (0x00000001U) /*!< Bit mask for SPBA_PRRn_RARA. */
#define BS_SPBA_PRRn_RARA    (1U)          /*!< Bit field size in bits for SPBA_PRRn_RARA. */

#define BV_SPBA_PRRn_RARA_PROHIBITED   (0U)          /*!< Bit field value for SPBA_PRRn_RARA: Access to peripheral is not allowed. */
#define BV_SPBA_PRRn_RARA_ALLOWED      (0x1U)        /*!< Bit field value for SPBA_PRRn_RARA: Access to peripheral is granted. */

/*! @brief Read current value of the SPBA_PRRn_RARA field. */
#define BR_SPBA_PRRn_RARA(x, n) (HW_SPBA_PRRn(x, n).B.RARA)

/*! @brief Format value for bitfield SPBA_PRRn_RARA. */
#define BF_SPBA_PRRn_RARA(v) ((uint32_t)((uint32_t)(v) << BP_SPBA_PRRn_RARA) & BM_SPBA_PRRn_RARA)

/*! @brief Set the RARA field to a new value. */
#define BW_SPBA_PRRn_RARA(x, n, v) (HW_SPBA_PRRn_WR(x, n, (HW_SPBA_PRRn_RD(x, n) & ~BM_SPBA_PRRn_RARA) | BF_SPBA_PRRn_RARA(v)))
/*@}*/

/*!
 * @name Register SPBA_PRRn, field RARB[1] (RW)
 *
 * Resource Access Right. Control and Status bit for master B. This field
 * indicates whether master B can access the peripheral. From 0 up to 3 masters can
 * have permission to access a resource (all the master can be granted on a
 * peripheral, but only one access at a time will be granted by SPBA).
 *
 * Values:
 * - 0 - Access to peripheral is not allowed.
 * - 1 - Access to peripheral is granted.
 */
/*@{*/
#define BP_SPBA_PRRn_RARB    (1U)          /*!< Bit position for SPBA_PRRn_RARB. */
#define BM_SPBA_PRRn_RARB    (0x00000002U) /*!< Bit mask for SPBA_PRRn_RARB. */
#define BS_SPBA_PRRn_RARB    (1U)          /*!< Bit field size in bits for SPBA_PRRn_RARB. */

#define BV_SPBA_PRRn_RARB_PROHIBITED   (0U)          /*!< Bit field value for SPBA_PRRn_RARB: Access to peripheral is not allowed. */
#define BV_SPBA_PRRn_RARB_ALLOWED      (0x1U)        /*!< Bit field value for SPBA_PRRn_RARB: Access to peripheral is granted. */

/*! @brief Read current value of the SPBA_PRRn_RARB field. */
#define BR_SPBA_PRRn_RARB(x, n) (HW_SPBA_PRRn(x, n).B.RARB)

/*! @brief Format value for bitfield SPBA_PRRn_RARB. */
#define BF_SPBA_PRRn_RARB(v) ((uint32_t)((uint32_t)(v) << BP_SPBA_PRRn_RARB) & BM_SPBA_PRRn_RARB)

/*! @brief Set the RARB field to a new value. */
#define BW_SPBA_PRRn_RARB(x, n, v) (HW_SPBA_PRRn_WR(x, n, (HW_SPBA_PRRn_RD(x, n) & ~BM_SPBA_PRRn_RARB) | BF_SPBA_PRRn_RARB(v)))
/*@}*/

/*!
 * @name Register SPBA_PRRn, field RARC[2] (RW)
 *
 * Resource Access Right. Control and Status bit for master C. This field
 * indicates whether master C can access the peripheral. From 0 up to 3 masters can
 * have permission to access a resource (all the master can be granted on a
 * peripheral, but only one access at a time will be granted by SPBA).
 *
 * Values:
 * - 0 - Access to peripheral is not allowed.
 * - 1 - Access to peripheral is granted.
 */
/*@{*/
#define BP_SPBA_PRRn_RARC    (2U)          /*!< Bit position for SPBA_PRRn_RARC. */
#define BM_SPBA_PRRn_RARC    (0x00000004U) /*!< Bit mask for SPBA_PRRn_RARC. */
#define BS_SPBA_PRRn_RARC    (1U)          /*!< Bit field size in bits for SPBA_PRRn_RARC. */

#define BV_SPBA_PRRn_RARC_PROHIBITED   (0U)          /*!< Bit field value for SPBA_PRRn_RARC: Access to peripheral is not allowed. */
#define BV_SPBA_PRRn_RARC_ALLOWED      (0x1U)        /*!< Bit field value for SPBA_PRRn_RARC: Access to peripheral is granted. */

/*! @brief Read current value of the SPBA_PRRn_RARC field. */
#define BR_SPBA_PRRn_RARC(x, n) (HW_SPBA_PRRn(x, n).B.RARC)

/*! @brief Format value for bitfield SPBA_PRRn_RARC. */
#define BF_SPBA_PRRn_RARC(v) ((uint32_t)((uint32_t)(v) << BP_SPBA_PRRn_RARC) & BM_SPBA_PRRn_RARC)

/*! @brief Set the RARC field to a new value. */
#define BW_SPBA_PRRn_RARC(x, n, v) (HW_SPBA_PRRn_WR(x, n, (HW_SPBA_PRRn_RD(x, n) & ~BM_SPBA_PRRn_RARC) | BF_SPBA_PRRn_RARC(v)))
/*@}*/

/*!
 * @name Register SPBA_PRRn, field ROI[17:16] (RO)
 *
 * Resource Owner ID. This field indicates which master (one at a time) can
 * access to the PRR for rights modification. This is a read-only register. After
 * reset, ROI bits are cleared ("00" -> un-owned resource). A master performing a
 * write access to the an un-owned PRR will get its ID automatically written into
 * ROI, while modifying RARx bits. It can then read back the RMO, RAR, ROI bits to
 * make sure RMO returns the right value, ROI bits contain its ID and RARx bits
 * are correctly asserted. Then no other master (whom ID is different from the
 * one stored in ROI) will be able to modify RAR fields. Owner master of a
 * peripheral can assert its dead_owner signal, or write 1'b0 in the RARx to release the
 * ownership (ROI[1:0] reset to 2'b0).
 *
 * Values:
 * - 00 - Unowned resource.
 * - 01 - The resource is owned by master A port.
 * - 10 - The resource is owned by master B port.
 * - 11 - The resource is owned by master C port.
 */
/*@{*/
#define BP_SPBA_PRRn_ROI     (16U)         /*!< Bit position for SPBA_PRRn_ROI. */
#define BM_SPBA_PRRn_ROI     (0x00030000U) /*!< Bit mask for SPBA_PRRn_ROI. */
#define BS_SPBA_PRRn_ROI     (2U)          /*!< Bit field size in bits for SPBA_PRRn_ROI. */

#define BV_SPBA_PRRn_ROI_UNOWNED       (0U)          /*!< Bit field value for SPBA_PRRn_ROI: Unowned resource. */
#define BV_SPBA_PRRn_ROI_MASTER_A      (0x1U)        /*!< Bit field value for SPBA_PRRn_ROI: The resource is owned by master A port. */
#define BV_SPBA_PRRn_ROI_MASTER_B      (0x2U)        /*!< Bit field value for SPBA_PRRn_ROI: The resource is owned by master B port. */
#define BV_SPBA_PRRn_ROI_MASTER_C      (0x3U)        /*!< Bit field value for SPBA_PRRn_ROI: The resource is owned by master C port. */

/*! @brief Read current value of the SPBA_PRRn_ROI field. */
#define BR_SPBA_PRRn_ROI(x, n) (HW_SPBA_PRRn(x, n).B.ROI)
/*@}*/

/*!
 * @name Register SPBA_PRRn, field RMO[31:30] (RO)
 *
 * Requesting Master Owner. This 2-bit register field indicates if the
 * corresponding resource is owned by the requesting master or not. This register is reset
 * to 2'b0 if ROI = 2'b0.
 *
 * Values:
 * - 00 - The resource is unowned.
 * - 01 - Reserved.
 * - 10 - The resource is owned by another master.
 * - 11 - The resource is owned by the requesting master.
 */
/*@{*/
#define BP_SPBA_PRRn_RMO     (30U)         /*!< Bit position for SPBA_PRRn_RMO. */
#define BM_SPBA_PRRn_RMO     (0xC0000000U) /*!< Bit mask for SPBA_PRRn_RMO. */
#define BS_SPBA_PRRn_RMO     (2U)          /*!< Bit field size in bits for SPBA_PRRn_RMO. */

#define BV_SPBA_PRRn_RMO_UNOWNED       (0U)          /*!< Bit field value for SPBA_PRRn_RMO: The resource is unowned. */
#define BV_SPBA_PRRn_RMO_ANOTHER_MASTER (0x2U)       /*!< Bit field value for SPBA_PRRn_RMO: The resource is owned by another master. */
#define BV_SPBA_PRRn_RMO_REQUESTING_MASTER (0x3U)    /*!< Bit field value for SPBA_PRRn_RMO: The resource is owned by the requesting master. */

/*! @brief Read current value of the SPBA_PRRn_RMO field. */
#define BR_SPBA_PRRn_RMO(x, n) (HW_SPBA_PRRn(x, n).B.RMO)
/*@}*/

/*******************************************************************************
 * hw_spba_t - module struct
 ******************************************************************************/
/*!
 * @brief All SPBA module registers.
 */
#pragma pack(1)
typedef struct _hw_spba
{
    __IO hw_spba_prrn_t PRRn[32];          /*!< [0x0] Peripheral Rights Register */
} hw_spba_t;
#pragma pack()

/*! @brief Macro to access all SPBA registers. */
/*! @param x SPBA module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_SPBA_REGS(SPBA_BASE)</code>. */
#define HW_SPBA_REGS(x) (*(hw_spba_t *)(x))

/*
 * iMX7D SRC
 *
 * System Reset Controller (SRC)
 *
 * Registers defined in this header file:
 * - HW_SRC_SCR - SRC Reset Control Register
 * - HW_SRC_A7RCR0 - A7 Reset Control Register
 * - HW_SRC_A7RCR1 - A7 Reset Control Register
 * - HW_SRC_M4RCR - M4 Reset Control Register
 * - HW_SRC_ERCR - EIM Reset Control Register
 * - HW_SRC_HSICPHY_RCR - HSIC PHY Reset Control Register
 * - HW_SRC_USBOPHY1_RCR - USB OTG PHY1 Reset Control Register
 * - HW_SRC_USBOPHY2_RCR - USB OTG PHY2 Reset Control Register
 * - HW_SRC_MIPIPHY_RCR - MIPI PHY Reset Control Register
 * - HW_SRC_PCIEPHY_RCR - PCIE PHY Reset Control Register
 * - HW_SRC_SBMR1 - SRC Boot Mode Register 1
 * - HW_SRC_SRSR - SRC Reset Status Register
 * - HW_SRC_SISR - SRC Interrupt Status Register
 * - HW_SRC_SIMR - SRC Interrupt Mask Register
 * - HW_SRC_SBMR2 - SRC Boot Mode Register 2
 * - HW_SRC_GPR1 - SRC General Purpose Register 1
 * - HW_SRC_GPR2 - SRC General Purpose Register 2
 * - HW_SRC_GPR3 - SRC General Purpose Register 3
 * - HW_SRC_GPR4 - SRC General Purpose Register 4
 * - HW_SRC_GPR5 - SRC General Purpose Register 5
 * - HW_SRC_GPR6 - SRC General Purpose Register 6
 * - HW_SRC_GPR7 - SRC General Purpose Register 7
 * - HW_SRC_GPR8 - SRC General Purpose Register 8
 * - HW_SRC_GPR9 - SRC General Purpose Register 9
 * - HW_SRC_GPR10 - SRC General Purpose Register 10
 * - HW_SRC_DDRC_RCR - SRC DDR Controller Reset Control Register
 *
 * - hw_src_t - Struct containing all module registers.
 */

#define HW_SRC_INSTANCE_COUNT (1U) /*!< Number of instances of the SRC module. */
#define HW_SRC (0U) /*!< Instance number for SRC. */
#define SRC_BASE              (0x30390000U) /*!< Base address for SRC. */
/*! Array initializer of SRC base addresses. */
#define SRC_BASE_ADDRS        { SRC_BASE }

/*******************************************************************************
 * HW_SRC_SCR - SRC Reset Control Register
 ******************************************************************************/

/*!
 * @brief HW_SRC_SCR - SRC Reset Control Register (RW)
 *
 * Reset value: 0x000000A0U
 *
 * The reset control register (SCR), contains bits that control operation of the
 * reset controller.
 */
typedef union _hw_src_scr
{
    uint32_t U;
    struct _hw_src_scr_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t MASK_TEMPSENSE_RESET : 4; /*!< [7:4]  */
        uint32_t RESERVED1 : 16;       /*!< [23:8]  */
        uint32_t DOMAIN0 : 1;          /*!< [24]  */
        uint32_t DOMAIN1 : 1;          /*!< [25]  */
        uint32_t DOMAIN2 : 1;          /*!< [26]  */
        uint32_t DOMAIN3 : 1;          /*!< [27]  */
        uint32_t RESERVED2 : 2;        /*!< [29:28]  */
        uint32_t LOCK : 1;             /*!< [30]  */
        uint32_t DOM_EN : 1;           /*!< [31]  */
    } B;
} hw_src_scr_t;

/*!
 * @name Constants and macros for entire SRC_SCR register
 */
/*@{*/
#define HW_SRC_SCR_ADDR(x)       ((uintptr_t)(x) + 0x0U)

#define HW_SRC_SCR(x)            (*(__IO hw_src_scr_t *) HW_SRC_SCR_ADDR(x))
#define HW_SRC_SCR_RD(x)         (HW_SRC_SCR(x).U)
#define HW_SRC_SCR_WR(x, v)      (HW_SRC_SCR(x).U = (v))
#define HW_SRC_SCR_SET(x, v)     (HW_SRC_SCR_WR(x, HW_SRC_SCR_RD(x) |  (v)))
#define HW_SRC_SCR_CLR(x, v)     (HW_SRC_SCR_WR(x, HW_SRC_SCR_RD(x) & ~(v)))
#define HW_SRC_SCR_TOG(x, v)     (HW_SRC_SCR_WR(x, HW_SRC_SCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_SCR bitfields
 */

/*!
 * @name Register SRC_SCR, field MASK_TEMPSENSE_RESET[7:4] (RW)
 *
 * Mask tempsense_reset source. If these 4 bits are coded from A to 5 then, the
 * tempsense_reset input to SRC will be masked and the tempsense_reset will not
 * create a reset to the chip.
 *
 * Values:
 * - 0101 - tempsense_reset is masked
 * - 1010 - tempsense_reset is not masked
 */
/*@{*/
#define BP_SRC_SCR_MASK_TEMPSENSE_RESET (4U) /*!< Bit position for SRC_SCR_MASK_TEMPSENSE_RESET. */
#define BM_SRC_SCR_MASK_TEMPSENSE_RESET (0x000000F0U) /*!< Bit mask for SRC_SCR_MASK_TEMPSENSE_RESET. */
#define BS_SRC_SCR_MASK_TEMPSENSE_RESET (4U) /*!< Bit field size in bits for SRC_SCR_MASK_TEMPSENSE_RESET. */

/*! @brief Read current value of the SRC_SCR_MASK_TEMPSENSE_RESET field. */
#define BR_SRC_SCR_MASK_TEMPSENSE_RESET(x) (HW_SRC_SCR(x).B.MASK_TEMPSENSE_RESET)

/*! @brief Format value for bitfield SRC_SCR_MASK_TEMPSENSE_RESET. */
#define BF_SRC_SCR_MASK_TEMPSENSE_RESET(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_MASK_TEMPSENSE_RESET) & BM_SRC_SCR_MASK_TEMPSENSE_RESET)

/*! @brief Set the MASK_TEMPSENSE_RESET field to a new value. */
#define BW_SRC_SCR_MASK_TEMPSENSE_RESET(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_MASK_TEMPSENSE_RESET) | BF_SRC_SCR_MASK_TEMPSENSE_RESET(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field DOMAIN0[24] (RW)
 *
 * Domain0 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain0. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain0. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_SCR_DOMAIN0   (24U)         /*!< Bit position for SRC_SCR_DOMAIN0. */
#define BM_SRC_SCR_DOMAIN0   (0x01000000U) /*!< Bit mask for SRC_SCR_DOMAIN0. */
#define BS_SRC_SCR_DOMAIN0   (1U)          /*!< Bit field size in bits for SRC_SCR_DOMAIN0. */

/*! @brief Read current value of the SRC_SCR_DOMAIN0 field. */
#define BR_SRC_SCR_DOMAIN0(x) (HW_SRC_SCR(x).B.DOMAIN0)

/*! @brief Format value for bitfield SRC_SCR_DOMAIN0. */
#define BF_SRC_SCR_DOMAIN0(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_DOMAIN0) & BM_SRC_SCR_DOMAIN0)

/*! @brief Set the DOMAIN0 field to a new value. */
#define BW_SRC_SCR_DOMAIN0(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_DOMAIN0) | BF_SRC_SCR_DOMAIN0(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field DOMAIN1[25] (RW)
 *
 * Domain1 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain1. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain1. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_SCR_DOMAIN1   (25U)         /*!< Bit position for SRC_SCR_DOMAIN1. */
#define BM_SRC_SCR_DOMAIN1   (0x02000000U) /*!< Bit mask for SRC_SCR_DOMAIN1. */
#define BS_SRC_SCR_DOMAIN1   (1U)          /*!< Bit field size in bits for SRC_SCR_DOMAIN1. */

/*! @brief Read current value of the SRC_SCR_DOMAIN1 field. */
#define BR_SRC_SCR_DOMAIN1(x) (HW_SRC_SCR(x).B.DOMAIN1)

/*! @brief Format value for bitfield SRC_SCR_DOMAIN1. */
#define BF_SRC_SCR_DOMAIN1(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_DOMAIN1) & BM_SRC_SCR_DOMAIN1)

/*! @brief Set the DOMAIN1 field to a new value. */
#define BW_SRC_SCR_DOMAIN1(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_DOMAIN1) | BF_SRC_SCR_DOMAIN1(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field DOMAIN2[26] (RW)
 *
 * Domain2 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain2. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain2. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_SCR_DOMAIN2   (26U)         /*!< Bit position for SRC_SCR_DOMAIN2. */
#define BM_SRC_SCR_DOMAIN2   (0x04000000U) /*!< Bit mask for SRC_SCR_DOMAIN2. */
#define BS_SRC_SCR_DOMAIN2   (1U)          /*!< Bit field size in bits for SRC_SCR_DOMAIN2. */

/*! @brief Read current value of the SRC_SCR_DOMAIN2 field. */
#define BR_SRC_SCR_DOMAIN2(x) (HW_SRC_SCR(x).B.DOMAIN2)

/*! @brief Format value for bitfield SRC_SCR_DOMAIN2. */
#define BF_SRC_SCR_DOMAIN2(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_DOMAIN2) & BM_SRC_SCR_DOMAIN2)

/*! @brief Set the DOMAIN2 field to a new value. */
#define BW_SRC_SCR_DOMAIN2(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_DOMAIN2) | BF_SRC_SCR_DOMAIN2(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field DOMAIN3[27] (RW)
 *
 * Domain3 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain3. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain3. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_SCR_DOMAIN3   (27U)         /*!< Bit position for SRC_SCR_DOMAIN3. */
#define BM_SRC_SCR_DOMAIN3   (0x08000000U) /*!< Bit mask for SRC_SCR_DOMAIN3. */
#define BS_SRC_SCR_DOMAIN3   (1U)          /*!< Bit field size in bits for SRC_SCR_DOMAIN3. */

/*! @brief Read current value of the SRC_SCR_DOMAIN3 field. */
#define BR_SRC_SCR_DOMAIN3(x) (HW_SRC_SCR(x).B.DOMAIN3)

/*! @brief Format value for bitfield SRC_SCR_DOMAIN3. */
#define BF_SRC_SCR_DOMAIN3(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_DOMAIN3) & BM_SRC_SCR_DOMAIN3)

/*! @brief Set the DOMAIN3 field to a new value. */
#define BW_SRC_SCR_DOMAIN3(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_DOMAIN3) | BF_SRC_SCR_DOMAIN3(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field LOCK[30] (RW)
 *
 * Domain control bits lock Lock bit is a write-once register, once it is set to
 * 1, it can't be write to 0
 *
 * Values:
 * - 0 - [31] and [27:24] bits can be modified
 * - 1 - [31] and [27:24] bits cannot be modified
 */
/*@{*/
#define BP_SRC_SCR_LOCK      (30U)         /*!< Bit position for SRC_SCR_LOCK. */
#define BM_SRC_SCR_LOCK      (0x40000000U) /*!< Bit mask for SRC_SCR_LOCK. */
#define BS_SRC_SCR_LOCK      (1U)          /*!< Bit field size in bits for SRC_SCR_LOCK. */

/*! @brief Read current value of the SRC_SCR_LOCK field. */
#define BR_SRC_SCR_LOCK(x)   (HW_SRC_SCR(x).B.LOCK)

/*! @brief Format value for bitfield SRC_SCR_LOCK. */
#define BF_SRC_SCR_LOCK(v)   ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_LOCK) & BM_SRC_SCR_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_SRC_SCR_LOCK(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_LOCK) | BF_SRC_SCR_LOCK(v)))
/*@}*/

/*!
 * @name Register SRC_SCR, field DOM_EN[31] (RW)
 *
 * Domain Control enable for this register. [31:30] and [27:24] areas are not
 * controlled by this bit. [31:30] and [27:24] area can be modified by any masters
 * from any domains when Lock bit is not set.
 *
 * Values:
 * - 0 - Disables domain control. All of this register's bits except [31:30] and
 *     [27:24] can be modified by any masters
 * - 1 - Enables domain control. All of this register's bits except [31:30] and
 *     [27:24] can only be modified by the masters from the domains specified in
 *     [27:24] area.
 */
/*@{*/
#define BP_SRC_SCR_DOM_EN    (31U)         /*!< Bit position for SRC_SCR_DOM_EN. */
#define BM_SRC_SCR_DOM_EN    (0x80000000U) /*!< Bit mask for SRC_SCR_DOM_EN. */
#define BS_SRC_SCR_DOM_EN    (1U)          /*!< Bit field size in bits for SRC_SCR_DOM_EN. */

/*! @brief Read current value of the SRC_SCR_DOM_EN field. */
#define BR_SRC_SCR_DOM_EN(x) (HW_SRC_SCR(x).B.DOM_EN)

/*! @brief Format value for bitfield SRC_SCR_DOM_EN. */
#define BF_SRC_SCR_DOM_EN(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SCR_DOM_EN) & BM_SRC_SCR_DOM_EN)

/*! @brief Set the DOM_EN field to a new value. */
#define BW_SRC_SCR_DOM_EN(x, v) (HW_SRC_SCR_WR(x, (HW_SRC_SCR_RD(x) & ~BM_SRC_SCR_DOM_EN) | BF_SRC_SCR_DOM_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_SRC_A7RCR0 - A7 Reset Control Register
 ******************************************************************************/

/*!
 * @brief HW_SRC_A7RCR0 - A7 Reset Control Register (RW)
 *
 * Reset value: 0x000A0000U
 *
 * The A7 Reset Control Register (A7RCR), contains bits that control the A7
 * reset generation.
 */
typedef union _hw_src_a7rcr0
{
    uint32_t U;
    struct _hw_src_a7rcr0_bitfields
    {
        uint32_t A7_CORE_POR_RESET0 : 1; /*!< [0]  */
        uint32_t A7_CORE_POR_RESET1 : 1; /*!< [1]  */
        uint32_t RESERVED0 : 2;        /*!< [3:2]  */
        uint32_t A7_CORE_RESET0 : 1;   /*!< [4]  */
        uint32_t A7_CORE_RESET1 : 1;   /*!< [5]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t A7_DBG_RESET0 : 1;    /*!< [8]  */
        uint32_t A7_DBG_RESET1 : 1;    /*!< [9]  */
        uint32_t RESERVED2 : 2;        /*!< [11:10]  */
        uint32_t A7_ETM_RESET0 : 1;    /*!< [12]  */
        uint32_t A7_ETM_RESET1 : 1;    /*!< [13]  */
        uint32_t RESERVED3 : 2;        /*!< [15:14]  */
        uint32_t MASK_WDOG1_RST : 4;   /*!< [19:16]  */
        uint32_t A7_SOC_DBG_RESET : 1; /*!< [20]  */
        uint32_t A7_L2RESET : 1;       /*!< [21]  */
        uint32_t RESERVED4 : 2;        /*!< [23:22]  */
        uint32_t DOMAIN0 : 1;          /*!< [24]  */
        uint32_t DOMAIN1 : 1;          /*!< [25]  */
        uint32_t DOMAIN2 : 1;          /*!< [26]  */
        uint32_t DOMAIN3 : 1;          /*!< [27]  */
        uint32_t RESERVED5 : 2;        /*!< [29:28]  */
        uint32_t LOCK : 1;             /*!< [30]  */
        uint32_t DOM_EN : 1;           /*!< [31]  */
    } B;
} hw_src_a7rcr0_t;

/*!
 * @name Constants and macros for entire SRC_A7RCR0 register
 */
/*@{*/
#define HW_SRC_A7RCR0_ADDR(x)    ((uintptr_t)(x) + 0x4U)

#define HW_SRC_A7RCR0(x)         (*(__IO hw_src_a7rcr0_t *) HW_SRC_A7RCR0_ADDR(x))
#define HW_SRC_A7RCR0_RD(x)      (HW_SRC_A7RCR0(x).U)
#define HW_SRC_A7RCR0_WR(x, v)   (HW_SRC_A7RCR0(x).U = (v))
#define HW_SRC_A7RCR0_SET(x, v)  (HW_SRC_A7RCR0_WR(x, HW_SRC_A7RCR0_RD(x) |  (v)))
#define HW_SRC_A7RCR0_CLR(x, v)  (HW_SRC_A7RCR0_WR(x, HW_SRC_A7RCR0_RD(x) & ~(v)))
#define HW_SRC_A7RCR0_TOG(x, v)  (HW_SRC_A7RCR0_WR(x, HW_SRC_A7RCR0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_A7RCR0 bitfields
 */

/*!
 * @name Register SRC_A7RCR0, field A7_CORE_POR_RESET0[0] (RW)
 *
 * POR reset for A7 core0 only. It initializes all the core0 processor logic,
 * including CPU Debug, and breakpoint and watchpoint logic in the core0 processor
 * power domains This is a self clearing bit. Once it is set to 1, the reset
 * process will begin, and once it finishes, this bit will be self cleared.
 *
 * Values:
 * - 0 - do not assert core0 reset
 * - 1 - assert core0 reset
 */
/*@{*/
#define BP_SRC_A7RCR0_A7_CORE_POR_RESET0 (0U) /*!< Bit position for SRC_A7RCR0_A7_CORE_POR_RESET0. */
#define BM_SRC_A7RCR0_A7_CORE_POR_RESET0 (0x00000001U) /*!< Bit mask for SRC_A7RCR0_A7_CORE_POR_RESET0. */
#define BS_SRC_A7RCR0_A7_CORE_POR_RESET0 (1U) /*!< Bit field size in bits for SRC_A7RCR0_A7_CORE_POR_RESET0. */

/*! @brief Read current value of the SRC_A7RCR0_A7_CORE_POR_RESET0 field. */
#define BR_SRC_A7RCR0_A7_CORE_POR_RESET0(x) (HW_SRC_A7RCR0(x).B.A7_CORE_POR_RESET0)

/*! @brief Format value for bitfield SRC_A7RCR0_A7_CORE_POR_RESET0. */
#define BF_SRC_A7RCR0_A7_CORE_POR_RESET0(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR0_A7_CORE_POR_RESET0) & BM_SRC_A7RCR0_A7_CORE_POR_RESET0)

/*! @brief Set the A7_CORE_POR_RESET0 field to a new value. */
#define BW_SRC_A7RCR0_A7_CORE_POR_RESET0(x, v) (HW_SRC_A7RCR0_WR(x, (HW_SRC_A7RCR0_RD(x) & ~BM_SRC_A7RCR0_A7_CORE_POR_RESET0) | BF_SRC_A7RCR0_A7_CORE_POR_RESET0(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR0, field A7_CORE_POR_RESET1[1] (RW)
 *
 * POR reset for A7 core1 only. It initializes all the core1 processor logic,
 * including CPU Debug, and breakpoint and watchpoint logic in the core1 processor
 * power domains This is a self clearing bit. Once it is set to 1, the reset
 * process will begin, and once it finishes, this bit will be self cleared.
 *
 * Values:
 * - 0 - do not assert core1 reset
 * - 1 - assert core1 reset
 */
/*@{*/
#define BP_SRC_A7RCR0_A7_CORE_POR_RESET1 (1U) /*!< Bit position for SRC_A7RCR0_A7_CORE_POR_RESET1. */
#define BM_SRC_A7RCR0_A7_CORE_POR_RESET1 (0x00000002U) /*!< Bit mask for SRC_A7RCR0_A7_CORE_POR_RESET1. */
#define BS_SRC_A7RCR0_A7_CORE_POR_RESET1 (1U) /*!< Bit field size in bits for SRC_A7RCR0_A7_CORE_POR_RESET1. */

/*! @brief Read current value of the SRC_A7RCR0_A7_CORE_POR_RESET1 field. */
#define BR_SRC_A7RCR0_A7_CORE_POR_RESET1(x) (HW_SRC_A7RCR0(x).B.A7_CORE_POR_RESET1)

/*! @brief Format value for bitfield SRC_A7RCR0_A7_CORE_POR_RESET1. */
#define BF_SRC_A7RCR0_A7_CORE_POR_RESET1(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR0_A7_CORE_POR_RESET1) & BM_SRC_A7RCR0_A7_CORE_POR_RESET1)

/*! @brief Set the A7_CORE_POR_RESET1 field to a new value. */
#define BW_SRC_A7RCR0_A7_CORE_POR_RESET1(x, v) (HW_SRC_A7RCR0_WR(x, (HW_SRC_A7RCR0_RD(x) & ~BM_SRC_A7RCR0_A7_CORE_POR_RESET1) | BF_SRC_A7RCR0_A7_CORE_POR_RESET1(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR0, field A7_CORE_RESET0[4] (RW)
 *
 * Software reset for core0 only. It initializes the processor logic in the
 * core0 processor power domains, not including the debug, breakpoint and watchpoint
 * logic. This is a self clearing bit. Once it is set to 1, the reset process
 * will begin, and once it finishes, this bit will be self cleared.
 *
 * Values:
 * - 0 - do not assert core0 reset
 * - 1 - assert core0 reset
 */
/*@{*/
#define BP_SRC_A7RCR0_A7_CORE_RESET0 (4U)  /*!< Bit position for SRC_A7RCR0_A7_CORE_RESET0. */
#define BM_SRC_A7RCR0_A7_CORE_RESET0 (0x00000010U) /*!< Bit mask for SRC_A7RCR0_A7_CORE_RESET0. */
#define BS_SRC_A7RCR0_A7_CORE_RESET0 (1U)  /*!< Bit field size in bits for SRC_A7RCR0_A7_CORE_RESET0. */

/*! @brief Read current value of the SRC_A7RCR0_A7_CORE_RESET0 field. */
#define BR_SRC_A7RCR0_A7_CORE_RESET0(x) (HW_SRC_A7RCR0(x).B.A7_CORE_RESET0)

/*! @brief Format value for bitfield SRC_A7RCR0_A7_CORE_RESET0. */
#define BF_SRC_A7RCR0_A7_CORE_RESET0(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR0_A7_CORE_RESET0) & BM_SRC_A7RCR0_A7_CORE_RESET0)

/*! @brief Set the A7_CORE_RESET0 field to a new value. */
#define BW_SRC_A7RCR0_A7_CORE_RESET0(x, v) (HW_SRC_A7RCR0_WR(x, (HW_SRC_A7RCR0_RD(x) & ~BM_SRC_A7RCR0_A7_CORE_RESET0) | BF_SRC_A7RCR0_A7_CORE_RESET0(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR0, field A7_CORE_RESET1[5] (RW)
 *
 * Software reset for core1 only. It initializes the processor logic in the
 * core1 processor power domains, not including the debug, breakpoint and watchpoint
 * logic. This is a self clearing bit. Once it is set to 1, the reset process
 * will begin, and once it finishes, this bit will be self cleared.
 *
 * Values:
 * - 0 - do not assert core1 reset
 * - 1 - assert core1 reset
 */
/*@{*/
#define BP_SRC_A7RCR0_A7_CORE_RESET1 (5U)  /*!< Bit position for SRC_A7RCR0_A7_CORE_RESET1. */
#define BM_SRC_A7RCR0_A7_CORE_RESET1 (0x00000020U) /*!< Bit mask for SRC_A7RCR0_A7_CORE_RESET1. */
#define BS_SRC_A7RCR0_A7_CORE_RESET1 (1U)  /*!< Bit field size in bits for SRC_A7RCR0_A7_CORE_RESET1. */

/*! @brief Read current value of the SRC_A7RCR0_A7_CORE_RESET1 field. */
#define BR_SRC_A7RCR0_A7_CORE_RESET1(x) (HW_SRC_A7RCR0(x).B.A7_CORE_RESET1)

/*! @brief Format value for bitfield SRC_A7RCR0_A7_CORE_RESET1. */
#define BF_SRC_A7RCR0_A7_CORE_RESET1(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR0_A7_CORE_RESET1) & BM_SRC_A7RCR0_A7_CORE_RESET1)

/*! @brief Set the A7_CORE_RESET1 field to a new value. */
#define BW_SRC_A7RCR0_A7_CORE_RESET1(x, v) (HW_SRC_A7RCR0_WR(x, (HW_SRC_A7RCR0_RD(x) & ~BM_SRC_A7RCR0_A7_CORE_RESET1) | BF_SRC_A7RCR0_A7_CORE_RESET1(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR0, field A7_DBG_RESET0[8] (RW)
 *
 * Software reset for core0 debug only. It initialize the debug, and breakpoint
 * and watchpoint logic in the core1 processor power domain. It also reset the
 * debug logic for core1 processor, which is in the debug power domain. This is a
 * self clearing bit. Once it is set to 1, the reset process will begin, and once
 * it finishes, this bit will be self cleared.
 *
 * Values:
 * - 0 - do not assert core0 debug reset
 * - 1 - assert core0 debug reset
 */
/*@{*/
#define BP_SRC_A7RCR0_A7_DBG_RESET0 (8U)   /*!< Bit position for SRC_A7RCR0_A7_DBG_RESET0. */
#define BM_SRC_A7RCR0_A7_DBG_RESET0 (0x00000100U) /*!< Bit mask for SRC_A7RCR0_A7_DBG_RESET0. */
#define BS_SRC_A7RCR0_A7_DBG_RESET0 (1U)   /*!< Bit field size in bits for SRC_A7RCR0_A7_DBG_RESET0. */

/*! @brief Read current value of the SRC_A7RCR0_A7_DBG_RESET0 field. */
#define BR_SRC_A7RCR0_A7_DBG_RESET0(x) (HW_SRC_A7RCR0(x).B.A7_DBG_RESET0)

/*! @brief Format value for bitfield SRC_A7RCR0_A7_DBG_RESET0. */
#define BF_SRC_A7RCR0_A7_DBG_RESET0(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR0_A7_DBG_RESET0) & BM_SRC_A7RCR0_A7_DBG_RESET0)

/*! @brief Set the A7_DBG_RESET0 field to a new value. */
#define BW_SRC_A7RCR0_A7_DBG_RESET0(x, v) (HW_SRC_A7RCR0_WR(x, (HW_SRC_A7RCR0_RD(x) & ~BM_SRC_A7RCR0_A7_DBG_RESET0) | BF_SRC_A7RCR0_A7_DBG_RESET0(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR0, field A7_DBG_RESET1[9] (RW)
 *
 * Software reset for core1 debug only. It initialize the debug, and breakpoint
 * and watchpoint logic in the core1 processor power domain. It also reset the
 * debug logic for core1 processor, which is in the debug power domain. This is a
 * self clearing bit. Once it is set to 1, the reset process will begin, and once
 * it finishes, this bit will be self cleared.
 *
 * Values:
 * - 0 - do not assert core1 debug reset
 * - 1 - assert core1 debug reset
 */
/*@{*/
#define BP_SRC_A7RCR0_A7_DBG_RESET1 (9U)   /*!< Bit position for SRC_A7RCR0_A7_DBG_RESET1. */
#define BM_SRC_A7RCR0_A7_DBG_RESET1 (0x00000200U) /*!< Bit mask for SRC_A7RCR0_A7_DBG_RESET1. */
#define BS_SRC_A7RCR0_A7_DBG_RESET1 (1U)   /*!< Bit field size in bits for SRC_A7RCR0_A7_DBG_RESET1. */

/*! @brief Read current value of the SRC_A7RCR0_A7_DBG_RESET1 field. */
#define BR_SRC_A7RCR0_A7_DBG_RESET1(x) (HW_SRC_A7RCR0(x).B.A7_DBG_RESET1)

/*! @brief Format value for bitfield SRC_A7RCR0_A7_DBG_RESET1. */
#define BF_SRC_A7RCR0_A7_DBG_RESET1(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR0_A7_DBG_RESET1) & BM_SRC_A7RCR0_A7_DBG_RESET1)

/*! @brief Set the A7_DBG_RESET1 field to a new value. */
#define BW_SRC_A7RCR0_A7_DBG_RESET1(x, v) (HW_SRC_A7RCR0_WR(x, (HW_SRC_A7RCR0_RD(x) & ~BM_SRC_A7RCR0_A7_DBG_RESET1) | BF_SRC_A7RCR0_A7_DBG_RESET1(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR0, field A7_ETM_RESET0[12] (RW)
 *
 * Software reset for core0 ETM only. This is a self clearing bit. Once it is
 * set to 1, the reset process will begin, and once it finishes, this bit will be
 * self cleared.
 *
 * Values:
 * - 0 - do not assert core0 ETM reset
 * - 1 - assert core0 ETM reset
 */
/*@{*/
#define BP_SRC_A7RCR0_A7_ETM_RESET0 (12U)  /*!< Bit position for SRC_A7RCR0_A7_ETM_RESET0. */
#define BM_SRC_A7RCR0_A7_ETM_RESET0 (0x00001000U) /*!< Bit mask for SRC_A7RCR0_A7_ETM_RESET0. */
#define BS_SRC_A7RCR0_A7_ETM_RESET0 (1U)   /*!< Bit field size in bits for SRC_A7RCR0_A7_ETM_RESET0. */

/*! @brief Read current value of the SRC_A7RCR0_A7_ETM_RESET0 field. */
#define BR_SRC_A7RCR0_A7_ETM_RESET0(x) (HW_SRC_A7RCR0(x).B.A7_ETM_RESET0)

/*! @brief Format value for bitfield SRC_A7RCR0_A7_ETM_RESET0. */
#define BF_SRC_A7RCR0_A7_ETM_RESET0(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR0_A7_ETM_RESET0) & BM_SRC_A7RCR0_A7_ETM_RESET0)

/*! @brief Set the A7_ETM_RESET0 field to a new value. */
#define BW_SRC_A7RCR0_A7_ETM_RESET0(x, v) (HW_SRC_A7RCR0_WR(x, (HW_SRC_A7RCR0_RD(x) & ~BM_SRC_A7RCR0_A7_ETM_RESET0) | BF_SRC_A7RCR0_A7_ETM_RESET0(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR0, field A7_ETM_RESET1[13] (RW)
 *
 * Software reset for core1 ETM only. This is a self clearing bit. Once it is
 * set to 1, the reset process will begin, and once it finishes, this bit will be
 * self cleared.
 *
 * Values:
 * - 0 - do not assert core1 ETM reset
 * - 1 - assert core1 ETM reset
 */
/*@{*/
#define BP_SRC_A7RCR0_A7_ETM_RESET1 (13U)  /*!< Bit position for SRC_A7RCR0_A7_ETM_RESET1. */
#define BM_SRC_A7RCR0_A7_ETM_RESET1 (0x00002000U) /*!< Bit mask for SRC_A7RCR0_A7_ETM_RESET1. */
#define BS_SRC_A7RCR0_A7_ETM_RESET1 (1U)   /*!< Bit field size in bits for SRC_A7RCR0_A7_ETM_RESET1. */

/*! @brief Read current value of the SRC_A7RCR0_A7_ETM_RESET1 field. */
#define BR_SRC_A7RCR0_A7_ETM_RESET1(x) (HW_SRC_A7RCR0(x).B.A7_ETM_RESET1)

/*! @brief Format value for bitfield SRC_A7RCR0_A7_ETM_RESET1. */
#define BF_SRC_A7RCR0_A7_ETM_RESET1(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR0_A7_ETM_RESET1) & BM_SRC_A7RCR0_A7_ETM_RESET1)

/*! @brief Set the A7_ETM_RESET1 field to a new value. */
#define BW_SRC_A7RCR0_A7_ETM_RESET1(x, v) (HW_SRC_A7RCR0_WR(x, (HW_SRC_A7RCR0_RD(x) & ~BM_SRC_A7RCR0_A7_ETM_RESET1) | BF_SRC_A7RCR0_A7_ETM_RESET1(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR0, field MASK_WDOG1_RST[19:16] (RW)
 *
 * Mask wdog1_rst_b source. If these 4 bits are coded from A to 5 then, the
 * wdog1_rst_b input to SRC will be masked and the wdog1_rst_b will not create a
 * reset to the chip. During the time the WDOG event is masked using SRC logic, it is
 * likely that the WDOG Reset Status Register (WRSR) bit 1 (which indicates a
 * WDOG timeout event) will get asserted. software / OS developer must prepare for
 * this case. Re-enabling the WDOG is possible, by un-masking it in SRC, though
 * it must be preceded by servicing the WDOG. However, for the case that the event
 * has been asserted, the status bit (WRSR bit-1) will remain asserted,
 * regardless of servicing the WDOG module. (Hardware reset is the only way to cause the
 * de-assertion of that bit). Any other code will be coded to 1010 i.e.
 * wdog1_rst_b is not masked
 *
 * Values:
 * - 0101 - wdog1_rst_b is masked
 * - 1010 - wdog1_rst_b is not masked
 */
/*@{*/
#define BP_SRC_A7RCR0_MASK_WDOG1_RST (16U) /*!< Bit position for SRC_A7RCR0_MASK_WDOG1_RST. */
#define BM_SRC_A7RCR0_MASK_WDOG1_RST (0x000F0000U) /*!< Bit mask for SRC_A7RCR0_MASK_WDOG1_RST. */
#define BS_SRC_A7RCR0_MASK_WDOG1_RST (4U)  /*!< Bit field size in bits for SRC_A7RCR0_MASK_WDOG1_RST. */

/*! @brief Read current value of the SRC_A7RCR0_MASK_WDOG1_RST field. */
#define BR_SRC_A7RCR0_MASK_WDOG1_RST(x) (HW_SRC_A7RCR0(x).B.MASK_WDOG1_RST)

/*! @brief Format value for bitfield SRC_A7RCR0_MASK_WDOG1_RST. */
#define BF_SRC_A7RCR0_MASK_WDOG1_RST(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR0_MASK_WDOG1_RST) & BM_SRC_A7RCR0_MASK_WDOG1_RST)

/*! @brief Set the MASK_WDOG1_RST field to a new value. */
#define BW_SRC_A7RCR0_MASK_WDOG1_RST(x, v) (HW_SRC_A7RCR0_WR(x, (HW_SRC_A7RCR0_RD(x) & ~BM_SRC_A7RCR0_MASK_WDOG1_RST) | BF_SRC_A7RCR0_MASK_WDOG1_RST(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR0, field A7_SOC_DBG_RESET[20] (RW)
 *
 * Software reset for system level debug reset. It initializes the shared Debug
 * APB, the CTI, and the CTM. It also causes: A7_dbgreset[1:0] and
 * A7_etmreset[1:0] to be asserted debug logic in the processor power domain and in the debug
 * power domain to be reset This is a self clearing bit. Once it is set to 1, the
 * reset process will begin, and once it finishes, this bit will be self cleared.
 *
 * Values:
 * - 0 - do not assert system level debug reset
 * - 1 - assert system level debug reset
 */
/*@{*/
#define BP_SRC_A7RCR0_A7_SOC_DBG_RESET (20U) /*!< Bit position for SRC_A7RCR0_A7_SOC_DBG_RESET. */
#define BM_SRC_A7RCR0_A7_SOC_DBG_RESET (0x00100000U) /*!< Bit mask for SRC_A7RCR0_A7_SOC_DBG_RESET. */
#define BS_SRC_A7RCR0_A7_SOC_DBG_RESET (1U) /*!< Bit field size in bits for SRC_A7RCR0_A7_SOC_DBG_RESET. */

/*! @brief Read current value of the SRC_A7RCR0_A7_SOC_DBG_RESET field. */
#define BR_SRC_A7RCR0_A7_SOC_DBG_RESET(x) (HW_SRC_A7RCR0(x).B.A7_SOC_DBG_RESET)

/*! @brief Format value for bitfield SRC_A7RCR0_A7_SOC_DBG_RESET. */
#define BF_SRC_A7RCR0_A7_SOC_DBG_RESET(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR0_A7_SOC_DBG_RESET) & BM_SRC_A7RCR0_A7_SOC_DBG_RESET)

/*! @brief Set the A7_SOC_DBG_RESET field to a new value. */
#define BW_SRC_A7RCR0_A7_SOC_DBG_RESET(x, v) (HW_SRC_A7RCR0_WR(x, (HW_SRC_A7RCR0_RD(x) & ~BM_SRC_A7RCR0_A7_SOC_DBG_RESET) | BF_SRC_A7RCR0_A7_SOC_DBG_RESET(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR0, field A7_L2RESET[21] (RW)
 *
 * Software reset for A7 Snoop Control Unit (SCU). This is a self clearing bit.
 * Once it is set to 1, the reset process will begin, and once it finishes, this
 * bit will be self cleared.
 *
 * Values:
 * - 0 - do not assert SCU reset
 * - 1 - assert SCU reset
 */
/*@{*/
#define BP_SRC_A7RCR0_A7_L2RESET (21U)     /*!< Bit position for SRC_A7RCR0_A7_L2RESET. */
#define BM_SRC_A7RCR0_A7_L2RESET (0x00200000U) /*!< Bit mask for SRC_A7RCR0_A7_L2RESET. */
#define BS_SRC_A7RCR0_A7_L2RESET (1U)      /*!< Bit field size in bits for SRC_A7RCR0_A7_L2RESET. */

/*! @brief Read current value of the SRC_A7RCR0_A7_L2RESET field. */
#define BR_SRC_A7RCR0_A7_L2RESET(x) (HW_SRC_A7RCR0(x).B.A7_L2RESET)

/*! @brief Format value for bitfield SRC_A7RCR0_A7_L2RESET. */
#define BF_SRC_A7RCR0_A7_L2RESET(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR0_A7_L2RESET) & BM_SRC_A7RCR0_A7_L2RESET)

/*! @brief Set the A7_L2RESET field to a new value. */
#define BW_SRC_A7RCR0_A7_L2RESET(x, v) (HW_SRC_A7RCR0_WR(x, (HW_SRC_A7RCR0_RD(x) & ~BM_SRC_A7RCR0_A7_L2RESET) | BF_SRC_A7RCR0_A7_L2RESET(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR0, field DOMAIN0[24] (RW)
 *
 * Domain0 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain0. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain0. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_A7RCR0_DOMAIN0 (24U)        /*!< Bit position for SRC_A7RCR0_DOMAIN0. */
#define BM_SRC_A7RCR0_DOMAIN0 (0x01000000U) /*!< Bit mask for SRC_A7RCR0_DOMAIN0. */
#define BS_SRC_A7RCR0_DOMAIN0 (1U)         /*!< Bit field size in bits for SRC_A7RCR0_DOMAIN0. */

/*! @brief Read current value of the SRC_A7RCR0_DOMAIN0 field. */
#define BR_SRC_A7RCR0_DOMAIN0(x) (HW_SRC_A7RCR0(x).B.DOMAIN0)

/*! @brief Format value for bitfield SRC_A7RCR0_DOMAIN0. */
#define BF_SRC_A7RCR0_DOMAIN0(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR0_DOMAIN0) & BM_SRC_A7RCR0_DOMAIN0)

/*! @brief Set the DOMAIN0 field to a new value. */
#define BW_SRC_A7RCR0_DOMAIN0(x, v) (HW_SRC_A7RCR0_WR(x, (HW_SRC_A7RCR0_RD(x) & ~BM_SRC_A7RCR0_DOMAIN0) | BF_SRC_A7RCR0_DOMAIN0(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR0, field DOMAIN1[25] (RW)
 *
 * Domain1 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain1. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain1. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_A7RCR0_DOMAIN1 (25U)        /*!< Bit position for SRC_A7RCR0_DOMAIN1. */
#define BM_SRC_A7RCR0_DOMAIN1 (0x02000000U) /*!< Bit mask for SRC_A7RCR0_DOMAIN1. */
#define BS_SRC_A7RCR0_DOMAIN1 (1U)         /*!< Bit field size in bits for SRC_A7RCR0_DOMAIN1. */

/*! @brief Read current value of the SRC_A7RCR0_DOMAIN1 field. */
#define BR_SRC_A7RCR0_DOMAIN1(x) (HW_SRC_A7RCR0(x).B.DOMAIN1)

/*! @brief Format value for bitfield SRC_A7RCR0_DOMAIN1. */
#define BF_SRC_A7RCR0_DOMAIN1(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR0_DOMAIN1) & BM_SRC_A7RCR0_DOMAIN1)

/*! @brief Set the DOMAIN1 field to a new value. */
#define BW_SRC_A7RCR0_DOMAIN1(x, v) (HW_SRC_A7RCR0_WR(x, (HW_SRC_A7RCR0_RD(x) & ~BM_SRC_A7RCR0_DOMAIN1) | BF_SRC_A7RCR0_DOMAIN1(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR0, field DOMAIN2[26] (RW)
 *
 * Domain2 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain2. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain2. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_A7RCR0_DOMAIN2 (26U)        /*!< Bit position for SRC_A7RCR0_DOMAIN2. */
#define BM_SRC_A7RCR0_DOMAIN2 (0x04000000U) /*!< Bit mask for SRC_A7RCR0_DOMAIN2. */
#define BS_SRC_A7RCR0_DOMAIN2 (1U)         /*!< Bit field size in bits for SRC_A7RCR0_DOMAIN2. */

/*! @brief Read current value of the SRC_A7RCR0_DOMAIN2 field. */
#define BR_SRC_A7RCR0_DOMAIN2(x) (HW_SRC_A7RCR0(x).B.DOMAIN2)

/*! @brief Format value for bitfield SRC_A7RCR0_DOMAIN2. */
#define BF_SRC_A7RCR0_DOMAIN2(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR0_DOMAIN2) & BM_SRC_A7RCR0_DOMAIN2)

/*! @brief Set the DOMAIN2 field to a new value. */
#define BW_SRC_A7RCR0_DOMAIN2(x, v) (HW_SRC_A7RCR0_WR(x, (HW_SRC_A7RCR0_RD(x) & ~BM_SRC_A7RCR0_DOMAIN2) | BF_SRC_A7RCR0_DOMAIN2(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR0, field DOMAIN3[27] (RW)
 *
 * Domain3 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain3. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain3. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_A7RCR0_DOMAIN3 (27U)        /*!< Bit position for SRC_A7RCR0_DOMAIN3. */
#define BM_SRC_A7RCR0_DOMAIN3 (0x08000000U) /*!< Bit mask for SRC_A7RCR0_DOMAIN3. */
#define BS_SRC_A7RCR0_DOMAIN3 (1U)         /*!< Bit field size in bits for SRC_A7RCR0_DOMAIN3. */

/*! @brief Read current value of the SRC_A7RCR0_DOMAIN3 field. */
#define BR_SRC_A7RCR0_DOMAIN3(x) (HW_SRC_A7RCR0(x).B.DOMAIN3)

/*! @brief Format value for bitfield SRC_A7RCR0_DOMAIN3. */
#define BF_SRC_A7RCR0_DOMAIN3(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR0_DOMAIN3) & BM_SRC_A7RCR0_DOMAIN3)

/*! @brief Set the DOMAIN3 field to a new value. */
#define BW_SRC_A7RCR0_DOMAIN3(x, v) (HW_SRC_A7RCR0_WR(x, (HW_SRC_A7RCR0_RD(x) & ~BM_SRC_A7RCR0_DOMAIN3) | BF_SRC_A7RCR0_DOMAIN3(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR0, field LOCK[30] (RW)
 *
 * Domain control bits lock Lock bit is a write-once register, once it is set to
 * 1, it can't be write to 0
 *
 * Values:
 * - 0 - [31] and [27:24] bits can be modified
 * - 1 - [31] and [27:24] bits cannot be modified
 */
/*@{*/
#define BP_SRC_A7RCR0_LOCK   (30U)         /*!< Bit position for SRC_A7RCR0_LOCK. */
#define BM_SRC_A7RCR0_LOCK   (0x40000000U) /*!< Bit mask for SRC_A7RCR0_LOCK. */
#define BS_SRC_A7RCR0_LOCK   (1U)          /*!< Bit field size in bits for SRC_A7RCR0_LOCK. */

/*! @brief Read current value of the SRC_A7RCR0_LOCK field. */
#define BR_SRC_A7RCR0_LOCK(x) (HW_SRC_A7RCR0(x).B.LOCK)

/*! @brief Format value for bitfield SRC_A7RCR0_LOCK. */
#define BF_SRC_A7RCR0_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR0_LOCK) & BM_SRC_A7RCR0_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_SRC_A7RCR0_LOCK(x, v) (HW_SRC_A7RCR0_WR(x, (HW_SRC_A7RCR0_RD(x) & ~BM_SRC_A7RCR0_LOCK) | BF_SRC_A7RCR0_LOCK(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR0, field DOM_EN[31] (RW)
 *
 * Domain Control enable for this register. [31:30] and [27:24] areas are not
 * controlled by this bit. [31:30] and [27:24] area can be modified by any masters
 * from any domains when Lock bit is not set.
 *
 * Values:
 * - 0 - Disables domain control. All of this register's bits except [31:30] and
 *     [27:24] can be modified by any masters
 * - 1 - Enables domain control. All of this register's bits except [31:30] and
 *     [27:24] can only be modified by the masters from the domains specified in
 *     [27:24] area.
 */
/*@{*/
#define BP_SRC_A7RCR0_DOM_EN (31U)         /*!< Bit position for SRC_A7RCR0_DOM_EN. */
#define BM_SRC_A7RCR0_DOM_EN (0x80000000U) /*!< Bit mask for SRC_A7RCR0_DOM_EN. */
#define BS_SRC_A7RCR0_DOM_EN (1U)          /*!< Bit field size in bits for SRC_A7RCR0_DOM_EN. */

/*! @brief Read current value of the SRC_A7RCR0_DOM_EN field. */
#define BR_SRC_A7RCR0_DOM_EN(x) (HW_SRC_A7RCR0(x).B.DOM_EN)

/*! @brief Format value for bitfield SRC_A7RCR0_DOM_EN. */
#define BF_SRC_A7RCR0_DOM_EN(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR0_DOM_EN) & BM_SRC_A7RCR0_DOM_EN)

/*! @brief Set the DOM_EN field to a new value. */
#define BW_SRC_A7RCR0_DOM_EN(x, v) (HW_SRC_A7RCR0_WR(x, (HW_SRC_A7RCR0_RD(x) & ~BM_SRC_A7RCR0_DOM_EN) | BF_SRC_A7RCR0_DOM_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_SRC_A7RCR1 - A7 Reset Control Register
 ******************************************************************************/

/*!
 * @brief HW_SRC_A7RCR1 - A7 Reset Control Register (RW)
 *
 * Reset value: 0x00000001U
 *
 * The A7 Reset Control Register (A7RCR), contains bits that control the A7
 * reset generation.
 */
typedef union _hw_src_a7rcr1
{
    uint32_t U;
    struct _hw_src_a7rcr1_bitfields
    {
        uint32_t RESERVED0 : 1;        /*!< [0]  */
        uint32_t A7_CORE1_ENABLE : 1;  /*!< [1]  */
        uint32_t RESERVED1 : 22;       /*!< [23:2]  */
        uint32_t DOMAIN0 : 1;          /*!< [24]  */
        uint32_t DOMAIN1 : 1;          /*!< [25]  */
        uint32_t DOMAIN2 : 1;          /*!< [26]  */
        uint32_t DOMAIN3 : 1;          /*!< [27]  */
        uint32_t RESERVED2 : 2;        /*!< [29:28]  */
        uint32_t LOCK : 1;             /*!< [30]  */
        uint32_t DOM_EN : 1;           /*!< [31]  */
    } B;
} hw_src_a7rcr1_t;

/*!
 * @name Constants and macros for entire SRC_A7RCR1 register
 */
/*@{*/
#define HW_SRC_A7RCR1_ADDR(x)    ((uintptr_t)(x) + 0x8U)

#define HW_SRC_A7RCR1(x)         (*(__IO hw_src_a7rcr1_t *) HW_SRC_A7RCR1_ADDR(x))
#define HW_SRC_A7RCR1_RD(x)      (HW_SRC_A7RCR1(x).U)
#define HW_SRC_A7RCR1_WR(x, v)   (HW_SRC_A7RCR1(x).U = (v))
#define HW_SRC_A7RCR1_SET(x, v)  (HW_SRC_A7RCR1_WR(x, HW_SRC_A7RCR1_RD(x) |  (v)))
#define HW_SRC_A7RCR1_CLR(x, v)  (HW_SRC_A7RCR1_WR(x, HW_SRC_A7RCR1_RD(x) & ~(v)))
#define HW_SRC_A7RCR1_TOG(x, v)  (HW_SRC_A7RCR1_WR(x, HW_SRC_A7RCR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_A7RCR1 bitfields
 */

/*!
 * @name Register SRC_A7RCR1, field A7_CORE1_ENABLE[1] (RW)
 *
 * core 1 enable
 *
 * Values:
 * - 0 - core1 is disabled
 * - 1 - core1 is enabled
 */
/*@{*/
#define BP_SRC_A7RCR1_A7_CORE1_ENABLE (1U) /*!< Bit position for SRC_A7RCR1_A7_CORE1_ENABLE. */
#define BM_SRC_A7RCR1_A7_CORE1_ENABLE (0x00000002U) /*!< Bit mask for SRC_A7RCR1_A7_CORE1_ENABLE. */
#define BS_SRC_A7RCR1_A7_CORE1_ENABLE (1U) /*!< Bit field size in bits for SRC_A7RCR1_A7_CORE1_ENABLE. */

/*! @brief Read current value of the SRC_A7RCR1_A7_CORE1_ENABLE field. */
#define BR_SRC_A7RCR1_A7_CORE1_ENABLE(x) (HW_SRC_A7RCR1(x).B.A7_CORE1_ENABLE)

/*! @brief Format value for bitfield SRC_A7RCR1_A7_CORE1_ENABLE. */
#define BF_SRC_A7RCR1_A7_CORE1_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR1_A7_CORE1_ENABLE) & BM_SRC_A7RCR1_A7_CORE1_ENABLE)

/*! @brief Set the A7_CORE1_ENABLE field to a new value. */
#define BW_SRC_A7RCR1_A7_CORE1_ENABLE(x, v) (HW_SRC_A7RCR1_WR(x, (HW_SRC_A7RCR1_RD(x) & ~BM_SRC_A7RCR1_A7_CORE1_ENABLE) | BF_SRC_A7RCR1_A7_CORE1_ENABLE(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR1, field DOMAIN0[24] (RW)
 *
 * Domain0 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain0. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain0. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_A7RCR1_DOMAIN0 (24U)        /*!< Bit position for SRC_A7RCR1_DOMAIN0. */
#define BM_SRC_A7RCR1_DOMAIN0 (0x01000000U) /*!< Bit mask for SRC_A7RCR1_DOMAIN0. */
#define BS_SRC_A7RCR1_DOMAIN0 (1U)         /*!< Bit field size in bits for SRC_A7RCR1_DOMAIN0. */

/*! @brief Read current value of the SRC_A7RCR1_DOMAIN0 field. */
#define BR_SRC_A7RCR1_DOMAIN0(x) (HW_SRC_A7RCR1(x).B.DOMAIN0)

/*! @brief Format value for bitfield SRC_A7RCR1_DOMAIN0. */
#define BF_SRC_A7RCR1_DOMAIN0(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR1_DOMAIN0) & BM_SRC_A7RCR1_DOMAIN0)

/*! @brief Set the DOMAIN0 field to a new value. */
#define BW_SRC_A7RCR1_DOMAIN0(x, v) (HW_SRC_A7RCR1_WR(x, (HW_SRC_A7RCR1_RD(x) & ~BM_SRC_A7RCR1_DOMAIN0) | BF_SRC_A7RCR1_DOMAIN0(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR1, field DOMAIN1[25] (RW)
 *
 * Domain1 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain1. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain1. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_A7RCR1_DOMAIN1 (25U)        /*!< Bit position for SRC_A7RCR1_DOMAIN1. */
#define BM_SRC_A7RCR1_DOMAIN1 (0x02000000U) /*!< Bit mask for SRC_A7RCR1_DOMAIN1. */
#define BS_SRC_A7RCR1_DOMAIN1 (1U)         /*!< Bit field size in bits for SRC_A7RCR1_DOMAIN1. */

/*! @brief Read current value of the SRC_A7RCR1_DOMAIN1 field. */
#define BR_SRC_A7RCR1_DOMAIN1(x) (HW_SRC_A7RCR1(x).B.DOMAIN1)

/*! @brief Format value for bitfield SRC_A7RCR1_DOMAIN1. */
#define BF_SRC_A7RCR1_DOMAIN1(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR1_DOMAIN1) & BM_SRC_A7RCR1_DOMAIN1)

/*! @brief Set the DOMAIN1 field to a new value. */
#define BW_SRC_A7RCR1_DOMAIN1(x, v) (HW_SRC_A7RCR1_WR(x, (HW_SRC_A7RCR1_RD(x) & ~BM_SRC_A7RCR1_DOMAIN1) | BF_SRC_A7RCR1_DOMAIN1(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR1, field DOMAIN2[26] (RW)
 *
 * Domain2 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain2. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain2. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_A7RCR1_DOMAIN2 (26U)        /*!< Bit position for SRC_A7RCR1_DOMAIN2. */
#define BM_SRC_A7RCR1_DOMAIN2 (0x04000000U) /*!< Bit mask for SRC_A7RCR1_DOMAIN2. */
#define BS_SRC_A7RCR1_DOMAIN2 (1U)         /*!< Bit field size in bits for SRC_A7RCR1_DOMAIN2. */

/*! @brief Read current value of the SRC_A7RCR1_DOMAIN2 field. */
#define BR_SRC_A7RCR1_DOMAIN2(x) (HW_SRC_A7RCR1(x).B.DOMAIN2)

/*! @brief Format value for bitfield SRC_A7RCR1_DOMAIN2. */
#define BF_SRC_A7RCR1_DOMAIN2(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR1_DOMAIN2) & BM_SRC_A7RCR1_DOMAIN2)

/*! @brief Set the DOMAIN2 field to a new value. */
#define BW_SRC_A7RCR1_DOMAIN2(x, v) (HW_SRC_A7RCR1_WR(x, (HW_SRC_A7RCR1_RD(x) & ~BM_SRC_A7RCR1_DOMAIN2) | BF_SRC_A7RCR1_DOMAIN2(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR1, field DOMAIN3[27] (RW)
 *
 * Domain3 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain3. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain3. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_A7RCR1_DOMAIN3 (27U)        /*!< Bit position for SRC_A7RCR1_DOMAIN3. */
#define BM_SRC_A7RCR1_DOMAIN3 (0x08000000U) /*!< Bit mask for SRC_A7RCR1_DOMAIN3. */
#define BS_SRC_A7RCR1_DOMAIN3 (1U)         /*!< Bit field size in bits for SRC_A7RCR1_DOMAIN3. */

/*! @brief Read current value of the SRC_A7RCR1_DOMAIN3 field. */
#define BR_SRC_A7RCR1_DOMAIN3(x) (HW_SRC_A7RCR1(x).B.DOMAIN3)

/*! @brief Format value for bitfield SRC_A7RCR1_DOMAIN3. */
#define BF_SRC_A7RCR1_DOMAIN3(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR1_DOMAIN3) & BM_SRC_A7RCR1_DOMAIN3)

/*! @brief Set the DOMAIN3 field to a new value. */
#define BW_SRC_A7RCR1_DOMAIN3(x, v) (HW_SRC_A7RCR1_WR(x, (HW_SRC_A7RCR1_RD(x) & ~BM_SRC_A7RCR1_DOMAIN3) | BF_SRC_A7RCR1_DOMAIN3(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR1, field LOCK[30] (RW)
 *
 * Domain control bits lock Lock bit is a write-once register, once it is set to
 * 1, it can't be write to 0
 *
 * Values:
 * - 0 - [31] and [27:24] bits can be modified
 * - 1 - [31] and [27:24] bits cannot be modified
 */
/*@{*/
#define BP_SRC_A7RCR1_LOCK   (30U)         /*!< Bit position for SRC_A7RCR1_LOCK. */
#define BM_SRC_A7RCR1_LOCK   (0x40000000U) /*!< Bit mask for SRC_A7RCR1_LOCK. */
#define BS_SRC_A7RCR1_LOCK   (1U)          /*!< Bit field size in bits for SRC_A7RCR1_LOCK. */

/*! @brief Read current value of the SRC_A7RCR1_LOCK field. */
#define BR_SRC_A7RCR1_LOCK(x) (HW_SRC_A7RCR1(x).B.LOCK)

/*! @brief Format value for bitfield SRC_A7RCR1_LOCK. */
#define BF_SRC_A7RCR1_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR1_LOCK) & BM_SRC_A7RCR1_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_SRC_A7RCR1_LOCK(x, v) (HW_SRC_A7RCR1_WR(x, (HW_SRC_A7RCR1_RD(x) & ~BM_SRC_A7RCR1_LOCK) | BF_SRC_A7RCR1_LOCK(v)))
/*@}*/

/*!
 * @name Register SRC_A7RCR1, field DOM_EN[31] (RW)
 *
 * Domain Control enable for this register. [31:30] and [27:24] areas are not
 * controlled by this bit. [31:30] and [27:24] area can be modified by any masters
 * from any domains when Lock bit is not set.
 *
 * Values:
 * - 0 - Disables domain control. All of this register's bits except [31:30] and
 *     [27:24] can be modified by any masters
 * - 1 - Enables domain control. All of this register's bits except [31:30] and
 *     [27:24] can only be modified by the masters from the domains specified in
 *     [27:24] area.
 */
/*@{*/
#define BP_SRC_A7RCR1_DOM_EN (31U)         /*!< Bit position for SRC_A7RCR1_DOM_EN. */
#define BM_SRC_A7RCR1_DOM_EN (0x80000000U) /*!< Bit mask for SRC_A7RCR1_DOM_EN. */
#define BS_SRC_A7RCR1_DOM_EN (1U)          /*!< Bit field size in bits for SRC_A7RCR1_DOM_EN. */

/*! @brief Read current value of the SRC_A7RCR1_DOM_EN field. */
#define BR_SRC_A7RCR1_DOM_EN(x) (HW_SRC_A7RCR1(x).B.DOM_EN)

/*! @brief Format value for bitfield SRC_A7RCR1_DOM_EN. */
#define BF_SRC_A7RCR1_DOM_EN(v) ((uint32_t)((uint32_t)(v) << BP_SRC_A7RCR1_DOM_EN) & BM_SRC_A7RCR1_DOM_EN)

/*! @brief Set the DOM_EN field to a new value. */
#define BW_SRC_A7RCR1_DOM_EN(x, v) (HW_SRC_A7RCR1_WR(x, (HW_SRC_A7RCR1_RD(x) & ~BM_SRC_A7RCR1_DOM_EN) | BF_SRC_A7RCR1_DOM_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_SRC_M4RCR - M4 Reset Control Register
 ******************************************************************************/

/*!
 * @brief HW_SRC_M4RCR - M4 Reset Control Register (RW)
 *
 * Reset value: 0x000000A8U
 *
 * The M4 Reset Control Register (M4RCR), contains bits that control the M4
 * reset generation.
 */
typedef union _hw_src_m4rcr
{
    uint32_t U;
    struct _hw_src_m4rcr_bitfields
    {
        uint32_t SW_M4C_NON_SCLR_RST : 1; /*!< [0]  */
        uint32_t SW_M4C_RST : 1;       /*!< [1]  */
        uint32_t SW_M4P_RST : 1;       /*!< [2]  */
        uint32_t ENABLE_M4 : 1;        /*!< [3]  */
        uint32_t MASK_WDOG3_RST : 4;   /*!< [7:4]  */
        uint32_t WDOG3_RST_OPTION_M4 : 1; /*!< [8]  */
        uint32_t WDOG3_RST_OPTION : 1; /*!< [9]  */
        uint32_t RESERVED0 : 14;       /*!< [23:10]  */
        uint32_t DOMAIN0 : 1;          /*!< [24]  */
        uint32_t DOMAIN1 : 1;          /*!< [25]  */
        uint32_t DOMAIN2 : 1;          /*!< [26]  */
        uint32_t DOMAIN3 : 1;          /*!< [27]  */
        uint32_t RESERVED1 : 2;        /*!< [29:28]  */
        uint32_t LOCK : 1;             /*!< [30]  */
        uint32_t DOM_EN : 1;           /*!< [31]  */
    } B;
} hw_src_m4rcr_t;

/*!
 * @name Constants and macros for entire SRC_M4RCR register
 */
/*@{*/
#define HW_SRC_M4RCR_ADDR(x)     ((uintptr_t)(x) + 0xCU)

#define HW_SRC_M4RCR(x)          (*(__IO hw_src_m4rcr_t *) HW_SRC_M4RCR_ADDR(x))
#define HW_SRC_M4RCR_RD(x)       (HW_SRC_M4RCR(x).U)
#define HW_SRC_M4RCR_WR(x, v)    (HW_SRC_M4RCR(x).U = (v))
#define HW_SRC_M4RCR_SET(x, v)   (HW_SRC_M4RCR_WR(x, HW_SRC_M4RCR_RD(x) |  (v)))
#define HW_SRC_M4RCR_CLR(x, v)   (HW_SRC_M4RCR_WR(x, HW_SRC_M4RCR_RD(x) & ~(v)))
#define HW_SRC_M4RCR_TOG(x, v)   (HW_SRC_M4RCR_WR(x, HW_SRC_M4RCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_M4RCR bitfields
 */

/*!
 * @name Register SRC_M4RCR, field SW_M4C_NON_SCLR_RST[0] (RU)
 *
 * Non-self-clearing SW reset for M4 core
 *
 * Values:
 * - 0 - do not assert M4 core reset
 * - 1 - assert M4 core reset
 */
/*@{*/
#define BP_SRC_M4RCR_SW_M4C_NON_SCLR_RST (0U) /*!< Bit position for SRC_M4RCR_SW_M4C_NON_SCLR_RST. */
#define BM_SRC_M4RCR_SW_M4C_NON_SCLR_RST (0x00000001U) /*!< Bit mask for SRC_M4RCR_SW_M4C_NON_SCLR_RST. */
#define BS_SRC_M4RCR_SW_M4C_NON_SCLR_RST (1U) /*!< Bit field size in bits for SRC_M4RCR_SW_M4C_NON_SCLR_RST. */
/*@}*/

/*!
 * @name Register SRC_M4RCR, field SW_M4C_RST[1] (RW)
 *
 * Self-clearing SW reset for M4 core This is a self clearing bit. Once it is
 * set to 1, the reset process will begin, and once it finishes, this bit will be
 * self cleared. Software can determine that the reset has finished once this bit
 * is cleared. Software can also configure SRC to generate interrupt once the
 * software has finished. Please refer to SRC_SISR register for details.
 *
 * Values:
 * - 0 - do not assert M4 core reset
 * - 1 - assert M4 core reset
 */
/*@{*/
#define BP_SRC_M4RCR_SW_M4C_RST (1U)       /*!< Bit position for SRC_M4RCR_SW_M4C_RST. */
#define BM_SRC_M4RCR_SW_M4C_RST (0x00000002U) /*!< Bit mask for SRC_M4RCR_SW_M4C_RST. */
#define BS_SRC_M4RCR_SW_M4C_RST (1U)       /*!< Bit field size in bits for SRC_M4RCR_SW_M4C_RST. */

/*! @brief Read current value of the SRC_M4RCR_SW_M4C_RST field. */
#define BR_SRC_M4RCR_SW_M4C_RST(x) (HW_SRC_M4RCR(x).B.SW_M4C_RST)

/*! @brief Format value for bitfield SRC_M4RCR_SW_M4C_RST. */
#define BF_SRC_M4RCR_SW_M4C_RST(v) ((uint32_t)((uint32_t)(v) << BP_SRC_M4RCR_SW_M4C_RST) & BM_SRC_M4RCR_SW_M4C_RST)

/*! @brief Set the SW_M4C_RST field to a new value. */
#define BW_SRC_M4RCR_SW_M4C_RST(x, v) (HW_SRC_M4RCR_WR(x, (HW_SRC_M4RCR_RD(x) & ~BM_SRC_M4RCR_SW_M4C_RST) | BF_SRC_M4RCR_SW_M4C_RST(v)))
/*@}*/

/*!
 * @name Register SRC_M4RCR, field SW_M4P_RST[2] (RW)
 *
 * Self-clearing SW reset for M4 platform This is a self clearing bit. Once it
 * is set to 1, the reset process will begin, and once it finishes, this bit will
 * be self cleared. Software can determine that the reset has finished once this
 * bit is cleared. Software can also configure SRC to generate interrupt once the
 * software has finished. Please refer to SRC_SISR register for details.
 *
 * Values:
 * - 0 - do not assert M4 platform reset
 * - 1 - assert M4 platform reset
 */
/*@{*/
#define BP_SRC_M4RCR_SW_M4P_RST (2U)       /*!< Bit position for SRC_M4RCR_SW_M4P_RST. */
#define BM_SRC_M4RCR_SW_M4P_RST (0x00000004U) /*!< Bit mask for SRC_M4RCR_SW_M4P_RST. */
#define BS_SRC_M4RCR_SW_M4P_RST (1U)       /*!< Bit field size in bits for SRC_M4RCR_SW_M4P_RST. */

/*! @brief Read current value of the SRC_M4RCR_SW_M4P_RST field. */
#define BR_SRC_M4RCR_SW_M4P_RST(x) (HW_SRC_M4RCR(x).B.SW_M4P_RST)

/*! @brief Format value for bitfield SRC_M4RCR_SW_M4P_RST. */
#define BF_SRC_M4RCR_SW_M4P_RST(v) ((uint32_t)((uint32_t)(v) << BP_SRC_M4RCR_SW_M4P_RST) & BM_SRC_M4RCR_SW_M4P_RST)

/*! @brief Set the SW_M4P_RST field to a new value. */
#define BW_SRC_M4RCR_SW_M4P_RST(x, v) (HW_SRC_M4RCR_WR(x, (HW_SRC_M4RCR_RD(x) & ~BM_SRC_M4RCR_SW_M4P_RST) | BF_SRC_M4RCR_SW_M4P_RST(v)))
/*@}*/

/*!
 * @name Register SRC_M4RCR, field ENABLE_M4[3] (RW)
 *
 * Enable M4
 *
 * Values:
 * - 0 - M4 is disabled
 * - 1 - M4 is enabled
 */
/*@{*/
#define BP_SRC_M4RCR_ENABLE_M4 (3U)        /*!< Bit position for SRC_M4RCR_ENABLE_M4. */
#define BM_SRC_M4RCR_ENABLE_M4 (0x00000008U) /*!< Bit mask for SRC_M4RCR_ENABLE_M4. */
#define BS_SRC_M4RCR_ENABLE_M4 (1U)        /*!< Bit field size in bits for SRC_M4RCR_ENABLE_M4. */

/*! @brief Read current value of the SRC_M4RCR_ENABLE_M4 field. */
#define BR_SRC_M4RCR_ENABLE_M4(x) (HW_SRC_M4RCR(x).B.ENABLE_M4)

/*! @brief Format value for bitfield SRC_M4RCR_ENABLE_M4. */
#define BF_SRC_M4RCR_ENABLE_M4(v) ((uint32_t)((uint32_t)(v) << BP_SRC_M4RCR_ENABLE_M4) & BM_SRC_M4RCR_ENABLE_M4)

/*! @brief Set the ENABLE_M4 field to a new value. */
#define BW_SRC_M4RCR_ENABLE_M4(x, v) (HW_SRC_M4RCR_WR(x, (HW_SRC_M4RCR_RD(x) & ~BM_SRC_M4RCR_ENABLE_M4) | BF_SRC_M4RCR_ENABLE_M4(v)))
/*@}*/

/*!
 * @name Register SRC_M4RCR, field MASK_WDOG3_RST[7:4] (RW)
 *
 * Mask wdog3_rst_b source. If these 4 bits are coded from A to 5 then, the
 * wdog3_rst_b input to SRC will be masked and the wdog3_rst_b will not create a
 * reset to the chip. During the time the WDOG3 event is masked using SRC logic, it
 * is likely that the WDOG3 Reset Status Register (WRSR) bit 1 (which indicates a
 * WDOG3 timeout event) will get asserted. Software / OS developer must prepare
 * for this case. Re-enabling the WDOG3 is possible, by un-masking it in SRC,
 * though it must be preceded by servicing the WDOG3. However, for the case that the
 * event has been asserted, the status bit (WRSR bit-1) will remain asserted,
 * regardless of servicing the WDOG3 module. (Hardware reset is the only way to
 * cause the de-assertion of that bit). Any other code will be coded to 1010 i.e.
 * wdog3_rst_b is not masked
 *
 * Values:
 * - 0101 - wdog3_rst_b is masked
 * - 1010 - wdog3_rst_b is not masked
 */
/*@{*/
#define BP_SRC_M4RCR_MASK_WDOG3_RST (4U)   /*!< Bit position for SRC_M4RCR_MASK_WDOG3_RST. */
#define BM_SRC_M4RCR_MASK_WDOG3_RST (0x000000F0U) /*!< Bit mask for SRC_M4RCR_MASK_WDOG3_RST. */
#define BS_SRC_M4RCR_MASK_WDOG3_RST (4U)   /*!< Bit field size in bits for SRC_M4RCR_MASK_WDOG3_RST. */

/*! @brief Read current value of the SRC_M4RCR_MASK_WDOG3_RST field. */
#define BR_SRC_M4RCR_MASK_WDOG3_RST(x) (HW_SRC_M4RCR(x).B.MASK_WDOG3_RST)

/*! @brief Format value for bitfield SRC_M4RCR_MASK_WDOG3_RST. */
#define BF_SRC_M4RCR_MASK_WDOG3_RST(v) ((uint32_t)((uint32_t)(v) << BP_SRC_M4RCR_MASK_WDOG3_RST) & BM_SRC_M4RCR_MASK_WDOG3_RST)

/*! @brief Set the MASK_WDOG3_RST field to a new value. */
#define BW_SRC_M4RCR_MASK_WDOG3_RST(x, v) (HW_SRC_M4RCR_WR(x, (HW_SRC_M4RCR_RD(x) & ~BM_SRC_M4RCR_MASK_WDOG3_RST) | BF_SRC_M4RCR_MASK_WDOG3_RST(v)))
/*@}*/

/*!
 * @name Register SRC_M4RCR, field WDOG3_RST_OPTION_M4[8] (RW)
 *
 * Wdog3_rst_b option for M4. This bit is only effective when wdog3_rst_option
 * is set to 1.
 *
 * Values:
 * - 0 - wdgo3_rst_b Reset M4 core only
 * - 1 - Reset both M4 core and platform
 */
/*@{*/
#define BP_SRC_M4RCR_WDOG3_RST_OPTION_M4 (8U) /*!< Bit position for SRC_M4RCR_WDOG3_RST_OPTION_M4. */
#define BM_SRC_M4RCR_WDOG3_RST_OPTION_M4 (0x00000100U) /*!< Bit mask for SRC_M4RCR_WDOG3_RST_OPTION_M4. */
#define BS_SRC_M4RCR_WDOG3_RST_OPTION_M4 (1U) /*!< Bit field size in bits for SRC_M4RCR_WDOG3_RST_OPTION_M4. */

/*! @brief Read current value of the SRC_M4RCR_WDOG3_RST_OPTION_M4 field. */
#define BR_SRC_M4RCR_WDOG3_RST_OPTION_M4(x) (HW_SRC_M4RCR(x).B.WDOG3_RST_OPTION_M4)

/*! @brief Format value for bitfield SRC_M4RCR_WDOG3_RST_OPTION_M4. */
#define BF_SRC_M4RCR_WDOG3_RST_OPTION_M4(v) ((uint32_t)((uint32_t)(v) << BP_SRC_M4RCR_WDOG3_RST_OPTION_M4) & BM_SRC_M4RCR_WDOG3_RST_OPTION_M4)

/*! @brief Set the WDOG3_RST_OPTION_M4 field to a new value. */
#define BW_SRC_M4RCR_WDOG3_RST_OPTION_M4(x, v) (HW_SRC_M4RCR_WR(x, (HW_SRC_M4RCR_RD(x) & ~BM_SRC_M4RCR_WDOG3_RST_OPTION_M4) | BF_SRC_M4RCR_WDOG3_RST_OPTION_M4(v)))
/*@}*/

/*!
 * @name Register SRC_M4RCR, field WDOG3_RST_OPTION[9] (RW)
 *
 * Wdog3_rst_b option
 *
 * Values:
 * - 0 - Wdog3_rst_b asserts M4 reset
 * - 1 - Wdog3_rst_b asserts global reset
 */
/*@{*/
#define BP_SRC_M4RCR_WDOG3_RST_OPTION (9U) /*!< Bit position for SRC_M4RCR_WDOG3_RST_OPTION. */
#define BM_SRC_M4RCR_WDOG3_RST_OPTION (0x00000200U) /*!< Bit mask for SRC_M4RCR_WDOG3_RST_OPTION. */
#define BS_SRC_M4RCR_WDOG3_RST_OPTION (1U) /*!< Bit field size in bits for SRC_M4RCR_WDOG3_RST_OPTION. */

/*! @brief Read current value of the SRC_M4RCR_WDOG3_RST_OPTION field. */
#define BR_SRC_M4RCR_WDOG3_RST_OPTION(x) (HW_SRC_M4RCR(x).B.WDOG3_RST_OPTION)

/*! @brief Format value for bitfield SRC_M4RCR_WDOG3_RST_OPTION. */
#define BF_SRC_M4RCR_WDOG3_RST_OPTION(v) ((uint32_t)((uint32_t)(v) << BP_SRC_M4RCR_WDOG3_RST_OPTION) & BM_SRC_M4RCR_WDOG3_RST_OPTION)

/*! @brief Set the WDOG3_RST_OPTION field to a new value. */
#define BW_SRC_M4RCR_WDOG3_RST_OPTION(x, v) (HW_SRC_M4RCR_WR(x, (HW_SRC_M4RCR_RD(x) & ~BM_SRC_M4RCR_WDOG3_RST_OPTION) | BF_SRC_M4RCR_WDOG3_RST_OPTION(v)))
/*@}*/

/*!
 * @name Register SRC_M4RCR, field DOMAIN0[24] (RW)
 *
 * Domain0 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain0. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain0. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_M4RCR_DOMAIN0 (24U)         /*!< Bit position for SRC_M4RCR_DOMAIN0. */
#define BM_SRC_M4RCR_DOMAIN0 (0x01000000U) /*!< Bit mask for SRC_M4RCR_DOMAIN0. */
#define BS_SRC_M4RCR_DOMAIN0 (1U)          /*!< Bit field size in bits for SRC_M4RCR_DOMAIN0. */

/*! @brief Read current value of the SRC_M4RCR_DOMAIN0 field. */
#define BR_SRC_M4RCR_DOMAIN0(x) (HW_SRC_M4RCR(x).B.DOMAIN0)

/*! @brief Format value for bitfield SRC_M4RCR_DOMAIN0. */
#define BF_SRC_M4RCR_DOMAIN0(v) ((uint32_t)((uint32_t)(v) << BP_SRC_M4RCR_DOMAIN0) & BM_SRC_M4RCR_DOMAIN0)

/*! @brief Set the DOMAIN0 field to a new value. */
#define BW_SRC_M4RCR_DOMAIN0(x, v) (HW_SRC_M4RCR_WR(x, (HW_SRC_M4RCR_RD(x) & ~BM_SRC_M4RCR_DOMAIN0) | BF_SRC_M4RCR_DOMAIN0(v)))
/*@}*/

/*!
 * @name Register SRC_M4RCR, field DOMAIN1[25] (RW)
 *
 * Domain1 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain1. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain1. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_M4RCR_DOMAIN1 (25U)         /*!< Bit position for SRC_M4RCR_DOMAIN1. */
#define BM_SRC_M4RCR_DOMAIN1 (0x02000000U) /*!< Bit mask for SRC_M4RCR_DOMAIN1. */
#define BS_SRC_M4RCR_DOMAIN1 (1U)          /*!< Bit field size in bits for SRC_M4RCR_DOMAIN1. */

/*! @brief Read current value of the SRC_M4RCR_DOMAIN1 field. */
#define BR_SRC_M4RCR_DOMAIN1(x) (HW_SRC_M4RCR(x).B.DOMAIN1)

/*! @brief Format value for bitfield SRC_M4RCR_DOMAIN1. */
#define BF_SRC_M4RCR_DOMAIN1(v) ((uint32_t)((uint32_t)(v) << BP_SRC_M4RCR_DOMAIN1) & BM_SRC_M4RCR_DOMAIN1)

/*! @brief Set the DOMAIN1 field to a new value. */
#define BW_SRC_M4RCR_DOMAIN1(x, v) (HW_SRC_M4RCR_WR(x, (HW_SRC_M4RCR_RD(x) & ~BM_SRC_M4RCR_DOMAIN1) | BF_SRC_M4RCR_DOMAIN1(v)))
/*@}*/

/*!
 * @name Register SRC_M4RCR, field DOMAIN2[26] (RW)
 *
 * Domain2 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain2. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain2. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_M4RCR_DOMAIN2 (26U)         /*!< Bit position for SRC_M4RCR_DOMAIN2. */
#define BM_SRC_M4RCR_DOMAIN2 (0x04000000U) /*!< Bit mask for SRC_M4RCR_DOMAIN2. */
#define BS_SRC_M4RCR_DOMAIN2 (1U)          /*!< Bit field size in bits for SRC_M4RCR_DOMAIN2. */

/*! @brief Read current value of the SRC_M4RCR_DOMAIN2 field. */
#define BR_SRC_M4RCR_DOMAIN2(x) (HW_SRC_M4RCR(x).B.DOMAIN2)

/*! @brief Format value for bitfield SRC_M4RCR_DOMAIN2. */
#define BF_SRC_M4RCR_DOMAIN2(v) ((uint32_t)((uint32_t)(v) << BP_SRC_M4RCR_DOMAIN2) & BM_SRC_M4RCR_DOMAIN2)

/*! @brief Set the DOMAIN2 field to a new value. */
#define BW_SRC_M4RCR_DOMAIN2(x, v) (HW_SRC_M4RCR_WR(x, (HW_SRC_M4RCR_RD(x) & ~BM_SRC_M4RCR_DOMAIN2) | BF_SRC_M4RCR_DOMAIN2(v)))
/*@}*/

/*!
 * @name Register SRC_M4RCR, field DOMAIN3[27] (RW)
 *
 * Domain3 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain3. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain3. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_M4RCR_DOMAIN3 (27U)         /*!< Bit position for SRC_M4RCR_DOMAIN3. */
#define BM_SRC_M4RCR_DOMAIN3 (0x08000000U) /*!< Bit mask for SRC_M4RCR_DOMAIN3. */
#define BS_SRC_M4RCR_DOMAIN3 (1U)          /*!< Bit field size in bits for SRC_M4RCR_DOMAIN3. */

/*! @brief Read current value of the SRC_M4RCR_DOMAIN3 field. */
#define BR_SRC_M4RCR_DOMAIN3(x) (HW_SRC_M4RCR(x).B.DOMAIN3)

/*! @brief Format value for bitfield SRC_M4RCR_DOMAIN3. */
#define BF_SRC_M4RCR_DOMAIN3(v) ((uint32_t)((uint32_t)(v) << BP_SRC_M4RCR_DOMAIN3) & BM_SRC_M4RCR_DOMAIN3)

/*! @brief Set the DOMAIN3 field to a new value. */
#define BW_SRC_M4RCR_DOMAIN3(x, v) (HW_SRC_M4RCR_WR(x, (HW_SRC_M4RCR_RD(x) & ~BM_SRC_M4RCR_DOMAIN3) | BF_SRC_M4RCR_DOMAIN3(v)))
/*@}*/

/*!
 * @name Register SRC_M4RCR, field LOCK[30] (RW)
 *
 * Domain control bits lock Lock bit is a write-once register, once it is set to
 * 1, it can't be write to 0
 *
 * Values:
 * - 0 - [31] and [27:24] bits can be modified
 * - 1 - [31] and [27:24] bits cannot be modified
 */
/*@{*/
#define BP_SRC_M4RCR_LOCK    (30U)         /*!< Bit position for SRC_M4RCR_LOCK. */
#define BM_SRC_M4RCR_LOCK    (0x40000000U) /*!< Bit mask for SRC_M4RCR_LOCK. */
#define BS_SRC_M4RCR_LOCK    (1U)          /*!< Bit field size in bits for SRC_M4RCR_LOCK. */

/*! @brief Read current value of the SRC_M4RCR_LOCK field. */
#define BR_SRC_M4RCR_LOCK(x) (HW_SRC_M4RCR(x).B.LOCK)

/*! @brief Format value for bitfield SRC_M4RCR_LOCK. */
#define BF_SRC_M4RCR_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_SRC_M4RCR_LOCK) & BM_SRC_M4RCR_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_SRC_M4RCR_LOCK(x, v) (HW_SRC_M4RCR_WR(x, (HW_SRC_M4RCR_RD(x) & ~BM_SRC_M4RCR_LOCK) | BF_SRC_M4RCR_LOCK(v)))
/*@}*/

/*!
 * @name Register SRC_M4RCR, field DOM_EN[31] (RW)
 *
 * Domain Control enable for this register. [31:30] and [27:24] areas are not
 * controlled by this bit. [31:30] and [27:24] area can be modified by any masters
 * from any domains when Lock bit is not set.
 *
 * Values:
 * - 0 - Disables domain control. All of this register's bits except [31:30] and
 *     [27:24] can be modified by any masters
 * - 1 - Enables domain control. All of this register's bits except [31:30] and
 *     [27:24] can only be modified by the masters from the domains specified in
 *     [27:24] area.
 */
/*@{*/
#define BP_SRC_M4RCR_DOM_EN  (31U)         /*!< Bit position for SRC_M4RCR_DOM_EN. */
#define BM_SRC_M4RCR_DOM_EN  (0x80000000U) /*!< Bit mask for SRC_M4RCR_DOM_EN. */
#define BS_SRC_M4RCR_DOM_EN  (1U)          /*!< Bit field size in bits for SRC_M4RCR_DOM_EN. */

/*! @brief Read current value of the SRC_M4RCR_DOM_EN field. */
#define BR_SRC_M4RCR_DOM_EN(x) (HW_SRC_M4RCR(x).B.DOM_EN)

/*! @brief Format value for bitfield SRC_M4RCR_DOM_EN. */
#define BF_SRC_M4RCR_DOM_EN(v) ((uint32_t)((uint32_t)(v) << BP_SRC_M4RCR_DOM_EN) & BM_SRC_M4RCR_DOM_EN)

/*! @brief Set the DOM_EN field to a new value. */
#define BW_SRC_M4RCR_DOM_EN(x, v) (HW_SRC_M4RCR_WR(x, (HW_SRC_M4RCR_RD(x) & ~BM_SRC_M4RCR_DOM_EN) | BF_SRC_M4RCR_DOM_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_SRC_ERCR - EIM Reset Control Register
 ******************************************************************************/

/*!
 * @brief HW_SRC_ERCR - EIM Reset Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The EIM Reset Control Register (SRC_ERCR), contains bits that control the EIM
 * Controller reset generation.
 */
typedef union _hw_src_ercr
{
    uint32_t U;
    struct _hw_src_ercr_bitfields
    {
        uint32_t EIM_RST : 1;          /*!< [0]  */
        uint32_t RESERVED0 : 23;       /*!< [23:1]  */
        uint32_t DOMAIN0 : 1;          /*!< [24]  */
        uint32_t DOMAIN1 : 1;          /*!< [25]  */
        uint32_t DOMAIN2 : 1;          /*!< [26]  */
        uint32_t DOMAIN3 : 1;          /*!< [27]  */
        uint32_t RESERVED1 : 2;        /*!< [29:28]  */
        uint32_t LOCK : 1;             /*!< [30]  */
        uint32_t DOM_EN : 1;           /*!< [31]  */
    } B;
} hw_src_ercr_t;

/*!
 * @name Constants and macros for entire SRC_ERCR register
 */
/*@{*/
#define HW_SRC_ERCR_ADDR(x)      ((uintptr_t)(x) + 0x14U)

#define HW_SRC_ERCR(x)           (*(__IO hw_src_ercr_t *) HW_SRC_ERCR_ADDR(x))
#define HW_SRC_ERCR_RD(x)        (HW_SRC_ERCR(x).U)
#define HW_SRC_ERCR_WR(x, v)     (HW_SRC_ERCR(x).U = (v))
#define HW_SRC_ERCR_SET(x, v)    (HW_SRC_ERCR_WR(x, HW_SRC_ERCR_RD(x) |  (v)))
#define HW_SRC_ERCR_CLR(x, v)    (HW_SRC_ERCR_WR(x, HW_SRC_ERCR_RD(x) & ~(v)))
#define HW_SRC_ERCR_TOG(x, v)    (HW_SRC_ERCR_WR(x, HW_SRC_ERCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_ERCR bitfields
 */

/*!
 * @name Register SRC_ERCR, field EIM_RST[0] (RW)
 *
 * EIM reset is needed in order to reconfigure the eim chip select. The software
 * reset bit must de-asserted. The eim chip select configuration should be
 * updated. The software bit must be re-asserted since this is not self-refresh.
 *
 * Values:
 * - 0 - assert EIM controller reset
 * - 1 - do not assert EIM controller reset
 */
/*@{*/
#define BP_SRC_ERCR_EIM_RST  (0U)          /*!< Bit position for SRC_ERCR_EIM_RST. */
#define BM_SRC_ERCR_EIM_RST  (0x00000001U) /*!< Bit mask for SRC_ERCR_EIM_RST. */
#define BS_SRC_ERCR_EIM_RST  (1U)          /*!< Bit field size in bits for SRC_ERCR_EIM_RST. */

/*! @brief Read current value of the SRC_ERCR_EIM_RST field. */
#define BR_SRC_ERCR_EIM_RST(x) (HW_SRC_ERCR(x).B.EIM_RST)

/*! @brief Format value for bitfield SRC_ERCR_EIM_RST. */
#define BF_SRC_ERCR_EIM_RST(v) ((uint32_t)((uint32_t)(v) << BP_SRC_ERCR_EIM_RST) & BM_SRC_ERCR_EIM_RST)

/*! @brief Set the EIM_RST field to a new value. */
#define BW_SRC_ERCR_EIM_RST(x, v) (HW_SRC_ERCR_WR(x, (HW_SRC_ERCR_RD(x) & ~BM_SRC_ERCR_EIM_RST) | BF_SRC_ERCR_EIM_RST(v)))
/*@}*/

/*!
 * @name Register SRC_ERCR, field DOMAIN0[24] (RW)
 *
 * Domain0 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain0. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain0. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_ERCR_DOMAIN0  (24U)         /*!< Bit position for SRC_ERCR_DOMAIN0. */
#define BM_SRC_ERCR_DOMAIN0  (0x01000000U) /*!< Bit mask for SRC_ERCR_DOMAIN0. */
#define BS_SRC_ERCR_DOMAIN0  (1U)          /*!< Bit field size in bits for SRC_ERCR_DOMAIN0. */

/*! @brief Read current value of the SRC_ERCR_DOMAIN0 field. */
#define BR_SRC_ERCR_DOMAIN0(x) (HW_SRC_ERCR(x).B.DOMAIN0)

/*! @brief Format value for bitfield SRC_ERCR_DOMAIN0. */
#define BF_SRC_ERCR_DOMAIN0(v) ((uint32_t)((uint32_t)(v) << BP_SRC_ERCR_DOMAIN0) & BM_SRC_ERCR_DOMAIN0)

/*! @brief Set the DOMAIN0 field to a new value. */
#define BW_SRC_ERCR_DOMAIN0(x, v) (HW_SRC_ERCR_WR(x, (HW_SRC_ERCR_RD(x) & ~BM_SRC_ERCR_DOMAIN0) | BF_SRC_ERCR_DOMAIN0(v)))
/*@}*/

/*!
 * @name Register SRC_ERCR, field DOMAIN1[25] (RW)
 *
 * Domain1 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain1. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain1. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_ERCR_DOMAIN1  (25U)         /*!< Bit position for SRC_ERCR_DOMAIN1. */
#define BM_SRC_ERCR_DOMAIN1  (0x02000000U) /*!< Bit mask for SRC_ERCR_DOMAIN1. */
#define BS_SRC_ERCR_DOMAIN1  (1U)          /*!< Bit field size in bits for SRC_ERCR_DOMAIN1. */

/*! @brief Read current value of the SRC_ERCR_DOMAIN1 field. */
#define BR_SRC_ERCR_DOMAIN1(x) (HW_SRC_ERCR(x).B.DOMAIN1)

/*! @brief Format value for bitfield SRC_ERCR_DOMAIN1. */
#define BF_SRC_ERCR_DOMAIN1(v) ((uint32_t)((uint32_t)(v) << BP_SRC_ERCR_DOMAIN1) & BM_SRC_ERCR_DOMAIN1)

/*! @brief Set the DOMAIN1 field to a new value. */
#define BW_SRC_ERCR_DOMAIN1(x, v) (HW_SRC_ERCR_WR(x, (HW_SRC_ERCR_RD(x) & ~BM_SRC_ERCR_DOMAIN1) | BF_SRC_ERCR_DOMAIN1(v)))
/*@}*/

/*!
 * @name Register SRC_ERCR, field DOMAIN2[26] (RW)
 *
 * Domain2 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain2. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain2. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_ERCR_DOMAIN2  (26U)         /*!< Bit position for SRC_ERCR_DOMAIN2. */
#define BM_SRC_ERCR_DOMAIN2  (0x04000000U) /*!< Bit mask for SRC_ERCR_DOMAIN2. */
#define BS_SRC_ERCR_DOMAIN2  (1U)          /*!< Bit field size in bits for SRC_ERCR_DOMAIN2. */

/*! @brief Read current value of the SRC_ERCR_DOMAIN2 field. */
#define BR_SRC_ERCR_DOMAIN2(x) (HW_SRC_ERCR(x).B.DOMAIN2)

/*! @brief Format value for bitfield SRC_ERCR_DOMAIN2. */
#define BF_SRC_ERCR_DOMAIN2(v) ((uint32_t)((uint32_t)(v) << BP_SRC_ERCR_DOMAIN2) & BM_SRC_ERCR_DOMAIN2)

/*! @brief Set the DOMAIN2 field to a new value. */
#define BW_SRC_ERCR_DOMAIN2(x, v) (HW_SRC_ERCR_WR(x, (HW_SRC_ERCR_RD(x) & ~BM_SRC_ERCR_DOMAIN2) | BF_SRC_ERCR_DOMAIN2(v)))
/*@}*/

/*!
 * @name Register SRC_ERCR, field DOMAIN3[27] (RW)
 *
 * Domain3 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain3. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain3. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_ERCR_DOMAIN3  (27U)         /*!< Bit position for SRC_ERCR_DOMAIN3. */
#define BM_SRC_ERCR_DOMAIN3  (0x08000000U) /*!< Bit mask for SRC_ERCR_DOMAIN3. */
#define BS_SRC_ERCR_DOMAIN3  (1U)          /*!< Bit field size in bits for SRC_ERCR_DOMAIN3. */

/*! @brief Read current value of the SRC_ERCR_DOMAIN3 field. */
#define BR_SRC_ERCR_DOMAIN3(x) (HW_SRC_ERCR(x).B.DOMAIN3)

/*! @brief Format value for bitfield SRC_ERCR_DOMAIN3. */
#define BF_SRC_ERCR_DOMAIN3(v) ((uint32_t)((uint32_t)(v) << BP_SRC_ERCR_DOMAIN3) & BM_SRC_ERCR_DOMAIN3)

/*! @brief Set the DOMAIN3 field to a new value. */
#define BW_SRC_ERCR_DOMAIN3(x, v) (HW_SRC_ERCR_WR(x, (HW_SRC_ERCR_RD(x) & ~BM_SRC_ERCR_DOMAIN3) | BF_SRC_ERCR_DOMAIN3(v)))
/*@}*/

/*!
 * @name Register SRC_ERCR, field LOCK[30] (RW)
 *
 * Domain control bits lock Lock bit is a write-once register, once it is set to
 * 1, it can't be write to 0
 *
 * Values:
 * - 0 - [31] and [27:24] bits can be modified
 * - 1 - [31] and [27:24] bits cannot be modified
 */
/*@{*/
#define BP_SRC_ERCR_LOCK     (30U)         /*!< Bit position for SRC_ERCR_LOCK. */
#define BM_SRC_ERCR_LOCK     (0x40000000U) /*!< Bit mask for SRC_ERCR_LOCK. */
#define BS_SRC_ERCR_LOCK     (1U)          /*!< Bit field size in bits for SRC_ERCR_LOCK. */

/*! @brief Read current value of the SRC_ERCR_LOCK field. */
#define BR_SRC_ERCR_LOCK(x)  (HW_SRC_ERCR(x).B.LOCK)

/*! @brief Format value for bitfield SRC_ERCR_LOCK. */
#define BF_SRC_ERCR_LOCK(v)  ((uint32_t)((uint32_t)(v) << BP_SRC_ERCR_LOCK) & BM_SRC_ERCR_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_SRC_ERCR_LOCK(x, v) (HW_SRC_ERCR_WR(x, (HW_SRC_ERCR_RD(x) & ~BM_SRC_ERCR_LOCK) | BF_SRC_ERCR_LOCK(v)))
/*@}*/

/*!
 * @name Register SRC_ERCR, field DOM_EN[31] (RW)
 *
 * Domain Control enable for this register. [31:30] and [27:24] areas are not
 * controlled by this bit. [31:30] and [27:24] area can be modified by any masters
 * from any domains when Lock bit is not set.
 *
 * Values:
 * - 0 - Disables domain control. All of this register's bits except [31:30] and
 *     [27:24] can be modified by any masters
 * - 1 - Enables domain control. All of this register's bits except [31:30] and
 *     [27:24] can only be modified by the masters from the domains specified in
 *     [27:24] area.
 */
/*@{*/
#define BP_SRC_ERCR_DOM_EN   (31U)         /*!< Bit position for SRC_ERCR_DOM_EN. */
#define BM_SRC_ERCR_DOM_EN   (0x80000000U) /*!< Bit mask for SRC_ERCR_DOM_EN. */
#define BS_SRC_ERCR_DOM_EN   (1U)          /*!< Bit field size in bits for SRC_ERCR_DOM_EN. */

/*! @brief Read current value of the SRC_ERCR_DOM_EN field. */
#define BR_SRC_ERCR_DOM_EN(x) (HW_SRC_ERCR(x).B.DOM_EN)

/*! @brief Format value for bitfield SRC_ERCR_DOM_EN. */
#define BF_SRC_ERCR_DOM_EN(v) ((uint32_t)((uint32_t)(v) << BP_SRC_ERCR_DOM_EN) & BM_SRC_ERCR_DOM_EN)

/*! @brief Set the DOM_EN field to a new value. */
#define BW_SRC_ERCR_DOM_EN(x, v) (HW_SRC_ERCR_WR(x, (HW_SRC_ERCR_RD(x) & ~BM_SRC_ERCR_DOM_EN) | BF_SRC_ERCR_DOM_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_SRC_HSICPHY_RCR - HSIC PHY Reset Control Register
 ******************************************************************************/

/*!
 * @brief HW_SRC_HSICPHY_RCR - HSIC PHY Reset Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The HSIC PHY Reset Control Register (SRC_HSICPHY_RCR), contains bits that
 * control the HSIC PHY reset generation.
 */
typedef union _hw_src_hsicphy_rcr
{
    uint32_t U;
    struct _hw_src_hsicphy_rcr_bitfields
    {
        uint32_t HSIC_PHY_POR : 1;     /*!< [0]  */
        uint32_t HSICPHY_PORT_RST : 1; /*!< [1]  */
        uint32_t RESERVED0 : 22;       /*!< [23:2]  */
        uint32_t DOMAIN0 : 1;          /*!< [24]  */
        uint32_t DOMAIN1 : 1;          /*!< [25]  */
        uint32_t DOMAIN2 : 1;          /*!< [26]  */
        uint32_t DOMAIN3 : 1;          /*!< [27]  */
        uint32_t RESERVED1 : 2;        /*!< [29:28]  */
        uint32_t LOCK : 1;             /*!< [30]  */
        uint32_t DOM_EN : 1;           /*!< [31]  */
    } B;
} hw_src_hsicphy_rcr_t;

/*!
 * @name Constants and macros for entire SRC_HSICPHY_RCR register
 */
/*@{*/
#define HW_SRC_HSICPHY_RCR_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_SRC_HSICPHY_RCR(x)    (*(__IO hw_src_hsicphy_rcr_t *) HW_SRC_HSICPHY_RCR_ADDR(x))
#define HW_SRC_HSICPHY_RCR_RD(x) (HW_SRC_HSICPHY_RCR(x).U)
#define HW_SRC_HSICPHY_RCR_WR(x, v) (HW_SRC_HSICPHY_RCR(x).U = (v))
#define HW_SRC_HSICPHY_RCR_SET(x, v) (HW_SRC_HSICPHY_RCR_WR(x, HW_SRC_HSICPHY_RCR_RD(x) |  (v)))
#define HW_SRC_HSICPHY_RCR_CLR(x, v) (HW_SRC_HSICPHY_RCR_WR(x, HW_SRC_HSICPHY_RCR_RD(x) & ~(v)))
#define HW_SRC_HSICPHY_RCR_TOG(x, v) (HW_SRC_HSICPHY_RCR_WR(x, HW_SRC_HSICPHY_RCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_HSICPHY_RCR bitfields
 */

/*!
 * @name Register SRC_HSICPHY_RCR, field HSIC_PHY_POR[0] (RU)
 *
 * HSIC PHY POR This is a self clearing bit. Once it is set to 1, the reset
 * process will begin, and once it finishes, this bit will be self cleared. Software
 * can determine that the reset has finished once this bit is cleared. Software
 * can also configure SRC to generate interrupt once the software has finished.
 * Please refer to SRC_SISR register for details.
 *
 * Values:
 * - 0 - Do not assert HSIC PHY reset
 * - 1 - Assert HSIC PHY reset
 */
/*@{*/
#define BP_SRC_HSICPHY_RCR_HSIC_PHY_POR (0U) /*!< Bit position for SRC_HSICPHY_RCR_HSIC_PHY_POR. */
#define BM_SRC_HSICPHY_RCR_HSIC_PHY_POR (0x00000001U) /*!< Bit mask for SRC_HSICPHY_RCR_HSIC_PHY_POR. */
#define BS_SRC_HSICPHY_RCR_HSIC_PHY_POR (1U) /*!< Bit field size in bits for SRC_HSICPHY_RCR_HSIC_PHY_POR. */
/*@}*/

/*!
 * @name Register SRC_HSICPHY_RCR, field HSICPHY_PORT_RST[1] (RW)
 *
 * HSIC PHY Port Reset
 *
 * Values:
 * - 0 - Do not assert HSIC PHY Port Reset
 * - 1 - Assert HSIC PHY Port Reset
 */
/*@{*/
#define BP_SRC_HSICPHY_RCR_HSICPHY_PORT_RST (1U) /*!< Bit position for SRC_HSICPHY_RCR_HSICPHY_PORT_RST. */
#define BM_SRC_HSICPHY_RCR_HSICPHY_PORT_RST (0x00000002U) /*!< Bit mask for SRC_HSICPHY_RCR_HSICPHY_PORT_RST. */
#define BS_SRC_HSICPHY_RCR_HSICPHY_PORT_RST (1U) /*!< Bit field size in bits for SRC_HSICPHY_RCR_HSICPHY_PORT_RST. */

/*! @brief Read current value of the SRC_HSICPHY_RCR_HSICPHY_PORT_RST field. */
#define BR_SRC_HSICPHY_RCR_HSICPHY_PORT_RST(x) (HW_SRC_HSICPHY_RCR(x).B.HSICPHY_PORT_RST)

/*! @brief Format value for bitfield SRC_HSICPHY_RCR_HSICPHY_PORT_RST. */
#define BF_SRC_HSICPHY_RCR_HSICPHY_PORT_RST(v) ((uint32_t)((uint32_t)(v) << BP_SRC_HSICPHY_RCR_HSICPHY_PORT_RST) & BM_SRC_HSICPHY_RCR_HSICPHY_PORT_RST)

/*! @brief Set the HSICPHY_PORT_RST field to a new value. */
#define BW_SRC_HSICPHY_RCR_HSICPHY_PORT_RST(x, v) (HW_SRC_HSICPHY_RCR_WR(x, (HW_SRC_HSICPHY_RCR_RD(x) & ~BM_SRC_HSICPHY_RCR_HSICPHY_PORT_RST) | BF_SRC_HSICPHY_RCR_HSICPHY_PORT_RST(v)))
/*@}*/

/*!
 * @name Register SRC_HSICPHY_RCR, field DOMAIN0[24] (RW)
 *
 * Domain0 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain0. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain0. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_HSICPHY_RCR_DOMAIN0 (24U)   /*!< Bit position for SRC_HSICPHY_RCR_DOMAIN0. */
#define BM_SRC_HSICPHY_RCR_DOMAIN0 (0x01000000U) /*!< Bit mask for SRC_HSICPHY_RCR_DOMAIN0. */
#define BS_SRC_HSICPHY_RCR_DOMAIN0 (1U)    /*!< Bit field size in bits for SRC_HSICPHY_RCR_DOMAIN0. */

/*! @brief Read current value of the SRC_HSICPHY_RCR_DOMAIN0 field. */
#define BR_SRC_HSICPHY_RCR_DOMAIN0(x) (HW_SRC_HSICPHY_RCR(x).B.DOMAIN0)

/*! @brief Format value for bitfield SRC_HSICPHY_RCR_DOMAIN0. */
#define BF_SRC_HSICPHY_RCR_DOMAIN0(v) ((uint32_t)((uint32_t)(v) << BP_SRC_HSICPHY_RCR_DOMAIN0) & BM_SRC_HSICPHY_RCR_DOMAIN0)

/*! @brief Set the DOMAIN0 field to a new value. */
#define BW_SRC_HSICPHY_RCR_DOMAIN0(x, v) (HW_SRC_HSICPHY_RCR_WR(x, (HW_SRC_HSICPHY_RCR_RD(x) & ~BM_SRC_HSICPHY_RCR_DOMAIN0) | BF_SRC_HSICPHY_RCR_DOMAIN0(v)))
/*@}*/

/*!
 * @name Register SRC_HSICPHY_RCR, field DOMAIN1[25] (RW)
 *
 * Domain1 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain1. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain1. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_HSICPHY_RCR_DOMAIN1 (25U)   /*!< Bit position for SRC_HSICPHY_RCR_DOMAIN1. */
#define BM_SRC_HSICPHY_RCR_DOMAIN1 (0x02000000U) /*!< Bit mask for SRC_HSICPHY_RCR_DOMAIN1. */
#define BS_SRC_HSICPHY_RCR_DOMAIN1 (1U)    /*!< Bit field size in bits for SRC_HSICPHY_RCR_DOMAIN1. */

/*! @brief Read current value of the SRC_HSICPHY_RCR_DOMAIN1 field. */
#define BR_SRC_HSICPHY_RCR_DOMAIN1(x) (HW_SRC_HSICPHY_RCR(x).B.DOMAIN1)

/*! @brief Format value for bitfield SRC_HSICPHY_RCR_DOMAIN1. */
#define BF_SRC_HSICPHY_RCR_DOMAIN1(v) ((uint32_t)((uint32_t)(v) << BP_SRC_HSICPHY_RCR_DOMAIN1) & BM_SRC_HSICPHY_RCR_DOMAIN1)

/*! @brief Set the DOMAIN1 field to a new value. */
#define BW_SRC_HSICPHY_RCR_DOMAIN1(x, v) (HW_SRC_HSICPHY_RCR_WR(x, (HW_SRC_HSICPHY_RCR_RD(x) & ~BM_SRC_HSICPHY_RCR_DOMAIN1) | BF_SRC_HSICPHY_RCR_DOMAIN1(v)))
/*@}*/

/*!
 * @name Register SRC_HSICPHY_RCR, field DOMAIN2[26] (RW)
 *
 * Domain2 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain2. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain2. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_HSICPHY_RCR_DOMAIN2 (26U)   /*!< Bit position for SRC_HSICPHY_RCR_DOMAIN2. */
#define BM_SRC_HSICPHY_RCR_DOMAIN2 (0x04000000U) /*!< Bit mask for SRC_HSICPHY_RCR_DOMAIN2. */
#define BS_SRC_HSICPHY_RCR_DOMAIN2 (1U)    /*!< Bit field size in bits for SRC_HSICPHY_RCR_DOMAIN2. */

/*! @brief Read current value of the SRC_HSICPHY_RCR_DOMAIN2 field. */
#define BR_SRC_HSICPHY_RCR_DOMAIN2(x) (HW_SRC_HSICPHY_RCR(x).B.DOMAIN2)

/*! @brief Format value for bitfield SRC_HSICPHY_RCR_DOMAIN2. */
#define BF_SRC_HSICPHY_RCR_DOMAIN2(v) ((uint32_t)((uint32_t)(v) << BP_SRC_HSICPHY_RCR_DOMAIN2) & BM_SRC_HSICPHY_RCR_DOMAIN2)

/*! @brief Set the DOMAIN2 field to a new value. */
#define BW_SRC_HSICPHY_RCR_DOMAIN2(x, v) (HW_SRC_HSICPHY_RCR_WR(x, (HW_SRC_HSICPHY_RCR_RD(x) & ~BM_SRC_HSICPHY_RCR_DOMAIN2) | BF_SRC_HSICPHY_RCR_DOMAIN2(v)))
/*@}*/

/*!
 * @name Register SRC_HSICPHY_RCR, field DOMAIN3[27] (RW)
 *
 * Domain3 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain3. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain3. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_HSICPHY_RCR_DOMAIN3 (27U)   /*!< Bit position for SRC_HSICPHY_RCR_DOMAIN3. */
#define BM_SRC_HSICPHY_RCR_DOMAIN3 (0x08000000U) /*!< Bit mask for SRC_HSICPHY_RCR_DOMAIN3. */
#define BS_SRC_HSICPHY_RCR_DOMAIN3 (1U)    /*!< Bit field size in bits for SRC_HSICPHY_RCR_DOMAIN3. */

/*! @brief Read current value of the SRC_HSICPHY_RCR_DOMAIN3 field. */
#define BR_SRC_HSICPHY_RCR_DOMAIN3(x) (HW_SRC_HSICPHY_RCR(x).B.DOMAIN3)

/*! @brief Format value for bitfield SRC_HSICPHY_RCR_DOMAIN3. */
#define BF_SRC_HSICPHY_RCR_DOMAIN3(v) ((uint32_t)((uint32_t)(v) << BP_SRC_HSICPHY_RCR_DOMAIN3) & BM_SRC_HSICPHY_RCR_DOMAIN3)

/*! @brief Set the DOMAIN3 field to a new value. */
#define BW_SRC_HSICPHY_RCR_DOMAIN3(x, v) (HW_SRC_HSICPHY_RCR_WR(x, (HW_SRC_HSICPHY_RCR_RD(x) & ~BM_SRC_HSICPHY_RCR_DOMAIN3) | BF_SRC_HSICPHY_RCR_DOMAIN3(v)))
/*@}*/

/*!
 * @name Register SRC_HSICPHY_RCR, field LOCK[30] (RW)
 *
 * Domain control bits lock Lock bit is a write-once register, once it is set to
 * 1, it can't be write to 0
 *
 * Values:
 * - 0 - [31] and [27:24] bits can be modified
 * - 1 - [31] and [27:24] bits cannot be modified
 */
/*@{*/
#define BP_SRC_HSICPHY_RCR_LOCK (30U)      /*!< Bit position for SRC_HSICPHY_RCR_LOCK. */
#define BM_SRC_HSICPHY_RCR_LOCK (0x40000000U) /*!< Bit mask for SRC_HSICPHY_RCR_LOCK. */
#define BS_SRC_HSICPHY_RCR_LOCK (1U)       /*!< Bit field size in bits for SRC_HSICPHY_RCR_LOCK. */

/*! @brief Read current value of the SRC_HSICPHY_RCR_LOCK field. */
#define BR_SRC_HSICPHY_RCR_LOCK(x) (HW_SRC_HSICPHY_RCR(x).B.LOCK)

/*! @brief Format value for bitfield SRC_HSICPHY_RCR_LOCK. */
#define BF_SRC_HSICPHY_RCR_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_SRC_HSICPHY_RCR_LOCK) & BM_SRC_HSICPHY_RCR_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_SRC_HSICPHY_RCR_LOCK(x, v) (HW_SRC_HSICPHY_RCR_WR(x, (HW_SRC_HSICPHY_RCR_RD(x) & ~BM_SRC_HSICPHY_RCR_LOCK) | BF_SRC_HSICPHY_RCR_LOCK(v)))
/*@}*/

/*!
 * @name Register SRC_HSICPHY_RCR, field DOM_EN[31] (RW)
 *
 * Domain Control enable for this register. [31:30] and [27:24] areas are not
 * controlled by this bit. [31:30] and [27:24] area can be modified by any masters
 * from any domains when Lock bit is not set.
 *
 * Values:
 * - 0 - Disables domain control. All of this register's bits except [31:30] and
 *     [27:24] can be modified by any masters
 * - 1 - Enables domain control. All of this register's bits except [31:30] and
 *     [27:24] can only be modified by the masters from the domains specified in
 *     [27:24] area.
 */
/*@{*/
#define BP_SRC_HSICPHY_RCR_DOM_EN (31U)    /*!< Bit position for SRC_HSICPHY_RCR_DOM_EN. */
#define BM_SRC_HSICPHY_RCR_DOM_EN (0x80000000U) /*!< Bit mask for SRC_HSICPHY_RCR_DOM_EN. */
#define BS_SRC_HSICPHY_RCR_DOM_EN (1U)     /*!< Bit field size in bits for SRC_HSICPHY_RCR_DOM_EN. */

/*! @brief Read current value of the SRC_HSICPHY_RCR_DOM_EN field. */
#define BR_SRC_HSICPHY_RCR_DOM_EN(x) (HW_SRC_HSICPHY_RCR(x).B.DOM_EN)

/*! @brief Format value for bitfield SRC_HSICPHY_RCR_DOM_EN. */
#define BF_SRC_HSICPHY_RCR_DOM_EN(v) ((uint32_t)((uint32_t)(v) << BP_SRC_HSICPHY_RCR_DOM_EN) & BM_SRC_HSICPHY_RCR_DOM_EN)

/*! @brief Set the DOM_EN field to a new value. */
#define BW_SRC_HSICPHY_RCR_DOM_EN(x, v) (HW_SRC_HSICPHY_RCR_WR(x, (HW_SRC_HSICPHY_RCR_RD(x) & ~BM_SRC_HSICPHY_RCR_DOM_EN) | BF_SRC_HSICPHY_RCR_DOM_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_SRC_USBOPHY1_RCR - USB OTG PHY1 Reset Control Register
 ******************************************************************************/

/*!
 * @brief HW_SRC_USBOPHY1_RCR - USB OTG PHY1 Reset Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The USB OTG PHY1 Reset Control Register (SRC_IP_RCR2), contains bits that
 * control the USB OTG PHY1 reset generation.
 */
typedef union _hw_src_usbophy1_rcr
{
    uint32_t U;
    struct _hw_src_usbophy1_rcr_bitfields
    {
        uint32_t USBPHY1_POR : 1;      /*!< [0]  */
        uint32_t USBPHY1_PORT_RST : 1; /*!< [1]  */
        uint32_t RESERVED0 : 22;       /*!< [23:2]  */
        uint32_t DOMAIN0 : 1;          /*!< [24]  */
        uint32_t DOMAIN1 : 1;          /*!< [25]  */
        uint32_t DOMAIN2 : 1;          /*!< [26]  */
        uint32_t DOMAIN3 : 1;          /*!< [27]  */
        uint32_t RESERVED1 : 2;        /*!< [29:28]  */
        uint32_t LOCK : 1;             /*!< [30]  */
        uint32_t DOM_EN : 1;           /*!< [31]  */
    } B;
} hw_src_usbophy1_rcr_t;

/*!
 * @name Constants and macros for entire SRC_USBOPHY1_RCR register
 */
/*@{*/
#define HW_SRC_USBOPHY1_RCR_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_SRC_USBOPHY1_RCR(x)   (*(__IO hw_src_usbophy1_rcr_t *) HW_SRC_USBOPHY1_RCR_ADDR(x))
#define HW_SRC_USBOPHY1_RCR_RD(x) (HW_SRC_USBOPHY1_RCR(x).U)
#define HW_SRC_USBOPHY1_RCR_WR(x, v) (HW_SRC_USBOPHY1_RCR(x).U = (v))
#define HW_SRC_USBOPHY1_RCR_SET(x, v) (HW_SRC_USBOPHY1_RCR_WR(x, HW_SRC_USBOPHY1_RCR_RD(x) |  (v)))
#define HW_SRC_USBOPHY1_RCR_CLR(x, v) (HW_SRC_USBOPHY1_RCR_WR(x, HW_SRC_USBOPHY1_RCR_RD(x) & ~(v)))
#define HW_SRC_USBOPHY1_RCR_TOG(x, v) (HW_SRC_USBOPHY1_RCR_WR(x, HW_SRC_USBOPHY1_RCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_USBOPHY1_RCR bitfields
 */

/*!
 * @name Register SRC_USBOPHY1_RCR, field USBPHY1_POR[0] (RW)
 *
 * USB OTG PHY 1 PORThis is a self clearing bit. Once it is set to 1, the reset
 * process will begin, and once it finishes, this bit will be self cleared.
 * Software can determine that the reset has finished once this bit is cleared.
 * Software can also configure SRC to generate interrupt once the software has
 * finished. Please refer to SRC_SISR register for details
 *
 * Values:
 * - 0 - De-assert USB OTG PHY1 reset
 * - 1 - Assert USB OTG PHY1 reset
 */
/*@{*/
#define BP_SRC_USBOPHY1_RCR_USBPHY1_POR (0U) /*!< Bit position for SRC_USBOPHY1_RCR_USBPHY1_POR. */
#define BM_SRC_USBOPHY1_RCR_USBPHY1_POR (0x00000001U) /*!< Bit mask for SRC_USBOPHY1_RCR_USBPHY1_POR. */
#define BS_SRC_USBOPHY1_RCR_USBPHY1_POR (1U) /*!< Bit field size in bits for SRC_USBOPHY1_RCR_USBPHY1_POR. */

/*! @brief Read current value of the SRC_USBOPHY1_RCR_USBPHY1_POR field. */
#define BR_SRC_USBOPHY1_RCR_USBPHY1_POR(x) (HW_SRC_USBOPHY1_RCR(x).B.USBPHY1_POR)

/*! @brief Format value for bitfield SRC_USBOPHY1_RCR_USBPHY1_POR. */
#define BF_SRC_USBOPHY1_RCR_USBPHY1_POR(v) ((uint32_t)((uint32_t)(v) << BP_SRC_USBOPHY1_RCR_USBPHY1_POR) & BM_SRC_USBOPHY1_RCR_USBPHY1_POR)

/*! @brief Set the USBPHY1_POR field to a new value. */
#define BW_SRC_USBOPHY1_RCR_USBPHY1_POR(x, v) (HW_SRC_USBOPHY1_RCR_WR(x, (HW_SRC_USBOPHY1_RCR_RD(x) & ~BM_SRC_USBOPHY1_RCR_USBPHY1_POR) | BF_SRC_USBOPHY1_RCR_USBPHY1_POR(v)))
/*@}*/

/*!
 * @name Register SRC_USBOPHY1_RCR, field USBPHY1_PORT_RST[1] (RW)
 *
 * USB OTG PHY1 Port Reset
 *
 * Values:
 * - 0 - Do not assert USB OTG PHY1 Port Reset
 * - 1 - Assert USB OTG PHY1 Port Reset
 */
/*@{*/
#define BP_SRC_USBOPHY1_RCR_USBPHY1_PORT_RST (1U) /*!< Bit position for SRC_USBOPHY1_RCR_USBPHY1_PORT_RST. */
#define BM_SRC_USBOPHY1_RCR_USBPHY1_PORT_RST (0x00000002U) /*!< Bit mask for SRC_USBOPHY1_RCR_USBPHY1_PORT_RST. */
#define BS_SRC_USBOPHY1_RCR_USBPHY1_PORT_RST (1U) /*!< Bit field size in bits for SRC_USBOPHY1_RCR_USBPHY1_PORT_RST. */

/*! @brief Read current value of the SRC_USBOPHY1_RCR_USBPHY1_PORT_RST field. */
#define BR_SRC_USBOPHY1_RCR_USBPHY1_PORT_RST(x) (HW_SRC_USBOPHY1_RCR(x).B.USBPHY1_PORT_RST)

/*! @brief Format value for bitfield SRC_USBOPHY1_RCR_USBPHY1_PORT_RST. */
#define BF_SRC_USBOPHY1_RCR_USBPHY1_PORT_RST(v) ((uint32_t)((uint32_t)(v) << BP_SRC_USBOPHY1_RCR_USBPHY1_PORT_RST) & BM_SRC_USBOPHY1_RCR_USBPHY1_PORT_RST)

/*! @brief Set the USBPHY1_PORT_RST field to a new value. */
#define BW_SRC_USBOPHY1_RCR_USBPHY1_PORT_RST(x, v) (HW_SRC_USBOPHY1_RCR_WR(x, (HW_SRC_USBOPHY1_RCR_RD(x) & ~BM_SRC_USBOPHY1_RCR_USBPHY1_PORT_RST) | BF_SRC_USBOPHY1_RCR_USBPHY1_PORT_RST(v)))
/*@}*/

/*!
 * @name Register SRC_USBOPHY1_RCR, field DOMAIN0[24] (RW)
 *
 * Domain0 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain0. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain0. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_USBOPHY1_RCR_DOMAIN0 (24U)  /*!< Bit position for SRC_USBOPHY1_RCR_DOMAIN0. */
#define BM_SRC_USBOPHY1_RCR_DOMAIN0 (0x01000000U) /*!< Bit mask for SRC_USBOPHY1_RCR_DOMAIN0. */
#define BS_SRC_USBOPHY1_RCR_DOMAIN0 (1U)   /*!< Bit field size in bits for SRC_USBOPHY1_RCR_DOMAIN0. */

/*! @brief Read current value of the SRC_USBOPHY1_RCR_DOMAIN0 field. */
#define BR_SRC_USBOPHY1_RCR_DOMAIN0(x) (HW_SRC_USBOPHY1_RCR(x).B.DOMAIN0)

/*! @brief Format value for bitfield SRC_USBOPHY1_RCR_DOMAIN0. */
#define BF_SRC_USBOPHY1_RCR_DOMAIN0(v) ((uint32_t)((uint32_t)(v) << BP_SRC_USBOPHY1_RCR_DOMAIN0) & BM_SRC_USBOPHY1_RCR_DOMAIN0)

/*! @brief Set the DOMAIN0 field to a new value. */
#define BW_SRC_USBOPHY1_RCR_DOMAIN0(x, v) (HW_SRC_USBOPHY1_RCR_WR(x, (HW_SRC_USBOPHY1_RCR_RD(x) & ~BM_SRC_USBOPHY1_RCR_DOMAIN0) | BF_SRC_USBOPHY1_RCR_DOMAIN0(v)))
/*@}*/

/*!
 * @name Register SRC_USBOPHY1_RCR, field DOMAIN1[25] (RW)
 *
 * Domain1 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain1. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain1. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_USBOPHY1_RCR_DOMAIN1 (25U)  /*!< Bit position for SRC_USBOPHY1_RCR_DOMAIN1. */
#define BM_SRC_USBOPHY1_RCR_DOMAIN1 (0x02000000U) /*!< Bit mask for SRC_USBOPHY1_RCR_DOMAIN1. */
#define BS_SRC_USBOPHY1_RCR_DOMAIN1 (1U)   /*!< Bit field size in bits for SRC_USBOPHY1_RCR_DOMAIN1. */

/*! @brief Read current value of the SRC_USBOPHY1_RCR_DOMAIN1 field. */
#define BR_SRC_USBOPHY1_RCR_DOMAIN1(x) (HW_SRC_USBOPHY1_RCR(x).B.DOMAIN1)

/*! @brief Format value for bitfield SRC_USBOPHY1_RCR_DOMAIN1. */
#define BF_SRC_USBOPHY1_RCR_DOMAIN1(v) ((uint32_t)((uint32_t)(v) << BP_SRC_USBOPHY1_RCR_DOMAIN1) & BM_SRC_USBOPHY1_RCR_DOMAIN1)

/*! @brief Set the DOMAIN1 field to a new value. */
#define BW_SRC_USBOPHY1_RCR_DOMAIN1(x, v) (HW_SRC_USBOPHY1_RCR_WR(x, (HW_SRC_USBOPHY1_RCR_RD(x) & ~BM_SRC_USBOPHY1_RCR_DOMAIN1) | BF_SRC_USBOPHY1_RCR_DOMAIN1(v)))
/*@}*/

/*!
 * @name Register SRC_USBOPHY1_RCR, field DOMAIN2[26] (RW)
 *
 * Domain2 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain2. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain2. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_USBOPHY1_RCR_DOMAIN2 (26U)  /*!< Bit position for SRC_USBOPHY1_RCR_DOMAIN2. */
#define BM_SRC_USBOPHY1_RCR_DOMAIN2 (0x04000000U) /*!< Bit mask for SRC_USBOPHY1_RCR_DOMAIN2. */
#define BS_SRC_USBOPHY1_RCR_DOMAIN2 (1U)   /*!< Bit field size in bits for SRC_USBOPHY1_RCR_DOMAIN2. */

/*! @brief Read current value of the SRC_USBOPHY1_RCR_DOMAIN2 field. */
#define BR_SRC_USBOPHY1_RCR_DOMAIN2(x) (HW_SRC_USBOPHY1_RCR(x).B.DOMAIN2)

/*! @brief Format value for bitfield SRC_USBOPHY1_RCR_DOMAIN2. */
#define BF_SRC_USBOPHY1_RCR_DOMAIN2(v) ((uint32_t)((uint32_t)(v) << BP_SRC_USBOPHY1_RCR_DOMAIN2) & BM_SRC_USBOPHY1_RCR_DOMAIN2)

/*! @brief Set the DOMAIN2 field to a new value. */
#define BW_SRC_USBOPHY1_RCR_DOMAIN2(x, v) (HW_SRC_USBOPHY1_RCR_WR(x, (HW_SRC_USBOPHY1_RCR_RD(x) & ~BM_SRC_USBOPHY1_RCR_DOMAIN2) | BF_SRC_USBOPHY1_RCR_DOMAIN2(v)))
/*@}*/

/*!
 * @name Register SRC_USBOPHY1_RCR, field DOMAIN3[27] (RW)
 *
 * Domain3 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain3. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain3. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_USBOPHY1_RCR_DOMAIN3 (27U)  /*!< Bit position for SRC_USBOPHY1_RCR_DOMAIN3. */
#define BM_SRC_USBOPHY1_RCR_DOMAIN3 (0x08000000U) /*!< Bit mask for SRC_USBOPHY1_RCR_DOMAIN3. */
#define BS_SRC_USBOPHY1_RCR_DOMAIN3 (1U)   /*!< Bit field size in bits for SRC_USBOPHY1_RCR_DOMAIN3. */

/*! @brief Read current value of the SRC_USBOPHY1_RCR_DOMAIN3 field. */
#define BR_SRC_USBOPHY1_RCR_DOMAIN3(x) (HW_SRC_USBOPHY1_RCR(x).B.DOMAIN3)

/*! @brief Format value for bitfield SRC_USBOPHY1_RCR_DOMAIN3. */
#define BF_SRC_USBOPHY1_RCR_DOMAIN3(v) ((uint32_t)((uint32_t)(v) << BP_SRC_USBOPHY1_RCR_DOMAIN3) & BM_SRC_USBOPHY1_RCR_DOMAIN3)

/*! @brief Set the DOMAIN3 field to a new value. */
#define BW_SRC_USBOPHY1_RCR_DOMAIN3(x, v) (HW_SRC_USBOPHY1_RCR_WR(x, (HW_SRC_USBOPHY1_RCR_RD(x) & ~BM_SRC_USBOPHY1_RCR_DOMAIN3) | BF_SRC_USBOPHY1_RCR_DOMAIN3(v)))
/*@}*/

/*!
 * @name Register SRC_USBOPHY1_RCR, field LOCK[30] (RW)
 *
 * Domain control bits lock Lock bit is a write-once register, once it is set to
 * 1, it can't be write to 0
 *
 * Values:
 * - 0 - [31] and [27:24] bits can be modified
 * - 1 - [31] and [27:24] bits cannot be modified
 */
/*@{*/
#define BP_SRC_USBOPHY1_RCR_LOCK (30U)     /*!< Bit position for SRC_USBOPHY1_RCR_LOCK. */
#define BM_SRC_USBOPHY1_RCR_LOCK (0x40000000U) /*!< Bit mask for SRC_USBOPHY1_RCR_LOCK. */
#define BS_SRC_USBOPHY1_RCR_LOCK (1U)      /*!< Bit field size in bits for SRC_USBOPHY1_RCR_LOCK. */

/*! @brief Read current value of the SRC_USBOPHY1_RCR_LOCK field. */
#define BR_SRC_USBOPHY1_RCR_LOCK(x) (HW_SRC_USBOPHY1_RCR(x).B.LOCK)

/*! @brief Format value for bitfield SRC_USBOPHY1_RCR_LOCK. */
#define BF_SRC_USBOPHY1_RCR_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_SRC_USBOPHY1_RCR_LOCK) & BM_SRC_USBOPHY1_RCR_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_SRC_USBOPHY1_RCR_LOCK(x, v) (HW_SRC_USBOPHY1_RCR_WR(x, (HW_SRC_USBOPHY1_RCR_RD(x) & ~BM_SRC_USBOPHY1_RCR_LOCK) | BF_SRC_USBOPHY1_RCR_LOCK(v)))
/*@}*/

/*!
 * @name Register SRC_USBOPHY1_RCR, field DOM_EN[31] (RW)
 *
 * Domain Control enable for this register. [31:30] and [27:24] areas are not
 * controlled by this bit. [31:30] and [27:24] area can be modified by any masters
 * from any domains when Lock bit is not set.
 *
 * Values:
 * - 0 - Disables domain control. All of this register's bits except [31:30] and
 *     [27:24] can be modified by any masters
 * - 1 - Enables domain control. All of this register's bits except [31:30] and
 *     [27:24] can only be modified by the masters from the domains specified in
 *     [27:24] area.
 */
/*@{*/
#define BP_SRC_USBOPHY1_RCR_DOM_EN (31U)   /*!< Bit position for SRC_USBOPHY1_RCR_DOM_EN. */
#define BM_SRC_USBOPHY1_RCR_DOM_EN (0x80000000U) /*!< Bit mask for SRC_USBOPHY1_RCR_DOM_EN. */
#define BS_SRC_USBOPHY1_RCR_DOM_EN (1U)    /*!< Bit field size in bits for SRC_USBOPHY1_RCR_DOM_EN. */

/*! @brief Read current value of the SRC_USBOPHY1_RCR_DOM_EN field. */
#define BR_SRC_USBOPHY1_RCR_DOM_EN(x) (HW_SRC_USBOPHY1_RCR(x).B.DOM_EN)

/*! @brief Format value for bitfield SRC_USBOPHY1_RCR_DOM_EN. */
#define BF_SRC_USBOPHY1_RCR_DOM_EN(v) ((uint32_t)((uint32_t)(v) << BP_SRC_USBOPHY1_RCR_DOM_EN) & BM_SRC_USBOPHY1_RCR_DOM_EN)

/*! @brief Set the DOM_EN field to a new value. */
#define BW_SRC_USBOPHY1_RCR_DOM_EN(x, v) (HW_SRC_USBOPHY1_RCR_WR(x, (HW_SRC_USBOPHY1_RCR_RD(x) & ~BM_SRC_USBOPHY1_RCR_DOM_EN) | BF_SRC_USBOPHY1_RCR_DOM_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_SRC_USBOPHY2_RCR - USB OTG PHY2 Reset Control Register
 ******************************************************************************/

/*!
 * @brief HW_SRC_USBOPHY2_RCR - USB OTG PHY2 Reset Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The USB OTG PHY2 Reset Control Register (SRC_IP_RCR2), contains bits that
 * control the USB OTG PHY2 reset generation.
 */
typedef union _hw_src_usbophy2_rcr
{
    uint32_t U;
    struct _hw_src_usbophy2_rcr_bitfields
    {
        uint32_t USBPHY2_POR : 1;      /*!< [0]  */
        uint32_t USBPHY2_PORT_RST : 1; /*!< [1]  */
        uint32_t RESERVED0 : 22;       /*!< [23:2]  */
        uint32_t DOMAIN0 : 1;          /*!< [24]  */
        uint32_t DOMAIN1 : 1;          /*!< [25]  */
        uint32_t DOMAIN2 : 1;          /*!< [26]  */
        uint32_t DOMAIN3 : 1;          /*!< [27]  */
        uint32_t RESERVED1 : 2;        /*!< [29:28]  */
        uint32_t LOCK : 1;             /*!< [30]  */
        uint32_t DOM_EN : 1;           /*!< [31]  */
    } B;
} hw_src_usbophy2_rcr_t;

/*!
 * @name Constants and macros for entire SRC_USBOPHY2_RCR register
 */
/*@{*/
#define HW_SRC_USBOPHY2_RCR_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_SRC_USBOPHY2_RCR(x)   (*(__IO hw_src_usbophy2_rcr_t *) HW_SRC_USBOPHY2_RCR_ADDR(x))
#define HW_SRC_USBOPHY2_RCR_RD(x) (HW_SRC_USBOPHY2_RCR(x).U)
#define HW_SRC_USBOPHY2_RCR_WR(x, v) (HW_SRC_USBOPHY2_RCR(x).U = (v))
#define HW_SRC_USBOPHY2_RCR_SET(x, v) (HW_SRC_USBOPHY2_RCR_WR(x, HW_SRC_USBOPHY2_RCR_RD(x) |  (v)))
#define HW_SRC_USBOPHY2_RCR_CLR(x, v) (HW_SRC_USBOPHY2_RCR_WR(x, HW_SRC_USBOPHY2_RCR_RD(x) & ~(v)))
#define HW_SRC_USBOPHY2_RCR_TOG(x, v) (HW_SRC_USBOPHY2_RCR_WR(x, HW_SRC_USBOPHY2_RCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_USBOPHY2_RCR bitfields
 */

/*!
 * @name Register SRC_USBOPHY2_RCR, field USBPHY2_POR[0] (RW)
 *
 * USB OTG PHY 2 PORThis is a self clearing bit. Once it is set to 1, the reset
 * process will begin, and once it finishes, this bit will be self cleared.
 * Software can determine that the reset has finished once this bit is cleared.
 * Software can also configure SRC to generate interrupt once the software has
 * finished. Please refer to SRC_SISR register for details
 *
 * Values:
 * - 0 - De-assert USB OTG PHY2 reset
 * - 1 - Assert USB OTG PHY2 reset
 */
/*@{*/
#define BP_SRC_USBOPHY2_RCR_USBPHY2_POR (0U) /*!< Bit position for SRC_USBOPHY2_RCR_USBPHY2_POR. */
#define BM_SRC_USBOPHY2_RCR_USBPHY2_POR (0x00000001U) /*!< Bit mask for SRC_USBOPHY2_RCR_USBPHY2_POR. */
#define BS_SRC_USBOPHY2_RCR_USBPHY2_POR (1U) /*!< Bit field size in bits for SRC_USBOPHY2_RCR_USBPHY2_POR. */

/*! @brief Read current value of the SRC_USBOPHY2_RCR_USBPHY2_POR field. */
#define BR_SRC_USBOPHY2_RCR_USBPHY2_POR(x) (HW_SRC_USBOPHY2_RCR(x).B.USBPHY2_POR)

/*! @brief Format value for bitfield SRC_USBOPHY2_RCR_USBPHY2_POR. */
#define BF_SRC_USBOPHY2_RCR_USBPHY2_POR(v) ((uint32_t)((uint32_t)(v) << BP_SRC_USBOPHY2_RCR_USBPHY2_POR) & BM_SRC_USBOPHY2_RCR_USBPHY2_POR)

/*! @brief Set the USBPHY2_POR field to a new value. */
#define BW_SRC_USBOPHY2_RCR_USBPHY2_POR(x, v) (HW_SRC_USBOPHY2_RCR_WR(x, (HW_SRC_USBOPHY2_RCR_RD(x) & ~BM_SRC_USBOPHY2_RCR_USBPHY2_POR) | BF_SRC_USBOPHY2_RCR_USBPHY2_POR(v)))
/*@}*/

/*!
 * @name Register SRC_USBOPHY2_RCR, field USBPHY2_PORT_RST[1] (RW)
 *
 * USB OTG PHY2 Port Reset
 *
 * Values:
 * - 0 - Do not assert USB OTG PHY2 Port Reset
 * - 1 - Assert USB OTG PHY2 Port Reset
 */
/*@{*/
#define BP_SRC_USBOPHY2_RCR_USBPHY2_PORT_RST (1U) /*!< Bit position for SRC_USBOPHY2_RCR_USBPHY2_PORT_RST. */
#define BM_SRC_USBOPHY2_RCR_USBPHY2_PORT_RST (0x00000002U) /*!< Bit mask for SRC_USBOPHY2_RCR_USBPHY2_PORT_RST. */
#define BS_SRC_USBOPHY2_RCR_USBPHY2_PORT_RST (1U) /*!< Bit field size in bits for SRC_USBOPHY2_RCR_USBPHY2_PORT_RST. */

/*! @brief Read current value of the SRC_USBOPHY2_RCR_USBPHY2_PORT_RST field. */
#define BR_SRC_USBOPHY2_RCR_USBPHY2_PORT_RST(x) (HW_SRC_USBOPHY2_RCR(x).B.USBPHY2_PORT_RST)

/*! @brief Format value for bitfield SRC_USBOPHY2_RCR_USBPHY2_PORT_RST. */
#define BF_SRC_USBOPHY2_RCR_USBPHY2_PORT_RST(v) ((uint32_t)((uint32_t)(v) << BP_SRC_USBOPHY2_RCR_USBPHY2_PORT_RST) & BM_SRC_USBOPHY2_RCR_USBPHY2_PORT_RST)

/*! @brief Set the USBPHY2_PORT_RST field to a new value. */
#define BW_SRC_USBOPHY2_RCR_USBPHY2_PORT_RST(x, v) (HW_SRC_USBOPHY2_RCR_WR(x, (HW_SRC_USBOPHY2_RCR_RD(x) & ~BM_SRC_USBOPHY2_RCR_USBPHY2_PORT_RST) | BF_SRC_USBOPHY2_RCR_USBPHY2_PORT_RST(v)))
/*@}*/

/*!
 * @name Register SRC_USBOPHY2_RCR, field DOMAIN0[24] (RW)
 *
 * Domain0 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain0. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain0. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_USBOPHY2_RCR_DOMAIN0 (24U)  /*!< Bit position for SRC_USBOPHY2_RCR_DOMAIN0. */
#define BM_SRC_USBOPHY2_RCR_DOMAIN0 (0x01000000U) /*!< Bit mask for SRC_USBOPHY2_RCR_DOMAIN0. */
#define BS_SRC_USBOPHY2_RCR_DOMAIN0 (1U)   /*!< Bit field size in bits for SRC_USBOPHY2_RCR_DOMAIN0. */

/*! @brief Read current value of the SRC_USBOPHY2_RCR_DOMAIN0 field. */
#define BR_SRC_USBOPHY2_RCR_DOMAIN0(x) (HW_SRC_USBOPHY2_RCR(x).B.DOMAIN0)

/*! @brief Format value for bitfield SRC_USBOPHY2_RCR_DOMAIN0. */
#define BF_SRC_USBOPHY2_RCR_DOMAIN0(v) ((uint32_t)((uint32_t)(v) << BP_SRC_USBOPHY2_RCR_DOMAIN0) & BM_SRC_USBOPHY2_RCR_DOMAIN0)

/*! @brief Set the DOMAIN0 field to a new value. */
#define BW_SRC_USBOPHY2_RCR_DOMAIN0(x, v) (HW_SRC_USBOPHY2_RCR_WR(x, (HW_SRC_USBOPHY2_RCR_RD(x) & ~BM_SRC_USBOPHY2_RCR_DOMAIN0) | BF_SRC_USBOPHY2_RCR_DOMAIN0(v)))
/*@}*/

/*!
 * @name Register SRC_USBOPHY2_RCR, field DOMAIN1[25] (RW)
 *
 * Domain1 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain1. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain1. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_USBOPHY2_RCR_DOMAIN1 (25U)  /*!< Bit position for SRC_USBOPHY2_RCR_DOMAIN1. */
#define BM_SRC_USBOPHY2_RCR_DOMAIN1 (0x02000000U) /*!< Bit mask for SRC_USBOPHY2_RCR_DOMAIN1. */
#define BS_SRC_USBOPHY2_RCR_DOMAIN1 (1U)   /*!< Bit field size in bits for SRC_USBOPHY2_RCR_DOMAIN1. */

/*! @brief Read current value of the SRC_USBOPHY2_RCR_DOMAIN1 field. */
#define BR_SRC_USBOPHY2_RCR_DOMAIN1(x) (HW_SRC_USBOPHY2_RCR(x).B.DOMAIN1)

/*! @brief Format value for bitfield SRC_USBOPHY2_RCR_DOMAIN1. */
#define BF_SRC_USBOPHY2_RCR_DOMAIN1(v) ((uint32_t)((uint32_t)(v) << BP_SRC_USBOPHY2_RCR_DOMAIN1) & BM_SRC_USBOPHY2_RCR_DOMAIN1)

/*! @brief Set the DOMAIN1 field to a new value. */
#define BW_SRC_USBOPHY2_RCR_DOMAIN1(x, v) (HW_SRC_USBOPHY2_RCR_WR(x, (HW_SRC_USBOPHY2_RCR_RD(x) & ~BM_SRC_USBOPHY2_RCR_DOMAIN1) | BF_SRC_USBOPHY2_RCR_DOMAIN1(v)))
/*@}*/

/*!
 * @name Register SRC_USBOPHY2_RCR, field DOMAIN2[26] (RW)
 *
 * Domain2 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain2. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain2. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_USBOPHY2_RCR_DOMAIN2 (26U)  /*!< Bit position for SRC_USBOPHY2_RCR_DOMAIN2. */
#define BM_SRC_USBOPHY2_RCR_DOMAIN2 (0x04000000U) /*!< Bit mask for SRC_USBOPHY2_RCR_DOMAIN2. */
#define BS_SRC_USBOPHY2_RCR_DOMAIN2 (1U)   /*!< Bit field size in bits for SRC_USBOPHY2_RCR_DOMAIN2. */

/*! @brief Read current value of the SRC_USBOPHY2_RCR_DOMAIN2 field. */
#define BR_SRC_USBOPHY2_RCR_DOMAIN2(x) (HW_SRC_USBOPHY2_RCR(x).B.DOMAIN2)

/*! @brief Format value for bitfield SRC_USBOPHY2_RCR_DOMAIN2. */
#define BF_SRC_USBOPHY2_RCR_DOMAIN2(v) ((uint32_t)((uint32_t)(v) << BP_SRC_USBOPHY2_RCR_DOMAIN2) & BM_SRC_USBOPHY2_RCR_DOMAIN2)

/*! @brief Set the DOMAIN2 field to a new value. */
#define BW_SRC_USBOPHY2_RCR_DOMAIN2(x, v) (HW_SRC_USBOPHY2_RCR_WR(x, (HW_SRC_USBOPHY2_RCR_RD(x) & ~BM_SRC_USBOPHY2_RCR_DOMAIN2) | BF_SRC_USBOPHY2_RCR_DOMAIN2(v)))
/*@}*/

/*!
 * @name Register SRC_USBOPHY2_RCR, field DOMAIN3[27] (RW)
 *
 * Domain3 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain3. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain3. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_USBOPHY2_RCR_DOMAIN3 (27U)  /*!< Bit position for SRC_USBOPHY2_RCR_DOMAIN3. */
#define BM_SRC_USBOPHY2_RCR_DOMAIN3 (0x08000000U) /*!< Bit mask for SRC_USBOPHY2_RCR_DOMAIN3. */
#define BS_SRC_USBOPHY2_RCR_DOMAIN3 (1U)   /*!< Bit field size in bits for SRC_USBOPHY2_RCR_DOMAIN3. */

/*! @brief Read current value of the SRC_USBOPHY2_RCR_DOMAIN3 field. */
#define BR_SRC_USBOPHY2_RCR_DOMAIN3(x) (HW_SRC_USBOPHY2_RCR(x).B.DOMAIN3)

/*! @brief Format value for bitfield SRC_USBOPHY2_RCR_DOMAIN3. */
#define BF_SRC_USBOPHY2_RCR_DOMAIN3(v) ((uint32_t)((uint32_t)(v) << BP_SRC_USBOPHY2_RCR_DOMAIN3) & BM_SRC_USBOPHY2_RCR_DOMAIN3)

/*! @brief Set the DOMAIN3 field to a new value. */
#define BW_SRC_USBOPHY2_RCR_DOMAIN3(x, v) (HW_SRC_USBOPHY2_RCR_WR(x, (HW_SRC_USBOPHY2_RCR_RD(x) & ~BM_SRC_USBOPHY2_RCR_DOMAIN3) | BF_SRC_USBOPHY2_RCR_DOMAIN3(v)))
/*@}*/

/*!
 * @name Register SRC_USBOPHY2_RCR, field LOCK[30] (RW)
 *
 * Domain control bits lock Lock bit is a write-once register, once it is set to
 * 1, it can't be write to 0
 *
 * Values:
 * - 0 - [31] and [27:24] bits can be modified
 * - 1 - [31] and [27:24] bits cannot be modified
 */
/*@{*/
#define BP_SRC_USBOPHY2_RCR_LOCK (30U)     /*!< Bit position for SRC_USBOPHY2_RCR_LOCK. */
#define BM_SRC_USBOPHY2_RCR_LOCK (0x40000000U) /*!< Bit mask for SRC_USBOPHY2_RCR_LOCK. */
#define BS_SRC_USBOPHY2_RCR_LOCK (1U)      /*!< Bit field size in bits for SRC_USBOPHY2_RCR_LOCK. */

/*! @brief Read current value of the SRC_USBOPHY2_RCR_LOCK field. */
#define BR_SRC_USBOPHY2_RCR_LOCK(x) (HW_SRC_USBOPHY2_RCR(x).B.LOCK)

/*! @brief Format value for bitfield SRC_USBOPHY2_RCR_LOCK. */
#define BF_SRC_USBOPHY2_RCR_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_SRC_USBOPHY2_RCR_LOCK) & BM_SRC_USBOPHY2_RCR_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_SRC_USBOPHY2_RCR_LOCK(x, v) (HW_SRC_USBOPHY2_RCR_WR(x, (HW_SRC_USBOPHY2_RCR_RD(x) & ~BM_SRC_USBOPHY2_RCR_LOCK) | BF_SRC_USBOPHY2_RCR_LOCK(v)))
/*@}*/

/*!
 * @name Register SRC_USBOPHY2_RCR, field DOM_EN[31] (RW)
 *
 * Domain Control enable for this register. [31:30] and [27:24] areas are not
 * controlled by this bit. [31:30] and [27:24] area can be modified by any masters
 * from any domains when Lock bit is not set.
 *
 * Values:
 * - 0 - Disables domain control. All of this register's bits except [31:30] and
 *     [27:24] can be modified by any masters
 * - 1 - Enables domain control. All of this register's bits except [31:30] and
 *     [27:24] can only be modified by the masters from the domains specified in
 *     [27:24] area.
 */
/*@{*/
#define BP_SRC_USBOPHY2_RCR_DOM_EN (31U)   /*!< Bit position for SRC_USBOPHY2_RCR_DOM_EN. */
#define BM_SRC_USBOPHY2_RCR_DOM_EN (0x80000000U) /*!< Bit mask for SRC_USBOPHY2_RCR_DOM_EN. */
#define BS_SRC_USBOPHY2_RCR_DOM_EN (1U)    /*!< Bit field size in bits for SRC_USBOPHY2_RCR_DOM_EN. */

/*! @brief Read current value of the SRC_USBOPHY2_RCR_DOM_EN field. */
#define BR_SRC_USBOPHY2_RCR_DOM_EN(x) (HW_SRC_USBOPHY2_RCR(x).B.DOM_EN)

/*! @brief Format value for bitfield SRC_USBOPHY2_RCR_DOM_EN. */
#define BF_SRC_USBOPHY2_RCR_DOM_EN(v) ((uint32_t)((uint32_t)(v) << BP_SRC_USBOPHY2_RCR_DOM_EN) & BM_SRC_USBOPHY2_RCR_DOM_EN)

/*! @brief Set the DOM_EN field to a new value. */
#define BW_SRC_USBOPHY2_RCR_DOM_EN(x, v) (HW_SRC_USBOPHY2_RCR_WR(x, (HW_SRC_USBOPHY2_RCR_RD(x) & ~BM_SRC_USBOPHY2_RCR_DOM_EN) | BF_SRC_USBOPHY2_RCR_DOM_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_SRC_MIPIPHY_RCR - MIPI PHY Reset Control Register
 ******************************************************************************/

/*!
 * @brief HW_SRC_MIPIPHY_RCR - MIPI PHY Reset Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The MIPI PHY Reset Control Register (SRC_MIPIPHY_RCR), contains bits that
 * control the MIPI PHYreset generation.
 */
typedef union _hw_src_mipiphy_rcr
{
    uint32_t U;
    struct _hw_src_mipiphy_rcr_bitfields
    {
        uint32_t RESERVED0 : 1;        /*!< [0]  */
        uint32_t MIPI_PHY_MRST : 1;    /*!< [1]  */
        uint32_t MIPI_PHY_SRST : 1;    /*!< [2]  */
        uint32_t RESERVED1 : 21;       /*!< [23:3]  */
        uint32_t DOMAIN0 : 1;          /*!< [24]  */
        uint32_t DOMAIN1 : 1;          /*!< [25]  */
        uint32_t DOMAIN2 : 1;          /*!< [26]  */
        uint32_t DOMAIN3 : 1;          /*!< [27]  */
        uint32_t RESERVED2 : 2;        /*!< [29:28]  */
        uint32_t LOCK : 1;             /*!< [30]  */
        uint32_t DOM_EN : 1;           /*!< [31]  */
    } B;
} hw_src_mipiphy_rcr_t;

/*!
 * @name Constants and macros for entire SRC_MIPIPHY_RCR register
 */
/*@{*/
#define HW_SRC_MIPIPHY_RCR_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_SRC_MIPIPHY_RCR(x)    (*(__IO hw_src_mipiphy_rcr_t *) HW_SRC_MIPIPHY_RCR_ADDR(x))
#define HW_SRC_MIPIPHY_RCR_RD(x) (HW_SRC_MIPIPHY_RCR(x).U)
#define HW_SRC_MIPIPHY_RCR_WR(x, v) (HW_SRC_MIPIPHY_RCR(x).U = (v))
#define HW_SRC_MIPIPHY_RCR_SET(x, v) (HW_SRC_MIPIPHY_RCR_WR(x, HW_SRC_MIPIPHY_RCR_RD(x) |  (v)))
#define HW_SRC_MIPIPHY_RCR_CLR(x, v) (HW_SRC_MIPIPHY_RCR_WR(x, HW_SRC_MIPIPHY_RCR_RD(x) & ~(v)))
#define HW_SRC_MIPIPHY_RCR_TOG(x, v) (HW_SRC_MIPIPHY_RCR_WR(x, HW_SRC_MIPIPHY_RCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_MIPIPHY_RCR bitfields
 */

/*!
 * @name Register SRC_MIPIPHY_RCR, field MIPI_PHY_MRST[1] (RW)
 *
 * MIPI PHY Master Reset
 *
 * Values:
 * - 0 - Do not assert MIPI PHY Master reset
 * - 1 - Assert MIPI PHY Master reset
 */
/*@{*/
#define BP_SRC_MIPIPHY_RCR_MIPI_PHY_MRST (1U) /*!< Bit position for SRC_MIPIPHY_RCR_MIPI_PHY_MRST. */
#define BM_SRC_MIPIPHY_RCR_MIPI_PHY_MRST (0x00000002U) /*!< Bit mask for SRC_MIPIPHY_RCR_MIPI_PHY_MRST. */
#define BS_SRC_MIPIPHY_RCR_MIPI_PHY_MRST (1U) /*!< Bit field size in bits for SRC_MIPIPHY_RCR_MIPI_PHY_MRST. */

/*! @brief Read current value of the SRC_MIPIPHY_RCR_MIPI_PHY_MRST field. */
#define BR_SRC_MIPIPHY_RCR_MIPI_PHY_MRST(x) (HW_SRC_MIPIPHY_RCR(x).B.MIPI_PHY_MRST)

/*! @brief Format value for bitfield SRC_MIPIPHY_RCR_MIPI_PHY_MRST. */
#define BF_SRC_MIPIPHY_RCR_MIPI_PHY_MRST(v) ((uint32_t)((uint32_t)(v) << BP_SRC_MIPIPHY_RCR_MIPI_PHY_MRST) & BM_SRC_MIPIPHY_RCR_MIPI_PHY_MRST)

/*! @brief Set the MIPI_PHY_MRST field to a new value. */
#define BW_SRC_MIPIPHY_RCR_MIPI_PHY_MRST(x, v) (HW_SRC_MIPIPHY_RCR_WR(x, (HW_SRC_MIPIPHY_RCR_RD(x) & ~BM_SRC_MIPIPHY_RCR_MIPI_PHY_MRST) | BF_SRC_MIPIPHY_RCR_MIPI_PHY_MRST(v)))
/*@}*/

/*!
 * @name Register SRC_MIPIPHY_RCR, field MIPI_PHY_SRST[2] (RW)
 *
 * MIPI PHY Slave Reset
 *
 * Values:
 * - 0 - Do not assert MIPI PHY Slave reset
 * - 1 - Assert MIPI PHY Slave reset
 */
/*@{*/
#define BP_SRC_MIPIPHY_RCR_MIPI_PHY_SRST (2U) /*!< Bit position for SRC_MIPIPHY_RCR_MIPI_PHY_SRST. */
#define BM_SRC_MIPIPHY_RCR_MIPI_PHY_SRST (0x00000004U) /*!< Bit mask for SRC_MIPIPHY_RCR_MIPI_PHY_SRST. */
#define BS_SRC_MIPIPHY_RCR_MIPI_PHY_SRST (1U) /*!< Bit field size in bits for SRC_MIPIPHY_RCR_MIPI_PHY_SRST. */

/*! @brief Read current value of the SRC_MIPIPHY_RCR_MIPI_PHY_SRST field. */
#define BR_SRC_MIPIPHY_RCR_MIPI_PHY_SRST(x) (HW_SRC_MIPIPHY_RCR(x).B.MIPI_PHY_SRST)

/*! @brief Format value for bitfield SRC_MIPIPHY_RCR_MIPI_PHY_SRST. */
#define BF_SRC_MIPIPHY_RCR_MIPI_PHY_SRST(v) ((uint32_t)((uint32_t)(v) << BP_SRC_MIPIPHY_RCR_MIPI_PHY_SRST) & BM_SRC_MIPIPHY_RCR_MIPI_PHY_SRST)

/*! @brief Set the MIPI_PHY_SRST field to a new value. */
#define BW_SRC_MIPIPHY_RCR_MIPI_PHY_SRST(x, v) (HW_SRC_MIPIPHY_RCR_WR(x, (HW_SRC_MIPIPHY_RCR_RD(x) & ~BM_SRC_MIPIPHY_RCR_MIPI_PHY_SRST) | BF_SRC_MIPIPHY_RCR_MIPI_PHY_SRST(v)))
/*@}*/

/*!
 * @name Register SRC_MIPIPHY_RCR, field DOMAIN0[24] (RW)
 *
 * Domain0 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain0. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain0. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_MIPIPHY_RCR_DOMAIN0 (24U)   /*!< Bit position for SRC_MIPIPHY_RCR_DOMAIN0. */
#define BM_SRC_MIPIPHY_RCR_DOMAIN0 (0x01000000U) /*!< Bit mask for SRC_MIPIPHY_RCR_DOMAIN0. */
#define BS_SRC_MIPIPHY_RCR_DOMAIN0 (1U)    /*!< Bit field size in bits for SRC_MIPIPHY_RCR_DOMAIN0. */

/*! @brief Read current value of the SRC_MIPIPHY_RCR_DOMAIN0 field. */
#define BR_SRC_MIPIPHY_RCR_DOMAIN0(x) (HW_SRC_MIPIPHY_RCR(x).B.DOMAIN0)

/*! @brief Format value for bitfield SRC_MIPIPHY_RCR_DOMAIN0. */
#define BF_SRC_MIPIPHY_RCR_DOMAIN0(v) ((uint32_t)((uint32_t)(v) << BP_SRC_MIPIPHY_RCR_DOMAIN0) & BM_SRC_MIPIPHY_RCR_DOMAIN0)

/*! @brief Set the DOMAIN0 field to a new value. */
#define BW_SRC_MIPIPHY_RCR_DOMAIN0(x, v) (HW_SRC_MIPIPHY_RCR_WR(x, (HW_SRC_MIPIPHY_RCR_RD(x) & ~BM_SRC_MIPIPHY_RCR_DOMAIN0) | BF_SRC_MIPIPHY_RCR_DOMAIN0(v)))
/*@}*/

/*!
 * @name Register SRC_MIPIPHY_RCR, field DOMAIN1[25] (RW)
 *
 * Domain1 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain1. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain1. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_MIPIPHY_RCR_DOMAIN1 (25U)   /*!< Bit position for SRC_MIPIPHY_RCR_DOMAIN1. */
#define BM_SRC_MIPIPHY_RCR_DOMAIN1 (0x02000000U) /*!< Bit mask for SRC_MIPIPHY_RCR_DOMAIN1. */
#define BS_SRC_MIPIPHY_RCR_DOMAIN1 (1U)    /*!< Bit field size in bits for SRC_MIPIPHY_RCR_DOMAIN1. */

/*! @brief Read current value of the SRC_MIPIPHY_RCR_DOMAIN1 field. */
#define BR_SRC_MIPIPHY_RCR_DOMAIN1(x) (HW_SRC_MIPIPHY_RCR(x).B.DOMAIN1)

/*! @brief Format value for bitfield SRC_MIPIPHY_RCR_DOMAIN1. */
#define BF_SRC_MIPIPHY_RCR_DOMAIN1(v) ((uint32_t)((uint32_t)(v) << BP_SRC_MIPIPHY_RCR_DOMAIN1) & BM_SRC_MIPIPHY_RCR_DOMAIN1)

/*! @brief Set the DOMAIN1 field to a new value. */
#define BW_SRC_MIPIPHY_RCR_DOMAIN1(x, v) (HW_SRC_MIPIPHY_RCR_WR(x, (HW_SRC_MIPIPHY_RCR_RD(x) & ~BM_SRC_MIPIPHY_RCR_DOMAIN1) | BF_SRC_MIPIPHY_RCR_DOMAIN1(v)))
/*@}*/

/*!
 * @name Register SRC_MIPIPHY_RCR, field DOMAIN2[26] (RW)
 *
 * Domain2 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain2. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain2. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_MIPIPHY_RCR_DOMAIN2 (26U)   /*!< Bit position for SRC_MIPIPHY_RCR_DOMAIN2. */
#define BM_SRC_MIPIPHY_RCR_DOMAIN2 (0x04000000U) /*!< Bit mask for SRC_MIPIPHY_RCR_DOMAIN2. */
#define BS_SRC_MIPIPHY_RCR_DOMAIN2 (1U)    /*!< Bit field size in bits for SRC_MIPIPHY_RCR_DOMAIN2. */

/*! @brief Read current value of the SRC_MIPIPHY_RCR_DOMAIN2 field. */
#define BR_SRC_MIPIPHY_RCR_DOMAIN2(x) (HW_SRC_MIPIPHY_RCR(x).B.DOMAIN2)

/*! @brief Format value for bitfield SRC_MIPIPHY_RCR_DOMAIN2. */
#define BF_SRC_MIPIPHY_RCR_DOMAIN2(v) ((uint32_t)((uint32_t)(v) << BP_SRC_MIPIPHY_RCR_DOMAIN2) & BM_SRC_MIPIPHY_RCR_DOMAIN2)

/*! @brief Set the DOMAIN2 field to a new value. */
#define BW_SRC_MIPIPHY_RCR_DOMAIN2(x, v) (HW_SRC_MIPIPHY_RCR_WR(x, (HW_SRC_MIPIPHY_RCR_RD(x) & ~BM_SRC_MIPIPHY_RCR_DOMAIN2) | BF_SRC_MIPIPHY_RCR_DOMAIN2(v)))
/*@}*/

/*!
 * @name Register SRC_MIPIPHY_RCR, field DOMAIN3[27] (RW)
 *
 * Domain3 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain3. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain3. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_MIPIPHY_RCR_DOMAIN3 (27U)   /*!< Bit position for SRC_MIPIPHY_RCR_DOMAIN3. */
#define BM_SRC_MIPIPHY_RCR_DOMAIN3 (0x08000000U) /*!< Bit mask for SRC_MIPIPHY_RCR_DOMAIN3. */
#define BS_SRC_MIPIPHY_RCR_DOMAIN3 (1U)    /*!< Bit field size in bits for SRC_MIPIPHY_RCR_DOMAIN3. */

/*! @brief Read current value of the SRC_MIPIPHY_RCR_DOMAIN3 field. */
#define BR_SRC_MIPIPHY_RCR_DOMAIN3(x) (HW_SRC_MIPIPHY_RCR(x).B.DOMAIN3)

/*! @brief Format value for bitfield SRC_MIPIPHY_RCR_DOMAIN3. */
#define BF_SRC_MIPIPHY_RCR_DOMAIN3(v) ((uint32_t)((uint32_t)(v) << BP_SRC_MIPIPHY_RCR_DOMAIN3) & BM_SRC_MIPIPHY_RCR_DOMAIN3)

/*! @brief Set the DOMAIN3 field to a new value. */
#define BW_SRC_MIPIPHY_RCR_DOMAIN3(x, v) (HW_SRC_MIPIPHY_RCR_WR(x, (HW_SRC_MIPIPHY_RCR_RD(x) & ~BM_SRC_MIPIPHY_RCR_DOMAIN3) | BF_SRC_MIPIPHY_RCR_DOMAIN3(v)))
/*@}*/

/*!
 * @name Register SRC_MIPIPHY_RCR, field LOCK[30] (RW)
 *
 * Domain control bits lock Lock bit is a write-once register, once it is set to
 * 1, it can't be write to 0
 *
 * Values:
 * - 0 - [31] and [27:24] bits can be modified
 * - 1 - [31] and [27:24] bits cannot be modified
 */
/*@{*/
#define BP_SRC_MIPIPHY_RCR_LOCK (30U)      /*!< Bit position for SRC_MIPIPHY_RCR_LOCK. */
#define BM_SRC_MIPIPHY_RCR_LOCK (0x40000000U) /*!< Bit mask for SRC_MIPIPHY_RCR_LOCK. */
#define BS_SRC_MIPIPHY_RCR_LOCK (1U)       /*!< Bit field size in bits for SRC_MIPIPHY_RCR_LOCK. */

/*! @brief Read current value of the SRC_MIPIPHY_RCR_LOCK field. */
#define BR_SRC_MIPIPHY_RCR_LOCK(x) (HW_SRC_MIPIPHY_RCR(x).B.LOCK)

/*! @brief Format value for bitfield SRC_MIPIPHY_RCR_LOCK. */
#define BF_SRC_MIPIPHY_RCR_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_SRC_MIPIPHY_RCR_LOCK) & BM_SRC_MIPIPHY_RCR_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_SRC_MIPIPHY_RCR_LOCK(x, v) (HW_SRC_MIPIPHY_RCR_WR(x, (HW_SRC_MIPIPHY_RCR_RD(x) & ~BM_SRC_MIPIPHY_RCR_LOCK) | BF_SRC_MIPIPHY_RCR_LOCK(v)))
/*@}*/

/*!
 * @name Register SRC_MIPIPHY_RCR, field DOM_EN[31] (RW)
 *
 * Domain Control enable for this register. [31:30] and [27:24] areas are not
 * controlled by this bit. [31:30] and [27:24] area can be modified by any masters
 * from any domains when Lock bit is not set.
 *
 * Values:
 * - 0 - Disables domain control. All of this register's bits except [31:30] and
 *     [27:24] can be modified by any masters
 * - 1 - Enables domain control. All of this register's bits except [31:30] and
 *     [27:24] can only be modified by the masters from the domains specified in
 *     [27:24] area.
 */
/*@{*/
#define BP_SRC_MIPIPHY_RCR_DOM_EN (31U)    /*!< Bit position for SRC_MIPIPHY_RCR_DOM_EN. */
#define BM_SRC_MIPIPHY_RCR_DOM_EN (0x80000000U) /*!< Bit mask for SRC_MIPIPHY_RCR_DOM_EN. */
#define BS_SRC_MIPIPHY_RCR_DOM_EN (1U)     /*!< Bit field size in bits for SRC_MIPIPHY_RCR_DOM_EN. */

/*! @brief Read current value of the SRC_MIPIPHY_RCR_DOM_EN field. */
#define BR_SRC_MIPIPHY_RCR_DOM_EN(x) (HW_SRC_MIPIPHY_RCR(x).B.DOM_EN)

/*! @brief Format value for bitfield SRC_MIPIPHY_RCR_DOM_EN. */
#define BF_SRC_MIPIPHY_RCR_DOM_EN(v) ((uint32_t)((uint32_t)(v) << BP_SRC_MIPIPHY_RCR_DOM_EN) & BM_SRC_MIPIPHY_RCR_DOM_EN)

/*! @brief Set the DOM_EN field to a new value. */
#define BW_SRC_MIPIPHY_RCR_DOM_EN(x, v) (HW_SRC_MIPIPHY_RCR_WR(x, (HW_SRC_MIPIPHY_RCR_RD(x) & ~BM_SRC_MIPIPHY_RCR_DOM_EN) | BF_SRC_MIPIPHY_RCR_DOM_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_SRC_PCIEPHY_RCR - PCIE PHY Reset Control Register
 ******************************************************************************/

/*!
 * @brief HW_SRC_PCIEPHY_RCR - PCIE PHY Reset Control Register (RW)
 *
 * Reset value: 0x00000006U
 *
 * The PCIE PHY Control Register (SRC_PCIEPHY_RCR), contains bits that control
 * the PCIE PHY reset generation.
 */
typedef union _hw_src_pciephy_rcr
{
    uint32_t U;
    struct _hw_src_pciephy_rcr_bitfields
    {
        uint32_t RESERVED0 : 1;        /*!< [0]  */
        uint32_t PCIEPHY_G_RST : 1;    /*!< [1]  */
        uint32_t PCIEPHY_BTN : 1;      /*!< [2]  */
        uint32_t PCIEPHY_PERST : 1;    /*!< [3]  */
        uint32_t PCIE_CTRL_APPS_CLK_REQ : 1; /*!< [4]  */
        uint32_t PCIE_CTRL_APPS_RST : 1; /*!< [5]  */
        uint32_t PCIE_CTRL_APPS_EN : 1; /*!< [6]  */
        uint32_t PCIE_CTRL_APPS_READY : 1; /*!< [7]  */
        uint32_t PCIE_CTRL_APPS_ENTER : 1; /*!< [8]  */
        uint32_t PCIE_CTRL_APPS_EXIT : 1; /*!< [9]  */
        uint32_t PCIE_CTRL_APPS_PME : 1; /*!< [10]  */
        uint32_t PCIE_CTRL_APPS_TURNOFF : 1; /*!< [11]  */
        uint32_t PCIE_CTRL_CFG_L1_AUX : 1; /*!< [12]  */
        uint32_t PCIE_CTRL_CFG_L1_MAC : 1; /*!< [13]  */
        uint32_t PCIE_CTRL_SYS_INT : 1; /*!< [14]  */
        uint32_t RESERVED1 : 9;        /*!< [23:15]  */
        uint32_t DOMAIN0 : 1;          /*!< [24]  */
        uint32_t DOMAIN1 : 1;          /*!< [25]  */
        uint32_t DOMAIN2 : 1;          /*!< [26]  */
        uint32_t DOMAIN3 : 1;          /*!< [27]  */
        uint32_t RESERVED2 : 2;        /*!< [29:28]  */
        uint32_t LOCK : 1;             /*!< [30]  */
        uint32_t DOM_EN : 1;           /*!< [31]  */
    } B;
} hw_src_pciephy_rcr_t;

/*!
 * @name Constants and macros for entire SRC_PCIEPHY_RCR register
 */
/*@{*/
#define HW_SRC_PCIEPHY_RCR_ADDR(x) ((uintptr_t)(x) + 0x2CU)

#define HW_SRC_PCIEPHY_RCR(x)    (*(__IO hw_src_pciephy_rcr_t *) HW_SRC_PCIEPHY_RCR_ADDR(x))
#define HW_SRC_PCIEPHY_RCR_RD(x) (HW_SRC_PCIEPHY_RCR(x).U)
#define HW_SRC_PCIEPHY_RCR_WR(x, v) (HW_SRC_PCIEPHY_RCR(x).U = (v))
#define HW_SRC_PCIEPHY_RCR_SET(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, HW_SRC_PCIEPHY_RCR_RD(x) |  (v)))
#define HW_SRC_PCIEPHY_RCR_CLR(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, HW_SRC_PCIEPHY_RCR_RD(x) & ~(v)))
#define HW_SRC_PCIEPHY_RCR_TOG(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, HW_SRC_PCIEPHY_RCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_PCIEPHY_RCR bitfields
 */

/*!
 * @name Register SRC_PCIEPHY_RCR, field PCIEPHY_G_RST[1] (RW)
 *
 * PCIE PHY Global Reset
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_PCIEPHY_G_RST (1U) /*!< Bit position for SRC_PCIEPHY_RCR_PCIEPHY_G_RST. */
#define BM_SRC_PCIEPHY_RCR_PCIEPHY_G_RST (0x00000002U) /*!< Bit mask for SRC_PCIEPHY_RCR_PCIEPHY_G_RST. */
#define BS_SRC_PCIEPHY_RCR_PCIEPHY_G_RST (1U) /*!< Bit field size in bits for SRC_PCIEPHY_RCR_PCIEPHY_G_RST. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_PCIEPHY_G_RST field. */
#define BR_SRC_PCIEPHY_RCR_PCIEPHY_G_RST(x) (HW_SRC_PCIEPHY_RCR(x).B.PCIEPHY_G_RST)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_PCIEPHY_G_RST. */
#define BF_SRC_PCIEPHY_RCR_PCIEPHY_G_RST(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_PCIEPHY_G_RST) & BM_SRC_PCIEPHY_RCR_PCIEPHY_G_RST)

/*! @brief Set the PCIEPHY_G_RST field to a new value. */
#define BW_SRC_PCIEPHY_RCR_PCIEPHY_G_RST(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_PCIEPHY_G_RST) | BF_SRC_PCIEPHY_RCR_PCIEPHY_G_RST(v)))
/*@}*/

/*!
 * @name Register SRC_PCIEPHY_RCR, field PCIEPHY_BTN[2] (RW)
 *
 * PCIE PHY button
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_PCIEPHY_BTN (2U) /*!< Bit position for SRC_PCIEPHY_RCR_PCIEPHY_BTN. */
#define BM_SRC_PCIEPHY_RCR_PCIEPHY_BTN (0x00000004U) /*!< Bit mask for SRC_PCIEPHY_RCR_PCIEPHY_BTN. */
#define BS_SRC_PCIEPHY_RCR_PCIEPHY_BTN (1U) /*!< Bit field size in bits for SRC_PCIEPHY_RCR_PCIEPHY_BTN. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_PCIEPHY_BTN field. */
#define BR_SRC_PCIEPHY_RCR_PCIEPHY_BTN(x) (HW_SRC_PCIEPHY_RCR(x).B.PCIEPHY_BTN)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_PCIEPHY_BTN. */
#define BF_SRC_PCIEPHY_RCR_PCIEPHY_BTN(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_PCIEPHY_BTN) & BM_SRC_PCIEPHY_RCR_PCIEPHY_BTN)

/*! @brief Set the PCIEPHY_BTN field to a new value. */
#define BW_SRC_PCIEPHY_RCR_PCIEPHY_BTN(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_PCIEPHY_BTN) | BF_SRC_PCIEPHY_RCR_PCIEPHY_BTN(v)))
/*@}*/

/*!
 * @name Register SRC_PCIEPHY_RCR, field PCIEPHY_PERST[3] (RW)
 *
 * Pciephy_perst
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_PCIEPHY_PERST (3U) /*!< Bit position for SRC_PCIEPHY_RCR_PCIEPHY_PERST. */
#define BM_SRC_PCIEPHY_RCR_PCIEPHY_PERST (0x00000008U) /*!< Bit mask for SRC_PCIEPHY_RCR_PCIEPHY_PERST. */
#define BS_SRC_PCIEPHY_RCR_PCIEPHY_PERST (1U) /*!< Bit field size in bits for SRC_PCIEPHY_RCR_PCIEPHY_PERST. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_PCIEPHY_PERST field. */
#define BR_SRC_PCIEPHY_RCR_PCIEPHY_PERST(x) (HW_SRC_PCIEPHY_RCR(x).B.PCIEPHY_PERST)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_PCIEPHY_PERST. */
#define BF_SRC_PCIEPHY_RCR_PCIEPHY_PERST(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_PCIEPHY_PERST) & BM_SRC_PCIEPHY_RCR_PCIEPHY_PERST)

/*! @brief Set the PCIEPHY_PERST field to a new value. */
#define BW_SRC_PCIEPHY_RCR_PCIEPHY_PERST(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_PCIEPHY_PERST) | BF_SRC_PCIEPHY_RCR_PCIEPHY_PERST(v)))
/*@}*/

/*!
 * @name Register SRC_PCIEPHY_RCR, field PCIE_CTRL_APPS_CLK_REQ[4] (RW)
 *
 * Pcie_ctrl_app_clk_req_n
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_CLK_REQ (4U) /*!< Bit position for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_CLK_REQ. */
#define BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_CLK_REQ (0x00000010U) /*!< Bit mask for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_CLK_REQ. */
#define BS_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_CLK_REQ (1U) /*!< Bit field size in bits for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_CLK_REQ. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_CLK_REQ field. */
#define BR_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_CLK_REQ(x) (HW_SRC_PCIEPHY_RCR(x).B.PCIE_CTRL_APPS_CLK_REQ)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_CLK_REQ. */
#define BF_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_CLK_REQ(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_CLK_REQ) & BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_CLK_REQ)

/*! @brief Set the PCIE_CTRL_APPS_CLK_REQ field to a new value. */
#define BW_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_CLK_REQ(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_CLK_REQ) | BF_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_CLK_REQ(v)))
/*@}*/

/*!
 * @name Register SRC_PCIEPHY_RCR, field PCIE_CTRL_APPS_RST[5] (RW)
 *
 * Pcie_ctrl_app_init_rst
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_RST (5U) /*!< Bit position for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_RST. */
#define BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_RST (0x00000020U) /*!< Bit mask for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_RST. */
#define BS_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_RST (1U) /*!< Bit field size in bits for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_RST. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_RST field. */
#define BR_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_RST(x) (HW_SRC_PCIEPHY_RCR(x).B.PCIE_CTRL_APPS_RST)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_RST. */
#define BF_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_RST(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_RST) & BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_RST)

/*! @brief Set the PCIE_CTRL_APPS_RST field to a new value. */
#define BW_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_RST(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_RST) | BF_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_RST(v)))
/*@}*/

/*!
 * @name Register SRC_PCIEPHY_RCR, field PCIE_CTRL_APPS_EN[6] (RW)
 *
 * Pcie_ctrl_app_ltssm_enable
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EN (6U) /*!< Bit position for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EN. */
#define BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EN (0x00000040U) /*!< Bit mask for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EN. */
#define BS_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EN (1U) /*!< Bit field size in bits for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EN. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EN field. */
#define BR_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EN(x) (HW_SRC_PCIEPHY_RCR(x).B.PCIE_CTRL_APPS_EN)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EN. */
#define BF_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EN(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EN) & BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EN)

/*! @brief Set the PCIE_CTRL_APPS_EN field to a new value. */
#define BW_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EN(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EN) | BF_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EN(v)))
/*@}*/

/*!
 * @name Register SRC_PCIEPHY_RCR, field PCIE_CTRL_APPS_READY[7] (RW)
 *
 * Pcie_ctrl_app_ready_entr_l23
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_READY (7U) /*!< Bit position for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_READY. */
#define BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_READY (0x00000080U) /*!< Bit mask for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_READY. */
#define BS_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_READY (1U) /*!< Bit field size in bits for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_READY. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_READY field. */
#define BR_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_READY(x) (HW_SRC_PCIEPHY_RCR(x).B.PCIE_CTRL_APPS_READY)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_READY. */
#define BF_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_READY(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_READY) & BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_READY)

/*! @brief Set the PCIE_CTRL_APPS_READY field to a new value. */
#define BW_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_READY(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_READY) | BF_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_READY(v)))
/*@}*/

/*!
 * @name Register SRC_PCIEPHY_RCR, field PCIE_CTRL_APPS_ENTER[8] (RW)
 *
 * Pcie_ctrl_app_req_entr_l1
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_ENTER (8U) /*!< Bit position for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_ENTER. */
#define BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_ENTER (0x00000100U) /*!< Bit mask for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_ENTER. */
#define BS_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_ENTER (1U) /*!< Bit field size in bits for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_ENTER. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_ENTER field. */
#define BR_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_ENTER(x) (HW_SRC_PCIEPHY_RCR(x).B.PCIE_CTRL_APPS_ENTER)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_ENTER. */
#define BF_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_ENTER(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_ENTER) & BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_ENTER)

/*! @brief Set the PCIE_CTRL_APPS_ENTER field to a new value. */
#define BW_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_ENTER(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_ENTER) | BF_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_ENTER(v)))
/*@}*/

/*!
 * @name Register SRC_PCIEPHY_RCR, field PCIE_CTRL_APPS_EXIT[9] (RW)
 *
 * Pcie_ctrl_app_req_exit_l1
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EXIT (9U) /*!< Bit position for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EXIT. */
#define BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EXIT (0x00000200U) /*!< Bit mask for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EXIT. */
#define BS_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EXIT (1U) /*!< Bit field size in bits for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EXIT. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EXIT field. */
#define BR_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EXIT(x) (HW_SRC_PCIEPHY_RCR(x).B.PCIE_CTRL_APPS_EXIT)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EXIT. */
#define BF_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EXIT(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EXIT) & BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EXIT)

/*! @brief Set the PCIE_CTRL_APPS_EXIT field to a new value. */
#define BW_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EXIT(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EXIT) | BF_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_EXIT(v)))
/*@}*/

/*!
 * @name Register SRC_PCIEPHY_RCR, field PCIE_CTRL_APPS_PME[10] (RW)
 *
 * Pcie_ctrl_apps_pm_xmt_pme
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_PME (10U) /*!< Bit position for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_PME. */
#define BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_PME (0x00000400U) /*!< Bit mask for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_PME. */
#define BS_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_PME (1U) /*!< Bit field size in bits for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_PME. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_PME field. */
#define BR_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_PME(x) (HW_SRC_PCIEPHY_RCR(x).B.PCIE_CTRL_APPS_PME)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_PME. */
#define BF_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_PME(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_PME) & BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_PME)

/*! @brief Set the PCIE_CTRL_APPS_PME field to a new value. */
#define BW_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_PME(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_PME) | BF_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_PME(v)))
/*@}*/

/*!
 * @name Register SRC_PCIEPHY_RCR, field PCIE_CTRL_APPS_TURNOFF[11] (RW)
 *
 * Pcie_ctrl_apps_pm_xmt_turnoff
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_TURNOFF (11U) /*!< Bit position for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_TURNOFF. */
#define BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_TURNOFF (0x00000800U) /*!< Bit mask for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_TURNOFF. */
#define BS_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_TURNOFF (1U) /*!< Bit field size in bits for SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_TURNOFF. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_TURNOFF field. */
#define BR_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_TURNOFF(x) (HW_SRC_PCIEPHY_RCR(x).B.PCIE_CTRL_APPS_TURNOFF)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_TURNOFF. */
#define BF_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_TURNOFF(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_TURNOFF) & BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_TURNOFF)

/*! @brief Set the PCIE_CTRL_APPS_TURNOFF field to a new value. */
#define BW_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_TURNOFF(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_TURNOFF) | BF_SRC_PCIEPHY_RCR_PCIE_CTRL_APPS_TURNOFF(v)))
/*@}*/

/*!
 * @name Register SRC_PCIEPHY_RCR, field PCIE_CTRL_CFG_L1_AUX[12] (RW)
 *
 * Pcie_ctrl_cfg_l1_aux_clk_switch_core_clk_gate_en
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_AUX (12U) /*!< Bit position for SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_AUX. */
#define BM_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_AUX (0x00001000U) /*!< Bit mask for SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_AUX. */
#define BS_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_AUX (1U) /*!< Bit field size in bits for SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_AUX. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_AUX field. */
#define BR_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_AUX(x) (HW_SRC_PCIEPHY_RCR(x).B.PCIE_CTRL_CFG_L1_AUX)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_AUX. */
#define BF_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_AUX(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_AUX) & BM_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_AUX)

/*! @brief Set the PCIE_CTRL_CFG_L1_AUX field to a new value. */
#define BW_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_AUX(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_AUX) | BF_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_AUX(v)))
/*@}*/

/*!
 * @name Register SRC_PCIEPHY_RCR, field PCIE_CTRL_CFG_L1_MAC[13] (RW)
 *
 * Pcie_ctrl_cfg_l1_mac_powerdown_override_to_p2_en
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_MAC (13U) /*!< Bit position for SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_MAC. */
#define BM_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_MAC (0x00002000U) /*!< Bit mask for SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_MAC. */
#define BS_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_MAC (1U) /*!< Bit field size in bits for SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_MAC. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_MAC field. */
#define BR_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_MAC(x) (HW_SRC_PCIEPHY_RCR(x).B.PCIE_CTRL_CFG_L1_MAC)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_MAC. */
#define BF_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_MAC(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_MAC) & BM_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_MAC)

/*! @brief Set the PCIE_CTRL_CFG_L1_MAC field to a new value. */
#define BW_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_MAC(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_MAC) | BF_SRC_PCIEPHY_RCR_PCIE_CTRL_CFG_L1_MAC(v)))
/*@}*/

/*!
 * @name Register SRC_PCIEPHY_RCR, field PCIE_CTRL_SYS_INT[14] (RW)
 *
 * PCIE_CTRL_SYS_INT
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_PCIE_CTRL_SYS_INT (14U) /*!< Bit position for SRC_PCIEPHY_RCR_PCIE_CTRL_SYS_INT. */
#define BM_SRC_PCIEPHY_RCR_PCIE_CTRL_SYS_INT (0x00004000U) /*!< Bit mask for SRC_PCIEPHY_RCR_PCIE_CTRL_SYS_INT. */
#define BS_SRC_PCIEPHY_RCR_PCIE_CTRL_SYS_INT (1U) /*!< Bit field size in bits for SRC_PCIEPHY_RCR_PCIE_CTRL_SYS_INT. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_PCIE_CTRL_SYS_INT field. */
#define BR_SRC_PCIEPHY_RCR_PCIE_CTRL_SYS_INT(x) (HW_SRC_PCIEPHY_RCR(x).B.PCIE_CTRL_SYS_INT)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_PCIE_CTRL_SYS_INT. */
#define BF_SRC_PCIEPHY_RCR_PCIE_CTRL_SYS_INT(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_PCIE_CTRL_SYS_INT) & BM_SRC_PCIEPHY_RCR_PCIE_CTRL_SYS_INT)

/*! @brief Set the PCIE_CTRL_SYS_INT field to a new value. */
#define BW_SRC_PCIEPHY_RCR_PCIE_CTRL_SYS_INT(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_PCIE_CTRL_SYS_INT) | BF_SRC_PCIEPHY_RCR_PCIE_CTRL_SYS_INT(v)))
/*@}*/

/*!
 * @name Register SRC_PCIEPHY_RCR, field DOMAIN0[24] (RW)
 *
 * Domain0 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain0. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain0. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_DOMAIN0 (24U)   /*!< Bit position for SRC_PCIEPHY_RCR_DOMAIN0. */
#define BM_SRC_PCIEPHY_RCR_DOMAIN0 (0x01000000U) /*!< Bit mask for SRC_PCIEPHY_RCR_DOMAIN0. */
#define BS_SRC_PCIEPHY_RCR_DOMAIN0 (1U)    /*!< Bit field size in bits for SRC_PCIEPHY_RCR_DOMAIN0. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_DOMAIN0 field. */
#define BR_SRC_PCIEPHY_RCR_DOMAIN0(x) (HW_SRC_PCIEPHY_RCR(x).B.DOMAIN0)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_DOMAIN0. */
#define BF_SRC_PCIEPHY_RCR_DOMAIN0(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_DOMAIN0) & BM_SRC_PCIEPHY_RCR_DOMAIN0)

/*! @brief Set the DOMAIN0 field to a new value. */
#define BW_SRC_PCIEPHY_RCR_DOMAIN0(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_DOMAIN0) | BF_SRC_PCIEPHY_RCR_DOMAIN0(v)))
/*@}*/

/*!
 * @name Register SRC_PCIEPHY_RCR, field DOMAIN1[25] (RW)
 *
 * Domain1 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain1. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain1. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_DOMAIN1 (25U)   /*!< Bit position for SRC_PCIEPHY_RCR_DOMAIN1. */
#define BM_SRC_PCIEPHY_RCR_DOMAIN1 (0x02000000U) /*!< Bit mask for SRC_PCIEPHY_RCR_DOMAIN1. */
#define BS_SRC_PCIEPHY_RCR_DOMAIN1 (1U)    /*!< Bit field size in bits for SRC_PCIEPHY_RCR_DOMAIN1. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_DOMAIN1 field. */
#define BR_SRC_PCIEPHY_RCR_DOMAIN1(x) (HW_SRC_PCIEPHY_RCR(x).B.DOMAIN1)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_DOMAIN1. */
#define BF_SRC_PCIEPHY_RCR_DOMAIN1(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_DOMAIN1) & BM_SRC_PCIEPHY_RCR_DOMAIN1)

/*! @brief Set the DOMAIN1 field to a new value. */
#define BW_SRC_PCIEPHY_RCR_DOMAIN1(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_DOMAIN1) | BF_SRC_PCIEPHY_RCR_DOMAIN1(v)))
/*@}*/

/*!
 * @name Register SRC_PCIEPHY_RCR, field DOMAIN2[26] (RW)
 *
 * Domain2 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain2. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain2. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_DOMAIN2 (26U)   /*!< Bit position for SRC_PCIEPHY_RCR_DOMAIN2. */
#define BM_SRC_PCIEPHY_RCR_DOMAIN2 (0x04000000U) /*!< Bit mask for SRC_PCIEPHY_RCR_DOMAIN2. */
#define BS_SRC_PCIEPHY_RCR_DOMAIN2 (1U)    /*!< Bit field size in bits for SRC_PCIEPHY_RCR_DOMAIN2. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_DOMAIN2 field. */
#define BR_SRC_PCIEPHY_RCR_DOMAIN2(x) (HW_SRC_PCIEPHY_RCR(x).B.DOMAIN2)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_DOMAIN2. */
#define BF_SRC_PCIEPHY_RCR_DOMAIN2(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_DOMAIN2) & BM_SRC_PCIEPHY_RCR_DOMAIN2)

/*! @brief Set the DOMAIN2 field to a new value. */
#define BW_SRC_PCIEPHY_RCR_DOMAIN2(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_DOMAIN2) | BF_SRC_PCIEPHY_RCR_DOMAIN2(v)))
/*@}*/

/*!
 * @name Register SRC_PCIEPHY_RCR, field DOMAIN3[27] (RW)
 *
 * Domain3 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain3. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain3. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_DOMAIN3 (27U)   /*!< Bit position for SRC_PCIEPHY_RCR_DOMAIN3. */
#define BM_SRC_PCIEPHY_RCR_DOMAIN3 (0x08000000U) /*!< Bit mask for SRC_PCIEPHY_RCR_DOMAIN3. */
#define BS_SRC_PCIEPHY_RCR_DOMAIN3 (1U)    /*!< Bit field size in bits for SRC_PCIEPHY_RCR_DOMAIN3. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_DOMAIN3 field. */
#define BR_SRC_PCIEPHY_RCR_DOMAIN3(x) (HW_SRC_PCIEPHY_RCR(x).B.DOMAIN3)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_DOMAIN3. */
#define BF_SRC_PCIEPHY_RCR_DOMAIN3(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_DOMAIN3) & BM_SRC_PCIEPHY_RCR_DOMAIN3)

/*! @brief Set the DOMAIN3 field to a new value. */
#define BW_SRC_PCIEPHY_RCR_DOMAIN3(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_DOMAIN3) | BF_SRC_PCIEPHY_RCR_DOMAIN3(v)))
/*@}*/

/*!
 * @name Register SRC_PCIEPHY_RCR, field LOCK[30] (RW)
 *
 * Domain control bits lock Lock bit is a write-once register, once it is set to
 * 1, it can't be write to 0
 *
 * Values:
 * - 0 - [31] and [27:24] bits can be modified
 * - 1 - [31] and [27:24] bits cannot be modified
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_LOCK (30U)      /*!< Bit position for SRC_PCIEPHY_RCR_LOCK. */
#define BM_SRC_PCIEPHY_RCR_LOCK (0x40000000U) /*!< Bit mask for SRC_PCIEPHY_RCR_LOCK. */
#define BS_SRC_PCIEPHY_RCR_LOCK (1U)       /*!< Bit field size in bits for SRC_PCIEPHY_RCR_LOCK. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_LOCK field. */
#define BR_SRC_PCIEPHY_RCR_LOCK(x) (HW_SRC_PCIEPHY_RCR(x).B.LOCK)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_LOCK. */
#define BF_SRC_PCIEPHY_RCR_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_LOCK) & BM_SRC_PCIEPHY_RCR_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_SRC_PCIEPHY_RCR_LOCK(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_LOCK) | BF_SRC_PCIEPHY_RCR_LOCK(v)))
/*@}*/

/*!
 * @name Register SRC_PCIEPHY_RCR, field DOM_EN[31] (RW)
 *
 * Domain Control enable for this register. [31:30] and [27:24] areas are not
 * controlled by this bit. [31:30] and [27:24] area can be modified by any masters
 * from any domains when Lock bit is not set.
 *
 * Values:
 * - 0 - Disables domain control. All of this register's bits except [31:30] and
 *     [27:24] can be modified by any masters
 * - 1 - Enables domain control. All of this register's bits except [31:30] and
 *     [27:24] can only be modified by the masters from the domains specified in
 *     [27:24] area.
 */
/*@{*/
#define BP_SRC_PCIEPHY_RCR_DOM_EN (31U)    /*!< Bit position for SRC_PCIEPHY_RCR_DOM_EN. */
#define BM_SRC_PCIEPHY_RCR_DOM_EN (0x80000000U) /*!< Bit mask for SRC_PCIEPHY_RCR_DOM_EN. */
#define BS_SRC_PCIEPHY_RCR_DOM_EN (1U)     /*!< Bit field size in bits for SRC_PCIEPHY_RCR_DOM_EN. */

/*! @brief Read current value of the SRC_PCIEPHY_RCR_DOM_EN field. */
#define BR_SRC_PCIEPHY_RCR_DOM_EN(x) (HW_SRC_PCIEPHY_RCR(x).B.DOM_EN)

/*! @brief Format value for bitfield SRC_PCIEPHY_RCR_DOM_EN. */
#define BF_SRC_PCIEPHY_RCR_DOM_EN(v) ((uint32_t)((uint32_t)(v) << BP_SRC_PCIEPHY_RCR_DOM_EN) & BM_SRC_PCIEPHY_RCR_DOM_EN)

/*! @brief Set the DOM_EN field to a new value. */
#define BW_SRC_PCIEPHY_RCR_DOM_EN(x, v) (HW_SRC_PCIEPHY_RCR_WR(x, (HW_SRC_PCIEPHY_RCR_RD(x) & ~BM_SRC_PCIEPHY_RCR_DOM_EN) | BF_SRC_PCIEPHY_RCR_DOM_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_SRC_SBMR1 - SRC Boot Mode Register 1
 ******************************************************************************/

/*!
 * @brief HW_SRC_SBMR1 - SRC Boot Mode Register 1 (RO)
 *
 * Reset value: 0x00000000U
 *
 * The Boot Mode register (SBMR) contains bits that reflect the status of Boot
 * Mode Pins of the chip. The reset value is configuration dependent (depending on
 * boot/fuses/IO pads).
 */
typedef union _hw_src_sbmr1
{
    uint32_t U;
    struct _hw_src_sbmr1_bitfields
    {
        uint32_t BOOT_CFG1 : 8;        /*!< [7:0]  */
        uint32_t BOOT_CFG2 : 8;        /*!< [15:8]  */
        uint32_t BOOT_CFG3 : 8;        /*!< [23:16]  */
        uint32_t BOOT_CFG4 : 8;        /*!< [31:24]  */
    } B;
} hw_src_sbmr1_t;

/*!
 * @name Constants and macros for entire SRC_SBMR1 register
 */
/*@{*/
#define HW_SRC_SBMR1_ADDR(x)     ((uintptr_t)(x) + 0x58U)

#define HW_SRC_SBMR1(x)          (*(__I hw_src_sbmr1_t *) HW_SRC_SBMR1_ADDR(x))
#define HW_SRC_SBMR1_RD(x)       (HW_SRC_SBMR1(x).U)
/*@}*/

/*
 * Constants & macros for individual SRC_SBMR1 bitfields
 */

/*!
 * @name Register SRC_SBMR1, field BOOT_CFG1[7:0] (RO)
 *
 * Refer to fusemap.
 */
/*@{*/
#define BP_SRC_SBMR1_BOOT_CFG1 (0U)        /*!< Bit position for SRC_SBMR1_BOOT_CFG1. */
#define BM_SRC_SBMR1_BOOT_CFG1 (0x000000FFU) /*!< Bit mask for SRC_SBMR1_BOOT_CFG1. */
#define BS_SRC_SBMR1_BOOT_CFG1 (8U)        /*!< Bit field size in bits for SRC_SBMR1_BOOT_CFG1. */

/*! @brief Read current value of the SRC_SBMR1_BOOT_CFG1 field. */
#define BR_SRC_SBMR1_BOOT_CFG1(x) (HW_SRC_SBMR1(x).B.BOOT_CFG1)
/*@}*/

/*!
 * @name Register SRC_SBMR1, field BOOT_CFG2[15:8] (RO)
 *
 * Refer to fusemap.
 */
/*@{*/
#define BP_SRC_SBMR1_BOOT_CFG2 (8U)        /*!< Bit position for SRC_SBMR1_BOOT_CFG2. */
#define BM_SRC_SBMR1_BOOT_CFG2 (0x0000FF00U) /*!< Bit mask for SRC_SBMR1_BOOT_CFG2. */
#define BS_SRC_SBMR1_BOOT_CFG2 (8U)        /*!< Bit field size in bits for SRC_SBMR1_BOOT_CFG2. */

/*! @brief Read current value of the SRC_SBMR1_BOOT_CFG2 field. */
#define BR_SRC_SBMR1_BOOT_CFG2(x) (HW_SRC_SBMR1(x).B.BOOT_CFG2)
/*@}*/

/*!
 * @name Register SRC_SBMR1, field BOOT_CFG3[23:16] (RO)
 *
 * Refer to fusemap.
 */
/*@{*/
#define BP_SRC_SBMR1_BOOT_CFG3 (16U)       /*!< Bit position for SRC_SBMR1_BOOT_CFG3. */
#define BM_SRC_SBMR1_BOOT_CFG3 (0x00FF0000U) /*!< Bit mask for SRC_SBMR1_BOOT_CFG3. */
#define BS_SRC_SBMR1_BOOT_CFG3 (8U)        /*!< Bit field size in bits for SRC_SBMR1_BOOT_CFG3. */

/*! @brief Read current value of the SRC_SBMR1_BOOT_CFG3 field. */
#define BR_SRC_SBMR1_BOOT_CFG3(x) (HW_SRC_SBMR1(x).B.BOOT_CFG3)
/*@}*/

/*!
 * @name Register SRC_SBMR1, field BOOT_CFG4[31:24] (RO)
 *
 * Refer to fusemap.
 */
/*@{*/
#define BP_SRC_SBMR1_BOOT_CFG4 (24U)       /*!< Bit position for SRC_SBMR1_BOOT_CFG4. */
#define BM_SRC_SBMR1_BOOT_CFG4 (0xFF000000U) /*!< Bit mask for SRC_SBMR1_BOOT_CFG4. */
#define BS_SRC_SBMR1_BOOT_CFG4 (8U)        /*!< Bit field size in bits for SRC_SBMR1_BOOT_CFG4. */

/*! @brief Read current value of the SRC_SBMR1_BOOT_CFG4 field. */
#define BR_SRC_SBMR1_BOOT_CFG4(x) (HW_SRC_SBMR1(x).B.BOOT_CFG4)
/*@}*/

/*******************************************************************************
 * HW_SRC_SRSR - SRC Reset Status Register
 ******************************************************************************/

/*!
 * @brief HW_SRC_SRSR - SRC Reset Status Register (RW)
 *
 * Reset value: 0x00000001U
 *
 * The SRSR is a write to one clear register which records the source of the
 * reset events for the chip. The SRC reset status register will capture all the
 * reset sources that have occurred. This register is reset on ipp_reset_b. This is
 * a read-write register. For bit[9-0] - writing zero does not have any effect.
 * Writing one will clear the corresponding bit. The individual bits can be
 * cleared by writing one to that bit. When the system comes out of reset, this
 * register will have bits set corresponding to all the reset sources that occurred
 * during system reset. Software has to take care to clear this register by writing
 * one after every reset that occurs so that the register will contain the
 * information of recently occurred reset.
 */
typedef union _hw_src_srsr
{
    uint32_t U;
    struct _hw_src_srsr_bitfields
    {
        uint32_t ipp_reset_b : 1;      /*!< [0]  */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t csu_reset_b : 1;      /*!< [2]  */
        uint32_t ipp_user_reset_b : 1; /*!< [3]  */
        uint32_t wdog1_rst_b : 1;      /*!< [4]  */
        uint32_t jtag_rst_b : 1;       /*!< [5]  */
        uint32_t jtag_sw_rst : 1;      /*!< [6]  */
        uint32_t wdog3_rst_b : 1;      /*!< [7]  */
        uint32_t wdog4_rst_b : 1;      /*!< [8]  */
        uint32_t tempsense_rst_b : 1;  /*!< [9]  */
        uint32_t RESERVED1 : 22;       /*!< [31:10]  */
    } B;
} hw_src_srsr_t;

/*!
 * @name Constants and macros for entire SRC_SRSR register
 */
/*@{*/
#define HW_SRC_SRSR_ADDR(x)      ((uintptr_t)(x) + 0x5CU)

#define HW_SRC_SRSR(x)           (*(__IO hw_src_srsr_t *) HW_SRC_SRSR_ADDR(x))
#define HW_SRC_SRSR_RD(x)        (HW_SRC_SRSR(x).U)
#define HW_SRC_SRSR_WR(x, v)     (HW_SRC_SRSR(x).U = (v))
#define HW_SRC_SRSR_SET(x, v)    (HW_SRC_SRSR_WR(x, HW_SRC_SRSR_RD(x) |  (v)))
#define HW_SRC_SRSR_CLR(x, v)    (HW_SRC_SRSR_WR(x, HW_SRC_SRSR_RD(x) & ~(v)))
#define HW_SRC_SRSR_TOG(x, v)    (HW_SRC_SRSR_WR(x, HW_SRC_SRSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_SRSR bitfields
 */

/*!
 * @name Register SRC_SRSR, field ipp_reset_b[0] (W1C)
 *
 * Indicates whether reset was the result of ipp_reset_b pin (Power-up sequence)
 *
 * Values:
 * - 0 - Reset is not a result of ipp_reset_b pin.
 * - 1 - Reset is a result of ipp_reset_b pin.
 */
/*@{*/
#define BP_SRC_SRSR_ipp_reset_b (0U)       /*!< Bit position for SRC_SRSR_ipp_reset_b. */
#define BM_SRC_SRSR_ipp_reset_b (0x00000001U) /*!< Bit mask for SRC_SRSR_ipp_reset_b. */
#define BS_SRC_SRSR_ipp_reset_b (1U)       /*!< Bit field size in bits for SRC_SRSR_ipp_reset_b. */

/*! @brief Read current value of the SRC_SRSR_ipp_reset_b field. */
#define BR_SRC_SRSR_ipp_reset_b(x) (HW_SRC_SRSR(x).B.ipp_reset_b)

/*! @brief Format value for bitfield SRC_SRSR_ipp_reset_b. */
#define BF_SRC_SRSR_ipp_reset_b(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SRSR_ipp_reset_b) & BM_SRC_SRSR_ipp_reset_b)

/*! @brief Set the ipp_reset_b field to a new value. */
#define BW_SRC_SRSR_ipp_reset_b(x, v) (HW_SRC_SRSR_WR(x, (HW_SRC_SRSR_RD(x) & ~(BM_SRC_SRSR_ipp_reset_b | BM_SRC_SRSR_csu_reset_b | BM_SRC_SRSR_ipp_user_reset_b | BM_SRC_SRSR_wdog1_rst_b | BM_SRC_SRSR_jtag_rst_b | BM_SRC_SRSR_jtag_sw_rst | BM_SRC_SRSR_wdog3_rst_b | BM_SRC_SRSR_wdog4_rst_b)) | BF_SRC_SRSR_ipp_reset_b(v)))
/*@}*/

/*!
 * @name Register SRC_SRSR, field csu_reset_b[2] (W1C)
 *
 * Indicates whether the reset was the result of the csu_reset_b input. If case
 * the csu_reset_b occurred during a WARM reset process, during the phase that
 * ipg_clk is not available yet, then the occurrence of CSU reset will not be
 * reflected in this bit.
 *
 * Values:
 * - 0 - Reset is not a result of the csu_reset_b event.
 * - 1 - Reset is a result of the csu_reset_b event.
 */
/*@{*/
#define BP_SRC_SRSR_csu_reset_b (2U)       /*!< Bit position for SRC_SRSR_csu_reset_b. */
#define BM_SRC_SRSR_csu_reset_b (0x00000004U) /*!< Bit mask for SRC_SRSR_csu_reset_b. */
#define BS_SRC_SRSR_csu_reset_b (1U)       /*!< Bit field size in bits for SRC_SRSR_csu_reset_b. */

/*! @brief Read current value of the SRC_SRSR_csu_reset_b field. */
#define BR_SRC_SRSR_csu_reset_b(x) (HW_SRC_SRSR(x).B.csu_reset_b)

/*! @brief Format value for bitfield SRC_SRSR_csu_reset_b. */
#define BF_SRC_SRSR_csu_reset_b(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SRSR_csu_reset_b) & BM_SRC_SRSR_csu_reset_b)

/*! @brief Set the csu_reset_b field to a new value. */
#define BW_SRC_SRSR_csu_reset_b(x, v) (HW_SRC_SRSR_WR(x, (HW_SRC_SRSR_RD(x) & ~(BM_SRC_SRSR_csu_reset_b | BM_SRC_SRSR_ipp_reset_b | BM_SRC_SRSR_ipp_user_reset_b | BM_SRC_SRSR_wdog1_rst_b | BM_SRC_SRSR_jtag_rst_b | BM_SRC_SRSR_jtag_sw_rst | BM_SRC_SRSR_wdog3_rst_b | BM_SRC_SRSR_wdog4_rst_b)) | BF_SRC_SRSR_csu_reset_b(v)))
/*@}*/

/*!
 * @name Register SRC_SRSR, field ipp_user_reset_b[3] (W1C)
 *
 * Indicates whether the reset was the result of the ipp_user_reset_b qualified
 * reset.
 *
 * Values:
 * - 0 - Reset is not a result of the ipp_user_reset_b qualified as COLD reset
 *     event.
 * - 1 - Reset is a result of the ipp_user_reset_b qualified as COLD reset event.
 */
/*@{*/
#define BP_SRC_SRSR_ipp_user_reset_b (3U)  /*!< Bit position for SRC_SRSR_ipp_user_reset_b. */
#define BM_SRC_SRSR_ipp_user_reset_b (0x00000008U) /*!< Bit mask for SRC_SRSR_ipp_user_reset_b. */
#define BS_SRC_SRSR_ipp_user_reset_b (1U)  /*!< Bit field size in bits for SRC_SRSR_ipp_user_reset_b. */

/*! @brief Read current value of the SRC_SRSR_ipp_user_reset_b field. */
#define BR_SRC_SRSR_ipp_user_reset_b(x) (HW_SRC_SRSR(x).B.ipp_user_reset_b)

/*! @brief Format value for bitfield SRC_SRSR_ipp_user_reset_b. */
#define BF_SRC_SRSR_ipp_user_reset_b(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SRSR_ipp_user_reset_b) & BM_SRC_SRSR_ipp_user_reset_b)

/*! @brief Set the ipp_user_reset_b field to a new value. */
#define BW_SRC_SRSR_ipp_user_reset_b(x, v) (HW_SRC_SRSR_WR(x, (HW_SRC_SRSR_RD(x) & ~(BM_SRC_SRSR_ipp_user_reset_b | BM_SRC_SRSR_ipp_reset_b | BM_SRC_SRSR_csu_reset_b | BM_SRC_SRSR_wdog1_rst_b | BM_SRC_SRSR_jtag_rst_b | BM_SRC_SRSR_jtag_sw_rst | BM_SRC_SRSR_wdog3_rst_b | BM_SRC_SRSR_wdog4_rst_b)) | BF_SRC_SRSR_ipp_user_reset_b(v)))
/*@}*/

/*!
 * @name Register SRC_SRSR, field wdog1_rst_b[4] (W1C)
 *
 * IC Watchdog1 Time-out reset. Indicates whether the reset was the result of
 * the watchdog time-out event.
 *
 * Values:
 * - 0 - Reset is not a result of the watchdog1 time-out event.
 * - 1 - Reset is a result of the watchdog1 time-out event.
 */
/*@{*/
#define BP_SRC_SRSR_wdog1_rst_b (4U)       /*!< Bit position for SRC_SRSR_wdog1_rst_b. */
#define BM_SRC_SRSR_wdog1_rst_b (0x00000010U) /*!< Bit mask for SRC_SRSR_wdog1_rst_b. */
#define BS_SRC_SRSR_wdog1_rst_b (1U)       /*!< Bit field size in bits for SRC_SRSR_wdog1_rst_b. */

/*! @brief Read current value of the SRC_SRSR_wdog1_rst_b field. */
#define BR_SRC_SRSR_wdog1_rst_b(x) (HW_SRC_SRSR(x).B.wdog1_rst_b)

/*! @brief Format value for bitfield SRC_SRSR_wdog1_rst_b. */
#define BF_SRC_SRSR_wdog1_rst_b(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SRSR_wdog1_rst_b) & BM_SRC_SRSR_wdog1_rst_b)

/*! @brief Set the wdog1_rst_b field to a new value. */
#define BW_SRC_SRSR_wdog1_rst_b(x, v) (HW_SRC_SRSR_WR(x, (HW_SRC_SRSR_RD(x) & ~(BM_SRC_SRSR_wdog1_rst_b | BM_SRC_SRSR_ipp_reset_b | BM_SRC_SRSR_csu_reset_b | BM_SRC_SRSR_ipp_user_reset_b | BM_SRC_SRSR_jtag_rst_b | BM_SRC_SRSR_jtag_sw_rst | BM_SRC_SRSR_wdog3_rst_b | BM_SRC_SRSR_wdog4_rst_b)) | BF_SRC_SRSR_wdog1_rst_b(v)))
/*@}*/

/*!
 * @name Register SRC_SRSR, field jtag_rst_b[5] (W1C)
 *
 * HIGH - Z JTAG reset. Indicates whether the reset was the result of HIGH-Z
 * reset from JTAG.
 *
 * Values:
 * - 0 - Reset is not a result of HIGH-Z reset from JTAG.
 * - 1 - Reset is a result of HIGH-Z reset from JTAG.
 */
/*@{*/
#define BP_SRC_SRSR_jtag_rst_b (5U)        /*!< Bit position for SRC_SRSR_jtag_rst_b. */
#define BM_SRC_SRSR_jtag_rst_b (0x00000020U) /*!< Bit mask for SRC_SRSR_jtag_rst_b. */
#define BS_SRC_SRSR_jtag_rst_b (1U)        /*!< Bit field size in bits for SRC_SRSR_jtag_rst_b. */

/*! @brief Read current value of the SRC_SRSR_jtag_rst_b field. */
#define BR_SRC_SRSR_jtag_rst_b(x) (HW_SRC_SRSR(x).B.jtag_rst_b)

/*! @brief Format value for bitfield SRC_SRSR_jtag_rst_b. */
#define BF_SRC_SRSR_jtag_rst_b(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SRSR_jtag_rst_b) & BM_SRC_SRSR_jtag_rst_b)

/*! @brief Set the jtag_rst_b field to a new value. */
#define BW_SRC_SRSR_jtag_rst_b(x, v) (HW_SRC_SRSR_WR(x, (HW_SRC_SRSR_RD(x) & ~(BM_SRC_SRSR_jtag_rst_b | BM_SRC_SRSR_ipp_reset_b | BM_SRC_SRSR_csu_reset_b | BM_SRC_SRSR_ipp_user_reset_b | BM_SRC_SRSR_wdog1_rst_b | BM_SRC_SRSR_jtag_sw_rst | BM_SRC_SRSR_wdog3_rst_b | BM_SRC_SRSR_wdog4_rst_b)) | BF_SRC_SRSR_jtag_rst_b(v)))
/*@}*/

/*!
 * @name Register SRC_SRSR, field jtag_sw_rst[6] (W1C)
 *
 * JTAG software reset. Indicates whether the reset was the result of software
 * reset from JTAG.
 *
 * Values:
 * - 0 - Reset is not a result of software reset from JTAG.
 * - 1 - Reset is a result of software reset from JTAG.
 */
/*@{*/
#define BP_SRC_SRSR_jtag_sw_rst (6U)       /*!< Bit position for SRC_SRSR_jtag_sw_rst. */
#define BM_SRC_SRSR_jtag_sw_rst (0x00000040U) /*!< Bit mask for SRC_SRSR_jtag_sw_rst. */
#define BS_SRC_SRSR_jtag_sw_rst (1U)       /*!< Bit field size in bits for SRC_SRSR_jtag_sw_rst. */

/*! @brief Read current value of the SRC_SRSR_jtag_sw_rst field. */
#define BR_SRC_SRSR_jtag_sw_rst(x) (HW_SRC_SRSR(x).B.jtag_sw_rst)

/*! @brief Format value for bitfield SRC_SRSR_jtag_sw_rst. */
#define BF_SRC_SRSR_jtag_sw_rst(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SRSR_jtag_sw_rst) & BM_SRC_SRSR_jtag_sw_rst)

/*! @brief Set the jtag_sw_rst field to a new value. */
#define BW_SRC_SRSR_jtag_sw_rst(x, v) (HW_SRC_SRSR_WR(x, (HW_SRC_SRSR_RD(x) & ~(BM_SRC_SRSR_jtag_sw_rst | BM_SRC_SRSR_ipp_reset_b | BM_SRC_SRSR_csu_reset_b | BM_SRC_SRSR_ipp_user_reset_b | BM_SRC_SRSR_wdog1_rst_b | BM_SRC_SRSR_jtag_rst_b | BM_SRC_SRSR_wdog3_rst_b | BM_SRC_SRSR_wdog4_rst_b)) | BF_SRC_SRSR_jtag_sw_rst(v)))
/*@}*/

/*!
 * @name Register SRC_SRSR, field wdog3_rst_b[7] (W1C)
 *
 * IC Watchdog3 Time-out reset. Indicates whether the reset was the result of
 * the watchdog3 time-out event.
 *
 * Values:
 * - 0 - Reset is not a result of the watchdog3 time-out event.
 * - 1 - Reset is a result of the watchdog3 time-out event.
 */
/*@{*/
#define BP_SRC_SRSR_wdog3_rst_b (7U)       /*!< Bit position for SRC_SRSR_wdog3_rst_b. */
#define BM_SRC_SRSR_wdog3_rst_b (0x00000080U) /*!< Bit mask for SRC_SRSR_wdog3_rst_b. */
#define BS_SRC_SRSR_wdog3_rst_b (1U)       /*!< Bit field size in bits for SRC_SRSR_wdog3_rst_b. */

/*! @brief Read current value of the SRC_SRSR_wdog3_rst_b field. */
#define BR_SRC_SRSR_wdog3_rst_b(x) (HW_SRC_SRSR(x).B.wdog3_rst_b)

/*! @brief Format value for bitfield SRC_SRSR_wdog3_rst_b. */
#define BF_SRC_SRSR_wdog3_rst_b(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SRSR_wdog3_rst_b) & BM_SRC_SRSR_wdog3_rst_b)

/*! @brief Set the wdog3_rst_b field to a new value. */
#define BW_SRC_SRSR_wdog3_rst_b(x, v) (HW_SRC_SRSR_WR(x, (HW_SRC_SRSR_RD(x) & ~(BM_SRC_SRSR_wdog3_rst_b | BM_SRC_SRSR_ipp_reset_b | BM_SRC_SRSR_csu_reset_b | BM_SRC_SRSR_ipp_user_reset_b | BM_SRC_SRSR_wdog1_rst_b | BM_SRC_SRSR_jtag_rst_b | BM_SRC_SRSR_jtag_sw_rst | BM_SRC_SRSR_wdog4_rst_b)) | BF_SRC_SRSR_wdog3_rst_b(v)))
/*@}*/

/*!
 * @name Register SRC_SRSR, field wdog4_rst_b[8] (W1C)
 *
 * IC Watchdog4 Time-out reset. Indicates whether the reset was the result of
 * the watchdog4 time-out event.
 *
 * Values:
 * - 0 - Reset is not a result of the watchdog4 time-out event.
 * - 1 - Reset is a result of the watchdog4 time-out event.
 */
/*@{*/
#define BP_SRC_SRSR_wdog4_rst_b (8U)       /*!< Bit position for SRC_SRSR_wdog4_rst_b. */
#define BM_SRC_SRSR_wdog4_rst_b (0x00000100U) /*!< Bit mask for SRC_SRSR_wdog4_rst_b. */
#define BS_SRC_SRSR_wdog4_rst_b (1U)       /*!< Bit field size in bits for SRC_SRSR_wdog4_rst_b. */

/*! @brief Read current value of the SRC_SRSR_wdog4_rst_b field. */
#define BR_SRC_SRSR_wdog4_rst_b(x) (HW_SRC_SRSR(x).B.wdog4_rst_b)

/*! @brief Format value for bitfield SRC_SRSR_wdog4_rst_b. */
#define BF_SRC_SRSR_wdog4_rst_b(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SRSR_wdog4_rst_b) & BM_SRC_SRSR_wdog4_rst_b)

/*! @brief Set the wdog4_rst_b field to a new value. */
#define BW_SRC_SRSR_wdog4_rst_b(x, v) (HW_SRC_SRSR_WR(x, (HW_SRC_SRSR_RD(x) & ~(BM_SRC_SRSR_wdog4_rst_b | BM_SRC_SRSR_ipp_reset_b | BM_SRC_SRSR_csu_reset_b | BM_SRC_SRSR_ipp_user_reset_b | BM_SRC_SRSR_wdog1_rst_b | BM_SRC_SRSR_jtag_rst_b | BM_SRC_SRSR_jtag_sw_rst | BM_SRC_SRSR_wdog3_rst_b)) | BF_SRC_SRSR_wdog4_rst_b(v)))
/*@}*/

/*!
 * @name Register SRC_SRSR, field tempsense_rst_b[9] (RW)
 *
 * Temper Sensor software reset. Indicates whether the reset was the result of
 * software reset from on-chip Temperature Sensor.
 *
 * Values:
 * - 0 - Reset is not a result of software reset from Temperature Sensor.
 * - 1 - Reset is a result of software reset from Temperature Sensor.
 */
/*@{*/
#define BP_SRC_SRSR_tempsense_rst_b (9U)   /*!< Bit position for SRC_SRSR_tempsense_rst_b. */
#define BM_SRC_SRSR_tempsense_rst_b (0x00000200U) /*!< Bit mask for SRC_SRSR_tempsense_rst_b. */
#define BS_SRC_SRSR_tempsense_rst_b (1U)   /*!< Bit field size in bits for SRC_SRSR_tempsense_rst_b. */

/*! @brief Read current value of the SRC_SRSR_tempsense_rst_b field. */
#define BR_SRC_SRSR_tempsense_rst_b(x) (HW_SRC_SRSR(x).B.tempsense_rst_b)

/*! @brief Format value for bitfield SRC_SRSR_tempsense_rst_b. */
#define BF_SRC_SRSR_tempsense_rst_b(v) ((uint32_t)((uint32_t)(v) << BP_SRC_SRSR_tempsense_rst_b) & BM_SRC_SRSR_tempsense_rst_b)

/*! @brief Set the tempsense_rst_b field to a new value. */
#define BW_SRC_SRSR_tempsense_rst_b(x, v) (HW_SRC_SRSR_WR(x, (HW_SRC_SRSR_RD(x) & ~(BM_SRC_SRSR_tempsense_rst_b | BM_SRC_SRSR_ipp_reset_b | BM_SRC_SRSR_csu_reset_b | BM_SRC_SRSR_ipp_user_reset_b | BM_SRC_SRSR_wdog1_rst_b | BM_SRC_SRSR_jtag_rst_b | BM_SRC_SRSR_jtag_sw_rst | BM_SRC_SRSR_wdog3_rst_b | BM_SRC_SRSR_wdog4_rst_b)) | BF_SRC_SRSR_tempsense_rst_b(v)))
/*@}*/

/*******************************************************************************
 * HW_SRC_SISR - SRC Interrupt Status Register
 ******************************************************************************/

/*!
 * @brief HW_SRC_SISR - SRC Interrupt Status Register (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_sisr
{
    uint32_t U;
    struct _hw_src_sisr_bitfields
    {
        uint32_t RESERVED0 : 1;        /*!< [0]  */
        uint32_t HSICPHY_PASSED_RESET : 1; /*!< [1]  */
        uint32_t OTGPHY1_PASSED_RESET : 1; /*!< [2]  */
        uint32_t OTGPHY2_PASSED_RESET : 1; /*!< [3]  */
        uint32_t MIPIPHY_PASSED_RESET : 1; /*!< [4]  */
        uint32_t RESERVED1 : 3;        /*!< [7:5]  */
        uint32_t M4C_PASSED_RESET : 1; /*!< [8]  */
        uint32_t M4P_PASSED_RESET : 1; /*!< [9]  */
        uint32_t RESERVED2 : 22;       /*!< [31:10]  */
    } B;
} hw_src_sisr_t;

/*!
 * @name Constants and macros for entire SRC_SISR register
 */
/*@{*/
#define HW_SRC_SISR_ADDR(x)      ((uintptr_t)(x) + 0x68U)

#define HW_SRC_SISR(x)           (*(__I hw_src_sisr_t *) HW_SRC_SISR_ADDR(x))
#define HW_SRC_SISR_RD(x)        (HW_SRC_SISR(x).U)
/*@}*/

/*
 * Constants & macros for individual SRC_SISR bitfields
 */

/*!
 * @name Register SRC_SISR, field HSICPHY_PASSED_RESET[1] (RO)
 *
 * Interrupt generated to indicate that HSIC PHY passed software reset and is
 * ready to be used
 *
 * Values:
 * - 0 - Interrupt generated not due to HSIC PHY passed reset
 * - 1 - Interrupt generated due to HSIC PHY passed reset
 */
/*@{*/
#define BP_SRC_SISR_HSICPHY_PASSED_RESET (1U) /*!< Bit position for SRC_SISR_HSICPHY_PASSED_RESET. */
#define BM_SRC_SISR_HSICPHY_PASSED_RESET (0x00000002U) /*!< Bit mask for SRC_SISR_HSICPHY_PASSED_RESET. */
#define BS_SRC_SISR_HSICPHY_PASSED_RESET (1U) /*!< Bit field size in bits for SRC_SISR_HSICPHY_PASSED_RESET. */

/*! @brief Read current value of the SRC_SISR_HSICPHY_PASSED_RESET field. */
#define BR_SRC_SISR_HSICPHY_PASSED_RESET(x) (HW_SRC_SISR(x).B.HSICPHY_PASSED_RESET)
/*@}*/

/*!
 * @name Register SRC_SISR, field OTGPHY1_PASSED_RESET[2] (RO)
 *
 * Interrupt generated to indicate that OTG PHY1 passed software reset and is
 * ready to be used
 *
 * Values:
 * - 0 - Interrupt generated not due to OTG PHY1 passed reset
 * - 1 - Interrupt generated due to OTG PHY1 passed reset
 */
/*@{*/
#define BP_SRC_SISR_OTGPHY1_PASSED_RESET (2U) /*!< Bit position for SRC_SISR_OTGPHY1_PASSED_RESET. */
#define BM_SRC_SISR_OTGPHY1_PASSED_RESET (0x00000004U) /*!< Bit mask for SRC_SISR_OTGPHY1_PASSED_RESET. */
#define BS_SRC_SISR_OTGPHY1_PASSED_RESET (1U) /*!< Bit field size in bits for SRC_SISR_OTGPHY1_PASSED_RESET. */

/*! @brief Read current value of the SRC_SISR_OTGPHY1_PASSED_RESET field. */
#define BR_SRC_SISR_OTGPHY1_PASSED_RESET(x) (HW_SRC_SISR(x).B.OTGPHY1_PASSED_RESET)
/*@}*/

/*!
 * @name Register SRC_SISR, field OTGPHY2_PASSED_RESET[3] (RO)
 *
 * Interrupt generated to indicate that OTG PHY2 passed software reset and is
 * ready to be used
 *
 * Values:
 * - 0 - Interrupt generated not due to OTG PHY2 passed reset
 * - 1 - Interrupt generated due to OTG PHY2 passed reset
 */
/*@{*/
#define BP_SRC_SISR_OTGPHY2_PASSED_RESET (3U) /*!< Bit position for SRC_SISR_OTGPHY2_PASSED_RESET. */
#define BM_SRC_SISR_OTGPHY2_PASSED_RESET (0x00000008U) /*!< Bit mask for SRC_SISR_OTGPHY2_PASSED_RESET. */
#define BS_SRC_SISR_OTGPHY2_PASSED_RESET (1U) /*!< Bit field size in bits for SRC_SISR_OTGPHY2_PASSED_RESET. */

/*! @brief Read current value of the SRC_SISR_OTGPHY2_PASSED_RESET field. */
#define BR_SRC_SISR_OTGPHY2_PASSED_RESET(x) (HW_SRC_SISR(x).B.OTGPHY2_PASSED_RESET)
/*@}*/

/*!
 * @name Register SRC_SISR, field MIPIPHY_PASSED_RESET[4] (RO)
 *
 * Interrupt generated to indicate that MIPI PHY passed software reset and is
 * ready to be used
 *
 * Values:
 * - 0 - Interrupt generated not due to MIPI PHY passed reset
 * - 1 - Interrupt generated due to MIPI PHY passed reset
 */
/*@{*/
#define BP_SRC_SISR_MIPIPHY_PASSED_RESET (4U) /*!< Bit position for SRC_SISR_MIPIPHY_PASSED_RESET. */
#define BM_SRC_SISR_MIPIPHY_PASSED_RESET (0x00000010U) /*!< Bit mask for SRC_SISR_MIPIPHY_PASSED_RESET. */
#define BS_SRC_SISR_MIPIPHY_PASSED_RESET (1U) /*!< Bit field size in bits for SRC_SISR_MIPIPHY_PASSED_RESET. */

/*! @brief Read current value of the SRC_SISR_MIPIPHY_PASSED_RESET field. */
#define BR_SRC_SISR_MIPIPHY_PASSED_RESET(x) (HW_SRC_SISR(x).B.MIPIPHY_PASSED_RESET)
/*@}*/

/*!
 * @name Register SRC_SISR, field M4C_PASSED_RESET[8] (RO)
 *
 * Interrupt generated to indicate that m4 core passed software reset and is
 * ready to be used
 *
 * Values:
 * - 0 - interrupt generated not due to m4 core reset
 * - 1 - interrupt generated due to m4 core reset
 */
/*@{*/
#define BP_SRC_SISR_M4C_PASSED_RESET (8U)  /*!< Bit position for SRC_SISR_M4C_PASSED_RESET. */
#define BM_SRC_SISR_M4C_PASSED_RESET (0x00000100U) /*!< Bit mask for SRC_SISR_M4C_PASSED_RESET. */
#define BS_SRC_SISR_M4C_PASSED_RESET (1U)  /*!< Bit field size in bits for SRC_SISR_M4C_PASSED_RESET. */

/*! @brief Read current value of the SRC_SISR_M4C_PASSED_RESET field. */
#define BR_SRC_SISR_M4C_PASSED_RESET(x) (HW_SRC_SISR(x).B.M4C_PASSED_RESET)
/*@}*/

/*!
 * @name Register SRC_SISR, field M4P_PASSED_RESET[9] (RO)
 *
 * Interrupt generated to indicate that m4 platform passed software reset and is
 * ready to be used
 *
 * Values:
 * - 0 - interrupt generated not due to m4 platform reset
 * - 1 - interrupt generated due to m4 platform reset
 */
/*@{*/
#define BP_SRC_SISR_M4P_PASSED_RESET (9U)  /*!< Bit position for SRC_SISR_M4P_PASSED_RESET. */
#define BM_SRC_SISR_M4P_PASSED_RESET (0x00000200U) /*!< Bit mask for SRC_SISR_M4P_PASSED_RESET. */
#define BS_SRC_SISR_M4P_PASSED_RESET (1U)  /*!< Bit field size in bits for SRC_SISR_M4P_PASSED_RESET. */

/*! @brief Read current value of the SRC_SISR_M4P_PASSED_RESET field. */
#define BR_SRC_SISR_M4P_PASSED_RESET(x) (HW_SRC_SISR(x).B.M4P_PASSED_RESET)
/*@}*/

/*******************************************************************************
 * HW_SRC_SIMR - SRC Interrupt Mask Register
 ******************************************************************************/

/*!
 * @brief HW_SRC_SIMR - SRC Interrupt Mask Register (RO)
 *
 * Reset value: 0x0000001FU
 */
typedef union _hw_src_simr
{
    uint32_t U;
    struct _hw_src_simr_bitfields
    {
        uint32_t RESERVED0 : 1;        /*!< [0]  */
        uint32_t MASK_HSICPHY_PASSED_RESET : 1; /*!< [1]  */
        uint32_t MASK_OTGPHY1_PASSED_RESET : 1; /*!< [2]  */
        uint32_t MASK_OTGPHY2_PASSED_RESET : 1; /*!< [3]  */
        uint32_t MASK_MIPIPHY_PASSED_RESET : 1; /*!< [4]  */
        uint32_t RESERVED1 : 3;        /*!< [7:5]  */
        uint32_t MASK_M4C_PASSED_RESET : 1; /*!< [8]  */
        uint32_t MASK_M4P_PASSED_RESET : 1; /*!< [9]  */
        uint32_t RESERVED2 : 22;       /*!< [31:10]  */
    } B;
} hw_src_simr_t;

/*!
 * @name Constants and macros for entire SRC_SIMR register
 */
/*@{*/
#define HW_SRC_SIMR_ADDR(x)      ((uintptr_t)(x) + 0x6CU)

#define HW_SRC_SIMR(x)           (*(__I hw_src_simr_t *) HW_SRC_SIMR_ADDR(x))
#define HW_SRC_SIMR_RD(x)        (HW_SRC_SIMR(x).U)
/*@}*/

/*
 * Constants & macros for individual SRC_SIMR bitfields
 */

/*!
 * @name Register SRC_SIMR, field MASK_HSICPHY_PASSED_RESET[1] (RO)
 *
 * mask interrupt generation due to HSIC PHY passed reset
 *
 * Values:
 * - 0 - do not mask interrupt due to HSIC PHY passed reset - interrupt will be
 *     created
 * - 1 - mask interrupt due to HSIC PHY passed reset
 */
/*@{*/
#define BP_SRC_SIMR_MASK_HSICPHY_PASSED_RESET (1U) /*!< Bit position for SRC_SIMR_MASK_HSICPHY_PASSED_RESET. */
#define BM_SRC_SIMR_MASK_HSICPHY_PASSED_RESET (0x00000002U) /*!< Bit mask for SRC_SIMR_MASK_HSICPHY_PASSED_RESET. */
#define BS_SRC_SIMR_MASK_HSICPHY_PASSED_RESET (1U) /*!< Bit field size in bits for SRC_SIMR_MASK_HSICPHY_PASSED_RESET. */

/*! @brief Read current value of the SRC_SIMR_MASK_HSICPHY_PASSED_RESET field. */
#define BR_SRC_SIMR_MASK_HSICPHY_PASSED_RESET(x) (HW_SRC_SIMR(x).B.MASK_HSICPHY_PASSED_RESET)
/*@}*/

/*!
 * @name Register SRC_SIMR, field MASK_OTGPHY1_PASSED_RESET[2] (RO)
 *
 * mask interrupt generation due to OTG PHY1 passed reset
 *
 * Values:
 * - 0 - do not mask interrupt due to OTG PHY1 passed reset - interrupt will be
 *     created
 * - 1 - mask interrupt due to OTG PHY1 passed reset
 */
/*@{*/
#define BP_SRC_SIMR_MASK_OTGPHY1_PASSED_RESET (2U) /*!< Bit position for SRC_SIMR_MASK_OTGPHY1_PASSED_RESET. */
#define BM_SRC_SIMR_MASK_OTGPHY1_PASSED_RESET (0x00000004U) /*!< Bit mask for SRC_SIMR_MASK_OTGPHY1_PASSED_RESET. */
#define BS_SRC_SIMR_MASK_OTGPHY1_PASSED_RESET (1U) /*!< Bit field size in bits for SRC_SIMR_MASK_OTGPHY1_PASSED_RESET. */

/*! @brief Read current value of the SRC_SIMR_MASK_OTGPHY1_PASSED_RESET field. */
#define BR_SRC_SIMR_MASK_OTGPHY1_PASSED_RESET(x) (HW_SRC_SIMR(x).B.MASK_OTGPHY1_PASSED_RESET)
/*@}*/

/*!
 * @name Register SRC_SIMR, field MASK_OTGPHY2_PASSED_RESET[3] (RO)
 *
 * mask interrupt generation due to OTG PHY2 passed reset
 *
 * Values:
 * - 0 - do not mask interrupt due to OTG PHY2 passed reset - interrupt will be
 *     created
 * - 1 - mask interrupt due to OTG PHY2 passed reset
 */
/*@{*/
#define BP_SRC_SIMR_MASK_OTGPHY2_PASSED_RESET (3U) /*!< Bit position for SRC_SIMR_MASK_OTGPHY2_PASSED_RESET. */
#define BM_SRC_SIMR_MASK_OTGPHY2_PASSED_RESET (0x00000008U) /*!< Bit mask for SRC_SIMR_MASK_OTGPHY2_PASSED_RESET. */
#define BS_SRC_SIMR_MASK_OTGPHY2_PASSED_RESET (1U) /*!< Bit field size in bits for SRC_SIMR_MASK_OTGPHY2_PASSED_RESET. */

/*! @brief Read current value of the SRC_SIMR_MASK_OTGPHY2_PASSED_RESET field. */
#define BR_SRC_SIMR_MASK_OTGPHY2_PASSED_RESET(x) (HW_SRC_SIMR(x).B.MASK_OTGPHY2_PASSED_RESET)
/*@}*/

/*!
 * @name Register SRC_SIMR, field MASK_MIPIPHY_PASSED_RESET[4] (RO)
 *
 * mask interrupt generation due to MIPI PHY passed reset
 *
 * Values:
 * - 0 - do not mask interrupt due to MIPI PHY passed reset - interrupt will be
 *     created
 * - 1 - mask interrupt due to MIPI PHY passed reset
 */
/*@{*/
#define BP_SRC_SIMR_MASK_MIPIPHY_PASSED_RESET (4U) /*!< Bit position for SRC_SIMR_MASK_MIPIPHY_PASSED_RESET. */
#define BM_SRC_SIMR_MASK_MIPIPHY_PASSED_RESET (0x00000010U) /*!< Bit mask for SRC_SIMR_MASK_MIPIPHY_PASSED_RESET. */
#define BS_SRC_SIMR_MASK_MIPIPHY_PASSED_RESET (1U) /*!< Bit field size in bits for SRC_SIMR_MASK_MIPIPHY_PASSED_RESET. */

/*! @brief Read current value of the SRC_SIMR_MASK_MIPIPHY_PASSED_RESET field. */
#define BR_SRC_SIMR_MASK_MIPIPHY_PASSED_RESET(x) (HW_SRC_SIMR(x).B.MASK_MIPIPHY_PASSED_RESET)
/*@}*/

/*!
 * @name Register SRC_SIMR, field MASK_M4C_PASSED_RESET[8] (RO)
 *
 * mask interrupt generation due to m4 core passed reset
 *
 * Values:
 * - 0 - do not mask interrupt due to m4 core passed reset - interrupt will be
 *     created
 * - 1 - mask interrupt due to m4 core passed reset
 */
/*@{*/
#define BP_SRC_SIMR_MASK_M4C_PASSED_RESET (8U) /*!< Bit position for SRC_SIMR_MASK_M4C_PASSED_RESET. */
#define BM_SRC_SIMR_MASK_M4C_PASSED_RESET (0x00000100U) /*!< Bit mask for SRC_SIMR_MASK_M4C_PASSED_RESET. */
#define BS_SRC_SIMR_MASK_M4C_PASSED_RESET (1U) /*!< Bit field size in bits for SRC_SIMR_MASK_M4C_PASSED_RESET. */

/*! @brief Read current value of the SRC_SIMR_MASK_M4C_PASSED_RESET field. */
#define BR_SRC_SIMR_MASK_M4C_PASSED_RESET(x) (HW_SRC_SIMR(x).B.MASK_M4C_PASSED_RESET)
/*@}*/

/*!
 * @name Register SRC_SIMR, field MASK_M4P_PASSED_RESET[9] (RO)
 *
 * mask interrupt generation due to m4 platform passed reset
 *
 * Values:
 * - 0 - do not mask interrupt due to m4 platform passed reset - interrupt will
 *     be created
 * - 1 - mask interrupt due to m4platform passed reset
 */
/*@{*/
#define BP_SRC_SIMR_MASK_M4P_PASSED_RESET (9U) /*!< Bit position for SRC_SIMR_MASK_M4P_PASSED_RESET. */
#define BM_SRC_SIMR_MASK_M4P_PASSED_RESET (0x00000200U) /*!< Bit mask for SRC_SIMR_MASK_M4P_PASSED_RESET. */
#define BS_SRC_SIMR_MASK_M4P_PASSED_RESET (1U) /*!< Bit field size in bits for SRC_SIMR_MASK_M4P_PASSED_RESET. */

/*! @brief Read current value of the SRC_SIMR_MASK_M4P_PASSED_RESET field. */
#define BR_SRC_SIMR_MASK_M4P_PASSED_RESET(x) (HW_SRC_SIMR(x).B.MASK_M4P_PASSED_RESET)
/*@}*/

/*******************************************************************************
 * HW_SRC_SBMR2 - SRC Boot Mode Register 2
 ******************************************************************************/

/*!
 * @brief HW_SRC_SBMR2 - SRC Boot Mode Register 2 (RO)
 *
 * Reset value: 0x00000000U
 *
 * The Boot Mode register (SBMR), contains bits that reflect the status of Boot
 * Mode Pins of the chip. The default values for those bits depends on the values
 * of pins/fuses during reset sequence, hence the question mark on their default
 * value.
 */
typedef union _hw_src_sbmr2
{
    uint32_t U;
    struct _hw_src_sbmr2_bitfields
    {
        uint32_t SEC_CONFIG : 2;       /*!< [1:0]  */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t DIR_BT_DIS : 1;       /*!< [3]  */
        uint32_t BT_FUSE_SEL : 1;      /*!< [4]  */
        uint32_t RESERVED1 : 19;       /*!< [23:5]  */
        uint32_t BMOD : 2;             /*!< [25:24]  */
        uint32_t RESERVED2 : 6;        /*!< [31:26]  */
    } B;
} hw_src_sbmr2_t;

/*!
 * @name Constants and macros for entire SRC_SBMR2 register
 */
/*@{*/
#define HW_SRC_SBMR2_ADDR(x)     ((uintptr_t)(x) + 0x70U)

#define HW_SRC_SBMR2(x)          (*(__I hw_src_sbmr2_t *) HW_SRC_SBMR2_ADDR(x))
#define HW_SRC_SBMR2_RD(x)       (HW_SRC_SBMR2(x).U)
/*@}*/

/*
 * Constants & macros for individual SRC_SBMR2 bitfields
 */

/*!
 * @name Register SRC_SBMR2, field SEC_CONFIG[1:0] (RO)
 *
 * SECONFIG[1] shows the state of the SECONFIG[1] fuse. See Fusemap for
 * additional information on this fuse. SECONFIG[0] shows the state of the SECONFIG[0]
 * fuse. This fuse is shown as reserved in Fusemap (address 0x440[1]) because it
 * does not have a user-relevant function.
 */
/*@{*/
#define BP_SRC_SBMR2_SEC_CONFIG (0U)       /*!< Bit position for SRC_SBMR2_SEC_CONFIG. */
#define BM_SRC_SBMR2_SEC_CONFIG (0x00000003U) /*!< Bit mask for SRC_SBMR2_SEC_CONFIG. */
#define BS_SRC_SBMR2_SEC_CONFIG (2U)       /*!< Bit field size in bits for SRC_SBMR2_SEC_CONFIG. */

/*! @brief Read current value of the SRC_SBMR2_SEC_CONFIG field. */
#define BR_SRC_SBMR2_SEC_CONFIG(x) (HW_SRC_SBMR2(x).B.SEC_CONFIG)
/*@}*/

/*!
 * @name Register SRC_SBMR2, field DIR_BT_DIS[3] (RO)
 *
 * DIR_BT_DIS shows the state of the DIR_BT_DIS fuse. See Chapter 5, Fusemap for
 * additional information on this fuse.
 */
/*@{*/
#define BP_SRC_SBMR2_DIR_BT_DIS (3U)       /*!< Bit position for SRC_SBMR2_DIR_BT_DIS. */
#define BM_SRC_SBMR2_DIR_BT_DIS (0x00000008U) /*!< Bit mask for SRC_SBMR2_DIR_BT_DIS. */
#define BS_SRC_SBMR2_DIR_BT_DIS (1U)       /*!< Bit field size in bits for SRC_SBMR2_DIR_BT_DIS. */

/*! @brief Read current value of the SRC_SBMR2_DIR_BT_DIS field. */
#define BR_SRC_SBMR2_DIR_BT_DIS(x) (HW_SRC_SBMR2(x).B.DIR_BT_DIS)
/*@}*/

/*!
 * @name Register SRC_SBMR2, field BT_FUSE_SEL[4] (RO)
 *
 * BT_FUSE_SEL (connected to gpio bt_fuse_sel) shows the state of the
 * BT_FUSE_SEL fuse. See Fusemap for additional information on this fuse.
 */
/*@{*/
#define BP_SRC_SBMR2_BT_FUSE_SEL (4U)      /*!< Bit position for SRC_SBMR2_BT_FUSE_SEL. */
#define BM_SRC_SBMR2_BT_FUSE_SEL (0x00000010U) /*!< Bit mask for SRC_SBMR2_BT_FUSE_SEL. */
#define BS_SRC_SBMR2_BT_FUSE_SEL (1U)      /*!< Bit field size in bits for SRC_SBMR2_BT_FUSE_SEL. */

/*! @brief Read current value of the SRC_SBMR2_BT_FUSE_SEL field. */
#define BR_SRC_SBMR2_BT_FUSE_SEL(x) (HW_SRC_SBMR2(x).B.BT_FUSE_SEL)
/*@}*/

/*!
 * @name Register SRC_SBMR2, field BMOD[25:24] (RO)
 *
 * BMOD[1:0] shows the latched state of the BOOT_MODE1 and BOOT_MODE0 signals on
 * the rising edge of POR_B. See the Boot mode pin settings section of System
 * Boot.
 */
/*@{*/
#define BP_SRC_SBMR2_BMOD    (24U)         /*!< Bit position for SRC_SBMR2_BMOD. */
#define BM_SRC_SBMR2_BMOD    (0x03000000U) /*!< Bit mask for SRC_SBMR2_BMOD. */
#define BS_SRC_SBMR2_BMOD    (2U)          /*!< Bit field size in bits for SRC_SBMR2_BMOD. */

/*! @brief Read current value of the SRC_SBMR2_BMOD field. */
#define BR_SRC_SBMR2_BMOD(x) (HW_SRC_SBMR2(x).B.BMOD)
/*@}*/

/*******************************************************************************
 * HW_SRC_GPR1 - SRC General Purpose Register 1
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR1 - SRC General Purpose Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_gpr1
{
    uint32_t U;
    struct _hw_src_gpr1_bitfields
    {
        uint32_t PERSISTENT_ENTRY0 : 32; /*!< [31:0]  */
    } B;
} hw_src_gpr1_t;

/*!
 * @name Constants and macros for entire SRC_GPR1 register
 */
/*@{*/
#define HW_SRC_GPR1_ADDR(x)      ((uintptr_t)(x) + 0x74U)

#define HW_SRC_GPR1(x)           (*(__IO hw_src_gpr1_t *) HW_SRC_GPR1_ADDR(x))
#define HW_SRC_GPR1_RD(x)        (HW_SRC_GPR1(x).U)
#define HW_SRC_GPR1_WR(x, v)     (HW_SRC_GPR1(x).U = (v))
#define HW_SRC_GPR1_SET(x, v)    (HW_SRC_GPR1_WR(x, HW_SRC_GPR1_RD(x) |  (v)))
#define HW_SRC_GPR1_CLR(x, v)    (HW_SRC_GPR1_WR(x, HW_SRC_GPR1_RD(x) & ~(v)))
#define HW_SRC_GPR1_TOG(x, v)    (HW_SRC_GPR1_WR(x, HW_SRC_GPR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR1 bitfields
 */

/*!
 * @name Register SRC_GPR1, field PERSISTENT_ENTRY0[31:0] (RW)
 *
 * Holds entry function for core0 for waking-up from low power mode. The SRC
 * ensures that the register value will persist across system resets.
 */
/*@{*/
#define BP_SRC_GPR1_PERSISTENT_ENTRY0 (0U) /*!< Bit position for SRC_GPR1_PERSISTENT_ENTRY0. */
#define BM_SRC_GPR1_PERSISTENT_ENTRY0 (0xFFFFFFFFU) /*!< Bit mask for SRC_GPR1_PERSISTENT_ENTRY0. */
#define BS_SRC_GPR1_PERSISTENT_ENTRY0 (32U) /*!< Bit field size in bits for SRC_GPR1_PERSISTENT_ENTRY0. */

/*! @brief Read current value of the SRC_GPR1_PERSISTENT_ENTRY0 field. */
#define BR_SRC_GPR1_PERSISTENT_ENTRY0(x) (HW_SRC_GPR1(x).U)

/*! @brief Format value for bitfield SRC_GPR1_PERSISTENT_ENTRY0. */
#define BF_SRC_GPR1_PERSISTENT_ENTRY0(v) ((uint32_t)((uint32_t)(v) << BP_SRC_GPR1_PERSISTENT_ENTRY0) & BM_SRC_GPR1_PERSISTENT_ENTRY0)

/*! @brief Set the PERSISTENT_ENTRY0 field to a new value. */
#define BW_SRC_GPR1_PERSISTENT_ENTRY0(x, v) (HW_SRC_GPR1_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SRC_GPR2 - SRC General Purpose Register 2
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR2 - SRC General Purpose Register 2 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_gpr2
{
    uint32_t U;
    struct _hw_src_gpr2_bitfields
    {
        uint32_t PERSISTENT_ARG0 : 32; /*!< [31:0]  */
    } B;
} hw_src_gpr2_t;

/*!
 * @name Constants and macros for entire SRC_GPR2 register
 */
/*@{*/
#define HW_SRC_GPR2_ADDR(x)      ((uintptr_t)(x) + 0x78U)

#define HW_SRC_GPR2(x)           (*(__IO hw_src_gpr2_t *) HW_SRC_GPR2_ADDR(x))
#define HW_SRC_GPR2_RD(x)        (HW_SRC_GPR2(x).U)
#define HW_SRC_GPR2_WR(x, v)     (HW_SRC_GPR2(x).U = (v))
#define HW_SRC_GPR2_SET(x, v)    (HW_SRC_GPR2_WR(x, HW_SRC_GPR2_RD(x) |  (v)))
#define HW_SRC_GPR2_CLR(x, v)    (HW_SRC_GPR2_WR(x, HW_SRC_GPR2_RD(x) & ~(v)))
#define HW_SRC_GPR2_TOG(x, v)    (HW_SRC_GPR2_WR(x, HW_SRC_GPR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR2 bitfields
 */

/*!
 * @name Register SRC_GPR2, field PERSISTENT_ARG0[31:0] (RW)
 *
 * Holds argument of entry function for core0 for waking-up from low power mode.
 * The SRC ensures that the register value will persist across system resets.
 */
/*@{*/
#define BP_SRC_GPR2_PERSISTENT_ARG0 (0U)   /*!< Bit position for SRC_GPR2_PERSISTENT_ARG0. */
#define BM_SRC_GPR2_PERSISTENT_ARG0 (0xFFFFFFFFU) /*!< Bit mask for SRC_GPR2_PERSISTENT_ARG0. */
#define BS_SRC_GPR2_PERSISTENT_ARG0 (32U)  /*!< Bit field size in bits for SRC_GPR2_PERSISTENT_ARG0. */

/*! @brief Read current value of the SRC_GPR2_PERSISTENT_ARG0 field. */
#define BR_SRC_GPR2_PERSISTENT_ARG0(x) (HW_SRC_GPR2(x).U)

/*! @brief Format value for bitfield SRC_GPR2_PERSISTENT_ARG0. */
#define BF_SRC_GPR2_PERSISTENT_ARG0(v) ((uint32_t)((uint32_t)(v) << BP_SRC_GPR2_PERSISTENT_ARG0) & BM_SRC_GPR2_PERSISTENT_ARG0)

/*! @brief Set the PERSISTENT_ARG0 field to a new value. */
#define BW_SRC_GPR2_PERSISTENT_ARG0(x, v) (HW_SRC_GPR2_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SRC_GPR3 - SRC General Purpose Register 3
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR3 - SRC General Purpose Register 3 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_gpr3
{
    uint32_t U;
    struct _hw_src_gpr3_bitfields
    {
        uint32_t PERSISTENT_ENTRY1 : 32; /*!< [31:0]  */
    } B;
} hw_src_gpr3_t;

/*!
 * @name Constants and macros for entire SRC_GPR3 register
 */
/*@{*/
#define HW_SRC_GPR3_ADDR(x)      ((uintptr_t)(x) + 0x7CU)

#define HW_SRC_GPR3(x)           (*(__IO hw_src_gpr3_t *) HW_SRC_GPR3_ADDR(x))
#define HW_SRC_GPR3_RD(x)        (HW_SRC_GPR3(x).U)
#define HW_SRC_GPR3_WR(x, v)     (HW_SRC_GPR3(x).U = (v))
#define HW_SRC_GPR3_SET(x, v)    (HW_SRC_GPR3_WR(x, HW_SRC_GPR3_RD(x) |  (v)))
#define HW_SRC_GPR3_CLR(x, v)    (HW_SRC_GPR3_WR(x, HW_SRC_GPR3_RD(x) & ~(v)))
#define HW_SRC_GPR3_TOG(x, v)    (HW_SRC_GPR3_WR(x, HW_SRC_GPR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR3 bitfields
 */

/*!
 * @name Register SRC_GPR3, field PERSISTENT_ENTRY1[31:0] (RW)
 *
 * Holds entry function for core1. The SRC ensures that the register value will
 * persist across system resets.
 */
/*@{*/
#define BP_SRC_GPR3_PERSISTENT_ENTRY1 (0U) /*!< Bit position for SRC_GPR3_PERSISTENT_ENTRY1. */
#define BM_SRC_GPR3_PERSISTENT_ENTRY1 (0xFFFFFFFFU) /*!< Bit mask for SRC_GPR3_PERSISTENT_ENTRY1. */
#define BS_SRC_GPR3_PERSISTENT_ENTRY1 (32U) /*!< Bit field size in bits for SRC_GPR3_PERSISTENT_ENTRY1. */

/*! @brief Read current value of the SRC_GPR3_PERSISTENT_ENTRY1 field. */
#define BR_SRC_GPR3_PERSISTENT_ENTRY1(x) (HW_SRC_GPR3(x).U)

/*! @brief Format value for bitfield SRC_GPR3_PERSISTENT_ENTRY1. */
#define BF_SRC_GPR3_PERSISTENT_ENTRY1(v) ((uint32_t)((uint32_t)(v) << BP_SRC_GPR3_PERSISTENT_ENTRY1) & BM_SRC_GPR3_PERSISTENT_ENTRY1)

/*! @brief Set the PERSISTENT_ENTRY1 field to a new value. */
#define BW_SRC_GPR3_PERSISTENT_ENTRY1(x, v) (HW_SRC_GPR3_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SRC_GPR4 - SRC General Purpose Register 4
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR4 - SRC General Purpose Register 4 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_gpr4
{
    uint32_t U;
    struct _hw_src_gpr4_bitfields
    {
        uint32_t PERSISTENT_ARG1 : 32; /*!< [31:0]  */
    } B;
} hw_src_gpr4_t;

/*!
 * @name Constants and macros for entire SRC_GPR4 register
 */
/*@{*/
#define HW_SRC_GPR4_ADDR(x)      ((uintptr_t)(x) + 0x80U)

#define HW_SRC_GPR4(x)           (*(__IO hw_src_gpr4_t *) HW_SRC_GPR4_ADDR(x))
#define HW_SRC_GPR4_RD(x)        (HW_SRC_GPR4(x).U)
#define HW_SRC_GPR4_WR(x, v)     (HW_SRC_GPR4(x).U = (v))
#define HW_SRC_GPR4_SET(x, v)    (HW_SRC_GPR4_WR(x, HW_SRC_GPR4_RD(x) |  (v)))
#define HW_SRC_GPR4_CLR(x, v)    (HW_SRC_GPR4_WR(x, HW_SRC_GPR4_RD(x) & ~(v)))
#define HW_SRC_GPR4_TOG(x, v)    (HW_SRC_GPR4_WR(x, HW_SRC_GPR4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR4 bitfields
 */

/*!
 * @name Register SRC_GPR4, field PERSISTENT_ARG1[31:0] (RW)
 *
 * Holds argument of entry function for core1. The SRC ensures that the register
 * value will persist across system resets.
 */
/*@{*/
#define BP_SRC_GPR4_PERSISTENT_ARG1 (0U)   /*!< Bit position for SRC_GPR4_PERSISTENT_ARG1. */
#define BM_SRC_GPR4_PERSISTENT_ARG1 (0xFFFFFFFFU) /*!< Bit mask for SRC_GPR4_PERSISTENT_ARG1. */
#define BS_SRC_GPR4_PERSISTENT_ARG1 (32U)  /*!< Bit field size in bits for SRC_GPR4_PERSISTENT_ARG1. */

/*! @brief Read current value of the SRC_GPR4_PERSISTENT_ARG1 field. */
#define BR_SRC_GPR4_PERSISTENT_ARG1(x) (HW_SRC_GPR4(x).U)

/*! @brief Format value for bitfield SRC_GPR4_PERSISTENT_ARG1. */
#define BF_SRC_GPR4_PERSISTENT_ARG1(v) ((uint32_t)((uint32_t)(v) << BP_SRC_GPR4_PERSISTENT_ARG1) & BM_SRC_GPR4_PERSISTENT_ARG1)

/*! @brief Set the PERSISTENT_ARG1 field to a new value. */
#define BW_SRC_GPR4_PERSISTENT_ARG1(x, v) (HW_SRC_GPR4_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_SRC_GPR5 - SRC General Purpose Register 5
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR5 - SRC General Purpose Register 5 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_gpr5
{
    uint32_t U;
    struct _hw_src_gpr5_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_src_gpr5_t;

/*!
 * @name Constants and macros for entire SRC_GPR5 register
 */
/*@{*/
#define HW_SRC_GPR5_ADDR(x)      ((uintptr_t)(x) + 0x84U)

#define HW_SRC_GPR5(x)           (*(__IO hw_src_gpr5_t *) HW_SRC_GPR5_ADDR(x))
#define HW_SRC_GPR5_RD(x)        (HW_SRC_GPR5(x).U)
#define HW_SRC_GPR5_WR(x, v)     (HW_SRC_GPR5(x).U = (v))
#define HW_SRC_GPR5_SET(x, v)    (HW_SRC_GPR5_WR(x, HW_SRC_GPR5_RD(x) |  (v)))
#define HW_SRC_GPR5_CLR(x, v)    (HW_SRC_GPR5_WR(x, HW_SRC_GPR5_RD(x) & ~(v)))
#define HW_SRC_GPR5_TOG(x, v)    (HW_SRC_GPR5_WR(x, HW_SRC_GPR5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR5 bitfields
 */

/*******************************************************************************
 * HW_SRC_GPR6 - SRC General Purpose Register 6
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR6 - SRC General Purpose Register 6 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_gpr6
{
    uint32_t U;
    struct _hw_src_gpr6_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_src_gpr6_t;

/*!
 * @name Constants and macros for entire SRC_GPR6 register
 */
/*@{*/
#define HW_SRC_GPR6_ADDR(x)      ((uintptr_t)(x) + 0x88U)

#define HW_SRC_GPR6(x)           (*(__IO hw_src_gpr6_t *) HW_SRC_GPR6_ADDR(x))
#define HW_SRC_GPR6_RD(x)        (HW_SRC_GPR6(x).U)
#define HW_SRC_GPR6_WR(x, v)     (HW_SRC_GPR6(x).U = (v))
#define HW_SRC_GPR6_SET(x, v)    (HW_SRC_GPR6_WR(x, HW_SRC_GPR6_RD(x) |  (v)))
#define HW_SRC_GPR6_CLR(x, v)    (HW_SRC_GPR6_WR(x, HW_SRC_GPR6_RD(x) & ~(v)))
#define HW_SRC_GPR6_TOG(x, v)    (HW_SRC_GPR6_WR(x, HW_SRC_GPR6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR6 bitfields
 */

/*******************************************************************************
 * HW_SRC_GPR7 - SRC General Purpose Register 7
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR7 - SRC General Purpose Register 7 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_gpr7
{
    uint32_t U;
    struct _hw_src_gpr7_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_src_gpr7_t;

/*!
 * @name Constants and macros for entire SRC_GPR7 register
 */
/*@{*/
#define HW_SRC_GPR7_ADDR(x)      ((uintptr_t)(x) + 0x8CU)

#define HW_SRC_GPR7(x)           (*(__IO hw_src_gpr7_t *) HW_SRC_GPR7_ADDR(x))
#define HW_SRC_GPR7_RD(x)        (HW_SRC_GPR7(x).U)
#define HW_SRC_GPR7_WR(x, v)     (HW_SRC_GPR7(x).U = (v))
#define HW_SRC_GPR7_SET(x, v)    (HW_SRC_GPR7_WR(x, HW_SRC_GPR7_RD(x) |  (v)))
#define HW_SRC_GPR7_CLR(x, v)    (HW_SRC_GPR7_WR(x, HW_SRC_GPR7_RD(x) & ~(v)))
#define HW_SRC_GPR7_TOG(x, v)    (HW_SRC_GPR7_WR(x, HW_SRC_GPR7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR7 bitfields
 */

/*******************************************************************************
 * HW_SRC_GPR8 - SRC General Purpose Register 8
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR8 - SRC General Purpose Register 8 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_gpr8
{
    uint32_t U;
    struct _hw_src_gpr8_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_src_gpr8_t;

/*!
 * @name Constants and macros for entire SRC_GPR8 register
 */
/*@{*/
#define HW_SRC_GPR8_ADDR(x)      ((uintptr_t)(x) + 0x90U)

#define HW_SRC_GPR8(x)           (*(__IO hw_src_gpr8_t *) HW_SRC_GPR8_ADDR(x))
#define HW_SRC_GPR8_RD(x)        (HW_SRC_GPR8(x).U)
#define HW_SRC_GPR8_WR(x, v)     (HW_SRC_GPR8(x).U = (v))
#define HW_SRC_GPR8_SET(x, v)    (HW_SRC_GPR8_WR(x, HW_SRC_GPR8_RD(x) |  (v)))
#define HW_SRC_GPR8_CLR(x, v)    (HW_SRC_GPR8_WR(x, HW_SRC_GPR8_RD(x) & ~(v)))
#define HW_SRC_GPR8_TOG(x, v)    (HW_SRC_GPR8_WR(x, HW_SRC_GPR8_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR8 bitfields
 */

/*******************************************************************************
 * HW_SRC_GPR9 - SRC General Purpose Register 9
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR9 - SRC General Purpose Register 9 (RU)
 *
 * Reset value: 0x00000000U
 *
 * Reserved for Internal Use.
 */
typedef union _hw_src_gpr9
{
    uint32_t U;
    struct _hw_src_gpr9_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_src_gpr9_t;

/*!
 * @name Constants and macros for entire SRC_GPR9 register
 */
/*@{*/
#define HW_SRC_GPR9_ADDR(x)      ((uintptr_t)(x) + 0x94U)
#define HW_SRC_GPR9(x)           (*(__I hw_src_gpr9_t *) HW_SRC_GPR9_ADDR(x))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR9 bitfields
 */

/*******************************************************************************
 * HW_SRC_GPR10 - SRC General Purpose Register 10
 ******************************************************************************/

/*!
 * @brief HW_SRC_GPR10 - SRC General Purpose Register 10 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_src_gpr10
{
    uint32_t U;
    struct _hw_src_gpr10_bitfields
    {
        uint32_t RESERVED0 : 32;       /*!< [31:0]  */
    } B;
} hw_src_gpr10_t;

/*!
 * @name Constants and macros for entire SRC_GPR10 register
 */
/*@{*/
#define HW_SRC_GPR10_ADDR(x)     ((uintptr_t)(x) + 0x98U)

#define HW_SRC_GPR10(x)          (*(__IO hw_src_gpr10_t *) HW_SRC_GPR10_ADDR(x))
#define HW_SRC_GPR10_RD(x)       (HW_SRC_GPR10(x).U)
#define HW_SRC_GPR10_WR(x, v)    (HW_SRC_GPR10(x).U = (v))
#define HW_SRC_GPR10_SET(x, v)   (HW_SRC_GPR10_WR(x, HW_SRC_GPR10_RD(x) |  (v)))
#define HW_SRC_GPR10_CLR(x, v)   (HW_SRC_GPR10_WR(x, HW_SRC_GPR10_RD(x) & ~(v)))
#define HW_SRC_GPR10_TOG(x, v)   (HW_SRC_GPR10_WR(x, HW_SRC_GPR10_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_GPR10 bitfields
 */

/*******************************************************************************
 * HW_SRC_DDRC_RCR - SRC DDR Controller Reset Control Register
 ******************************************************************************/

/*!
 * @brief HW_SRC_DDRC_RCR - SRC DDR Controller Reset Control Register (RW)
 *
 * Reset value: 0x00000003U
 *
 * DDR Controller Reset Control Register
 */
typedef union _hw_src_ddrc_rcr
{
    uint32_t U;
    struct _hw_src_ddrc_rcr_bitfields
    {
        uint32_t DDRC_PRST : 1;        /*!< [0]  */
        uint32_t DDRC_CORE_RST : 1;    /*!< [1]  */
        uint32_t RESERVED0 : 22;       /*!< [23:2]  */
        uint32_t DOMAIN0 : 1;          /*!< [24]  */
        uint32_t DOMAIN1 : 1;          /*!< [25]  */
        uint32_t DOMAIN2 : 1;          /*!< [26]  */
        uint32_t DOMAIN3 : 1;          /*!< [27]  */
        uint32_t RESERVED1 : 2;        /*!< [29:28]  */
        uint32_t LOCK : 1;             /*!< [30]  */
        uint32_t DOM_EN : 1;           /*!< [31]  */
    } B;
} hw_src_ddrc_rcr_t;

/*!
 * @name Constants and macros for entire SRC_DDRC_RCR register
 */
/*@{*/
#define HW_SRC_DDRC_RCR_ADDR(x)  ((uintptr_t)(x) + 0x1000U)

#define HW_SRC_DDRC_RCR(x)       (*(__IO hw_src_ddrc_rcr_t *) HW_SRC_DDRC_RCR_ADDR(x))
#define HW_SRC_DDRC_RCR_RD(x)    (HW_SRC_DDRC_RCR(x).U)
#define HW_SRC_DDRC_RCR_WR(x, v) (HW_SRC_DDRC_RCR(x).U = (v))
#define HW_SRC_DDRC_RCR_SET(x, v) (HW_SRC_DDRC_RCR_WR(x, HW_SRC_DDRC_RCR_RD(x) |  (v)))
#define HW_SRC_DDRC_RCR_CLR(x, v) (HW_SRC_DDRC_RCR_WR(x, HW_SRC_DDRC_RCR_RD(x) & ~(v)))
#define HW_SRC_DDRC_RCR_TOG(x, v) (HW_SRC_DDRC_RCR_WR(x, HW_SRC_DDRC_RCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual SRC_DDRC_RCR bitfields
 */

/*!
 * @name Register SRC_DDRC_RCR, field DDRC_PRST[0] (RW)
 *
 * DDR Controller preset and DDR PHY reset. This bit is set to 1 automatically
 * when fastmix is powered off. This reset can only be released when DDR
 * Controller clock inputs are active and stable for 30 cycles
 *
 * Values:
 * - 0 - De-ssert DDR Controller preset and DDR PHY reset reset
 * - 1 - Assert DDR Controller preset and DDR PHY reset
 */
/*@{*/
#define BP_SRC_DDRC_RCR_DDRC_PRST (0U)     /*!< Bit position for SRC_DDRC_RCR_DDRC_PRST. */
#define BM_SRC_DDRC_RCR_DDRC_PRST (0x00000001U) /*!< Bit mask for SRC_DDRC_RCR_DDRC_PRST. */
#define BS_SRC_DDRC_RCR_DDRC_PRST (1U)     /*!< Bit field size in bits for SRC_DDRC_RCR_DDRC_PRST. */

/*! @brief Read current value of the SRC_DDRC_RCR_DDRC_PRST field. */
#define BR_SRC_DDRC_RCR_DDRC_PRST(x) (HW_SRC_DDRC_RCR(x).B.DDRC_PRST)

/*! @brief Format value for bitfield SRC_DDRC_RCR_DDRC_PRST. */
#define BF_SRC_DDRC_RCR_DDRC_PRST(v) ((uint32_t)((uint32_t)(v) << BP_SRC_DDRC_RCR_DDRC_PRST) & BM_SRC_DDRC_RCR_DDRC_PRST)

/*! @brief Set the DDRC_PRST field to a new value. */
#define BW_SRC_DDRC_RCR_DDRC_PRST(x, v) (HW_SRC_DDRC_RCR_WR(x, (HW_SRC_DDRC_RCR_RD(x) & ~BM_SRC_DDRC_RCR_DDRC_PRST) | BF_SRC_DDRC_RCR_DDRC_PRST(v)))
/*@}*/

/*!
 * @name Register SRC_DDRC_RCR, field DDRC_CORE_RST[1] (RW)
 *
 * DDR Controller core_ddrc_rstn and aresetn. This bit is set to 1 automatically
 * when fastmix is powered off.
 *
 * Values:
 * - 0 - De-ssert DDR controller aresetn and core_ddrc_rstn
 * - 1 - Assert DDR Controller preset and DDR PHY reset
 */
/*@{*/
#define BP_SRC_DDRC_RCR_DDRC_CORE_RST (1U) /*!< Bit position for SRC_DDRC_RCR_DDRC_CORE_RST. */
#define BM_SRC_DDRC_RCR_DDRC_CORE_RST (0x00000002U) /*!< Bit mask for SRC_DDRC_RCR_DDRC_CORE_RST. */
#define BS_SRC_DDRC_RCR_DDRC_CORE_RST (1U) /*!< Bit field size in bits for SRC_DDRC_RCR_DDRC_CORE_RST. */

/*! @brief Read current value of the SRC_DDRC_RCR_DDRC_CORE_RST field. */
#define BR_SRC_DDRC_RCR_DDRC_CORE_RST(x) (HW_SRC_DDRC_RCR(x).B.DDRC_CORE_RST)

/*! @brief Format value for bitfield SRC_DDRC_RCR_DDRC_CORE_RST. */
#define BF_SRC_DDRC_RCR_DDRC_CORE_RST(v) ((uint32_t)((uint32_t)(v) << BP_SRC_DDRC_RCR_DDRC_CORE_RST) & BM_SRC_DDRC_RCR_DDRC_CORE_RST)

/*! @brief Set the DDRC_CORE_RST field to a new value. */
#define BW_SRC_DDRC_RCR_DDRC_CORE_RST(x, v) (HW_SRC_DDRC_RCR_WR(x, (HW_SRC_DDRC_RCR_RD(x) & ~BM_SRC_DDRC_RCR_DDRC_CORE_RST) | BF_SRC_DDRC_RCR_DDRC_CORE_RST(v)))
/*@}*/

/*!
 * @name Register SRC_DDRC_RCR, field DOMAIN0[24] (RW)
 *
 * Domain0 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain0. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain0. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_DDRC_RCR_DOMAIN0 (24U)      /*!< Bit position for SRC_DDRC_RCR_DOMAIN0. */
#define BM_SRC_DDRC_RCR_DOMAIN0 (0x01000000U) /*!< Bit mask for SRC_DDRC_RCR_DOMAIN0. */
#define BS_SRC_DDRC_RCR_DOMAIN0 (1U)       /*!< Bit field size in bits for SRC_DDRC_RCR_DOMAIN0. */

/*! @brief Read current value of the SRC_DDRC_RCR_DOMAIN0 field. */
#define BR_SRC_DDRC_RCR_DOMAIN0(x) (HW_SRC_DDRC_RCR(x).B.DOMAIN0)

/*! @brief Format value for bitfield SRC_DDRC_RCR_DOMAIN0. */
#define BF_SRC_DDRC_RCR_DOMAIN0(v) ((uint32_t)((uint32_t)(v) << BP_SRC_DDRC_RCR_DOMAIN0) & BM_SRC_DDRC_RCR_DOMAIN0)

/*! @brief Set the DOMAIN0 field to a new value. */
#define BW_SRC_DDRC_RCR_DOMAIN0(x, v) (HW_SRC_DDRC_RCR_WR(x, (HW_SRC_DDRC_RCR_RD(x) & ~BM_SRC_DDRC_RCR_DOMAIN0) | BF_SRC_DDRC_RCR_DOMAIN0(v)))
/*@}*/

/*!
 * @name Register SRC_DDRC_RCR, field DOMAIN1[25] (RW)
 *
 * Domain1 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain1. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain1. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_DDRC_RCR_DOMAIN1 (25U)      /*!< Bit position for SRC_DDRC_RCR_DOMAIN1. */
#define BM_SRC_DDRC_RCR_DOMAIN1 (0x02000000U) /*!< Bit mask for SRC_DDRC_RCR_DOMAIN1. */
#define BS_SRC_DDRC_RCR_DOMAIN1 (1U)       /*!< Bit field size in bits for SRC_DDRC_RCR_DOMAIN1. */

/*! @brief Read current value of the SRC_DDRC_RCR_DOMAIN1 field. */
#define BR_SRC_DDRC_RCR_DOMAIN1(x) (HW_SRC_DDRC_RCR(x).B.DOMAIN1)

/*! @brief Format value for bitfield SRC_DDRC_RCR_DOMAIN1. */
#define BF_SRC_DDRC_RCR_DOMAIN1(v) ((uint32_t)((uint32_t)(v) << BP_SRC_DDRC_RCR_DOMAIN1) & BM_SRC_DDRC_RCR_DOMAIN1)

/*! @brief Set the DOMAIN1 field to a new value. */
#define BW_SRC_DDRC_RCR_DOMAIN1(x, v) (HW_SRC_DDRC_RCR_WR(x, (HW_SRC_DDRC_RCR_RD(x) & ~BM_SRC_DDRC_RCR_DOMAIN1) | BF_SRC_DDRC_RCR_DOMAIN1(v)))
/*@}*/

/*!
 * @name Register SRC_DDRC_RCR, field DOMAIN2[26] (RW)
 *
 * Domain2 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain2. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain2. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_DDRC_RCR_DOMAIN2 (26U)      /*!< Bit position for SRC_DDRC_RCR_DOMAIN2. */
#define BM_SRC_DDRC_RCR_DOMAIN2 (0x04000000U) /*!< Bit mask for SRC_DDRC_RCR_DOMAIN2. */
#define BS_SRC_DDRC_RCR_DOMAIN2 (1U)       /*!< Bit field size in bits for SRC_DDRC_RCR_DOMAIN2. */

/*! @brief Read current value of the SRC_DDRC_RCR_DOMAIN2 field. */
#define BR_SRC_DDRC_RCR_DOMAIN2(x) (HW_SRC_DDRC_RCR(x).B.DOMAIN2)

/*! @brief Format value for bitfield SRC_DDRC_RCR_DOMAIN2. */
#define BF_SRC_DDRC_RCR_DOMAIN2(v) ((uint32_t)((uint32_t)(v) << BP_SRC_DDRC_RCR_DOMAIN2) & BM_SRC_DDRC_RCR_DOMAIN2)

/*! @brief Set the DOMAIN2 field to a new value. */
#define BW_SRC_DDRC_RCR_DOMAIN2(x, v) (HW_SRC_DDRC_RCR_WR(x, (HW_SRC_DDRC_RCR_RD(x) & ~BM_SRC_DDRC_RCR_DOMAIN2) | BF_SRC_DDRC_RCR_DOMAIN2(v)))
/*@}*/

/*!
 * @name Register SRC_DDRC_RCR, field DOMAIN3[27] (RW)
 *
 * Domain3 assignment control. Effective when dom_en is set to 1.
 *
 * Values:
 * - 0 - This register is not assigned to domain3. The master from domain3
 *     cannot write to this register.
 * - 1 - This register is assigned to domain3. The master from domain3 can write
 *     to this register
 */
/*@{*/
#define BP_SRC_DDRC_RCR_DOMAIN3 (27U)      /*!< Bit position for SRC_DDRC_RCR_DOMAIN3. */
#define BM_SRC_DDRC_RCR_DOMAIN3 (0x08000000U) /*!< Bit mask for SRC_DDRC_RCR_DOMAIN3. */
#define BS_SRC_DDRC_RCR_DOMAIN3 (1U)       /*!< Bit field size in bits for SRC_DDRC_RCR_DOMAIN3. */

/*! @brief Read current value of the SRC_DDRC_RCR_DOMAIN3 field. */
#define BR_SRC_DDRC_RCR_DOMAIN3(x) (HW_SRC_DDRC_RCR(x).B.DOMAIN3)

/*! @brief Format value for bitfield SRC_DDRC_RCR_DOMAIN3. */
#define BF_SRC_DDRC_RCR_DOMAIN3(v) ((uint32_t)((uint32_t)(v) << BP_SRC_DDRC_RCR_DOMAIN3) & BM_SRC_DDRC_RCR_DOMAIN3)

/*! @brief Set the DOMAIN3 field to a new value. */
#define BW_SRC_DDRC_RCR_DOMAIN3(x, v) (HW_SRC_DDRC_RCR_WR(x, (HW_SRC_DDRC_RCR_RD(x) & ~BM_SRC_DDRC_RCR_DOMAIN3) | BF_SRC_DDRC_RCR_DOMAIN3(v)))
/*@}*/

/*!
 * @name Register SRC_DDRC_RCR, field LOCK[30] (RW)
 *
 * Domain control bits lock Lock bit is a write-once register, once it is set to
 * 1, it can't be write to 0
 *
 * Values:
 * - 0 - [31] and [27:24] bits can be modified
 * - 1 - [31] and [27:24] bits cannot be modified
 */
/*@{*/
#define BP_SRC_DDRC_RCR_LOCK (30U)         /*!< Bit position for SRC_DDRC_RCR_LOCK. */
#define BM_SRC_DDRC_RCR_LOCK (0x40000000U) /*!< Bit mask for SRC_DDRC_RCR_LOCK. */
#define BS_SRC_DDRC_RCR_LOCK (1U)          /*!< Bit field size in bits for SRC_DDRC_RCR_LOCK. */

/*! @brief Read current value of the SRC_DDRC_RCR_LOCK field. */
#define BR_SRC_DDRC_RCR_LOCK(x) (HW_SRC_DDRC_RCR(x).B.LOCK)

/*! @brief Format value for bitfield SRC_DDRC_RCR_LOCK. */
#define BF_SRC_DDRC_RCR_LOCK(v) ((uint32_t)((uint32_t)(v) << BP_SRC_DDRC_RCR_LOCK) & BM_SRC_DDRC_RCR_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_SRC_DDRC_RCR_LOCK(x, v) (HW_SRC_DDRC_RCR_WR(x, (HW_SRC_DDRC_RCR_RD(x) & ~BM_SRC_DDRC_RCR_LOCK) | BF_SRC_DDRC_RCR_LOCK(v)))
/*@}*/

/*!
 * @name Register SRC_DDRC_RCR, field DOM_EN[31] (RW)
 *
 * Domain Control enable for this register. [31:30] and [27:24] areas are not
 * controlled by this bit. [31:30] and [27:24] area can be modified by any masters
 * from any domains when Lock bit is not set.
 *
 * Values:
 * - 0 - Disables domain control. All of this register's bits except [31:30] and
 *     [27:24] can be modified by any masters
 * - 1 - Enables domain control. All of this register's bits except [31:30] and
 *     [27:24] can only be modified by the masters from the domains specified in
 *     [27:24] area.
 */
/*@{*/
#define BP_SRC_DDRC_RCR_DOM_EN (31U)       /*!< Bit position for SRC_DDRC_RCR_DOM_EN. */
#define BM_SRC_DDRC_RCR_DOM_EN (0x80000000U) /*!< Bit mask for SRC_DDRC_RCR_DOM_EN. */
#define BS_SRC_DDRC_RCR_DOM_EN (1U)        /*!< Bit field size in bits for SRC_DDRC_RCR_DOM_EN. */

/*! @brief Read current value of the SRC_DDRC_RCR_DOM_EN field. */
#define BR_SRC_DDRC_RCR_DOM_EN(x) (HW_SRC_DDRC_RCR(x).B.DOM_EN)

/*! @brief Format value for bitfield SRC_DDRC_RCR_DOM_EN. */
#define BF_SRC_DDRC_RCR_DOM_EN(v) ((uint32_t)((uint32_t)(v) << BP_SRC_DDRC_RCR_DOM_EN) & BM_SRC_DDRC_RCR_DOM_EN)

/*! @brief Set the DOM_EN field to a new value. */
#define BW_SRC_DDRC_RCR_DOM_EN(x, v) (HW_SRC_DDRC_RCR_WR(x, (HW_SRC_DDRC_RCR_RD(x) & ~BM_SRC_DDRC_RCR_DOM_EN) | BF_SRC_DDRC_RCR_DOM_EN(v)))
/*@}*/

/*******************************************************************************
 * hw_src_t - module struct
 ******************************************************************************/
/*!
 * @brief All SRC module registers.
 */
#pragma pack(1)
typedef struct _hw_src
{
    __IO hw_src_scr_t SCR;                 /*!< [0x0] SRC Reset Control Register */
    __IO hw_src_a7rcr0_t A7RCR0;           /*!< [0x4] A7 Reset Control Register */
    __IO hw_src_a7rcr1_t A7RCR1;           /*!< [0x8] A7 Reset Control Register */
    __IO hw_src_m4rcr_t M4RCR;             /*!< [0xC] M4 Reset Control Register */
    uint8_t _reserved0[4];
    __IO hw_src_ercr_t ERCR;               /*!< [0x14] EIM Reset Control Register */
    uint8_t _reserved1[4];
    __IO hw_src_hsicphy_rcr_t HSICPHY_RCR; /*!< [0x1C] HSIC PHY Reset Control Register */
    __IO hw_src_usbophy1_rcr_t USBOPHY1_RCR; /*!< [0x20] USB OTG PHY1 Reset Control Register */
    __IO hw_src_usbophy2_rcr_t USBOPHY2_RCR; /*!< [0x24] USB OTG PHY2 Reset Control Register */
    __IO hw_src_mipiphy_rcr_t MIPIPHY_RCR; /*!< [0x28] MIPI PHY Reset Control Register */
    __IO hw_src_pciephy_rcr_t PCIEPHY_RCR; /*!< [0x2C] PCIE PHY Reset Control Register */
    uint8_t _reserved2[40];
    __I hw_src_sbmr1_t SBMR1;              /*!< [0x58] SRC Boot Mode Register 1 */
    __IO hw_src_srsr_t SRSR;               /*!< [0x5C] SRC Reset Status Register */
    uint8_t _reserved3[8];
    __I hw_src_sisr_t SISR;                /*!< [0x68] SRC Interrupt Status Register */
    __I hw_src_simr_t SIMR;                /*!< [0x6C] SRC Interrupt Mask Register */
    __I hw_src_sbmr2_t SBMR2;              /*!< [0x70] SRC Boot Mode Register 2 */
    __IO hw_src_gpr1_t GPR1;               /*!< [0x74] SRC General Purpose Register 1 */
    __IO hw_src_gpr2_t GPR2;               /*!< [0x78] SRC General Purpose Register 2 */
    __IO hw_src_gpr3_t GPR3;               /*!< [0x7C] SRC General Purpose Register 3 */
    __IO hw_src_gpr4_t GPR4;               /*!< [0x80] SRC General Purpose Register 4 */
    __IO hw_src_gpr5_t GPR5;               /*!< [0x84] SRC General Purpose Register 5 */
    __IO hw_src_gpr6_t GPR6;               /*!< [0x88] SRC General Purpose Register 6 */
    __IO hw_src_gpr7_t GPR7;               /*!< [0x8C] SRC General Purpose Register 7 */
    __IO hw_src_gpr8_t GPR8;               /*!< [0x90] SRC General Purpose Register 8 */
    __I hw_src_gpr9_t GPR9;                /*!< [0x94] SRC General Purpose Register 9 */
    __IO hw_src_gpr10_t GPR10;             /*!< [0x98] SRC General Purpose Register 10 */
    uint8_t _reserved4[3940];
    __IO hw_src_ddrc_rcr_t DDRC_RCR;       /*!< [0x1000] SRC DDR Controller Reset Control Register */
} hw_src_t;
#pragma pack()

/*! @brief Macro to access all SRC registers. */
/*! @param x SRC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_SRC_REGS(SRC_BASE)</code>. */
#define HW_SRC_REGS(x) (*(hw_src_t *)(x))

/*
 * iMX7D TEMPMON
 *
 * Temperature Monitor
 *
 * Registers defined in this header file:
 * - HW_TEMPMON_HW_ANADIG_TEMPSENSE0 - Anadig Tempsensor Control Register 0
 * - HW_TEMPMON_HW_ANADIG_TEMPSENSE1 - Anadig Tempsensor Control Register 1
 * - HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM - Anadig Tempsensor Trim Control Register
 *
 * - hw_tempmon_t - Struct containing all module registers.
 */

#define HW_TEMPMON_INSTANCE_COUNT (1U) /*!< Number of instances of the TEMPMON module. */
#define HW_TEMPMON (0U) /*!< Instance number for TEMPMON. */
#define TEMPMON_BASE          (0x30360300U) /*!< Base address for TEMPMON. */
/*! Array initializer of TEMPMON base addresses. */
#define TEMPMON_BASE_ADDRS    { TEMPMON_BASE }

/*******************************************************************************
 * HW_TEMPMON_HW_ANADIG_TEMPSENSE0 - Anadig Tempsensor Control Register 0
 ******************************************************************************/

/*!
 * @brief HW_TEMPMON_HW_ANADIG_TEMPSENSE0 - Anadig Tempsensor Control Register 0 (RW)
 *
 * Reset value: 0x07FFFE00U
 *
 * This register defines the alarm and panic functions for the temperature
 * sensor.
 */
typedef union _hw_tempmon_hw_anadig_tempsense0
{
    uint32_t U;
    struct _hw_tempmon_hw_anadig_tempsense0_bitfields
    {
        uint32_t LOW_ALARM_VALUE : 9;  /*!< [8:0]  */
        uint32_t HIGH_ALARM_VALUE : 9; /*!< [17:9]  */
        uint32_t PANIC_ALARM_VALUE : 9; /*!< [26:18]  */
        uint32_t RSVD1 : 5;            /*!< [31:27]  */
    } B;
} hw_tempmon_hw_anadig_tempsense0_t;

/*!
 * @name Constants and macros for entire TEMPMON_HW_ANADIG_TEMPSENSE0 register
 */
/*@{*/
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE0_ADDR(x) ((uintptr_t)(x) + 0x300U)
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE0_SET_ADDR(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE0_ADDR(x) + 0x4U)
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_ADDR(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE0_ADDR(x) + 0x8U)
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_ADDR(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE0_ADDR(x) + 0xCU)

#define HW_TEMPMON_HW_ANADIG_TEMPSENSE0(x) (*(__IO hw_tempmon_hw_anadig_tempsense0_t *) HW_TEMPMON_HW_ANADIG_TEMPSENSE0_ADDR(x))
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE0_RD(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE0(x).U)
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE0_WR(x, v) (HW_TEMPMON_HW_ANADIG_TEMPSENSE0(x).U = (v))
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE0_SET(x, v) ((*(uint32_t *) HW_TEMPMON_HW_ANADIG_TEMPSENSE0_SET_ADDR(x)) = (v))
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE0_CLR(x, v) ((*(uint32_t *) HW_TEMPMON_HW_ANADIG_TEMPSENSE0_CLR_ADDR(x)) = (v))
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE0_TOG(x, v) ((*(uint32_t *) HW_TEMPMON_HW_ANADIG_TEMPSENSE0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual TEMPMON_HW_ANADIG_TEMPSENSE0 bitfields
 */

/*!
 * @name Register TEMPMON_HW_ANADIG_TEMPSENSE0, field LOW_ALARM_VALUE[8:0] (RW)
 *
 * This bit field contains the temperature measurement that will issue a low
 * temperature interrupt.
 */
/*@{*/
#define BP_TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE (0U) /*!< Bit position for TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE. */
#define BM_TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE (0x000001FFU) /*!< Bit mask for TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE. */
#define BS_TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE (9U) /*!< Bit field size in bits for TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE. */

/*! @brief Read current value of the TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE field. */
#define BR_TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE0(x).B.LOW_ALARM_VALUE)

/*! @brief Format value for bitfield TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE. */
#define BF_TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE) & BM_TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE)

/*! @brief Set the LOW_ALARM_VALUE field to a new value. */
#define BW_TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE(x, v) (HW_TEMPMON_HW_ANADIG_TEMPSENSE0_WR(x, (HW_TEMPMON_HW_ANADIG_TEMPSENSE0_RD(x) & ~BM_TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE) | BF_TEMPMON_HW_ANADIG_TEMPSENSE0_LOW_ALARM_VALUE(v)))
/*@}*/

/*!
 * @name Register TEMPMON_HW_ANADIG_TEMPSENSE0, field HIGH_ALARM_VALUE[17:9] (RW)
 *
 * This bit field contains the temperature measurement that will issue a high
 * temperature interrupt
 */
/*@{*/
#define BP_TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE (9U) /*!< Bit position for TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE. */
#define BM_TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE (0x0003FE00U) /*!< Bit mask for TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE. */
#define BS_TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE (9U) /*!< Bit field size in bits for TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE. */

/*! @brief Read current value of the TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE field. */
#define BR_TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE0(x).B.HIGH_ALARM_VALUE)

/*! @brief Format value for bitfield TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE. */
#define BF_TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE) & BM_TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE)

/*! @brief Set the HIGH_ALARM_VALUE field to a new value. */
#define BW_TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE(x, v) (HW_TEMPMON_HW_ANADIG_TEMPSENSE0_WR(x, (HW_TEMPMON_HW_ANADIG_TEMPSENSE0_RD(x) & ~BM_TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE) | BF_TEMPMON_HW_ANADIG_TEMPSENSE0_HIGH_ALARM_VALUE(v)))
/*@}*/

/*!
 * @name Register TEMPMON_HW_ANADIG_TEMPSENSE0, field PANIC_ALARM_VALUE[26:18] (RW)
 *
 * This bit field contains the temperature measurement that will cause a panic
 * and reset the chip.
 */
/*@{*/
#define BP_TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE (18U) /*!< Bit position for TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE. */
#define BM_TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE (0x07FC0000U) /*!< Bit mask for TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE. */
#define BS_TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE (9U) /*!< Bit field size in bits for TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE. */

/*! @brief Read current value of the TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE field. */
#define BR_TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE0(x).B.PANIC_ALARM_VALUE)

/*! @brief Format value for bitfield TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE. */
#define BF_TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE(v) ((uint32_t)((uint32_t)(v) << BP_TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE) & BM_TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE)

/*! @brief Set the PANIC_ALARM_VALUE field to a new value. */
#define BW_TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE(x, v) (HW_TEMPMON_HW_ANADIG_TEMPSENSE0_WR(x, (HW_TEMPMON_HW_ANADIG_TEMPSENSE0_RD(x) & ~BM_TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE) | BF_TEMPMON_HW_ANADIG_TEMPSENSE0_PANIC_ALARM_VALUE(v)))
/*@}*/

/*!
 * @name Register TEMPMON_HW_ANADIG_TEMPSENSE0, field RSVD1[31:27] (RO)
 *
 * This bit field contains the last measured temperature.
 */
/*@{*/
#define BP_TEMPMON_HW_ANADIG_TEMPSENSE0_RSVD1 (27U) /*!< Bit position for TEMPMON_HW_ANADIG_TEMPSENSE0_RSVD1. */
#define BM_TEMPMON_HW_ANADIG_TEMPSENSE0_RSVD1 (0xF8000000U) /*!< Bit mask for TEMPMON_HW_ANADIG_TEMPSENSE0_RSVD1. */
#define BS_TEMPMON_HW_ANADIG_TEMPSENSE0_RSVD1 (5U) /*!< Bit field size in bits for TEMPMON_HW_ANADIG_TEMPSENSE0_RSVD1. */

/*! @brief Read current value of the TEMPMON_HW_ANADIG_TEMPSENSE0_RSVD1 field. */
#define BR_TEMPMON_HW_ANADIG_TEMPSENSE0_RSVD1(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE0(x).B.RSVD1)
/*@}*/




/*******************************************************************************
 * HW_TEMPMON_HW_ANADIG_TEMPSENSE1 - Anadig Tempsensor Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_TEMPMON_HW_ANADIG_TEMPSENSE1 - Anadig Tempsensor Control Register 1 (RW)
 *
 * Reset value: 0x00010219U
 *
 * This register defines the automatic repeat time of the temperature sensor.
 */
typedef union _hw_tempmon_hw_anadig_tempsense1
{
    uint32_t U;
    struct _hw_tempmon_hw_anadig_tempsense1_bitfields
    {
        uint32_t TEMP_VALUE : 9;       /*!< [8:0]  */
        uint32_t POWER_DOWN : 1;       /*!< [9]  */
        uint32_t MEASURE_TEMP : 1;     /*!< [10]  */
        uint32_t FINISHED : 1;         /*!< [11]  */
        uint32_t RSVD0 : 4;            /*!< [15:12]  */
        uint32_t MEASURE_FREQ : 16;    /*!< [31:16]  */
    } B;
} hw_tempmon_hw_anadig_tempsense1_t;

/*!
 * @name Constants and macros for entire TEMPMON_HW_ANADIG_TEMPSENSE1 register
 */
/*@{*/
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE1_ADDR(x) ((uintptr_t)(x) + 0x310U)
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE1_SET_ADDR(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE1_ADDR(x) + 0x4U)
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_ADDR(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE1_ADDR(x) + 0x8U)
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_ADDR(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE1_ADDR(x) + 0xCU)

#define HW_TEMPMON_HW_ANADIG_TEMPSENSE1(x) (*(__IO hw_tempmon_hw_anadig_tempsense1_t *) HW_TEMPMON_HW_ANADIG_TEMPSENSE1_ADDR(x))
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE1_RD(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE1(x).U)
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE1_WR(x, v) (HW_TEMPMON_HW_ANADIG_TEMPSENSE1(x).U = (v))
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE1_SET(x, v) ((*(uint32_t *) HW_TEMPMON_HW_ANADIG_TEMPSENSE1_SET_ADDR(x)) = (v))
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE1_CLR(x, v) ((*(uint32_t *) HW_TEMPMON_HW_ANADIG_TEMPSENSE1_CLR_ADDR(x)) = (v))
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE1_TOG(x, v) ((*(uint32_t *) HW_TEMPMON_HW_ANADIG_TEMPSENSE1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual TEMPMON_HW_ANADIG_TEMPSENSE1 bitfields
 */

/*!
 * @name Register TEMPMON_HW_ANADIG_TEMPSENSE1, field TEMP_VALUE[8:0] (RO)
 *
 * This bit field contains the temperature measurement.
 */
/*@{*/
#define BP_TEMPMON_HW_ANADIG_TEMPSENSE1_TEMP_VALUE (0U) /*!< Bit position for TEMPMON_HW_ANADIG_TEMPSENSE1_TEMP_VALUE. */
#define BM_TEMPMON_HW_ANADIG_TEMPSENSE1_TEMP_VALUE (0x000001FFU) /*!< Bit mask for TEMPMON_HW_ANADIG_TEMPSENSE1_TEMP_VALUE. */
#define BS_TEMPMON_HW_ANADIG_TEMPSENSE1_TEMP_VALUE (9U) /*!< Bit field size in bits for TEMPMON_HW_ANADIG_TEMPSENSE1_TEMP_VALUE. */

/*! @brief Read current value of the TEMPMON_HW_ANADIG_TEMPSENSE1_TEMP_VALUE field. */
#define BR_TEMPMON_HW_ANADIG_TEMPSENSE1_TEMP_VALUE(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE1(x).B.TEMP_VALUE)
/*@}*/

/*!
 * @name Register TEMPMON_HW_ANADIG_TEMPSENSE1, field POWER_DOWN[9] (RW)
 *
 * This bit powers down the temperature sensor.
 */
/*@{*/
#define BP_TEMPMON_HW_ANADIG_TEMPSENSE1_POWER_DOWN (9U) /*!< Bit position for TEMPMON_HW_ANADIG_TEMPSENSE1_POWER_DOWN. */
#define BM_TEMPMON_HW_ANADIG_TEMPSENSE1_POWER_DOWN (0x00000200U) /*!< Bit mask for TEMPMON_HW_ANADIG_TEMPSENSE1_POWER_DOWN. */
#define BS_TEMPMON_HW_ANADIG_TEMPSENSE1_POWER_DOWN (1U) /*!< Bit field size in bits for TEMPMON_HW_ANADIG_TEMPSENSE1_POWER_DOWN. */

/*! @brief Read current value of the TEMPMON_HW_ANADIG_TEMPSENSE1_POWER_DOWN field. */
#define BR_TEMPMON_HW_ANADIG_TEMPSENSE1_POWER_DOWN(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE1(x).B.POWER_DOWN)

/*! @brief Format value for bitfield TEMPMON_HW_ANADIG_TEMPSENSE1_POWER_DOWN. */
#define BF_TEMPMON_HW_ANADIG_TEMPSENSE1_POWER_DOWN(v) ((uint32_t)((uint32_t)(v) << BP_TEMPMON_HW_ANADIG_TEMPSENSE1_POWER_DOWN) & BM_TEMPMON_HW_ANADIG_TEMPSENSE1_POWER_DOWN)

/*! @brief Set the POWER_DOWN field to a new value. */
#define BW_TEMPMON_HW_ANADIG_TEMPSENSE1_POWER_DOWN(x, v) (HW_TEMPMON_HW_ANADIG_TEMPSENSE1_WR(x, (HW_TEMPMON_HW_ANADIG_TEMPSENSE1_RD(x) & ~BM_TEMPMON_HW_ANADIG_TEMPSENSE1_POWER_DOWN) | BF_TEMPMON_HW_ANADIG_TEMPSENSE1_POWER_DOWN(v)))
/*@}*/

/*!
 * @name Register TEMPMON_HW_ANADIG_TEMPSENSE1, field MEASURE_TEMP[10] (RW)
 *
 * Starts the measurement process. If the measurement frequency is zero in the
 * tempsens_1 register. This results in a single conversion.
 */
/*@{*/
#define BP_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_TEMP (10U) /*!< Bit position for TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_TEMP. */
#define BM_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_TEMP (0x00000400U) /*!< Bit mask for TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_TEMP. */
#define BS_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_TEMP (1U) /*!< Bit field size in bits for TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_TEMP. */

/*! @brief Read current value of the TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_TEMP field. */
#define BR_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_TEMP(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE1(x).B.MEASURE_TEMP)

/*! @brief Format value for bitfield TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_TEMP. */
#define BF_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_TEMP(v) ((uint32_t)((uint32_t)(v) << BP_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_TEMP) & BM_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_TEMP)

/*! @brief Set the MEASURE_TEMP field to a new value. */
#define BW_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_TEMP(x, v) (HW_TEMPMON_HW_ANADIG_TEMPSENSE1_WR(x, (HW_TEMPMON_HW_ANADIG_TEMPSENSE1_RD(x) & ~BM_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_TEMP) | BF_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_TEMP(v)))
/*@}*/

/*!
 * @name Register TEMPMON_HW_ANADIG_TEMPSENSE1, field FINISHED[11] (RO)
 *
 * Indicates that the latest temp is valid. This bit should be cleared by the
 * sensor after the start of each measurement.
 */
/*@{*/
#define BP_TEMPMON_HW_ANADIG_TEMPSENSE1_FINISHED (11U) /*!< Bit position for TEMPMON_HW_ANADIG_TEMPSENSE1_FINISHED. */
#define BM_TEMPMON_HW_ANADIG_TEMPSENSE1_FINISHED (0x00000800U) /*!< Bit mask for TEMPMON_HW_ANADIG_TEMPSENSE1_FINISHED. */
#define BS_TEMPMON_HW_ANADIG_TEMPSENSE1_FINISHED (1U) /*!< Bit field size in bits for TEMPMON_HW_ANADIG_TEMPSENSE1_FINISHED. */

/*! @brief Read current value of the TEMPMON_HW_ANADIG_TEMPSENSE1_FINISHED field. */
#define BR_TEMPMON_HW_ANADIG_TEMPSENSE1_FINISHED(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE1(x).B.FINISHED)
/*@}*/

/*!
 * @name Register TEMPMON_HW_ANADIG_TEMPSENSE1, field RSVD0[15:12] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_TEMPMON_HW_ANADIG_TEMPSENSE1_RSVD0 (12U) /*!< Bit position for TEMPMON_HW_ANADIG_TEMPSENSE1_RSVD0. */
#define BM_TEMPMON_HW_ANADIG_TEMPSENSE1_RSVD0 (0x0000F000U) /*!< Bit mask for TEMPMON_HW_ANADIG_TEMPSENSE1_RSVD0. */
#define BS_TEMPMON_HW_ANADIG_TEMPSENSE1_RSVD0 (4U) /*!< Bit field size in bits for TEMPMON_HW_ANADIG_TEMPSENSE1_RSVD0. */

/*! @brief Read current value of the TEMPMON_HW_ANADIG_TEMPSENSE1_RSVD0 field. */
#define BR_TEMPMON_HW_ANADIG_TEMPSENSE1_RSVD0(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE1(x).B.RSVD0)
/*@}*/

/*!
 * @name Register TEMPMON_HW_ANADIG_TEMPSENSE1, field MEASURE_FREQ[31:16] (RW)
 *
 * This bits determines how many RTC clocks to wait before automatically
 * repeating a temperature measurement. 0x0000 - defines a single measurement with no
 * repeat. 0xFFFF determines a two second sample rate with a 32.768KHz RTC clock.
 * Exact timings depend on the accuracy of the RTC clock.
 */
/*@{*/
#define BP_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ (16U) /*!< Bit position for TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ. */
#define BM_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ (0xFFFF0000U) /*!< Bit mask for TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ. */
#define BS_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ (16U) /*!< Bit field size in bits for TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ. */

/*! @brief Read current value of the TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ field. */
#define BR_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE1(x).B.MEASURE_FREQ)

/*! @brief Format value for bitfield TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ. */
#define BF_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ(v) ((uint32_t)((uint32_t)(v) << BP_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ) & BM_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ)

/*! @brief Set the MEASURE_FREQ field to a new value. */
#define BW_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ(x, v) (HW_TEMPMON_HW_ANADIG_TEMPSENSE1_WR(x, (HW_TEMPMON_HW_ANADIG_TEMPSENSE1_RD(x) & ~BM_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ) | BF_TEMPMON_HW_ANADIG_TEMPSENSE1_MEASURE_FREQ(v)))
/*@}*/




/*******************************************************************************
 * HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM - Anadig Tempsensor Trim Control Register
 ******************************************************************************/

/*!
 * @brief HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM - Anadig Tempsensor Trim Control Register (RW)
 *
 * Reset value: 0xC0800010U
 *
 * This register defines the automatic repeat time of the temperature sensor.
 */
typedef union _hw_tempmon_hw_anadig_tempsense_trim
{
    uint32_t U;
    struct _hw_tempmon_hw_anadig_tempsense_trim_bitfields
    {
        uint32_t T_BUF_VREF_SEL : 5;   /*!< [4:0]  */
        uint32_t RSVD0 : 2;            /*!< [6:5]  */
        uint32_t T_EN_READ : 1;        /*!< [7]  */
        uint32_t T_VREF_VBE_SEL : 9;   /*!< [16:8]  */
        uint32_t RSVD1 : 3;            /*!< [19:17]  */
        uint32_t T_BUF_SLOPE_SEL : 4;  /*!< [23:20]  */
        uint32_t RSVD2 : 5;            /*!< [28:24]  */
        uint32_t T_MUX_ADDR : 3;       /*!< [31:29]  */
    } B;
} hw_tempmon_hw_anadig_tempsense_trim_t;

/*!
 * @name Constants and macros for entire TEMPMON_HW_ANADIG_TEMPSENSE_TRIM register
 */
/*@{*/
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_ADDR(x) ((uintptr_t)(x) + 0x320U)
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_ADDR(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_ADDR(x) + 0x4U)
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_ADDR(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_ADDR(x) + 0x8U)
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_ADDR(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_ADDR(x) + 0xCU)

#define HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM(x) (*(__IO hw_tempmon_hw_anadig_tempsense_trim_t *) HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_ADDR(x))
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RD(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM(x).U)
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_WR(x, v) (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM(x).U = (v))
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET(x, v) ((*(uint32_t *) HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_SET_ADDR(x)) = (v))
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR(x, v) ((*(uint32_t *) HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_CLR_ADDR(x)) = (v))
#define HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG(x, v) ((*(uint32_t *) HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual TEMPMON_HW_ANADIG_TEMPSENSE_TRIM bitfields
 */

/*!
 * @name Register TEMPMON_HW_ANADIG_TEMPSENSE_TRIM, field T_BUF_VREF_SEL[4:0] (RW)
 *
 * Reference voltage setting bits for the am-plifier in the Positive-TC
 * generator block. Default: 10000
 */
/*@{*/
#define BP_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL (0U) /*!< Bit position for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL. */
#define BM_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL (0x0000001FU) /*!< Bit mask for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL. */
#define BS_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL (5U) /*!< Bit field size in bits for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL. */

/*! @brief Read current value of the TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL field. */
#define BR_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM(x).B.T_BUF_VREF_SEL)

/*! @brief Format value for bitfield TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL. */
#define BF_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL(v) ((uint32_t)((uint32_t)(v) << BP_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL) & BM_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL)

/*! @brief Set the T_BUF_VREF_SEL field to a new value. */
#define BW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL(x, v) (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_WR(x, (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RD(x) & ~BM_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL) | BF_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_VREF_SEL(v)))
/*@}*/

/*!
 * @name Register TEMPMON_HW_ANADIG_TEMPSENSE_TRIM, field RSVD0[6:5] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD0 (5U) /*!< Bit position for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD0. */
#define BM_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD0 (0x00000060U) /*!< Bit mask for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD0. */
#define BS_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD0 (2U) /*!< Bit field size in bits for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD0. */

/*! @brief Read current value of the TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD0 field. */
#define BR_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD0(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM(x).B.RSVD0)
/*@}*/

/*!
 * @name Register TEMPMON_HW_ANADIG_TEMPSENSE_TRIM, field T_EN_READ[7] (RW)
 *
 * Definition:TBD
 */
/*@{*/
#define BP_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_EN_READ (7U) /*!< Bit position for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_EN_READ. */
#define BM_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_EN_READ (0x00000080U) /*!< Bit mask for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_EN_READ. */
#define BS_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_EN_READ (1U) /*!< Bit field size in bits for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_EN_READ. */

/*! @brief Read current value of the TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_EN_READ field. */
#define BR_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_EN_READ(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM(x).B.T_EN_READ)

/*! @brief Format value for bitfield TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_EN_READ. */
#define BF_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_EN_READ(v) ((uint32_t)((uint32_t)(v) << BP_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_EN_READ) & BM_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_EN_READ)

/*! @brief Set the T_EN_READ field to a new value. */
#define BW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_EN_READ(x, v) (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_WR(x, (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RD(x) & ~BM_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_EN_READ) | BF_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_EN_READ(v)))
/*@}*/

/*!
 * @name Register TEMPMON_HW_ANADIG_TEMPSENSE_TRIM, field T_VREF_VBE_SEL[16:8] (RW)
 *
 * Reference voltage setting bits for the am-plifier in the Positive-TC
 * generator block. Default: 10000
 */
/*@{*/
#define BP_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL (8U) /*!< Bit position for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL. */
#define BM_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL (0x0001FF00U) /*!< Bit mask for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL. */
#define BS_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL (9U) /*!< Bit field size in bits for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL. */

/*! @brief Read current value of the TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL field. */
#define BR_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM(x).B.T_VREF_VBE_SEL)

/*! @brief Format value for bitfield TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL. */
#define BF_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL(v) ((uint32_t)((uint32_t)(v) << BP_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL) & BM_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL)

/*! @brief Set the T_VREF_VBE_SEL field to a new value. */
#define BW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL(x, v) (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_WR(x, (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RD(x) & ~BM_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL) | BF_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_VREF_VBE_SEL(v)))
/*@}*/

/*!
 * @name Register TEMPMON_HW_ANADIG_TEMPSENSE_TRIM, field RSVD1[19:17] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD1 (17U) /*!< Bit position for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD1. */
#define BM_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD1 (0x000E0000U) /*!< Bit mask for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD1. */
#define BS_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD1 (3U) /*!< Bit field size in bits for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD1. */

/*! @brief Read current value of the TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD1 field. */
#define BR_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD1(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM(x).B.RSVD1)
/*@}*/

/*!
 * @name Register TEMPMON_HW_ANADIG_TEMPSENSE_TRIM, field T_BUF_SLOPE_SEL[23:20] (RW)
 *
 * Amplifier gain setting bits. Default: 1000 This value can be changed by BJT
 * characteristics. It will be fixed after temperature test.
 */
/*@{*/
#define BP_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL (20U) /*!< Bit position for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL. */
#define BM_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL (0x00F00000U) /*!< Bit mask for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL. */
#define BS_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL (4U) /*!< Bit field size in bits for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL. */

/*! @brief Read current value of the TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL field. */
#define BR_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM(x).B.T_BUF_SLOPE_SEL)

/*! @brief Format value for bitfield TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL. */
#define BF_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL(v) ((uint32_t)((uint32_t)(v) << BP_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL) & BM_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL)

/*! @brief Set the T_BUF_SLOPE_SEL field to a new value. */
#define BW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL(x, v) (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_WR(x, (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RD(x) & ~BM_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL) | BF_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_BUF_SLOPE_SEL(v)))
/*@}*/

/*!
 * @name Register TEMPMON_HW_ANADIG_TEMPSENSE_TRIM, field RSVD2[28:24] (RO)
 *
 * Always set to zero (0).
 */
/*@{*/
#define BP_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD2 (24U) /*!< Bit position for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD2. */
#define BM_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD2 (0x1F000000U) /*!< Bit mask for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD2. */
#define BS_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD2 (5U) /*!< Bit field size in bits for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD2. */

/*! @brief Read current value of the TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD2 field. */
#define BR_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RSVD2(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM(x).B.RSVD2)
/*@}*/

/*!
 * @name Register TEMPMON_HW_ANADIG_TEMPSENSE_TRIM, field T_MUX_ADDR[31:29] (RW)
 *
 * Test MUX address setting bits. Only for de-bugging purpose. Default: 110
 * Other Values : TBD
 */
/*@{*/
#define BP_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR (29U) /*!< Bit position for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR. */
#define BM_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR (0xE0000000U) /*!< Bit mask for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR. */
#define BS_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR (3U) /*!< Bit field size in bits for TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR. */

/*! @brief Read current value of the TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR field. */
#define BR_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR(x) (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM(x).B.T_MUX_ADDR)

/*! @brief Format value for bitfield TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR. */
#define BF_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR) & BM_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR)

/*! @brief Set the T_MUX_ADDR field to a new value. */
#define BW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR(x, v) (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_WR(x, (HW_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_RD(x) & ~BM_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR) | BF_TEMPMON_HW_ANADIG_TEMPSENSE_TRIM_T_MUX_ADDR(v)))
/*@}*/




/*******************************************************************************
 * hw_tempmon_t - module struct
 ******************************************************************************/
/*!
 * @brief All TEMPMON module registers.
 */
#pragma pack(1)
typedef struct _hw_tempmon
{
    uint8_t _reserved0[768];
    __IO hw_tempmon_hw_anadig_tempsense0_t HW_ANADIG_TEMPSENSE0; /*!< [0x300] Anadig Tempsensor Control Register 0 */
    uint8_t _reserved1[12];
    __IO hw_tempmon_hw_anadig_tempsense1_t HW_ANADIG_TEMPSENSE1; /*!< [0x310] Anadig Tempsensor Control Register 1 */
    uint8_t _reserved2[12];
    __IO hw_tempmon_hw_anadig_tempsense_trim_t HW_ANADIG_TEMPSENSE_TRIM; /*!< [0x320] Anadig Tempsensor Trim Control Register */
} hw_tempmon_t;
#pragma pack()

/*! @brief Macro to access all TEMPMON registers. */
/*! @param x TEMPMON module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_TEMPMON_REGS(TEMPMON_BASE)</code>. */
#define HW_TEMPMON_REGS(x) (*(hw_tempmon_t *)(x))

/*
 * iMX7D UART
 *
 * Universal Asynchronous Receiver/Transmitter (UART)
 *
 * Registers defined in this header file:
 * - HW_UART_URXD - UART Receiver Register
 * - HW_UART_UTXD - UART Transmitter Register
 * - HW_UART_UCR1 - UART Control Register 1
 * - HW_UART_UCR2 - UART Control Register 2
 * - HW_UART_UCR3 - UART Control Register 3
 * - HW_UART_UCR4 - UART Control Register 4
 * - HW_UART_UFCR - UART FIFO Control Register
 * - HW_UART_USR1 - UART Status Register 1
 * - HW_UART_USR2 - UART Status Register 2
 * - HW_UART_UESC - UART Escape Character Register
 * - HW_UART_UTIM - UART Escape Timer Register
 * - HW_UART_UBIR - UART BRM Incremental Register
 * - HW_UART_UBMR - UART BRM Modulator Register
 * - HW_UART_UBRC - UART Baud Rate Count Register
 * - HW_UART_ONEMS - UART One Millisecond Register
 * - HW_UART_UTS - UART Test Register
 * - HW_UART_UMCR - UART RS-485 Mode Control Register
 *
 * - hw_uart_t - Struct containing all module registers.
 */

#define HW_UART_INSTANCE_COUNT (7U) /*!< Number of instances of the UART module. */
#define HW_UART1 (1U) /*!< Instance number for UART1. */
#define HW_UART2 (2U) /*!< Instance number for UART2. */
#define HW_UART3 (3U) /*!< Instance number for UART3. */
#define HW_UART4 (4U) /*!< Instance number for UART4. */
#define HW_UART5 (5U) /*!< Instance number for UART5. */
#define HW_UART6 (6U) /*!< Instance number for UART6. */
#define HW_UART7 (7U) /*!< Instance number for UART7. */
#define UART1_BASE            (0x30860000U) /*!< Base address for UART1. */
#define UART2_BASE            (0x30890000U) /*!< Base address for UART2. */
#define UART3_BASE            (0x30880000U) /*!< Base address for UART3. */
#define UART4_BASE            (0x30A60000U) /*!< Base address for UART4. */
#define UART5_BASE            (0x30A70000U) /*!< Base address for UART5. */
#define UART6_BASE            (0x30A80000U) /*!< Base address for UART6. */
#define UART7_BASE            (0x30A90000U) /*!< Base address for UART7. */
/*! Array initializer of UART base addresses. */
#define UART_BASE_ADDRS       { UART1_BASE, UART2_BASE, UART3_BASE, UART4_BASE, UART5_BASE, UART6_BASE, UART7_BASE }

/*******************************************************************************
 * HW_UART_URXD - UART Receiver Register
 ******************************************************************************/

/*!
 * @brief HW_UART_URXD - UART Receiver Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The UART will yield a transfer error on the peripheral bus when core is
 * reading URXD register with receive interface disabled (RXEN=0 or UARTEN=0).
 */
typedef union _hw_uart_urxd
{
    uint32_t U;
    struct _hw_uart_urxd_bitfields
    {
        uint32_t RX_DATA : 8;          /*!< [7:0]  */
        uint32_t RESERVED0 : 2;        /*!< [9:8]  */
        uint32_t PRERR : 1;            /*!< [10]  */
        uint32_t BRK : 1;              /*!< [11]  */
        uint32_t FRMERR : 1;           /*!< [12]  */
        uint32_t OVRRUN : 1;           /*!< [13]  */
        uint32_t ERR : 1;              /*!< [14]  */
        uint32_t CHARRDY : 1;          /*!< [15]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_urxd_t;

/*!
 * @name Constants and macros for entire UART_URXD register
 */
/*@{*/
#define HW_UART_URXD_ADDR(x)     ((uintptr_t)(x) + 0x0U)

#define HW_UART_URXD(x)          (*(__I hw_uart_urxd_t *) HW_UART_URXD_ADDR(x))
#define HW_UART_URXD_RD(x)       (HW_UART_URXD(x).U)
/*@}*/

/*
 * Constants & macros for individual UART_URXD bitfields
 */

/*!
 * @name Register UART_URXD, field RX_DATA[7:0] (RO)
 *
 * Received Data. Holds the received character. In 7-bit mode, the most
 * significant bit (MSB) is forced to 0. In 8-bit mode, all bits are active.
 */
/*@{*/
#define BP_UART_URXD_RX_DATA (0U)          /*!< Bit position for UART_URXD_RX_DATA. */
#define BM_UART_URXD_RX_DATA (0x000000FFU) /*!< Bit mask for UART_URXD_RX_DATA. */
#define BS_UART_URXD_RX_DATA (8U)          /*!< Bit field size in bits for UART_URXD_RX_DATA. */

/*! @brief Read current value of the UART_URXD_RX_DATA field. */
#define BR_UART_URXD_RX_DATA(x) (HW_UART_URXD(x).B.RX_DATA)
/*@}*/

/*!
 * @name Register UART_URXD, field PRERR[10] (RO)
 *
 * In RS-485 mode, it holds the ninth data bit (bit [8]) of received 9-bit
 * RS-485 data In RS232/IrDA mode, it is the Parity Error flag. Indicates whether the
 * current character was detected with a parity error and is possibly corrupted.
 * PRERR is updated for each character read from the RxFIFO. When parity is
 * disabled, PRERR always reads as 0.
 *
 * Values:
 * - 0 - = No parity error was detected for data in the RX_DATA field
 * - 1 - = A parity error was detected for data in the RX_DATA field
 */
/*@{*/
#define BP_UART_URXD_PRERR   (10U)         /*!< Bit position for UART_URXD_PRERR. */
#define BM_UART_URXD_PRERR   (0x00000400U) /*!< Bit mask for UART_URXD_PRERR. */
#define BS_UART_URXD_PRERR   (1U)          /*!< Bit field size in bits for UART_URXD_PRERR. */

/*! @brief Read current value of the UART_URXD_PRERR field. */
#define BR_UART_URXD_PRERR(x) (HW_UART_URXD(x).B.PRERR)
/*@}*/

/*!
 * @name Register UART_URXD, field BRK[11] (RO)
 *
 * BREAK Detect. Indicates whether the current character was detected as a BREAK
 * character. The data bits and the stop bit are all 0. The FRMERR bit is set
 * when BRK is set. When odd parity is selected, PRERR is also set when BRK is set.
 * BRK is valid for each character read from the RxFIFO.
 *
 * Values:
 * - 0 - The current character is not a BREAK character
 * - 1 - The current character is a BREAK character
 */
/*@{*/
#define BP_UART_URXD_BRK     (11U)         /*!< Bit position for UART_URXD_BRK. */
#define BM_UART_URXD_BRK     (0x00000800U) /*!< Bit mask for UART_URXD_BRK. */
#define BS_UART_URXD_BRK     (1U)          /*!< Bit field size in bits for UART_URXD_BRK. */

/*! @brief Read current value of the UART_URXD_BRK field. */
#define BR_UART_URXD_BRK(x)  (HW_UART_URXD(x).B.BRK)
/*@}*/

/*!
 * @name Register UART_URXD, field FRMERR[12] (RO)
 *
 * Frame Error. Indicates whether the current character had a framing error (a
 * missing stop bit) and is possibly corrupted. FRMERR is updated for each
 * character read from the RxFIFO.
 *
 * Values:
 * - 0 - The current character has no framing error
 * - 1 - The current character has a framing error
 */
/*@{*/
#define BP_UART_URXD_FRMERR  (12U)         /*!< Bit position for UART_URXD_FRMERR. */
#define BM_UART_URXD_FRMERR  (0x00001000U) /*!< Bit mask for UART_URXD_FRMERR. */
#define BS_UART_URXD_FRMERR  (1U)          /*!< Bit field size in bits for UART_URXD_FRMERR. */

/*! @brief Read current value of the UART_URXD_FRMERR field. */
#define BR_UART_URXD_FRMERR(x) (HW_UART_URXD(x).B.FRMERR)
/*@}*/

/*!
 * @name Register UART_URXD, field OVRRUN[13] (RO)
 *
 * Receiver Overrun. This read-only bit, when HIGH, indicates that the
 * corresponding character was stored in the last position (32nd) of the Rx FIFO. Even if
 * a 33rd character has not been detected, this bit will be set to '1' for the
 * 32nd character.
 *
 * Values:
 * - 0 - No RxFIFO overrun was detected
 * - 1 - A RxFIFO overrun was detected
 */
/*@{*/
#define BP_UART_URXD_OVRRUN  (13U)         /*!< Bit position for UART_URXD_OVRRUN. */
#define BM_UART_URXD_OVRRUN  (0x00002000U) /*!< Bit mask for UART_URXD_OVRRUN. */
#define BS_UART_URXD_OVRRUN  (1U)          /*!< Bit field size in bits for UART_URXD_OVRRUN. */

/*! @brief Read current value of the UART_URXD_OVRRUN field. */
#define BR_UART_URXD_OVRRUN(x) (HW_UART_URXD(x).B.OVRRUN)
/*@}*/

/*!
 * @name Register UART_URXD, field ERR[14] (RO)
 *
 * Error Detect. Indicates whether the character present in the RX_DATA field
 * has an error (OVRRUN, FRMERR, BRK or PRERR) status. The ERR bit is updated and
 * valid for each received character.
 *
 * Values:
 * - 0 - No error status was detected
 * - 1 - An error status was detected
 */
/*@{*/
#define BP_UART_URXD_ERR     (14U)         /*!< Bit position for UART_URXD_ERR. */
#define BM_UART_URXD_ERR     (0x00004000U) /*!< Bit mask for UART_URXD_ERR. */
#define BS_UART_URXD_ERR     (1U)          /*!< Bit field size in bits for UART_URXD_ERR. */

/*! @brief Read current value of the UART_URXD_ERR field. */
#define BR_UART_URXD_ERR(x)  (HW_UART_URXD(x).B.ERR)
/*@}*/

/*!
 * @name Register UART_URXD, field CHARRDY[15] (RO)
 *
 * Character Ready. This read-only bit indicates an invalid read when the FIFO
 * becomes empty and software tries to read the same old data. This bit should not
 * be used for polling for data written to the RX FIFO.
 *
 * Values:
 * - 0 - Character in RX_DATA field and associated flags are invalid.
 * - 1 - Character in RX_DATA field and associated flags valid and ready for
 *     reading.
 */
/*@{*/
#define BP_UART_URXD_CHARRDY (15U)         /*!< Bit position for UART_URXD_CHARRDY. */
#define BM_UART_URXD_CHARRDY (0x00008000U) /*!< Bit mask for UART_URXD_CHARRDY. */
#define BS_UART_URXD_CHARRDY (1U)          /*!< Bit field size in bits for UART_URXD_CHARRDY. */

/*! @brief Read current value of the UART_URXD_CHARRDY field. */
#define BR_UART_URXD_CHARRDY(x) (HW_UART_URXD(x).B.CHARRDY)
/*@}*/

/*******************************************************************************
 * HW_UART_UTXD - UART Transmitter Register
 ******************************************************************************/

/*!
 * @brief HW_UART_UTXD - UART Transmitter Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The UART will yield a transfer error on the peripheral bus when core is
 * writing into UART_URXD register with transmit interface disabled (TXEN=0 or
 * UARTEN=0). Memory space between UART_URXD and UART_UTXD registers is reserved. Any
 * read or write access to this space will be considered as an invalid access and
 * yield a transfer error.
 */
typedef union _hw_uart_utxd
{
    uint32_t U;
    struct _hw_uart_utxd_bitfields
    {
        uint32_t TX_DATA : 8;          /*!< [7:0]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_uart_utxd_t;

/*!
 * @name Constants and macros for entire UART_UTXD register
 */
/*@{*/
#define HW_UART_UTXD_ADDR(x)     ((uintptr_t)(x) + 0x40U)

#define HW_UART_UTXD(x)          (*(__IO hw_uart_utxd_t *) HW_UART_UTXD_ADDR(x))
#define HW_UART_UTXD_RD(x)       (HW_UART_UTXD(x).U)
#define HW_UART_UTXD_WR(x, v)    (HW_UART_UTXD(x).U = (v))
#define HW_UART_UTXD_SET(x, v)   (HW_UART_UTXD_WR(x, HW_UART_UTXD_RD(x) |  (v)))
#define HW_UART_UTXD_CLR(x, v)   (HW_UART_UTXD_WR(x, HW_UART_UTXD_RD(x) & ~(v)))
#define HW_UART_UTXD_TOG(x, v)   (HW_UART_UTXD_WR(x, HW_UART_UTXD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UTXD bitfields
 */

/*!
 * @name Register UART_UTXD, field TX_DATA[7:0] (WO)
 *
 * Transmit Data. Holds the parallel transmit data inputs. In 7-bit mode, D7 is
 * ignored. In 8-bit mode, all bits are used. Data is transmitted least
 * significant bit (LSB) first. A new character is transmitted when the TX_DATA field is
 * written. The TX_DATA field must be written only when the TRDY bit is high to
 * ensure that corrupted data is not sent.
 */
/*@{*/
#define BP_UART_UTXD_TX_DATA (0U)          /*!< Bit position for UART_UTXD_TX_DATA. */
#define BM_UART_UTXD_TX_DATA (0x000000FFU) /*!< Bit mask for UART_UTXD_TX_DATA. */
#define BS_UART_UTXD_TX_DATA (8U)          /*!< Bit field size in bits for UART_UTXD_TX_DATA. */

/*! @brief Format value for bitfield UART_UTXD_TX_DATA. */
#define BF_UART_UTXD_TX_DATA(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTXD_TX_DATA) & BM_UART_UTXD_TX_DATA)
/*@}*/

/*******************************************************************************
 * HW_UART_UCR1 - UART Control Register 1
 ******************************************************************************/

/*!
 * @brief HW_UART_UCR1 - UART Control Register 1 (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_uart_ucr1
{
    uint32_t U;
    struct _hw_uart_ucr1_bitfields
    {
        uint32_t UARTEN : 1;           /*!< [0]  */
        uint32_t DOZE : 1;             /*!< [1]  */
        uint32_t ATDMAEN : 1;          /*!< [2]  */
        uint32_t TXDMAEN : 1;          /*!< [3]  */
        uint32_t SNDBRK : 1;           /*!< [4]  */
        uint32_t RTSDEN : 1;           /*!< [5]  */
        uint32_t TXMPTYEN : 1;         /*!< [6]  */
        uint32_t IREN : 1;             /*!< [7]  */
        uint32_t RXDMAEN : 1;          /*!< [8]  */
        uint32_t RRDYEN : 1;           /*!< [9]  */
        uint32_t ICD : 2;              /*!< [11:10]  */
        uint32_t IDEN : 1;             /*!< [12]  */
        uint32_t TRDYEN : 1;           /*!< [13]  */
        uint32_t ADBR : 1;             /*!< [14]  */
        uint32_t ADEN : 1;             /*!< [15]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_ucr1_t;

/*!
 * @name Constants and macros for entire UART_UCR1 register
 */
/*@{*/
#define HW_UART_UCR1_ADDR(x)     ((uintptr_t)(x) + 0x80U)

#define HW_UART_UCR1(x)          (*(__IO hw_uart_ucr1_t *) HW_UART_UCR1_ADDR(x))
#define HW_UART_UCR1_RD(x)       (HW_UART_UCR1(x).U)
#define HW_UART_UCR1_WR(x, v)    (HW_UART_UCR1(x).U = (v))
#define HW_UART_UCR1_SET(x, v)   (HW_UART_UCR1_WR(x, HW_UART_UCR1_RD(x) |  (v)))
#define HW_UART_UCR1_CLR(x, v)   (HW_UART_UCR1_WR(x, HW_UART_UCR1_RD(x) & ~(v)))
#define HW_UART_UCR1_TOG(x, v)   (HW_UART_UCR1_WR(x, HW_UART_UCR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UCR1 bitfields
 */

/*!
 * @name Register UART_UCR1, field UARTEN[0] (RW)
 *
 * UART Enable. Enables/Disables the UART. If UARTEN is negated in the middle of
 * a transmission, the transmitter stops and pulls the TXD line to a logic 1.
 * UARTEN must be set to 1 before any access to UTXD and URXD registers, otherwise
 * a transfer error is returned. This bit can be set to 1 along with other bits
 * in this register. There is no restriction to the sequence of programing this
 * bit and other control registers.
 *
 * Values:
 * - 0 - Disable the UART
 * - 1 - Enable the UART
 */
/*@{*/
#define BP_UART_UCR1_UARTEN  (0U)          /*!< Bit position for UART_UCR1_UARTEN. */
#define BM_UART_UCR1_UARTEN  (0x00000001U) /*!< Bit mask for UART_UCR1_UARTEN. */
#define BS_UART_UCR1_UARTEN  (1U)          /*!< Bit field size in bits for UART_UCR1_UARTEN. */

/*! @brief Read current value of the UART_UCR1_UARTEN field. */
#define BR_UART_UCR1_UARTEN(x) (HW_UART_UCR1(x).B.UARTEN)

/*! @brief Format value for bitfield UART_UCR1_UARTEN. */
#define BF_UART_UCR1_UARTEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_UARTEN) & BM_UART_UCR1_UARTEN)

/*! @brief Set the UARTEN field to a new value. */
#define BW_UART_UCR1_UARTEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_UARTEN) | BF_UART_UCR1_UARTEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field DOZE[1] (RW)
 *
 * DOZE. Determines the UART enable condition in the DOZE state. When doze_req
 * input pin is at '1', (the ARM Platform executes a doze instruction and the
 * system is placed in the Doze State), the DOZE bit affects operation of the UART.
 * While in the Doze State, if this bit is asserted, the UART is disabled. See the
 * description in Low Power ModesThese modes are controlled by the signals
 * doze_req and stop_req. The control/status/data registers won't change when getting
 * in/out of low power modes. .
 *
 * Values:
 * - 0 - The UART is enabled when in DOZE state
 * - 1 - The UART is disabled when in DOZE state
 */
/*@{*/
#define BP_UART_UCR1_DOZE    (1U)          /*!< Bit position for UART_UCR1_DOZE. */
#define BM_UART_UCR1_DOZE    (0x00000002U) /*!< Bit mask for UART_UCR1_DOZE. */
#define BS_UART_UCR1_DOZE    (1U)          /*!< Bit field size in bits for UART_UCR1_DOZE. */

/*! @brief Read current value of the UART_UCR1_DOZE field. */
#define BR_UART_UCR1_DOZE(x) (HW_UART_UCR1(x).B.DOZE)

/*! @brief Format value for bitfield UART_UCR1_DOZE. */
#define BF_UART_UCR1_DOZE(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_DOZE) & BM_UART_UCR1_DOZE)

/*! @brief Set the DOZE field to a new value. */
#define BW_UART_UCR1_DOZE(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_DOZE) | BF_UART_UCR1_DOZE(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field ATDMAEN[2] (RW)
 *
 * Aging DMA Timer Enable. Enables/Disables the receive DMA request dma_req_rx
 * for the aging timer interrupt (triggered with AGTIM flag in USR1[8]).
 *
 * Values:
 * - 0 - Disable AGTIM DMA request
 * - 1 - Enable AGTIM DMA request
 */
/*@{*/
#define BP_UART_UCR1_ATDMAEN (2U)          /*!< Bit position for UART_UCR1_ATDMAEN. */
#define BM_UART_UCR1_ATDMAEN (0x00000004U) /*!< Bit mask for UART_UCR1_ATDMAEN. */
#define BS_UART_UCR1_ATDMAEN (1U)          /*!< Bit field size in bits for UART_UCR1_ATDMAEN. */

/*! @brief Read current value of the UART_UCR1_ATDMAEN field. */
#define BR_UART_UCR1_ATDMAEN(x) (HW_UART_UCR1(x).B.ATDMAEN)

/*! @brief Format value for bitfield UART_UCR1_ATDMAEN. */
#define BF_UART_UCR1_ATDMAEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_ATDMAEN) & BM_UART_UCR1_ATDMAEN)

/*! @brief Set the ATDMAEN field to a new value. */
#define BW_UART_UCR1_ATDMAEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_ATDMAEN) | BF_UART_UCR1_ATDMAEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field TXDMAEN[3] (RW)
 *
 * Transmitter Ready DMA Enable. Enables/Disables the transmit DMA request
 * dma_req_tx when the transmitter has one or more slots available in the TxFIFO. The
 * fill level in the TxFIFO that generates the dma_req_tx is controlled by the
 * TXTL bits. A DMA request will be issued as long as TXDMAEN and TRDY are high
 * even if the transmitter is not enabled. In general, user should enable the
 * transmitter before enabling the transmit DMA request.
 *
 * Values:
 * - 0 - Disable transmit DMA request
 * - 1 - Enable transmit DMA request
 */
/*@{*/
#define BP_UART_UCR1_TXDMAEN (3U)          /*!< Bit position for UART_UCR1_TXDMAEN. */
#define BM_UART_UCR1_TXDMAEN (0x00000008U) /*!< Bit mask for UART_UCR1_TXDMAEN. */
#define BS_UART_UCR1_TXDMAEN (1U)          /*!< Bit field size in bits for UART_UCR1_TXDMAEN. */

/*! @brief Read current value of the UART_UCR1_TXDMAEN field. */
#define BR_UART_UCR1_TXDMAEN(x) (HW_UART_UCR1(x).B.TXDMAEN)

/*! @brief Format value for bitfield UART_UCR1_TXDMAEN. */
#define BF_UART_UCR1_TXDMAEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_TXDMAEN) & BM_UART_UCR1_TXDMAEN)

/*! @brief Set the TXDMAEN field to a new value. */
#define BW_UART_UCR1_TXDMAEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_TXDMAEN) | BF_UART_UCR1_TXDMAEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field SNDBRK[4] (RW)
 *
 * Send BREAK. Forces the transmitter to send a BREAK character. The transmitter
 * finishes sending the character in progress (if any) and sends BREAK
 * characters until SNDBRK is reset. Because the transmitter samples SNDBRK after every
 * bit is transmitted, it is important that SNDBRK is asserted high for a
 * sufficient period of time to generate a valid BREAK. After the BREAK transmission
 * completes, the UART transmits 2 mark bits. The user can continue to fill the TxFIFO
 * and any characters remaining are transmitted when the BREAK is terminated.
 *
 * Values:
 * - 0 - Do not send a BREAK character
 * - 1 - Send a BREAK character (continuous 0s)
 */
/*@{*/
#define BP_UART_UCR1_SNDBRK  (4U)          /*!< Bit position for UART_UCR1_SNDBRK. */
#define BM_UART_UCR1_SNDBRK  (0x00000010U) /*!< Bit mask for UART_UCR1_SNDBRK. */
#define BS_UART_UCR1_SNDBRK  (1U)          /*!< Bit field size in bits for UART_UCR1_SNDBRK. */

/*! @brief Read current value of the UART_UCR1_SNDBRK field. */
#define BR_UART_UCR1_SNDBRK(x) (HW_UART_UCR1(x).B.SNDBRK)

/*! @brief Format value for bitfield UART_UCR1_SNDBRK. */
#define BF_UART_UCR1_SNDBRK(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_SNDBRK) & BM_UART_UCR1_SNDBRK)

/*! @brief Set the SNDBRK field to a new value. */
#define BW_UART_UCR1_SNDBRK(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_SNDBRK) | BF_UART_UCR1_SNDBRK(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field RTSDEN[5] (RW)
 *
 * RTS Delta Interrupt Enable. Enables/Disables the RTSD interrupt. The current
 * status of the RTS_B pin is read in the RTSS bit.
 *
 * Values:
 * - 0 - Disable RTSD interrupt
 * - 1 - Enable RTSD interrupt
 */
/*@{*/
#define BP_UART_UCR1_RTSDEN  (5U)          /*!< Bit position for UART_UCR1_RTSDEN. */
#define BM_UART_UCR1_RTSDEN  (0x00000020U) /*!< Bit mask for UART_UCR1_RTSDEN. */
#define BS_UART_UCR1_RTSDEN  (1U)          /*!< Bit field size in bits for UART_UCR1_RTSDEN. */

/*! @brief Read current value of the UART_UCR1_RTSDEN field. */
#define BR_UART_UCR1_RTSDEN(x) (HW_UART_UCR1(x).B.RTSDEN)

/*! @brief Format value for bitfield UART_UCR1_RTSDEN. */
#define BF_UART_UCR1_RTSDEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_RTSDEN) & BM_UART_UCR1_RTSDEN)

/*! @brief Set the RTSDEN field to a new value. */
#define BW_UART_UCR1_RTSDEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_RTSDEN) | BF_UART_UCR1_RTSDEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field TXMPTYEN[6] (RW)
 *
 * Transmitter Empty Interrupt Enable. Enables/Disables the transmitter FIFO
 * empty (TXFE) interrupt. interrupt_uart . When negated, the TXFE interrupt is
 * disabled. An interrupt will be issued as long as TXMPTYEN and TXFE are high even
 * if the transmitter is not enabled. In general, user should enable the
 * transmitter before enabling the TXFE interrupt.
 *
 * Values:
 * - 0 - Disable the transmitter FIFO empty interrupt
 * - 1 - Enable the transmitter FIFO empty interrupt
 */
/*@{*/
#define BP_UART_UCR1_TXMPTYEN (6U)         /*!< Bit position for UART_UCR1_TXMPTYEN. */
#define BM_UART_UCR1_TXMPTYEN (0x00000040U) /*!< Bit mask for UART_UCR1_TXMPTYEN. */
#define BS_UART_UCR1_TXMPTYEN (1U)         /*!< Bit field size in bits for UART_UCR1_TXMPTYEN. */

/*! @brief Read current value of the UART_UCR1_TXMPTYEN field. */
#define BR_UART_UCR1_TXMPTYEN(x) (HW_UART_UCR1(x).B.TXMPTYEN)

/*! @brief Format value for bitfield UART_UCR1_TXMPTYEN. */
#define BF_UART_UCR1_TXMPTYEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_TXMPTYEN) & BM_UART_UCR1_TXMPTYEN)

/*! @brief Set the TXMPTYEN field to a new value. */
#define BW_UART_UCR1_TXMPTYEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_TXMPTYEN) | BF_UART_UCR1_TXMPTYEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field IREN[7] (RW)
 *
 * Infrared Interface Enable. Enables/Disables the IR interface. See the IR
 * interface description in Infrared Interface , for more information. Note:
 * MDEN(UMCR[0]) must be cleared to 0 when using IrDA interface. See
 *
 * Values:
 * - 0 - Disable the IR interface
 * - 1 - Enable the IR interface
 */
/*@{*/
#define BP_UART_UCR1_IREN    (7U)          /*!< Bit position for UART_UCR1_IREN. */
#define BM_UART_UCR1_IREN    (0x00000080U) /*!< Bit mask for UART_UCR1_IREN. */
#define BS_UART_UCR1_IREN    (1U)          /*!< Bit field size in bits for UART_UCR1_IREN. */

/*! @brief Read current value of the UART_UCR1_IREN field. */
#define BR_UART_UCR1_IREN(x) (HW_UART_UCR1(x).B.IREN)

/*! @brief Format value for bitfield UART_UCR1_IREN. */
#define BF_UART_UCR1_IREN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_IREN) & BM_UART_UCR1_IREN)

/*! @brief Set the IREN field to a new value. */
#define BW_UART_UCR1_IREN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_IREN) | BF_UART_UCR1_IREN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field RXDMAEN[8] (RW)
 *
 * Receive Ready DMA Enable. Enables/Disables the receive DMA request dma_req_rx
 * when the receiver has data in the RxFIFO. The fill level in the RxFIFO at
 * which a DMA request is generated is controlled by the RXTL bits. When negated,
 * the receive DMA request is disabled.
 *
 * Values:
 * - 0 - Disable DMA request
 * - 1 - Enable DMA request
 */
/*@{*/
#define BP_UART_UCR1_RXDMAEN (8U)          /*!< Bit position for UART_UCR1_RXDMAEN. */
#define BM_UART_UCR1_RXDMAEN (0x00000100U) /*!< Bit mask for UART_UCR1_RXDMAEN. */
#define BS_UART_UCR1_RXDMAEN (1U)          /*!< Bit field size in bits for UART_UCR1_RXDMAEN. */

/*! @brief Read current value of the UART_UCR1_RXDMAEN field. */
#define BR_UART_UCR1_RXDMAEN(x) (HW_UART_UCR1(x).B.RXDMAEN)

/*! @brief Format value for bitfield UART_UCR1_RXDMAEN. */
#define BF_UART_UCR1_RXDMAEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_RXDMAEN) & BM_UART_UCR1_RXDMAEN)

/*! @brief Set the RXDMAEN field to a new value. */
#define BW_UART_UCR1_RXDMAEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_RXDMAEN) | BF_UART_UCR1_RXDMAEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field RRDYEN[9] (RW)
 *
 * Receiver Ready Interrupt Enable. Enables/Disables the RRDY interrupt when the
 * RxFIFO contains data. The fill level in the RxFIFO at which an interrupt is
 * generated is controlled by the RXTL bits. When RRDYEN is negated, the receiver
 * ready interrupt is disabled.
 *
 * Values:
 * - 0 - Disables the RRDY interrupt
 * - 1 - Enables the RRDY interrupt
 */
/*@{*/
#define BP_UART_UCR1_RRDYEN  (9U)          /*!< Bit position for UART_UCR1_RRDYEN. */
#define BM_UART_UCR1_RRDYEN  (0x00000200U) /*!< Bit mask for UART_UCR1_RRDYEN. */
#define BS_UART_UCR1_RRDYEN  (1U)          /*!< Bit field size in bits for UART_UCR1_RRDYEN. */

/*! @brief Read current value of the UART_UCR1_RRDYEN field. */
#define BR_UART_UCR1_RRDYEN(x) (HW_UART_UCR1(x).B.RRDYEN)

/*! @brief Format value for bitfield UART_UCR1_RRDYEN. */
#define BF_UART_UCR1_RRDYEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_RRDYEN) & BM_UART_UCR1_RRDYEN)

/*! @brief Set the RRDYEN field to a new value. */
#define BW_UART_UCR1_RRDYEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_RRDYEN) | BF_UART_UCR1_RRDYEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field ICD[11:10] (RW)
 *
 * Idle Condition Detect. Controls the number of frames RXD is allowed to be
 * idle before an idle condition is reported.
 *
 * Values:
 * - 00 - Idle for more than 4 frames
 * - 01 - Idle for more than 8 frames
 * - 10 - Idle for more than 16 frames
 * - 11 - Idle for more than 32 frames
 */
/*@{*/
#define BP_UART_UCR1_ICD     (10U)         /*!< Bit position for UART_UCR1_ICD. */
#define BM_UART_UCR1_ICD     (0x00000C00U) /*!< Bit mask for UART_UCR1_ICD. */
#define BS_UART_UCR1_ICD     (2U)          /*!< Bit field size in bits for UART_UCR1_ICD. */

/*! @brief Read current value of the UART_UCR1_ICD field. */
#define BR_UART_UCR1_ICD(x)  (HW_UART_UCR1(x).B.ICD)

/*! @brief Format value for bitfield UART_UCR1_ICD. */
#define BF_UART_UCR1_ICD(v)  ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_ICD) & BM_UART_UCR1_ICD)

/*! @brief Set the ICD field to a new value. */
#define BW_UART_UCR1_ICD(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_ICD) | BF_UART_UCR1_ICD(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field IDEN[12] (RW)
 *
 * Idle Condition Detected Interrupt Enable. Enables/Disables the IDLE bit to
 * generate an interrupt ( interrupt_uart = 0).
 *
 * Values:
 * - 0 - Disable the IDLE interrupt
 * - 1 - Enable the IDLE interrupt
 */
/*@{*/
#define BP_UART_UCR1_IDEN    (12U)         /*!< Bit position for UART_UCR1_IDEN. */
#define BM_UART_UCR1_IDEN    (0x00001000U) /*!< Bit mask for UART_UCR1_IDEN. */
#define BS_UART_UCR1_IDEN    (1U)          /*!< Bit field size in bits for UART_UCR1_IDEN. */

/*! @brief Read current value of the UART_UCR1_IDEN field. */
#define BR_UART_UCR1_IDEN(x) (HW_UART_UCR1(x).B.IDEN)

/*! @brief Format value for bitfield UART_UCR1_IDEN. */
#define BF_UART_UCR1_IDEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_IDEN) & BM_UART_UCR1_IDEN)

/*! @brief Set the IDEN field to a new value. */
#define BW_UART_UCR1_IDEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_IDEN) | BF_UART_UCR1_IDEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field TRDYEN[13] (RW)
 *
 * Transmitter Ready Interrupt Enable. Enables/Disables the transmitter Ready
 * Interrupt (TRDY) when the transmitter has one or more slots available in the
 * TxFIFO. The fill level in the TXFIFO at which an interrupt is generated is
 * controlled by TxTL bits. When TRDYEN is negated, the transmitter ready interrupt is
 * disabled. An interrupt will be issued as long as TRDYEN and TRDY are high even
 * if the transmitter is not enabled. In general, user should enable the
 * transmitter before enabling the TRDY interrupt.
 *
 * Values:
 * - 0 - Disable the transmitter ready interrupt
 * - 1 - Enable the transmitter ready interrupt
 */
/*@{*/
#define BP_UART_UCR1_TRDYEN  (13U)         /*!< Bit position for UART_UCR1_TRDYEN. */
#define BM_UART_UCR1_TRDYEN  (0x00002000U) /*!< Bit mask for UART_UCR1_TRDYEN. */
#define BS_UART_UCR1_TRDYEN  (1U)          /*!< Bit field size in bits for UART_UCR1_TRDYEN. */

/*! @brief Read current value of the UART_UCR1_TRDYEN field. */
#define BR_UART_UCR1_TRDYEN(x) (HW_UART_UCR1(x).B.TRDYEN)

/*! @brief Format value for bitfield UART_UCR1_TRDYEN. */
#define BF_UART_UCR1_TRDYEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_TRDYEN) & BM_UART_UCR1_TRDYEN)

/*! @brief Set the TRDYEN field to a new value. */
#define BW_UART_UCR1_TRDYEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_TRDYEN) | BF_UART_UCR1_TRDYEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field ADBR[14] (RW)
 *
 * Automatic Detection of Baud Rate. Enables/Disables automatic baud rate
 * detection. When the ADBR bit is set and the ADET bit is cleared, the receiver
 * detects the incoming baud rate automatically. The ADET flag is set when the receiver
 * verifies that the incoming baud rate is detected properly by detecting an
 * ASCII character "A" or "a" (0x41 or 0x61).
 *
 * Values:
 * - 0 - Disable automatic detection of baud rate
 * - 1 - Enable automatic detection of baud rate
 */
/*@{*/
#define BP_UART_UCR1_ADBR    (14U)         /*!< Bit position for UART_UCR1_ADBR. */
#define BM_UART_UCR1_ADBR    (0x00004000U) /*!< Bit mask for UART_UCR1_ADBR. */
#define BS_UART_UCR1_ADBR    (1U)          /*!< Bit field size in bits for UART_UCR1_ADBR. */

/*! @brief Read current value of the UART_UCR1_ADBR field. */
#define BR_UART_UCR1_ADBR(x) (HW_UART_UCR1(x).B.ADBR)

/*! @brief Format value for bitfield UART_UCR1_ADBR. */
#define BF_UART_UCR1_ADBR(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_ADBR) & BM_UART_UCR1_ADBR)

/*! @brief Set the ADBR field to a new value. */
#define BW_UART_UCR1_ADBR(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_ADBR) | BF_UART_UCR1_ADBR(v)))
/*@}*/

/*!
 * @name Register UART_UCR1, field ADEN[15] (RW)
 *
 * Automatic Baud Rate Detection Interrupt Enable. Enables/Disables the
 * automatic baud rate detect complete (ADET) bit to generate an interrupt (
 * interrupt_uart = 0).
 *
 * Values:
 * - 0 - Disable the automatic baud rate detection interrupt
 * - 1 - Enable the automatic baud rate detection interrupt
 */
/*@{*/
#define BP_UART_UCR1_ADEN    (15U)         /*!< Bit position for UART_UCR1_ADEN. */
#define BM_UART_UCR1_ADEN    (0x00008000U) /*!< Bit mask for UART_UCR1_ADEN. */
#define BS_UART_UCR1_ADEN    (1U)          /*!< Bit field size in bits for UART_UCR1_ADEN. */

/*! @brief Read current value of the UART_UCR1_ADEN field. */
#define BR_UART_UCR1_ADEN(x) (HW_UART_UCR1(x).B.ADEN)

/*! @brief Format value for bitfield UART_UCR1_ADEN. */
#define BF_UART_UCR1_ADEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR1_ADEN) & BM_UART_UCR1_ADEN)

/*! @brief Set the ADEN field to a new value. */
#define BW_UART_UCR1_ADEN(x, v) (HW_UART_UCR1_WR(x, (HW_UART_UCR1_RD(x) & ~BM_UART_UCR1_ADEN) | BF_UART_UCR1_ADEN(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UCR2 - UART Control Register 2
 ******************************************************************************/

/*!
 * @brief HW_UART_UCR2 - UART Control Register 2 (RW)
 *
 * Reset value: 0x00000001U
 */
typedef union _hw_uart_ucr2
{
    uint32_t U;
    struct _hw_uart_ucr2_bitfields
    {
        uint32_t SRST : 1;             /*!< [0]  */
        uint32_t RXEN : 1;             /*!< [1]  */
        uint32_t TXEN : 1;             /*!< [2]  */
        uint32_t ATEN : 1;             /*!< [3]  */
        uint32_t RTSEN : 1;            /*!< [4]  */
        uint32_t WS : 1;               /*!< [5]  */
        uint32_t STPB : 1;             /*!< [6]  */
        uint32_t PROE : 1;             /*!< [7]  */
        uint32_t PREN : 1;             /*!< [8]  */
        uint32_t RTEC : 2;             /*!< [10:9]  */
        uint32_t ESCEN : 1;            /*!< [11]  */
        uint32_t CTS : 1;              /*!< [12]  */
        uint32_t CTSC : 1;             /*!< [13]  */
        uint32_t IRTS : 1;             /*!< [14]  */
        uint32_t ESCI : 1;             /*!< [15]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_ucr2_t;

/*!
 * @name Constants and macros for entire UART_UCR2 register
 */
/*@{*/
#define HW_UART_UCR2_ADDR(x)     ((uintptr_t)(x) + 0x84U)

#define HW_UART_UCR2(x)          (*(__IO hw_uart_ucr2_t *) HW_UART_UCR2_ADDR(x))
#define HW_UART_UCR2_RD(x)       (HW_UART_UCR2(x).U)
#define HW_UART_UCR2_WR(x, v)    (HW_UART_UCR2(x).U = (v))
#define HW_UART_UCR2_SET(x, v)   (HW_UART_UCR2_WR(x, HW_UART_UCR2_RD(x) |  (v)))
#define HW_UART_UCR2_CLR(x, v)   (HW_UART_UCR2_WR(x, HW_UART_UCR2_RD(x) & ~(v)))
#define HW_UART_UCR2_TOG(x, v)   (HW_UART_UCR2_WR(x, HW_UART_UCR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UCR2 bitfields
 */

/*!
 * @name Register UART_UCR2, field SRST[0] (RW)
 *
 * Software Reset. Once the software writes 0 to SRST_B, the software reset
 * remains active for 4 module_clock cycles before the hardware deasserts SRST_B. The
 * software can only write 0 to SRST_B. Writing 1 to SRST_B is ignored.
 *
 * Values:
 * - 0 - Reset the transmit and receive state machines, all FIFOs and register
 *     USR1, USR2, UBIR, UBMR, UBRC , URXD, UTXD and UTS[6-3].
 * - 1 - No reset
 */
/*@{*/
#define BP_UART_UCR2_SRST    (0U)          /*!< Bit position for UART_UCR2_SRST. */
#define BM_UART_UCR2_SRST    (0x00000001U) /*!< Bit mask for UART_UCR2_SRST. */
#define BS_UART_UCR2_SRST    (1U)          /*!< Bit field size in bits for UART_UCR2_SRST. */

/*! @brief Read current value of the UART_UCR2_SRST field. */
#define BR_UART_UCR2_SRST(x) (HW_UART_UCR2(x).B.SRST)

/*! @brief Format value for bitfield UART_UCR2_SRST. */
#define BF_UART_UCR2_SRST(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_SRST) & BM_UART_UCR2_SRST)

/*! @brief Set the SRST field to a new value. */
#define BW_UART_UCR2_SRST(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_SRST) | BF_UART_UCR2_SRST(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field RXEN[1] (RW)
 *
 * Receiver Enable. Enables/Disables the receiver. When the receiver is enabled,
 * if the RXD input is already low, the receiver does not recognize BREAK
 * characters, because it requires a valid 1-to-0 transition before it can accept any
 * character.
 *
 * Values:
 * - 0 - Disable the receiver
 * - 1 - Enable the receiver
 */
/*@{*/
#define BP_UART_UCR2_RXEN    (1U)          /*!< Bit position for UART_UCR2_RXEN. */
#define BM_UART_UCR2_RXEN    (0x00000002U) /*!< Bit mask for UART_UCR2_RXEN. */
#define BS_UART_UCR2_RXEN    (1U)          /*!< Bit field size in bits for UART_UCR2_RXEN. */

/*! @brief Read current value of the UART_UCR2_RXEN field. */
#define BR_UART_UCR2_RXEN(x) (HW_UART_UCR2(x).B.RXEN)

/*! @brief Format value for bitfield UART_UCR2_RXEN. */
#define BF_UART_UCR2_RXEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_RXEN) & BM_UART_UCR2_RXEN)

/*! @brief Set the RXEN field to a new value. */
#define BW_UART_UCR2_RXEN(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_RXEN) | BF_UART_UCR2_RXEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field TXEN[2] (RW)
 *
 * Transmitter Enable. Enables/Disables the transmitter. When TXEN is negated
 * the transmitter is disabled and idle. When the UARTEN and TXEN bits are set the
 * transmitter is enabled. If TXEN is negated in the middle of a transmission,
 * the UART disables the transmitter immediately, and starts marking 1s. The
 * transmitter FIFO cannot be written when this bit is cleared.
 *
 * Values:
 * - 0 - Disable the transmitter
 * - 1 - Enable the transmitter
 */
/*@{*/
#define BP_UART_UCR2_TXEN    (2U)          /*!< Bit position for UART_UCR2_TXEN. */
#define BM_UART_UCR2_TXEN    (0x00000004U) /*!< Bit mask for UART_UCR2_TXEN. */
#define BS_UART_UCR2_TXEN    (1U)          /*!< Bit field size in bits for UART_UCR2_TXEN. */

/*! @brief Read current value of the UART_UCR2_TXEN field. */
#define BR_UART_UCR2_TXEN(x) (HW_UART_UCR2(x).B.TXEN)

/*! @brief Format value for bitfield UART_UCR2_TXEN. */
#define BF_UART_UCR2_TXEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_TXEN) & BM_UART_UCR2_TXEN)

/*! @brief Set the TXEN field to a new value. */
#define BW_UART_UCR2_TXEN(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_TXEN) | BF_UART_UCR2_TXEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field ATEN[3] (RW)
 *
 * Aging Timer Enable. This bit is used to enable the aging timer interrupt
 * (triggered with AGTIM)
 *
 * Values:
 * - 0 - AGTIM interrupt disabled
 * - 1 - AGTIM interrupt enabled
 */
/*@{*/
#define BP_UART_UCR2_ATEN    (3U)          /*!< Bit position for UART_UCR2_ATEN. */
#define BM_UART_UCR2_ATEN    (0x00000008U) /*!< Bit mask for UART_UCR2_ATEN. */
#define BS_UART_UCR2_ATEN    (1U)          /*!< Bit field size in bits for UART_UCR2_ATEN. */

/*! @brief Read current value of the UART_UCR2_ATEN field. */
#define BR_UART_UCR2_ATEN(x) (HW_UART_UCR2(x).B.ATEN)

/*! @brief Format value for bitfield UART_UCR2_ATEN. */
#define BF_UART_UCR2_ATEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_ATEN) & BM_UART_UCR2_ATEN)

/*! @brief Set the ATEN field to a new value. */
#define BW_UART_UCR2_ATEN(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_ATEN) | BF_UART_UCR2_ATEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field RTSEN[4] (RW)
 *
 * Request to Send Interrupt Enable. Controls the RTS edge sensitive interrupt.
 * When RTSEN is asserted and the programmed edge is detected on the RTS_B pin
 * (the RTSF bit is asserted), an interrupt will be generated on the interrupt_uart
 * pin. (See .)
 *
 * Values:
 * - 0 - Disable request to send interrupt
 * - 1 - Enable request to send interrupt
 */
/*@{*/
#define BP_UART_UCR2_RTSEN   (4U)          /*!< Bit position for UART_UCR2_RTSEN. */
#define BM_UART_UCR2_RTSEN   (0x00000010U) /*!< Bit mask for UART_UCR2_RTSEN. */
#define BS_UART_UCR2_RTSEN   (1U)          /*!< Bit field size in bits for UART_UCR2_RTSEN. */

/*! @brief Read current value of the UART_UCR2_RTSEN field. */
#define BR_UART_UCR2_RTSEN(x) (HW_UART_UCR2(x).B.RTSEN)

/*! @brief Format value for bitfield UART_UCR2_RTSEN. */
#define BF_UART_UCR2_RTSEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_RTSEN) & BM_UART_UCR2_RTSEN)

/*! @brief Set the RTSEN field to a new value. */
#define BW_UART_UCR2_RTSEN(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_RTSEN) | BF_UART_UCR2_RTSEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field WS[5] (RW)
 *
 * Word Size. Controls the character length. When WS is high, the transmitter
 * and receiver are in 8-bit mode. When WS is low, they are in 7-bit mode. The
 * transmitter ignores bit 7 and the receiver sets bit 7 to 0. WS can be changed
 * in-between transmission (reception) of characters, however not when a transmission
 * (reception) is in progress, in which case the length of the current character
 * being transmitted (received) is unpredictable.
 *
 * Values:
 * - 0 - 7-bit transmit and receive character length (not including START, STOP
 *     or PARITY bits)
 * - 1 - 8-bit transmit and receive character length (not including START, STOP
 *     or PARITY bits)
 */
/*@{*/
#define BP_UART_UCR2_WS      (5U)          /*!< Bit position for UART_UCR2_WS. */
#define BM_UART_UCR2_WS      (0x00000020U) /*!< Bit mask for UART_UCR2_WS. */
#define BS_UART_UCR2_WS      (1U)          /*!< Bit field size in bits for UART_UCR2_WS. */

/*! @brief Read current value of the UART_UCR2_WS field. */
#define BR_UART_UCR2_WS(x)   (HW_UART_UCR2(x).B.WS)

/*! @brief Format value for bitfield UART_UCR2_WS. */
#define BF_UART_UCR2_WS(v)   ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_WS) & BM_UART_UCR2_WS)

/*! @brief Set the WS field to a new value. */
#define BW_UART_UCR2_WS(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_WS) | BF_UART_UCR2_WS(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field STPB[6] (RW)
 *
 * Stop. Controls the number of stop bits after a character. When STPB is low, 1
 * stop bit is sent. When STPB is high, 2 stop bits are sent. STPB also affects
 * the receiver.
 *
 * Values:
 * - 0 - The transmitter sends 1 stop bit. The receiver expects 1 or more stop
 *     bits.
 * - 1 - The transmitter sends 2 stop bits. The receiver expects 2 or more stop
 *     bits.
 */
/*@{*/
#define BP_UART_UCR2_STPB    (6U)          /*!< Bit position for UART_UCR2_STPB. */
#define BM_UART_UCR2_STPB    (0x00000040U) /*!< Bit mask for UART_UCR2_STPB. */
#define BS_UART_UCR2_STPB    (1U)          /*!< Bit field size in bits for UART_UCR2_STPB. */

/*! @brief Read current value of the UART_UCR2_STPB field. */
#define BR_UART_UCR2_STPB(x) (HW_UART_UCR2(x).B.STPB)

/*! @brief Format value for bitfield UART_UCR2_STPB. */
#define BF_UART_UCR2_STPB(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_STPB) & BM_UART_UCR2_STPB)

/*! @brief Set the STPB field to a new value. */
#define BW_UART_UCR2_STPB(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_STPB) | BF_UART_UCR2_STPB(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field PROE[7] (RW)
 *
 * Parity Odd/Even. Controls the sense of the parity generator and checker. When
 * PROE is high, odd parity is generated and expected. When PROE is low, even
 * parity is generated and expected. PROE has no function if PREN is low.
 *
 * Values:
 * - 0 - Even parity
 * - 1 - Odd parity
 */
/*@{*/
#define BP_UART_UCR2_PROE    (7U)          /*!< Bit position for UART_UCR2_PROE. */
#define BM_UART_UCR2_PROE    (0x00000080U) /*!< Bit mask for UART_UCR2_PROE. */
#define BS_UART_UCR2_PROE    (1U)          /*!< Bit field size in bits for UART_UCR2_PROE. */

/*! @brief Read current value of the UART_UCR2_PROE field. */
#define BR_UART_UCR2_PROE(x) (HW_UART_UCR2(x).B.PROE)

/*! @brief Format value for bitfield UART_UCR2_PROE. */
#define BF_UART_UCR2_PROE(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_PROE) & BM_UART_UCR2_PROE)

/*! @brief Set the PROE field to a new value. */
#define BW_UART_UCR2_PROE(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_PROE) | BF_UART_UCR2_PROE(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field PREN[8] (RW)
 *
 * Parity Enable. Enables/Disables the parity generator in the transmitter and
 * parity checker in the receiver. When PREN is asserted, the parity generator and
 * checker are enabled, and disabled when PREN is negated.
 *
 * Values:
 * - 0 - Disable parity generator and checker
 * - 1 - Enable parity generator and checker
 */
/*@{*/
#define BP_UART_UCR2_PREN    (8U)          /*!< Bit position for UART_UCR2_PREN. */
#define BM_UART_UCR2_PREN    (0x00000100U) /*!< Bit mask for UART_UCR2_PREN. */
#define BS_UART_UCR2_PREN    (1U)          /*!< Bit field size in bits for UART_UCR2_PREN. */

/*! @brief Read current value of the UART_UCR2_PREN field. */
#define BR_UART_UCR2_PREN(x) (HW_UART_UCR2(x).B.PREN)

/*! @brief Format value for bitfield UART_UCR2_PREN. */
#define BF_UART_UCR2_PREN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_PREN) & BM_UART_UCR2_PREN)

/*! @brief Set the PREN field to a new value. */
#define BW_UART_UCR2_PREN(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_PREN) | BF_UART_UCR2_PREN(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field RTEC[10:9] (RW)
 *
 * Request to Send Edge Control. Selects the edge that triggers the RTS
 * interrupt. This has no effect on the RTS delta interrupt. RTEC has an effect only when
 * RTSEN = 1 (see ).
 *
 * Values:
 * - 00 - Trigger interrupt on a rising edge
 * - 01 - Trigger interrupt on a falling edge
 */
/*@{*/
#define BP_UART_UCR2_RTEC    (9U)          /*!< Bit position for UART_UCR2_RTEC. */
#define BM_UART_UCR2_RTEC    (0x00000600U) /*!< Bit mask for UART_UCR2_RTEC. */
#define BS_UART_UCR2_RTEC    (2U)          /*!< Bit field size in bits for UART_UCR2_RTEC. */

/*! @brief Read current value of the UART_UCR2_RTEC field. */
#define BR_UART_UCR2_RTEC(x) (HW_UART_UCR2(x).B.RTEC)

/*! @brief Format value for bitfield UART_UCR2_RTEC. */
#define BF_UART_UCR2_RTEC(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_RTEC) & BM_UART_UCR2_RTEC)

/*! @brief Set the RTEC field to a new value. */
#define BW_UART_UCR2_RTEC(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_RTEC) | BF_UART_UCR2_RTEC(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field ESCEN[11] (RW)
 *
 * Escape Enable. Enables/Disables the escape sequence detection logic.
 *
 * Values:
 * - 0 - Disable escape sequence detection
 * - 1 - Enable escape sequence detection
 */
/*@{*/
#define BP_UART_UCR2_ESCEN   (11U)         /*!< Bit position for UART_UCR2_ESCEN. */
#define BM_UART_UCR2_ESCEN   (0x00000800U) /*!< Bit mask for UART_UCR2_ESCEN. */
#define BS_UART_UCR2_ESCEN   (1U)          /*!< Bit field size in bits for UART_UCR2_ESCEN. */

/*! @brief Read current value of the UART_UCR2_ESCEN field. */
#define BR_UART_UCR2_ESCEN(x) (HW_UART_UCR2(x).B.ESCEN)

/*! @brief Format value for bitfield UART_UCR2_ESCEN. */
#define BF_UART_UCR2_ESCEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_ESCEN) & BM_UART_UCR2_ESCEN)

/*! @brief Set the ESCEN field to a new value. */
#define BW_UART_UCR2_ESCEN(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_ESCEN) | BF_UART_UCR2_ESCEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field CTS[12] (RW)
 *
 * Clear to Send. Controls the CTS_B pin when the CTSC bit is negated. CTS has
 * no function when CTSC is asserted.
 *
 * Values:
 * - 0 - The CTS_B pin is high (inactive)
 * - 1 - The CTS_B pin is low (active)
 */
/*@{*/
#define BP_UART_UCR2_CTS     (12U)         /*!< Bit position for UART_UCR2_CTS. */
#define BM_UART_UCR2_CTS     (0x00001000U) /*!< Bit mask for UART_UCR2_CTS. */
#define BS_UART_UCR2_CTS     (1U)          /*!< Bit field size in bits for UART_UCR2_CTS. */

/*! @brief Read current value of the UART_UCR2_CTS field. */
#define BR_UART_UCR2_CTS(x)  (HW_UART_UCR2(x).B.CTS)

/*! @brief Format value for bitfield UART_UCR2_CTS. */
#define BF_UART_UCR2_CTS(v)  ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_CTS) & BM_UART_UCR2_CTS)

/*! @brief Set the CTS field to a new value. */
#define BW_UART_UCR2_CTS(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_CTS) | BF_UART_UCR2_CTS(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field CTSC[13] (RW)
 *
 * CTS Pin Control. Controls the operation of the CTS_B module output. When CTSC
 * is asserted, the CTS_B module output is controlled by the receiver. When the
 * RxFIFO is filled to the level of the programmed trigger level and the start
 * bit of the overflowing character (TRIGGER LEVEL + 1) is validated, the CTS_B
 * module output is negated to indicate to the far-end transmitter to stop
 * transmitting. When the trigger level is programmed for less than 32, the receiver
 * continues to receive data until the RxFIFO is full. When the CTSC bit is negated,
 * the CTS_B module output is controlled by the CTS bit. On reset, because CTSC is
 * cleared to 0, the CTS_B pin is controlled by the CTS bit, which again is
 * cleared to 0 on reset. This means that on reset the CTS_B signal is negated.
 *
 * Values:
 * - 0 - The CTS_B pin is controlled by the CTS bit
 * - 1 - The CTS_B pin is controlled by the receiver
 */
/*@{*/
#define BP_UART_UCR2_CTSC    (13U)         /*!< Bit position for UART_UCR2_CTSC. */
#define BM_UART_UCR2_CTSC    (0x00002000U) /*!< Bit mask for UART_UCR2_CTSC. */
#define BS_UART_UCR2_CTSC    (1U)          /*!< Bit field size in bits for UART_UCR2_CTSC. */

/*! @brief Read current value of the UART_UCR2_CTSC field. */
#define BR_UART_UCR2_CTSC(x) (HW_UART_UCR2(x).B.CTSC)

/*! @brief Format value for bitfield UART_UCR2_CTSC. */
#define BF_UART_UCR2_CTSC(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_CTSC) & BM_UART_UCR2_CTSC)

/*! @brief Set the CTSC field to a new value. */
#define BW_UART_UCR2_CTSC(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_CTSC) | BF_UART_UCR2_CTSC(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field IRTS[14] (RW)
 *
 * Ignore RTS Pin. Forces the RTS input signal presented to the transmitter to
 * always be asserted (set to low), effectively ignoring the external pin. When in
 * this mode, the RTS pin serves as a general purpose input.
 *
 * Values:
 * - 0 - Transmit only when the RTS pin is asserted
 * - 1 - Ignore the RTS pin
 */
/*@{*/
#define BP_UART_UCR2_IRTS    (14U)         /*!< Bit position for UART_UCR2_IRTS. */
#define BM_UART_UCR2_IRTS    (0x00004000U) /*!< Bit mask for UART_UCR2_IRTS. */
#define BS_UART_UCR2_IRTS    (1U)          /*!< Bit field size in bits for UART_UCR2_IRTS. */

/*! @brief Read current value of the UART_UCR2_IRTS field. */
#define BR_UART_UCR2_IRTS(x) (HW_UART_UCR2(x).B.IRTS)

/*! @brief Format value for bitfield UART_UCR2_IRTS. */
#define BF_UART_UCR2_IRTS(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_IRTS) & BM_UART_UCR2_IRTS)

/*! @brief Set the IRTS field to a new value. */
#define BW_UART_UCR2_IRTS(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_IRTS) | BF_UART_UCR2_IRTS(v)))
/*@}*/

/*!
 * @name Register UART_UCR2, field ESCI[15] (RW)
 *
 * Escape Sequence Interrupt Enable. Enables/Disables the ESCF bit to generate
 * an interrupt.
 *
 * Values:
 * - 0 - Disable the escape sequence interrupt
 * - 1 - Enable the escape sequence interrupt
 */
/*@{*/
#define BP_UART_UCR2_ESCI    (15U)         /*!< Bit position for UART_UCR2_ESCI. */
#define BM_UART_UCR2_ESCI    (0x00008000U) /*!< Bit mask for UART_UCR2_ESCI. */
#define BS_UART_UCR2_ESCI    (1U)          /*!< Bit field size in bits for UART_UCR2_ESCI. */

/*! @brief Read current value of the UART_UCR2_ESCI field. */
#define BR_UART_UCR2_ESCI(x) (HW_UART_UCR2(x).B.ESCI)

/*! @brief Format value for bitfield UART_UCR2_ESCI. */
#define BF_UART_UCR2_ESCI(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR2_ESCI) & BM_UART_UCR2_ESCI)

/*! @brief Set the ESCI field to a new value. */
#define BW_UART_UCR2_ESCI(x, v) (HW_UART_UCR2_WR(x, (HW_UART_UCR2_RD(x) & ~BM_UART_UCR2_ESCI) | BF_UART_UCR2_ESCI(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UCR3 - UART Control Register 3
 ******************************************************************************/

/*!
 * @brief HW_UART_UCR3 - UART Control Register 3 (RW)
 *
 * Reset value: 0x00000700U
 */
typedef union _hw_uart_ucr3
{
    uint32_t U;
    struct _hw_uart_ucr3_bitfields
    {
        uint32_t ACIEN : 1;            /*!< [0]  */
        uint32_t INVT : 1;             /*!< [1]  */
        uint32_t RXDMUXSEL : 1;        /*!< [2]  */
        uint32_t DTRDEN : 1;           /*!< [3]  */
        uint32_t AWAKEN : 1;           /*!< [4]  */
        uint32_t AIRINTEN : 1;         /*!< [5]  */
        uint32_t RXDSEN : 1;           /*!< [6]  */
        uint32_t ADNIMP : 1;           /*!< [7]  */
        uint32_t RI : 1;               /*!< [8]  */
        uint32_t DCD : 1;              /*!< [9]  */
        uint32_t DSR : 1;              /*!< [10]  */
        uint32_t FRAERREN : 1;         /*!< [11]  */
        uint32_t PARERREN : 1;         /*!< [12]  */
        uint32_t DTREN : 1;            /*!< [13]  */
        uint32_t DPEC : 2;             /*!< [15:14]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_ucr3_t;

/*!
 * @name Constants and macros for entire UART_UCR3 register
 */
/*@{*/
#define HW_UART_UCR3_ADDR(x)     ((uintptr_t)(x) + 0x88U)

#define HW_UART_UCR3(x)          (*(__IO hw_uart_ucr3_t *) HW_UART_UCR3_ADDR(x))
#define HW_UART_UCR3_RD(x)       (HW_UART_UCR3(x).U)
#define HW_UART_UCR3_WR(x, v)    (HW_UART_UCR3(x).U = (v))
#define HW_UART_UCR3_SET(x, v)   (HW_UART_UCR3_WR(x, HW_UART_UCR3_RD(x) |  (v)))
#define HW_UART_UCR3_CLR(x, v)   (HW_UART_UCR3_WR(x, HW_UART_UCR3_RD(x) & ~(v)))
#define HW_UART_UCR3_TOG(x, v)   (HW_UART_UCR3_WR(x, HW_UART_UCR3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UCR3 bitfields
 */

/*!
 * @name Register UART_UCR3, field ACIEN[0] (RW)
 *
 * Autobaud Counter Interrupt Enable. This bit is used to enable the autobaud
 * counter stopped interrupt (triggered with ACST (USR2[11]).
 *
 * Values:
 * - 0 - ACST interrupt disabled
 * - 1 - ACST interrupt enabled
 */
/*@{*/
#define BP_UART_UCR3_ACIEN   (0U)          /*!< Bit position for UART_UCR3_ACIEN. */
#define BM_UART_UCR3_ACIEN   (0x00000001U) /*!< Bit mask for UART_UCR3_ACIEN. */
#define BS_UART_UCR3_ACIEN   (1U)          /*!< Bit field size in bits for UART_UCR3_ACIEN. */

/*! @brief Read current value of the UART_UCR3_ACIEN field. */
#define BR_UART_UCR3_ACIEN(x) (HW_UART_UCR3(x).B.ACIEN)

/*! @brief Format value for bitfield UART_UCR3_ACIEN. */
#define BF_UART_UCR3_ACIEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_ACIEN) & BM_UART_UCR3_ACIEN)

/*! @brief Set the ACIEN field to a new value. */
#define BW_UART_UCR3_ACIEN(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_ACIEN) | BF_UART_UCR3_ACIEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field INVT[1] (RW)
 *
 * Invert TXD output in RS-232/RS-485 mode, set TXD active level in IrDA mode.
 * In RS232/RS-485 mode(UMCR[0] = 1), if this bit is set to 1, the TXD output is
 * inverted before transmitted. In IrDA mode, when INVT is cleared, the infrared
 * logic block transmits a positive IR 3/16 pulse for all 0s and 0s are
 * transmitted for 1s. When INVT is set (INVT = 1), the infrared logic block transmits an
 * active low or negative infrared 3/16 pulse for all 0s and 1s are transmitted
 * for 1s.
 *
 * Values:
 * - 0 - TXD is not inverted
 * - 1 - TXD is inverted
 * - 0 - TXD Active low transmission
 * - 1 - TXD Active high transmission
 */
/*@{*/
#define BP_UART_UCR3_INVT    (1U)          /*!< Bit position for UART_UCR3_INVT. */
#define BM_UART_UCR3_INVT    (0x00000002U) /*!< Bit mask for UART_UCR3_INVT. */
#define BS_UART_UCR3_INVT    (1U)          /*!< Bit field size in bits for UART_UCR3_INVT. */

/*! @brief Read current value of the UART_UCR3_INVT field. */
#define BR_UART_UCR3_INVT(x) (HW_UART_UCR3(x).B.INVT)

/*! @brief Format value for bitfield UART_UCR3_INVT. */
#define BF_UART_UCR3_INVT(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_INVT) & BM_UART_UCR3_INVT)

/*! @brief Set the INVT field to a new value. */
#define BW_UART_UCR3_INVT(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_INVT) | BF_UART_UCR3_INVT(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field RXDMUXSEL[2] (RW)
 *
 * RXD Muxed Input Selected. Selects proper input pins for serial and Infrared
 * input signal. In this chip, UARTs are used in MUXED mode, so that this bit
 * should always be set.
 */
/*@{*/
#define BP_UART_UCR3_RXDMUXSEL (2U)        /*!< Bit position for UART_UCR3_RXDMUXSEL. */
#define BM_UART_UCR3_RXDMUXSEL (0x00000004U) /*!< Bit mask for UART_UCR3_RXDMUXSEL. */
#define BS_UART_UCR3_RXDMUXSEL (1U)        /*!< Bit field size in bits for UART_UCR3_RXDMUXSEL. */

/*! @brief Read current value of the UART_UCR3_RXDMUXSEL field. */
#define BR_UART_UCR3_RXDMUXSEL(x) (HW_UART_UCR3(x).B.RXDMUXSEL)

/*! @brief Format value for bitfield UART_UCR3_RXDMUXSEL. */
#define BF_UART_UCR3_RXDMUXSEL(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_RXDMUXSEL) & BM_UART_UCR3_RXDMUXSEL)

/*! @brief Set the RXDMUXSEL field to a new value. */
#define BW_UART_UCR3_RXDMUXSEL(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_RXDMUXSEL) | BF_UART_UCR3_RXDMUXSEL(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field DTRDEN[3] (RW)
 *
 * This bit is not used in this chip.
 */
/*@{*/
#define BP_UART_UCR3_DTRDEN  (3U)          /*!< Bit position for UART_UCR3_DTRDEN. */
#define BM_UART_UCR3_DTRDEN  (0x00000008U) /*!< Bit mask for UART_UCR3_DTRDEN. */
#define BS_UART_UCR3_DTRDEN  (1U)          /*!< Bit field size in bits for UART_UCR3_DTRDEN. */

/*! @brief Read current value of the UART_UCR3_DTRDEN field. */
#define BR_UART_UCR3_DTRDEN(x) (HW_UART_UCR3(x).B.DTRDEN)

/*! @brief Format value for bitfield UART_UCR3_DTRDEN. */
#define BF_UART_UCR3_DTRDEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_DTRDEN) & BM_UART_UCR3_DTRDEN)

/*! @brief Set the DTRDEN field to a new value. */
#define BW_UART_UCR3_DTRDEN(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_DTRDEN) | BF_UART_UCR3_DTRDEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field AWAKEN[4] (RW)
 *
 * Asynchronous WAKE Interrupt Enable. Controls the asynchronous WAKE interrupt.
 * An interrupt is generated when AWAKEN is asserted and a falling edge is
 * detected on the RXD pin.
 *
 * Values:
 * - 0 - Disable the AWAKE interrupt
 * - 1 - Enable the AWAKE interrupt
 */
/*@{*/
#define BP_UART_UCR3_AWAKEN  (4U)          /*!< Bit position for UART_UCR3_AWAKEN. */
#define BM_UART_UCR3_AWAKEN  (0x00000010U) /*!< Bit mask for UART_UCR3_AWAKEN. */
#define BS_UART_UCR3_AWAKEN  (1U)          /*!< Bit field size in bits for UART_UCR3_AWAKEN. */

/*! @brief Read current value of the UART_UCR3_AWAKEN field. */
#define BR_UART_UCR3_AWAKEN(x) (HW_UART_UCR3(x).B.AWAKEN)

/*! @brief Format value for bitfield UART_UCR3_AWAKEN. */
#define BF_UART_UCR3_AWAKEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_AWAKEN) & BM_UART_UCR3_AWAKEN)

/*! @brief Set the AWAKEN field to a new value. */
#define BW_UART_UCR3_AWAKEN(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_AWAKEN) | BF_UART_UCR3_AWAKEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field AIRINTEN[5] (RW)
 *
 * Asynchronous IR WAKE Interrupt Enable. Controls the asynchronous IR WAKE
 * interrupt. An interrupt is generated when AIRINTEN is asserted and a pulse is
 * detected on the RXD pin.
 *
 * Values:
 * - 0 - Disable the AIRINT interrupt
 * - 1 - Enable the AIRINT interrupt
 */
/*@{*/
#define BP_UART_UCR3_AIRINTEN (5U)         /*!< Bit position for UART_UCR3_AIRINTEN. */
#define BM_UART_UCR3_AIRINTEN (0x00000020U) /*!< Bit mask for UART_UCR3_AIRINTEN. */
#define BS_UART_UCR3_AIRINTEN (1U)         /*!< Bit field size in bits for UART_UCR3_AIRINTEN. */

/*! @brief Read current value of the UART_UCR3_AIRINTEN field. */
#define BR_UART_UCR3_AIRINTEN(x) (HW_UART_UCR3(x).B.AIRINTEN)

/*! @brief Format value for bitfield UART_UCR3_AIRINTEN. */
#define BF_UART_UCR3_AIRINTEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_AIRINTEN) & BM_UART_UCR3_AIRINTEN)

/*! @brief Set the AIRINTEN field to a new value. */
#define BW_UART_UCR3_AIRINTEN(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_AIRINTEN) | BF_UART_UCR3_AIRINTEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field RXDSEN[6] (RW)
 *
 * Receive Status Interrupt Enable. Controls the receive status interrupt (
 * interrupt_uart ). When this bit is enabled and RXDS status bit is set, the
 * interrupt interrupt_uart will be generated.
 *
 * Values:
 * - 0 - Disable the RXDS interrupt
 * - 1 - Enable the RXDS interrupt
 */
/*@{*/
#define BP_UART_UCR3_RXDSEN  (6U)          /*!< Bit position for UART_UCR3_RXDSEN. */
#define BM_UART_UCR3_RXDSEN  (0x00000040U) /*!< Bit mask for UART_UCR3_RXDSEN. */
#define BS_UART_UCR3_RXDSEN  (1U)          /*!< Bit field size in bits for UART_UCR3_RXDSEN. */

/*! @brief Read current value of the UART_UCR3_RXDSEN field. */
#define BR_UART_UCR3_RXDSEN(x) (HW_UART_UCR3(x).B.RXDSEN)

/*! @brief Format value for bitfield UART_UCR3_RXDSEN. */
#define BF_UART_UCR3_RXDSEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_RXDSEN) & BM_UART_UCR3_RXDSEN)

/*! @brief Set the RXDSEN field to a new value. */
#define BW_UART_UCR3_RXDSEN(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_RXDSEN) | BF_UART_UCR3_RXDSEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field ADNIMP[7] (RW)
 *
 * Autobaud Detection Not Improved-. Disables new features of autobaud detection
 * (See Baud Rate Automatic Detection ProtocolThe receiver must receive an ASCII
 * character "A" or "a" to verify proper detection of the incoming baud rate.
 * When an ASCII character "A" (0x41) or "a" (0x61) is received and no error
 * occurs, the Automatic Detect baud rate bit is set (ADET=1) and if the interrupt is
 * enabled (ADEN=UCR1[15]=1), an interrupt interrupt_uart is generated. , for more
 * details).
 *
 * Values:
 * - 0 - Autobaud detection new features selected
 * - 1 - Keep old autobaud detection mechanism
 */
/*@{*/
#define BP_UART_UCR3_ADNIMP  (7U)          /*!< Bit position for UART_UCR3_ADNIMP. */
#define BM_UART_UCR3_ADNIMP  (0x00000080U) /*!< Bit mask for UART_UCR3_ADNIMP. */
#define BS_UART_UCR3_ADNIMP  (1U)          /*!< Bit field size in bits for UART_UCR3_ADNIMP. */

/*! @brief Read current value of the UART_UCR3_ADNIMP field. */
#define BR_UART_UCR3_ADNIMP(x) (HW_UART_UCR3(x).B.ADNIMP)

/*! @brief Format value for bitfield UART_UCR3_ADNIMP. */
#define BF_UART_UCR3_ADNIMP(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_ADNIMP) & BM_UART_UCR3_ADNIMP)

/*! @brief Set the ADNIMP field to a new value. */
#define BW_UART_UCR3_ADNIMP(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_ADNIMP) | BF_UART_UCR3_ADNIMP(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field RI[8] (RW)
 *
 * This bit is not used in this chip.
 */
/*@{*/
#define BP_UART_UCR3_RI      (8U)          /*!< Bit position for UART_UCR3_RI. */
#define BM_UART_UCR3_RI      (0x00000100U) /*!< Bit mask for UART_UCR3_RI. */
#define BS_UART_UCR3_RI      (1U)          /*!< Bit field size in bits for UART_UCR3_RI. */

/*! @brief Read current value of the UART_UCR3_RI field. */
#define BR_UART_UCR3_RI(x)   (HW_UART_UCR3(x).B.RI)

/*! @brief Format value for bitfield UART_UCR3_RI. */
#define BF_UART_UCR3_RI(v)   ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_RI) & BM_UART_UCR3_RI)

/*! @brief Set the RI field to a new value. */
#define BW_UART_UCR3_RI(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_RI) | BF_UART_UCR3_RI(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field DCD[9] (RW)
 *
 * This bit is not used in this chip.
 */
/*@{*/
#define BP_UART_UCR3_DCD     (9U)          /*!< Bit position for UART_UCR3_DCD. */
#define BM_UART_UCR3_DCD     (0x00000200U) /*!< Bit mask for UART_UCR3_DCD. */
#define BS_UART_UCR3_DCD     (1U)          /*!< Bit field size in bits for UART_UCR3_DCD. */

/*! @brief Read current value of the UART_UCR3_DCD field. */
#define BR_UART_UCR3_DCD(x)  (HW_UART_UCR3(x).B.DCD)

/*! @brief Format value for bitfield UART_UCR3_DCD. */
#define BF_UART_UCR3_DCD(v)  ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_DCD) & BM_UART_UCR3_DCD)

/*! @brief Set the DCD field to a new value. */
#define BW_UART_UCR3_DCD(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_DCD) | BF_UART_UCR3_DCD(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field DSR[10] (RW)
 *
 * This bit is not used in this chip.
 */
/*@{*/
#define BP_UART_UCR3_DSR     (10U)         /*!< Bit position for UART_UCR3_DSR. */
#define BM_UART_UCR3_DSR     (0x00000400U) /*!< Bit mask for UART_UCR3_DSR. */
#define BS_UART_UCR3_DSR     (1U)          /*!< Bit field size in bits for UART_UCR3_DSR. */

/*! @brief Read current value of the UART_UCR3_DSR field. */
#define BR_UART_UCR3_DSR(x)  (HW_UART_UCR3(x).B.DSR)

/*! @brief Format value for bitfield UART_UCR3_DSR. */
#define BF_UART_UCR3_DSR(v)  ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_DSR) & BM_UART_UCR3_DSR)

/*! @brief Set the DSR field to a new value. */
#define BW_UART_UCR3_DSR(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_DSR) | BF_UART_UCR3_DSR(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field FRAERREN[11] (RW)
 *
 * Frame Error Interrupt Enable. Enables/Disables the interrupt. When asserted,
 * FRAERREN causes the FRAMERR bit to generate an interrupt.
 *
 * Values:
 * - 0 - Disable the frame error interrupt
 * - 1 - Enable the frame error interrupt
 */
/*@{*/
#define BP_UART_UCR3_FRAERREN (11U)        /*!< Bit position for UART_UCR3_FRAERREN. */
#define BM_UART_UCR3_FRAERREN (0x00000800U) /*!< Bit mask for UART_UCR3_FRAERREN. */
#define BS_UART_UCR3_FRAERREN (1U)         /*!< Bit field size in bits for UART_UCR3_FRAERREN. */

/*! @brief Read current value of the UART_UCR3_FRAERREN field. */
#define BR_UART_UCR3_FRAERREN(x) (HW_UART_UCR3(x).B.FRAERREN)

/*! @brief Format value for bitfield UART_UCR3_FRAERREN. */
#define BF_UART_UCR3_FRAERREN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_FRAERREN) & BM_UART_UCR3_FRAERREN)

/*! @brief Set the FRAERREN field to a new value. */
#define BW_UART_UCR3_FRAERREN(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_FRAERREN) | BF_UART_UCR3_FRAERREN(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field PARERREN[12] (RW)
 *
 * Parity Error Interrupt Enable. Enables/Disables the interrupt. When asserted,
 * PARERREN causes the PARITYERR bit to generate an interrupt.
 *
 * Values:
 * - 0 - Disable the parity error interrupt
 * - 1 - Enable the parity error interrupt
 */
/*@{*/
#define BP_UART_UCR3_PARERREN (12U)        /*!< Bit position for UART_UCR3_PARERREN. */
#define BM_UART_UCR3_PARERREN (0x00001000U) /*!< Bit mask for UART_UCR3_PARERREN. */
#define BS_UART_UCR3_PARERREN (1U)         /*!< Bit field size in bits for UART_UCR3_PARERREN. */

/*! @brief Read current value of the UART_UCR3_PARERREN field. */
#define BR_UART_UCR3_PARERREN(x) (HW_UART_UCR3(x).B.PARERREN)

/*! @brief Format value for bitfield UART_UCR3_PARERREN. */
#define BF_UART_UCR3_PARERREN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_PARERREN) & BM_UART_UCR3_PARERREN)

/*! @brief Set the PARERREN field to a new value. */
#define BW_UART_UCR3_PARERREN(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_PARERREN) | BF_UART_UCR3_PARERREN(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field DTREN[13] (RW)
 *
 * This bit is not used in this chip.
 */
/*@{*/
#define BP_UART_UCR3_DTREN   (13U)         /*!< Bit position for UART_UCR3_DTREN. */
#define BM_UART_UCR3_DTREN   (0x00002000U) /*!< Bit mask for UART_UCR3_DTREN. */
#define BS_UART_UCR3_DTREN   (1U)          /*!< Bit field size in bits for UART_UCR3_DTREN. */

/*! @brief Read current value of the UART_UCR3_DTREN field. */
#define BR_UART_UCR3_DTREN(x) (HW_UART_UCR3(x).B.DTREN)

/*! @brief Format value for bitfield UART_UCR3_DTREN. */
#define BF_UART_UCR3_DTREN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_DTREN) & BM_UART_UCR3_DTREN)

/*! @brief Set the DTREN field to a new value. */
#define BW_UART_UCR3_DTREN(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_DTREN) | BF_UART_UCR3_DTREN(v)))
/*@}*/

/*!
 * @name Register UART_UCR3, field DPEC[15:14] (RW)
 *
 * This bit is not used in this chip.
 */
/*@{*/
#define BP_UART_UCR3_DPEC    (14U)         /*!< Bit position for UART_UCR3_DPEC. */
#define BM_UART_UCR3_DPEC    (0x0000C000U) /*!< Bit mask for UART_UCR3_DPEC. */
#define BS_UART_UCR3_DPEC    (2U)          /*!< Bit field size in bits for UART_UCR3_DPEC. */

/*! @brief Read current value of the UART_UCR3_DPEC field. */
#define BR_UART_UCR3_DPEC(x) (HW_UART_UCR3(x).B.DPEC)

/*! @brief Format value for bitfield UART_UCR3_DPEC. */
#define BF_UART_UCR3_DPEC(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR3_DPEC) & BM_UART_UCR3_DPEC)

/*! @brief Set the DPEC field to a new value. */
#define BW_UART_UCR3_DPEC(x, v) (HW_UART_UCR3_WR(x, (HW_UART_UCR3_RD(x) & ~BM_UART_UCR3_DPEC) | BF_UART_UCR3_DPEC(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UCR4 - UART Control Register 4
 ******************************************************************************/

/*!
 * @brief HW_UART_UCR4 - UART Control Register 4 (RW)
 *
 * Reset value: 0x00008000U
 */
typedef union _hw_uart_ucr4
{
    uint32_t U;
    struct _hw_uart_ucr4_bitfields
    {
        uint32_t DREN : 1;             /*!< [0]  */
        uint32_t OREN : 1;             /*!< [1]  */
        uint32_t BKEN : 1;             /*!< [2]  */
        uint32_t TCEN : 1;             /*!< [3]  */
        uint32_t LPBYP : 1;            /*!< [4]  */
        uint32_t IRSC : 1;             /*!< [5]  */
        uint32_t IDDMAEN : 1;          /*!< [6]  */
        uint32_t WKEN : 1;             /*!< [7]  */
        uint32_t ENIRI : 1;            /*!< [8]  */
        uint32_t INVR : 1;             /*!< [9]  */
        uint32_t CTSTL : 6;            /*!< [15:10]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_ucr4_t;

/*!
 * @name Constants and macros for entire UART_UCR4 register
 */
/*@{*/
#define HW_UART_UCR4_ADDR(x)     ((uintptr_t)(x) + 0x8CU)

#define HW_UART_UCR4(x)          (*(__IO hw_uart_ucr4_t *) HW_UART_UCR4_ADDR(x))
#define HW_UART_UCR4_RD(x)       (HW_UART_UCR4(x).U)
#define HW_UART_UCR4_WR(x, v)    (HW_UART_UCR4(x).U = (v))
#define HW_UART_UCR4_SET(x, v)   (HW_UART_UCR4_WR(x, HW_UART_UCR4_RD(x) |  (v)))
#define HW_UART_UCR4_CLR(x, v)   (HW_UART_UCR4_WR(x, HW_UART_UCR4_RD(x) & ~(v)))
#define HW_UART_UCR4_TOG(x, v)   (HW_UART_UCR4_WR(x, HW_UART_UCR4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UCR4 bitfields
 */

/*!
 * @name Register UART_UCR4, field DREN[0] (RW)
 *
 * Receive Data Ready Interrupt Enable. Enables/Disables the RDR bit to generate
 * an interrupt.
 *
 * Values:
 * - 0 - Disable RDR interrupt
 * - 1 - Enable RDR interrupt
 */
/*@{*/
#define BP_UART_UCR4_DREN    (0U)          /*!< Bit position for UART_UCR4_DREN. */
#define BM_UART_UCR4_DREN    (0x00000001U) /*!< Bit mask for UART_UCR4_DREN. */
#define BS_UART_UCR4_DREN    (1U)          /*!< Bit field size in bits for UART_UCR4_DREN. */

/*! @brief Read current value of the UART_UCR4_DREN field. */
#define BR_UART_UCR4_DREN(x) (HW_UART_UCR4(x).B.DREN)

/*! @brief Format value for bitfield UART_UCR4_DREN. */
#define BF_UART_UCR4_DREN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_DREN) & BM_UART_UCR4_DREN)

/*! @brief Set the DREN field to a new value. */
#define BW_UART_UCR4_DREN(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_DREN) | BF_UART_UCR4_DREN(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field OREN[1] (RW)
 *
 * Receiver Overrun Interrupt Enable. Enables/Disables the ORE bit to generate
 * an interrupt.
 *
 * Values:
 * - 0 - Disable ORE interrupt
 * - 1 - Enable ORE interrupt
 */
/*@{*/
#define BP_UART_UCR4_OREN    (1U)          /*!< Bit position for UART_UCR4_OREN. */
#define BM_UART_UCR4_OREN    (0x00000002U) /*!< Bit mask for UART_UCR4_OREN. */
#define BS_UART_UCR4_OREN    (1U)          /*!< Bit field size in bits for UART_UCR4_OREN. */

/*! @brief Read current value of the UART_UCR4_OREN field. */
#define BR_UART_UCR4_OREN(x) (HW_UART_UCR4(x).B.OREN)

/*! @brief Format value for bitfield UART_UCR4_OREN. */
#define BF_UART_UCR4_OREN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_OREN) & BM_UART_UCR4_OREN)

/*! @brief Set the OREN field to a new value. */
#define BW_UART_UCR4_OREN(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_OREN) | BF_UART_UCR4_OREN(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field BKEN[2] (RW)
 *
 * BREAK Condition Detected Interrupt Enable. Enables/Disables the BRCD bit to
 * generate an interrupt.
 *
 * Values:
 * - 0 - Disable the BRCD interrupt
 * - 1 - Enable the BRCD interrupt
 */
/*@{*/
#define BP_UART_UCR4_BKEN    (2U)          /*!< Bit position for UART_UCR4_BKEN. */
#define BM_UART_UCR4_BKEN    (0x00000004U) /*!< Bit mask for UART_UCR4_BKEN. */
#define BS_UART_UCR4_BKEN    (1U)          /*!< Bit field size in bits for UART_UCR4_BKEN. */

/*! @brief Read current value of the UART_UCR4_BKEN field. */
#define BR_UART_UCR4_BKEN(x) (HW_UART_UCR4(x).B.BKEN)

/*! @brief Format value for bitfield UART_UCR4_BKEN. */
#define BF_UART_UCR4_BKEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_BKEN) & BM_UART_UCR4_BKEN)

/*! @brief Set the BKEN field to a new value. */
#define BW_UART_UCR4_BKEN(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_BKEN) | BF_UART_UCR4_BKEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field TCEN[3] (RW)
 *
 * Transmit Complete Interrupt Enable. Enables/Disables the TXDC bit to generate
 * an interrupt ( interrupt_uart = 0) An interrupt will be issued as long as
 * TCEN and TXDC are high even if the transmitter is not enabled. In general, user
 * should enable the transmitter before enabling the TXDC interrupt.
 *
 * Values:
 * - 0 - Disable TXDC interrupt
 * - 1 - Enable TXDC interrupt
 */
/*@{*/
#define BP_UART_UCR4_TCEN    (3U)          /*!< Bit position for UART_UCR4_TCEN. */
#define BM_UART_UCR4_TCEN    (0x00000008U) /*!< Bit mask for UART_UCR4_TCEN. */
#define BS_UART_UCR4_TCEN    (1U)          /*!< Bit field size in bits for UART_UCR4_TCEN. */

/*! @brief Read current value of the UART_UCR4_TCEN field. */
#define BR_UART_UCR4_TCEN(x) (HW_UART_UCR4(x).B.TCEN)

/*! @brief Format value for bitfield UART_UCR4_TCEN. */
#define BF_UART_UCR4_TCEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_TCEN) & BM_UART_UCR4_TCEN)

/*! @brief Set the TCEN field to a new value. */
#define BW_UART_UCR4_TCEN(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_TCEN) | BF_UART_UCR4_TCEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field LPBYP[4] (RW)
 *
 * Low Power Bypass. Allows to bypass the low power new features in UART. To use
 * during debug phase.
 *
 * Values:
 * - 0 - Low power features enabled
 * - 1 - Low power features disabled
 */
/*@{*/
#define BP_UART_UCR4_LPBYP   (4U)          /*!< Bit position for UART_UCR4_LPBYP. */
#define BM_UART_UCR4_LPBYP   (0x00000010U) /*!< Bit mask for UART_UCR4_LPBYP. */
#define BS_UART_UCR4_LPBYP   (1U)          /*!< Bit field size in bits for UART_UCR4_LPBYP. */

/*! @brief Read current value of the UART_UCR4_LPBYP field. */
#define BR_UART_UCR4_LPBYP(x) (HW_UART_UCR4(x).B.LPBYP)

/*! @brief Format value for bitfield UART_UCR4_LPBYP. */
#define BF_UART_UCR4_LPBYP(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_LPBYP) & BM_UART_UCR4_LPBYP)

/*! @brief Set the LPBYP field to a new value. */
#define BW_UART_UCR4_LPBYP(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_LPBYP) | BF_UART_UCR4_LPBYP(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field IRSC[5] (RW)
 *
 * IR Special Case. Selects the clock for the vote logic. When set, IRSC
 * switches the vote logic clock from the sampling clock to the UART reference clock.
 * The IR pulses are counted a predetermined amount of time depending on the
 * reference frequency. See InfraRed Special Case (IRSC) BitThe value to apply to IRSC
 * bit is based on 2 parameters: the baud rate and the Minimum Pulse Duration
 * (MPD) of the transceiver. .
 *
 * Values:
 * - 0 - The vote logic uses the sampling clock (16x baud rate) for normal
 *     operation
 * - 1 - The vote logic uses the UART reference clock
 */
/*@{*/
#define BP_UART_UCR4_IRSC    (5U)          /*!< Bit position for UART_UCR4_IRSC. */
#define BM_UART_UCR4_IRSC    (0x00000020U) /*!< Bit mask for UART_UCR4_IRSC. */
#define BS_UART_UCR4_IRSC    (1U)          /*!< Bit field size in bits for UART_UCR4_IRSC. */

/*! @brief Read current value of the UART_UCR4_IRSC field. */
#define BR_UART_UCR4_IRSC(x) (HW_UART_UCR4(x).B.IRSC)

/*! @brief Format value for bitfield UART_UCR4_IRSC. */
#define BF_UART_UCR4_IRSC(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_IRSC) & BM_UART_UCR4_IRSC)

/*! @brief Set the IRSC field to a new value. */
#define BW_UART_UCR4_IRSC(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_IRSC) | BF_UART_UCR4_IRSC(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field IDDMAEN[6] (RW)
 *
 * DMA IDLE Condition Detected Interrupt Enable Enables/Disables the receive DMA
 * request dma_req_rx for the IDLE interrupt (triggered with IDLE flag in
 * USR2[12]).
 *
 * Values:
 * - 0 - DMA IDLE interrupt disabled
 * - 1 - DMA IDLE interrupt enabled
 */
/*@{*/
#define BP_UART_UCR4_IDDMAEN (6U)          /*!< Bit position for UART_UCR4_IDDMAEN. */
#define BM_UART_UCR4_IDDMAEN (0x00000040U) /*!< Bit mask for UART_UCR4_IDDMAEN. */
#define BS_UART_UCR4_IDDMAEN (1U)          /*!< Bit field size in bits for UART_UCR4_IDDMAEN. */

/*! @brief Read current value of the UART_UCR4_IDDMAEN field. */
#define BR_UART_UCR4_IDDMAEN(x) (HW_UART_UCR4(x).B.IDDMAEN)

/*! @brief Format value for bitfield UART_UCR4_IDDMAEN. */
#define BF_UART_UCR4_IDDMAEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_IDDMAEN) & BM_UART_UCR4_IDDMAEN)

/*! @brief Set the IDDMAEN field to a new value. */
#define BW_UART_UCR4_IDDMAEN(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_IDDMAEN) | BF_UART_UCR4_IDDMAEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field WKEN[7] (RW)
 *
 * WAKE Interrupt Enable. Enables/Disables the WAKE bit to generate an
 * interrupt. The WAKE bit is set at the detection of a start bit by the receiver.
 *
 * Values:
 * - 0 - Disable the WAKE interrupt
 * - 1 - Enable the WAKE interrupt
 */
/*@{*/
#define BP_UART_UCR4_WKEN    (7U)          /*!< Bit position for UART_UCR4_WKEN. */
#define BM_UART_UCR4_WKEN    (0x00000080U) /*!< Bit mask for UART_UCR4_WKEN. */
#define BS_UART_UCR4_WKEN    (1U)          /*!< Bit field size in bits for UART_UCR4_WKEN. */

/*! @brief Read current value of the UART_UCR4_WKEN field. */
#define BR_UART_UCR4_WKEN(x) (HW_UART_UCR4(x).B.WKEN)

/*! @brief Format value for bitfield UART_UCR4_WKEN. */
#define BF_UART_UCR4_WKEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_WKEN) & BM_UART_UCR4_WKEN)

/*! @brief Set the WKEN field to a new value. */
#define BW_UART_UCR4_WKEN(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_WKEN) | BF_UART_UCR4_WKEN(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field ENIRI[8] (RW)
 *
 * Serial Infrared Interrupt Enable. Enables/Disables the serial infrared
 * interrupt.
 *
 * Values:
 * - 0 - Serial infrared Interrupt disabled
 * - 1 - Serial infrared Interrupt enabled
 */
/*@{*/
#define BP_UART_UCR4_ENIRI   (8U)          /*!< Bit position for UART_UCR4_ENIRI. */
#define BM_UART_UCR4_ENIRI   (0x00000100U) /*!< Bit mask for UART_UCR4_ENIRI. */
#define BS_UART_UCR4_ENIRI   (1U)          /*!< Bit field size in bits for UART_UCR4_ENIRI. */

/*! @brief Read current value of the UART_UCR4_ENIRI field. */
#define BR_UART_UCR4_ENIRI(x) (HW_UART_UCR4(x).B.ENIRI)

/*! @brief Format value for bitfield UART_UCR4_ENIRI. */
#define BF_UART_UCR4_ENIRI(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_ENIRI) & BM_UART_UCR4_ENIRI)

/*! @brief Set the ENIRI field to a new value. */
#define BW_UART_UCR4_ENIRI(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_ENIRI) | BF_UART_UCR4_ENIRI(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field INVR[9] (RW)
 *
 * Invert RXD input in RS-232/RS-485 Mode, determine RXD input logic level being
 * sampled in In IrDA mode. In RS232/RS-485 Mode(UMCR[0] = 1), if this bit is
 * set to 1, the RXD input is inverted before sampled. In IrDA mode,when cleared,
 * the infrared logic block expects an active low or negative IR 3/16 pulse for 0s
 * and 1s are expected for 1s. When INVR is set (INVR 1), the infrared logic
 * block expects an active high or positive IR 3/16 pulse for 0s and 0s are expected
 * for 1s.
 *
 * Values:
 * - 0 - RXD input is not inverted
 * - 1 - RXD input is inverted
 * - 0 - RXD active low detection
 * - 1 - RXD active high detection
 */
/*@{*/
#define BP_UART_UCR4_INVR    (9U)          /*!< Bit position for UART_UCR4_INVR. */
#define BM_UART_UCR4_INVR    (0x00000200U) /*!< Bit mask for UART_UCR4_INVR. */
#define BS_UART_UCR4_INVR    (1U)          /*!< Bit field size in bits for UART_UCR4_INVR. */

/*! @brief Read current value of the UART_UCR4_INVR field. */
#define BR_UART_UCR4_INVR(x) (HW_UART_UCR4(x).B.INVR)

/*! @brief Format value for bitfield UART_UCR4_INVR. */
#define BF_UART_UCR4_INVR(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_INVR) & BM_UART_UCR4_INVR)

/*! @brief Set the INVR field to a new value. */
#define BW_UART_UCR4_INVR(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_INVR) | BF_UART_UCR4_INVR(v)))
/*@}*/

/*!
 * @name Register UART_UCR4, field CTSTL[15:10] (RW)
 *
 * CTS Trigger Level. Controls the threshold at which the CTS_B pin is
 * deasserted by the RxFIFO. After the trigger level is reached and the CTS_B pin is
 * deasserted, the RxFIFO continues to receive data until it is full. The CTSTL bits
 * are encoded as shown in the Settings column. Settings 0 to 32 are in use. All
 * other settings are Reserved.
 *
 * Values:
 * - 000000 - 0 characters received
 * - 000001 - 1 characters in the RxFIFO
 * - 100000 - 32 characters in the RxFIFO (maximum)
 */
/*@{*/
#define BP_UART_UCR4_CTSTL   (10U)         /*!< Bit position for UART_UCR4_CTSTL. */
#define BM_UART_UCR4_CTSTL   (0x0000FC00U) /*!< Bit mask for UART_UCR4_CTSTL. */
#define BS_UART_UCR4_CTSTL   (6U)          /*!< Bit field size in bits for UART_UCR4_CTSTL. */

/*! @brief Read current value of the UART_UCR4_CTSTL field. */
#define BR_UART_UCR4_CTSTL(x) (HW_UART_UCR4(x).B.CTSTL)

/*! @brief Format value for bitfield UART_UCR4_CTSTL. */
#define BF_UART_UCR4_CTSTL(v) ((uint32_t)((uint32_t)(v) << BP_UART_UCR4_CTSTL) & BM_UART_UCR4_CTSTL)

/*! @brief Set the CTSTL field to a new value. */
#define BW_UART_UCR4_CTSTL(x, v) (HW_UART_UCR4_WR(x, (HW_UART_UCR4_RD(x) & ~BM_UART_UCR4_CTSTL) | BF_UART_UCR4_CTSTL(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UFCR - UART FIFO Control Register
 ******************************************************************************/

/*!
 * @brief HW_UART_UFCR - UART FIFO Control Register (RW)
 *
 * Reset value: 0x00000801U
 */
typedef union _hw_uart_ufcr
{
    uint32_t U;
    struct _hw_uart_ufcr_bitfields
    {
        uint32_t RXTL : 6;             /*!< [5:0]  */
        uint32_t DCEDTE : 1;           /*!< [6]  */
        uint32_t RFDIV : 3;            /*!< [9:7]  */
        uint32_t TXTL : 6;             /*!< [15:10]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_ufcr_t;

/*!
 * @name Constants and macros for entire UART_UFCR register
 */
/*@{*/
#define HW_UART_UFCR_ADDR(x)     ((uintptr_t)(x) + 0x90U)

#define HW_UART_UFCR(x)          (*(__IO hw_uart_ufcr_t *) HW_UART_UFCR_ADDR(x))
#define HW_UART_UFCR_RD(x)       (HW_UART_UFCR(x).U)
#define HW_UART_UFCR_WR(x, v)    (HW_UART_UFCR(x).U = (v))
#define HW_UART_UFCR_SET(x, v)   (HW_UART_UFCR_WR(x, HW_UART_UFCR_RD(x) |  (v)))
#define HW_UART_UFCR_CLR(x, v)   (HW_UART_UFCR_WR(x, HW_UART_UFCR_RD(x) & ~(v)))
#define HW_UART_UFCR_TOG(x, v)   (HW_UART_UFCR_WR(x, HW_UART_UFCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UFCR bitfields
 */

/*!
 * @name Register UART_UFCR, field RXTL[5:0] (RW)
 *
 * Receiver Trigger Level. Controls the threshold at which a maskable interrupt
 * is generated by the RxFIFO. A maskable interrupt is generated whenever the
 * data level in the RxFIFO reaches the selected threshold. The RXTL bits are
 * encoded as shown in the Settings column. Setting 0 to 32 are in use. All other
 * settings are Reserved.
 *
 * Values:
 * - 000000 - 0 characters received
 * - 000001 - RxFIFO has 1 character
 * - 011111 - RxFIFO has 31 characters
 * - 100000 - RxFIFO has 32 characters (maximum)
 */
/*@{*/
#define BP_UART_UFCR_RXTL    (0U)          /*!< Bit position for UART_UFCR_RXTL. */
#define BM_UART_UFCR_RXTL    (0x0000003FU) /*!< Bit mask for UART_UFCR_RXTL. */
#define BS_UART_UFCR_RXTL    (6U)          /*!< Bit field size in bits for UART_UFCR_RXTL. */

/*! @brief Read current value of the UART_UFCR_RXTL field. */
#define BR_UART_UFCR_RXTL(x) (HW_UART_UFCR(x).B.RXTL)

/*! @brief Format value for bitfield UART_UFCR_RXTL. */
#define BF_UART_UFCR_RXTL(v) ((uint32_t)((uint32_t)(v) << BP_UART_UFCR_RXTL) & BM_UART_UFCR_RXTL)

/*! @brief Set the RXTL field to a new value. */
#define BW_UART_UFCR_RXTL(x, v) (HW_UART_UFCR_WR(x, (HW_UART_UFCR_RD(x) & ~BM_UART_UFCR_RXTL) | BF_UART_UFCR_RXTL(v)))
/*@}*/

/*!
 * @name Register UART_UFCR, field DCEDTE[6] (RW)
 *
 * DCE/DTE mode select. Select UART as data communication equipment (DCE mode)
 * or as data terminal equipment (DTE mode).
 *
 * Values:
 * - 0 - DCE mode selected
 * - 1 - DTE mode selected
 */
/*@{*/
#define BP_UART_UFCR_DCEDTE  (6U)          /*!< Bit position for UART_UFCR_DCEDTE. */
#define BM_UART_UFCR_DCEDTE  (0x00000040U) /*!< Bit mask for UART_UFCR_DCEDTE. */
#define BS_UART_UFCR_DCEDTE  (1U)          /*!< Bit field size in bits for UART_UFCR_DCEDTE. */

/*! @brief Read current value of the UART_UFCR_DCEDTE field. */
#define BR_UART_UFCR_DCEDTE(x) (HW_UART_UFCR(x).B.DCEDTE)

/*! @brief Format value for bitfield UART_UFCR_DCEDTE. */
#define BF_UART_UFCR_DCEDTE(v) ((uint32_t)((uint32_t)(v) << BP_UART_UFCR_DCEDTE) & BM_UART_UFCR_DCEDTE)

/*! @brief Set the DCEDTE field to a new value. */
#define BW_UART_UFCR_DCEDTE(x, v) (HW_UART_UFCR_WR(x, (HW_UART_UFCR_RD(x) & ~BM_UART_UFCR_DCEDTE) | BF_UART_UFCR_DCEDTE(v)))
/*@}*/

/*!
 * @name Register UART_UFCR, field RFDIV[9:7] (RW)
 *
 * Reference Frequency Divider. Controls the divide ratio for the reference
 * clock. The input clock is module_clock. The output from the divider is ref_clk
 * which is used by BRM to create the 16x baud rate oversampling clock (brm_clk).
 *
 * Values:
 * - 000 - Divide input clock by 6
 * - 001 - Divide input clock by 5
 * - 010 - Divide input clock by 4
 * - 011 - Divide input clock by 3
 * - 100 - Divide input clock by 2
 * - 101 - Divide input clock by 1
 * - 110 - Divide input clock by 7
 * - 111 - Reserved
 */
/*@{*/
#define BP_UART_UFCR_RFDIV   (7U)          /*!< Bit position for UART_UFCR_RFDIV. */
#define BM_UART_UFCR_RFDIV   (0x00000380U) /*!< Bit mask for UART_UFCR_RFDIV. */
#define BS_UART_UFCR_RFDIV   (3U)          /*!< Bit field size in bits for UART_UFCR_RFDIV. */

/*! @brief Read current value of the UART_UFCR_RFDIV field. */
#define BR_UART_UFCR_RFDIV(x) (HW_UART_UFCR(x).B.RFDIV)

/*! @brief Format value for bitfield UART_UFCR_RFDIV. */
#define BF_UART_UFCR_RFDIV(v) ((uint32_t)((uint32_t)(v) << BP_UART_UFCR_RFDIV) & BM_UART_UFCR_RFDIV)

/*! @brief Set the RFDIV field to a new value. */
#define BW_UART_UFCR_RFDIV(x, v) (HW_UART_UFCR_WR(x, (HW_UART_UFCR_RD(x) & ~BM_UART_UFCR_RFDIV) | BF_UART_UFCR_RFDIV(v)))
/*@}*/

/*!
 * @name Register UART_UFCR, field TXTL[15:10] (RW)
 *
 * Transmitter Trigger Level. Controls the threshold at which a maskable
 * interrupt is generated by the TxFIFO. A maskable interrupt is generated whenever the
 * data level in the TxFIFO falls below the selected threshold. The bits are
 * encoded as shown in the Settings column. Settings 0 to 32 are in use. All other
 * settings are Reserved.
 *
 * Values:
 * - 000000 - Reserved
 * - 000001 - Reserved
 * - 000010 - TxFIFO has 2 or fewer characters
 * - 011111 - TxFIFO has 31 or fewer characters
 * - 100000 - TxFIFO has 32 characters (maximum)
 */
/*@{*/
#define BP_UART_UFCR_TXTL    (10U)         /*!< Bit position for UART_UFCR_TXTL. */
#define BM_UART_UFCR_TXTL    (0x0000FC00U) /*!< Bit mask for UART_UFCR_TXTL. */
#define BS_UART_UFCR_TXTL    (6U)          /*!< Bit field size in bits for UART_UFCR_TXTL. */

/*! @brief Read current value of the UART_UFCR_TXTL field. */
#define BR_UART_UFCR_TXTL(x) (HW_UART_UFCR(x).B.TXTL)

/*! @brief Format value for bitfield UART_UFCR_TXTL. */
#define BF_UART_UFCR_TXTL(v) ((uint32_t)((uint32_t)(v) << BP_UART_UFCR_TXTL) & BM_UART_UFCR_TXTL)

/*! @brief Set the TXTL field to a new value. */
#define BW_UART_UFCR_TXTL(x, v) (HW_UART_UFCR_WR(x, (HW_UART_UFCR_RD(x) & ~BM_UART_UFCR_TXTL) | BF_UART_UFCR_TXTL(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_USR1 - UART Status Register 1
 ******************************************************************************/

/*!
 * @brief HW_UART_USR1 - UART Status Register 1 (RW)
 *
 * Reset value: 0x00002040U
 */
typedef union _hw_uart_usr1
{
    uint32_t U;
    struct _hw_uart_usr1_bitfields
    {
        uint32_t RESERVED0 : 3;        /*!< [2:0]  */
        uint32_t SAD : 1;              /*!< [3]  */
        uint32_t AWAKE : 1;            /*!< [4]  */
        uint32_t AIRINT : 1;           /*!< [5]  */
        uint32_t RXDS : 1;             /*!< [6]  */
        uint32_t DTRD : 1;             /*!< [7]  */
        uint32_t AGTIM : 1;            /*!< [8]  */
        uint32_t RRDY : 1;             /*!< [9]  */
        uint32_t FRAMERR : 1;          /*!< [10]  */
        uint32_t ESCF : 1;             /*!< [11]  */
        uint32_t RTSD : 1;             /*!< [12]  */
        uint32_t TRDY : 1;             /*!< [13]  */
        uint32_t RTSS : 1;             /*!< [14]  */
        uint32_t PARITYERR : 1;        /*!< [15]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_usr1_t;

/*!
 * @name Constants and macros for entire UART_USR1 register
 */
/*@{*/
#define HW_UART_USR1_ADDR(x)     ((uintptr_t)(x) + 0x94U)

#define HW_UART_USR1(x)          (*(__IO hw_uart_usr1_t *) HW_UART_USR1_ADDR(x))
#define HW_UART_USR1_RD(x)       (HW_UART_USR1(x).U)
#define HW_UART_USR1_WR(x, v)    (HW_UART_USR1(x).U = (v))
#define HW_UART_USR1_SET(x, v)   (HW_UART_USR1_WR(x, HW_UART_USR1_RD(x) |  (v)))
#define HW_UART_USR1_CLR(x, v)   (HW_UART_USR1_WR(x, HW_UART_USR1_RD(x) & ~(v)))
#define HW_UART_USR1_TOG(x, v)   (HW_UART_USR1_WR(x, HW_UART_USR1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_USR1 bitfields
 */

/*!
 * @name Register UART_USR1, field SAD[3] (W1C)
 *
 * RS-485 Slave Address Detected Interrupt Flag. Indicates if RS-485 Slave
 * Address was detected . SAD was asserted in RS-485 mode when the SADEN bit is set
 * and Slave Address is detected in RxFIFO (in Nomal Address Detect Mode, the 9th
 * data bit = 1; in Automatic Address Detect Mode, the received charater matches
 * the programmed SLADDR).
 *
 * Values:
 * - 0 - No slave address detected
 * - 1 - Slave address detected
 */
/*@{*/
#define BP_UART_USR1_SAD     (3U)          /*!< Bit position for UART_USR1_SAD. */
#define BM_UART_USR1_SAD     (0x00000008U) /*!< Bit mask for UART_USR1_SAD. */
#define BS_UART_USR1_SAD     (1U)          /*!< Bit field size in bits for UART_USR1_SAD. */

/*! @brief Read current value of the UART_USR1_SAD field. */
#define BR_UART_USR1_SAD(x)  (HW_UART_USR1(x).B.SAD)

/*! @brief Format value for bitfield UART_USR1_SAD. */
#define BF_UART_USR1_SAD(v)  ((uint32_t)((uint32_t)(v) << BP_UART_USR1_SAD) & BM_UART_USR1_SAD)

/*! @brief Set the SAD field to a new value. */
#define BW_UART_USR1_SAD(x, v) (HW_UART_USR1_WR(x, (HW_UART_USR1_RD(x) & ~(BM_UART_USR1_SAD | BM_UART_USR1_AWAKE | BM_UART_USR1_AIRINT | BM_UART_USR1_DTRD | BM_UART_USR1_AGTIM | BM_UART_USR1_FRAMERR | BM_UART_USR1_ESCF | BM_UART_USR1_RTSD | BM_UART_USR1_PARITYERR)) | BF_UART_USR1_SAD(v)))
/*@}*/

/*!
 * @name Register UART_USR1, field AWAKE[4] (W1C)
 *
 * Asynchronous WAKE Interrupt Flag. Indicates that a falling edge was detected
 * on the RXD pin. Clear AWAKE by writing 1 to it. Writing 0 to AWAKE has no
 * effect.
 *
 * Values:
 * - 0 - No falling edge was detected on the RXD Serial pin
 * - 1 - A falling edge was detected on the RXD Serial pin
 */
/*@{*/
#define BP_UART_USR1_AWAKE   (4U)          /*!< Bit position for UART_USR1_AWAKE. */
#define BM_UART_USR1_AWAKE   (0x00000010U) /*!< Bit mask for UART_USR1_AWAKE. */
#define BS_UART_USR1_AWAKE   (1U)          /*!< Bit field size in bits for UART_USR1_AWAKE. */

/*! @brief Read current value of the UART_USR1_AWAKE field. */
#define BR_UART_USR1_AWAKE(x) (HW_UART_USR1(x).B.AWAKE)

/*! @brief Format value for bitfield UART_USR1_AWAKE. */
#define BF_UART_USR1_AWAKE(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR1_AWAKE) & BM_UART_USR1_AWAKE)

/*! @brief Set the AWAKE field to a new value. */
#define BW_UART_USR1_AWAKE(x, v) (HW_UART_USR1_WR(x, (HW_UART_USR1_RD(x) & ~(BM_UART_USR1_AWAKE | BM_UART_USR1_SAD | BM_UART_USR1_AIRINT | BM_UART_USR1_DTRD | BM_UART_USR1_AGTIM | BM_UART_USR1_FRAMERR | BM_UART_USR1_ESCF | BM_UART_USR1_RTSD | BM_UART_USR1_PARITYERR)) | BF_UART_USR1_AWAKE(v)))
/*@}*/

/*!
 * @name Register UART_USR1, field AIRINT[5] (W1C)
 *
 * Asynchronous IR WAKE Interrupt Flag. Indicates that the IR WAKE pulse was
 * detected on the RXD pin. Clear AIRINT by writing 1 to it. Writing 0 to AIRINT has
 * no effect.
 *
 * Values:
 * - 0 - No pulse was detected on the RXD IrDA pin
 * - 1 - A pulse was detected on the RXD IrDA pin
 */
/*@{*/
#define BP_UART_USR1_AIRINT  (5U)          /*!< Bit position for UART_USR1_AIRINT. */
#define BM_UART_USR1_AIRINT  (0x00000020U) /*!< Bit mask for UART_USR1_AIRINT. */
#define BS_UART_USR1_AIRINT  (1U)          /*!< Bit field size in bits for UART_USR1_AIRINT. */

/*! @brief Read current value of the UART_USR1_AIRINT field. */
#define BR_UART_USR1_AIRINT(x) (HW_UART_USR1(x).B.AIRINT)

/*! @brief Format value for bitfield UART_USR1_AIRINT. */
#define BF_UART_USR1_AIRINT(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR1_AIRINT) & BM_UART_USR1_AIRINT)

/*! @brief Set the AIRINT field to a new value. */
#define BW_UART_USR1_AIRINT(x, v) (HW_UART_USR1_WR(x, (HW_UART_USR1_RD(x) & ~(BM_UART_USR1_AIRINT | BM_UART_USR1_SAD | BM_UART_USR1_AWAKE | BM_UART_USR1_DTRD | BM_UART_USR1_AGTIM | BM_UART_USR1_FRAMERR | BM_UART_USR1_ESCF | BM_UART_USR1_RTSD | BM_UART_USR1_PARITYERR)) | BF_UART_USR1_AIRINT(v)))
/*@}*/

/*!
 * @name Register UART_USR1, field RXDS[6] (RO)
 *
 * Receiver IDLE Interrupt Flag. Indicates that the receiver state machine is in
 * an IDLE state, the next state is IDLE, and the receive pin is high. RXDS is
 * automatically cleared when a character is received. RXDS is active only when
 * the receiver is enabled.
 *
 * Values:
 * - 0 - Receive in progress
 * - 1 - Receiver is IDLE
 */
/*@{*/
#define BP_UART_USR1_RXDS    (6U)          /*!< Bit position for UART_USR1_RXDS. */
#define BM_UART_USR1_RXDS    (0x00000040U) /*!< Bit mask for UART_USR1_RXDS. */
#define BS_UART_USR1_RXDS    (1U)          /*!< Bit field size in bits for UART_USR1_RXDS. */

/*! @brief Read current value of the UART_USR1_RXDS field. */
#define BR_UART_USR1_RXDS(x) (HW_UART_USR1(x).B.RXDS)
/*@}*/

/*!
 * @name Register UART_USR1, field DTRD[7] (W1C)
 *
 * This bit is not used in this chip.
 */
/*@{*/
#define BP_UART_USR1_DTRD    (7U)          /*!< Bit position for UART_USR1_DTRD. */
#define BM_UART_USR1_DTRD    (0x00000080U) /*!< Bit mask for UART_USR1_DTRD. */
#define BS_UART_USR1_DTRD    (1U)          /*!< Bit field size in bits for UART_USR1_DTRD. */

/*! @brief Read current value of the UART_USR1_DTRD field. */
#define BR_UART_USR1_DTRD(x) (HW_UART_USR1(x).B.DTRD)

/*! @brief Format value for bitfield UART_USR1_DTRD. */
#define BF_UART_USR1_DTRD(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR1_DTRD) & BM_UART_USR1_DTRD)

/*! @brief Set the DTRD field to a new value. */
#define BW_UART_USR1_DTRD(x, v) (HW_UART_USR1_WR(x, (HW_UART_USR1_RD(x) & ~(BM_UART_USR1_DTRD | BM_UART_USR1_SAD | BM_UART_USR1_AWAKE | BM_UART_USR1_AIRINT | BM_UART_USR1_AGTIM | BM_UART_USR1_FRAMERR | BM_UART_USR1_ESCF | BM_UART_USR1_RTSD | BM_UART_USR1_PARITYERR)) | BF_UART_USR1_DTRD(v)))
/*@}*/

/*!
 * @name Register UART_USR1, field AGTIM[8] (W1C)
 *
 * Ageing Timer Interrupt Flag. Indicates that data in the RxFIFO has been idle
 * for a time of 8 character lengths (where a character length consists of 7 or 8
 * bits, depending on the setting of the WS bit in UCR2, with the bit time
 * corresponding to the baud rate setting) and FIFO data level is less than RxFIFO
 * threshold level (RXTL in the UFCR). Clear by writing a 1 to it.
 *
 * Values:
 * - 0 - AGTIM is not active
 * - 1 - AGTIM is active (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR1_AGTIM   (8U)          /*!< Bit position for UART_USR1_AGTIM. */
#define BM_UART_USR1_AGTIM   (0x00000100U) /*!< Bit mask for UART_USR1_AGTIM. */
#define BS_UART_USR1_AGTIM   (1U)          /*!< Bit field size in bits for UART_USR1_AGTIM. */

/*! @brief Read current value of the UART_USR1_AGTIM field. */
#define BR_UART_USR1_AGTIM(x) (HW_UART_USR1(x).B.AGTIM)

/*! @brief Format value for bitfield UART_USR1_AGTIM. */
#define BF_UART_USR1_AGTIM(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR1_AGTIM) & BM_UART_USR1_AGTIM)

/*! @brief Set the AGTIM field to a new value. */
#define BW_UART_USR1_AGTIM(x, v) (HW_UART_USR1_WR(x, (HW_UART_USR1_RD(x) & ~(BM_UART_USR1_AGTIM | BM_UART_USR1_SAD | BM_UART_USR1_AWAKE | BM_UART_USR1_AIRINT | BM_UART_USR1_DTRD | BM_UART_USR1_FRAMERR | BM_UART_USR1_ESCF | BM_UART_USR1_RTSD | BM_UART_USR1_PARITYERR)) | BF_UART_USR1_AGTIM(v)))
/*@}*/

/*!
 * @name Register UART_USR1, field RRDY[9] (RO)
 *
 * Receiver Ready Interrupt / DMA Flag. Indicates that the RxFIFO data level is
 * above the threshold set by the RXTL bits. (See the RXTL bits description in
 * UFCRUART FIFO Control Register for setting the interrupt threshold.) When
 * asserted, RRDY generates a maskable interrupt or DMA request. RRDY is automatically
 * cleared when data level in the RxFIFO goes below the set threshold level. At
 * reset, RRDY is set to 0.
 *
 * Values:
 * - 0 - No character ready
 * - 1 - Character(s) ready (interrupt posted)
 */
/*@{*/
#define BP_UART_USR1_RRDY    (9U)          /*!< Bit position for UART_USR1_RRDY. */
#define BM_UART_USR1_RRDY    (0x00000200U) /*!< Bit mask for UART_USR1_RRDY. */
#define BS_UART_USR1_RRDY    (1U)          /*!< Bit field size in bits for UART_USR1_RRDY. */

/*! @brief Read current value of the UART_USR1_RRDY field. */
#define BR_UART_USR1_RRDY(x) (HW_UART_USR1(x).B.RRDY)
/*@}*/

/*!
 * @name Register UART_USR1, field FRAMERR[10] (W1C)
 *
 * Frame Error Interrupt Flag. Indicates that a frame error is detected. The
 * interrupt_uart interrupt will be generated if a frame error is detected and the
 * interrupt is enabled. Clear FRAMERR by writing 1 to it. Writing 0 to FRAMERR
 * has no effect.
 *
 * Values:
 * - 0 - No frame error detected
 * - 1 - Frame error detected (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR1_FRAMERR (10U)         /*!< Bit position for UART_USR1_FRAMERR. */
#define BM_UART_USR1_FRAMERR (0x00000400U) /*!< Bit mask for UART_USR1_FRAMERR. */
#define BS_UART_USR1_FRAMERR (1U)          /*!< Bit field size in bits for UART_USR1_FRAMERR. */

/*! @brief Read current value of the UART_USR1_FRAMERR field. */
#define BR_UART_USR1_FRAMERR(x) (HW_UART_USR1(x).B.FRAMERR)

/*! @brief Format value for bitfield UART_USR1_FRAMERR. */
#define BF_UART_USR1_FRAMERR(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR1_FRAMERR) & BM_UART_USR1_FRAMERR)

/*! @brief Set the FRAMERR field to a new value. */
#define BW_UART_USR1_FRAMERR(x, v) (HW_UART_USR1_WR(x, (HW_UART_USR1_RD(x) & ~(BM_UART_USR1_FRAMERR | BM_UART_USR1_SAD | BM_UART_USR1_AWAKE | BM_UART_USR1_AIRINT | BM_UART_USR1_DTRD | BM_UART_USR1_AGTIM | BM_UART_USR1_ESCF | BM_UART_USR1_RTSD | BM_UART_USR1_PARITYERR)) | BF_UART_USR1_FRAMERR(v)))
/*@}*/

/*!
 * @name Register UART_USR1, field ESCF[11] (W1C)
 *
 * Escape Sequence Interrupt Flag. Indicates if an escape sequence was detected.
 * ESCF is asserted when the ESCEN bit is set and an escape sequence is detected
 * in the RxFIFO. Clear ESCF by writing 1 to it. Writing 0 to ESCF has no effect.
 *
 * Values:
 * - 0 - No escape sequence detected
 * - 1 - Escape sequence detected (write 1 to clear).
 */
/*@{*/
#define BP_UART_USR1_ESCF    (11U)         /*!< Bit position for UART_USR1_ESCF. */
#define BM_UART_USR1_ESCF    (0x00000800U) /*!< Bit mask for UART_USR1_ESCF. */
#define BS_UART_USR1_ESCF    (1U)          /*!< Bit field size in bits for UART_USR1_ESCF. */

/*! @brief Read current value of the UART_USR1_ESCF field. */
#define BR_UART_USR1_ESCF(x) (HW_UART_USR1(x).B.ESCF)

/*! @brief Format value for bitfield UART_USR1_ESCF. */
#define BF_UART_USR1_ESCF(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR1_ESCF) & BM_UART_USR1_ESCF)

/*! @brief Set the ESCF field to a new value. */
#define BW_UART_USR1_ESCF(x, v) (HW_UART_USR1_WR(x, (HW_UART_USR1_RD(x) & ~(BM_UART_USR1_ESCF | BM_UART_USR1_SAD | BM_UART_USR1_AWAKE | BM_UART_USR1_AIRINT | BM_UART_USR1_DTRD | BM_UART_USR1_AGTIM | BM_UART_USR1_FRAMERR | BM_UART_USR1_RTSD | BM_UART_USR1_PARITYERR)) | BF_UART_USR1_ESCF(v)))
/*@}*/

/*!
 * @name Register UART_USR1, field RTSD[12] (W1C)
 *
 * RTS Delta. Indicates whether the RTS_B pin changed state. It (RTSD) generates
 * a maskable interrupt. When in STOP mode, RTS assertion sets RTSD and can be
 * used to wake the processor. The current state of the RTS_B pin is available on
 * the RTSS bit. Clear RTSD by writing 1 to it. Writing 0 to RTSD has no effect.
 * At reset, RTSD is set to 0.
 *
 * Values:
 * - 0 - RTS_B pin did not change state since last cleared
 * - 1 - RTS_B pin changed state (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR1_RTSD    (12U)         /*!< Bit position for UART_USR1_RTSD. */
#define BM_UART_USR1_RTSD    (0x00001000U) /*!< Bit mask for UART_USR1_RTSD. */
#define BS_UART_USR1_RTSD    (1U)          /*!< Bit field size in bits for UART_USR1_RTSD. */

/*! @brief Read current value of the UART_USR1_RTSD field. */
#define BR_UART_USR1_RTSD(x) (HW_UART_USR1(x).B.RTSD)

/*! @brief Format value for bitfield UART_USR1_RTSD. */
#define BF_UART_USR1_RTSD(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR1_RTSD) & BM_UART_USR1_RTSD)

/*! @brief Set the RTSD field to a new value. */
#define BW_UART_USR1_RTSD(x, v) (HW_UART_USR1_WR(x, (HW_UART_USR1_RD(x) & ~(BM_UART_USR1_RTSD | BM_UART_USR1_SAD | BM_UART_USR1_AWAKE | BM_UART_USR1_AIRINT | BM_UART_USR1_DTRD | BM_UART_USR1_AGTIM | BM_UART_USR1_FRAMERR | BM_UART_USR1_ESCF | BM_UART_USR1_PARITYERR)) | BF_UART_USR1_RTSD(v)))
/*@}*/

/*!
 * @name Register UART_USR1, field TRDY[13] (RO)
 *
 * Transmitter Ready Interrupt / DMA Flag. Indicates that the TxFIFO emptied
 * below its target threshold and requires data. TRDY is automatically cleared when
 * the data level in the TxFIFO exceeds the threshold set by TXTL bits. At reset,
 * TRDY is set to 1.
 *
 * Values:
 * - 0 - The transmitter does not require data
 * - 1 - The transmitter requires data (interrupt posted)
 */
/*@{*/
#define BP_UART_USR1_TRDY    (13U)         /*!< Bit position for UART_USR1_TRDY. */
#define BM_UART_USR1_TRDY    (0x00002000U) /*!< Bit mask for UART_USR1_TRDY. */
#define BS_UART_USR1_TRDY    (1U)          /*!< Bit field size in bits for UART_USR1_TRDY. */

/*! @brief Read current value of the UART_USR1_TRDY field. */
#define BR_UART_USR1_TRDY(x) (HW_UART_USR1(x).B.TRDY)
/*@}*/

/*!
 * @name Register UART_USR1, field RTSS[14] (RO)
 *
 * RTS_B Pin Status. Indicates the current status of the RTS_B pin. A "snapshot"
 * of RTS_B is taken immediately before RTSS is presented to the data bus. RTSS
 * cannot be cleared because all writes to RTSS are ignored. At reset, RTSS is
 * set to 0.
 *
 * Values:
 * - 0 - The RTS_B module input is high (inactive)
 * - 1 - The RTS_B module input is low (active)
 */
/*@{*/
#define BP_UART_USR1_RTSS    (14U)         /*!< Bit position for UART_USR1_RTSS. */
#define BM_UART_USR1_RTSS    (0x00004000U) /*!< Bit mask for UART_USR1_RTSS. */
#define BS_UART_USR1_RTSS    (1U)          /*!< Bit field size in bits for UART_USR1_RTSS. */

/*! @brief Read current value of the UART_USR1_RTSS field. */
#define BR_UART_USR1_RTSS(x) (HW_UART_USR1(x).B.RTSS)
/*@}*/

/*!
 * @name Register UART_USR1, field PARITYERR[15] (W1C)
 *
 * Parity Error Interrupt Flag. Indicates a parity error is detected. PARITYERR
 * is cleared by writing 1 to it. Writing 0 to PARITYERR has no effect. When
 * parity is disabled, PARITYERR always reads 0. At reset, PARITYERR is set to 0.
 *
 * Values:
 * - 0 - No parity error detected
 * - 1 - Parity error detected (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR1_PARITYERR (15U)       /*!< Bit position for UART_USR1_PARITYERR. */
#define BM_UART_USR1_PARITYERR (0x00008000U) /*!< Bit mask for UART_USR1_PARITYERR. */
#define BS_UART_USR1_PARITYERR (1U)        /*!< Bit field size in bits for UART_USR1_PARITYERR. */

/*! @brief Read current value of the UART_USR1_PARITYERR field. */
#define BR_UART_USR1_PARITYERR(x) (HW_UART_USR1(x).B.PARITYERR)

/*! @brief Format value for bitfield UART_USR1_PARITYERR. */
#define BF_UART_USR1_PARITYERR(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR1_PARITYERR) & BM_UART_USR1_PARITYERR)

/*! @brief Set the PARITYERR field to a new value. */
#define BW_UART_USR1_PARITYERR(x, v) (HW_UART_USR1_WR(x, (HW_UART_USR1_RD(x) & ~(BM_UART_USR1_PARITYERR | BM_UART_USR1_SAD | BM_UART_USR1_AWAKE | BM_UART_USR1_AIRINT | BM_UART_USR1_DTRD | BM_UART_USR1_AGTIM | BM_UART_USR1_FRAMERR | BM_UART_USR1_ESCF | BM_UART_USR1_RTSD)) | BF_UART_USR1_PARITYERR(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_USR2 - UART Status Register 2
 ******************************************************************************/

/*!
 * @brief HW_UART_USR2 - UART Status Register 2 (RW)
 *
 * Reset value: 0x00004028U
 */
typedef union _hw_uart_usr2
{
    uint32_t U;
    struct _hw_uart_usr2_bitfields
    {
        uint32_t RDR : 1;              /*!< [0]  */
        uint32_t ORE : 1;              /*!< [1]  */
        uint32_t BRCD : 1;             /*!< [2]  */
        uint32_t TXDC : 1;             /*!< [3]  */
        uint32_t RTSF : 1;             /*!< [4]  */
        uint32_t DCDIN : 1;            /*!< [5]  */
        uint32_t DCDDELT : 1;          /*!< [6]  */
        uint32_t WAKE : 1;             /*!< [7]  */
        uint32_t IRINT : 1;            /*!< [8]  */
        uint32_t RIIN : 1;             /*!< [9]  */
        uint32_t RIDELT : 1;           /*!< [10]  */
        uint32_t ACST : 1;             /*!< [11]  */
        uint32_t IDLE : 1;             /*!< [12]  */
        uint32_t DTRF : 1;             /*!< [13]  */
        uint32_t TXFE : 1;             /*!< [14]  */
        uint32_t ADET : 1;             /*!< [15]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_usr2_t;

/*!
 * @name Constants and macros for entire UART_USR2 register
 */
/*@{*/
#define HW_UART_USR2_ADDR(x)     ((uintptr_t)(x) + 0x98U)

#define HW_UART_USR2(x)          (*(__IO hw_uart_usr2_t *) HW_UART_USR2_ADDR(x))
#define HW_UART_USR2_RD(x)       (HW_UART_USR2(x).U)
#define HW_UART_USR2_WR(x, v)    (HW_UART_USR2(x).U = (v))
#define HW_UART_USR2_SET(x, v)   (HW_UART_USR2_WR(x, HW_UART_USR2_RD(x) |  (v)))
#define HW_UART_USR2_CLR(x, v)   (HW_UART_USR2_WR(x, HW_UART_USR2_RD(x) & ~(v)))
#define HW_UART_USR2_TOG(x, v)   (HW_UART_USR2_WR(x, HW_UART_USR2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_USR2 bitfields
 */

/*!
 * @name Register UART_USR2, field RDR[0] (RO)
 *
 * Receive Data Ready-Indicates that at least 1 character is received and
 * written to the RxFIFO. If the URXD register is read and there is only 1 character in
 * the RxFIFO, RDR is automatically cleared.
 *
 * Values:
 * - 0 - No receive data ready
 * - 1 - Receive data ready
 */
/*@{*/
#define BP_UART_USR2_RDR     (0U)          /*!< Bit position for UART_USR2_RDR. */
#define BM_UART_USR2_RDR     (0x00000001U) /*!< Bit mask for UART_USR2_RDR. */
#define BS_UART_USR2_RDR     (1U)          /*!< Bit field size in bits for UART_USR2_RDR. */

/*! @brief Read current value of the UART_USR2_RDR field. */
#define BR_UART_USR2_RDR(x)  (HW_UART_USR2(x).B.RDR)
/*@}*/

/*!
 * @name Register UART_USR2, field ORE[1] (W1C)
 *
 * Overrun Error. When set to 1, ORE indicates that the receive buffer (RxFIFO)
 * was full (32 chars inside), and a 33rd character has been fully received. This
 * 33rd character has been discarded. Clear ORE by writing 1 to it. Writing 0 to
 * ORE has no effect.
 *
 * Values:
 * - 0 - No overrun error
 * - 1 - Overrun error (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR2_ORE     (1U)          /*!< Bit position for UART_USR2_ORE. */
#define BM_UART_USR2_ORE     (0x00000002U) /*!< Bit mask for UART_USR2_ORE. */
#define BS_UART_USR2_ORE     (1U)          /*!< Bit field size in bits for UART_USR2_ORE. */

/*! @brief Read current value of the UART_USR2_ORE field. */
#define BR_UART_USR2_ORE(x)  (HW_UART_USR2(x).B.ORE)

/*! @brief Format value for bitfield UART_USR2_ORE. */
#define BF_UART_USR2_ORE(v)  ((uint32_t)((uint32_t)(v) << BP_UART_USR2_ORE) & BM_UART_USR2_ORE)

/*! @brief Set the ORE field to a new value. */
#define BW_UART_USR2_ORE(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_RTSF | BM_UART_USR2_DCDDELT | BM_UART_USR2_WAKE | BM_UART_USR2_IRINT | BM_UART_USR2_RIDELT | BM_UART_USR2_ACST | BM_UART_USR2_IDLE | BM_UART_USR2_DTRF | BM_UART_USR2_ADET)) | BF_UART_USR2_ORE(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field BRCD[2] (W1C)
 *
 * BREAK Condition Detected. Indicates that a BREAK condition was detected by
 * the receiver. Clear BRCD by writing 1 to it. Writing 0 to BRCD has no effect.
 *
 * Values:
 * - 0 - No BREAK condition was detected
 * - 1 - A BREAK condition was detected (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR2_BRCD    (2U)          /*!< Bit position for UART_USR2_BRCD. */
#define BM_UART_USR2_BRCD    (0x00000004U) /*!< Bit mask for UART_USR2_BRCD. */
#define BS_UART_USR2_BRCD    (1U)          /*!< Bit field size in bits for UART_USR2_BRCD. */

/*! @brief Read current value of the UART_USR2_BRCD field. */
#define BR_UART_USR2_BRCD(x) (HW_UART_USR2(x).B.BRCD)

/*! @brief Format value for bitfield UART_USR2_BRCD. */
#define BF_UART_USR2_BRCD(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_BRCD) & BM_UART_USR2_BRCD)

/*! @brief Set the BRCD field to a new value. */
#define BW_UART_USR2_BRCD(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_BRCD | BM_UART_USR2_ORE | BM_UART_USR2_RTSF | BM_UART_USR2_DCDDELT | BM_UART_USR2_WAKE | BM_UART_USR2_IRINT | BM_UART_USR2_RIDELT | BM_UART_USR2_ACST | BM_UART_USR2_IDLE | BM_UART_USR2_DTRF | BM_UART_USR2_ADET)) | BF_UART_USR2_BRCD(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field TXDC[3] (RO)
 *
 * Transmitter Complete. Indicates that the transmit buffer (TxFIFO) and Shift
 * Register is empty; therefore the transmission is complete. TXDC is cleared
 * automatically when data is written to the TxFIFO.
 *
 * Values:
 * - 0 - Transmit is incomplete
 * - 1 - Transmit is complete
 */
/*@{*/
#define BP_UART_USR2_TXDC    (3U)          /*!< Bit position for UART_USR2_TXDC. */
#define BM_UART_USR2_TXDC    (0x00000008U) /*!< Bit mask for UART_USR2_TXDC. */
#define BS_UART_USR2_TXDC    (1U)          /*!< Bit field size in bits for UART_USR2_TXDC. */

/*! @brief Read current value of the UART_USR2_TXDC field. */
#define BR_UART_USR2_TXDC(x) (HW_UART_USR2(x).B.TXDC)
/*@}*/

/*!
 * @name Register UART_USR2, field RTSF[4] (W1C)
 *
 * RTS Edge Triggered Interrupt Flag. Indicates if a programmed edge is detected
 * on the RTS_B pin. The RTEC bits select the edge that generates an interrupt
 * (see ). RTSF can generate an interrupt that can be masked using the RTSEN bit.
 * Clear RTSF by writing 1 to it. Writing 0 to RTSF has no effect.
 *
 * Values:
 * - 0 - Programmed edge not detected on RTS_B
 * - 1 - Programmed edge detected on RTS_B (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR2_RTSF    (4U)          /*!< Bit position for UART_USR2_RTSF. */
#define BM_UART_USR2_RTSF    (0x00000010U) /*!< Bit mask for UART_USR2_RTSF. */
#define BS_UART_USR2_RTSF    (1U)          /*!< Bit field size in bits for UART_USR2_RTSF. */

/*! @brief Read current value of the UART_USR2_RTSF field. */
#define BR_UART_USR2_RTSF(x) (HW_UART_USR2(x).B.RTSF)

/*! @brief Format value for bitfield UART_USR2_RTSF. */
#define BF_UART_USR2_RTSF(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_RTSF) & BM_UART_USR2_RTSF)

/*! @brief Set the RTSF field to a new value. */
#define BW_UART_USR2_RTSF(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_RTSF | BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_DCDDELT | BM_UART_USR2_WAKE | BM_UART_USR2_IRINT | BM_UART_USR2_RIDELT | BM_UART_USR2_ACST | BM_UART_USR2_IDLE | BM_UART_USR2_DTRF | BM_UART_USR2_ADET)) | BF_UART_USR2_RTSF(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field DCDIN[5] (RO)
 *
 * This bit is not used in this chip.
 */
/*@{*/
#define BP_UART_USR2_DCDIN   (5U)          /*!< Bit position for UART_USR2_DCDIN. */
#define BM_UART_USR2_DCDIN   (0x00000020U) /*!< Bit mask for UART_USR2_DCDIN. */
#define BS_UART_USR2_DCDIN   (1U)          /*!< Bit field size in bits for UART_USR2_DCDIN. */

/*! @brief Read current value of the UART_USR2_DCDIN field. */
#define BR_UART_USR2_DCDIN(x) (HW_UART_USR2(x).B.DCDIN)
/*@}*/

/*!
 * @name Register UART_USR2, field DCDDELT[6] (W1C)
 *
 * This bit is not used in this chip.
 */
/*@{*/
#define BP_UART_USR2_DCDDELT (6U)          /*!< Bit position for UART_USR2_DCDDELT. */
#define BM_UART_USR2_DCDDELT (0x00000040U) /*!< Bit mask for UART_USR2_DCDDELT. */
#define BS_UART_USR2_DCDDELT (1U)          /*!< Bit field size in bits for UART_USR2_DCDDELT. */

/*! @brief Read current value of the UART_USR2_DCDDELT field. */
#define BR_UART_USR2_DCDDELT(x) (HW_UART_USR2(x).B.DCDDELT)

/*! @brief Format value for bitfield UART_USR2_DCDDELT. */
#define BF_UART_USR2_DCDDELT(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_DCDDELT) & BM_UART_USR2_DCDDELT)

/*! @brief Set the DCDDELT field to a new value. */
#define BW_UART_USR2_DCDDELT(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_DCDDELT | BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_RTSF | BM_UART_USR2_WAKE | BM_UART_USR2_IRINT | BM_UART_USR2_RIDELT | BM_UART_USR2_ACST | BM_UART_USR2_IDLE | BM_UART_USR2_DTRF | BM_UART_USR2_ADET)) | BF_UART_USR2_DCDDELT(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field WAKE[7] (W1C)
 *
 * Wake. Indicates the start bit is detected. WAKE can generate an interrupt
 * that can be masked using the WKEN bit. Clear WAKE by writing 1 to it. Writing 0
 * to WAKE has no effect.
 *
 * Values:
 * - 0 - start bit not detected
 * - 1 - start bit detected (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR2_WAKE    (7U)          /*!< Bit position for UART_USR2_WAKE. */
#define BM_UART_USR2_WAKE    (0x00000080U) /*!< Bit mask for UART_USR2_WAKE. */
#define BS_UART_USR2_WAKE    (1U)          /*!< Bit field size in bits for UART_USR2_WAKE. */

/*! @brief Read current value of the UART_USR2_WAKE field. */
#define BR_UART_USR2_WAKE(x) (HW_UART_USR2(x).B.WAKE)

/*! @brief Format value for bitfield UART_USR2_WAKE. */
#define BF_UART_USR2_WAKE(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_WAKE) & BM_UART_USR2_WAKE)

/*! @brief Set the WAKE field to a new value. */
#define BW_UART_USR2_WAKE(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_WAKE | BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_RTSF | BM_UART_USR2_DCDDELT | BM_UART_USR2_IRINT | BM_UART_USR2_RIDELT | BM_UART_USR2_ACST | BM_UART_USR2_IDLE | BM_UART_USR2_DTRF | BM_UART_USR2_ADET)) | BF_UART_USR2_WAKE(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field IRINT[8] (W1C)
 *
 * Serial Infrared Interrupt Flag. When an edge is detected on the RXD pin
 * during SIR Mode, this flag will be asserted. This flag can cause an interrupt which
 * can be masked using the control bit ENIRI: UCR4 [8].
 *
 * Values:
 * - 0 - no edge detected
 * - 1 - valid edge detected (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR2_IRINT   (8U)          /*!< Bit position for UART_USR2_IRINT. */
#define BM_UART_USR2_IRINT   (0x00000100U) /*!< Bit mask for UART_USR2_IRINT. */
#define BS_UART_USR2_IRINT   (1U)          /*!< Bit field size in bits for UART_USR2_IRINT. */

/*! @brief Read current value of the UART_USR2_IRINT field. */
#define BR_UART_USR2_IRINT(x) (HW_UART_USR2(x).B.IRINT)

/*! @brief Format value for bitfield UART_USR2_IRINT. */
#define BF_UART_USR2_IRINT(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_IRINT) & BM_UART_USR2_IRINT)

/*! @brief Set the IRINT field to a new value. */
#define BW_UART_USR2_IRINT(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_IRINT | BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_RTSF | BM_UART_USR2_DCDDELT | BM_UART_USR2_WAKE | BM_UART_USR2_RIDELT | BM_UART_USR2_ACST | BM_UART_USR2_IDLE | BM_UART_USR2_DTRF | BM_UART_USR2_ADET)) | BF_UART_USR2_IRINT(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field RIIN[9] (RO)
 *
 * This bit is not used in this chip.
 */
/*@{*/
#define BP_UART_USR2_RIIN    (9U)          /*!< Bit position for UART_USR2_RIIN. */
#define BM_UART_USR2_RIIN    (0x00000200U) /*!< Bit mask for UART_USR2_RIIN. */
#define BS_UART_USR2_RIIN    (1U)          /*!< Bit field size in bits for UART_USR2_RIIN. */

/*! @brief Read current value of the UART_USR2_RIIN field. */
#define BR_UART_USR2_RIIN(x) (HW_UART_USR2(x).B.RIIN)
/*@}*/

/*!
 * @name Register UART_USR2, field RIDELT[10] (W1C)
 *
 * This bit is not used in this chip.
 */
/*@{*/
#define BP_UART_USR2_RIDELT  (10U)         /*!< Bit position for UART_USR2_RIDELT. */
#define BM_UART_USR2_RIDELT  (0x00000400U) /*!< Bit mask for UART_USR2_RIDELT. */
#define BS_UART_USR2_RIDELT  (1U)          /*!< Bit field size in bits for UART_USR2_RIDELT. */

/*! @brief Read current value of the UART_USR2_RIDELT field. */
#define BR_UART_USR2_RIDELT(x) (HW_UART_USR2(x).B.RIDELT)

/*! @brief Format value for bitfield UART_USR2_RIDELT. */
#define BF_UART_USR2_RIDELT(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_RIDELT) & BM_UART_USR2_RIDELT)

/*! @brief Set the RIDELT field to a new value. */
#define BW_UART_USR2_RIDELT(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_RIDELT | BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_RTSF | BM_UART_USR2_DCDDELT | BM_UART_USR2_WAKE | BM_UART_USR2_IRINT | BM_UART_USR2_ACST | BM_UART_USR2_IDLE | BM_UART_USR2_DTRF | BM_UART_USR2_ADET)) | BF_UART_USR2_RIDELT(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field ACST[11] (W1C)
 *
 * Autobaud Counter Stopped. In autobaud detection (ADBR=1), indicates the
 * counter which determines the baud rate was running and is now stopped. This means
 * either START bit is finished (if ADNIMP=1), or Bit 0 is finished (if ADNIMP=0).
 * See New Autobaud Counter Stopped bit and InterruptA new bit has been added in
 * USR2 register: ACST (USR2[11]). This bit is set immediately after the
 * determination of the baud rate. , for more details. An interrupt can be flagged on
 * interrupt_uart if ACIEN=1.
 *
 * Values:
 * - 0 - Measurement of bit length not finished (in autobaud)
 * - 1 - Measurement of bit length finished (in autobaud). (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR2_ACST    (11U)         /*!< Bit position for UART_USR2_ACST. */
#define BM_UART_USR2_ACST    (0x00000800U) /*!< Bit mask for UART_USR2_ACST. */
#define BS_UART_USR2_ACST    (1U)          /*!< Bit field size in bits for UART_USR2_ACST. */

/*! @brief Read current value of the UART_USR2_ACST field. */
#define BR_UART_USR2_ACST(x) (HW_UART_USR2(x).B.ACST)

/*! @brief Format value for bitfield UART_USR2_ACST. */
#define BF_UART_USR2_ACST(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_ACST) & BM_UART_USR2_ACST)

/*! @brief Set the ACST field to a new value. */
#define BW_UART_USR2_ACST(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_ACST | BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_RTSF | BM_UART_USR2_DCDDELT | BM_UART_USR2_WAKE | BM_UART_USR2_IRINT | BM_UART_USR2_RIDELT | BM_UART_USR2_IDLE | BM_UART_USR2_DTRF | BM_UART_USR2_ADET)) | BF_UART_USR2_ACST(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field IDLE[12] (W1C)
 *
 * Idle Condition. Indicates that an idle condition has existed for more than a
 * programmed amount frame (see Idle Line DetectThe receiver logic block includes
 * the ability to detect an idle line. Idle lines indicate the end or the
 * beginning of a message. . An interrupt can be generated by this IDLE bit if IDEN
 * (UCR1[12]) is enabled. IDLE is cleared by writing 1 to it. Writing 0 to IDLE has
 * no effect.
 *
 * Values:
 * - 0 - No idle condition detected
 * - 1 - Idle condition detected (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR2_IDLE    (12U)         /*!< Bit position for UART_USR2_IDLE. */
#define BM_UART_USR2_IDLE    (0x00001000U) /*!< Bit mask for UART_USR2_IDLE. */
#define BS_UART_USR2_IDLE    (1U)          /*!< Bit field size in bits for UART_USR2_IDLE. */

/*! @brief Read current value of the UART_USR2_IDLE field. */
#define BR_UART_USR2_IDLE(x) (HW_UART_USR2(x).B.IDLE)

/*! @brief Format value for bitfield UART_USR2_IDLE. */
#define BF_UART_USR2_IDLE(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_IDLE) & BM_UART_USR2_IDLE)

/*! @brief Set the IDLE field to a new value. */
#define BW_UART_USR2_IDLE(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_IDLE | BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_RTSF | BM_UART_USR2_DCDDELT | BM_UART_USR2_WAKE | BM_UART_USR2_IRINT | BM_UART_USR2_RIDELT | BM_UART_USR2_ACST | BM_UART_USR2_DTRF | BM_UART_USR2_ADET)) | BF_UART_USR2_IDLE(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field DTRF[13] (W1C)
 *
 * This bit is not used in this chip.
 */
/*@{*/
#define BP_UART_USR2_DTRF    (13U)         /*!< Bit position for UART_USR2_DTRF. */
#define BM_UART_USR2_DTRF    (0x00002000U) /*!< Bit mask for UART_USR2_DTRF. */
#define BS_UART_USR2_DTRF    (1U)          /*!< Bit field size in bits for UART_USR2_DTRF. */

/*! @brief Read current value of the UART_USR2_DTRF field. */
#define BR_UART_USR2_DTRF(x) (HW_UART_USR2(x).B.DTRF)

/*! @brief Format value for bitfield UART_USR2_DTRF. */
#define BF_UART_USR2_DTRF(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_DTRF) & BM_UART_USR2_DTRF)

/*! @brief Set the DTRF field to a new value. */
#define BW_UART_USR2_DTRF(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_DTRF | BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_RTSF | BM_UART_USR2_DCDDELT | BM_UART_USR2_WAKE | BM_UART_USR2_IRINT | BM_UART_USR2_RIDELT | BM_UART_USR2_ACST | BM_UART_USR2_IDLE | BM_UART_USR2_ADET)) | BF_UART_USR2_DTRF(v)))
/*@}*/

/*!
 * @name Register UART_USR2, field TXFE[14] (RO)
 *
 * Transmit Buffer FIFO Empty. Indicates that the transmit buffer (TxFIFO) is
 * empty. TXFE is cleared automatically when data is written to the TxFIFO. Even
 * though TXFE is high, the transmission might still be in progress.
 *
 * Values:
 * - 0 - The transmit buffer (TxFIFO) is not empty
 * - 1 - The transmit buffer (TxFIFO) is empty
 */
/*@{*/
#define BP_UART_USR2_TXFE    (14U)         /*!< Bit position for UART_USR2_TXFE. */
#define BM_UART_USR2_TXFE    (0x00004000U) /*!< Bit mask for UART_USR2_TXFE. */
#define BS_UART_USR2_TXFE    (1U)          /*!< Bit field size in bits for UART_USR2_TXFE. */

/*! @brief Read current value of the UART_USR2_TXFE field. */
#define BR_UART_USR2_TXFE(x) (HW_UART_USR2(x).B.TXFE)
/*@}*/

/*!
 * @name Register UART_USR2, field ADET[15] (W1C)
 *
 * Automatic Baud Rate Detect Complete. Indicates that an "A" or "a" was
 * received and that the receiver detected and verified the incoming baud rate. Clear
 * ADET by writing 1 to it. Writing 0 to ADET has no effect.
 *
 * Values:
 * - 0 - ASCII "A" or "a" was not received
 * - 1 - ASCII "A" or "a" was received (write 1 to clear)
 */
/*@{*/
#define BP_UART_USR2_ADET    (15U)         /*!< Bit position for UART_USR2_ADET. */
#define BM_UART_USR2_ADET    (0x00008000U) /*!< Bit mask for UART_USR2_ADET. */
#define BS_UART_USR2_ADET    (1U)          /*!< Bit field size in bits for UART_USR2_ADET. */

/*! @brief Read current value of the UART_USR2_ADET field. */
#define BR_UART_USR2_ADET(x) (HW_UART_USR2(x).B.ADET)

/*! @brief Format value for bitfield UART_USR2_ADET. */
#define BF_UART_USR2_ADET(v) ((uint32_t)((uint32_t)(v) << BP_UART_USR2_ADET) & BM_UART_USR2_ADET)

/*! @brief Set the ADET field to a new value. */
#define BW_UART_USR2_ADET(x, v) (HW_UART_USR2_WR(x, (HW_UART_USR2_RD(x) & ~(BM_UART_USR2_ADET | BM_UART_USR2_ORE | BM_UART_USR2_BRCD | BM_UART_USR2_RTSF | BM_UART_USR2_DCDDELT | BM_UART_USR2_WAKE | BM_UART_USR2_IRINT | BM_UART_USR2_RIDELT | BM_UART_USR2_ACST | BM_UART_USR2_IDLE | BM_UART_USR2_DTRF)) | BF_UART_USR2_ADET(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UESC - UART Escape Character Register
 ******************************************************************************/

/*!
 * @brief HW_UART_UESC - UART Escape Character Register (RW)
 *
 * Reset value: 0x0000002BU
 */
typedef union _hw_uart_uesc
{
    uint32_t U;
    struct _hw_uart_uesc_bitfields
    {
        uint32_t ESC_CHAR : 8;         /*!< [7:0]  */
        uint32_t RESERVED0 : 24;       /*!< [31:8]  */
    } B;
} hw_uart_uesc_t;

/*!
 * @name Constants and macros for entire UART_UESC register
 */
/*@{*/
#define HW_UART_UESC_ADDR(x)     ((uintptr_t)(x) + 0x9CU)

#define HW_UART_UESC(x)          (*(__IO hw_uart_uesc_t *) HW_UART_UESC_ADDR(x))
#define HW_UART_UESC_RD(x)       (HW_UART_UESC(x).U)
#define HW_UART_UESC_WR(x, v)    (HW_UART_UESC(x).U = (v))
#define HW_UART_UESC_SET(x, v)   (HW_UART_UESC_WR(x, HW_UART_UESC_RD(x) |  (v)))
#define HW_UART_UESC_CLR(x, v)   (HW_UART_UESC_WR(x, HW_UART_UESC_RD(x) & ~(v)))
#define HW_UART_UESC_TOG(x, v)   (HW_UART_UESC_WR(x, HW_UART_UESC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UESC bitfields
 */

/*!
 * @name Register UART_UESC, field ESC_CHAR[7:0] (RW)
 *
 * UART Escape Character. Holds the selected escape character that all received
 * characters are compared against to detect an escape sequence.
 */
/*@{*/
#define BP_UART_UESC_ESC_CHAR (0U)         /*!< Bit position for UART_UESC_ESC_CHAR. */
#define BM_UART_UESC_ESC_CHAR (0x000000FFU) /*!< Bit mask for UART_UESC_ESC_CHAR. */
#define BS_UART_UESC_ESC_CHAR (8U)         /*!< Bit field size in bits for UART_UESC_ESC_CHAR. */

/*! @brief Read current value of the UART_UESC_ESC_CHAR field. */
#define BR_UART_UESC_ESC_CHAR(x) (HW_UART_UESC(x).B.ESC_CHAR)

/*! @brief Format value for bitfield UART_UESC_ESC_CHAR. */
#define BF_UART_UESC_ESC_CHAR(v) ((uint32_t)((uint32_t)(v) << BP_UART_UESC_ESC_CHAR) & BM_UART_UESC_ESC_CHAR)

/*! @brief Set the ESC_CHAR field to a new value. */
#define BW_UART_UESC_ESC_CHAR(x, v) (HW_UART_UESC_WR(x, (HW_UART_UESC_RD(x) & ~BM_UART_UESC_ESC_CHAR) | BF_UART_UESC_ESC_CHAR(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UTIM - UART Escape Timer Register
 ******************************************************************************/

/*!
 * @brief HW_UART_UTIM - UART Escape Timer Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_uart_utim
{
    uint32_t U;
    struct _hw_uart_utim_bitfields
    {
        uint32_t TIM : 12;             /*!< [11:0]  */
        uint32_t RESERVED0 : 20;       /*!< [31:12]  */
    } B;
} hw_uart_utim_t;

/*!
 * @name Constants and macros for entire UART_UTIM register
 */
/*@{*/
#define HW_UART_UTIM_ADDR(x)     ((uintptr_t)(x) + 0xA0U)

#define HW_UART_UTIM(x)          (*(__IO hw_uart_utim_t *) HW_UART_UTIM_ADDR(x))
#define HW_UART_UTIM_RD(x)       (HW_UART_UTIM(x).U)
#define HW_UART_UTIM_WR(x, v)    (HW_UART_UTIM(x).U = (v))
#define HW_UART_UTIM_SET(x, v)   (HW_UART_UTIM_WR(x, HW_UART_UTIM_RD(x) |  (v)))
#define HW_UART_UTIM_CLR(x, v)   (HW_UART_UTIM_WR(x, HW_UART_UTIM_RD(x) & ~(v)))
#define HW_UART_UTIM_TOG(x, v)   (HW_UART_UTIM_WR(x, HW_UART_UTIM_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UTIM bitfields
 */

/*!
 * @name Register UART_UTIM, field TIM[11:0] (RW)
 *
 * UART Escape Timer. Holds the maximum time interval (in ms) allowed between
 * escape characters. The escape timer register is programmable in intervals of 2
 * ms. See Escape Sequence DetectionAn escape sequence typically consists of 3
 * characters entered in rapid succession (such as +++). Because these are valid
 * characters by themselves, the time between characters determines if it is a valid
 * escape sequence. and for more information on the UART escape sequence
 * detection. Reset value 0x000 = 2 ms up to 0xFFF = 8.192 s.
 */
/*@{*/
#define BP_UART_UTIM_TIM     (0U)          /*!< Bit position for UART_UTIM_TIM. */
#define BM_UART_UTIM_TIM     (0x00000FFFU) /*!< Bit mask for UART_UTIM_TIM. */
#define BS_UART_UTIM_TIM     (12U)         /*!< Bit field size in bits for UART_UTIM_TIM. */

/*! @brief Read current value of the UART_UTIM_TIM field. */
#define BR_UART_UTIM_TIM(x)  (HW_UART_UTIM(x).B.TIM)

/*! @brief Format value for bitfield UART_UTIM_TIM. */
#define BF_UART_UTIM_TIM(v)  ((uint32_t)((uint32_t)(v) << BP_UART_UTIM_TIM) & BM_UART_UTIM_TIM)

/*! @brief Set the TIM field to a new value. */
#define BW_UART_UTIM_TIM(x, v) (HW_UART_UTIM_WR(x, (HW_UART_UTIM_RD(x) & ~BM_UART_UTIM_TIM) | BF_UART_UTIM_TIM(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UBIR - UART BRM Incremental Register
 ******************************************************************************/

/*!
 * @brief HW_UART_UBIR - UART BRM Incremental Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register can be written by both software and hardware. When enabling the
 * automatic baud rate detection feature hardware can write 0x000F value into
 * the UBIR after finishing detecting baud rate. Hardware has higher priority when
 * both software and hardware try to write it at the same cycle Note: The write
 * priority in the new design is not same as the original UART. In the orginal
 * design, software has higher priority than hardware when writing this register at
 * the same time. . Please note software reset will reset the register to its
 * reset value.
 */
typedef union _hw_uart_ubir
{
    uint32_t U;
    struct _hw_uart_ubir_bitfields
    {
        uint32_t INC : 16;             /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_ubir_t;

/*!
 * @name Constants and macros for entire UART_UBIR register
 */
/*@{*/
#define HW_UART_UBIR_ADDR(x)     ((uintptr_t)(x) + 0xA4U)

#define HW_UART_UBIR(x)          (*(__IO hw_uart_ubir_t *) HW_UART_UBIR_ADDR(x))
#define HW_UART_UBIR_RD(x)       (HW_UART_UBIR(x).U)
#define HW_UART_UBIR_WR(x, v)    (HW_UART_UBIR(x).U = (v))
#define HW_UART_UBIR_SET(x, v)   (HW_UART_UBIR_WR(x, HW_UART_UBIR_RD(x) |  (v)))
#define HW_UART_UBIR_CLR(x, v)   (HW_UART_UBIR_WR(x, HW_UART_UBIR_RD(x) & ~(v)))
#define HW_UART_UBIR_TOG(x, v)   (HW_UART_UBIR_WR(x, HW_UART_UBIR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UBIR bitfields
 */

/*!
 * @name Register UART_UBIR, field INC[15:0] (RW)
 *
 * Incremental Numerator. Holds the numerator value minus one of the BRM ratio
 * (see Binary Rate Multiplier (BRM)The BRM sub-block receives ref_clk
 * (module_clock clock after divider). From this clock, and with integer and non-integer
 * division, BRM generates a 16x baud rate clock . ). The UBIR register MUST be
 * updated before the UBMR register for the baud rate to be updated correctly. If
 * only one register is written to by software, the BRM will ignore this data until
 * the other register is written to by software. Updating this field using byte
 * accesses is not recommended and is undefined.
 */
/*@{*/
#define BP_UART_UBIR_INC     (0U)          /*!< Bit position for UART_UBIR_INC. */
#define BM_UART_UBIR_INC     (0x0000FFFFU) /*!< Bit mask for UART_UBIR_INC. */
#define BS_UART_UBIR_INC     (16U)         /*!< Bit field size in bits for UART_UBIR_INC. */

/*! @brief Read current value of the UART_UBIR_INC field. */
#define BR_UART_UBIR_INC(x)  (HW_UART_UBIR(x).B.INC)

/*! @brief Format value for bitfield UART_UBIR_INC. */
#define BF_UART_UBIR_INC(v)  ((uint32_t)((uint32_t)(v) << BP_UART_UBIR_INC) & BM_UART_UBIR_INC)

/*! @brief Set the INC field to a new value. */
#define BW_UART_UBIR_INC(x, v) (HW_UART_UBIR_WR(x, (HW_UART_UBIR_RD(x) & ~BM_UART_UBIR_INC) | BF_UART_UBIR_INC(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UBMR - UART BRM Modulator Register
 ******************************************************************************/

/*!
 * @brief HW_UART_UBMR - UART BRM Modulator Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register can be written by both software and hardware. When enabling the
 * automatic baud rate detection feature hardware can write a proper value into
 * the UBMR based on detected baud rate. Hardware has higher priority when both
 * software and hardware try to write it at the same cycle Note: The write
 * priority in the new design is not same as the original UART. In the orginal design,
 * software has higher priority than hardware when writing this register at the
 * same time. . Please note software reset will reset the register to its reset
 * value.
 */
typedef union _hw_uart_ubmr
{
    uint32_t U;
    struct _hw_uart_ubmr_bitfields
    {
        uint32_t MOD : 16;             /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_ubmr_t;

/*!
 * @name Constants and macros for entire UART_UBMR register
 */
/*@{*/
#define HW_UART_UBMR_ADDR(x)     ((uintptr_t)(x) + 0xA8U)

#define HW_UART_UBMR(x)          (*(__IO hw_uart_ubmr_t *) HW_UART_UBMR_ADDR(x))
#define HW_UART_UBMR_RD(x)       (HW_UART_UBMR(x).U)
#define HW_UART_UBMR_WR(x, v)    (HW_UART_UBMR(x).U = (v))
#define HW_UART_UBMR_SET(x, v)   (HW_UART_UBMR_WR(x, HW_UART_UBMR_RD(x) |  (v)))
#define HW_UART_UBMR_CLR(x, v)   (HW_UART_UBMR_WR(x, HW_UART_UBMR_RD(x) & ~(v)))
#define HW_UART_UBMR_TOG(x, v)   (HW_UART_UBMR_WR(x, HW_UART_UBMR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UBMR bitfields
 */

/*!
 * @name Register UART_UBMR, field MOD[15:0] (RW)
 *
 * Modulator Denominator. Holds the value of the denominator minus one of the
 * BRM ratio (see Binary Rate Multiplier (BRM)The BRM sub-block receives ref_clk
 * (module_clock clock after divider). From this clock, and with integer and
 * non-integer division, BRM generates a 16x baud rate clock . ). The UBIR register
 * MUST be updated before the UBMR register for the baud rate to be updated
 * correctly. If only one register is written to by software, the BRM will ignore this
 * data until the other register is written to by software. Updating this register
 * using byte accesses is not recommended and undefined.
 */
/*@{*/
#define BP_UART_UBMR_MOD     (0U)          /*!< Bit position for UART_UBMR_MOD. */
#define BM_UART_UBMR_MOD     (0x0000FFFFU) /*!< Bit mask for UART_UBMR_MOD. */
#define BS_UART_UBMR_MOD     (16U)         /*!< Bit field size in bits for UART_UBMR_MOD. */

/*! @brief Read current value of the UART_UBMR_MOD field. */
#define BR_UART_UBMR_MOD(x)  (HW_UART_UBMR(x).B.MOD)

/*! @brief Format value for bitfield UART_UBMR_MOD. */
#define BF_UART_UBMR_MOD(v)  ((uint32_t)((uint32_t)(v) << BP_UART_UBMR_MOD) & BM_UART_UBMR_MOD)

/*! @brief Set the MOD field to a new value. */
#define BW_UART_UBMR_MOD(x, v) (HW_UART_UBMR_WR(x, (HW_UART_UBMR_RD(x) & ~BM_UART_UBMR_MOD) | BF_UART_UBMR_MOD(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UBRC - UART Baud Rate Count Register
 ******************************************************************************/

/*!
 * @brief HW_UART_UBRC - UART Baud Rate Count Register (RO)
 *
 * Reset value: 0x00000004U
 */
typedef union _hw_uart_ubrc
{
    uint32_t U;
    struct _hw_uart_ubrc_bitfields
    {
        uint32_t BCNT : 16;            /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_ubrc_t;

/*!
 * @name Constants and macros for entire UART_UBRC register
 */
/*@{*/
#define HW_UART_UBRC_ADDR(x)     ((uintptr_t)(x) + 0xACU)

#define HW_UART_UBRC(x)          (*(__I hw_uart_ubrc_t *) HW_UART_UBRC_ADDR(x))
#define HW_UART_UBRC_RD(x)       (HW_UART_UBRC(x).U)
/*@}*/

/*
 * Constants & macros for individual UART_UBRC bitfields
 */

/*!
 * @name Register UART_UBRC, field BCNT[15:0] (RO)
 *
 * Baud Rate Count Register. This read only register is used to count the start
 * bit of the incoming baud rate (if ADNIMP=1), or start bit + bit0 (if
 * ADNIMP=0). When the measurement is done, the Baud Rate Count Register contains the
 * number of UART internal clock cycles (clock after divider) present in an incoming
 * bit. BCNT retains its value until the next Automatic Baud Rate Detection
 * sequence has been initiated. The 16 bit Baud Rate Count register is reset to 4 and
 * stays at hex FFFF in the case of an overflow.
 */
/*@{*/
#define BP_UART_UBRC_BCNT    (0U)          /*!< Bit position for UART_UBRC_BCNT. */
#define BM_UART_UBRC_BCNT    (0x0000FFFFU) /*!< Bit mask for UART_UBRC_BCNT. */
#define BS_UART_UBRC_BCNT    (16U)         /*!< Bit field size in bits for UART_UBRC_BCNT. */

/*! @brief Read current value of the UART_UBRC_BCNT field. */
#define BR_UART_UBRC_BCNT(x) (HW_UART_UBRC(x).B.BCNT)
/*@}*/

/*******************************************************************************
 * HW_UART_ONEMS - UART One Millisecond Register
 ******************************************************************************/

/*!
 * @brief HW_UART_ONEMS - UART One Millisecond Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register has been expanded from 16 bits to 24 bits. In previous
 * versions, the 16-bit ONEMS can only support the maximum 65.535MHz (0xFFFFx1000)
 * ref_clk. To support 4Mbps Bluetooth application with 66.5MHz module_clock , the
 * value 0x103C4 (66.5M/1000) should be written into this register. In this case, the
 * 16 bits are not enough to contain the 0x103C4. So this register was expanded
 * to 24 bits to support high frequency of the ref_clk.
 */
typedef union _hw_uart_onems
{
    uint32_t U;
    struct _hw_uart_onems_bitfields
    {
        uint32_t ONEMS : 24;           /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_uart_onems_t;

/*!
 * @name Constants and macros for entire UART_ONEMS register
 */
/*@{*/
#define HW_UART_ONEMS_ADDR(x)    ((uintptr_t)(x) + 0xB0U)

#define HW_UART_ONEMS(x)         (*(__IO hw_uart_onems_t *) HW_UART_ONEMS_ADDR(x))
#define HW_UART_ONEMS_RD(x)      (HW_UART_ONEMS(x).U)
#define HW_UART_ONEMS_WR(x, v)   (HW_UART_ONEMS(x).U = (v))
#define HW_UART_ONEMS_SET(x, v)  (HW_UART_ONEMS_WR(x, HW_UART_ONEMS_RD(x) |  (v)))
#define HW_UART_ONEMS_CLR(x, v)  (HW_UART_ONEMS_WR(x, HW_UART_ONEMS_RD(x) & ~(v)))
#define HW_UART_ONEMS_TOG(x, v)  (HW_UART_ONEMS_WR(x, HW_UART_ONEMS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_ONEMS bitfields
 */

/*!
 * @name Register UART_ONEMS, field ONEMS[23:0] (RW)
 *
 * One Millisecond Register. This 24-bit register must contain the value of the
 * UART internal frequency (ref_clk in ) divided by 1000. The internal frequency
 * is obtained after the UART BRM internal divider (F (ref_clk) = F(module_clock)
 * / RFDIV). In fact this register contains the value corresponding to the
 * number of UART BRM internal clock cycles present in one millisecond. The ONEMS (and
 * UTIM) registers value are used in the escape character detection feature
 * (Escape Sequence DetectionAn escape sequence typically consists of 3 characters
 * entered in rapid succession (such as +++). Because these are valid characters by
 * themselves, the time between characters determines if it is a valid escape
 * sequence. ) to count the number of clock cycles left between two escape
 * characters. The ONEMS register is also used in infrared special case mode (IRSC =
 * UCR4[5] = 1'b1), see InfraRed Special Case (IRSC) BitThe value to apply to IRSC
 * bit is based on 2 parameters: the baud rate and the Minimum Pulse Duration (MPD)
 * of the transceiver. .
 */
/*@{*/
#define BP_UART_ONEMS_ONEMS  (0U)          /*!< Bit position for UART_ONEMS_ONEMS. */
#define BM_UART_ONEMS_ONEMS  (0x00FFFFFFU) /*!< Bit mask for UART_ONEMS_ONEMS. */
#define BS_UART_ONEMS_ONEMS  (24U)         /*!< Bit field size in bits for UART_ONEMS_ONEMS. */

/*! @brief Read current value of the UART_ONEMS_ONEMS field. */
#define BR_UART_ONEMS_ONEMS(x) (HW_UART_ONEMS(x).B.ONEMS)

/*! @brief Format value for bitfield UART_ONEMS_ONEMS. */
#define BF_UART_ONEMS_ONEMS(v) ((uint32_t)((uint32_t)(v) << BP_UART_ONEMS_ONEMS) & BM_UART_ONEMS_ONEMS)

/*! @brief Set the ONEMS field to a new value. */
#define BW_UART_ONEMS_ONEMS(x, v) (HW_UART_ONEMS_WR(x, (HW_UART_ONEMS_RD(x) & ~BM_UART_ONEMS_ONEMS) | BF_UART_ONEMS_ONEMS(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UTS - UART Test Register
 ******************************************************************************/

/*!
 * @brief HW_UART_UTS - UART Test Register (RW)
 *
 * Reset value: 0x00000060U
 */
typedef union _hw_uart_uts
{
    uint32_t U;
    struct _hw_uart_uts_bitfields
    {
        uint32_t SOFTRST : 1;          /*!< [0]  */
        uint32_t RESERVED0 : 2;        /*!< [2:1]  */
        uint32_t RXFULL : 1;           /*!< [3]  */
        uint32_t TXFULL : 1;           /*!< [4]  */
        uint32_t RXEMPTY : 1;          /*!< [5]  */
        uint32_t TXEMPTY : 1;          /*!< [6]  */
        uint32_t RESERVED1 : 2;        /*!< [8:7]  */
        uint32_t RXDBG : 1;            /*!< [9]  */
        uint32_t LOOPIR : 1;           /*!< [10]  */
        uint32_t DBGEN : 1;            /*!< [11]  */
        uint32_t LOOP : 1;             /*!< [12]  */
        uint32_t FRCPERR : 1;          /*!< [13]  */
        uint32_t RESERVED2 : 18;       /*!< [31:14]  */
    } B;
} hw_uart_uts_t;

/*!
 * @name Constants and macros for entire UART_UTS register
 */
/*@{*/
#define HW_UART_UTS_ADDR(x)      ((uintptr_t)(x) + 0xB4U)

#define HW_UART_UTS(x)           (*(__IO hw_uart_uts_t *) HW_UART_UTS_ADDR(x))
#define HW_UART_UTS_RD(x)        (HW_UART_UTS(x).U)
#define HW_UART_UTS_WR(x, v)     (HW_UART_UTS(x).U = (v))
#define HW_UART_UTS_SET(x, v)    (HW_UART_UTS_WR(x, HW_UART_UTS_RD(x) |  (v)))
#define HW_UART_UTS_CLR(x, v)    (HW_UART_UTS_WR(x, HW_UART_UTS_RD(x) & ~(v)))
#define HW_UART_UTS_TOG(x, v)    (HW_UART_UTS_WR(x, HW_UART_UTS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UTS bitfields
 */

/*!
 * @name Register UART_UTS, field SOFTRST[0] (RW)
 *
 * Software Reset. Indicates the status of the software reset (SRST_B bit of
 * UCR2).
 *
 * Values:
 * - 0 - Software reset inactive
 * - 1 - Software reset active
 */
/*@{*/
#define BP_UART_UTS_SOFTRST  (0U)          /*!< Bit position for UART_UTS_SOFTRST. */
#define BM_UART_UTS_SOFTRST  (0x00000001U) /*!< Bit mask for UART_UTS_SOFTRST. */
#define BS_UART_UTS_SOFTRST  (1U)          /*!< Bit field size in bits for UART_UTS_SOFTRST. */

/*! @brief Read current value of the UART_UTS_SOFTRST field. */
#define BR_UART_UTS_SOFTRST(x) (HW_UART_UTS(x).B.SOFTRST)

/*! @brief Format value for bitfield UART_UTS_SOFTRST. */
#define BF_UART_UTS_SOFTRST(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTS_SOFTRST) & BM_UART_UTS_SOFTRST)

/*! @brief Set the SOFTRST field to a new value. */
#define BW_UART_UTS_SOFTRST(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_SOFTRST) | BF_UART_UTS_SOFTRST(v)))
/*@}*/

/*!
 * @name Register UART_UTS, field RXFULL[3] (RW)
 *
 * RxFIFO FULL. Indicates the RxFIFO is full.
 *
 * Values:
 * - 0 - The RxFIFO is not full
 * - 1 - The RxFIFO is full
 */
/*@{*/
#define BP_UART_UTS_RXFULL   (3U)          /*!< Bit position for UART_UTS_RXFULL. */
#define BM_UART_UTS_RXFULL   (0x00000008U) /*!< Bit mask for UART_UTS_RXFULL. */
#define BS_UART_UTS_RXFULL   (1U)          /*!< Bit field size in bits for UART_UTS_RXFULL. */

/*! @brief Read current value of the UART_UTS_RXFULL field. */
#define BR_UART_UTS_RXFULL(x) (HW_UART_UTS(x).B.RXFULL)

/*! @brief Format value for bitfield UART_UTS_RXFULL. */
#define BF_UART_UTS_RXFULL(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTS_RXFULL) & BM_UART_UTS_RXFULL)

/*! @brief Set the RXFULL field to a new value. */
#define BW_UART_UTS_RXFULL(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_RXFULL) | BF_UART_UTS_RXFULL(v)))
/*@}*/

/*!
 * @name Register UART_UTS, field TXFULL[4] (RW)
 *
 * TxFIFO FULL. Indicates the TxFIFO is full.
 *
 * Values:
 * - 0 - The TxFIFO is not full
 * - 1 - The TxFIFO is full
 */
/*@{*/
#define BP_UART_UTS_TXFULL   (4U)          /*!< Bit position for UART_UTS_TXFULL. */
#define BM_UART_UTS_TXFULL   (0x00000010U) /*!< Bit mask for UART_UTS_TXFULL. */
#define BS_UART_UTS_TXFULL   (1U)          /*!< Bit field size in bits for UART_UTS_TXFULL. */

/*! @brief Read current value of the UART_UTS_TXFULL field. */
#define BR_UART_UTS_TXFULL(x) (HW_UART_UTS(x).B.TXFULL)

/*! @brief Format value for bitfield UART_UTS_TXFULL. */
#define BF_UART_UTS_TXFULL(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTS_TXFULL) & BM_UART_UTS_TXFULL)

/*! @brief Set the TXFULL field to a new value. */
#define BW_UART_UTS_TXFULL(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_TXFULL) | BF_UART_UTS_TXFULL(v)))
/*@}*/

/*!
 * @name Register UART_UTS, field RXEMPTY[5] (RW)
 *
 * RxFIFO Empty. Indicates the RxFIFO is empty.
 *
 * Values:
 * - 0 - The RxFIFO is not empty
 * - 1 - The RxFIFO is empty
 */
/*@{*/
#define BP_UART_UTS_RXEMPTY  (5U)          /*!< Bit position for UART_UTS_RXEMPTY. */
#define BM_UART_UTS_RXEMPTY  (0x00000020U) /*!< Bit mask for UART_UTS_RXEMPTY. */
#define BS_UART_UTS_RXEMPTY  (1U)          /*!< Bit field size in bits for UART_UTS_RXEMPTY. */

/*! @brief Read current value of the UART_UTS_RXEMPTY field. */
#define BR_UART_UTS_RXEMPTY(x) (HW_UART_UTS(x).B.RXEMPTY)

/*! @brief Format value for bitfield UART_UTS_RXEMPTY. */
#define BF_UART_UTS_RXEMPTY(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTS_RXEMPTY) & BM_UART_UTS_RXEMPTY)

/*! @brief Set the RXEMPTY field to a new value. */
#define BW_UART_UTS_RXEMPTY(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_RXEMPTY) | BF_UART_UTS_RXEMPTY(v)))
/*@}*/

/*!
 * @name Register UART_UTS, field TXEMPTY[6] (RW)
 *
 * TxFIFO Empty. Indicates that the TxFIFO is empty.
 *
 * Values:
 * - 0 - The TxFIFO is not empty
 * - 1 - The TxFIFO is empty
 */
/*@{*/
#define BP_UART_UTS_TXEMPTY  (6U)          /*!< Bit position for UART_UTS_TXEMPTY. */
#define BM_UART_UTS_TXEMPTY  (0x00000040U) /*!< Bit mask for UART_UTS_TXEMPTY. */
#define BS_UART_UTS_TXEMPTY  (1U)          /*!< Bit field size in bits for UART_UTS_TXEMPTY. */

/*! @brief Read current value of the UART_UTS_TXEMPTY field. */
#define BR_UART_UTS_TXEMPTY(x) (HW_UART_UTS(x).B.TXEMPTY)

/*! @brief Format value for bitfield UART_UTS_TXEMPTY. */
#define BF_UART_UTS_TXEMPTY(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTS_TXEMPTY) & BM_UART_UTS_TXEMPTY)

/*! @brief Set the TXEMPTY field to a new value. */
#define BW_UART_UTS_TXEMPTY(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_TXEMPTY) | BF_UART_UTS_TXEMPTY(v)))
/*@}*/

/*!
 * @name Register UART_UTS, field RXDBG[9] (RW)
 *
 * This bit is not used in this chip. RX_fifo_debug_mode. This bit controls the
 * operation of the RX fifo read counter when in debug mode.
 *
 * Values:
 * - 0 - rx fifo read pointer does not increment
 * - 1 - rx_fifo read pointer increments as normal
 */
/*@{*/
#define BP_UART_UTS_RXDBG    (9U)          /*!< Bit position for UART_UTS_RXDBG. */
#define BM_UART_UTS_RXDBG    (0x00000200U) /*!< Bit mask for UART_UTS_RXDBG. */
#define BS_UART_UTS_RXDBG    (1U)          /*!< Bit field size in bits for UART_UTS_RXDBG. */

/*! @brief Read current value of the UART_UTS_RXDBG field. */
#define BR_UART_UTS_RXDBG(x) (HW_UART_UTS(x).B.RXDBG)

/*! @brief Format value for bitfield UART_UTS_RXDBG. */
#define BF_UART_UTS_RXDBG(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTS_RXDBG) & BM_UART_UTS_RXDBG)

/*! @brief Set the RXDBG field to a new value. */
#define BW_UART_UTS_RXDBG(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_RXDBG) | BF_UART_UTS_RXDBG(v)))
/*@}*/

/*!
 * @name Register UART_UTS, field LOOPIR[10] (RW)
 *
 * Loop TX and RX for IR Test (LOOPIR). This bit controls loopback from
 * transmitter to receiver in the InfraRed interface.
 *
 * Values:
 * - 0 - No IR loop
 * - 1 - Connect IR transmitter to IR receiver
 */
/*@{*/
#define BP_UART_UTS_LOOPIR   (10U)         /*!< Bit position for UART_UTS_LOOPIR. */
#define BM_UART_UTS_LOOPIR   (0x00000400U) /*!< Bit mask for UART_UTS_LOOPIR. */
#define BS_UART_UTS_LOOPIR   (1U)          /*!< Bit field size in bits for UART_UTS_LOOPIR. */

/*! @brief Read current value of the UART_UTS_LOOPIR field. */
#define BR_UART_UTS_LOOPIR(x) (HW_UART_UTS(x).B.LOOPIR)

/*! @brief Format value for bitfield UART_UTS_LOOPIR. */
#define BF_UART_UTS_LOOPIR(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTS_LOOPIR) & BM_UART_UTS_LOOPIR)

/*! @brief Set the LOOPIR field to a new value. */
#define BW_UART_UTS_LOOPIR(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_LOOPIR) | BF_UART_UTS_LOOPIR(v)))
/*@}*/

/*!
 * @name Register UART_UTS, field DBGEN[11] (RW)
 *
 * This bit is not used in this chip. debug_enable_B. This bit controls whether
 * to respond to the debug_req input signal.
 *
 * Values:
 * - 0 - UART will go into debug mode when debug_req is HIGH
 * - 1 - UART will not go into debug mode even if debug_req is HIGH
 */
/*@{*/
#define BP_UART_UTS_DBGEN    (11U)         /*!< Bit position for UART_UTS_DBGEN. */
#define BM_UART_UTS_DBGEN    (0x00000800U) /*!< Bit mask for UART_UTS_DBGEN. */
#define BS_UART_UTS_DBGEN    (1U)          /*!< Bit field size in bits for UART_UTS_DBGEN. */

/*! @brief Read current value of the UART_UTS_DBGEN field. */
#define BR_UART_UTS_DBGEN(x) (HW_UART_UTS(x).B.DBGEN)

/*! @brief Format value for bitfield UART_UTS_DBGEN. */
#define BF_UART_UTS_DBGEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTS_DBGEN) & BM_UART_UTS_DBGEN)

/*! @brief Set the DBGEN field to a new value. */
#define BW_UART_UTS_DBGEN(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_DBGEN) | BF_UART_UTS_DBGEN(v)))
/*@}*/

/*!
 * @name Register UART_UTS, field LOOP[12] (RW)
 *
 * Loop TX and RX for Test. Controls loopback for test purposes. When LOOP is
 * high, the receiver input is internally connected to the transmitter and ignores
 * the RXD pin. The transmitter is unaffected by LOOP. If RXDMUXSEL (UCR3[2]) is
 * set to 1, the loopback is applied on serial and IrDA signals. If RXDMUXSEL is
 * set to 0, the loopback is only applied on serial signals.
 *
 * Values:
 * - 0 - Normal receiver operation
 * - 1 - Internally connect the transmitter output to the receiver input
 */
/*@{*/
#define BP_UART_UTS_LOOP     (12U)         /*!< Bit position for UART_UTS_LOOP. */
#define BM_UART_UTS_LOOP     (0x00001000U) /*!< Bit mask for UART_UTS_LOOP. */
#define BS_UART_UTS_LOOP     (1U)          /*!< Bit field size in bits for UART_UTS_LOOP. */

/*! @brief Read current value of the UART_UTS_LOOP field. */
#define BR_UART_UTS_LOOP(x)  (HW_UART_UTS(x).B.LOOP)

/*! @brief Format value for bitfield UART_UTS_LOOP. */
#define BF_UART_UTS_LOOP(v)  ((uint32_t)((uint32_t)(v) << BP_UART_UTS_LOOP) & BM_UART_UTS_LOOP)

/*! @brief Set the LOOP field to a new value. */
#define BW_UART_UTS_LOOP(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_LOOP) | BF_UART_UTS_LOOP(v)))
/*@}*/

/*!
 * @name Register UART_UTS, field FRCPERR[13] (RW)
 *
 * Force Parity Error. Forces the transmitter to generate a parity error if
 * parity is enabled. FRCPERR is provided for system debugging.
 *
 * Values:
 * - 0 - Generate normal parity
 * - 1 - Generate inverted parity (error)
 */
/*@{*/
#define BP_UART_UTS_FRCPERR  (13U)         /*!< Bit position for UART_UTS_FRCPERR. */
#define BM_UART_UTS_FRCPERR  (0x00002000U) /*!< Bit mask for UART_UTS_FRCPERR. */
#define BS_UART_UTS_FRCPERR  (1U)          /*!< Bit field size in bits for UART_UTS_FRCPERR. */

/*! @brief Read current value of the UART_UTS_FRCPERR field. */
#define BR_UART_UTS_FRCPERR(x) (HW_UART_UTS(x).B.FRCPERR)

/*! @brief Format value for bitfield UART_UTS_FRCPERR. */
#define BF_UART_UTS_FRCPERR(v) ((uint32_t)((uint32_t)(v) << BP_UART_UTS_FRCPERR) & BM_UART_UTS_FRCPERR)

/*! @brief Set the FRCPERR field to a new value. */
#define BW_UART_UTS_FRCPERR(x, v) (HW_UART_UTS_WR(x, (HW_UART_UTS_RD(x) & ~BM_UART_UTS_FRCPERR) | BF_UART_UTS_FRCPERR(v)))
/*@}*/

/*******************************************************************************
 * HW_UART_UMCR - UART RS-485 Mode Control Register
 ******************************************************************************/

/*!
 * @brief HW_UART_UMCR - UART RS-485 Mode Control Register (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_uart_umcr
{
    uint32_t U;
    struct _hw_uart_umcr_bitfields
    {
        uint32_t MDEN : 1;             /*!< [0]  */
        uint32_t SLAM : 1;             /*!< [1]  */
        uint32_t TXB8 : 1;             /*!< [2]  */
        uint32_t SADEN : 1;            /*!< [3]  */
        uint32_t RESERVED0 : 4;        /*!< [7:4]  */
        uint32_t SLADDR : 8;           /*!< [15:8]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_uart_umcr_t;

/*!
 * @name Constants and macros for entire UART_UMCR register
 */
/*@{*/
#define HW_UART_UMCR_ADDR(x)     ((uintptr_t)(x) + 0xB8U)

#define HW_UART_UMCR(x)          (*(__IO hw_uart_umcr_t *) HW_UART_UMCR_ADDR(x))
#define HW_UART_UMCR_RD(x)       (HW_UART_UMCR(x).U)
#define HW_UART_UMCR_WR(x, v)    (HW_UART_UMCR(x).U = (v))
#define HW_UART_UMCR_SET(x, v)   (HW_UART_UMCR_WR(x, HW_UART_UMCR_RD(x) |  (v)))
#define HW_UART_UMCR_CLR(x, v)   (HW_UART_UMCR_WR(x, HW_UART_UMCR_RD(x) & ~(v)))
#define HW_UART_UMCR_TOG(x, v)   (HW_UART_UMCR_WR(x, HW_UART_UMCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual UART_UMCR bitfields
 */

/*!
 * @name Register UART_UMCR, field MDEN[0] (RW)
 *
 * 9-bit data or Multidrop Mode (RS-485) Enable.
 *
 * Values:
 * - 0 - Normal RS-232 or IrDA mode, see for detail.
 * - 1 - Enable RS-485 mode, see for detail
 */
/*@{*/
#define BP_UART_UMCR_MDEN    (0U)          /*!< Bit position for UART_UMCR_MDEN. */
#define BM_UART_UMCR_MDEN    (0x00000001U) /*!< Bit mask for UART_UMCR_MDEN. */
#define BS_UART_UMCR_MDEN    (1U)          /*!< Bit field size in bits for UART_UMCR_MDEN. */

/*! @brief Read current value of the UART_UMCR_MDEN field. */
#define BR_UART_UMCR_MDEN(x) (HW_UART_UMCR(x).B.MDEN)

/*! @brief Format value for bitfield UART_UMCR_MDEN. */
#define BF_UART_UMCR_MDEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UMCR_MDEN) & BM_UART_UMCR_MDEN)

/*! @brief Set the MDEN field to a new value. */
#define BW_UART_UMCR_MDEN(x, v) (HW_UART_UMCR_WR(x, (HW_UART_UMCR_RD(x) & ~BM_UART_UMCR_MDEN) | BF_UART_UMCR_MDEN(v)))
/*@}*/

/*!
 * @name Register UART_UMCR, field SLAM[1] (RW)
 *
 * RS-485 Slave Address Detect Mode Selection.
 *
 * Values:
 * - 0 - Select Normal Address Detect mode
 * - 1 - Select Automatic Address Detect mode
 */
/*@{*/
#define BP_UART_UMCR_SLAM    (1U)          /*!< Bit position for UART_UMCR_SLAM. */
#define BM_UART_UMCR_SLAM    (0x00000002U) /*!< Bit mask for UART_UMCR_SLAM. */
#define BS_UART_UMCR_SLAM    (1U)          /*!< Bit field size in bits for UART_UMCR_SLAM. */

/*! @brief Read current value of the UART_UMCR_SLAM field. */
#define BR_UART_UMCR_SLAM(x) (HW_UART_UMCR(x).B.SLAM)

/*! @brief Format value for bitfield UART_UMCR_SLAM. */
#define BF_UART_UMCR_SLAM(v) ((uint32_t)((uint32_t)(v) << BP_UART_UMCR_SLAM) & BM_UART_UMCR_SLAM)

/*! @brief Set the SLAM field to a new value. */
#define BW_UART_UMCR_SLAM(x, v) (HW_UART_UMCR_WR(x, (HW_UART_UMCR_RD(x) & ~BM_UART_UMCR_SLAM) | BF_UART_UMCR_SLAM(v)))
/*@}*/

/*!
 * @name Register UART_UMCR, field TXB8[2] (RW)
 *
 * Transmit RS-485 bit 8 (the ninth bit or 9th bit). In RS-485 mode, software
 * writes TXB8 bit as the 9th data bit to be transmitted.
 *
 * Values:
 * - 0 - 0 will be transmitted as the RS485 9th data bit
 * - 1 - 1 will be transmitted as the RS485 9th data bit
 */
/*@{*/
#define BP_UART_UMCR_TXB8    (2U)          /*!< Bit position for UART_UMCR_TXB8. */
#define BM_UART_UMCR_TXB8    (0x00000004U) /*!< Bit mask for UART_UMCR_TXB8. */
#define BS_UART_UMCR_TXB8    (1U)          /*!< Bit field size in bits for UART_UMCR_TXB8. */

/*! @brief Read current value of the UART_UMCR_TXB8 field. */
#define BR_UART_UMCR_TXB8(x) (HW_UART_UMCR(x).B.TXB8)

/*! @brief Format value for bitfield UART_UMCR_TXB8. */
#define BF_UART_UMCR_TXB8(v) ((uint32_t)((uint32_t)(v) << BP_UART_UMCR_TXB8) & BM_UART_UMCR_TXB8)

/*! @brief Set the TXB8 field to a new value. */
#define BW_UART_UMCR_TXB8(x, v) (HW_UART_UMCR_WR(x, (HW_UART_UMCR_RD(x) & ~BM_UART_UMCR_TXB8) | BF_UART_UMCR_TXB8(v)))
/*@}*/

/*!
 * @name Register UART_UMCR, field SADEN[3] (RW)
 *
 * RS-485 Slave Address Detected Interrupt Enable.
 *
 * Values:
 * - 0 - Disable RS-485 Slave Address Detected Interrupt
 * - 1 - Enable RS-485 Slave Address Detected Interrupt
 */
/*@{*/
#define BP_UART_UMCR_SADEN   (3U)          /*!< Bit position for UART_UMCR_SADEN. */
#define BM_UART_UMCR_SADEN   (0x00000008U) /*!< Bit mask for UART_UMCR_SADEN. */
#define BS_UART_UMCR_SADEN   (1U)          /*!< Bit field size in bits for UART_UMCR_SADEN. */

/*! @brief Read current value of the UART_UMCR_SADEN field. */
#define BR_UART_UMCR_SADEN(x) (HW_UART_UMCR(x).B.SADEN)

/*! @brief Format value for bitfield UART_UMCR_SADEN. */
#define BF_UART_UMCR_SADEN(v) ((uint32_t)((uint32_t)(v) << BP_UART_UMCR_SADEN) & BM_UART_UMCR_SADEN)

/*! @brief Set the SADEN field to a new value. */
#define BW_UART_UMCR_SADEN(x, v) (HW_UART_UMCR_WR(x, (HW_UART_UMCR_RD(x) & ~BM_UART_UMCR_SADEN) | BF_UART_UMCR_SADEN(v)))
/*@}*/

/*!
 * @name Register UART_UMCR, field SLADDR[15:8] (RW)
 *
 * RS-485 Slave Address Character. Holds the selected slave adress character
 * that the receiver wil try to detect.
 */
/*@{*/
#define BP_UART_UMCR_SLADDR  (8U)          /*!< Bit position for UART_UMCR_SLADDR. */
#define BM_UART_UMCR_SLADDR  (0x0000FF00U) /*!< Bit mask for UART_UMCR_SLADDR. */
#define BS_UART_UMCR_SLADDR  (8U)          /*!< Bit field size in bits for UART_UMCR_SLADDR. */

/*! @brief Read current value of the UART_UMCR_SLADDR field. */
#define BR_UART_UMCR_SLADDR(x) (HW_UART_UMCR(x).B.SLADDR)

/*! @brief Format value for bitfield UART_UMCR_SLADDR. */
#define BF_UART_UMCR_SLADDR(v) ((uint32_t)((uint32_t)(v) << BP_UART_UMCR_SLADDR) & BM_UART_UMCR_SLADDR)

/*! @brief Set the SLADDR field to a new value. */
#define BW_UART_UMCR_SLADDR(x, v) (HW_UART_UMCR_WR(x, (HW_UART_UMCR_RD(x) & ~BM_UART_UMCR_SLADDR) | BF_UART_UMCR_SLADDR(v)))
/*@}*/

/*******************************************************************************
 * hw_uart_t - module struct
 ******************************************************************************/
/*!
 * @brief All UART module registers.
 */
#pragma pack(1)
typedef struct _hw_uart
{
    __I hw_uart_urxd_t URXD;               /*!< [0x0] UART Receiver Register */
    uint8_t _reserved0[60];
    __IO hw_uart_utxd_t UTXD;              /*!< [0x40] UART Transmitter Register */
    uint8_t _reserved1[60];
    __IO hw_uart_ucr1_t UCR1;              /*!< [0x80] UART Control Register 1 */
    __IO hw_uart_ucr2_t UCR2;              /*!< [0x84] UART Control Register 2 */
    __IO hw_uart_ucr3_t UCR3;              /*!< [0x88] UART Control Register 3 */
    __IO hw_uart_ucr4_t UCR4;              /*!< [0x8C] UART Control Register 4 */
    __IO hw_uart_ufcr_t UFCR;              /*!< [0x90] UART FIFO Control Register */
    __IO hw_uart_usr1_t USR1;              /*!< [0x94] UART Status Register 1 */
    __IO hw_uart_usr2_t USR2;              /*!< [0x98] UART Status Register 2 */
    __IO hw_uart_uesc_t UESC;              /*!< [0x9C] UART Escape Character Register */
    __IO hw_uart_utim_t UTIM;              /*!< [0xA0] UART Escape Timer Register */
    __IO hw_uart_ubir_t UBIR;              /*!< [0xA4] UART BRM Incremental Register */
    __IO hw_uart_ubmr_t UBMR;              /*!< [0xA8] UART BRM Modulator Register */
    __I hw_uart_ubrc_t UBRC;               /*!< [0xAC] UART Baud Rate Count Register */
    __IO hw_uart_onems_t ONEMS;            /*!< [0xB0] UART One Millisecond Register */
    __IO hw_uart_uts_t UTS;                /*!< [0xB4] UART Test Register */
    __IO hw_uart_umcr_t UMCR;              /*!< [0xB8] UART RS-485 Mode Control Register */
} hw_uart_t;
#pragma pack()

/*! @brief Macro to access all UART registers. */
/*! @param x UART module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_UART_REGS(UART1_BASE)</code>. */
#define HW_UART_REGS(x) (*(hw_uart_t *)(x))

/*
 * iMX7D USB
 *
 * USB
 *
 * Registers defined in this header file:
 * - HW_USB_ID - Identification register
 * - HW_USB_HWGENERAL - Hardware General
 * - HW_USB_HWHOST - Host Hardware Parameters
 * - HW_USB_HWDEVICE - Device Hardware Parameters
 * - HW_USB_HWTXBUF - TX Buffer Hardware Parameters
 * - HW_USB_HWRXBUF - RX Buffer Hardware Parameters
 * - HW_USB_GPTIMER0LD - General Purpose Timer #0 Load
 * - HW_USB_GPTIMER0CTRL - General Purpose Timer #0 Controller
 * - HW_USB_GPTIMER1LD - General Purpose Timer #1 Load
 * - HW_USB_GPTIMER1CTRL - General Purpose Timer #1 Controller
 * - HW_USB_SBUSCFG - System Bus Config
 * - HW_USB_CAPLENGTH - Capability Registers Length
 * - HW_USB_HCIVERSION - Host Controller Interface Version
 * - HW_USB_HCSPARAMS - Host Controller Structural Parameters
 * - HW_USB_HCCPARAMS - Host Controller Capability Parameters
 * - HW_USB_DCIVERSION - Device Controller Interface Version
 * - HW_USB_DCCPARAMS - Device Controller Capability Parameters
 * - HW_USB_USBCMD - USB Command Register
 * - HW_USB_USBSTS - USB Status Register
 * - HW_USB_USBINTR - Interrupt Enable Register
 * - HW_USB_FRINDEX - USB Frame Index
 * - HW_USB_DEVICEADDR - Device Address
 * - HW_USB_PERIODICLISTBASE - Frame List Base Address
 * - HW_USB_ASYNCLISTADDR - Next Asynch. Address
 * - HW_USB_ENDPTLISTADDR - Endpoint List Address
 * - HW_USB_BURSTSIZE - Programmable Burst Size
 * - HW_USB_TXFILLTUNING - TX FIFO Fill Tuning
 * - HW_USB_ENDPTNAK - Endpoint NAK
 * - HW_USB_ENDPTNAKEN - Endpoint NAK Enable
 * - HW_USB_CONFIGFLAG - Configure Flag Register
 * - HW_USB_PORTSC1 - Port Status & Control
 * - HW_USB_OTGSC - On-The-Go Status & control
 * - HW_USB_USBMODE - USB Device Mode
 * - HW_USB_ENDPTSETUPSTAT - Endpoint Setup Status
 * - HW_USB_ENDPTPRIME - Endpoint Prime
 * - HW_USB_ENDPTFLUSH - Endpoint Flush
 * - HW_USB_ENDPTSTAT - Endpoint Status
 * - HW_USB_ENDPTCOMPLETE - Endpoint Complete
 * - HW_USB_ENDPTCTRL0 - Endpoint Control0
 * - HW_USB_ENDPTCTRL1 - Endpoint Control 1
 * - HW_USB_ENDPTCTRL2 - Endpoint Control 2
 * - HW_USB_ENDPTCTRL3 - Endpoint Control 3
 * - HW_USB_ENDPTCTRL4 - Endpoint Control 4
 * - HW_USB_ENDPTCTRL5 - Endpoint Control 5
 * - HW_USB_ENDPTCTRL6 - Endpoint Control 6
 * - HW_USB_ENDPTCTRL7 - Endpoint Control 7
 *
 * - hw_usb_t - Struct containing all module registers.
 */

#define HW_USB_INSTANCE_COUNT (3U) /*!< Number of instances of the USB module. */
#define HW_USB_OTG1 (0U) /*!< Instance number for USB_OTG1. */
#define HW_USB_OTG2 (1U) /*!< Instance number for USB_OTG2. */
#define HW_USB_HSIC (2U) /*!< Instance number for USB_HSIC. */
#define USB_OTG1_BASE         (0x30B10000U) /*!< Base address for USB_OTG1. */
#define USB_OTG2_BASE         (0x30B20000U) /*!< Base address for USB_OTG2. */
#define USB_HSIC_BASE         (0x30B30000U) /*!< Base address for USB_HSIC. */
/*! Array initializer of USB base addresses. */
#define USB_BASE_ADDRS        { USB_OTG1_BASE, USB_OTG2_BASE, USB_HSIC_BASE }

/*******************************************************************************
 * HW_USB_ID - Identification register
 ******************************************************************************/

/*!
 * @brief HW_USB_ID - Identification register (RO)
 *
 * Reset value: 0xE401FA05U
 *
 * The ID register identifies the USB 2.0 High-Speed core and its revision.
 */
typedef union _hw_usb_id
{
    uint32_t U;
    struct _hw_usb_id_bitfields
    {
        uint32_t ID : 6;               /*!< [5:0]  */
        uint32_t RESERVED0 : 2;        /*!< [7:6]  */
        uint32_t NID : 6;              /*!< [13:8]  */
        uint32_t RESERVED1 : 2;        /*!< [15:14]  */
        uint32_t REVISION : 8;         /*!< [23:16]  */
        uint32_t RESERVED2 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_id_t;

/*!
 * @name Constants and macros for entire USB_ID register
 */
/*@{*/
#define HW_USB_ID_ADDR(x)        ((uintptr_t)(x) + 0x0U)

#define HW_USB_ID(x)             (*(__I hw_usb_id_t *) HW_USB_ID_ADDR(x))
#define HW_USB_ID_RD(x)          (HW_USB_ID(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_ID bitfields
 */

/*!
 * @name Register USB_ID, field ID[5:0] (RO)
 *
 * Configuration number. This number is set to 0x05 and indicates that the
 * peripheral is USB 2.0 High-Speed core.
 */
/*@{*/
#define BP_USB_ID_ID         (0U)          /*!< Bit position for USB_ID_ID. */
#define BM_USB_ID_ID         (0x0000003FU) /*!< Bit mask for USB_ID_ID. */
#define BS_USB_ID_ID         (6U)          /*!< Bit field size in bits for USB_ID_ID. */

/*! @brief Read current value of the USB_ID_ID field. */
#define BR_USB_ID_ID(x)      (HW_USB_ID(x).B.ID)
/*@}*/

/*!
 * @name Register USB_ID, field NID[13:8] (RO)
 *
 * Complement version of ID
 */
/*@{*/
#define BP_USB_ID_NID        (8U)          /*!< Bit position for USB_ID_NID. */
#define BM_USB_ID_NID        (0x00003F00U) /*!< Bit mask for USB_ID_NID. */
#define BS_USB_ID_NID        (6U)          /*!< Bit field size in bits for USB_ID_NID. */

/*! @brief Read current value of the USB_ID_NID field. */
#define BR_USB_ID_NID(x)     (HW_USB_ID(x).B.NID)
/*@}*/

/*!
 * @name Register USB_ID, field REVISION[23:16] (RO)
 *
 * Revision number of the controller core.
 */
/*@{*/
#define BP_USB_ID_REVISION   (16U)         /*!< Bit position for USB_ID_REVISION. */
#define BM_USB_ID_REVISION   (0x00FF0000U) /*!< Bit mask for USB_ID_REVISION. */
#define BS_USB_ID_REVISION   (8U)          /*!< Bit field size in bits for USB_ID_REVISION. */

/*! @brief Read current value of the USB_ID_REVISION field. */
#define BR_USB_ID_REVISION(x) (HW_USB_ID(x).B.REVISION)
/*@}*/

/*******************************************************************************
 * HW_USB_HWGENERAL - Hardware General
 ******************************************************************************/

/*!
 * @brief HW_USB_HWGENERAL - Hardware General (RO)
 *
 * Reset value: 0x00000035U
 *
 * General hardware parameters as defined in System Level Issues and Core
 * Configuration. The reset value could vary from instance to instance. Please see the
 * detail in bit field description and ignore reset value in summary table in
 * this case!
 */
typedef union _hw_usb_hwgeneral
{
    uint32_t U;
    struct _hw_usb_hwgeneral_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t PHYW : 2;             /*!< [5:4]  */
        uint32_t PHYM : 4;             /*!< [9:6]  */
        uint32_t SM : 2;               /*!< [11:10]  */
        uint32_t RESERVED1 : 20;       /*!< [31:12]  */
    } B;
} hw_usb_hwgeneral_t;

/*!
 * @name Constants and macros for entire USB_HWGENERAL register
 */
/*@{*/
#define HW_USB_HWGENERAL_ADDR(x) ((uintptr_t)(x) + 0x4U)

#define HW_USB_HWGENERAL(x)      (*(__I hw_usb_hwgeneral_t *) HW_USB_HWGENERAL_ADDR(x))
#define HW_USB_HWGENERAL_RD(x)   (HW_USB_HWGENERAL(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_HWGENERAL bitfields
 */

/*!
 * @name Register USB_HWGENERAL, field PHYW[5:4] (RO)
 *
 * Data width of the transciever connected to the controller core. PHYW bit
 * reset value is PHYW bit reset value is '11b'.
 *
 * Values:
 * - 11 - Reset to 16 bit wide data bus Software programmable
 */
/*@{*/
#define BP_USB_HWGENERAL_PHYW (4U)         /*!< Bit position for USB_HWGENERAL_PHYW. */
#define BM_USB_HWGENERAL_PHYW (0x00000030U) /*!< Bit mask for USB_HWGENERAL_PHYW. */
#define BS_USB_HWGENERAL_PHYW (2U)         /*!< Bit field size in bits for USB_HWGENERAL_PHYW. */

/*! @brief Read current value of the USB_HWGENERAL_PHYW field. */
#define BR_USB_HWGENERAL_PHYW(x) (HW_USB_HWGENERAL(x).B.PHYW)
/*@}*/

/*!
 * @name Register USB_HWGENERAL, field PHYM[9:6] (RO)
 *
 * Transceiver type PHYM bit reset value: '0000b' for OTG1/OTG2 controller core,
 * and '1011b' for Host-only HSIC controller core.
 *
 * Values:
 * - 0000 - UTMI/UMTI+
 * - 1011 - Software programmable - reset to HSIC
 */
/*@{*/
#define BP_USB_HWGENERAL_PHYM (6U)         /*!< Bit position for USB_HWGENERAL_PHYM. */
#define BM_USB_HWGENERAL_PHYM (0x000003C0U) /*!< Bit mask for USB_HWGENERAL_PHYM. */
#define BS_USB_HWGENERAL_PHYM (4U)         /*!< Bit field size in bits for USB_HWGENERAL_PHYM. */

/*! @brief Read current value of the USB_HWGENERAL_PHYM field. */
#define BR_USB_HWGENERAL_PHYM(x) (HW_USB_HWGENERAL(x).B.PHYM)
/*@}*/

/*!
 * @name Register USB_HWGENERAL, field SM[11:10] (RO)
 *
 * Serial interface mode capability SM bit reset value is '00b'
 *
 * Values:
 * - 00 - No Serial Engine, always use parallel signalling.
 */
/*@{*/
#define BP_USB_HWGENERAL_SM  (10U)         /*!< Bit position for USB_HWGENERAL_SM. */
#define BM_USB_HWGENERAL_SM  (0x00000C00U) /*!< Bit mask for USB_HWGENERAL_SM. */
#define BS_USB_HWGENERAL_SM  (2U)          /*!< Bit field size in bits for USB_HWGENERAL_SM. */

/*! @brief Read current value of the USB_HWGENERAL_SM field. */
#define BR_USB_HWGENERAL_SM(x) (HW_USB_HWGENERAL(x).B.SM)
/*@}*/

/*******************************************************************************
 * HW_USB_HWHOST - Host Hardware Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_HWHOST - Host Hardware Parameters (RO)
 *
 * Reset value: 0x10020001U
 */
typedef union _hw_usb_hwhost
{
    uint32_t U;
    struct _hw_usb_hwhost_bitfields
    {
        uint32_t HC : 1;               /*!< [0]  */
        uint32_t NPORT : 3;            /*!< [3:1]  */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_usb_hwhost_t;

/*!
 * @name Constants and macros for entire USB_HWHOST register
 */
/*@{*/
#define HW_USB_HWHOST_ADDR(x)    ((uintptr_t)(x) + 0x8U)

#define HW_USB_HWHOST(x)         (*(__I hw_usb_hwhost_t *) HW_USB_HWHOST_ADDR(x))
#define HW_USB_HWHOST_RD(x)      (HW_USB_HWHOST(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_HWHOST bitfields
 */

/*!
 * @name Register USB_HWHOST, field HC[0] (RO)
 *
 * Host Capable. Indicating whether host operation mode is supported or not.
 *
 * Values:
 * - 1 - Supported
 * - 0 - Not supported
 */
/*@{*/
#define BP_USB_HWHOST_HC     (0U)          /*!< Bit position for USB_HWHOST_HC. */
#define BM_USB_HWHOST_HC     (0x00000001U) /*!< Bit mask for USB_HWHOST_HC. */
#define BS_USB_HWHOST_HC     (1U)          /*!< Bit field size in bits for USB_HWHOST_HC. */

/*! @brief Read current value of the USB_HWHOST_HC field. */
#define BR_USB_HWHOST_HC(x)  (HW_USB_HWHOST(x).B.HC)
/*@}*/

/*!
 * @name Register USB_HWHOST, field NPORT[3:1] (RO)
 *
 * The Nmber of downstream ports supported by the host controller is (NPORT+1).
 * When these bits value is '000', it indicates a single-port host controller.
 */
/*@{*/
#define BP_USB_HWHOST_NPORT  (1U)          /*!< Bit position for USB_HWHOST_NPORT. */
#define BM_USB_HWHOST_NPORT  (0x0000000EU) /*!< Bit mask for USB_HWHOST_NPORT. */
#define BS_USB_HWHOST_NPORT  (3U)          /*!< Bit field size in bits for USB_HWHOST_NPORT. */

/*! @brief Read current value of the USB_HWHOST_NPORT field. */
#define BR_USB_HWHOST_NPORT(x) (HW_USB_HWHOST(x).B.NPORT)
/*@}*/

/*******************************************************************************
 * HW_USB_HWDEVICE - Device Hardware Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_HWDEVICE - Device Hardware Parameters (RO)
 *
 * Reset value: 0x00000011U
 *
 * This register is only available in OTG core.
 */
typedef union _hw_usb_hwdevice
{
    uint32_t U;
    struct _hw_usb_hwdevice_bitfields
    {
        uint32_t DC : 1;               /*!< [0]  */
        uint32_t DEVEP : 5;            /*!< [5:1]  */
        uint32_t RESERVED0 : 26;       /*!< [31:6]  */
    } B;
} hw_usb_hwdevice_t;

/*!
 * @name Constants and macros for entire USB_HWDEVICE register
 */
/*@{*/
#define HW_USB_HWDEVICE_ADDR(x)  ((uintptr_t)(x) + 0xCU)

#define HW_USB_HWDEVICE(x)       (*(__I hw_usb_hwdevice_t *) HW_USB_HWDEVICE_ADDR(x))
#define HW_USB_HWDEVICE_RD(x)    (HW_USB_HWDEVICE(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_HWDEVICE bitfields
 */

/*!
 * @name Register USB_HWDEVICE, field DC[0] (RO)
 *
 * Device Capable. Indicating whether device operation mode is supported or not.
 *
 * Values:
 * - 1 - Supported
 * - 0 - Not supported
 */
/*@{*/
#define BP_USB_HWDEVICE_DC   (0U)          /*!< Bit position for USB_HWDEVICE_DC. */
#define BM_USB_HWDEVICE_DC   (0x00000001U) /*!< Bit mask for USB_HWDEVICE_DC. */
#define BS_USB_HWDEVICE_DC   (1U)          /*!< Bit field size in bits for USB_HWDEVICE_DC. */

/*! @brief Read current value of the USB_HWDEVICE_DC field. */
#define BR_USB_HWDEVICE_DC(x) (HW_USB_HWDEVICE(x).B.DC)
/*@}*/

/*!
 * @name Register USB_HWDEVICE, field DEVEP[5:1] (RO)
 *
 * Device Endpoint Number
 */
/*@{*/
#define BP_USB_HWDEVICE_DEVEP (1U)         /*!< Bit position for USB_HWDEVICE_DEVEP. */
#define BM_USB_HWDEVICE_DEVEP (0x0000003EU) /*!< Bit mask for USB_HWDEVICE_DEVEP. */
#define BS_USB_HWDEVICE_DEVEP (5U)         /*!< Bit field size in bits for USB_HWDEVICE_DEVEP. */

/*! @brief Read current value of the USB_HWDEVICE_DEVEP field. */
#define BR_USB_HWDEVICE_DEVEP(x) (HW_USB_HWDEVICE(x).B.DEVEP)
/*@}*/

/*******************************************************************************
 * HW_USB_HWTXBUF - TX Buffer Hardware Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_HWTXBUF - TX Buffer Hardware Parameters (RO)
 *
 * Reset value: 0x80080B08U
 */
typedef union _hw_usb_hwtxbuf
{
    uint32_t U;
    struct _hw_usb_hwtxbuf_bitfields
    {
        uint32_t TXBURST : 8;          /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t TXCHANADD : 8;        /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_hwtxbuf_t;

/*!
 * @name Constants and macros for entire USB_HWTXBUF register
 */
/*@{*/
#define HW_USB_HWTXBUF_ADDR(x)   ((uintptr_t)(x) + 0x10U)

#define HW_USB_HWTXBUF(x)        (*(__I hw_usb_hwtxbuf_t *) HW_USB_HWTXBUF_ADDR(x))
#define HW_USB_HWTXBUF_RD(x)     (HW_USB_HWTXBUF(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_HWTXBUF bitfields
 */

/*!
 * @name Register USB_HWTXBUF, field TXBURST[7:0] (RO)
 *
 * Default burst size for memory to TX buffer transfer. This is reset value of
 * TXPBURST bits in USB core regsiter USB_n_BURSTSIZE. Please see
 * BURSTSIZEProgrammable Burst Size .
 */
/*@{*/
#define BP_USB_HWTXBUF_TXBURST (0U)        /*!< Bit position for USB_HWTXBUF_TXBURST. */
#define BM_USB_HWTXBUF_TXBURST (0x000000FFU) /*!< Bit mask for USB_HWTXBUF_TXBURST. */
#define BS_USB_HWTXBUF_TXBURST (8U)        /*!< Bit field size in bits for USB_HWTXBUF_TXBURST. */

/*! @brief Read current value of the USB_HWTXBUF_TXBURST field. */
#define BR_USB_HWTXBUF_TXBURST(x) (HW_USB_HWTXBUF(x).B.TXBURST)
/*@}*/

/*!
 * @name Register USB_HWTXBUF, field TXCHANADD[23:16] (RO)
 *
 * TX FIFO Buffer size is: (2^TXCHANADD) * 4 Bytes. These bits are set to '08h',
 * so buffer size is 256*4 Bytes. For the OTG controller operating in device
 * mode, this is the FIFO buffer size per endpoint. As the OTG controller has 8 TX
 * endpoint, there are 8 of these buffers. For the OTG controller operating in
 * host mode, or for Host-only controller, the entire buffer memory is used as a
 * single TX buffer. Therefore, there is only 1 of this buffer
 */
/*@{*/
#define BP_USB_HWTXBUF_TXCHANADD (16U)     /*!< Bit position for USB_HWTXBUF_TXCHANADD. */
#define BM_USB_HWTXBUF_TXCHANADD (0x00FF0000U) /*!< Bit mask for USB_HWTXBUF_TXCHANADD. */
#define BS_USB_HWTXBUF_TXCHANADD (8U)      /*!< Bit field size in bits for USB_HWTXBUF_TXCHANADD. */

/*! @brief Read current value of the USB_HWTXBUF_TXCHANADD field. */
#define BR_USB_HWTXBUF_TXCHANADD(x) (HW_USB_HWTXBUF(x).B.TXCHANADD)
/*@}*/

/*******************************************************************************
 * HW_USB_HWRXBUF - RX Buffer Hardware Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_HWRXBUF - RX Buffer Hardware Parameters (RO)
 *
 * Reset value: 0x00000808U
 */
typedef union _hw_usb_hwrxbuf
{
    uint32_t U;
    struct _hw_usb_hwrxbuf_bitfields
    {
        uint32_t RXBURST : 8;          /*!< [7:0]  */
        uint32_t RXADD : 8;            /*!< [15:8]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_usb_hwrxbuf_t;

/*!
 * @name Constants and macros for entire USB_HWRXBUF register
 */
/*@{*/
#define HW_USB_HWRXBUF_ADDR(x)   ((uintptr_t)(x) + 0x14U)

#define HW_USB_HWRXBUF(x)        (*(__I hw_usb_hwrxbuf_t *) HW_USB_HWRXBUF_ADDR(x))
#define HW_USB_HWRXBUF_RD(x)     (HW_USB_HWRXBUF(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_HWRXBUF bitfields
 */

/*!
 * @name Register USB_HWRXBUF, field RXBURST[7:0] (RO)
 *
 * Default burst size for memory to RX buffer transfer. This is reset value of
 * RXPBURST bits in USB core regsiter USB_n_BURSTSIZE. Please see
 * BURSTSIZEProgrammable Burst Size .
 */
/*@{*/
#define BP_USB_HWRXBUF_RXBURST (0U)        /*!< Bit position for USB_HWRXBUF_RXBURST. */
#define BM_USB_HWRXBUF_RXBURST (0x000000FFU) /*!< Bit mask for USB_HWRXBUF_RXBURST. */
#define BS_USB_HWRXBUF_RXBURST (8U)        /*!< Bit field size in bits for USB_HWRXBUF_RXBURST. */

/*! @brief Read current value of the USB_HWRXBUF_RXBURST field. */
#define BR_USB_HWRXBUF_RXBURST(x) (HW_USB_HWRXBUF(x).B.RXBURST)
/*@}*/

/*!
 * @name Register USB_HWRXBUF, field RXADD[15:8] (RO)
 *
 * Buffer total size for all receive endpoints is (2^RXADD). RX Buffer size is:
 * (2^RXADD) * 4 Bytes. These bits are set to '08h', so buffer size is 256*4
 * Bytes. There is a single Receive FIFO buffer in the USB controller. The buffer is
 * shared for all endpoints for the OTG controller in device mode.
 */
/*@{*/
#define BP_USB_HWRXBUF_RXADD (8U)          /*!< Bit position for USB_HWRXBUF_RXADD. */
#define BM_USB_HWRXBUF_RXADD (0x0000FF00U) /*!< Bit mask for USB_HWRXBUF_RXADD. */
#define BS_USB_HWRXBUF_RXADD (8U)          /*!< Bit field size in bits for USB_HWRXBUF_RXADD. */

/*! @brief Read current value of the USB_HWRXBUF_RXADD field. */
#define BR_USB_HWRXBUF_RXADD(x) (HW_USB_HWRXBUF(x).B.RXADD)
/*@}*/

/*******************************************************************************
 * HW_USB_GPTIMER0LD - General Purpose Timer #0 Load
 ******************************************************************************/

/*!
 * @brief HW_USB_GPTIMER0LD - General Purpose Timer #0 Load (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register controls load value of the count timer in register
 * n_GPTIMER0CTRL. Please see GPTIMER0CTRLGeneral Purpose Timer #0 Controller .
 */
typedef union _hw_usb_gptimer0ld
{
    uint32_t U;
    struct _hw_usb_gptimer0ld_bitfields
    {
        uint32_t GPTLD : 24;           /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_gptimer0ld_t;

/*!
 * @name Constants and macros for entire USB_GPTIMER0LD register
 */
/*@{*/
#define HW_USB_GPTIMER0LD_ADDR(x) ((uintptr_t)(x) + 0x80U)

#define HW_USB_GPTIMER0LD(x)     (*(__IO hw_usb_gptimer0ld_t *) HW_USB_GPTIMER0LD_ADDR(x))
#define HW_USB_GPTIMER0LD_RD(x)  (HW_USB_GPTIMER0LD(x).U)
#define HW_USB_GPTIMER0LD_WR(x, v) (HW_USB_GPTIMER0LD(x).U = (v))
#define HW_USB_GPTIMER0LD_SET(x, v) (HW_USB_GPTIMER0LD_WR(x, HW_USB_GPTIMER0LD_RD(x) |  (v)))
#define HW_USB_GPTIMER0LD_CLR(x, v) (HW_USB_GPTIMER0LD_WR(x, HW_USB_GPTIMER0LD_RD(x) & ~(v)))
#define HW_USB_GPTIMER0LD_TOG(x, v) (HW_USB_GPTIMER0LD_WR(x, HW_USB_GPTIMER0LD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_GPTIMER0LD bitfields
 */

/*!
 * @name Register USB_GPTIMER0LD, field GPTLD[23:0] (RW)
 *
 * General Purpose Timer Load Value These bit fields are loaded to GPTCNT bits
 * when GPTRST bit is set '1b'. This value represents the time in microseconds
 * minus 1 for the timer duration. Example: for a one millisecond timer, load
 * 1000-1=999 or 0x0003E7. Max value is 0xFFFFFF or 16.777215 seconds.
 */
/*@{*/
#define BP_USB_GPTIMER0LD_GPTLD (0U)       /*!< Bit position for USB_GPTIMER0LD_GPTLD. */
#define BM_USB_GPTIMER0LD_GPTLD (0x00FFFFFFU) /*!< Bit mask for USB_GPTIMER0LD_GPTLD. */
#define BS_USB_GPTIMER0LD_GPTLD (24U)      /*!< Bit field size in bits for USB_GPTIMER0LD_GPTLD. */

/*! @brief Read current value of the USB_GPTIMER0LD_GPTLD field. */
#define BR_USB_GPTIMER0LD_GPTLD(x) (HW_USB_GPTIMER0LD(x).B.GPTLD)

/*! @brief Format value for bitfield USB_GPTIMER0LD_GPTLD. */
#define BF_USB_GPTIMER0LD_GPTLD(v) ((uint32_t)((uint32_t)(v) << BP_USB_GPTIMER0LD_GPTLD) & BM_USB_GPTIMER0LD_GPTLD)

/*! @brief Set the GPTLD field to a new value. */
#define BW_USB_GPTIMER0LD_GPTLD(x, v) (HW_USB_GPTIMER0LD_WR(x, (HW_USB_GPTIMER0LD_RD(x) & ~BM_USB_GPTIMER0LD_GPTLD) | BF_USB_GPTIMER0LD_GPTLD(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_GPTIMER0CTRL - General Purpose Timer #0 Controller
 ******************************************************************************/

/*!
 * @brief HW_USB_GPTIMER0CTRL - General Purpose Timer #0 Controller (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the control for this countdown timer and a data field
 * can be queried to determine the running count value. This timer has
 * granularity on 1 us and can be programmed to a little over 16 seconds. There are two
 * counter modes which are described in the register table below. When the timer
 * counter value transitions to zero, an interrupt could be generated if enable.
 * Interrupt status bit is TI0 bit in n_USBSTS register (See USBSTSUSB Status
 * Register ), interrupt enable bit is TIE0 bit in n_USBINTR register. (See
 * USBINTRInterrupt Enable Register .)
 */
typedef union _hw_usb_gptimer0ctrl
{
    uint32_t U;
    struct _hw_usb_gptimer0ctrl_bitfields
    {
        uint32_t GPTCNT : 24;          /*!< [23:0]  */
        uint32_t GPTMODE : 1;          /*!< [24]  */
        uint32_t RESERVED0 : 5;        /*!< [29:25]  */
        uint32_t GPTRST : 1;           /*!< [30]  */
        uint32_t GPTRUN : 1;           /*!< [31]  */
    } B;
} hw_usb_gptimer0ctrl_t;

/*!
 * @name Constants and macros for entire USB_GPTIMER0CTRL register
 */
/*@{*/
#define HW_USB_GPTIMER0CTRL_ADDR(x) ((uintptr_t)(x) + 0x84U)

#define HW_USB_GPTIMER0CTRL(x)   (*(__IO hw_usb_gptimer0ctrl_t *) HW_USB_GPTIMER0CTRL_ADDR(x))
#define HW_USB_GPTIMER0CTRL_RD(x) (HW_USB_GPTIMER0CTRL(x).U)
#define HW_USB_GPTIMER0CTRL_WR(x, v) (HW_USB_GPTIMER0CTRL(x).U = (v))
#define HW_USB_GPTIMER0CTRL_SET(x, v) (HW_USB_GPTIMER0CTRL_WR(x, HW_USB_GPTIMER0CTRL_RD(x) |  (v)))
#define HW_USB_GPTIMER0CTRL_CLR(x, v) (HW_USB_GPTIMER0CTRL_WR(x, HW_USB_GPTIMER0CTRL_RD(x) & ~(v)))
#define HW_USB_GPTIMER0CTRL_TOG(x, v) (HW_USB_GPTIMER0CTRL_WR(x, HW_USB_GPTIMER0CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_GPTIMER0CTRL bitfields
 */

/*!
 * @name Register USB_GPTIMER0CTRL, field GPTCNT[23:0] (RW)
 *
 * General Purpose Timer Counter. This field is the count value of the countdown
 * timer.
 */
/*@{*/
#define BP_USB_GPTIMER0CTRL_GPTCNT (0U)    /*!< Bit position for USB_GPTIMER0CTRL_GPTCNT. */
#define BM_USB_GPTIMER0CTRL_GPTCNT (0x00FFFFFFU) /*!< Bit mask for USB_GPTIMER0CTRL_GPTCNT. */
#define BS_USB_GPTIMER0CTRL_GPTCNT (24U)   /*!< Bit field size in bits for USB_GPTIMER0CTRL_GPTCNT. */

/*! @brief Read current value of the USB_GPTIMER0CTRL_GPTCNT field. */
#define BR_USB_GPTIMER0CTRL_GPTCNT(x) (HW_USB_GPTIMER0CTRL(x).B.GPTCNT)

/*! @brief Format value for bitfield USB_GPTIMER0CTRL_GPTCNT. */
#define BF_USB_GPTIMER0CTRL_GPTCNT(v) ((uint32_t)((uint32_t)(v) << BP_USB_GPTIMER0CTRL_GPTCNT) & BM_USB_GPTIMER0CTRL_GPTCNT)

/*! @brief Set the GPTCNT field to a new value. */
#define BW_USB_GPTIMER0CTRL_GPTCNT(x, v) (HW_USB_GPTIMER0CTRL_WR(x, (HW_USB_GPTIMER0CTRL_RD(x) & ~BM_USB_GPTIMER0CTRL_GPTCNT) | BF_USB_GPTIMER0CTRL_GPTCNT(v)))
/*@}*/

/*!
 * @name Register USB_GPTIMER0CTRL, field GPTMODE[24] (RW)
 *
 * General Purpose Timer Mode In one shot mode, the timer will count down to
 * zero, generate an interrupt, and stop until the counter is reset by software; In
 * repeat mode, the timer will count down to zero, generate an interrupt and
 * automatically reload the counter value from GPTLD bits to start again.
 *
 * Values:
 * - 0 - One Shot Mode
 * - 1 - Repeat Mode
 */
/*@{*/
#define BP_USB_GPTIMER0CTRL_GPTMODE (24U)  /*!< Bit position for USB_GPTIMER0CTRL_GPTMODE. */
#define BM_USB_GPTIMER0CTRL_GPTMODE (0x01000000U) /*!< Bit mask for USB_GPTIMER0CTRL_GPTMODE. */
#define BS_USB_GPTIMER0CTRL_GPTMODE (1U)   /*!< Bit field size in bits for USB_GPTIMER0CTRL_GPTMODE. */

/*! @brief Read current value of the USB_GPTIMER0CTRL_GPTMODE field. */
#define BR_USB_GPTIMER0CTRL_GPTMODE(x) (HW_USB_GPTIMER0CTRL(x).B.GPTMODE)

/*! @brief Format value for bitfield USB_GPTIMER0CTRL_GPTMODE. */
#define BF_USB_GPTIMER0CTRL_GPTMODE(v) ((uint32_t)((uint32_t)(v) << BP_USB_GPTIMER0CTRL_GPTMODE) & BM_USB_GPTIMER0CTRL_GPTMODE)

/*! @brief Set the GPTMODE field to a new value. */
#define BW_USB_GPTIMER0CTRL_GPTMODE(x, v) (HW_USB_GPTIMER0CTRL_WR(x, (HW_USB_GPTIMER0CTRL_RD(x) & ~BM_USB_GPTIMER0CTRL_GPTMODE) | BF_USB_GPTIMER0CTRL_GPTMODE(v)))
/*@}*/

/*!
 * @name Register USB_GPTIMER0CTRL, field GPTRST[30] (RW)
 *
 * General Purpose Timer Reset
 *
 * Values:
 * - 0 - No action
 * - 1 - Load counter value from GPTLD bits in n_GPTIMER0LD
 */
/*@{*/
#define BP_USB_GPTIMER0CTRL_GPTRST (30U)   /*!< Bit position for USB_GPTIMER0CTRL_GPTRST. */
#define BM_USB_GPTIMER0CTRL_GPTRST (0x40000000U) /*!< Bit mask for USB_GPTIMER0CTRL_GPTRST. */
#define BS_USB_GPTIMER0CTRL_GPTRST (1U)    /*!< Bit field size in bits for USB_GPTIMER0CTRL_GPTRST. */

/*! @brief Read current value of the USB_GPTIMER0CTRL_GPTRST field. */
#define BR_USB_GPTIMER0CTRL_GPTRST(x) (HW_USB_GPTIMER0CTRL(x).B.GPTRST)

/*! @brief Format value for bitfield USB_GPTIMER0CTRL_GPTRST. */
#define BF_USB_GPTIMER0CTRL_GPTRST(v) ((uint32_t)((uint32_t)(v) << BP_USB_GPTIMER0CTRL_GPTRST) & BM_USB_GPTIMER0CTRL_GPTRST)

/*! @brief Set the GPTRST field to a new value. */
#define BW_USB_GPTIMER0CTRL_GPTRST(x, v) (HW_USB_GPTIMER0CTRL_WR(x, (HW_USB_GPTIMER0CTRL_RD(x) & ~BM_USB_GPTIMER0CTRL_GPTRST) | BF_USB_GPTIMER0CTRL_GPTRST(v)))
/*@}*/

/*!
 * @name Register USB_GPTIMER0CTRL, field GPTRUN[31] (RW)
 *
 * General Purpose Timer Run GPTCNT bits are not effected when setting or
 * clearing this bit.
 *
 * Values:
 * - 0 - Stop counting
 * - 1 - Run
 */
/*@{*/
#define BP_USB_GPTIMER0CTRL_GPTRUN (31U)   /*!< Bit position for USB_GPTIMER0CTRL_GPTRUN. */
#define BM_USB_GPTIMER0CTRL_GPTRUN (0x80000000U) /*!< Bit mask for USB_GPTIMER0CTRL_GPTRUN. */
#define BS_USB_GPTIMER0CTRL_GPTRUN (1U)    /*!< Bit field size in bits for USB_GPTIMER0CTRL_GPTRUN. */

/*! @brief Read current value of the USB_GPTIMER0CTRL_GPTRUN field. */
#define BR_USB_GPTIMER0CTRL_GPTRUN(x) (HW_USB_GPTIMER0CTRL(x).B.GPTRUN)

/*! @brief Format value for bitfield USB_GPTIMER0CTRL_GPTRUN. */
#define BF_USB_GPTIMER0CTRL_GPTRUN(v) ((uint32_t)((uint32_t)(v) << BP_USB_GPTIMER0CTRL_GPTRUN) & BM_USB_GPTIMER0CTRL_GPTRUN)

/*! @brief Set the GPTRUN field to a new value. */
#define BW_USB_GPTIMER0CTRL_GPTRUN(x, v) (HW_USB_GPTIMER0CTRL_WR(x, (HW_USB_GPTIMER0CTRL_RD(x) & ~BM_USB_GPTIMER0CTRL_GPTRUN) | BF_USB_GPTIMER0CTRL_GPTRUN(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_GPTIMER1LD - General Purpose Timer #1 Load
 ******************************************************************************/

/*!
 * @brief HW_USB_GPTIMER1LD - General Purpose Timer #1 Load (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register controls load value of the count timer in register
 * n_GPTIMER1CTRL. Please see GPTIMER1CTRLGeneral Purpose Timer #1 Controller .
 */
typedef union _hw_usb_gptimer1ld
{
    uint32_t U;
    struct _hw_usb_gptimer1ld_bitfields
    {
        uint32_t GPTLD : 24;           /*!< [23:0]  */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_gptimer1ld_t;

/*!
 * @name Constants and macros for entire USB_GPTIMER1LD register
 */
/*@{*/
#define HW_USB_GPTIMER1LD_ADDR(x) ((uintptr_t)(x) + 0x88U)

#define HW_USB_GPTIMER1LD(x)     (*(__IO hw_usb_gptimer1ld_t *) HW_USB_GPTIMER1LD_ADDR(x))
#define HW_USB_GPTIMER1LD_RD(x)  (HW_USB_GPTIMER1LD(x).U)
#define HW_USB_GPTIMER1LD_WR(x, v) (HW_USB_GPTIMER1LD(x).U = (v))
#define HW_USB_GPTIMER1LD_SET(x, v) (HW_USB_GPTIMER1LD_WR(x, HW_USB_GPTIMER1LD_RD(x) |  (v)))
#define HW_USB_GPTIMER1LD_CLR(x, v) (HW_USB_GPTIMER1LD_WR(x, HW_USB_GPTIMER1LD_RD(x) & ~(v)))
#define HW_USB_GPTIMER1LD_TOG(x, v) (HW_USB_GPTIMER1LD_WR(x, HW_USB_GPTIMER1LD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_GPTIMER1LD bitfields
 */

/*!
 * @name Register USB_GPTIMER1LD, field GPTLD[23:0] (RW)
 *
 * General Purpose Timer Load Value These bit fields are loaded to GPTCNT bits
 * when GPTRST bit is set '1b'. This value represents the time in microseconds
 * minus 1 for the timer duration. Example: for a one millisecond timer, load
 * 1000-1=999 or 0x0003E7. Max value is 0xFFFFFF or 16.777215 seconds.
 */
/*@{*/
#define BP_USB_GPTIMER1LD_GPTLD (0U)       /*!< Bit position for USB_GPTIMER1LD_GPTLD. */
#define BM_USB_GPTIMER1LD_GPTLD (0x00FFFFFFU) /*!< Bit mask for USB_GPTIMER1LD_GPTLD. */
#define BS_USB_GPTIMER1LD_GPTLD (24U)      /*!< Bit field size in bits for USB_GPTIMER1LD_GPTLD. */

/*! @brief Read current value of the USB_GPTIMER1LD_GPTLD field. */
#define BR_USB_GPTIMER1LD_GPTLD(x) (HW_USB_GPTIMER1LD(x).B.GPTLD)

/*! @brief Format value for bitfield USB_GPTIMER1LD_GPTLD. */
#define BF_USB_GPTIMER1LD_GPTLD(v) ((uint32_t)((uint32_t)(v) << BP_USB_GPTIMER1LD_GPTLD) & BM_USB_GPTIMER1LD_GPTLD)

/*! @brief Set the GPTLD field to a new value. */
#define BW_USB_GPTIMER1LD_GPTLD(x, v) (HW_USB_GPTIMER1LD_WR(x, (HW_USB_GPTIMER1LD_RD(x) & ~BM_USB_GPTIMER1LD_GPTLD) | BF_USB_GPTIMER1LD_GPTLD(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_GPTIMER1CTRL - General Purpose Timer #1 Controller
 ******************************************************************************/

/*!
 * @brief HW_USB_GPTIMER1CTRL - General Purpose Timer #1 Controller (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the control for this countdown timer and a data field
 * can be queried to determine the running count value. This timer has
 * granularity on 1 us and can be programmed to a little over 16 seconds. There are two
 * counter modes which are described in the register table below. When the timer
 * counter value transitions to zero, an interrupt could be generated if enable.
 * Interrupt status bit is TI1 bit in USB_n_USBSTS register (See USBSTSUSB Status
 * Register ), interrupt enable bit is TIE1 bit in n_USBINTR register (See
 * USBINTRInterrupt Enable Register ).
 */
typedef union _hw_usb_gptimer1ctrl
{
    uint32_t U;
    struct _hw_usb_gptimer1ctrl_bitfields
    {
        uint32_t GPTCNT : 24;          /*!< [23:0]  */
        uint32_t GPTMODE : 1;          /*!< [24]  */
        uint32_t RESERVED0 : 5;        /*!< [29:25]  */
        uint32_t GPTRST : 1;           /*!< [30]  */
        uint32_t GPTRUN : 1;           /*!< [31]  */
    } B;
} hw_usb_gptimer1ctrl_t;

/*!
 * @name Constants and macros for entire USB_GPTIMER1CTRL register
 */
/*@{*/
#define HW_USB_GPTIMER1CTRL_ADDR(x) ((uintptr_t)(x) + 0x8CU)

#define HW_USB_GPTIMER1CTRL(x)   (*(__IO hw_usb_gptimer1ctrl_t *) HW_USB_GPTIMER1CTRL_ADDR(x))
#define HW_USB_GPTIMER1CTRL_RD(x) (HW_USB_GPTIMER1CTRL(x).U)
#define HW_USB_GPTIMER1CTRL_WR(x, v) (HW_USB_GPTIMER1CTRL(x).U = (v))
#define HW_USB_GPTIMER1CTRL_SET(x, v) (HW_USB_GPTIMER1CTRL_WR(x, HW_USB_GPTIMER1CTRL_RD(x) |  (v)))
#define HW_USB_GPTIMER1CTRL_CLR(x, v) (HW_USB_GPTIMER1CTRL_WR(x, HW_USB_GPTIMER1CTRL_RD(x) & ~(v)))
#define HW_USB_GPTIMER1CTRL_TOG(x, v) (HW_USB_GPTIMER1CTRL_WR(x, HW_USB_GPTIMER1CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_GPTIMER1CTRL bitfields
 */

/*!
 * @name Register USB_GPTIMER1CTRL, field GPTCNT[23:0] (RW)
 *
 * General Purpose Timer Counter. This field is the count value of the countdown
 * timer.
 */
/*@{*/
#define BP_USB_GPTIMER1CTRL_GPTCNT (0U)    /*!< Bit position for USB_GPTIMER1CTRL_GPTCNT. */
#define BM_USB_GPTIMER1CTRL_GPTCNT (0x00FFFFFFU) /*!< Bit mask for USB_GPTIMER1CTRL_GPTCNT. */
#define BS_USB_GPTIMER1CTRL_GPTCNT (24U)   /*!< Bit field size in bits for USB_GPTIMER1CTRL_GPTCNT. */

/*! @brief Read current value of the USB_GPTIMER1CTRL_GPTCNT field. */
#define BR_USB_GPTIMER1CTRL_GPTCNT(x) (HW_USB_GPTIMER1CTRL(x).B.GPTCNT)

/*! @brief Format value for bitfield USB_GPTIMER1CTRL_GPTCNT. */
#define BF_USB_GPTIMER1CTRL_GPTCNT(v) ((uint32_t)((uint32_t)(v) << BP_USB_GPTIMER1CTRL_GPTCNT) & BM_USB_GPTIMER1CTRL_GPTCNT)

/*! @brief Set the GPTCNT field to a new value. */
#define BW_USB_GPTIMER1CTRL_GPTCNT(x, v) (HW_USB_GPTIMER1CTRL_WR(x, (HW_USB_GPTIMER1CTRL_RD(x) & ~BM_USB_GPTIMER1CTRL_GPTCNT) | BF_USB_GPTIMER1CTRL_GPTCNT(v)))
/*@}*/

/*!
 * @name Register USB_GPTIMER1CTRL, field GPTMODE[24] (RW)
 *
 * General Purpose Timer Mode In one shot mode, the timer will count down to
 * zero, generate an interrupt, and stop until the counter is reset by software. In
 * repeat mode, the timer will count down to zero, generate an interrupt and
 * automatically reload the counter value from GPTLD bits to start again.
 *
 * Values:
 * - 0 - One Shot Mode
 * - 1 - Repeat Mode
 */
/*@{*/
#define BP_USB_GPTIMER1CTRL_GPTMODE (24U)  /*!< Bit position for USB_GPTIMER1CTRL_GPTMODE. */
#define BM_USB_GPTIMER1CTRL_GPTMODE (0x01000000U) /*!< Bit mask for USB_GPTIMER1CTRL_GPTMODE. */
#define BS_USB_GPTIMER1CTRL_GPTMODE (1U)   /*!< Bit field size in bits for USB_GPTIMER1CTRL_GPTMODE. */

/*! @brief Read current value of the USB_GPTIMER1CTRL_GPTMODE field. */
#define BR_USB_GPTIMER1CTRL_GPTMODE(x) (HW_USB_GPTIMER1CTRL(x).B.GPTMODE)

/*! @brief Format value for bitfield USB_GPTIMER1CTRL_GPTMODE. */
#define BF_USB_GPTIMER1CTRL_GPTMODE(v) ((uint32_t)((uint32_t)(v) << BP_USB_GPTIMER1CTRL_GPTMODE) & BM_USB_GPTIMER1CTRL_GPTMODE)

/*! @brief Set the GPTMODE field to a new value. */
#define BW_USB_GPTIMER1CTRL_GPTMODE(x, v) (HW_USB_GPTIMER1CTRL_WR(x, (HW_USB_GPTIMER1CTRL_RD(x) & ~BM_USB_GPTIMER1CTRL_GPTMODE) | BF_USB_GPTIMER1CTRL_GPTMODE(v)))
/*@}*/

/*!
 * @name Register USB_GPTIMER1CTRL, field GPTRST[30] (RW)
 *
 * General Purpose Timer Reset
 *
 * Values:
 * - 0 - No action
 * - 1 - Load counter value from GPTLD bits in USB_n_GPTIMER0LD
 */
/*@{*/
#define BP_USB_GPTIMER1CTRL_GPTRST (30U)   /*!< Bit position for USB_GPTIMER1CTRL_GPTRST. */
#define BM_USB_GPTIMER1CTRL_GPTRST (0x40000000U) /*!< Bit mask for USB_GPTIMER1CTRL_GPTRST. */
#define BS_USB_GPTIMER1CTRL_GPTRST (1U)    /*!< Bit field size in bits for USB_GPTIMER1CTRL_GPTRST. */

/*! @brief Read current value of the USB_GPTIMER1CTRL_GPTRST field. */
#define BR_USB_GPTIMER1CTRL_GPTRST(x) (HW_USB_GPTIMER1CTRL(x).B.GPTRST)

/*! @brief Format value for bitfield USB_GPTIMER1CTRL_GPTRST. */
#define BF_USB_GPTIMER1CTRL_GPTRST(v) ((uint32_t)((uint32_t)(v) << BP_USB_GPTIMER1CTRL_GPTRST) & BM_USB_GPTIMER1CTRL_GPTRST)

/*! @brief Set the GPTRST field to a new value. */
#define BW_USB_GPTIMER1CTRL_GPTRST(x, v) (HW_USB_GPTIMER1CTRL_WR(x, (HW_USB_GPTIMER1CTRL_RD(x) & ~BM_USB_GPTIMER1CTRL_GPTRST) | BF_USB_GPTIMER1CTRL_GPTRST(v)))
/*@}*/

/*!
 * @name Register USB_GPTIMER1CTRL, field GPTRUN[31] (RW)
 *
 * General Purpose Timer Run GPTCNT bits are not effected when setting or
 * clearing this bit.
 *
 * Values:
 * - 0 - Stop counting
 * - 1 - Run
 */
/*@{*/
#define BP_USB_GPTIMER1CTRL_GPTRUN (31U)   /*!< Bit position for USB_GPTIMER1CTRL_GPTRUN. */
#define BM_USB_GPTIMER1CTRL_GPTRUN (0x80000000U) /*!< Bit mask for USB_GPTIMER1CTRL_GPTRUN. */
#define BS_USB_GPTIMER1CTRL_GPTRUN (1U)    /*!< Bit field size in bits for USB_GPTIMER1CTRL_GPTRUN. */

/*! @brief Read current value of the USB_GPTIMER1CTRL_GPTRUN field. */
#define BR_USB_GPTIMER1CTRL_GPTRUN(x) (HW_USB_GPTIMER1CTRL(x).B.GPTRUN)

/*! @brief Format value for bitfield USB_GPTIMER1CTRL_GPTRUN. */
#define BF_USB_GPTIMER1CTRL_GPTRUN(v) ((uint32_t)((uint32_t)(v) << BP_USB_GPTIMER1CTRL_GPTRUN) & BM_USB_GPTIMER1CTRL_GPTRUN)

/*! @brief Set the GPTRUN field to a new value. */
#define BW_USB_GPTIMER1CTRL_GPTRUN(x, v) (HW_USB_GPTIMER1CTRL_WR(x, (HW_USB_GPTIMER1CTRL_RD(x) & ~BM_USB_GPTIMER1CTRL_GPTRUN) | BF_USB_GPTIMER1CTRL_GPTRUN(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_SBUSCFG - System Bus Config
 ******************************************************************************/

/*!
 * @brief HW_USB_SBUSCFG - System Bus Config (RW)
 *
 * Reset value: 0x00000002U
 */
typedef union _hw_usb_sbuscfg
{
    uint32_t U;
    struct _hw_usb_sbuscfg_bitfields
    {
        uint32_t AHBBRST : 3;          /*!< [2:0]  */
        uint32_t RESERVED0 : 29;       /*!< [31:3]  */
    } B;
} hw_usb_sbuscfg_t;

/*!
 * @name Constants and macros for entire USB_SBUSCFG register
 */
/*@{*/
#define HW_USB_SBUSCFG_ADDR(x)   ((uintptr_t)(x) + 0x90U)

#define HW_USB_SBUSCFG(x)        (*(__IO hw_usb_sbuscfg_t *) HW_USB_SBUSCFG_ADDR(x))
#define HW_USB_SBUSCFG_RD(x)     (HW_USB_SBUSCFG(x).U)
#define HW_USB_SBUSCFG_WR(x, v)  (HW_USB_SBUSCFG(x).U = (v))
#define HW_USB_SBUSCFG_SET(x, v) (HW_USB_SBUSCFG_WR(x, HW_USB_SBUSCFG_RD(x) |  (v)))
#define HW_USB_SBUSCFG_CLR(x, v) (HW_USB_SBUSCFG_WR(x, HW_USB_SBUSCFG_RD(x) & ~(v)))
#define HW_USB_SBUSCFG_TOG(x, v) (HW_USB_SBUSCFG_WR(x, HW_USB_SBUSCFG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_SBUSCFG bitfields
 */

/*!
 * @name Register USB_SBUSCFG, field AHBBRST[2:0] (RW)
 *
 * AHB master interface Burst configuration These bits control AHB master
 * transfer type sequence (or priority). This register overrides n_BURSTSIZE register
 * when its value is not zero.
 *
 * Values:
 * - 000 - Incremental burst of unspecified length only
 * - 001 - INCR4 burst, then single transfer
 * - 010 - INCR8 burst, INCR4 burst, then single transfer
 * - 011 - INCR16 burst, INCR8 burst, INCR4 burst, then single transfer
 * - 100 - Reserved, don't use
 * - 101 - INCR4 burst, then incremental burst of unspecified length
 * - 110 - INCR8 burst, INCR4 burst, then incremental burst of unspecified length
 * - 111 - INCR16 burst, INCR8 burst, INCR4 burst, then incremental burst of
 *     unspecified length
 */
/*@{*/
#define BP_USB_SBUSCFG_AHBBRST (0U)        /*!< Bit position for USB_SBUSCFG_AHBBRST. */
#define BM_USB_SBUSCFG_AHBBRST (0x00000007U) /*!< Bit mask for USB_SBUSCFG_AHBBRST. */
#define BS_USB_SBUSCFG_AHBBRST (3U)        /*!< Bit field size in bits for USB_SBUSCFG_AHBBRST. */

/*! @brief Read current value of the USB_SBUSCFG_AHBBRST field. */
#define BR_USB_SBUSCFG_AHBBRST(x) (HW_USB_SBUSCFG(x).B.AHBBRST)

/*! @brief Format value for bitfield USB_SBUSCFG_AHBBRST. */
#define BF_USB_SBUSCFG_AHBBRST(v) ((uint32_t)((uint32_t)(v) << BP_USB_SBUSCFG_AHBBRST) & BM_USB_SBUSCFG_AHBBRST)

/*! @brief Set the AHBBRST field to a new value. */
#define BW_USB_SBUSCFG_AHBBRST(x, v) (HW_USB_SBUSCFG_WR(x, (HW_USB_SBUSCFG_RD(x) & ~BM_USB_SBUSCFG_AHBBRST) | BF_USB_SBUSCFG_AHBBRST(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_CAPLENGTH - Capability Registers Length
 ******************************************************************************/

/*!
 * @brief HW_USB_CAPLENGTH - Capability Registers Length (RO)
 *
 * Reset value: 0x40U
 *
 * The Capability Registers Length register contains the address offset to the
 * Operational registers relative to the CAPLENGTH register.
 */
typedef union _hw_usb_caplength
{
    uint8_t U;
    struct _hw_usb_caplength_bitfields
    {
        uint8_t CAPLENGTH : 8;         /*!< [7:0]  */
    } B;
} hw_usb_caplength_t;

/*!
 * @name Constants and macros for entire USB_CAPLENGTH register
 */
/*@{*/
#define HW_USB_CAPLENGTH_ADDR(x) ((uintptr_t)(x) + 0x100U)

#define HW_USB_CAPLENGTH(x)      (*(__I hw_usb_caplength_t *) HW_USB_CAPLENGTH_ADDR(x))
#define HW_USB_CAPLENGTH_RD(x)   (HW_USB_CAPLENGTH(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_CAPLENGTH bitfields
 */

/*!
 * @name Register USB_CAPLENGTH, field CAPLENGTH[7:0] (RO)
 *
 * These bits are used as an offset to add to register base to find the
 * beginning of the Operational Register. Default value is '40h'.
 */
/*@{*/
#define BP_USB_CAPLENGTH_CAPLENGTH (0U)    /*!< Bit position for USB_CAPLENGTH_CAPLENGTH. */
#define BM_USB_CAPLENGTH_CAPLENGTH (0xFFU) /*!< Bit mask for USB_CAPLENGTH_CAPLENGTH. */
#define BS_USB_CAPLENGTH_CAPLENGTH (8U)    /*!< Bit field size in bits for USB_CAPLENGTH_CAPLENGTH. */

/*! @brief Read current value of the USB_CAPLENGTH_CAPLENGTH field. */
#define BR_USB_CAPLENGTH_CAPLENGTH(x) (HW_USB_CAPLENGTH(x).U)
/*@}*/

/*******************************************************************************
 * HW_USB_HCIVERSION - Host Controller Interface Version
 ******************************************************************************/

/*!
 * @brief HW_USB_HCIVERSION - Host Controller Interface Version (RO)
 *
 * Reset value: 0x0100U
 *
 * This is a 2-byte register containing a BCD encoding of the EHCI revision
 * number supported by this host controller. The most significant byte of this
 * register represents a major revision and the least significant byte is the minor
 * revision.
 */
typedef union _hw_usb_hciversion
{
    uint16_t U;
    struct _hw_usb_hciversion_bitfields
    {
        uint16_t HCIVERSION : 16;      /*!< [15:0]  */
    } B;
} hw_usb_hciversion_t;

/*!
 * @name Constants and macros for entire USB_HCIVERSION register
 */
/*@{*/
#define HW_USB_HCIVERSION_ADDR(x) ((uintptr_t)(x) + 0x102U)

#define HW_USB_HCIVERSION(x)     (*(__I hw_usb_hciversion_t *) HW_USB_HCIVERSION_ADDR(x))
#define HW_USB_HCIVERSION_RD(x)  (HW_USB_HCIVERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_HCIVERSION bitfields
 */

/*!
 * @name Register USB_HCIVERSION, field HCIVERSION[15:0] (RO)
 *
 * Host Controller Interface Version Number Default value is '10h', which means
 * EHCI rev1.0.
 */
/*@{*/
#define BP_USB_HCIVERSION_HCIVERSION (0U)  /*!< Bit position for USB_HCIVERSION_HCIVERSION. */
#define BM_USB_HCIVERSION_HCIVERSION (0xFFFFU) /*!< Bit mask for USB_HCIVERSION_HCIVERSION. */
#define BS_USB_HCIVERSION_HCIVERSION (16U) /*!< Bit field size in bits for USB_HCIVERSION_HCIVERSION. */

/*! @brief Read current value of the USB_HCIVERSION_HCIVERSION field. */
#define BR_USB_HCIVERSION_HCIVERSION(x) (HW_USB_HCIVERSION(x).U)
/*@}*/

/*******************************************************************************
 * HW_USB_HCSPARAMS - Host Controller Structural Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_HCSPARAMS - Host Controller Structural Parameters (RO)
 *
 * Reset value: 0x00010011U
 *
 * The following figure shows the port steering logic capabilities of Host
 * Control Structural Parameters (n_HCSPARAMS).
 */
typedef union _hw_usb_hcsparams
{
    uint32_t U;
    struct _hw_usb_hcsparams_bitfields
    {
        uint32_t N_PORTS : 4;          /*!< [3:0]  */
        uint32_t PPC : 1;              /*!< [4]  */
        uint32_t RESERVED0 : 3;        /*!< [7:5]  */
        uint32_t N_PCC : 4;            /*!< [11:8]  */
        uint32_t N_CC : 4;             /*!< [15:12]  */
        uint32_t PI : 1;               /*!< [16]  */
        uint32_t RESERVED1 : 3;        /*!< [19:17]  */
        uint32_t N_PTT : 4;            /*!< [23:20]  */
        uint32_t N_TT : 4;             /*!< [27:24]  */
        uint32_t RESERVED2 : 4;        /*!< [31:28]  */
    } B;
} hw_usb_hcsparams_t;

/*!
 * @name Constants and macros for entire USB_HCSPARAMS register
 */
/*@{*/
#define HW_USB_HCSPARAMS_ADDR(x) ((uintptr_t)(x) + 0x104U)

#define HW_USB_HCSPARAMS(x)      (*(__I hw_usb_hcsparams_t *) HW_USB_HCSPARAMS_ADDR(x))
#define HW_USB_HCSPARAMS_RD(x)   (HW_USB_HCSPARAMS(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_HCSPARAMS bitfields
 */

/*!
 * @name Register USB_HCSPARAMS, field N_PORTS[3:0] (RO)
 *
 * Number of downstream ports. This field specifies the number of physical
 * downstream ports implemented on this host controller. The value of this field
 * determines how many port registers are addressable in the Operational Register.
 * Valid values are in the range of 1h to Fh. A zero in this field is undefined.
 * These bits are always set to '0001b' because all controller cores are Single-Port
 * Host.
 */
/*@{*/
#define BP_USB_HCSPARAMS_N_PORTS (0U)      /*!< Bit position for USB_HCSPARAMS_N_PORTS. */
#define BM_USB_HCSPARAMS_N_PORTS (0x0000000FU) /*!< Bit mask for USB_HCSPARAMS_N_PORTS. */
#define BS_USB_HCSPARAMS_N_PORTS (4U)      /*!< Bit field size in bits for USB_HCSPARAMS_N_PORTS. */

/*! @brief Read current value of the USB_HCSPARAMS_N_PORTS field. */
#define BR_USB_HCSPARAMS_N_PORTS(x) (HW_USB_HCSPARAMS(x).B.N_PORTS)
/*@}*/

/*!
 * @name Register USB_HCSPARAMS, field PPC[4] (RO)
 *
 * Port Power Control This field indicates whether the host controller
 * implementation includes port power control. A one indicates the ports have port power
 * switches. A zero indicates the ports do not have port power switches. The value
 * of this field affects the functionality of the Port Power field in each port
 * status and control register
 */
/*@{*/
#define BP_USB_HCSPARAMS_PPC (4U)          /*!< Bit position for USB_HCSPARAMS_PPC. */
#define BM_USB_HCSPARAMS_PPC (0x00000010U) /*!< Bit mask for USB_HCSPARAMS_PPC. */
#define BS_USB_HCSPARAMS_PPC (1U)          /*!< Bit field size in bits for USB_HCSPARAMS_PPC. */

/*! @brief Read current value of the USB_HCSPARAMS_PPC field. */
#define BR_USB_HCSPARAMS_PPC(x) (HW_USB_HCSPARAMS(x).B.PPC)
/*@}*/

/*!
 * @name Register USB_HCSPARAMS, field N_PCC[11:8] (RO)
 *
 * Number of Ports per Companion Controller This field indicates the number of
 * ports supported per internal Companion Controller. It is used to indicate the
 * port routing configuration to the system software. For example, if N_PORTS has
 * a value of 6 and N_CC has a value of 2 then N_PCC could have a value of 3. The
 * convention is that the first N_PCC ports are assumed to be routed to
 * companion controller 1, the next N_PCC ports to companion controller 2, etc. In the
 * previous example, the N_PCC could have been 4, where the first 4 are routed to
 * companion controller 1 and the last two are routed to companion controller 2.
 * The number in this field must be consistent with N_PORTS and N_CC. These bits
 * are '0000b' in all controller core.
 */
/*@{*/
#define BP_USB_HCSPARAMS_N_PCC (8U)        /*!< Bit position for USB_HCSPARAMS_N_PCC. */
#define BM_USB_HCSPARAMS_N_PCC (0x00000F00U) /*!< Bit mask for USB_HCSPARAMS_N_PCC. */
#define BS_USB_HCSPARAMS_N_PCC (4U)        /*!< Bit field size in bits for USB_HCSPARAMS_N_PCC. */

/*! @brief Read current value of the USB_HCSPARAMS_N_PCC field. */
#define BR_USB_HCSPARAMS_N_PCC(x) (HW_USB_HCSPARAMS(x).B.N_PCC)
/*@}*/

/*!
 * @name Register USB_HCSPARAMS, field N_CC[15:12] (RO)
 *
 * Number of Companion Controller (N_CC). This field indicates the number of
 * companion controllers associated with this USB2.0 host controller. These bits are
 * '0000b' in all controller core.
 *
 * Values:
 * - 0 - There is no internal Companion Controller and port-ownership hand-off
 *     is not supported.
 * - 1 - There are internal companion controller(s) and port-ownership hand-offs
 *     is supported.
 */
/*@{*/
#define BP_USB_HCSPARAMS_N_CC (12U)        /*!< Bit position for USB_HCSPARAMS_N_CC. */
#define BM_USB_HCSPARAMS_N_CC (0x0000F000U) /*!< Bit mask for USB_HCSPARAMS_N_CC. */
#define BS_USB_HCSPARAMS_N_CC (4U)         /*!< Bit field size in bits for USB_HCSPARAMS_N_CC. */

/*! @brief Read current value of the USB_HCSPARAMS_N_CC field. */
#define BR_USB_HCSPARAMS_N_CC(x) (HW_USB_HCSPARAMS(x).B.N_CC)
/*@}*/

/*!
 * @name Register USB_HCSPARAMS, field PI[16] (RO)
 *
 * Port Indicators (P INDICATOR) This bit indicates whether the ports support
 * port indicator control. When set to one, the port status and control registers
 * include a read/writeable field for controlling the state of the port indicator
 * This bit is "1b" in all controller core.
 */
/*@{*/
#define BP_USB_HCSPARAMS_PI  (16U)         /*!< Bit position for USB_HCSPARAMS_PI. */
#define BM_USB_HCSPARAMS_PI  (0x00010000U) /*!< Bit mask for USB_HCSPARAMS_PI. */
#define BS_USB_HCSPARAMS_PI  (1U)          /*!< Bit field size in bits for USB_HCSPARAMS_PI. */

/*! @brief Read current value of the USB_HCSPARAMS_PI field. */
#define BR_USB_HCSPARAMS_PI(x) (HW_USB_HCSPARAMS(x).B.PI)
/*@}*/

/*!
 * @name Register USB_HCSPARAMS, field N_PTT[23:20] (RO)
 *
 * Number of Ports per Transaction Translator (N_PTT). Default value '0000b'
 * This field indicates the number of ports assigned to each transaction translator
 * within the USB2.0 host controller. These bits would be set to equal N_PORTS
 * for Multi-Port Host, and '0000b' for Single-Port Host.
 */
/*@{*/
#define BP_USB_HCSPARAMS_N_PTT (20U)       /*!< Bit position for USB_HCSPARAMS_N_PTT. */
#define BM_USB_HCSPARAMS_N_PTT (0x00F00000U) /*!< Bit mask for USB_HCSPARAMS_N_PTT. */
#define BS_USB_HCSPARAMS_N_PTT (4U)        /*!< Bit field size in bits for USB_HCSPARAMS_N_PTT. */

/*! @brief Read current value of the USB_HCSPARAMS_N_PTT field. */
#define BR_USB_HCSPARAMS_N_PTT(x) (HW_USB_HCSPARAMS(x).B.N_PTT)
/*@}*/

/*!
 * @name Register USB_HCSPARAMS, field N_TT[27:24] (RO)
 *
 * Number of Transaction Translators (N_TT). Default value '0000b' This field
 * indicates the number of embedded transaction translators associated with the
 * USB2.0 host controller. These bits would be set to '0001b' for Multi-Port Host,
 * and '0000b' for Single-Port Host.
 */
/*@{*/
#define BP_USB_HCSPARAMS_N_TT (24U)        /*!< Bit position for USB_HCSPARAMS_N_TT. */
#define BM_USB_HCSPARAMS_N_TT (0x0F000000U) /*!< Bit mask for USB_HCSPARAMS_N_TT. */
#define BS_USB_HCSPARAMS_N_TT (4U)         /*!< Bit field size in bits for USB_HCSPARAMS_N_TT. */

/*! @brief Read current value of the USB_HCSPARAMS_N_TT field. */
#define BR_USB_HCSPARAMS_N_TT(x) (HW_USB_HCSPARAMS(x).B.N_TT)
/*@}*/

/*******************************************************************************
 * HW_USB_HCCPARAMS - Host Controller Capability Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_HCCPARAMS - Host Controller Capability Parameters (RO)
 *
 * Reset value: 0x00000006U
 *
 * This register identifies multiple mode control (time-base bit functionality),
 * addressing capability.
 */
typedef union _hw_usb_hccparams
{
    uint32_t U;
    struct _hw_usb_hccparams_bitfields
    {
        uint32_t ADC : 1;              /*!< [0]  */
        uint32_t PFL : 1;              /*!< [1]  */
        uint32_t ASP : 1;              /*!< [2]  */
        uint32_t RESERVED0 : 1;        /*!< [3]  */
        uint32_t IST : 4;              /*!< [7:4]  */
        uint32_t EECP : 8;             /*!< [15:8]  */
        uint32_t RESERVED1 : 16;       /*!< [31:16]  */
    } B;
} hw_usb_hccparams_t;

/*!
 * @name Constants and macros for entire USB_HCCPARAMS register
 */
/*@{*/
#define HW_USB_HCCPARAMS_ADDR(x) ((uintptr_t)(x) + 0x108U)

#define HW_USB_HCCPARAMS(x)      (*(__I hw_usb_hccparams_t *) HW_USB_HCCPARAMS_ADDR(x))
#define HW_USB_HCCPARAMS_RD(x)   (HW_USB_HCCPARAMS(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_HCCPARAMS bitfields
 */

/*!
 * @name Register USB_HCCPARAMS, field ADC[0] (RO)
 *
 * 64-bit Addressing Capability This bit is set '0b' in all controller core, no
 * 64-bit addressing capability is supported.
 */
/*@{*/
#define BP_USB_HCCPARAMS_ADC (0U)          /*!< Bit position for USB_HCCPARAMS_ADC. */
#define BM_USB_HCCPARAMS_ADC (0x00000001U) /*!< Bit mask for USB_HCCPARAMS_ADC. */
#define BS_USB_HCCPARAMS_ADC (1U)          /*!< Bit field size in bits for USB_HCCPARAMS_ADC. */

/*! @brief Read current value of the USB_HCCPARAMS_ADC field. */
#define BR_USB_HCCPARAMS_ADC(x) (HW_USB_HCCPARAMS(x).B.ADC)
/*@}*/

/*!
 * @name Register USB_HCCPARAMS, field PFL[1] (RO)
 *
 * Programmable Frame List Flag If this bit is set to zero, then the system
 * software must use a frame list length of 1024 elements with this host controller.
 * The USBCMD register Frame List Size field is a read-only register and must be
 * set to zero. If set to a one, then the system software can specify and use a
 * smaller frame list and configure the host controller via the USBCMD register
 * Frame List Size field. The frame list must always be aligned on a 4K-page
 * boundary. This requirement ensures that the frame list is always physically
 * contiguous. This bit is set '1b' in all controller core.
 */
/*@{*/
#define BP_USB_HCCPARAMS_PFL (1U)          /*!< Bit position for USB_HCCPARAMS_PFL. */
#define BM_USB_HCCPARAMS_PFL (0x00000002U) /*!< Bit mask for USB_HCCPARAMS_PFL. */
#define BS_USB_HCCPARAMS_PFL (1U)          /*!< Bit field size in bits for USB_HCCPARAMS_PFL. */

/*! @brief Read current value of the USB_HCCPARAMS_PFL field. */
#define BR_USB_HCCPARAMS_PFL(x) (HW_USB_HCCPARAMS(x).B.PFL)
/*@}*/

/*!
 * @name Register USB_HCCPARAMS, field ASP[2] (RO)
 *
 * Asynchronous Schedule Park Capability If this bit is set to a one, then the
 * host controller supports the park feature for high-speed queue heads in the
 * Asynchronous Schedule. The feature can be disabled or enabled and set to a
 * specific level by using the Asynchronous Schedule Park Mode Enable and Asynchronous
 * Schedule Park Mode Count fields in the USBCMD register. ASP bit reset value:
 * '00b' for OTG controller core, '11b' for Host-only controller core.
 */
/*@{*/
#define BP_USB_HCCPARAMS_ASP (2U)          /*!< Bit position for USB_HCCPARAMS_ASP. */
#define BM_USB_HCCPARAMS_ASP (0x00000004U) /*!< Bit mask for USB_HCCPARAMS_ASP. */
#define BS_USB_HCCPARAMS_ASP (1U)          /*!< Bit field size in bits for USB_HCCPARAMS_ASP. */

/*! @brief Read current value of the USB_HCCPARAMS_ASP field. */
#define BR_USB_HCCPARAMS_ASP(x) (HW_USB_HCCPARAMS(x).B.ASP)
/*@}*/

/*!
 * @name Register USB_HCCPARAMS, field IST[7:4] (RO)
 *
 * Isochronous Scheduling Threshold. This field indicates, relative to the
 * current position of the executing host controller, where software can reliably
 * update the isochronous schedule. When bit [7] is zero, the value of the least
 * significant 3 bits indicates the number of micro-frames a host controller can hold
 * a set of isochronous data structures (one or more) before flushing the state.
 * When bit [7] is a one, then host software assumes the host controller may
 * cache an isochronous data structure for an entire frame. These bits are set '00h'
 * in all controller core.
 */
/*@{*/
#define BP_USB_HCCPARAMS_IST (4U)          /*!< Bit position for USB_HCCPARAMS_IST. */
#define BM_USB_HCCPARAMS_IST (0x000000F0U) /*!< Bit mask for USB_HCCPARAMS_IST. */
#define BS_USB_HCCPARAMS_IST (4U)          /*!< Bit field size in bits for USB_HCCPARAMS_IST. */

/*! @brief Read current value of the USB_HCCPARAMS_IST field. */
#define BR_USB_HCCPARAMS_IST(x) (HW_USB_HCCPARAMS(x).B.IST)
/*@}*/

/*!
 * @name Register USB_HCCPARAMS, field EECP[15:8] (RO)
 *
 * EHCI Extended Capabilities Pointer. This field indicates the existence of a
 * capabilities list. A value of 00h indicates no extended capabilities are
 * implemented. A non-zero value in this register indicates the offset in PCI
 * configuration space of the first EHCI extended capability. The pointer value must be
 * 40h or greater if implemented to maintain the consistency of the PCI header
 * defined for this class of device. These bits are set '00h' in all controller core.
 */
/*@{*/
#define BP_USB_HCCPARAMS_EECP (8U)         /*!< Bit position for USB_HCCPARAMS_EECP. */
#define BM_USB_HCCPARAMS_EECP (0x0000FF00U) /*!< Bit mask for USB_HCCPARAMS_EECP. */
#define BS_USB_HCCPARAMS_EECP (8U)         /*!< Bit field size in bits for USB_HCCPARAMS_EECP. */

/*! @brief Read current value of the USB_HCCPARAMS_EECP field. */
#define BR_USB_HCCPARAMS_EECP(x) (HW_USB_HCCPARAMS(x).B.EECP)
/*@}*/

/*******************************************************************************
 * HW_USB_DCIVERSION - Device Controller Interface Version
 ******************************************************************************/

/*!
 * @brief HW_USB_DCIVERSION - Device Controller Interface Version (RO)
 *
 * Reset value: 0x0001U
 *
 * This register indicates the two-byte BCD encoding of the device controller
 * interface version number.
 */
typedef union _hw_usb_dciversion
{
    uint16_t U;
    struct _hw_usb_dciversion_bitfields
    {
        uint16_t DCIVERSION : 16;      /*!< [15:0]  */
    } B;
} hw_usb_dciversion_t;

/*!
 * @name Constants and macros for entire USB_DCIVERSION register
 */
/*@{*/
#define HW_USB_DCIVERSION_ADDR(x) ((uintptr_t)(x) + 0x120U)

#define HW_USB_DCIVERSION(x)     (*(__I hw_usb_dciversion_t *) HW_USB_DCIVERSION_ADDR(x))
#define HW_USB_DCIVERSION_RD(x)  (HW_USB_DCIVERSION(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_DCIVERSION bitfields
 */

/*!
 * @name Register USB_DCIVERSION, field DCIVERSION[15:0] (RO)
 *
 * Device Controller Interface Version Number Default value is '01h', which
 * means rev0.1.
 */
/*@{*/
#define BP_USB_DCIVERSION_DCIVERSION (0U)  /*!< Bit position for USB_DCIVERSION_DCIVERSION. */
#define BM_USB_DCIVERSION_DCIVERSION (0xFFFFU) /*!< Bit mask for USB_DCIVERSION_DCIVERSION. */
#define BS_USB_DCIVERSION_DCIVERSION (16U) /*!< Bit field size in bits for USB_DCIVERSION_DCIVERSION. */

/*! @brief Read current value of the USB_DCIVERSION_DCIVERSION field. */
#define BR_USB_DCIVERSION_DCIVERSION(x) (HW_USB_DCIVERSION(x).U)
/*@}*/

/*******************************************************************************
 * HW_USB_DCCPARAMS - Device Controller Capability Parameters
 ******************************************************************************/

/*!
 * @brief HW_USB_DCCPARAMS - Device Controller Capability Parameters (RO)
 *
 * Reset value: 0x00000188U
 *
 * These fields describe the overall device capability of the controller. This
 * register is only available in OTG controller core.
 */
typedef union _hw_usb_dccparams
{
    uint32_t U;
    struct _hw_usb_dccparams_bitfields
    {
        uint32_t DEN : 5;              /*!< [4:0]  */
        uint32_t RESERVED0 : 2;        /*!< [6:5]  */
        uint32_t DC : 1;               /*!< [7]  */
        uint32_t HC : 1;               /*!< [8]  */
        uint32_t RESERVED1 : 23;       /*!< [31:9]  */
    } B;
} hw_usb_dccparams_t;

/*!
 * @name Constants and macros for entire USB_DCCPARAMS register
 */
/*@{*/
#define HW_USB_DCCPARAMS_ADDR(x) ((uintptr_t)(x) + 0x124U)

#define HW_USB_DCCPARAMS(x)      (*(__I hw_usb_dccparams_t *) HW_USB_DCCPARAMS_ADDR(x))
#define HW_USB_DCCPARAMS_RD(x)   (HW_USB_DCCPARAMS(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_DCCPARAMS bitfields
 */

/*!
 * @name Register USB_DCCPARAMS, field DEN[4:0] (RO)
 *
 * Device Endpoint Number This field indicates the number of endpoints built
 * into the device controller. If this controller is not device capable, then this
 * field will be zero. Valid values are 0 - 15.
 */
/*@{*/
#define BP_USB_DCCPARAMS_DEN (0U)          /*!< Bit position for USB_DCCPARAMS_DEN. */
#define BM_USB_DCCPARAMS_DEN (0x0000001FU) /*!< Bit mask for USB_DCCPARAMS_DEN. */
#define BS_USB_DCCPARAMS_DEN (5U)          /*!< Bit field size in bits for USB_DCCPARAMS_DEN. */

/*! @brief Read current value of the USB_DCCPARAMS_DEN field. */
#define BR_USB_DCCPARAMS_DEN(x) (HW_USB_DCCPARAMS(x).B.DEN)
/*@}*/

/*!
 * @name Register USB_DCCPARAMS, field DC[7] (RO)
 *
 * Device Capable When this bit is 1, this controller is capable of operating as
 * a USB 2.0 device.
 */
/*@{*/
#define BP_USB_DCCPARAMS_DC  (7U)          /*!< Bit position for USB_DCCPARAMS_DC. */
#define BM_USB_DCCPARAMS_DC  (0x00000080U) /*!< Bit mask for USB_DCCPARAMS_DC. */
#define BS_USB_DCCPARAMS_DC  (1U)          /*!< Bit field size in bits for USB_DCCPARAMS_DC. */

/*! @brief Read current value of the USB_DCCPARAMS_DC field. */
#define BR_USB_DCCPARAMS_DC(x) (HW_USB_DCCPARAMS(x).B.DC)
/*@}*/

/*!
 * @name Register USB_DCCPARAMS, field HC[8] (RO)
 *
 * Host Capable When this bit is 1, this controller is capable of operating as
 * an EHCI compatible USB 2.0 host controller.
 */
/*@{*/
#define BP_USB_DCCPARAMS_HC  (8U)          /*!< Bit position for USB_DCCPARAMS_HC. */
#define BM_USB_DCCPARAMS_HC  (0x00000100U) /*!< Bit mask for USB_DCCPARAMS_HC. */
#define BS_USB_DCCPARAMS_HC  (1U)          /*!< Bit field size in bits for USB_DCCPARAMS_HC. */

/*! @brief Read current value of the USB_DCCPARAMS_HC field. */
#define BR_USB_DCCPARAMS_HC(x) (HW_USB_DCCPARAMS(x).B.HC)
/*@}*/

/*******************************************************************************
 * HW_USB_USBCMD - USB Command Register
 ******************************************************************************/

/*!
 * @brief HW_USB_USBCMD - USB Command Register (RW)
 *
 * Reset value: 0x00080000U
 *
 * The Command Register indicates the command to be executed by the serial bus
 * host/device controller. Writing to the register causes a command to be executed.
 */
typedef union _hw_usb_usbcmd
{
    uint32_t U;
    struct _hw_usb_usbcmd_bitfields
    {
        uint32_t RS : 1;               /*!< [0]  */
        uint32_t RST : 1;              /*!< [1]  */
        uint32_t FS_1 : 2;             /*!< [3:2]  */
        uint32_t PSE : 1;              /*!< [4]  */
        uint32_t ASE : 1;              /*!< [5]  */
        uint32_t IAA : 1;              /*!< [6]  */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t ASP : 2;              /*!< [9:8]  */
        uint32_t RESERVED1 : 1;        /*!< [10]  */
        uint32_t ASPE : 1;             /*!< [11]  */
        uint32_t ATDTW : 1;            /*!< [12]  */
        uint32_t SUTW : 1;             /*!< [13]  */
        uint32_t RESERVED2 : 1;        /*!< [14]  */
        uint32_t FS_2 : 1;             /*!< [15]  */
        uint32_t ITC : 8;              /*!< [23:16]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_usbcmd_t;

/*!
 * @name Constants and macros for entire USB_USBCMD register
 */
/*@{*/
#define HW_USB_USBCMD_ADDR(x)    ((uintptr_t)(x) + 0x140U)

#define HW_USB_USBCMD(x)         (*(__IO hw_usb_usbcmd_t *) HW_USB_USBCMD_ADDR(x))
#define HW_USB_USBCMD_RD(x)      (HW_USB_USBCMD(x).U)
#define HW_USB_USBCMD_WR(x, v)   (HW_USB_USBCMD(x).U = (v))
#define HW_USB_USBCMD_SET(x, v)  (HW_USB_USBCMD_WR(x, HW_USB_USBCMD_RD(x) |  (v)))
#define HW_USB_USBCMD_CLR(x, v)  (HW_USB_USBCMD_WR(x, HW_USB_USBCMD_RD(x) & ~(v)))
#define HW_USB_USBCMD_TOG(x, v)  (HW_USB_USBCMD_WR(x, HW_USB_USBCMD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_USBCMD bitfields
 */

/*!
 * @name Register USB_USBCMD, field RS[0] (RW)
 *
 * Run/Stop (RS) - Read/Write. Default 0b. 1=Run. 0=Stop. Host operation mode:
 * When set to '1b', the Controller proceeds with the execution of the schedule.
 * The Controller continues execution as long as this bit is set to a one. When
 * this bit is set to 0, the Host Controller completes the current transaction on
 * the USB and then halts. The HC Halted bit in the status register indicates when
 * the Controller has finished the transaction and has entered the stopped
 * state. Software should not write a one to this field unless the controller is in
 * the Halted state (that is, HCHalted in the USBSTS register is a one). Device
 * operation mode: Writing a one to this bit will cause the controller to enable a
 * pull-up on D+ and initiate an attach event. This control bit is not directly
 * connected to the pull-up enable, as the pull-up will become disabled upon
 * transitioning into high-speed mode. Software should use this bit to prevent an
 * attach event before the controller has been properly initialized. Writing a 0 to
 * this will cause a detach event.
 */
/*@{*/
#define BP_USB_USBCMD_RS     (0U)          /*!< Bit position for USB_USBCMD_RS. */
#define BM_USB_USBCMD_RS     (0x00000001U) /*!< Bit mask for USB_USBCMD_RS. */
#define BS_USB_USBCMD_RS     (1U)          /*!< Bit field size in bits for USB_USBCMD_RS. */

/*! @brief Read current value of the USB_USBCMD_RS field. */
#define BR_USB_USBCMD_RS(x)  (HW_USB_USBCMD(x).B.RS)

/*! @brief Format value for bitfield USB_USBCMD_RS. */
#define BF_USB_USBCMD_RS(v)  ((uint32_t)((uint32_t)(v) << BP_USB_USBCMD_RS) & BM_USB_USBCMD_RS)

/*! @brief Set the RS field to a new value. */
#define BW_USB_USBCMD_RS(x, v) (HW_USB_USBCMD_WR(x, (HW_USB_USBCMD_RD(x) & ~BM_USB_USBCMD_RS) | BF_USB_USBCMD_RS(v)))
/*@}*/

/*!
 * @name Register USB_USBCMD, field RST[1] (RW)
 *
 * Controller Reset (RESET) - Read/Write. Software uses this bit to reset the
 * controller. This bit is set to zero by the Host/Device Controller when the reset
 * process is complete. Software cannot terminate the reset process early by
 * writing a zero to this register. Host operation mode: When software writes a one
 * to this bit, the Controller resets its internal pipelines, timers, counters,
 * state machines etc. to their initial value. Any transaction currently in
 * progress on USB is immediately terminated. A USB reset is not driven on downstream
 * ports. Software should not set this bit to a one when the HCHalted bit in the
 * USBSTS register is a zero. Attempting to reset an actively running host
 * controller will result in undefined behavior. Device operation mode: When software
 * writes a one to this bit, the Controller resets its internal pipelines, timers,
 * counters, state machines etc. to their initial value. Writing a one to this
 * bit when the device is in the attached state is not recommended, because the
 * effect on an attached host is undefined. In order to ensure that the device is
 * not in an attached state before initiating a device controller reset, all primed
 * endpoints should be flushed and the USBCMD Run/Stop bit should be set to 0.
 */
/*@{*/
#define BP_USB_USBCMD_RST    (1U)          /*!< Bit position for USB_USBCMD_RST. */
#define BM_USB_USBCMD_RST    (0x00000002U) /*!< Bit mask for USB_USBCMD_RST. */
#define BS_USB_USBCMD_RST    (1U)          /*!< Bit field size in bits for USB_USBCMD_RST. */

/*! @brief Read current value of the USB_USBCMD_RST field. */
#define BR_USB_USBCMD_RST(x) (HW_USB_USBCMD(x).B.RST)

/*! @brief Format value for bitfield USB_USBCMD_RST. */
#define BF_USB_USBCMD_RST(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBCMD_RST) & BM_USB_USBCMD_RST)

/*! @brief Set the RST field to a new value. */
#define BW_USB_USBCMD_RST(x, v) (HW_USB_USBCMD_WR(x, (HW_USB_USBCMD_RD(x) & ~BM_USB_USBCMD_RST) | BF_USB_USBCMD_RST(v)))
/*@}*/

/*!
 * @name Register USB_USBCMD, field FS_1[3:2] (RW)
 *
 * See description at bit 15
 */
/*@{*/
#define BP_USB_USBCMD_FS_1   (2U)          /*!< Bit position for USB_USBCMD_FS_1. */
#define BM_USB_USBCMD_FS_1   (0x0000000CU) /*!< Bit mask for USB_USBCMD_FS_1. */
#define BS_USB_USBCMD_FS_1   (2U)          /*!< Bit field size in bits for USB_USBCMD_FS_1. */

/*! @brief Read current value of the USB_USBCMD_FS_1 field. */
#define BR_USB_USBCMD_FS_1(x) (HW_USB_USBCMD(x).B.FS_1)

/*! @brief Format value for bitfield USB_USBCMD_FS_1. */
#define BF_USB_USBCMD_FS_1(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBCMD_FS_1) & BM_USB_USBCMD_FS_1)

/*! @brief Set the FS_1 field to a new value. */
#define BW_USB_USBCMD_FS_1(x, v) (HW_USB_USBCMD_WR(x, (HW_USB_USBCMD_RD(x) & ~BM_USB_USBCMD_FS_1) | BF_USB_USBCMD_FS_1(v)))
/*@}*/

/*!
 * @name Register USB_USBCMD, field PSE[4] (RW)
 *
 * Periodic Schedule Enable- Read/Write. Default 0b. This bit controls whether
 * the host controller skips processing the Periodic Schedule. Only the host
 * controller uses this bit. Values Meaning
 *
 * Values:
 * - 0 - Do not process the Periodic Schedule
 * - 1 - Use the PERIODICLISTBASE register to access the Periodic Schedule.
 */
/*@{*/
#define BP_USB_USBCMD_PSE    (4U)          /*!< Bit position for USB_USBCMD_PSE. */
#define BM_USB_USBCMD_PSE    (0x00000010U) /*!< Bit mask for USB_USBCMD_PSE. */
#define BS_USB_USBCMD_PSE    (1U)          /*!< Bit field size in bits for USB_USBCMD_PSE. */

/*! @brief Read current value of the USB_USBCMD_PSE field. */
#define BR_USB_USBCMD_PSE(x) (HW_USB_USBCMD(x).B.PSE)

/*! @brief Format value for bitfield USB_USBCMD_PSE. */
#define BF_USB_USBCMD_PSE(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBCMD_PSE) & BM_USB_USBCMD_PSE)

/*! @brief Set the PSE field to a new value. */
#define BW_USB_USBCMD_PSE(x, v) (HW_USB_USBCMD_WR(x, (HW_USB_USBCMD_RD(x) & ~BM_USB_USBCMD_PSE) | BF_USB_USBCMD_PSE(v)))
/*@}*/

/*!
 * @name Register USB_USBCMD, field ASE[5] (RW)
 *
 * Asynchronous Schedule Enable - Read/Write. Default 0b. This bit controls
 * whether the host controller skips processing the Asynchronous Schedule. Only the
 * host controller uses this bit. Values Meaning
 *
 * Values:
 * - 0 - Do not process the Asynchronous Schedule.
 * - 1 - Use the ASYNCLISTADDR register to access the Asynchronous Schedule.
 */
/*@{*/
#define BP_USB_USBCMD_ASE    (5U)          /*!< Bit position for USB_USBCMD_ASE. */
#define BM_USB_USBCMD_ASE    (0x00000020U) /*!< Bit mask for USB_USBCMD_ASE. */
#define BS_USB_USBCMD_ASE    (1U)          /*!< Bit field size in bits for USB_USBCMD_ASE. */

/*! @brief Read current value of the USB_USBCMD_ASE field. */
#define BR_USB_USBCMD_ASE(x) (HW_USB_USBCMD(x).B.ASE)

/*! @brief Format value for bitfield USB_USBCMD_ASE. */
#define BF_USB_USBCMD_ASE(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBCMD_ASE) & BM_USB_USBCMD_ASE)

/*! @brief Set the ASE field to a new value. */
#define BW_USB_USBCMD_ASE(x, v) (HW_USB_USBCMD_WR(x, (HW_USB_USBCMD_RD(x) & ~BM_USB_USBCMD_ASE) | BF_USB_USBCMD_ASE(v)))
/*@}*/

/*!
 * @name Register USB_USBCMD, field IAA[6] (RW)
 *
 * Interrupt on Async Advance Doorbell - Read/Write. This bit is used as a
 * doorbell by software to tell the host controller to issue an interrupt the next
 * time it advances asynchronous schedule. Software must write a 1 to this bit to
 * ring the doorbell. When the host controller has evicted all appropriate cached
 * schedule states, it sets the Interrupt on Async Advance status bit in the
 * USBSTS register. If the Interrupt on Sync Advance Enable bit in the USBINTR
 * register is one, then the host controller will assert an interrupt at the next
 * interrupt threshold. The host controller sets this bit to zero after it has set the
 * Interrupt on Sync Advance status bit in the USBSTS register to one. Software
 * should not write a one to this bit when the asynchronous schedule is inactive.
 * Doing so will yield undefined results. This bit is only used in host mode.
 * Writing a one to this bit when device mode is selected will have undefined
 * results.
 */
/*@{*/
#define BP_USB_USBCMD_IAA    (6U)          /*!< Bit position for USB_USBCMD_IAA. */
#define BM_USB_USBCMD_IAA    (0x00000040U) /*!< Bit mask for USB_USBCMD_IAA. */
#define BS_USB_USBCMD_IAA    (1U)          /*!< Bit field size in bits for USB_USBCMD_IAA. */

/*! @brief Read current value of the USB_USBCMD_IAA field. */
#define BR_USB_USBCMD_IAA(x) (HW_USB_USBCMD(x).B.IAA)

/*! @brief Format value for bitfield USB_USBCMD_IAA. */
#define BF_USB_USBCMD_IAA(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBCMD_IAA) & BM_USB_USBCMD_IAA)

/*! @brief Set the IAA field to a new value. */
#define BW_USB_USBCMD_IAA(x, v) (HW_USB_USBCMD_WR(x, (HW_USB_USBCMD_RD(x) & ~BM_USB_USBCMD_IAA) | BF_USB_USBCMD_IAA(v)))
/*@}*/

/*!
 * @name Register USB_USBCMD, field ASP[9:8] (RW)
 *
 * Asynchronous Schedule Park Mode Count - Read/Write. If the Asynchronous Park
 * Capability bit in the HCCPARAMS register is a one, then this field defaults to
 * 3h and is R/W. Otherwise it defaults to zero and is Read-Only. It contains a
 * count of the number of successive transactions the host controller is allowed
 * to execute from a high-speed queue head on the Asynchronous schedule before
 * continuing traversal of the Asynchronous schedule. Valid values are 1h to 3h.
 * Software must not write a zero to this bit when Park Mode Enable is a one as
 * this will result in undefined behavior. This field is set to 3h in all controller
 * core.
 */
/*@{*/
#define BP_USB_USBCMD_ASP    (8U)          /*!< Bit position for USB_USBCMD_ASP. */
#define BM_USB_USBCMD_ASP    (0x00000300U) /*!< Bit mask for USB_USBCMD_ASP. */
#define BS_USB_USBCMD_ASP    (2U)          /*!< Bit field size in bits for USB_USBCMD_ASP. */

/*! @brief Read current value of the USB_USBCMD_ASP field. */
#define BR_USB_USBCMD_ASP(x) (HW_USB_USBCMD(x).B.ASP)

/*! @brief Format value for bitfield USB_USBCMD_ASP. */
#define BF_USB_USBCMD_ASP(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBCMD_ASP) & BM_USB_USBCMD_ASP)

/*! @brief Set the ASP field to a new value. */
#define BW_USB_USBCMD_ASP(x, v) (HW_USB_USBCMD_WR(x, (HW_USB_USBCMD_RD(x) & ~BM_USB_USBCMD_ASP) | BF_USB_USBCMD_ASP(v)))
/*@}*/

/*!
 * @name Register USB_USBCMD, field ASPE[11] (RW)
 *
 * Asynchronous Schedule Park Mode Enable - Read/Write. If the Asynchronous Park
 * Capability bit in the HCCPARAMS register is a one, then this bit defaults to
 * a 1h and is R/W. Otherwise the bit must be a zero and is RO. Software uses
 * this bit to enable or disable Park mode. When this bit is one, Park mode is
 * enabled. When this bit is a zero, Park mode is disabled. ASPE bit reset value: '0b'
 * for OTG controller core, '1b' for Host-only controller core.
 */
/*@{*/
#define BP_USB_USBCMD_ASPE   (11U)         /*!< Bit position for USB_USBCMD_ASPE. */
#define BM_USB_USBCMD_ASPE   (0x00000800U) /*!< Bit mask for USB_USBCMD_ASPE. */
#define BS_USB_USBCMD_ASPE   (1U)          /*!< Bit field size in bits for USB_USBCMD_ASPE. */

/*! @brief Read current value of the USB_USBCMD_ASPE field. */
#define BR_USB_USBCMD_ASPE(x) (HW_USB_USBCMD(x).B.ASPE)

/*! @brief Format value for bitfield USB_USBCMD_ASPE. */
#define BF_USB_USBCMD_ASPE(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBCMD_ASPE) & BM_USB_USBCMD_ASPE)

/*! @brief Set the ASPE field to a new value. */
#define BW_USB_USBCMD_ASPE(x, v) (HW_USB_USBCMD_WR(x, (HW_USB_USBCMD_RD(x) & ~BM_USB_USBCMD_ASPE) | BF_USB_USBCMD_ASPE(v)))
/*@}*/

/*!
 * @name Register USB_USBCMD, field ATDTW[12] (RW)
 *
 * Add dTD TripWire - Read/Write. [device mode only] This bit is used as a
 * semaphore to ensure proper addition of a new dTD to an active (primed) endpoint's
 * linked list. This bit is set and cleared by software. This bit would also be
 * cleared by hardware when state machine is hazard region for which adding a dTD
 * to a primed endpoint may go unrecognized.
 */
/*@{*/
#define BP_USB_USBCMD_ATDTW  (12U)         /*!< Bit position for USB_USBCMD_ATDTW. */
#define BM_USB_USBCMD_ATDTW  (0x00001000U) /*!< Bit mask for USB_USBCMD_ATDTW. */
#define BS_USB_USBCMD_ATDTW  (1U)          /*!< Bit field size in bits for USB_USBCMD_ATDTW. */

/*! @brief Read current value of the USB_USBCMD_ATDTW field. */
#define BR_USB_USBCMD_ATDTW(x) (HW_USB_USBCMD(x).B.ATDTW)

/*! @brief Format value for bitfield USB_USBCMD_ATDTW. */
#define BF_USB_USBCMD_ATDTW(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBCMD_ATDTW) & BM_USB_USBCMD_ATDTW)

/*! @brief Set the ATDTW field to a new value. */
#define BW_USB_USBCMD_ATDTW(x, v) (HW_USB_USBCMD_WR(x, (HW_USB_USBCMD_RD(x) & ~BM_USB_USBCMD_ATDTW) | BF_USB_USBCMD_ATDTW(v)))
/*@}*/

/*!
 * @name Register USB_USBCMD, field SUTW[13] (RW)
 *
 * Setup TripWire - Read/Write. [device mode only] This bit is used as a
 * semaphore to ensure that the setup data payload of 8 bytes is extracted from a QH by
 * the DCD without being corrupted. If the setup lockout mode is off (SLOM bit in
 * USB core register n_USBMODE, see USBMODEUSB Device Mode ) then there is a
 * hazard when new setup data arrives while the DCD is copying the setup data
 * payload from the QH for a previous setup packet. This bit is set and cleared by
 * software. This bit would also be cleared by hardware when a hazard detected.
 */
/*@{*/
#define BP_USB_USBCMD_SUTW   (13U)         /*!< Bit position for USB_USBCMD_SUTW. */
#define BM_USB_USBCMD_SUTW   (0x00002000U) /*!< Bit mask for USB_USBCMD_SUTW. */
#define BS_USB_USBCMD_SUTW   (1U)          /*!< Bit field size in bits for USB_USBCMD_SUTW. */

/*! @brief Read current value of the USB_USBCMD_SUTW field. */
#define BR_USB_USBCMD_SUTW(x) (HW_USB_USBCMD(x).B.SUTW)

/*! @brief Format value for bitfield USB_USBCMD_SUTW. */
#define BF_USB_USBCMD_SUTW(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBCMD_SUTW) & BM_USB_USBCMD_SUTW)

/*! @brief Set the SUTW field to a new value. */
#define BW_USB_USBCMD_SUTW(x, v) (HW_USB_USBCMD_WR(x, (HW_USB_USBCMD_RD(x) & ~BM_USB_USBCMD_SUTW) | BF_USB_USBCMD_SUTW(v)))
/*@}*/

/*!
 * @name Register USB_USBCMD, field FS_2[15] (RW)
 *
 * See also bits 3-2 Frame List Size - (Read/Write or Read Only). [host mode
 * only] This field is Read/Write only if Programmable Frame List Flag in the
 * HCCPARAMS registers is set to one. This field specifies the size of the frame list
 * that controls which bits in the Frame Index Register should be used for the
 * Frame List Current index. This field is made up from USBCMD bits 15, 3 and 2.
 * Value Meaning
 *
 * Values:
 * - 000 - 1024 elements (4096 bytes) Default value
 * - 001 - 512 elements (2048 bytes)
 */
/*@{*/
#define BP_USB_USBCMD_FS_2   (15U)         /*!< Bit position for USB_USBCMD_FS_2. */
#define BM_USB_USBCMD_FS_2   (0x00008000U) /*!< Bit mask for USB_USBCMD_FS_2. */
#define BS_USB_USBCMD_FS_2   (1U)          /*!< Bit field size in bits for USB_USBCMD_FS_2. */

/*! @brief Read current value of the USB_USBCMD_FS_2 field. */
#define BR_USB_USBCMD_FS_2(x) (HW_USB_USBCMD(x).B.FS_2)

/*! @brief Format value for bitfield USB_USBCMD_FS_2. */
#define BF_USB_USBCMD_FS_2(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBCMD_FS_2) & BM_USB_USBCMD_FS_2)

/*! @brief Set the FS_2 field to a new value. */
#define BW_USB_USBCMD_FS_2(x, v) (HW_USB_USBCMD_WR(x, (HW_USB_USBCMD_RD(x) & ~BM_USB_USBCMD_FS_2) | BF_USB_USBCMD_FS_2(v)))
/*@}*/

/*!
 * @name Register USB_USBCMD, field ITC[23:16] (RW)
 *
 * Interrupt Threshold Control -Read/Write. The system software uses this field
 * to set the maximum rate at which the host/device controller will issue
 * interrupts. ITC contains the maximum interrupt interval measured in micro-frames.
 * Valid values are shown below. Value Maximum Interrupt Interval
 *
 * Values:
 * - 0 - Immediate (no threshold)
 * - 1 - 1 micro-frame
 * - 10 - 2 micro-frames
 * - 100 - 4 micro-frames
 * - 1000 - 8 micro-frames
 * - 10000 - 16 micro-frames
 * - 100000 - 32 micro-frames
 * - 1000000 - 64 micro-frames
 */
/*@{*/
#define BP_USB_USBCMD_ITC    (16U)         /*!< Bit position for USB_USBCMD_ITC. */
#define BM_USB_USBCMD_ITC    (0x00FF0000U) /*!< Bit mask for USB_USBCMD_ITC. */
#define BS_USB_USBCMD_ITC    (8U)          /*!< Bit field size in bits for USB_USBCMD_ITC. */

/*! @brief Read current value of the USB_USBCMD_ITC field. */
#define BR_USB_USBCMD_ITC(x) (HW_USB_USBCMD(x).B.ITC)

/*! @brief Format value for bitfield USB_USBCMD_ITC. */
#define BF_USB_USBCMD_ITC(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBCMD_ITC) & BM_USB_USBCMD_ITC)

/*! @brief Set the ITC field to a new value. */
#define BW_USB_USBCMD_ITC(x, v) (HW_USB_USBCMD_WR(x, (HW_USB_USBCMD_RD(x) & ~BM_USB_USBCMD_ITC) | BF_USB_USBCMD_ITC(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_USBSTS - USB Status Register
 ******************************************************************************/

/*!
 * @brief HW_USB_USBSTS - USB Status Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register indicates various states of the Host/Device Controller and any
 * pending interrupts. This register does not indicate status resulting from a
 * transaction on the serial bus.
 */
typedef union _hw_usb_usbsts
{
    uint32_t U;
    struct _hw_usb_usbsts_bitfields
    {
        uint32_t UI : 1;               /*!< [0]  */
        uint32_t UEI : 1;              /*!< [1]  */
        uint32_t PCI : 1;              /*!< [2]  */
        uint32_t FRI : 1;              /*!< [3]  */
        uint32_t SEI : 1;              /*!< [4]  */
        uint32_t AAI : 1;              /*!< [5]  */
        uint32_t URI : 1;              /*!< [6]  */
        uint32_t SRI : 1;              /*!< [7]  */
        uint32_t SLI : 1;              /*!< [8]  */
        uint32_t RESERVED0 : 1;        /*!< [9]  */
        uint32_t ULPII : 1;            /*!< [10]  */
        uint32_t RESERVED1 : 1;        /*!< [11]  */
        uint32_t HCH : 1;              /*!< [12]  */
        uint32_t RCL : 1;              /*!< [13]  */
        uint32_t PS : 1;               /*!< [14]  */
        uint32_t AS : 1;               /*!< [15]  */
        uint32_t NAKI : 1;             /*!< [16]  */
        uint32_t RESERVED2 : 7;        /*!< [23:17]  */
        uint32_t TI0 : 1;              /*!< [24]  */
        uint32_t TI1 : 1;              /*!< [25]  */
        uint32_t RESERVED3 : 6;        /*!< [31:26]  */
    } B;
} hw_usb_usbsts_t;

/*!
 * @name Constants and macros for entire USB_USBSTS register
 */
/*@{*/
#define HW_USB_USBSTS_ADDR(x)    ((uintptr_t)(x) + 0x144U)

#define HW_USB_USBSTS(x)         (*(__IO hw_usb_usbsts_t *) HW_USB_USBSTS_ADDR(x))
#define HW_USB_USBSTS_RD(x)      (HW_USB_USBSTS(x).U)
#define HW_USB_USBSTS_WR(x, v)   (HW_USB_USBSTS(x).U = (v))
#define HW_USB_USBSTS_SET(x, v)  (HW_USB_USBSTS_WR(x, HW_USB_USBSTS_RD(x) |  (v)))
#define HW_USB_USBSTS_CLR(x, v)  (HW_USB_USBSTS_WR(x, HW_USB_USBSTS_RD(x) & ~(v)))
#define HW_USB_USBSTS_TOG(x, v)  (HW_USB_USBSTS_WR(x, HW_USB_USBSTS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_USBSTS bitfields
 */

/*!
 * @name Register USB_USBSTS, field UI[0] (RW)
 *
 * USB Interrupt (USBINT) - R/WC. This bit is set by the Host/Device Controller
 * when the cause of an interrupt is a completion of a USB transaction where the
 * Transfer Descriptor (TD) has an interrupt on complete (IOC) bit set. This bit
 * is also set by the Host/Device Controller when a short packet is detected. A
 * short packet is when the actual number of bytes received was less than the
 * expected number of bytes.
 */
/*@{*/
#define BP_USB_USBSTS_UI     (0U)          /*!< Bit position for USB_USBSTS_UI. */
#define BM_USB_USBSTS_UI     (0x00000001U) /*!< Bit mask for USB_USBSTS_UI. */
#define BS_USB_USBSTS_UI     (1U)          /*!< Bit field size in bits for USB_USBSTS_UI. */

/*! @brief Read current value of the USB_USBSTS_UI field. */
#define BR_USB_USBSTS_UI(x)  (HW_USB_USBSTS(x).B.UI)

/*! @brief Format value for bitfield USB_USBSTS_UI. */
#define BF_USB_USBSTS_UI(v)  ((uint32_t)((uint32_t)(v) << BP_USB_USBSTS_UI) & BM_USB_USBSTS_UI)

/*! @brief Set the UI field to a new value. */
#define BW_USB_USBSTS_UI(x, v) (HW_USB_USBSTS_WR(x, (HW_USB_USBSTS_RD(x) & ~BM_USB_USBSTS_UI) | BF_USB_USBSTS_UI(v)))
/*@}*/

/*!
 * @name Register USB_USBSTS, field UEI[1] (RW)
 *
 * USB Error Interrupt (USBERRINT) - R/WC. When completion of a USB transaction
 * results in an error condition, this bit is set by the Host/Device Controller.
 * This bit is set along with the USBINT bit, if the TD on which the error
 * interrupt occurred also had its interrupt on complete (IOC) bit set. The device
 * controller detects resume signaling only.
 */
/*@{*/
#define BP_USB_USBSTS_UEI    (1U)          /*!< Bit position for USB_USBSTS_UEI. */
#define BM_USB_USBSTS_UEI    (0x00000002U) /*!< Bit mask for USB_USBSTS_UEI. */
#define BS_USB_USBSTS_UEI    (1U)          /*!< Bit field size in bits for USB_USBSTS_UEI. */

/*! @brief Read current value of the USB_USBSTS_UEI field. */
#define BR_USB_USBSTS_UEI(x) (HW_USB_USBSTS(x).B.UEI)

/*! @brief Format value for bitfield USB_USBSTS_UEI. */
#define BF_USB_USBSTS_UEI(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBSTS_UEI) & BM_USB_USBSTS_UEI)

/*! @brief Set the UEI field to a new value. */
#define BW_USB_USBSTS_UEI(x, v) (HW_USB_USBSTS_WR(x, (HW_USB_USBSTS_RD(x) & ~BM_USB_USBSTS_UEI) | BF_USB_USBSTS_UEI(v)))
/*@}*/

/*!
 * @name Register USB_USBSTS, field PCI[2] (RW)
 *
 * Port Change Detect - R/WC. The Host Controller sets this bit to a one when on
 * any port a Connect Status occurs, a Port Enable/Disable Change occurs, or the
 * Force Port Resume bit is set as the result of a J-K transition on the
 * suspended port. The Device Controller sets this bit to a one when the port controller
 * enters the full or high-speed operational state. When the port controller
 * exits the full or high-speed operation states due to Reset or Suspend events, the
 * notification mechanisms are the USB Reset Received bit and the DCSuspend bits
 * respectively.
 */
/*@{*/
#define BP_USB_USBSTS_PCI    (2U)          /*!< Bit position for USB_USBSTS_PCI. */
#define BM_USB_USBSTS_PCI    (0x00000004U) /*!< Bit mask for USB_USBSTS_PCI. */
#define BS_USB_USBSTS_PCI    (1U)          /*!< Bit field size in bits for USB_USBSTS_PCI. */

/*! @brief Read current value of the USB_USBSTS_PCI field. */
#define BR_USB_USBSTS_PCI(x) (HW_USB_USBSTS(x).B.PCI)

/*! @brief Format value for bitfield USB_USBSTS_PCI. */
#define BF_USB_USBSTS_PCI(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBSTS_PCI) & BM_USB_USBSTS_PCI)

/*! @brief Set the PCI field to a new value. */
#define BW_USB_USBSTS_PCI(x, v) (HW_USB_USBSTS_WR(x, (HW_USB_USBSTS_RD(x) & ~BM_USB_USBSTS_PCI) | BF_USB_USBSTS_PCI(v)))
/*@}*/

/*!
 * @name Register USB_USBSTS, field FRI[3] (RW)
 *
 * Frame List Rollover - R/WC. The Host Controller sets this bit to a one when
 * the Frame List Index rolls over from its maximum value to zero. The exact value
 * at which the rollover occurs depends on the frame list size. For example. If
 * the frame list size (as programmed in the Frame List Size field of the
 * USB_n_USBCMD register) is 1024, the Frame Index Register rolls over every time
 * FRINDEX [13] toggles. Similarly, if the size is 512, the Host Controller sets this
 * bit to a one every time FHINDEX [12] toggles. Only used in host operation mode.
 */
/*@{*/
#define BP_USB_USBSTS_FRI    (3U)          /*!< Bit position for USB_USBSTS_FRI. */
#define BM_USB_USBSTS_FRI    (0x00000008U) /*!< Bit mask for USB_USBSTS_FRI. */
#define BS_USB_USBSTS_FRI    (1U)          /*!< Bit field size in bits for USB_USBSTS_FRI. */

/*! @brief Read current value of the USB_USBSTS_FRI field. */
#define BR_USB_USBSTS_FRI(x) (HW_USB_USBSTS(x).B.FRI)

/*! @brief Format value for bitfield USB_USBSTS_FRI. */
#define BF_USB_USBSTS_FRI(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBSTS_FRI) & BM_USB_USBSTS_FRI)

/*! @brief Set the FRI field to a new value. */
#define BW_USB_USBSTS_FRI(x, v) (HW_USB_USBSTS_WR(x, (HW_USB_USBSTS_RD(x) & ~BM_USB_USBSTS_FRI) | BF_USB_USBSTS_FRI(v)))
/*@}*/

/*!
 * @name Register USB_USBSTS, field SEI[4] (RW)
 *
 * System Error- R/WC. This bit is will be set to '1b' when an Error response is
 * seen to a read on the system interface.
 */
/*@{*/
#define BP_USB_USBSTS_SEI    (4U)          /*!< Bit position for USB_USBSTS_SEI. */
#define BM_USB_USBSTS_SEI    (0x00000010U) /*!< Bit mask for USB_USBSTS_SEI. */
#define BS_USB_USBSTS_SEI    (1U)          /*!< Bit field size in bits for USB_USBSTS_SEI. */

/*! @brief Read current value of the USB_USBSTS_SEI field. */
#define BR_USB_USBSTS_SEI(x) (HW_USB_USBSTS(x).B.SEI)

/*! @brief Format value for bitfield USB_USBSTS_SEI. */
#define BF_USB_USBSTS_SEI(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBSTS_SEI) & BM_USB_USBSTS_SEI)

/*! @brief Set the SEI field to a new value. */
#define BW_USB_USBSTS_SEI(x, v) (HW_USB_USBSTS_WR(x, (HW_USB_USBSTS_RD(x) & ~BM_USB_USBSTS_SEI) | BF_USB_USBSTS_SEI(v)))
/*@}*/

/*!
 * @name Register USB_USBSTS, field AAI[5] (RW)
 *
 * Interrupt on Async Advance - R/WC. System software can force the host
 * controller to issue an interrupt the next time the host controller advances the
 * asynchronous schedule by writing a one to the Interrupt on Async Advance Doorbell
 * bit in the n_USBCMD register. This status bit indicates the assertion of that
 * interrupt source. Only used in host operation mode.
 */
/*@{*/
#define BP_USB_USBSTS_AAI    (5U)          /*!< Bit position for USB_USBSTS_AAI. */
#define BM_USB_USBSTS_AAI    (0x00000020U) /*!< Bit mask for USB_USBSTS_AAI. */
#define BS_USB_USBSTS_AAI    (1U)          /*!< Bit field size in bits for USB_USBSTS_AAI. */

/*! @brief Read current value of the USB_USBSTS_AAI field. */
#define BR_USB_USBSTS_AAI(x) (HW_USB_USBSTS(x).B.AAI)

/*! @brief Format value for bitfield USB_USBSTS_AAI. */
#define BF_USB_USBSTS_AAI(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBSTS_AAI) & BM_USB_USBSTS_AAI)

/*! @brief Set the AAI field to a new value. */
#define BW_USB_USBSTS_AAI(x, v) (HW_USB_USBSTS_WR(x, (HW_USB_USBSTS_RD(x) & ~BM_USB_USBSTS_AAI) | BF_USB_USBSTS_AAI(v)))
/*@}*/

/*!
 * @name Register USB_USBSTS, field URI[6] (RW)
 *
 * USB Reset Received - R/WC. When the device controller detects a USB Reset and
 * enters the default state, this bit will be set to a one. Software can write a
 * 1 to this bit to clear the USB Reset Received status bit. Only used in device
 * operation mode.
 */
/*@{*/
#define BP_USB_USBSTS_URI    (6U)          /*!< Bit position for USB_USBSTS_URI. */
#define BM_USB_USBSTS_URI    (0x00000040U) /*!< Bit mask for USB_USBSTS_URI. */
#define BS_USB_USBSTS_URI    (1U)          /*!< Bit field size in bits for USB_USBSTS_URI. */

/*! @brief Read current value of the USB_USBSTS_URI field. */
#define BR_USB_USBSTS_URI(x) (HW_USB_USBSTS(x).B.URI)

/*! @brief Format value for bitfield USB_USBSTS_URI. */
#define BF_USB_USBSTS_URI(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBSTS_URI) & BM_USB_USBSTS_URI)

/*! @brief Set the URI field to a new value. */
#define BW_USB_USBSTS_URI(x, v) (HW_USB_USBSTS_WR(x, (HW_USB_USBSTS_RD(x) & ~BM_USB_USBSTS_URI) | BF_USB_USBSTS_URI(v)))
/*@}*/

/*!
 * @name Register USB_USBSTS, field SRI[7] (RW)
 *
 * SOF Received - R/WC. When the device controller detects a Start Of (micro)
 * Frame, this bit will be set to a one. When a SOF is extremely late, the device
 * controller will automatically set this bit to indicate that an SOF was
 * expected. Therefore, this bit will be set roughly every 1ms in device FS mode and
 * every 125ms in HS mode and will be synchronized to the actual SOF that is
 * received. Because the device controller is initialized to FS before connect, this bit
 * will be set at an interval of 1ms during the prelude to connect and chirp. In
 * host mode, this bit will be set every 125us and can be used by host controller
 * driver as a time base. Software writes a 1 to this bit to clear it.
 */
/*@{*/
#define BP_USB_USBSTS_SRI    (7U)          /*!< Bit position for USB_USBSTS_SRI. */
#define BM_USB_USBSTS_SRI    (0x00000080U) /*!< Bit mask for USB_USBSTS_SRI. */
#define BS_USB_USBSTS_SRI    (1U)          /*!< Bit field size in bits for USB_USBSTS_SRI. */

/*! @brief Read current value of the USB_USBSTS_SRI field. */
#define BR_USB_USBSTS_SRI(x) (HW_USB_USBSTS(x).B.SRI)

/*! @brief Format value for bitfield USB_USBSTS_SRI. */
#define BF_USB_USBSTS_SRI(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBSTS_SRI) & BM_USB_USBSTS_SRI)

/*! @brief Set the SRI field to a new value. */
#define BW_USB_USBSTS_SRI(x, v) (HW_USB_USBSTS_WR(x, (HW_USB_USBSTS_RD(x) & ~BM_USB_USBSTS_SRI) | BF_USB_USBSTS_SRI(v)))
/*@}*/

/*!
 * @name Register USB_USBSTS, field SLI[8] (RW)
 *
 * DCSuspend - R/WC. When a controller enters a suspend state from an active
 * state, this bit will be set to a one. The device controller clears the bit upon
 * exiting from a suspend state. Only used in device operation mode.
 */
/*@{*/
#define BP_USB_USBSTS_SLI    (8U)          /*!< Bit position for USB_USBSTS_SLI. */
#define BM_USB_USBSTS_SLI    (0x00000100U) /*!< Bit mask for USB_USBSTS_SLI. */
#define BS_USB_USBSTS_SLI    (1U)          /*!< Bit field size in bits for USB_USBSTS_SLI. */

/*! @brief Read current value of the USB_USBSTS_SLI field. */
#define BR_USB_USBSTS_SLI(x) (HW_USB_USBSTS(x).B.SLI)

/*! @brief Format value for bitfield USB_USBSTS_SLI. */
#define BF_USB_USBSTS_SLI(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBSTS_SLI) & BM_USB_USBSTS_SLI)

/*! @brief Set the SLI field to a new value. */
#define BW_USB_USBSTS_SLI(x, v) (HW_USB_USBSTS_WR(x, (HW_USB_USBSTS_RD(x) & ~BM_USB_USBSTS_SLI) | BF_USB_USBSTS_SLI(v)))
/*@}*/

/*!
 * @name Register USB_USBSTS, field ULPII[10] (RW)
 *
 * ULPI Interrupt - R/WC. This bit will be set '1b' by hardware when there is an
 * event completion in ULPI viewport. This bit is usable only if the controller
 * support UPLI interface mode.
 */
/*@{*/
#define BP_USB_USBSTS_ULPII  (10U)         /*!< Bit position for USB_USBSTS_ULPII. */
#define BM_USB_USBSTS_ULPII  (0x00000400U) /*!< Bit mask for USB_USBSTS_ULPII. */
#define BS_USB_USBSTS_ULPII  (1U)          /*!< Bit field size in bits for USB_USBSTS_ULPII. */

/*! @brief Read current value of the USB_USBSTS_ULPII field. */
#define BR_USB_USBSTS_ULPII(x) (HW_USB_USBSTS(x).B.ULPII)

/*! @brief Format value for bitfield USB_USBSTS_ULPII. */
#define BF_USB_USBSTS_ULPII(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBSTS_ULPII) & BM_USB_USBSTS_ULPII)

/*! @brief Set the ULPII field to a new value. */
#define BW_USB_USBSTS_ULPII(x, v) (HW_USB_USBSTS_WR(x, (HW_USB_USBSTS_RD(x) & ~BM_USB_USBSTS_ULPII) | BF_USB_USBSTS_ULPII(v)))
/*@}*/

/*!
 * @name Register USB_USBSTS, field HCH[12] (RW)
 *
 * HCHaIted - Read Only. This bit is a zero whenever the Run/Stop bit is a one.
 * The Controller sets this bit to one after it has stopped executing because of
 * the Run/Stop bit being set to 0, either by software or by the Controller
 * hardware (for example, an internal error). Only used in the host operation mode.
 * Default value is '0b' for OTG core, and '1b' for Host1/Host2/Host3 core. This is
 * because OTG core is not operating as host in default. Please see CM bit in
 * USB_n_USBMODE register. HCH bit reset value: '0b' for OTG controller core, '1b'
 * for Host-only controller core.
 */
/*@{*/
#define BP_USB_USBSTS_HCH    (12U)         /*!< Bit position for USB_USBSTS_HCH. */
#define BM_USB_USBSTS_HCH    (0x00001000U) /*!< Bit mask for USB_USBSTS_HCH. */
#define BS_USB_USBSTS_HCH    (1U)          /*!< Bit field size in bits for USB_USBSTS_HCH. */

/*! @brief Read current value of the USB_USBSTS_HCH field. */
#define BR_USB_USBSTS_HCH(x) (HW_USB_USBSTS(x).B.HCH)

/*! @brief Format value for bitfield USB_USBSTS_HCH. */
#define BF_USB_USBSTS_HCH(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBSTS_HCH) & BM_USB_USBSTS_HCH)

/*! @brief Set the HCH field to a new value. */
#define BW_USB_USBSTS_HCH(x, v) (HW_USB_USBSTS_WR(x, (HW_USB_USBSTS_RD(x) & ~BM_USB_USBSTS_HCH) | BF_USB_USBSTS_HCH(v)))
/*@}*/

/*!
 * @name Register USB_USBSTS, field RCL[13] (RW)
 *
 * Reclamation - Read Only. This is a read-only status bit used to detect an
 * empty asynchronous schedule. Only used in the host operation mode.
 */
/*@{*/
#define BP_USB_USBSTS_RCL    (13U)         /*!< Bit position for USB_USBSTS_RCL. */
#define BM_USB_USBSTS_RCL    (0x00002000U) /*!< Bit mask for USB_USBSTS_RCL. */
#define BS_USB_USBSTS_RCL    (1U)          /*!< Bit field size in bits for USB_USBSTS_RCL. */

/*! @brief Read current value of the USB_USBSTS_RCL field. */
#define BR_USB_USBSTS_RCL(x) (HW_USB_USBSTS(x).B.RCL)

/*! @brief Format value for bitfield USB_USBSTS_RCL. */
#define BF_USB_USBSTS_RCL(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBSTS_RCL) & BM_USB_USBSTS_RCL)

/*! @brief Set the RCL field to a new value. */
#define BW_USB_USBSTS_RCL(x, v) (HW_USB_USBSTS_WR(x, (HW_USB_USBSTS_RD(x) & ~BM_USB_USBSTS_RCL) | BF_USB_USBSTS_RCL(v)))
/*@}*/

/*!
 * @name Register USB_USBSTS, field PS[14] (RW)
 *
 * Periodic Schedule Status - Read Only. This bit reports the current real
 * status of the Periodic Schedule. When set to zero the periodic schedule is
 * disabled, and if set to one the status is enabled. The Host Controller is not required
 * to immediately disable or enable the Periodic Schedule when software
 * transitions the Periodic Schedule Enable bit in the USBCMD register. When this bit and
 * the Periodic Schedule Enable bit are the same value, the Periodic Schedule is
 * either enabled (1) or disabled (0). Only used in the host operation mode.
 */
/*@{*/
#define BP_USB_USBSTS_PS     (14U)         /*!< Bit position for USB_USBSTS_PS. */
#define BM_USB_USBSTS_PS     (0x00004000U) /*!< Bit mask for USB_USBSTS_PS. */
#define BS_USB_USBSTS_PS     (1U)          /*!< Bit field size in bits for USB_USBSTS_PS. */

/*! @brief Read current value of the USB_USBSTS_PS field. */
#define BR_USB_USBSTS_PS(x)  (HW_USB_USBSTS(x).B.PS)

/*! @brief Format value for bitfield USB_USBSTS_PS. */
#define BF_USB_USBSTS_PS(v)  ((uint32_t)((uint32_t)(v) << BP_USB_USBSTS_PS) & BM_USB_USBSTS_PS)

/*! @brief Set the PS field to a new value. */
#define BW_USB_USBSTS_PS(x, v) (HW_USB_USBSTS_WR(x, (HW_USB_USBSTS_RD(x) & ~BM_USB_USBSTS_PS) | BF_USB_USBSTS_PS(v)))
/*@}*/

/*!
 * @name Register USB_USBSTS, field AS[15] (RW)
 *
 * Asynchronous Schedule Status - Read Only. This bit reports the current real
 * status of the Asynchronous Schedule. When set to zero the asynchronous schedule
 * status is disabled and if set to one the status is enabled. The Host
 * Controller is not required to immediately disable or enable the Asynchronous Schedule
 * when software transitions the Asynchronous Schedule Enable bit in the USBCMD
 * register. When this bit and the Asynchronous Schedule Enable bit are the same
 * value, the Asynchronous Schedule is either enabled (1) or disabled (0). Only
 * used in the host operation mode.
 */
/*@{*/
#define BP_USB_USBSTS_AS     (15U)         /*!< Bit position for USB_USBSTS_AS. */
#define BM_USB_USBSTS_AS     (0x00008000U) /*!< Bit mask for USB_USBSTS_AS. */
#define BS_USB_USBSTS_AS     (1U)          /*!< Bit field size in bits for USB_USBSTS_AS. */

/*! @brief Read current value of the USB_USBSTS_AS field. */
#define BR_USB_USBSTS_AS(x)  (HW_USB_USBSTS(x).B.AS)

/*! @brief Format value for bitfield USB_USBSTS_AS. */
#define BF_USB_USBSTS_AS(v)  ((uint32_t)((uint32_t)(v) << BP_USB_USBSTS_AS) & BM_USB_USBSTS_AS)

/*! @brief Set the AS field to a new value. */
#define BW_USB_USBSTS_AS(x, v) (HW_USB_USBSTS_WR(x, (HW_USB_USBSTS_RD(x) & ~BM_USB_USBSTS_AS) | BF_USB_USBSTS_AS(v)))
/*@}*/

/*!
 * @name Register USB_USBSTS, field NAKI[16] (RO)
 *
 * NAK Interrupt Bit--RO. This bit is set by hardware when for a particular
 * endpoint both the TX/RX Endpoint NAK bit and corresponding TX/RX Endpoint NAK
 * Enable bit are set. This bit is automatically cleared by hardware when all Enabled
 * TX/RX Endpoint NAK bits are cleared.
 */
/*@{*/
#define BP_USB_USBSTS_NAKI   (16U)         /*!< Bit position for USB_USBSTS_NAKI. */
#define BM_USB_USBSTS_NAKI   (0x00010000U) /*!< Bit mask for USB_USBSTS_NAKI. */
#define BS_USB_USBSTS_NAKI   (1U)          /*!< Bit field size in bits for USB_USBSTS_NAKI. */

/*! @brief Read current value of the USB_USBSTS_NAKI field. */
#define BR_USB_USBSTS_NAKI(x) (HW_USB_USBSTS(x).B.NAKI)
/*@}*/

/*!
 * @name Register USB_USBSTS, field TI0[24] (RW)
 *
 * General Purpose Timer Interrupt 0(GPTINT0)--R/WC. This bit is set when the
 * counter in the GPTIMER0CTRL register transitions to zero, writing a one to this
 * bit clears it.
 */
/*@{*/
#define BP_USB_USBSTS_TI0    (24U)         /*!< Bit position for USB_USBSTS_TI0. */
#define BM_USB_USBSTS_TI0    (0x01000000U) /*!< Bit mask for USB_USBSTS_TI0. */
#define BS_USB_USBSTS_TI0    (1U)          /*!< Bit field size in bits for USB_USBSTS_TI0. */

/*! @brief Read current value of the USB_USBSTS_TI0 field. */
#define BR_USB_USBSTS_TI0(x) (HW_USB_USBSTS(x).B.TI0)

/*! @brief Format value for bitfield USB_USBSTS_TI0. */
#define BF_USB_USBSTS_TI0(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBSTS_TI0) & BM_USB_USBSTS_TI0)

/*! @brief Set the TI0 field to a new value. */
#define BW_USB_USBSTS_TI0(x, v) (HW_USB_USBSTS_WR(x, (HW_USB_USBSTS_RD(x) & ~BM_USB_USBSTS_TI0) | BF_USB_USBSTS_TI0(v)))
/*@}*/

/*!
 * @name Register USB_USBSTS, field TI1[25] (RW)
 *
 * General Purpose Timer Interrupt 1(GPTINT1)--R/WC. This bit is set when the
 * counter in the GPTIMER1CTRL register transitions to zero, writing a one to this
 * bit will clear it.
 */
/*@{*/
#define BP_USB_USBSTS_TI1    (25U)         /*!< Bit position for USB_USBSTS_TI1. */
#define BM_USB_USBSTS_TI1    (0x02000000U) /*!< Bit mask for USB_USBSTS_TI1. */
#define BS_USB_USBSTS_TI1    (1U)          /*!< Bit field size in bits for USB_USBSTS_TI1. */

/*! @brief Read current value of the USB_USBSTS_TI1 field. */
#define BR_USB_USBSTS_TI1(x) (HW_USB_USBSTS(x).B.TI1)

/*! @brief Format value for bitfield USB_USBSTS_TI1. */
#define BF_USB_USBSTS_TI1(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBSTS_TI1) & BM_USB_USBSTS_TI1)

/*! @brief Set the TI1 field to a new value. */
#define BW_USB_USBSTS_TI1(x, v) (HW_USB_USBSTS_WR(x, (HW_USB_USBSTS_RD(x) & ~BM_USB_USBSTS_TI1) | BF_USB_USBSTS_TI1(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_USBINTR - Interrupt Enable Register
 ******************************************************************************/

/*!
 * @brief HW_USB_USBINTR - Interrupt Enable Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The interrupts to software are enabled with this register. An interrupt is
 * generated when a bit is set and the corresponding interrupt source is active.
 * The USB Status register (n_USBSTS) still shows interrupt sources even if they
 * are disabled by the n_USBINTR register, allowing polling of interrupt events by
 * the software.
 */
typedef union _hw_usb_usbintr
{
    uint32_t U;
    struct _hw_usb_usbintr_bitfields
    {
        uint32_t UE : 1;               /*!< [0]  */
        uint32_t UEE : 1;              /*!< [1]  */
        uint32_t PCE : 1;              /*!< [2]  */
        uint32_t FRE : 1;              /*!< [3]  */
        uint32_t SEE : 1;              /*!< [4]  */
        uint32_t AAE : 1;              /*!< [5]  */
        uint32_t URE : 1;              /*!< [6]  */
        uint32_t SRE : 1;              /*!< [7]  */
        uint32_t SLE : 1;              /*!< [8]  */
        uint32_t RESERVED0 : 1;        /*!< [9]  */
        uint32_t ULPIE : 1;            /*!< [10]  */
        uint32_t RESERVED1 : 5;        /*!< [15:11]  */
        uint32_t NAKE : 1;             /*!< [16]  */
        uint32_t RESERVED2 : 1;        /*!< [17]  */
        uint32_t UAIE : 1;             /*!< [18]  */
        uint32_t UPIE : 1;             /*!< [19]  */
        uint32_t RESERVED3 : 4;        /*!< [23:20]  */
        uint32_t TIE0 : 1;             /*!< [24]  */
        uint32_t TIE1 : 1;             /*!< [25]  */
        uint32_t RESERVED4 : 6;        /*!< [31:26]  */
    } B;
} hw_usb_usbintr_t;

/*!
 * @name Constants and macros for entire USB_USBINTR register
 */
/*@{*/
#define HW_USB_USBINTR_ADDR(x)   ((uintptr_t)(x) + 0x148U)

#define HW_USB_USBINTR(x)        (*(__IO hw_usb_usbintr_t *) HW_USB_USBINTR_ADDR(x))
#define HW_USB_USBINTR_RD(x)     (HW_USB_USBINTR(x).U)
#define HW_USB_USBINTR_WR(x, v)  (HW_USB_USBINTR(x).U = (v))
#define HW_USB_USBINTR_SET(x, v) (HW_USB_USBINTR_WR(x, HW_USB_USBINTR_RD(x) |  (v)))
#define HW_USB_USBINTR_CLR(x, v) (HW_USB_USBINTR_WR(x, HW_USB_USBINTR_RD(x) & ~(v)))
#define HW_USB_USBINTR_TOG(x, v) (HW_USB_USBINTR_WR(x, HW_USB_USBINTR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_USBINTR bitfields
 */

/*!
 * @name Register USB_USBINTR, field UE[0] (RW)
 *
 * USB Interrupt Enable When this bit is one and the UI bit in n_USBSTS register
 * is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_USBINTR_UE    (0U)          /*!< Bit position for USB_USBINTR_UE. */
#define BM_USB_USBINTR_UE    (0x00000001U) /*!< Bit mask for USB_USBINTR_UE. */
#define BS_USB_USBINTR_UE    (1U)          /*!< Bit field size in bits for USB_USBINTR_UE. */

/*! @brief Read current value of the USB_USBINTR_UE field. */
#define BR_USB_USBINTR_UE(x) (HW_USB_USBINTR(x).B.UE)

/*! @brief Format value for bitfield USB_USBINTR_UE. */
#define BF_USB_USBINTR_UE(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBINTR_UE) & BM_USB_USBINTR_UE)

/*! @brief Set the UE field to a new value. */
#define BW_USB_USBINTR_UE(x, v) (HW_USB_USBINTR_WR(x, (HW_USB_USBINTR_RD(x) & ~BM_USB_USBINTR_UE) | BF_USB_USBINTR_UE(v)))
/*@}*/

/*!
 * @name Register USB_USBINTR, field UEE[1] (RW)
 *
 * USB Error Interrupt Enable When this bit is one and the UEI bit in n_USBSTS
 * register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_USBINTR_UEE   (1U)          /*!< Bit position for USB_USBINTR_UEE. */
#define BM_USB_USBINTR_UEE   (0x00000002U) /*!< Bit mask for USB_USBINTR_UEE. */
#define BS_USB_USBINTR_UEE   (1U)          /*!< Bit field size in bits for USB_USBINTR_UEE. */

/*! @brief Read current value of the USB_USBINTR_UEE field. */
#define BR_USB_USBINTR_UEE(x) (HW_USB_USBINTR(x).B.UEE)

/*! @brief Format value for bitfield USB_USBINTR_UEE. */
#define BF_USB_USBINTR_UEE(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBINTR_UEE) & BM_USB_USBINTR_UEE)

/*! @brief Set the UEE field to a new value. */
#define BW_USB_USBINTR_UEE(x, v) (HW_USB_USBINTR_WR(x, (HW_USB_USBINTR_RD(x) & ~BM_USB_USBINTR_UEE) | BF_USB_USBINTR_UEE(v)))
/*@}*/

/*!
 * @name Register USB_USBINTR, field PCE[2] (RW)
 *
 * Port Change Detect Interrupt Enable When this bit is one and the PCI bit in
 * n_USBSTS register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_USBINTR_PCE   (2U)          /*!< Bit position for USB_USBINTR_PCE. */
#define BM_USB_USBINTR_PCE   (0x00000004U) /*!< Bit mask for USB_USBINTR_PCE. */
#define BS_USB_USBINTR_PCE   (1U)          /*!< Bit field size in bits for USB_USBINTR_PCE. */

/*! @brief Read current value of the USB_USBINTR_PCE field. */
#define BR_USB_USBINTR_PCE(x) (HW_USB_USBINTR(x).B.PCE)

/*! @brief Format value for bitfield USB_USBINTR_PCE. */
#define BF_USB_USBINTR_PCE(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBINTR_PCE) & BM_USB_USBINTR_PCE)

/*! @brief Set the PCE field to a new value. */
#define BW_USB_USBINTR_PCE(x, v) (HW_USB_USBINTR_WR(x, (HW_USB_USBINTR_RD(x) & ~BM_USB_USBINTR_PCE) | BF_USB_USBINTR_PCE(v)))
/*@}*/

/*!
 * @name Register USB_USBINTR, field FRE[3] (RW)
 *
 * Frame List Rollover Interrupt Enable When this bit is one and the FRI bit in
 * n_USBSTS register is a one the controller will issue an interrupt. Only used
 * in host operation mode.
 */
/*@{*/
#define BP_USB_USBINTR_FRE   (3U)          /*!< Bit position for USB_USBINTR_FRE. */
#define BM_USB_USBINTR_FRE   (0x00000008U) /*!< Bit mask for USB_USBINTR_FRE. */
#define BS_USB_USBINTR_FRE   (1U)          /*!< Bit field size in bits for USB_USBINTR_FRE. */

/*! @brief Read current value of the USB_USBINTR_FRE field. */
#define BR_USB_USBINTR_FRE(x) (HW_USB_USBINTR(x).B.FRE)

/*! @brief Format value for bitfield USB_USBINTR_FRE. */
#define BF_USB_USBINTR_FRE(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBINTR_FRE) & BM_USB_USBINTR_FRE)

/*! @brief Set the FRE field to a new value. */
#define BW_USB_USBINTR_FRE(x, v) (HW_USB_USBINTR_WR(x, (HW_USB_USBINTR_RD(x) & ~BM_USB_USBINTR_FRE) | BF_USB_USBINTR_FRE(v)))
/*@}*/

/*!
 * @name Register USB_USBINTR, field SEE[4] (RW)
 *
 * System Error Interrupt Enable When this bit is one and the SEI bit in
 * n_USBSTS register is a one the controller will issue an interrupt. Only used in host
 * operation mode.
 */
/*@{*/
#define BP_USB_USBINTR_SEE   (4U)          /*!< Bit position for USB_USBINTR_SEE. */
#define BM_USB_USBINTR_SEE   (0x00000010U) /*!< Bit mask for USB_USBINTR_SEE. */
#define BS_USB_USBINTR_SEE   (1U)          /*!< Bit field size in bits for USB_USBINTR_SEE. */

/*! @brief Read current value of the USB_USBINTR_SEE field. */
#define BR_USB_USBINTR_SEE(x) (HW_USB_USBINTR(x).B.SEE)

/*! @brief Format value for bitfield USB_USBINTR_SEE. */
#define BF_USB_USBINTR_SEE(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBINTR_SEE) & BM_USB_USBINTR_SEE)

/*! @brief Set the SEE field to a new value. */
#define BW_USB_USBINTR_SEE(x, v) (HW_USB_USBINTR_WR(x, (HW_USB_USBINTR_RD(x) & ~BM_USB_USBINTR_SEE) | BF_USB_USBINTR_SEE(v)))
/*@}*/

/*!
 * @name Register USB_USBINTR, field AAE[5] (RW)
 *
 * Async Advance Interrupt Enable When this bit is one and the AAI bit in
 * n_USBSTS register is a one the controller will issue an interrupt. Only used in host
 * operation mode.
 */
/*@{*/
#define BP_USB_USBINTR_AAE   (5U)          /*!< Bit position for USB_USBINTR_AAE. */
#define BM_USB_USBINTR_AAE   (0x00000020U) /*!< Bit mask for USB_USBINTR_AAE. */
#define BS_USB_USBINTR_AAE   (1U)          /*!< Bit field size in bits for USB_USBINTR_AAE. */

/*! @brief Read current value of the USB_USBINTR_AAE field. */
#define BR_USB_USBINTR_AAE(x) (HW_USB_USBINTR(x).B.AAE)

/*! @brief Format value for bitfield USB_USBINTR_AAE. */
#define BF_USB_USBINTR_AAE(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBINTR_AAE) & BM_USB_USBINTR_AAE)

/*! @brief Set the AAE field to a new value. */
#define BW_USB_USBINTR_AAE(x, v) (HW_USB_USBINTR_WR(x, (HW_USB_USBINTR_RD(x) & ~BM_USB_USBINTR_AAE) | BF_USB_USBINTR_AAE(v)))
/*@}*/

/*!
 * @name Register USB_USBINTR, field URE[6] (RW)
 *
 * USB Reset Interrupt Enable When this bit is one and the URI bit in n_USBSTS
 * register is a one the controller will issue an interrupt. Only used in device
 * operation mode.
 */
/*@{*/
#define BP_USB_USBINTR_URE   (6U)          /*!< Bit position for USB_USBINTR_URE. */
#define BM_USB_USBINTR_URE   (0x00000040U) /*!< Bit mask for USB_USBINTR_URE. */
#define BS_USB_USBINTR_URE   (1U)          /*!< Bit field size in bits for USB_USBINTR_URE. */

/*! @brief Read current value of the USB_USBINTR_URE field. */
#define BR_USB_USBINTR_URE(x) (HW_USB_USBINTR(x).B.URE)

/*! @brief Format value for bitfield USB_USBINTR_URE. */
#define BF_USB_USBINTR_URE(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBINTR_URE) & BM_USB_USBINTR_URE)

/*! @brief Set the URE field to a new value. */
#define BW_USB_USBINTR_URE(x, v) (HW_USB_USBINTR_WR(x, (HW_USB_USBINTR_RD(x) & ~BM_USB_USBINTR_URE) | BF_USB_USBINTR_URE(v)))
/*@}*/

/*!
 * @name Register USB_USBINTR, field SRE[7] (RW)
 *
 * SOF Received Interrupt Enable When this bit is one and the SRI bit in
 * n_USBSTS register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_USBINTR_SRE   (7U)          /*!< Bit position for USB_USBINTR_SRE. */
#define BM_USB_USBINTR_SRE   (0x00000080U) /*!< Bit mask for USB_USBINTR_SRE. */
#define BS_USB_USBINTR_SRE   (1U)          /*!< Bit field size in bits for USB_USBINTR_SRE. */

/*! @brief Read current value of the USB_USBINTR_SRE field. */
#define BR_USB_USBINTR_SRE(x) (HW_USB_USBINTR(x).B.SRE)

/*! @brief Format value for bitfield USB_USBINTR_SRE. */
#define BF_USB_USBINTR_SRE(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBINTR_SRE) & BM_USB_USBINTR_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_USB_USBINTR_SRE(x, v) (HW_USB_USBINTR_WR(x, (HW_USB_USBINTR_RD(x) & ~BM_USB_USBINTR_SRE) | BF_USB_USBINTR_SRE(v)))
/*@}*/

/*!
 * @name Register USB_USBINTR, field SLE[8] (RW)
 *
 * Sleep Interrupt Enable When this bit is one and the SLI bit in n_n_USBSTS
 * register is a one the controller will issue an interrupt. Only used in device
 * operation mode.
 */
/*@{*/
#define BP_USB_USBINTR_SLE   (8U)          /*!< Bit position for USB_USBINTR_SLE. */
#define BM_USB_USBINTR_SLE   (0x00000100U) /*!< Bit mask for USB_USBINTR_SLE. */
#define BS_USB_USBINTR_SLE   (1U)          /*!< Bit field size in bits for USB_USBINTR_SLE. */

/*! @brief Read current value of the USB_USBINTR_SLE field. */
#define BR_USB_USBINTR_SLE(x) (HW_USB_USBINTR(x).B.SLE)

/*! @brief Format value for bitfield USB_USBINTR_SLE. */
#define BF_USB_USBINTR_SLE(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBINTR_SLE) & BM_USB_USBINTR_SLE)

/*! @brief Set the SLE field to a new value. */
#define BW_USB_USBINTR_SLE(x, v) (HW_USB_USBINTR_WR(x, (HW_USB_USBINTR_RD(x) & ~BM_USB_USBINTR_SLE) | BF_USB_USBINTR_SLE(v)))
/*@}*/

/*!
 * @name Register USB_USBINTR, field ULPIE[10] (RW)
 *
 * ULPI Interrupt Enable When this bit is one and the UPLII bit in n_USBSTS
 * register is a one the controller will issue an interrupt. This bit is usable only
 * if the controller support UPLI interface mode.
 */
/*@{*/
#define BP_USB_USBINTR_ULPIE (10U)         /*!< Bit position for USB_USBINTR_ULPIE. */
#define BM_USB_USBINTR_ULPIE (0x00000400U) /*!< Bit mask for USB_USBINTR_ULPIE. */
#define BS_USB_USBINTR_ULPIE (1U)          /*!< Bit field size in bits for USB_USBINTR_ULPIE. */

/*! @brief Read current value of the USB_USBINTR_ULPIE field. */
#define BR_USB_USBINTR_ULPIE(x) (HW_USB_USBINTR(x).B.ULPIE)

/*! @brief Format value for bitfield USB_USBINTR_ULPIE. */
#define BF_USB_USBINTR_ULPIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBINTR_ULPIE) & BM_USB_USBINTR_ULPIE)

/*! @brief Set the ULPIE field to a new value. */
#define BW_USB_USBINTR_ULPIE(x, v) (HW_USB_USBINTR_WR(x, (HW_USB_USBINTR_RD(x) & ~BM_USB_USBINTR_ULPIE) | BF_USB_USBINTR_ULPIE(v)))
/*@}*/

/*!
 * @name Register USB_USBINTR, field NAKE[16] (RW)
 *
 * NAK Interrupt Enable When this bit is one and the NAKI bit in n_USBSTS
 * register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_USBINTR_NAKE  (16U)         /*!< Bit position for USB_USBINTR_NAKE. */
#define BM_USB_USBINTR_NAKE  (0x00010000U) /*!< Bit mask for USB_USBINTR_NAKE. */
#define BS_USB_USBINTR_NAKE  (1U)          /*!< Bit field size in bits for USB_USBINTR_NAKE. */

/*! @brief Read current value of the USB_USBINTR_NAKE field. */
#define BR_USB_USBINTR_NAKE(x) (HW_USB_USBINTR(x).B.NAKE)

/*! @brief Format value for bitfield USB_USBINTR_NAKE. */
#define BF_USB_USBINTR_NAKE(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBINTR_NAKE) & BM_USB_USBINTR_NAKE)

/*! @brief Set the NAKE field to a new value. */
#define BW_USB_USBINTR_NAKE(x, v) (HW_USB_USBINTR_WR(x, (HW_USB_USBINTR_RD(x) & ~BM_USB_USBINTR_NAKE) | BF_USB_USBINTR_NAKE(v)))
/*@}*/

/*!
 * @name Register USB_USBINTR, field UAIE[18] (RW)
 *
 * USB Host Asynchronous Interrupt Enable When this bit is one, and the UAI bit
 * in the n_USBSTS register is one, host controller will issue an interrupt at
 * the next interrupt threshold.
 */
/*@{*/
#define BP_USB_USBINTR_UAIE  (18U)         /*!< Bit position for USB_USBINTR_UAIE. */
#define BM_USB_USBINTR_UAIE  (0x00040000U) /*!< Bit mask for USB_USBINTR_UAIE. */
#define BS_USB_USBINTR_UAIE  (1U)          /*!< Bit field size in bits for USB_USBINTR_UAIE. */

/*! @brief Read current value of the USB_USBINTR_UAIE field. */
#define BR_USB_USBINTR_UAIE(x) (HW_USB_USBINTR(x).B.UAIE)

/*! @brief Format value for bitfield USB_USBINTR_UAIE. */
#define BF_USB_USBINTR_UAIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBINTR_UAIE) & BM_USB_USBINTR_UAIE)

/*! @brief Set the UAIE field to a new value. */
#define BW_USB_USBINTR_UAIE(x, v) (HW_USB_USBINTR_WR(x, (HW_USB_USBINTR_RD(x) & ~BM_USB_USBINTR_UAIE) | BF_USB_USBINTR_UAIE(v)))
/*@}*/

/*!
 * @name Register USB_USBINTR, field UPIE[19] (RW)
 *
 * USB Host Periodic Interrupt Enable When this bit is one, and the UPI bit in
 * the n_USBSTS register is one, host controller will issue an interrupt at the
 * next interrupt threshold.
 */
/*@{*/
#define BP_USB_USBINTR_UPIE  (19U)         /*!< Bit position for USB_USBINTR_UPIE. */
#define BM_USB_USBINTR_UPIE  (0x00080000U) /*!< Bit mask for USB_USBINTR_UPIE. */
#define BS_USB_USBINTR_UPIE  (1U)          /*!< Bit field size in bits for USB_USBINTR_UPIE. */

/*! @brief Read current value of the USB_USBINTR_UPIE field. */
#define BR_USB_USBINTR_UPIE(x) (HW_USB_USBINTR(x).B.UPIE)

/*! @brief Format value for bitfield USB_USBINTR_UPIE. */
#define BF_USB_USBINTR_UPIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBINTR_UPIE) & BM_USB_USBINTR_UPIE)

/*! @brief Set the UPIE field to a new value. */
#define BW_USB_USBINTR_UPIE(x, v) (HW_USB_USBINTR_WR(x, (HW_USB_USBINTR_RD(x) & ~BM_USB_USBINTR_UPIE) | BF_USB_USBINTR_UPIE(v)))
/*@}*/

/*!
 * @name Register USB_USBINTR, field TIE0[24] (RW)
 *
 * General Purpose Timer #0 Interrupt Enable When this bit is one and the TI0
 * bit in n_USBSTS register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_USBINTR_TIE0  (24U)         /*!< Bit position for USB_USBINTR_TIE0. */
#define BM_USB_USBINTR_TIE0  (0x01000000U) /*!< Bit mask for USB_USBINTR_TIE0. */
#define BS_USB_USBINTR_TIE0  (1U)          /*!< Bit field size in bits for USB_USBINTR_TIE0. */

/*! @brief Read current value of the USB_USBINTR_TIE0 field. */
#define BR_USB_USBINTR_TIE0(x) (HW_USB_USBINTR(x).B.TIE0)

/*! @brief Format value for bitfield USB_USBINTR_TIE0. */
#define BF_USB_USBINTR_TIE0(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBINTR_TIE0) & BM_USB_USBINTR_TIE0)

/*! @brief Set the TIE0 field to a new value. */
#define BW_USB_USBINTR_TIE0(x, v) (HW_USB_USBINTR_WR(x, (HW_USB_USBINTR_RD(x) & ~BM_USB_USBINTR_TIE0) | BF_USB_USBINTR_TIE0(v)))
/*@}*/

/*!
 * @name Register USB_USBINTR, field TIE1[25] (RW)
 *
 * General Purpose Timer #1 Interrupt Enable When this bit is one and the TI1
 * bit in n_USBSTS register is a one the controller will issue an interrupt.
 */
/*@{*/
#define BP_USB_USBINTR_TIE1  (25U)         /*!< Bit position for USB_USBINTR_TIE1. */
#define BM_USB_USBINTR_TIE1  (0x02000000U) /*!< Bit mask for USB_USBINTR_TIE1. */
#define BS_USB_USBINTR_TIE1  (1U)          /*!< Bit field size in bits for USB_USBINTR_TIE1. */

/*! @brief Read current value of the USB_USBINTR_TIE1 field. */
#define BR_USB_USBINTR_TIE1(x) (HW_USB_USBINTR(x).B.TIE1)

/*! @brief Format value for bitfield USB_USBINTR_TIE1. */
#define BF_USB_USBINTR_TIE1(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBINTR_TIE1) & BM_USB_USBINTR_TIE1)

/*! @brief Set the TIE1 field to a new value. */
#define BW_USB_USBINTR_TIE1(x, v) (HW_USB_USBINTR_WR(x, (HW_USB_USBINTR_RD(x) & ~BM_USB_USBINTR_TIE1) | BF_USB_USBINTR_TIE1(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_FRINDEX - USB Frame Index
 ******************************************************************************/

/*!
 * @brief HW_USB_FRINDEX - USB Frame Index (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used by the host controller to index the periodic frame
 * list. The register updates every 125 microseconds (once each micro-frame). Bits
 * [N: 3] are used to select a particular entry in the Periodic Frame List during
 * periodic schedule execution. The number of bits used for the index depends on
 * the size of the frame list as set by system software in the Frame List Size
 * field in the n_USBCMD register. This register must be written as a DWord. Byte
 * writes produce undefined results. This register cannot be written unless the
 * Host Controller is in the 'Halted' state as indicated by the HCHalted bit. A
 * write to this register while the Run/Stop hit is set to a one produces undefined
 * results. Writes to this register also affect the SOF value. In device mode this
 * register is read only and, the device controller updates the FRINDEX [13:3]
 * register from the frame number indicated by the SOF marker. Whenever a SOF is
 * received by the USB bus, FRINDEX [13:3] will be checked against the SOF marker.
 * If FRINDEX [13:3] is different from the SOF marker, FRINDEX [13:3] will be
 * set to the SOF value and FRINDEX [2:0] will be set to zero (that is, SOF for 1
 * ms frame). If FRINDEX [13:3] is equal to the SOF value, FRINDEX [2:0] will be
 * increment (that is, SOF for 125 us micro-frame.).
 */
typedef union _hw_usb_frindex
{
    uint32_t U;
    struct _hw_usb_frindex_bitfields
    {
        uint32_t FRINDEX : 14;         /*!< [13:0]  */
        uint32_t RESERVED0 : 18;       /*!< [31:14]  */
    } B;
} hw_usb_frindex_t;

/*!
 * @name Constants and macros for entire USB_FRINDEX register
 */
/*@{*/
#define HW_USB_FRINDEX_ADDR(x)   ((uintptr_t)(x) + 0x14CU)

#define HW_USB_FRINDEX(x)        (*(__IO hw_usb_frindex_t *) HW_USB_FRINDEX_ADDR(x))
#define HW_USB_FRINDEX_RD(x)     (HW_USB_FRINDEX(x).U)
#define HW_USB_FRINDEX_WR(x, v)  (HW_USB_FRINDEX(x).U = (v))
#define HW_USB_FRINDEX_SET(x, v) (HW_USB_FRINDEX_WR(x, HW_USB_FRINDEX_RD(x) |  (v)))
#define HW_USB_FRINDEX_CLR(x, v) (HW_USB_FRINDEX_WR(x, HW_USB_FRINDEX_RD(x) & ~(v)))
#define HW_USB_FRINDEX_TOG(x, v) (HW_USB_FRINDEX_WR(x, HW_USB_FRINDEX_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_FRINDEX bitfields
 */

/*!
 * @name Register USB_FRINDEX, field FRINDEX[13:0] (RW)
 *
 * Frame Index. The value, in this register, increments at the end of each time
 * frame (micro-frame). Bits [N: 3] are used for the Frame List current index.
 * This means that each location of the frame list is accessed 8 times (frames or
 * micro-frames) before moving to the next index. The following illustrates values
 * of N based on the value of the Frame List Size field in the USBCMD register,
 * when used in host mode. USBCMD [Frame List Size] Number Elements N In device
 * mode the value is the current frame number of the last frame transmitted. It is
 * not used as an index. In either mode bits 2:0 indicate the current microframe.
 *
 * Values:
 * - 000 - (1024) 12
 * - 001 - (512) 11
 * - 010 - (256) 10
 * - 011 - (128) 9
 * - 100 - (64) 8
 * - 101 - (32) 7
 * - 110 - (16) 6
 * - 111 - (8) 5
 */
/*@{*/
#define BP_USB_FRINDEX_FRINDEX (0U)        /*!< Bit position for USB_FRINDEX_FRINDEX. */
#define BM_USB_FRINDEX_FRINDEX (0x00003FFFU) /*!< Bit mask for USB_FRINDEX_FRINDEX. */
#define BS_USB_FRINDEX_FRINDEX (14U)       /*!< Bit field size in bits for USB_FRINDEX_FRINDEX. */

/*! @brief Read current value of the USB_FRINDEX_FRINDEX field. */
#define BR_USB_FRINDEX_FRINDEX(x) (HW_USB_FRINDEX(x).B.FRINDEX)

/*! @brief Format value for bitfield USB_FRINDEX_FRINDEX. */
#define BF_USB_FRINDEX_FRINDEX(v) ((uint32_t)((uint32_t)(v) << BP_USB_FRINDEX_FRINDEX) & BM_USB_FRINDEX_FRINDEX)

/*! @brief Set the FRINDEX field to a new value. */
#define BW_USB_FRINDEX_FRINDEX(x, v) (HW_USB_FRINDEX_WR(x, (HW_USB_FRINDEX_RD(x) & ~BM_USB_FRINDEX_FRINDEX) | BF_USB_FRINDEX_FRINDEX(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_DEVICEADDR - Device Address
 ******************************************************************************/

/*!
 * @brief HW_USB_DEVICEADDR - Device Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * Device Controller only The upper seven bits of this register represent the
 * device address. After any controller reset or a USB reset, the device address is
 * set to the default address (0). The default address will match all incoming
 * addresses. Software shall reprogram the address after receiving a SET_ADDRESS
 * descriptor.
 */
typedef union _hw_usb_deviceaddr
{
    uint32_t U;
    struct _hw_usb_deviceaddr_bitfields
    {
        uint32_t RESERVED0 : 24;       /*!< [23:0]  */
        uint32_t USBADRA : 1;          /*!< [24]  */
        uint32_t USBADR : 7;           /*!< [31:25]  */
    } B;
} hw_usb_deviceaddr_t;

/*!
 * @name Constants and macros for entire USB_DEVICEADDR register
 */
/*@{*/
#define HW_USB_DEVICEADDR_ADDR(x) ((uintptr_t)(x) + 0x154U)

#define HW_USB_DEVICEADDR(x)     (*(__IO hw_usb_deviceaddr_t *) HW_USB_DEVICEADDR_ADDR(x))
#define HW_USB_DEVICEADDR_RD(x)  (HW_USB_DEVICEADDR(x).U)
#define HW_USB_DEVICEADDR_WR(x, v) (HW_USB_DEVICEADDR(x).U = (v))
#define HW_USB_DEVICEADDR_SET(x, v) (HW_USB_DEVICEADDR_WR(x, HW_USB_DEVICEADDR_RD(x) |  (v)))
#define HW_USB_DEVICEADDR_CLR(x, v) (HW_USB_DEVICEADDR_WR(x, HW_USB_DEVICEADDR_RD(x) & ~(v)))
#define HW_USB_DEVICEADDR_TOG(x, v) (HW_USB_DEVICEADDR_WR(x, HW_USB_DEVICEADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_DEVICEADDR bitfields
 */

/*!
 * @name Register USB_DEVICEADDR, field USBADRA[24] (RW)
 *
 * Device Address Advance. Default=0. When this bit is '0', any writes to USBADR
 * are instantaneous. When this bit is written to a '1' at the same time or
 * before USBADR is written, the write to the USBADR field is staged and held in a
 * hidden register. After an IN occurs on endpoint 0 and is ACKed, USBADR will be
 * loaded from the holding register. Hardware will automatically clear this bit on
 * the following conditions: 1) IN is ACKed to endpoint 0. (USBADR is updated
 * from staging register). 2) OUT/SETUP occur to endpoint 0. (USBADR is not
 * updated). 3) Device Reset occurs (USBADR is reset to 0). After the status phase of
 * the SET_ADDRESS descriptor, the DCD has 2 ms to program the USBADR field. This
 * mechanism will ensure this specification is met when the DCD can not write of
 * the device address within 2ms from the SET_ADDRESS status phase. If the DCD
 * writes the USBADR with USBADRA=1 after the SET_ADDRESS data phase (before the
 * prime of the status phase), the USBADR will be programmed instantly at the
 * correct time and meet the 2ms USB requirement.
 */
/*@{*/
#define BP_USB_DEVICEADDR_USBADRA (24U)    /*!< Bit position for USB_DEVICEADDR_USBADRA. */
#define BM_USB_DEVICEADDR_USBADRA (0x01000000U) /*!< Bit mask for USB_DEVICEADDR_USBADRA. */
#define BS_USB_DEVICEADDR_USBADRA (1U)     /*!< Bit field size in bits for USB_DEVICEADDR_USBADRA. */

/*! @brief Read current value of the USB_DEVICEADDR_USBADRA field. */
#define BR_USB_DEVICEADDR_USBADRA(x) (HW_USB_DEVICEADDR(x).B.USBADRA)

/*! @brief Format value for bitfield USB_DEVICEADDR_USBADRA. */
#define BF_USB_DEVICEADDR_USBADRA(v) ((uint32_t)((uint32_t)(v) << BP_USB_DEVICEADDR_USBADRA) & BM_USB_DEVICEADDR_USBADRA)

/*! @brief Set the USBADRA field to a new value. */
#define BW_USB_DEVICEADDR_USBADRA(x, v) (HW_USB_DEVICEADDR_WR(x, (HW_USB_DEVICEADDR_RD(x) & ~BM_USB_DEVICEADDR_USBADRA) | BF_USB_DEVICEADDR_USBADRA(v)))
/*@}*/

/*!
 * @name Register USB_DEVICEADDR, field USBADR[31:25] (RW)
 *
 * Device Address. These bits correspond to the USB device address
 */
/*@{*/
#define BP_USB_DEVICEADDR_USBADR (25U)     /*!< Bit position for USB_DEVICEADDR_USBADR. */
#define BM_USB_DEVICEADDR_USBADR (0xFE000000U) /*!< Bit mask for USB_DEVICEADDR_USBADR. */
#define BS_USB_DEVICEADDR_USBADR (7U)      /*!< Bit field size in bits for USB_DEVICEADDR_USBADR. */

/*! @brief Read current value of the USB_DEVICEADDR_USBADR field. */
#define BR_USB_DEVICEADDR_USBADR(x) (HW_USB_DEVICEADDR(x).B.USBADR)

/*! @brief Format value for bitfield USB_DEVICEADDR_USBADR. */
#define BF_USB_DEVICEADDR_USBADR(v) ((uint32_t)((uint32_t)(v) << BP_USB_DEVICEADDR_USBADR) & BM_USB_DEVICEADDR_USBADR)

/*! @brief Set the USBADR field to a new value. */
#define BW_USB_DEVICEADDR_USBADR(x, v) (HW_USB_DEVICEADDR_WR(x, (HW_USB_DEVICEADDR_RD(x) & ~BM_USB_DEVICEADDR_USBADR) | BF_USB_DEVICEADDR_USBADR(v)))
/*@}*/
/*******************************************************************************
 * HW_USB_PERIODICLISTBASE - Frame List Base Address
 ******************************************************************************/

/*!
 * @brief HW_USB_PERIODICLISTBASE - Frame List Base Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * Host Controller only This 32-bit register contains the beginning address of
 * the Periodic Frame List in the system memory. HCD loads this register prior to
 * starting the schedule execution by the Host Controller. The memory structure
 * referenced by this physical memory pointer is assumed to be 4-Kbyte aligned.
 * The contents of this register are combined with the Frame Index Register
 * (USB_n_FRINDEX) to enable the Host Controller to step through the Periodic Frame List
 * in sequence.
 */
typedef union _hw_usb_periodiclistbase
{
    uint32_t U;
    struct _hw_usb_periodiclistbase_bitfields
    {
        uint32_t RESERVED0 : 12;       /*!< [11:0]  */
        uint32_t BASEADR : 20;         /*!< [31:12]  */
    } B;
} hw_usb_periodiclistbase_t;

/*!
 * @name Constants and macros for entire USB_PERIODICLISTBASE register
 */
/*@{*/
#define HW_USB_PERIODICLISTBASE_ADDR(x) ((uintptr_t)(x) + 0x154U)

#define HW_USB_PERIODICLISTBASE(x) (*(__IO hw_usb_periodiclistbase_t *) HW_USB_PERIODICLISTBASE_ADDR(x))
#define HW_USB_PERIODICLISTBASE_RD(x) (HW_USB_PERIODICLISTBASE(x).U)
#define HW_USB_PERIODICLISTBASE_WR(x, v) (HW_USB_PERIODICLISTBASE(x).U = (v))
#define HW_USB_PERIODICLISTBASE_SET(x, v) (HW_USB_PERIODICLISTBASE_WR(x, HW_USB_PERIODICLISTBASE_RD(x) |  (v)))
#define HW_USB_PERIODICLISTBASE_CLR(x, v) (HW_USB_PERIODICLISTBASE_WR(x, HW_USB_PERIODICLISTBASE_RD(x) & ~(v)))
#define HW_USB_PERIODICLISTBASE_TOG(x, v) (HW_USB_PERIODICLISTBASE_WR(x, HW_USB_PERIODICLISTBASE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_PERIODICLISTBASE bitfields
 */

/*!
 * @name Register USB_PERIODICLISTBASE, field BASEADR[31:12] (RW)
 *
 * Base Address (Low). These bits correspond to memory address signals [31:12],
 * respectively. Only used by the host controller.
 */
/*@{*/
#define BP_USB_PERIODICLISTBASE_BASEADR (12U) /*!< Bit position for USB_PERIODICLISTBASE_BASEADR. */
#define BM_USB_PERIODICLISTBASE_BASEADR (0xFFFFF000U) /*!< Bit mask for USB_PERIODICLISTBASE_BASEADR. */
#define BS_USB_PERIODICLISTBASE_BASEADR (20U) /*!< Bit field size in bits for USB_PERIODICLISTBASE_BASEADR. */

/*! @brief Read current value of the USB_PERIODICLISTBASE_BASEADR field. */
#define BR_USB_PERIODICLISTBASE_BASEADR(x) (HW_USB_PERIODICLISTBASE(x).B.BASEADR)

/*! @brief Format value for bitfield USB_PERIODICLISTBASE_BASEADR. */
#define BF_USB_PERIODICLISTBASE_BASEADR(v) ((uint32_t)((uint32_t)(v) << BP_USB_PERIODICLISTBASE_BASEADR) & BM_USB_PERIODICLISTBASE_BASEADR)

/*! @brief Set the BASEADR field to a new value. */
#define BW_USB_PERIODICLISTBASE_BASEADR(x, v) (HW_USB_PERIODICLISTBASE_WR(x, (HW_USB_PERIODICLISTBASE_RD(x) & ~BM_USB_PERIODICLISTBASE_BASEADR) | BF_USB_PERIODICLISTBASE_BASEADR(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_ASYNCLISTADDR - Next Asynch. Address
 ******************************************************************************/

/*!
 * @brief HW_USB_ASYNCLISTADDR - Next Asynch. Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * Host Controller only This 32-bit register contains the address of the next
 * asynchronous queue head to be executed by the host. Bits [4:0] of this register
 * cannot be modified by the system software and will always return a zero when
 * read.
 */
typedef union _hw_usb_asynclistaddr
{
    uint32_t U;
    struct _hw_usb_asynclistaddr_bitfields
    {
        uint32_t RESERVED0 : 5;        /*!< [4:0]  */
        uint32_t ASYBASE : 27;         /*!< [31:5]  */
    } B;
} hw_usb_asynclistaddr_t;

/*!
 * @name Constants and macros for entire USB_ASYNCLISTADDR register
 */
/*@{*/
#define HW_USB_ASYNCLISTADDR_ADDR(x) ((uintptr_t)(x) + 0x158U)

#define HW_USB_ASYNCLISTADDR(x)  (*(__IO hw_usb_asynclistaddr_t *) HW_USB_ASYNCLISTADDR_ADDR(x))
#define HW_USB_ASYNCLISTADDR_RD(x) (HW_USB_ASYNCLISTADDR(x).U)
#define HW_USB_ASYNCLISTADDR_WR(x, v) (HW_USB_ASYNCLISTADDR(x).U = (v))
#define HW_USB_ASYNCLISTADDR_SET(x, v) (HW_USB_ASYNCLISTADDR_WR(x, HW_USB_ASYNCLISTADDR_RD(x) |  (v)))
#define HW_USB_ASYNCLISTADDR_CLR(x, v) (HW_USB_ASYNCLISTADDR_WR(x, HW_USB_ASYNCLISTADDR_RD(x) & ~(v)))
#define HW_USB_ASYNCLISTADDR_TOG(x, v) (HW_USB_ASYNCLISTADDR_WR(x, HW_USB_ASYNCLISTADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_ASYNCLISTADDR bitfields
 */

/*!
 * @name Register USB_ASYNCLISTADDR, field ASYBASE[31:5] (RW)
 *
 * Link Pointer Low (LPL). These bits correspond to memory address signals
 * [31:5], respectively. This field may only reference a Queue Head (QH). Only used by
 * the host controller.
 */
/*@{*/
#define BP_USB_ASYNCLISTADDR_ASYBASE (5U)  /*!< Bit position for USB_ASYNCLISTADDR_ASYBASE. */
#define BM_USB_ASYNCLISTADDR_ASYBASE (0xFFFFFFE0U) /*!< Bit mask for USB_ASYNCLISTADDR_ASYBASE. */
#define BS_USB_ASYNCLISTADDR_ASYBASE (27U) /*!< Bit field size in bits for USB_ASYNCLISTADDR_ASYBASE. */

/*! @brief Read current value of the USB_ASYNCLISTADDR_ASYBASE field. */
#define BR_USB_ASYNCLISTADDR_ASYBASE(x) (HW_USB_ASYNCLISTADDR(x).B.ASYBASE)

/*! @brief Format value for bitfield USB_ASYNCLISTADDR_ASYBASE. */
#define BF_USB_ASYNCLISTADDR_ASYBASE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ASYNCLISTADDR_ASYBASE) & BM_USB_ASYNCLISTADDR_ASYBASE)

/*! @brief Set the ASYBASE field to a new value. */
#define BW_USB_ASYNCLISTADDR_ASYBASE(x, v) (HW_USB_ASYNCLISTADDR_WR(x, (HW_USB_ASYNCLISTADDR_RD(x) & ~BM_USB_ASYNCLISTADDR_ASYBASE) | BF_USB_ASYNCLISTADDR_ASYBASE(v)))
/*@}*/
/*******************************************************************************
 * HW_USB_ENDPTLISTADDR - Endpoint List Address
 ******************************************************************************/

/*!
 * @brief HW_USB_ENDPTLISTADDR - Endpoint List Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * Device Controller only In device mode, this register contains the address of
 * the top of the endpoint list in system memory. Bits [10:0] of this register
 * cannot be modified by the system software and will always return a zero when
 * read. The memory structure referenced by this physical memory pointer is assumed
 * 64-byte.
 */
typedef union _hw_usb_endptlistaddr
{
    uint32_t U;
    struct _hw_usb_endptlistaddr_bitfields
    {
        uint32_t RESERVED0 : 11;       /*!< [10:0]  */
        uint32_t EPBASE : 21;          /*!< [31:11]  */
    } B;
} hw_usb_endptlistaddr_t;

/*!
 * @name Constants and macros for entire USB_ENDPTLISTADDR register
 */
/*@{*/
#define HW_USB_ENDPTLISTADDR_ADDR(x) ((uintptr_t)(x) + 0x158U)

#define HW_USB_ENDPTLISTADDR(x)  (*(__IO hw_usb_endptlistaddr_t *) HW_USB_ENDPTLISTADDR_ADDR(x))
#define HW_USB_ENDPTLISTADDR_RD(x) (HW_USB_ENDPTLISTADDR(x).U)
#define HW_USB_ENDPTLISTADDR_WR(x, v) (HW_USB_ENDPTLISTADDR(x).U = (v))
#define HW_USB_ENDPTLISTADDR_SET(x, v) (HW_USB_ENDPTLISTADDR_WR(x, HW_USB_ENDPTLISTADDR_RD(x) |  (v)))
#define HW_USB_ENDPTLISTADDR_CLR(x, v) (HW_USB_ENDPTLISTADDR_WR(x, HW_USB_ENDPTLISTADDR_RD(x) & ~(v)))
#define HW_USB_ENDPTLISTADDR_TOG(x, v) (HW_USB_ENDPTLISTADDR_WR(x, HW_USB_ENDPTLISTADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_ENDPTLISTADDR bitfields
 */

/*!
 * @name Register USB_ENDPTLISTADDR, field EPBASE[31:11] (RW)
 *
 * Endpoint List Pointer(Low). These bits correspond to memory address signals
 * [31:11], respectively. This field will reference a list of up to 32 Queue Head
 * (QH) (that is, one queue head per endpoint & direction).
 */
/*@{*/
#define BP_USB_ENDPTLISTADDR_EPBASE (11U)  /*!< Bit position for USB_ENDPTLISTADDR_EPBASE. */
#define BM_USB_ENDPTLISTADDR_EPBASE (0xFFFFF800U) /*!< Bit mask for USB_ENDPTLISTADDR_EPBASE. */
#define BS_USB_ENDPTLISTADDR_EPBASE (21U)  /*!< Bit field size in bits for USB_ENDPTLISTADDR_EPBASE. */

/*! @brief Read current value of the USB_ENDPTLISTADDR_EPBASE field. */
#define BR_USB_ENDPTLISTADDR_EPBASE(x) (HW_USB_ENDPTLISTADDR(x).B.EPBASE)

/*! @brief Format value for bitfield USB_ENDPTLISTADDR_EPBASE. */
#define BF_USB_ENDPTLISTADDR_EPBASE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTLISTADDR_EPBASE) & BM_USB_ENDPTLISTADDR_EPBASE)

/*! @brief Set the EPBASE field to a new value. */
#define BW_USB_ENDPTLISTADDR_EPBASE(x, v) (HW_USB_ENDPTLISTADDR_WR(x, (HW_USB_ENDPTLISTADDR_RD(x) & ~BM_USB_ENDPTLISTADDR_EPBASE) | BF_USB_ENDPTLISTADDR_EPBASE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_BURSTSIZE - Programmable Burst Size
 ******************************************************************************/

/*!
 * @brief HW_USB_BURSTSIZE - Programmable Burst Size (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to control the burst size used during data movement on
 * the AHB master interface. This register is ignored if AHBBRST bits in SBUSCFG
 * register is non-zero value.
 */
typedef union _hw_usb_burstsize
{
    uint32_t U;
    struct _hw_usb_burstsize_bitfields
    {
        uint32_t RXPBURST : 8;         /*!< [7:0]  */
        uint32_t TXPBURST : 9;         /*!< [16:8]  */
        uint32_t RESERVED0 : 15;       /*!< [31:17]  */
    } B;
} hw_usb_burstsize_t;

/*!
 * @name Constants and macros for entire USB_BURSTSIZE register
 */
/*@{*/
#define HW_USB_BURSTSIZE_ADDR(x) ((uintptr_t)(x) + 0x160U)

#define HW_USB_BURSTSIZE(x)      (*(__IO hw_usb_burstsize_t *) HW_USB_BURSTSIZE_ADDR(x))
#define HW_USB_BURSTSIZE_RD(x)   (HW_USB_BURSTSIZE(x).U)
#define HW_USB_BURSTSIZE_WR(x, v) (HW_USB_BURSTSIZE(x).U = (v))
#define HW_USB_BURSTSIZE_SET(x, v) (HW_USB_BURSTSIZE_WR(x, HW_USB_BURSTSIZE_RD(x) |  (v)))
#define HW_USB_BURSTSIZE_CLR(x, v) (HW_USB_BURSTSIZE_WR(x, HW_USB_BURSTSIZE_RD(x) & ~(v)))
#define HW_USB_BURSTSIZE_TOG(x, v) (HW_USB_BURSTSIZE_WR(x, HW_USB_BURSTSIZE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_BURSTSIZE bitfields
 */

/*!
 * @name Register USB_BURSTSIZE, field RXPBURST[7:0] (RW)
 *
 * Programmable RX Burst Size. Default value is determined by TXBURST bits in
 * n_HWRXBUF. This register represents the maximum length of a the burst in 32-bit
 * words while moving data from the USB bus to system memory.
 */
/*@{*/
#define BP_USB_BURSTSIZE_RXPBURST (0U)     /*!< Bit position for USB_BURSTSIZE_RXPBURST. */
#define BM_USB_BURSTSIZE_RXPBURST (0x000000FFU) /*!< Bit mask for USB_BURSTSIZE_RXPBURST. */
#define BS_USB_BURSTSIZE_RXPBURST (8U)     /*!< Bit field size in bits for USB_BURSTSIZE_RXPBURST. */

/*! @brief Read current value of the USB_BURSTSIZE_RXPBURST field. */
#define BR_USB_BURSTSIZE_RXPBURST(x) (HW_USB_BURSTSIZE(x).B.RXPBURST)

/*! @brief Format value for bitfield USB_BURSTSIZE_RXPBURST. */
#define BF_USB_BURSTSIZE_RXPBURST(v) ((uint32_t)((uint32_t)(v) << BP_USB_BURSTSIZE_RXPBURST) & BM_USB_BURSTSIZE_RXPBURST)

/*! @brief Set the RXPBURST field to a new value. */
#define BW_USB_BURSTSIZE_RXPBURST(x, v) (HW_USB_BURSTSIZE_WR(x, (HW_USB_BURSTSIZE_RD(x) & ~BM_USB_BURSTSIZE_RXPBURST) | BF_USB_BURSTSIZE_RXPBURST(v)))
/*@}*/

/*!
 * @name Register USB_BURSTSIZE, field TXPBURST[16:8] (RW)
 *
 * Programmable TX Burst Size. Default value is determined by TXBURST bits in
 * n_HWTXBUF. This register represents the maximum length of a the burst in 32-bit
 * words while moving data from system memory to the USB bus.
 */
/*@{*/
#define BP_USB_BURSTSIZE_TXPBURST (8U)     /*!< Bit position for USB_BURSTSIZE_TXPBURST. */
#define BM_USB_BURSTSIZE_TXPBURST (0x0001FF00U) /*!< Bit mask for USB_BURSTSIZE_TXPBURST. */
#define BS_USB_BURSTSIZE_TXPBURST (9U)     /*!< Bit field size in bits for USB_BURSTSIZE_TXPBURST. */

/*! @brief Read current value of the USB_BURSTSIZE_TXPBURST field. */
#define BR_USB_BURSTSIZE_TXPBURST(x) (HW_USB_BURSTSIZE(x).B.TXPBURST)

/*! @brief Format value for bitfield USB_BURSTSIZE_TXPBURST. */
#define BF_USB_BURSTSIZE_TXPBURST(v) ((uint32_t)((uint32_t)(v) << BP_USB_BURSTSIZE_TXPBURST) & BM_USB_BURSTSIZE_TXPBURST)

/*! @brief Set the TXPBURST field to a new value. */
#define BW_USB_BURSTSIZE_TXPBURST(x, v) (HW_USB_BURSTSIZE_WR(x, (HW_USB_BURSTSIZE_RD(x) & ~BM_USB_BURSTSIZE_TXPBURST) | BF_USB_BURSTSIZE_TXPBURST(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_TXFILLTUNING - TX FIFO Fill Tuning
 ******************************************************************************/

/*!
 * @brief HW_USB_TXFILLTUNING - TX FIFO Fill Tuning (RW)
 *
 * Reset value: 0x00000808U
 *
 * The fields in this register control performance tuning associated with how
 * the host controller posts data to the TX latency FIFO before moving the data
 * onto the USB bus. The specific areas of performance include the how much data to
 * post into the FIFO and an estimate for how long that operation should take in
 * the target system. Definitions: T 0 = Standard packet overhead T 1 = Time to
 * send data payload T ff = Time to fetch packet into TX FIFO up to specified
 * level. T s = Total Packet Flight Time (send-only) packet T s = T 0 + T 1 T p =
 * Total Packet Time (fetch and send) packet T p = T ff + T 0 + T 1 Upon discovery
 * of a transmit (OUT/SETUP) packet in the data structures, host controller checks
 * to ensure T p remains before the end of the [micro]frame. If so it proceeds
 * to pre-fill the TX FIFO. If at anytime during the pre-fill operation the time
 * remaining the [micro]frame is < T s then the packet attempt ceases and the
 * packet is tried at a later time. Although this is not an error condition and the
 * host controller will eventually recover, a mark will be made the scheduler
 * health counter to note the occurrence of a "back-off" event. When a back-off event
 * is detected, the partial packet fetched may need to be discarded from the
 * latency buffer to make room for periodic traffic that will begin after the next
 * SOF. Too many back-off events can waste bandwidth and power on the system bus
 * and thus should be minimized (not necessarily eliminated). Back-offs can be
 * minimized with use of the n_TSCHHEALTH ( T ff ) described below. The reset value
 * could vary from instance to instance. Please see the detail in bit field
 * description and ignore reset value in summary table in this case!
 */
typedef union _hw_usb_txfilltuning
{
    uint32_t U;
    struct _hw_usb_txfilltuning_bitfields
    {
        uint32_t TXSCHOH : 8;          /*!< [7:0]  */
        uint32_t TXSCHHEALTH : 5;      /*!< [12:8]  */
        uint32_t RESERVED0 : 3;        /*!< [15:13]  */
        uint32_t TXFIFOTHRES : 6;      /*!< [21:16]  */
        uint32_t RESERVED1 : 10;       /*!< [31:22]  */
    } B;
} hw_usb_txfilltuning_t;

/*!
 * @name Constants and macros for entire USB_TXFILLTUNING register
 */
/*@{*/
#define HW_USB_TXFILLTUNING_ADDR(x) ((uintptr_t)(x) + 0x164U)

#define HW_USB_TXFILLTUNING(x)   (*(__IO hw_usb_txfilltuning_t *) HW_USB_TXFILLTUNING_ADDR(x))
#define HW_USB_TXFILLTUNING_RD(x) (HW_USB_TXFILLTUNING(x).U)
#define HW_USB_TXFILLTUNING_WR(x, v) (HW_USB_TXFILLTUNING(x).U = (v))
#define HW_USB_TXFILLTUNING_SET(x, v) (HW_USB_TXFILLTUNING_WR(x, HW_USB_TXFILLTUNING_RD(x) |  (v)))
#define HW_USB_TXFILLTUNING_CLR(x, v) (HW_USB_TXFILLTUNING_WR(x, HW_USB_TXFILLTUNING_RD(x) & ~(v)))
#define HW_USB_TXFILLTUNING_TOG(x, v) (HW_USB_TXFILLTUNING_WR(x, HW_USB_TXFILLTUNING_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_TXFILLTUNING bitfields
 */

/*!
 * @name Register USB_TXFILLTUNING, field TXSCHOH[7:0] (RW)
 *
 * Scheduler Overhead. (Read/Write) [Default = 0] This register adds an
 * additional fixed offset to the schedule time estimator described above as Tff. As an
 * approximation, the value chosen for this register should limit the number of
 * back-off events captured in the TXSCHHEALTH to less than 10 per second in a
 * highly utilized bus. Choosing a value that is too high for this register is not
 * desired as it can needlessly reduce USB utilization. The time unit represented
 * in this register is 1.267us when a device is connected in High-Speed Mode. The
 * time unit represented in this register is 6.333us when a device is connected
 * in Low/Full Speed Mode. Default value is '08h' for OTG controller core, and
 * '00h' for Host-only controller core.
 */
/*@{*/
#define BP_USB_TXFILLTUNING_TXSCHOH (0U)   /*!< Bit position for USB_TXFILLTUNING_TXSCHOH. */
#define BM_USB_TXFILLTUNING_TXSCHOH (0x000000FFU) /*!< Bit mask for USB_TXFILLTUNING_TXSCHOH. */
#define BS_USB_TXFILLTUNING_TXSCHOH (8U)   /*!< Bit field size in bits for USB_TXFILLTUNING_TXSCHOH. */

/*! @brief Read current value of the USB_TXFILLTUNING_TXSCHOH field. */
#define BR_USB_TXFILLTUNING_TXSCHOH(x) (HW_USB_TXFILLTUNING(x).B.TXSCHOH)

/*! @brief Format value for bitfield USB_TXFILLTUNING_TXSCHOH. */
#define BF_USB_TXFILLTUNING_TXSCHOH(v) ((uint32_t)((uint32_t)(v) << BP_USB_TXFILLTUNING_TXSCHOH) & BM_USB_TXFILLTUNING_TXSCHOH)

/*! @brief Set the TXSCHOH field to a new value. */
#define BW_USB_TXFILLTUNING_TXSCHOH(x, v) (HW_USB_TXFILLTUNING_WR(x, (HW_USB_TXFILLTUNING_RD(x) & ~BM_USB_TXFILLTUNING_TXSCHOH) | BF_USB_TXFILLTUNING_TXSCHOH(v)))
/*@}*/

/*!
 * @name Register USB_TXFILLTUNING, field TXSCHHEALTH[12:8] (RW)
 *
 * Scheduler Health Counter. (Read/Write To Clear) This register increments when
 * the host controller fails to fill the TX latency FIFO to the level programmed
 * by TXFIFOTHRES before running out of time to send the packet before the next
 * Start-Of-Frame. This health counter measures the number of times this occurs
 * to provide feedback to selecting a proper TXSCHOH. Writing to this register
 * will clear the counter and this counter will max. at 31. Default value is '08h'
 * for OTG controller core, and '00h' for Host-only controller core.
 */
/*@{*/
#define BP_USB_TXFILLTUNING_TXSCHHEALTH (8U) /*!< Bit position for USB_TXFILLTUNING_TXSCHHEALTH. */
#define BM_USB_TXFILLTUNING_TXSCHHEALTH (0x00001F00U) /*!< Bit mask for USB_TXFILLTUNING_TXSCHHEALTH. */
#define BS_USB_TXFILLTUNING_TXSCHHEALTH (5U) /*!< Bit field size in bits for USB_TXFILLTUNING_TXSCHHEALTH. */

/*! @brief Read current value of the USB_TXFILLTUNING_TXSCHHEALTH field. */
#define BR_USB_TXFILLTUNING_TXSCHHEALTH(x) (HW_USB_TXFILLTUNING(x).B.TXSCHHEALTH)

/*! @brief Format value for bitfield USB_TXFILLTUNING_TXSCHHEALTH. */
#define BF_USB_TXFILLTUNING_TXSCHHEALTH(v) ((uint32_t)((uint32_t)(v) << BP_USB_TXFILLTUNING_TXSCHHEALTH) & BM_USB_TXFILLTUNING_TXSCHHEALTH)

/*! @brief Set the TXSCHHEALTH field to a new value. */
#define BW_USB_TXFILLTUNING_TXSCHHEALTH(x, v) (HW_USB_TXFILLTUNING_WR(x, (HW_USB_TXFILLTUNING_RD(x) & ~BM_USB_TXFILLTUNING_TXSCHHEALTH) | BF_USB_TXFILLTUNING_TXSCHHEALTH(v)))
/*@}*/

/*!
 * @name Register USB_TXFILLTUNING, field TXFIFOTHRES[21:16] (RW)
 *
 * FIFO Burst Threshold. (Read/Write) This register controls the number of data
 * bursts that are posted to the TX latency FIFO in host mode before the packet
 * begins on to the bus. The minimum value is 2 and this value should be a low as
 * possible to maximize USB performance. A higher value can be used in systems
 * with unpredictable latency and/or insufficient bandwidth where the FIFO may
 * underrun because the data transferred from the latency FIFO to USB occurs before
 * it can be replenished from system memory. This value is ignored if the Stream
 * Disable bit in USB_n_USBMODE register is set. Default value is '00h' for OTG
 * controller core, and '02h' for Host-only controller core.
 */
/*@{*/
#define BP_USB_TXFILLTUNING_TXFIFOTHRES (16U) /*!< Bit position for USB_TXFILLTUNING_TXFIFOTHRES. */
#define BM_USB_TXFILLTUNING_TXFIFOTHRES (0x003F0000U) /*!< Bit mask for USB_TXFILLTUNING_TXFIFOTHRES. */
#define BS_USB_TXFILLTUNING_TXFIFOTHRES (6U) /*!< Bit field size in bits for USB_TXFILLTUNING_TXFIFOTHRES. */

/*! @brief Read current value of the USB_TXFILLTUNING_TXFIFOTHRES field. */
#define BR_USB_TXFILLTUNING_TXFIFOTHRES(x) (HW_USB_TXFILLTUNING(x).B.TXFIFOTHRES)

/*! @brief Format value for bitfield USB_TXFILLTUNING_TXFIFOTHRES. */
#define BF_USB_TXFILLTUNING_TXFIFOTHRES(v) ((uint32_t)((uint32_t)(v) << BP_USB_TXFILLTUNING_TXFIFOTHRES) & BM_USB_TXFILLTUNING_TXFIFOTHRES)

/*! @brief Set the TXFIFOTHRES field to a new value. */
#define BW_USB_TXFILLTUNING_TXFIFOTHRES(x, v) (HW_USB_TXFILLTUNING_WR(x, (HW_USB_TXFILLTUNING_RD(x) & ~BM_USB_TXFILLTUNING_TXFIFOTHRES) | BF_USB_TXFILLTUNING_TXFIFOTHRES(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_ENDPTNAK - Endpoint NAK
 ******************************************************************************/

/*!
 * @brief HW_USB_ENDPTNAK - Endpoint NAK (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_usb_endptnak
{
    uint32_t U;
    struct _hw_usb_endptnak_bitfields
    {
        uint32_t EPRN : 8;             /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t EPTN : 8;             /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_endptnak_t;

/*!
 * @name Constants and macros for entire USB_ENDPTNAK register
 */
/*@{*/
#define HW_USB_ENDPTNAK_ADDR(x)  ((uintptr_t)(x) + 0x178U)

#define HW_USB_ENDPTNAK(x)       (*(__IO hw_usb_endptnak_t *) HW_USB_ENDPTNAK_ADDR(x))
#define HW_USB_ENDPTNAK_RD(x)    (HW_USB_ENDPTNAK(x).U)
#define HW_USB_ENDPTNAK_WR(x, v) (HW_USB_ENDPTNAK(x).U = (v))
#define HW_USB_ENDPTNAK_SET(x, v) (HW_USB_ENDPTNAK_WR(x, HW_USB_ENDPTNAK_RD(x) |  (v)))
#define HW_USB_ENDPTNAK_CLR(x, v) (HW_USB_ENDPTNAK_WR(x, HW_USB_ENDPTNAK_RD(x) & ~(v)))
#define HW_USB_ENDPTNAK_TOG(x, v) (HW_USB_ENDPTNAK_WR(x, HW_USB_ENDPTNAK_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_ENDPTNAK bitfields
 */

/*!
 * @name Register USB_ENDPTNAK, field EPRN[7:0] (RW)
 *
 * RX Endpoint NAK - R/WC. Each RX endpoint has 1 bit in this field. The bit is
 * set when the device sends a NAK handshake on a received OUT or PING token for
 * the corresponding endpoint. Bit [N] - Endpoint #[N], N is 0-7
 */
/*@{*/
#define BP_USB_ENDPTNAK_EPRN (0U)          /*!< Bit position for USB_ENDPTNAK_EPRN. */
#define BM_USB_ENDPTNAK_EPRN (0x000000FFU) /*!< Bit mask for USB_ENDPTNAK_EPRN. */
#define BS_USB_ENDPTNAK_EPRN (8U)          /*!< Bit field size in bits for USB_ENDPTNAK_EPRN. */

/*! @brief Read current value of the USB_ENDPTNAK_EPRN field. */
#define BR_USB_ENDPTNAK_EPRN(x) (HW_USB_ENDPTNAK(x).B.EPRN)

/*! @brief Format value for bitfield USB_ENDPTNAK_EPRN. */
#define BF_USB_ENDPTNAK_EPRN(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTNAK_EPRN) & BM_USB_ENDPTNAK_EPRN)

/*! @brief Set the EPRN field to a new value. */
#define BW_USB_ENDPTNAK_EPRN(x, v) (HW_USB_ENDPTNAK_WR(x, (HW_USB_ENDPTNAK_RD(x) & ~BM_USB_ENDPTNAK_EPRN) | BF_USB_ENDPTNAK_EPRN(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTNAK, field EPTN[23:16] (RW)
 *
 * TX Endpoint NAK - R/WC. Each TX endpoint has 1 bit in this field. The bit is
 * set when the device sends a NAK handshake on a received IN token for the
 * corresponding endpoint. Bit [N] - Endpoint #[N], N is 0-7
 */
/*@{*/
#define BP_USB_ENDPTNAK_EPTN (16U)         /*!< Bit position for USB_ENDPTNAK_EPTN. */
#define BM_USB_ENDPTNAK_EPTN (0x00FF0000U) /*!< Bit mask for USB_ENDPTNAK_EPTN. */
#define BS_USB_ENDPTNAK_EPTN (8U)          /*!< Bit field size in bits for USB_ENDPTNAK_EPTN. */

/*! @brief Read current value of the USB_ENDPTNAK_EPTN field. */
#define BR_USB_ENDPTNAK_EPTN(x) (HW_USB_ENDPTNAK(x).B.EPTN)

/*! @brief Format value for bitfield USB_ENDPTNAK_EPTN. */
#define BF_USB_ENDPTNAK_EPTN(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTNAK_EPTN) & BM_USB_ENDPTNAK_EPTN)

/*! @brief Set the EPTN field to a new value. */
#define BW_USB_ENDPTNAK_EPTN(x, v) (HW_USB_ENDPTNAK_WR(x, (HW_USB_ENDPTNAK_RD(x) & ~BM_USB_ENDPTNAK_EPTN) | BF_USB_ENDPTNAK_EPTN(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_ENDPTNAKEN - Endpoint NAK Enable
 ******************************************************************************/

/*!
 * @brief HW_USB_ENDPTNAKEN - Endpoint NAK Enable (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_usb_endptnaken
{
    uint32_t U;
    struct _hw_usb_endptnaken_bitfields
    {
        uint32_t EPRNE : 8;            /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t EPTNE : 8;            /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_endptnaken_t;

/*!
 * @name Constants and macros for entire USB_ENDPTNAKEN register
 */
/*@{*/
#define HW_USB_ENDPTNAKEN_ADDR(x) ((uintptr_t)(x) + 0x17CU)

#define HW_USB_ENDPTNAKEN(x)     (*(__IO hw_usb_endptnaken_t *) HW_USB_ENDPTNAKEN_ADDR(x))
#define HW_USB_ENDPTNAKEN_RD(x)  (HW_USB_ENDPTNAKEN(x).U)
#define HW_USB_ENDPTNAKEN_WR(x, v) (HW_USB_ENDPTNAKEN(x).U = (v))
#define HW_USB_ENDPTNAKEN_SET(x, v) (HW_USB_ENDPTNAKEN_WR(x, HW_USB_ENDPTNAKEN_RD(x) |  (v)))
#define HW_USB_ENDPTNAKEN_CLR(x, v) (HW_USB_ENDPTNAKEN_WR(x, HW_USB_ENDPTNAKEN_RD(x) & ~(v)))
#define HW_USB_ENDPTNAKEN_TOG(x, v) (HW_USB_ENDPTNAKEN_WR(x, HW_USB_ENDPTNAKEN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_ENDPTNAKEN bitfields
 */

/*!
 * @name Register USB_ENDPTNAKEN, field EPRNE[7:0] (RW)
 *
 * RX Endpoint NAK Enable - R/W. Each bit is an enable bit for the corresponding
 * RX Endpoint NAK bit. If this bit is set and the corresponding RX Endpoint NAK
 * bit is set, the NAK Interrupt bit is set. Bit [N] - Endpoint #[N], N is 0-7
 */
/*@{*/
#define BP_USB_ENDPTNAKEN_EPRNE (0U)       /*!< Bit position for USB_ENDPTNAKEN_EPRNE. */
#define BM_USB_ENDPTNAKEN_EPRNE (0x000000FFU) /*!< Bit mask for USB_ENDPTNAKEN_EPRNE. */
#define BS_USB_ENDPTNAKEN_EPRNE (8U)       /*!< Bit field size in bits for USB_ENDPTNAKEN_EPRNE. */

/*! @brief Read current value of the USB_ENDPTNAKEN_EPRNE field. */
#define BR_USB_ENDPTNAKEN_EPRNE(x) (HW_USB_ENDPTNAKEN(x).B.EPRNE)

/*! @brief Format value for bitfield USB_ENDPTNAKEN_EPRNE. */
#define BF_USB_ENDPTNAKEN_EPRNE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTNAKEN_EPRNE) & BM_USB_ENDPTNAKEN_EPRNE)

/*! @brief Set the EPRNE field to a new value. */
#define BW_USB_ENDPTNAKEN_EPRNE(x, v) (HW_USB_ENDPTNAKEN_WR(x, (HW_USB_ENDPTNAKEN_RD(x) & ~BM_USB_ENDPTNAKEN_EPRNE) | BF_USB_ENDPTNAKEN_EPRNE(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTNAKEN, field EPTNE[23:16] (RW)
 *
 * TX Endpoint NAK Enable - R/W. Each bit is an enable bit for the corresponding
 * TX Endpoint NAK bit. If this bit is set and the corresponding TX Endpoint NAK
 * bit is set, the NAK Interrupt bit is set. Bit [N] - Endpoint #[N], N is 0-7
 */
/*@{*/
#define BP_USB_ENDPTNAKEN_EPTNE (16U)      /*!< Bit position for USB_ENDPTNAKEN_EPTNE. */
#define BM_USB_ENDPTNAKEN_EPTNE (0x00FF0000U) /*!< Bit mask for USB_ENDPTNAKEN_EPTNE. */
#define BS_USB_ENDPTNAKEN_EPTNE (8U)       /*!< Bit field size in bits for USB_ENDPTNAKEN_EPTNE. */

/*! @brief Read current value of the USB_ENDPTNAKEN_EPTNE field. */
#define BR_USB_ENDPTNAKEN_EPTNE(x) (HW_USB_ENDPTNAKEN(x).B.EPTNE)

/*! @brief Format value for bitfield USB_ENDPTNAKEN_EPTNE. */
#define BF_USB_ENDPTNAKEN_EPTNE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTNAKEN_EPTNE) & BM_USB_ENDPTNAKEN_EPTNE)

/*! @brief Set the EPTNE field to a new value. */
#define BW_USB_ENDPTNAKEN_EPTNE(x, v) (HW_USB_ENDPTNAKEN_WR(x, (HW_USB_ENDPTNAKEN_RD(x) & ~BM_USB_ENDPTNAKEN_EPTNE) | BF_USB_ENDPTNAKEN_EPTNE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_CONFIGFLAG - Configure Flag Register
 ******************************************************************************/

/*!
 * @brief HW_USB_CONFIGFLAG - Configure Flag Register (RO)
 *
 * Reset value: 0x00000001U
 */
typedef union _hw_usb_configflag
{
    uint32_t U;
    struct _hw_usb_configflag_bitfields
    {
        uint32_t CF : 1;               /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_usb_configflag_t;

/*!
 * @name Constants and macros for entire USB_CONFIGFLAG register
 */
/*@{*/
#define HW_USB_CONFIGFLAG_ADDR(x) ((uintptr_t)(x) + 0x180U)

#define HW_USB_CONFIGFLAG(x)     (*(__I hw_usb_configflag_t *) HW_USB_CONFIGFLAG_ADDR(x))
#define HW_USB_CONFIGFLAG_RD(x)  (HW_USB_CONFIGFLAG(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_CONFIGFLAG bitfields
 */

/*!
 * @name Register USB_CONFIGFLAG, field CF[0] (RO)
 *
 * Configure Flag Host software sets this bit as the last action in its process
 * of configuring the Host Controller. This bit controls the default port-routing
 * control logic.
 *
 * Values:
 * - 0 - Port routing control logic default-routes each port to an
 *     implementation dependent classic host controller.
 * - 1 - Port routing control logic default-routes all ports to this host
 *     controller.
 */
/*@{*/
#define BP_USB_CONFIGFLAG_CF (0U)          /*!< Bit position for USB_CONFIGFLAG_CF. */
#define BM_USB_CONFIGFLAG_CF (0x00000001U) /*!< Bit mask for USB_CONFIGFLAG_CF. */
#define BS_USB_CONFIGFLAG_CF (1U)          /*!< Bit field size in bits for USB_CONFIGFLAG_CF. */

/*! @brief Read current value of the USB_CONFIGFLAG_CF field. */
#define BR_USB_CONFIGFLAG_CF(x) (HW_USB_CONFIGFLAG(x).B.CF)
/*@}*/

/*******************************************************************************
 * HW_USB_PORTSC1 - Port Status & Control
 ******************************************************************************/

/*!
 * @brief HW_USB_PORTSC1 - Port Status & Control (RW)
 *
 * Reset value: 0x10000000U
 *
 * Host Controller A host controller could implement one to eight port status
 * and control registers. The number is determined by N_PORTs bits in HWSPARAMs
 * register (please see HCSPARAMSHost Controller Structural Parameters ). Software
 * could read this parameter register to determine how many ports need service.
 * All controller cores on this product are Single-Port, so there is only one port
 * status and control register for each controller core. This register is only
 * reset by power on reset or controller core reset. The initial conditions of a
 * port are: No device connected Port disabled If the port supports power control,
 * this state remains until port power is supplied (by software). Device
 * Controller A controller operating in device mode has only port register one (PORTSC1)
 * and it does not support power control in that mode. Port control in device
 * mode is only used for status port reset, suspend, and current connect status. It
 * is also used to initiate test mode or force signaling and allows software to
 * put the PHY into low power suspend mode and disable the PHY clock.
 */
typedef union _hw_usb_portsc1
{
    uint32_t U;
    struct _hw_usb_portsc1_bitfields
    {
        uint32_t CCS : 1;              /*!< [0]  */
        uint32_t CSC : 1;              /*!< [1]  */
        uint32_t PE : 1;               /*!< [2]  */
        uint32_t PEC : 1;              /*!< [3]  */
        uint32_t OCA : 1;              /*!< [4]  */
        uint32_t OCC : 1;              /*!< [5]  */
        uint32_t FPR : 1;              /*!< [6]  */
        uint32_t SUSP : 1;             /*!< [7]  */
        uint32_t PR : 1;               /*!< [8]  */
        uint32_t HSP : 1;              /*!< [9]  */
        uint32_t LS : 2;               /*!< [11:10]  */
        uint32_t PP : 1;               /*!< [12]  */
        uint32_t PO : 1;               /*!< [13]  */
        uint32_t PIC : 2;              /*!< [15:14]  */
        uint32_t PTC : 4;              /*!< [19:16]  */
        uint32_t WKCN : 1;             /*!< [20]  */
        uint32_t WKDC : 1;             /*!< [21]  */
        uint32_t WKOC : 1;             /*!< [22]  */
        uint32_t PHCD : 1;             /*!< [23]  */
        uint32_t PFSC : 1;             /*!< [24]  */
        uint32_t PTS_2 : 1;            /*!< [25]  */
        uint32_t PSPD : 2;             /*!< [27:26]  */
        uint32_t PTW : 1;              /*!< [28]  */
        uint32_t STS : 1;              /*!< [29]  */
        uint32_t PTS_1 : 2;            /*!< [31:30]  */
    } B;
} hw_usb_portsc1_t;

/*!
 * @name Constants and macros for entire USB_PORTSC1 register
 */
/*@{*/
#define HW_USB_PORTSC1_ADDR(x)   ((uintptr_t)(x) + 0x184U)

#define HW_USB_PORTSC1(x)        (*(__IO hw_usb_portsc1_t *) HW_USB_PORTSC1_ADDR(x))
#define HW_USB_PORTSC1_RD(x)     (HW_USB_PORTSC1(x).U)
#define HW_USB_PORTSC1_WR(x, v)  (HW_USB_PORTSC1(x).U = (v))
#define HW_USB_PORTSC1_SET(x, v) (HW_USB_PORTSC1_WR(x, HW_USB_PORTSC1_RD(x) |  (v)))
#define HW_USB_PORTSC1_CLR(x, v) (HW_USB_PORTSC1_WR(x, HW_USB_PORTSC1_RD(x) & ~(v)))
#define HW_USB_PORTSC1_TOG(x, v) (HW_USB_PORTSC1_WR(x, HW_USB_PORTSC1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_PORTSC1 bitfields
 */

/*!
 * @name Register USB_PORTSC1, field CCS[0] (RO)
 *
 * Current Connect Status-Read Only. In Host Mode: 1=Device is present on port.
 * 0=No device is present. Default = 0. This value reflects the current state of
 * the port, and may not correspond directly to the event that caused the Connect
 * Status Change bit (Bit 1) to be set. This field is zero if Port Power(
 * PORTSC1Port Status & Control ) is zero in host mode. In Device Mode: 1=Attached.
 * 0=Not Attached. Default=0. A one indicates that the device successfully attached
 * and is operating in either high speed or full speed as indicated by the High
 * Speed Port bit in this register. A zero indicates that the device did not
 * attach successfully or was forcibly disconnected by the software writing a zero to
 * the Run bit in the USBCMD register. It does not state the device being
 * disconnected or suspended.
 */
/*@{*/
#define BP_USB_PORTSC1_CCS   (0U)          /*!< Bit position for USB_PORTSC1_CCS. */
#define BM_USB_PORTSC1_CCS   (0x00000001U) /*!< Bit mask for USB_PORTSC1_CCS. */
#define BS_USB_PORTSC1_CCS   (1U)          /*!< Bit field size in bits for USB_PORTSC1_CCS. */

/*! @brief Read current value of the USB_PORTSC1_CCS field. */
#define BR_USB_PORTSC1_CCS(x) (HW_USB_PORTSC1(x).B.CCS)
/*@}*/

/*!
 * @name Register USB_PORTSC1, field CSC[1] (RW)
 *
 * Connect Status Change-R/WC. 1 =Change in Current Connect Status. 0=No change.
 * Default 0. In Host Mode: Indicates a change has occurred in the port's
 * Current Connect Status. The host/device controller sets this bit for all changes to
 * the port device connect status, even if system software has not cleared an
 * existing connect status change. For example, the insertion status changes twice
 * before system software has cleared the changed condition, hub hardware will be
 * 'setting' an already-set bit (that is, the bit will remain set). Software
 * clears this bit by writing a one to it. This field is zero if Port Power(
 * PORTSC1Port Status & Control ) is zero in host mode. In Device Mode: This bit is
 * undefined in device controller mode.
 */
/*@{*/
#define BP_USB_PORTSC1_CSC   (1U)          /*!< Bit position for USB_PORTSC1_CSC. */
#define BM_USB_PORTSC1_CSC   (0x00000002U) /*!< Bit mask for USB_PORTSC1_CSC. */
#define BS_USB_PORTSC1_CSC   (1U)          /*!< Bit field size in bits for USB_PORTSC1_CSC. */

/*! @brief Read current value of the USB_PORTSC1_CSC field. */
#define BR_USB_PORTSC1_CSC(x) (HW_USB_PORTSC1(x).B.CSC)

/*! @brief Format value for bitfield USB_PORTSC1_CSC. */
#define BF_USB_PORTSC1_CSC(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_CSC) & BM_USB_PORTSC1_CSC)

/*! @brief Set the CSC field to a new value. */
#define BW_USB_PORTSC1_CSC(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_CSC) | BF_USB_PORTSC1_CSC(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field PE[2] (RW)
 *
 * Port Enabled/Disabled-Read/Write. 1=Enable. 0=Disable. Default 0. In Host
 * Mode: Ports can only be enabled by the host controller as a part of the reset and
 * enable. Software cannot enable a port by writing a one to this field. Ports
 * can be disabled by either a fault condition (disconnect event or other fault
 * condition) or by the host software. Note that the bit status does not change
 * until the port state actually changes. There may be a delay in disabling or
 * enabling a port due to other host controller and bus events. When the port is
 * disabled, (0b) downstream propagation of data is blocked except for reset. This
 * field is zero if Port Power( PORTSC1Port Status & Control ) is zero in host mode.
 * In Device Mode: The device port is always enabled, so this bit is always '1b'.
 */
/*@{*/
#define BP_USB_PORTSC1_PE    (2U)          /*!< Bit position for USB_PORTSC1_PE. */
#define BM_USB_PORTSC1_PE    (0x00000004U) /*!< Bit mask for USB_PORTSC1_PE. */
#define BS_USB_PORTSC1_PE    (1U)          /*!< Bit field size in bits for USB_PORTSC1_PE. */

/*! @brief Read current value of the USB_PORTSC1_PE field. */
#define BR_USB_PORTSC1_PE(x) (HW_USB_PORTSC1(x).B.PE)

/*! @brief Format value for bitfield USB_PORTSC1_PE. */
#define BF_USB_PORTSC1_PE(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_PE) & BM_USB_PORTSC1_PE)

/*! @brief Set the PE field to a new value. */
#define BW_USB_PORTSC1_PE(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_PE) | BF_USB_PORTSC1_PE(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field PEC[3] (RW)
 *
 * Port Enable/Disable Change-R/WC. 1=Port enabled/disabled status has changed.
 * 0=No change. Default = 0. In Host Mode: For the root hub, this bit is set to a
 * one only when a port is disabled due to disconnect on the port or due to the
 * appropriate conditions existing at the EOF2 point (See Chapter 11 of the USB
 * Specification). Software clears this by writing a one to it. This field is zero
 * if Port Power( PORTSC1Port Status & Control ) is zero. In Device mode: The
 * device port is always enabled, so this bit is always '0b'.
 */
/*@{*/
#define BP_USB_PORTSC1_PEC   (3U)          /*!< Bit position for USB_PORTSC1_PEC. */
#define BM_USB_PORTSC1_PEC   (0x00000008U) /*!< Bit mask for USB_PORTSC1_PEC. */
#define BS_USB_PORTSC1_PEC   (1U)          /*!< Bit field size in bits for USB_PORTSC1_PEC. */

/*! @brief Read current value of the USB_PORTSC1_PEC field. */
#define BR_USB_PORTSC1_PEC(x) (HW_USB_PORTSC1(x).B.PEC)

/*! @brief Format value for bitfield USB_PORTSC1_PEC. */
#define BF_USB_PORTSC1_PEC(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_PEC) & BM_USB_PORTSC1_PEC)

/*! @brief Set the PEC field to a new value. */
#define BW_USB_PORTSC1_PEC(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_PEC) | BF_USB_PORTSC1_PEC(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field OCA[4] (RO)
 *
 * Over-current Active-Read Only. Default 0. This bit will automatically
 * transition from one to zero when the over current condition is removed.
 *
 * Values:
 * - 1 - This port currently has an over-current condition
 * - 0 - This port does not have an over-current condition.
 */
/*@{*/
#define BP_USB_PORTSC1_OCA   (4U)          /*!< Bit position for USB_PORTSC1_OCA. */
#define BM_USB_PORTSC1_OCA   (0x00000010U) /*!< Bit mask for USB_PORTSC1_OCA. */
#define BS_USB_PORTSC1_OCA   (1U)          /*!< Bit field size in bits for USB_PORTSC1_OCA. */

/*! @brief Read current value of the USB_PORTSC1_OCA field. */
#define BR_USB_PORTSC1_OCA(x) (HW_USB_PORTSC1(x).B.OCA)
/*@}*/

/*!
 * @name Register USB_PORTSC1, field OCC[5] (RW)
 *
 * Over-current Change-R/WC. Default=0. This bit is set '1b' by hardware when
 * there is a change to Over-current Active. Software can clear this bit by writing
 * a one to this bit position.
 */
/*@{*/
#define BP_USB_PORTSC1_OCC   (5U)          /*!< Bit position for USB_PORTSC1_OCC. */
#define BM_USB_PORTSC1_OCC   (0x00000020U) /*!< Bit mask for USB_PORTSC1_OCC. */
#define BS_USB_PORTSC1_OCC   (1U)          /*!< Bit field size in bits for USB_PORTSC1_OCC. */

/*! @brief Read current value of the USB_PORTSC1_OCC field. */
#define BR_USB_PORTSC1_OCC(x) (HW_USB_PORTSC1(x).B.OCC)

/*! @brief Format value for bitfield USB_PORTSC1_OCC. */
#define BF_USB_PORTSC1_OCC(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_OCC) & BM_USB_PORTSC1_OCC)

/*! @brief Set the OCC field to a new value. */
#define BW_USB_PORTSC1_OCC(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_OCC) | BF_USB_PORTSC1_OCC(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field FPR[6] (RW)
 *
 * Force Port Resume -Read/Write. 1= Resume detected/driven on port. 0=No resume
 * (K-state) detected/driven on port. Default = 0. In Host Mode: Software sets
 * this bit to one to drive resume signaling. The Host Controller sets this bit to
 * one if a J-to-K transition is detected while the port is in the Suspend
 * state. When this bit transitions to a one because a J-to-K transition is detected,
 * the Port Change Detect bit in the USBSTS register is also set to one. This bit
 * will automatically change to zero after the resume sequence is complete. This
 * behavior is different from EHCI where the host controller driver is required
 * to set this bit to a zero after the resume duration is timed in the driver.
 * Note that when the Host controller owns the port, the resume sequence follows
 * the defined sequence documented in the USB Specification Revision 2.0. The
 * resume signaling (Full-speed 'K') is driven on the port as long as this bit remains
 * a one. This bit will remain a one until the port has switched to the
 * high-speed idle. Writing a zero has no effect because the port controller will time
 * the resume operation, clear the bit the port control state switches to HS or FS
 * idle. This field is zero if Port Power( PORTSC1Port Status & Control ) is zero
 * in host mode. This bit is not-EHCI compatible. In Device mode: After the
 * device has been in Suspend State for 5ms or more, software must set this bit to
 * one to drive resume signaling before clearing. The Device Controller will set
 * this bit to one if a J-to-K transition is detected while the port is in the
 * Suspend state. The bit will be cleared when the device returns to normal
 * operation. Also, when this bit wil be cleared because a K-to-J transition detected, the
 * Port Change Detect bit in the USBSTS register is also set to one.
 */
/*@{*/
#define BP_USB_PORTSC1_FPR   (6U)          /*!< Bit position for USB_PORTSC1_FPR. */
#define BM_USB_PORTSC1_FPR   (0x00000040U) /*!< Bit mask for USB_PORTSC1_FPR. */
#define BS_USB_PORTSC1_FPR   (1U)          /*!< Bit field size in bits for USB_PORTSC1_FPR. */

/*! @brief Read current value of the USB_PORTSC1_FPR field. */
#define BR_USB_PORTSC1_FPR(x) (HW_USB_PORTSC1(x).B.FPR)

/*! @brief Format value for bitfield USB_PORTSC1_FPR. */
#define BF_USB_PORTSC1_FPR(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_FPR) & BM_USB_PORTSC1_FPR)

/*! @brief Set the FPR field to a new value. */
#define BW_USB_PORTSC1_FPR(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_FPR) | BF_USB_PORTSC1_FPR(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field SUSP[7] (RW)
 *
 * Suspend - Read/Write or Read Only. Default = 0b. 1=Port in suspend state.
 * 0=Port not in suspend state. In Host Mode: Read/Write. Port Enabled Bit and
 * Suspend bit of this register define the port states as follows: Bits [Port Enabled,
 * Suspend] Port State 0x Disable 10 Enable 11 Suspend When in suspend state,
 * downstream propagation of data is blocked on this port, except for port reset.
 * The blocking occurs at the end of the current transaction if a transaction was
 * in progress when this bit was written to 1. In the suspend state, the port is
 * sensitive to resume detection. Note that the bit status does not change until
 * the port is suspended and that there may be a delay in suspending a port if
 * there is a transaction currently in progress on the USB. The host controller
 * will unconditionally set this bit to zero when software sets the Force Port
 * Resume bit to zero. The host controller ignores a write of zero to this bit. If
 * host software sets this bit to a one when the port is not enabled (that is, Port
 * enabled bit is a zero) the results are undefined. This field is zero if Port
 * Power( PORTSC1Port Status & Control ) is zero in host mode. In Device Mode:
 * Read Only. In device mode this bit is a read only status bit.
 */
/*@{*/
#define BP_USB_PORTSC1_SUSP  (7U)          /*!< Bit position for USB_PORTSC1_SUSP. */
#define BM_USB_PORTSC1_SUSP  (0x00000080U) /*!< Bit mask for USB_PORTSC1_SUSP. */
#define BS_USB_PORTSC1_SUSP  (1U)          /*!< Bit field size in bits for USB_PORTSC1_SUSP. */

/*! @brief Read current value of the USB_PORTSC1_SUSP field. */
#define BR_USB_PORTSC1_SUSP(x) (HW_USB_PORTSC1(x).B.SUSP)

/*! @brief Format value for bitfield USB_PORTSC1_SUSP. */
#define BF_USB_PORTSC1_SUSP(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_SUSP) & BM_USB_PORTSC1_SUSP)

/*! @brief Set the SUSP field to a new value. */
#define BW_USB_PORTSC1_SUSP(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_SUSP) | BF_USB_PORTSC1_SUSP(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field PR[8] (RW)
 *
 * Port Reset - Read/Write or Read Only. Default = 0b. In Host Mode: Read/Write.
 * 1=Port is in Reset. 0=Port is not in Reset. Default 0. When software writes a
 * one to this bit the bus-reset sequence as defined in the USB Specification
 * Revision 2.0 is started. This bit will automatically change to zero after the
 * reset sequence is complete. This behavior is different from EHCI where the host
 * controller driver is required to set this bit to a zero after the reset
 * duration is timed in the driver. In Device Mode: This bit is a read only status bit.
 * Device reset from the USB bus is also indicated in the USBSTS register. This
 * field is zero if Port Power( PORTSC1Port Status & Control ) is zero.
 */
/*@{*/
#define BP_USB_PORTSC1_PR    (8U)          /*!< Bit position for USB_PORTSC1_PR. */
#define BM_USB_PORTSC1_PR    (0x00000100U) /*!< Bit mask for USB_PORTSC1_PR. */
#define BS_USB_PORTSC1_PR    (1U)          /*!< Bit field size in bits for USB_PORTSC1_PR. */

/*! @brief Read current value of the USB_PORTSC1_PR field. */
#define BR_USB_PORTSC1_PR(x) (HW_USB_PORTSC1(x).B.PR)

/*! @brief Format value for bitfield USB_PORTSC1_PR. */
#define BF_USB_PORTSC1_PR(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_PR) & BM_USB_PORTSC1_PR)

/*! @brief Set the PR field to a new value. */
#define BW_USB_PORTSC1_PR(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_PR) | BF_USB_PORTSC1_PR(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field HSP[9] (RO)
 *
 * High-Speed Port - Read Only. Default = 0b. When the bit is one, the
 * host/device connected to the port is in high-speed mode and if set to zero, the
 * host/device connected to the port is not in a high-speed mode. HSP is redundant with
 * PSPD(bit 27, 26) but remained for compatibility.
 */
/*@{*/
#define BP_USB_PORTSC1_HSP   (9U)          /*!< Bit position for USB_PORTSC1_HSP. */
#define BM_USB_PORTSC1_HSP   (0x00000200U) /*!< Bit mask for USB_PORTSC1_HSP. */
#define BS_USB_PORTSC1_HSP   (1U)          /*!< Bit field size in bits for USB_PORTSC1_HSP. */

/*! @brief Read current value of the USB_PORTSC1_HSP field. */
#define BR_USB_PORTSC1_HSP(x) (HW_USB_PORTSC1(x).B.HSP)
/*@}*/

/*!
 * @name Register USB_PORTSC1, field LS[11:10] (RW)
 *
 * Line Status-Read Only. These bits reflect the current logical levels of the
 * D+ (bit 11) and D- (bit 10) signal lines. In host mode, the use of linestate by
 * the host controller driver is not necessary (unlike EHCI), because the port
 * controller state machine and the port routing manage the connection of LS and
 * FS. In device mode, the use of linestate by the device controller driver is not
 * necessary. The encoding of the bits are: Bits [11:10] Meaning
 *
 * Values:
 * - 00 - SE0
 * - 10 - J-state
 * - 01 - K-state
 * - 11 - Undefined
 */
/*@{*/
#define BP_USB_PORTSC1_LS    (10U)         /*!< Bit position for USB_PORTSC1_LS. */
#define BM_USB_PORTSC1_LS    (0x00000C00U) /*!< Bit mask for USB_PORTSC1_LS. */
#define BS_USB_PORTSC1_LS    (2U)          /*!< Bit field size in bits for USB_PORTSC1_LS. */

/*! @brief Read current value of the USB_PORTSC1_LS field. */
#define BR_USB_PORTSC1_LS(x) (HW_USB_PORTSC1(x).B.LS)

/*! @brief Format value for bitfield USB_PORTSC1_LS. */
#define BF_USB_PORTSC1_LS(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_LS) & BM_USB_PORTSC1_LS)

/*! @brief Set the LS field to a new value. */
#define BW_USB_PORTSC1_LS(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_LS) | BF_USB_PORTSC1_LS(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field PP[12] (RW)
 *
 * Port Power (PP)-Read/Write or Read Only. The function of this bit depends on
 * the value of the Port Power Switching (PPC) field in the HCSPARAMS register.
 * The behavior is as follows: PPC PP Operation 0 1b Read Only - Host controller
 * does not have port power control switches. Each port is hard-wired to power. 1
 * 1b/0b - Read/Write. Host/OTG controller requires port power control switches.
 * This bit represents the current setting of the switch (0=off, 1=on). When
 * power is not available on a port (that is, PP equals a 0), the port is
 * non-functional and will not report attaches, detaches, etc. When an over-current
 * condition is detected on a powered port and PPC is a one, the PP bit in each affected
 * port may be transitional by the host controller driver from a one to a zero
 * (removing power from the port). This feature is implemented in all controller
 * cores (PPC = 1).
 */
/*@{*/
#define BP_USB_PORTSC1_PP    (12U)         /*!< Bit position for USB_PORTSC1_PP. */
#define BM_USB_PORTSC1_PP    (0x00001000U) /*!< Bit mask for USB_PORTSC1_PP. */
#define BS_USB_PORTSC1_PP    (1U)          /*!< Bit field size in bits for USB_PORTSC1_PP. */

/*! @brief Read current value of the USB_PORTSC1_PP field. */
#define BR_USB_PORTSC1_PP(x) (HW_USB_PORTSC1(x).B.PP)

/*! @brief Format value for bitfield USB_PORTSC1_PP. */
#define BF_USB_PORTSC1_PP(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_PP) & BM_USB_PORTSC1_PP)

/*! @brief Set the PP field to a new value. */
#define BW_USB_PORTSC1_PP(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_PP) | BF_USB_PORTSC1_PP(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field PO[13] (RW)
 *
 * Port Owner-Read/Write. Default = 0. This bit unconditionally goes to a 0 when
 * the configured bit in the CONFIGFLAG register makes a 0 to 1 transition. This
 * bit unconditionally goes to 1 whenever the Configured bit is zero System
 * software uses this field to release ownership of the port to a selected host
 * controller (in the event that the attached device is not a high-speed device).
 * Software writes a one to this bit when the attached device is not a high-speed
 * device. A one in this bit means that an internal companion controller owns and
 * controls the port. Port owner handoff is not supported in all controller cores,
 * therefore this bit will always be 0.
 */
/*@{*/
#define BP_USB_PORTSC1_PO    (13U)         /*!< Bit position for USB_PORTSC1_PO. */
#define BM_USB_PORTSC1_PO    (0x00002000U) /*!< Bit mask for USB_PORTSC1_PO. */
#define BS_USB_PORTSC1_PO    (1U)          /*!< Bit field size in bits for USB_PORTSC1_PO. */

/*! @brief Read current value of the USB_PORTSC1_PO field. */
#define BR_USB_PORTSC1_PO(x) (HW_USB_PORTSC1(x).B.PO)

/*! @brief Format value for bitfield USB_PORTSC1_PO. */
#define BF_USB_PORTSC1_PO(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_PO) & BM_USB_PORTSC1_PO)

/*! @brief Set the PO field to a new value. */
#define BW_USB_PORTSC1_PO(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_PO) | BF_USB_PORTSC1_PO(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field PIC[15:14] (RW)
 *
 * Port Indicator Control - Read/Write. Default = Ob. Writing to this field has
 * no effect if the P_INDICATOR bit in the HCSPARAMS register is a zero. Refer to
 * the USB Specification Revision 2.0 for a description on how these bits are to
 * be used. This field is zero if Port Power is zero. Bit Value Meaning
 *
 * Values:
 * - 00 - Port indicators are off
 * - 01 - Amber
 * - 10 - Green
 * - 11 - Undefined
 */
/*@{*/
#define BP_USB_PORTSC1_PIC   (14U)         /*!< Bit position for USB_PORTSC1_PIC. */
#define BM_USB_PORTSC1_PIC   (0x0000C000U) /*!< Bit mask for USB_PORTSC1_PIC. */
#define BS_USB_PORTSC1_PIC   (2U)          /*!< Bit field size in bits for USB_PORTSC1_PIC. */

/*! @brief Read current value of the USB_PORTSC1_PIC field. */
#define BR_USB_PORTSC1_PIC(x) (HW_USB_PORTSC1(x).B.PIC)

/*! @brief Format value for bitfield USB_PORTSC1_PIC. */
#define BF_USB_PORTSC1_PIC(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_PIC) & BM_USB_PORTSC1_PIC)

/*! @brief Set the PIC field to a new value. */
#define BW_USB_PORTSC1_PIC(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_PIC) | BF_USB_PORTSC1_PIC(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field PTC[19:16] (RW)
 *
 * Port Test Control - Read/Write. Default = 0000b. Refer to Port Test Mode for
 * the operational model for using these test modes and the USB Specification
 * Revision 2.0, Chapter 7 for details on each test mode. The FORCE_ENABLE_FS and
 * FORCE ENABLE_LS are extensions to the test mode support specified in the EHCI
 * specification. Writing the PTC field to any of the FORCE_ENABLE_{HS/FS/LS}
 * values will force the port into the connected and enabled state at the selected
 * speed. Writing the PTC field back to TEST_MODE_DISABLE will allow the port state
 * machines to progress normally from that point. Low speed operations are not
 * supported as a peripheral device. Any other value than zero indicates that the
 * port is operating in test mode. Value Specific Test
 *
 * Values:
 * - 0000 - TEST_MODE_DISABLE
 * - 0001 - J_STATE
 * - 0010 - K_STATE
 * - 0011 - SE0 (host) / NAK (device)
 * - 0100 - Packet
 * - 0101 - FORCE_ENABLE_HS
 * - 0110 - FORCE_ENABLE_FS
 * - 0111 - FORCE_ENABLE_LS
 */
/*@{*/
#define BP_USB_PORTSC1_PTC   (16U)         /*!< Bit position for USB_PORTSC1_PTC. */
#define BM_USB_PORTSC1_PTC   (0x000F0000U) /*!< Bit mask for USB_PORTSC1_PTC. */
#define BS_USB_PORTSC1_PTC   (4U)          /*!< Bit field size in bits for USB_PORTSC1_PTC. */

/*! @brief Read current value of the USB_PORTSC1_PTC field. */
#define BR_USB_PORTSC1_PTC(x) (HW_USB_PORTSC1(x).B.PTC)

/*! @brief Format value for bitfield USB_PORTSC1_PTC. */
#define BF_USB_PORTSC1_PTC(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_PTC) & BM_USB_PORTSC1_PTC)

/*! @brief Set the PTC field to a new value. */
#define BW_USB_PORTSC1_PTC(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_PTC) | BF_USB_PORTSC1_PTC(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field WKCN[20] (RW)
 *
 * Wake on Connect Enable (WKCNNT_E) - Read/Write. Default=0b. Writing this bit
 * to a one enables the port to be sensitive to device connects as wake-up
 * events. This field is zero if Port Power( PORTSC1Port Status & Control ) is zero or
 * in device mode.
 */
/*@{*/
#define BP_USB_PORTSC1_WKCN  (20U)         /*!< Bit position for USB_PORTSC1_WKCN. */
#define BM_USB_PORTSC1_WKCN  (0x00100000U) /*!< Bit mask for USB_PORTSC1_WKCN. */
#define BS_USB_PORTSC1_WKCN  (1U)          /*!< Bit field size in bits for USB_PORTSC1_WKCN. */

/*! @brief Read current value of the USB_PORTSC1_WKCN field. */
#define BR_USB_PORTSC1_WKCN(x) (HW_USB_PORTSC1(x).B.WKCN)

/*! @brief Format value for bitfield USB_PORTSC1_WKCN. */
#define BF_USB_PORTSC1_WKCN(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_WKCN) & BM_USB_PORTSC1_WKCN)

/*! @brief Set the WKCN field to a new value. */
#define BW_USB_PORTSC1_WKCN(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_WKCN) | BF_USB_PORTSC1_WKCN(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field WKDC[21] (RW)
 *
 * Wake on Disconnect Enable (WKDSCNNT_E) - Read/Write. Default=0b. Writing this
 * bit to a one enables the port to be sensitive to device disconnects as
 * wake-up events. This field is zero if Port Power( PORTSC1Port Status & Control ) is
 * zero or in device mode.
 */
/*@{*/
#define BP_USB_PORTSC1_WKDC  (21U)         /*!< Bit position for USB_PORTSC1_WKDC. */
#define BM_USB_PORTSC1_WKDC  (0x00200000U) /*!< Bit mask for USB_PORTSC1_WKDC. */
#define BS_USB_PORTSC1_WKDC  (1U)          /*!< Bit field size in bits for USB_PORTSC1_WKDC. */

/*! @brief Read current value of the USB_PORTSC1_WKDC field. */
#define BR_USB_PORTSC1_WKDC(x) (HW_USB_PORTSC1(x).B.WKDC)

/*! @brief Format value for bitfield USB_PORTSC1_WKDC. */
#define BF_USB_PORTSC1_WKDC(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_WKDC) & BM_USB_PORTSC1_WKDC)

/*! @brief Set the WKDC field to a new value. */
#define BW_USB_PORTSC1_WKDC(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_WKDC) | BF_USB_PORTSC1_WKDC(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field WKOC[22] (RW)
 *
 * Wake on Over-current Enable (WKOC_E) - Read/Write. Default = 0b. Writing this
 * bit to a one enables the port to be sensitive to over-current conditions as
 * wake-up events. This field is zero if Port Power( PORTSC1Port Status & Control
 * ) is zero.
 */
/*@{*/
#define BP_USB_PORTSC1_WKOC  (22U)         /*!< Bit position for USB_PORTSC1_WKOC. */
#define BM_USB_PORTSC1_WKOC  (0x00400000U) /*!< Bit mask for USB_PORTSC1_WKOC. */
#define BS_USB_PORTSC1_WKOC  (1U)          /*!< Bit field size in bits for USB_PORTSC1_WKOC. */

/*! @brief Read current value of the USB_PORTSC1_WKOC field. */
#define BR_USB_PORTSC1_WKOC(x) (HW_USB_PORTSC1(x).B.WKOC)

/*! @brief Format value for bitfield USB_PORTSC1_WKOC. */
#define BF_USB_PORTSC1_WKOC(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_WKOC) & BM_USB_PORTSC1_WKOC)

/*! @brief Set the WKOC field to a new value. */
#define BW_USB_PORTSC1_WKOC(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_WKOC) | BF_USB_PORTSC1_WKOC(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field PHCD[23] (RW)
 *
 * PHY Low Power Suspend - Clock Disable (PLPSCD) - Read/Write. Default = 0b.
 * When this bit is set to '1b', the PHY clock is disabled. Reading this bit will
 * indicate the status of the PHY clock. The PHY clock cannot be disabled if it is
 * being used as the system clock. In device mode, The PHY can be put into Low
 * Power Suspend when the device is not running (USBCMD Run/Stop=0b) or the host
 * has signalled suspend (PORTSC1 SUSPEND=1b). PHY Low power suspend will be
 * cleared automatically when the host initials resume. Before forcing a resume from
 * the device, the device controller driver must clear this bit. In host mode, the
 * PHY can be put into Low Power Suspend when the downstream device has been put
 * into suspend mode or when no downstream device is connected. Low power
 * suspend is completely under the control of software.
 *
 * Values:
 * - 1 - Disable PHY clock
 * - 0 - Enable PHY clock
 */
/*@{*/
#define BP_USB_PORTSC1_PHCD  (23U)         /*!< Bit position for USB_PORTSC1_PHCD. */
#define BM_USB_PORTSC1_PHCD  (0x00800000U) /*!< Bit mask for USB_PORTSC1_PHCD. */
#define BS_USB_PORTSC1_PHCD  (1U)          /*!< Bit field size in bits for USB_PORTSC1_PHCD. */

/*! @brief Read current value of the USB_PORTSC1_PHCD field. */
#define BR_USB_PORTSC1_PHCD(x) (HW_USB_PORTSC1(x).B.PHCD)

/*! @brief Format value for bitfield USB_PORTSC1_PHCD. */
#define BF_USB_PORTSC1_PHCD(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_PHCD) & BM_USB_PORTSC1_PHCD)

/*! @brief Set the PHCD field to a new value. */
#define BW_USB_PORTSC1_PHCD(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_PHCD) | BF_USB_PORTSC1_PHCD(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field PFSC[24] (RW)
 *
 * Port Force Full Speed Connect - Read/Write. Default = 0b. When this bit is
 * set to '1b', the port will be forced to only connect at Full Speed, It disables
 * the chirp sequence that allows the port to identify itself as High Speed.
 *
 * Values:
 * - 1 - Forced to full speed
 * - 0 - Normal operation
 */
/*@{*/
#define BP_USB_PORTSC1_PFSC  (24U)         /*!< Bit position for USB_PORTSC1_PFSC. */
#define BM_USB_PORTSC1_PFSC  (0x01000000U) /*!< Bit mask for USB_PORTSC1_PFSC. */
#define BS_USB_PORTSC1_PFSC  (1U)          /*!< Bit field size in bits for USB_PORTSC1_PFSC. */

/*! @brief Read current value of the USB_PORTSC1_PFSC field. */
#define BR_USB_PORTSC1_PFSC(x) (HW_USB_PORTSC1(x).B.PFSC)

/*! @brief Format value for bitfield USB_PORTSC1_PFSC. */
#define BF_USB_PORTSC1_PFSC(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_PFSC) & BM_USB_PORTSC1_PFSC)

/*! @brief Set the PFSC field to a new value. */
#define BW_USB_PORTSC1_PFSC(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_PFSC) | BF_USB_PORTSC1_PFSC(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field PTS_2[25] (RW)
 *
 * See description at bits 31-30
 */
/*@{*/
#define BP_USB_PORTSC1_PTS_2 (25U)         /*!< Bit position for USB_PORTSC1_PTS_2. */
#define BM_USB_PORTSC1_PTS_2 (0x02000000U) /*!< Bit mask for USB_PORTSC1_PTS_2. */
#define BS_USB_PORTSC1_PTS_2 (1U)          /*!< Bit field size in bits for USB_PORTSC1_PTS_2. */

/*! @brief Read current value of the USB_PORTSC1_PTS_2 field. */
#define BR_USB_PORTSC1_PTS_2(x) (HW_USB_PORTSC1(x).B.PTS_2)

/*! @brief Format value for bitfield USB_PORTSC1_PTS_2. */
#define BF_USB_PORTSC1_PTS_2(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_PTS_2) & BM_USB_PORTSC1_PTS_2)

/*! @brief Set the PTS_2 field to a new value. */
#define BW_USB_PORTSC1_PTS_2(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_PTS_2) | BF_USB_PORTSC1_PTS_2(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field PSPD[27:26] (RW)
 *
 * Port Speed - Read Only. This register field indicates the speed at which the
 * port is operating.
 *
 * Values:
 * - 00 - Full Speed
 * - 01 - Low Speed
 * - 10 - High Speed
 * - 11 - Undefined
 */
/*@{*/
#define BP_USB_PORTSC1_PSPD  (26U)         /*!< Bit position for USB_PORTSC1_PSPD. */
#define BM_USB_PORTSC1_PSPD  (0x0C000000U) /*!< Bit mask for USB_PORTSC1_PSPD. */
#define BS_USB_PORTSC1_PSPD  (2U)          /*!< Bit field size in bits for USB_PORTSC1_PSPD. */

/*! @brief Read current value of the USB_PORTSC1_PSPD field. */
#define BR_USB_PORTSC1_PSPD(x) (HW_USB_PORTSC1(x).B.PSPD)

/*! @brief Format value for bitfield USB_PORTSC1_PSPD. */
#define BF_USB_PORTSC1_PSPD(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_PSPD) & BM_USB_PORTSC1_PSPD)

/*! @brief Set the PSPD field to a new value. */
#define BW_USB_PORTSC1_PSPD(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_PSPD) | BF_USB_PORTSC1_PSPD(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field PTW[28] (RW)
 *
 * Parallel Transceiver Width This bit has no effect if serial interface engine
 * is used. For OTG1/OTG2/Host1 core, it is Read-Only. Reset value is '1b'.
 *
 * Values:
 * - 0 - Select the 8-bit UTMI interface [60MHz]
 * - 1 - Select the 16-bit UTMI interface [30MHz]
 */
/*@{*/
#define BP_USB_PORTSC1_PTW   (28U)         /*!< Bit position for USB_PORTSC1_PTW. */
#define BM_USB_PORTSC1_PTW   (0x10000000U) /*!< Bit mask for USB_PORTSC1_PTW. */
#define BS_USB_PORTSC1_PTW   (1U)          /*!< Bit field size in bits for USB_PORTSC1_PTW. */

/*! @brief Read current value of the USB_PORTSC1_PTW field. */
#define BR_USB_PORTSC1_PTW(x) (HW_USB_PORTSC1(x).B.PTW)

/*! @brief Format value for bitfield USB_PORTSC1_PTW. */
#define BF_USB_PORTSC1_PTW(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_PTW) & BM_USB_PORTSC1_PTW)

/*! @brief Set the PTW field to a new value. */
#define BW_USB_PORTSC1_PTW(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_PTW) | BF_USB_PORTSC1_PTW(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field STS[29] (RW)
 *
 * Serial Transceiver Select - Read Only Serial Transceiver Select 1 Serial
 * Interface Engine is selected 0 Parallel Interface signals is selected Serial
 * Interface Engine can be used in combination with UTMI+/ULPI physical interface to
 * provide FS/LS signaling instead of the parallel interface signals. When this
 * bit is set '1b', serial interface engine will be used instead of parallel
 * interface signals. This bit has no effect unless PTS bits is set to select
 * UTMI+/ULPI interface. The Serial/USB1.1 PHY/IC-USB will use the serial interface engine
 * for FS/LS signaling regardless of this bit value.
 */
/*@{*/
#define BP_USB_PORTSC1_STS   (29U)         /*!< Bit position for USB_PORTSC1_STS. */
#define BM_USB_PORTSC1_STS   (0x20000000U) /*!< Bit mask for USB_PORTSC1_STS. */
#define BS_USB_PORTSC1_STS   (1U)          /*!< Bit field size in bits for USB_PORTSC1_STS. */

/*! @brief Read current value of the USB_PORTSC1_STS field. */
#define BR_USB_PORTSC1_STS(x) (HW_USB_PORTSC1(x).B.STS)

/*! @brief Format value for bitfield USB_PORTSC1_STS. */
#define BF_USB_PORTSC1_STS(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_STS) & BM_USB_PORTSC1_STS)

/*! @brief Set the STS field to a new value. */
#define BW_USB_PORTSC1_STS(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_STS) | BF_USB_PORTSC1_STS(v)))
/*@}*/

/*!
 * @name Register USB_PORTSC1, field PTS_1[31:30] (RW)
 *
 * Bit field {bit25, bit31, bit30}: "000b" UTMI/UTMI+ "001b" Reserved "010b"
 * ULPI "011b" Serial/USB 1.1 PHY/IC-USB (FS Only) "100b" HSIC Parallel Transceiver
 * Select (bit25, bit31, bi30). For OTG core, it is Read-Only. Reset value is
 * 000b. All USB port interface modes are listed in this field description, but not
 * all are supported. For detail feature of each controller core, please see
 * Features . The behaviour is unknown when unsupported interface mode is selected.
 */
/*@{*/
#define BP_USB_PORTSC1_PTS_1 (30U)         /*!< Bit position for USB_PORTSC1_PTS_1. */
#define BM_USB_PORTSC1_PTS_1 (0xC0000000U) /*!< Bit mask for USB_PORTSC1_PTS_1. */
#define BS_USB_PORTSC1_PTS_1 (2U)          /*!< Bit field size in bits for USB_PORTSC1_PTS_1. */

/*! @brief Read current value of the USB_PORTSC1_PTS_1 field. */
#define BR_USB_PORTSC1_PTS_1(x) (HW_USB_PORTSC1(x).B.PTS_1)

/*! @brief Format value for bitfield USB_PORTSC1_PTS_1. */
#define BF_USB_PORTSC1_PTS_1(v) ((uint32_t)((uint32_t)(v) << BP_USB_PORTSC1_PTS_1) & BM_USB_PORTSC1_PTS_1)

/*! @brief Set the PTS_1 field to a new value. */
#define BW_USB_PORTSC1_PTS_1(x, v) (HW_USB_PORTSC1_WR(x, (HW_USB_PORTSC1_RD(x) & ~BM_USB_PORTSC1_PTS_1) | BF_USB_PORTSC1_PTS_1(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_OTGSC - On-The-Go Status & control
 ******************************************************************************/

/*!
 * @brief HW_USB_OTGSC - On-The-Go Status & control (RW)
 *
 * Reset value: 0x00000120U
 *
 * This register is availabe only in OTG controller core. It has four sections:
 * OTG Interrupt enables (Read/Write) OTG Interrupt status (Read/Write to Clear)
 * OTG Status inputs (Read Only) OTG Controls (Read/Write) The status inputs are
 * debounced using a 1 ms time constant. Values on the status inputs that do not
 * persist for more than 1 ms does not cause an update of the status input
 * register, or cause an OTG interrupt. See also USBMODEUSB Device Mode register.
 */
typedef union _hw_usb_otgsc
{
    uint32_t U;
    struct _hw_usb_otgsc_bitfields
    {
        uint32_t VD : 1;               /*!< [0]  */
        uint32_t VC : 1;               /*!< [1]  */
        uint32_t RESERVED0 : 1;        /*!< [2]  */
        uint32_t OT : 1;               /*!< [3]  */
        uint32_t DP : 1;               /*!< [4]  */
        uint32_t IDPU : 1;             /*!< [5]  */
        uint32_t RESERVED1 : 2;        /*!< [7:6]  */
        uint32_t ID : 1;               /*!< [8]  */
        uint32_t AVV : 1;              /*!< [9]  */
        uint32_t ASV : 1;              /*!< [10]  */
        uint32_t BSV : 1;              /*!< [11]  */
        uint32_t BSE : 1;              /*!< [12]  */
        uint32_t TOG_1MS : 1;          /*!< [13]  */
        uint32_t DPS : 1;              /*!< [14]  */
        uint32_t RESERVED2 : 1;        /*!< [15]  */
        uint32_t IDIS : 1;             /*!< [16]  */
        uint32_t AVVIS : 1;            /*!< [17]  */
        uint32_t ASVIS : 1;            /*!< [18]  */
        uint32_t BSVIS : 1;            /*!< [19]  */
        uint32_t BSEIS : 1;            /*!< [20]  */
        uint32_t STATUS_1MS : 1;       /*!< [21]  */
        uint32_t DPIS : 1;             /*!< [22]  */
        uint32_t RESERVED3 : 1;        /*!< [23]  */
        uint32_t IDIE : 1;             /*!< [24]  */
        uint32_t AVVIE : 1;            /*!< [25]  */
        uint32_t ASVIE : 1;            /*!< [26]  */
        uint32_t BSVIE : 1;            /*!< [27]  */
        uint32_t BSEIE : 1;            /*!< [28]  */
        uint32_t EN_1MS : 1;           /*!< [29]  */
        uint32_t DPIE : 1;             /*!< [30]  */
        uint32_t RESERVED4 : 1;        /*!< [31]  */
    } B;
} hw_usb_otgsc_t;

/*!
 * @name Constants and macros for entire USB_OTGSC register
 */
/*@{*/
#define HW_USB_OTGSC_ADDR(x)     ((uintptr_t)(x) + 0x1A4U)

#define HW_USB_OTGSC(x)          (*(__IO hw_usb_otgsc_t *) HW_USB_OTGSC_ADDR(x))
#define HW_USB_OTGSC_RD(x)       (HW_USB_OTGSC(x).U)
#define HW_USB_OTGSC_WR(x, v)    (HW_USB_OTGSC(x).U = (v))
#define HW_USB_OTGSC_SET(x, v)   (HW_USB_OTGSC_WR(x, HW_USB_OTGSC_RD(x) |  (v)))
#define HW_USB_OTGSC_CLR(x, v)   (HW_USB_OTGSC_WR(x, HW_USB_OTGSC_RD(x) & ~(v)))
#define HW_USB_OTGSC_TOG(x, v)   (HW_USB_OTGSC_WR(x, HW_USB_OTGSC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_OTGSC bitfields
 */

/*!
 * @name Register USB_OTGSC, field VD[0] (RW)
 *
 * VBUS_Discharge - Read/Write. Setting this bit causes VBus to discharge
 * through a resistor.
 */
/*@{*/
#define BP_USB_OTGSC_VD      (0U)          /*!< Bit position for USB_OTGSC_VD. */
#define BM_USB_OTGSC_VD      (0x00000001U) /*!< Bit mask for USB_OTGSC_VD. */
#define BS_USB_OTGSC_VD      (1U)          /*!< Bit field size in bits for USB_OTGSC_VD. */

/*! @brief Read current value of the USB_OTGSC_VD field. */
#define BR_USB_OTGSC_VD(x)   (HW_USB_OTGSC(x).B.VD)

/*! @brief Format value for bitfield USB_OTGSC_VD. */
#define BF_USB_OTGSC_VD(v)   ((uint32_t)((uint32_t)(v) << BP_USB_OTGSC_VD) & BM_USB_OTGSC_VD)

/*! @brief Set the VD field to a new value. */
#define BW_USB_OTGSC_VD(x, v) (HW_USB_OTGSC_WR(x, (HW_USB_OTGSC_RD(x) & ~BM_USB_OTGSC_VD) | BF_USB_OTGSC_VD(v)))
/*@}*/

/*!
 * @name Register USB_OTGSC, field VC[1] (RW)
 *
 * VBUS Charge - Read/Write. Setting this bit causes the VBus line to be
 * charged. This is used for VBus pulsing during SRP.
 */
/*@{*/
#define BP_USB_OTGSC_VC      (1U)          /*!< Bit position for USB_OTGSC_VC. */
#define BM_USB_OTGSC_VC      (0x00000002U) /*!< Bit mask for USB_OTGSC_VC. */
#define BS_USB_OTGSC_VC      (1U)          /*!< Bit field size in bits for USB_OTGSC_VC. */

/*! @brief Read current value of the USB_OTGSC_VC field. */
#define BR_USB_OTGSC_VC(x)   (HW_USB_OTGSC(x).B.VC)

/*! @brief Format value for bitfield USB_OTGSC_VC. */
#define BF_USB_OTGSC_VC(v)   ((uint32_t)((uint32_t)(v) << BP_USB_OTGSC_VC) & BM_USB_OTGSC_VC)

/*! @brief Set the VC field to a new value. */
#define BW_USB_OTGSC_VC(x, v) (HW_USB_OTGSC_WR(x, (HW_USB_OTGSC_RD(x) & ~BM_USB_OTGSC_VC) | BF_USB_OTGSC_VC(v)))
/*@}*/

/*!
 * @name Register USB_OTGSC, field OT[3] (RW)
 *
 * OTG Termination - Read/Write. This bit must be set when the OTG device is in
 * device mode, this controls the pulldown on DM.
 */
/*@{*/
#define BP_USB_OTGSC_OT      (3U)          /*!< Bit position for USB_OTGSC_OT. */
#define BM_USB_OTGSC_OT      (0x00000008U) /*!< Bit mask for USB_OTGSC_OT. */
#define BS_USB_OTGSC_OT      (1U)          /*!< Bit field size in bits for USB_OTGSC_OT. */

/*! @brief Read current value of the USB_OTGSC_OT field. */
#define BR_USB_OTGSC_OT(x)   (HW_USB_OTGSC(x).B.OT)

/*! @brief Format value for bitfield USB_OTGSC_OT. */
#define BF_USB_OTGSC_OT(v)   ((uint32_t)((uint32_t)(v) << BP_USB_OTGSC_OT) & BM_USB_OTGSC_OT)

/*! @brief Set the OT field to a new value. */
#define BW_USB_OTGSC_OT(x, v) (HW_USB_OTGSC_WR(x, (HW_USB_OTGSC_RD(x) & ~BM_USB_OTGSC_OT) | BF_USB_OTGSC_OT(v)))
/*@}*/

/*!
 * @name Register USB_OTGSC, field DP[4] (RW)
 *
 * Data Pulsing - Read/Write. Setting this bit causes the pullup on DP to be
 * asserted for data pulsing during SRP.
 */
/*@{*/
#define BP_USB_OTGSC_DP      (4U)          /*!< Bit position for USB_OTGSC_DP. */
#define BM_USB_OTGSC_DP      (0x00000010U) /*!< Bit mask for USB_OTGSC_DP. */
#define BS_USB_OTGSC_DP      (1U)          /*!< Bit field size in bits for USB_OTGSC_DP. */

/*! @brief Read current value of the USB_OTGSC_DP field. */
#define BR_USB_OTGSC_DP(x)   (HW_USB_OTGSC(x).B.DP)

/*! @brief Format value for bitfield USB_OTGSC_DP. */
#define BF_USB_OTGSC_DP(v)   ((uint32_t)((uint32_t)(v) << BP_USB_OTGSC_DP) & BM_USB_OTGSC_DP)

/*! @brief Set the DP field to a new value. */
#define BW_USB_OTGSC_DP(x, v) (HW_USB_OTGSC_WR(x, (HW_USB_OTGSC_RD(x) & ~BM_USB_OTGSC_DP) | BF_USB_OTGSC_DP(v)))
/*@}*/

/*!
 * @name Register USB_OTGSC, field IDPU[5] (RW)
 *
 * ID Pullup - Read/Write This bit provide control over the ID pull-up resistor;
 * 0 = off, 1 = on [default]. When this bit is 0, the ID input will not be
 * sampled.
 */
/*@{*/
#define BP_USB_OTGSC_IDPU    (5U)          /*!< Bit position for USB_OTGSC_IDPU. */
#define BM_USB_OTGSC_IDPU    (0x00000020U) /*!< Bit mask for USB_OTGSC_IDPU. */
#define BS_USB_OTGSC_IDPU    (1U)          /*!< Bit field size in bits for USB_OTGSC_IDPU. */

/*! @brief Read current value of the USB_OTGSC_IDPU field. */
#define BR_USB_OTGSC_IDPU(x) (HW_USB_OTGSC(x).B.IDPU)

/*! @brief Format value for bitfield USB_OTGSC_IDPU. */
#define BF_USB_OTGSC_IDPU(v) ((uint32_t)((uint32_t)(v) << BP_USB_OTGSC_IDPU) & BM_USB_OTGSC_IDPU)

/*! @brief Set the IDPU field to a new value. */
#define BW_USB_OTGSC_IDPU(x, v) (HW_USB_OTGSC_WR(x, (HW_USB_OTGSC_RD(x) & ~BM_USB_OTGSC_IDPU) | BF_USB_OTGSC_IDPU(v)))
/*@}*/

/*!
 * @name Register USB_OTGSC, field ID[8] (RO)
 *
 * USB ID - Read Only. 0 = A device, 1 = B device
 */
/*@{*/
#define BP_USB_OTGSC_ID      (8U)          /*!< Bit position for USB_OTGSC_ID. */
#define BM_USB_OTGSC_ID      (0x00000100U) /*!< Bit mask for USB_OTGSC_ID. */
#define BS_USB_OTGSC_ID      (1U)          /*!< Bit field size in bits for USB_OTGSC_ID. */

/*! @brief Read current value of the USB_OTGSC_ID field. */
#define BR_USB_OTGSC_ID(x)   (HW_USB_OTGSC(x).B.ID)
/*@}*/

/*!
 * @name Register USB_OTGSC, field AVV[9] (RO)
 *
 * A VBus Valid - Read Only. Indicates VBus is above the A VBus valid threshold.
 */
/*@{*/
#define BP_USB_OTGSC_AVV     (9U)          /*!< Bit position for USB_OTGSC_AVV. */
#define BM_USB_OTGSC_AVV     (0x00000200U) /*!< Bit mask for USB_OTGSC_AVV. */
#define BS_USB_OTGSC_AVV     (1U)          /*!< Bit field size in bits for USB_OTGSC_AVV. */

/*! @brief Read current value of the USB_OTGSC_AVV field. */
#define BR_USB_OTGSC_AVV(x)  (HW_USB_OTGSC(x).B.AVV)
/*@}*/

/*!
 * @name Register USB_OTGSC, field ASV[10] (RO)
 *
 * A Session Valid - Read Only. Indicates VBus is above the A session valid
 * threshold.
 */
/*@{*/
#define BP_USB_OTGSC_ASV     (10U)         /*!< Bit position for USB_OTGSC_ASV. */
#define BM_USB_OTGSC_ASV     (0x00000400U) /*!< Bit mask for USB_OTGSC_ASV. */
#define BS_USB_OTGSC_ASV     (1U)          /*!< Bit field size in bits for USB_OTGSC_ASV. */

/*! @brief Read current value of the USB_OTGSC_ASV field. */
#define BR_USB_OTGSC_ASV(x)  (HW_USB_OTGSC(x).B.ASV)
/*@}*/

/*!
 * @name Register USB_OTGSC, field BSV[11] (RO)
 *
 * B Session Valid - Read Only. Indicates VBus is above the B session valid
 * threshold.
 */
/*@{*/
#define BP_USB_OTGSC_BSV     (11U)         /*!< Bit position for USB_OTGSC_BSV. */
#define BM_USB_OTGSC_BSV     (0x00000800U) /*!< Bit mask for USB_OTGSC_BSV. */
#define BS_USB_OTGSC_BSV     (1U)          /*!< Bit field size in bits for USB_OTGSC_BSV. */

/*! @brief Read current value of the USB_OTGSC_BSV field. */
#define BR_USB_OTGSC_BSV(x)  (HW_USB_OTGSC(x).B.BSV)
/*@}*/

/*!
 * @name Register USB_OTGSC, field BSE[12] (RO)
 *
 * B Session End - Read Only. Indicates VBus is below the B session end
 * threshold.
 */
/*@{*/
#define BP_USB_OTGSC_BSE     (12U)         /*!< Bit position for USB_OTGSC_BSE. */
#define BM_USB_OTGSC_BSE     (0x00001000U) /*!< Bit mask for USB_OTGSC_BSE. */
#define BS_USB_OTGSC_BSE     (1U)          /*!< Bit field size in bits for USB_OTGSC_BSE. */

/*! @brief Read current value of the USB_OTGSC_BSE field. */
#define BR_USB_OTGSC_BSE(x)  (HW_USB_OTGSC(x).B.BSE)
/*@}*/

/*!
 * @name Register USB_OTGSC, field TOG_1MS[13] (RO)
 *
 * 1 millisecond timer toggle - Read Only. This bit toggles once per millisecond.
 */
/*@{*/
#define BP_USB_OTGSC_TOG_1MS (13U)         /*!< Bit position for USB_OTGSC_TOG_1MS. */
#define BM_USB_OTGSC_TOG_1MS (0x00002000U) /*!< Bit mask for USB_OTGSC_TOG_1MS. */
#define BS_USB_OTGSC_TOG_1MS (1U)          /*!< Bit field size in bits for USB_OTGSC_TOG_1MS. */

/*! @brief Read current value of the USB_OTGSC_TOG_1MS field. */
#define BR_USB_OTGSC_TOG_1MS(x) (HW_USB_OTGSC(x).B.TOG_1MS)
/*@}*/

/*!
 * @name Register USB_OTGSC, field DPS[14] (RO)
 *
 * Data Bus Pulsing Status - Read Only. A '1' indicates data bus pulsing is
 * being detected on the port.
 */
/*@{*/
#define BP_USB_OTGSC_DPS     (14U)         /*!< Bit position for USB_OTGSC_DPS. */
#define BM_USB_OTGSC_DPS     (0x00004000U) /*!< Bit mask for USB_OTGSC_DPS. */
#define BS_USB_OTGSC_DPS     (1U)          /*!< Bit field size in bits for USB_OTGSC_DPS. */

/*! @brief Read current value of the USB_OTGSC_DPS field. */
#define BR_USB_OTGSC_DPS(x)  (HW_USB_OTGSC(x).B.DPS)
/*@}*/

/*!
 * @name Register USB_OTGSC, field IDIS[16] (RW)
 *
 * USB ID Interrupt Status - Read/Write. This bit is set when a change on the ID
 * input has been detected. Software must write a one to clear this bit.
 */
/*@{*/
#define BP_USB_OTGSC_IDIS    (16U)         /*!< Bit position for USB_OTGSC_IDIS. */
#define BM_USB_OTGSC_IDIS    (0x00010000U) /*!< Bit mask for USB_OTGSC_IDIS. */
#define BS_USB_OTGSC_IDIS    (1U)          /*!< Bit field size in bits for USB_OTGSC_IDIS. */

/*! @brief Read current value of the USB_OTGSC_IDIS field. */
#define BR_USB_OTGSC_IDIS(x) (HW_USB_OTGSC(x).B.IDIS)

/*! @brief Format value for bitfield USB_OTGSC_IDIS. */
#define BF_USB_OTGSC_IDIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_OTGSC_IDIS) & BM_USB_OTGSC_IDIS)

/*! @brief Set the IDIS field to a new value. */
#define BW_USB_OTGSC_IDIS(x, v) (HW_USB_OTGSC_WR(x, (HW_USB_OTGSC_RD(x) & ~BM_USB_OTGSC_IDIS) | BF_USB_OTGSC_IDIS(v)))
/*@}*/

/*!
 * @name Register USB_OTGSC, field AVVIS[17] (RW)
 *
 * A VBus Valid Interrupt Status - Read/Write to Clear. This bit is set when
 * VBus has either risen above or fallen below the VBus valid threshold on an A
 * device. Software must write a one to clear this bit.
 */
/*@{*/
#define BP_USB_OTGSC_AVVIS   (17U)         /*!< Bit position for USB_OTGSC_AVVIS. */
#define BM_USB_OTGSC_AVVIS   (0x00020000U) /*!< Bit mask for USB_OTGSC_AVVIS. */
#define BS_USB_OTGSC_AVVIS   (1U)          /*!< Bit field size in bits for USB_OTGSC_AVVIS. */

/*! @brief Read current value of the USB_OTGSC_AVVIS field. */
#define BR_USB_OTGSC_AVVIS(x) (HW_USB_OTGSC(x).B.AVVIS)

/*! @brief Format value for bitfield USB_OTGSC_AVVIS. */
#define BF_USB_OTGSC_AVVIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_OTGSC_AVVIS) & BM_USB_OTGSC_AVVIS)

/*! @brief Set the AVVIS field to a new value. */
#define BW_USB_OTGSC_AVVIS(x, v) (HW_USB_OTGSC_WR(x, (HW_USB_OTGSC_RD(x) & ~BM_USB_OTGSC_AVVIS) | BF_USB_OTGSC_AVVIS(v)))
/*@}*/

/*!
 * @name Register USB_OTGSC, field ASVIS[18] (RW)
 *
 * A Session Valid Interrupt Status - Read/Write to Clear. This bit is set when
 * VBus has either risen above or fallen below the A session valid threshold.
 * Software must write a one to clear this bit.
 */
/*@{*/
#define BP_USB_OTGSC_ASVIS   (18U)         /*!< Bit position for USB_OTGSC_ASVIS. */
#define BM_USB_OTGSC_ASVIS   (0x00040000U) /*!< Bit mask for USB_OTGSC_ASVIS. */
#define BS_USB_OTGSC_ASVIS   (1U)          /*!< Bit field size in bits for USB_OTGSC_ASVIS. */

/*! @brief Read current value of the USB_OTGSC_ASVIS field. */
#define BR_USB_OTGSC_ASVIS(x) (HW_USB_OTGSC(x).B.ASVIS)

/*! @brief Format value for bitfield USB_OTGSC_ASVIS. */
#define BF_USB_OTGSC_ASVIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_OTGSC_ASVIS) & BM_USB_OTGSC_ASVIS)

/*! @brief Set the ASVIS field to a new value. */
#define BW_USB_OTGSC_ASVIS(x, v) (HW_USB_OTGSC_WR(x, (HW_USB_OTGSC_RD(x) & ~BM_USB_OTGSC_ASVIS) | BF_USB_OTGSC_ASVIS(v)))
/*@}*/

/*!
 * @name Register USB_OTGSC, field BSVIS[19] (RW)
 *
 * B Session Valid Interrupt Status - Read/Write to Clear. This bit is set when
 * VBus has either risen above or fallen below the B session valid threshold.
 * Software must write a one to clear this bit.
 */
/*@{*/
#define BP_USB_OTGSC_BSVIS   (19U)         /*!< Bit position for USB_OTGSC_BSVIS. */
#define BM_USB_OTGSC_BSVIS   (0x00080000U) /*!< Bit mask for USB_OTGSC_BSVIS. */
#define BS_USB_OTGSC_BSVIS   (1U)          /*!< Bit field size in bits for USB_OTGSC_BSVIS. */

/*! @brief Read current value of the USB_OTGSC_BSVIS field. */
#define BR_USB_OTGSC_BSVIS(x) (HW_USB_OTGSC(x).B.BSVIS)

/*! @brief Format value for bitfield USB_OTGSC_BSVIS. */
#define BF_USB_OTGSC_BSVIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_OTGSC_BSVIS) & BM_USB_OTGSC_BSVIS)

/*! @brief Set the BSVIS field to a new value. */
#define BW_USB_OTGSC_BSVIS(x, v) (HW_USB_OTGSC_WR(x, (HW_USB_OTGSC_RD(x) & ~BM_USB_OTGSC_BSVIS) | BF_USB_OTGSC_BSVIS(v)))
/*@}*/

/*!
 * @name Register USB_OTGSC, field BSEIS[20] (RW)
 *
 * B Session End Interrupt Status - Read/Write to Clear. This bit is set when
 * VBus has fallen below the B session end threshold. Software must write a one to
 * clear this bit.
 */
/*@{*/
#define BP_USB_OTGSC_BSEIS   (20U)         /*!< Bit position for USB_OTGSC_BSEIS. */
#define BM_USB_OTGSC_BSEIS   (0x00100000U) /*!< Bit mask for USB_OTGSC_BSEIS. */
#define BS_USB_OTGSC_BSEIS   (1U)          /*!< Bit field size in bits for USB_OTGSC_BSEIS. */

/*! @brief Read current value of the USB_OTGSC_BSEIS field. */
#define BR_USB_OTGSC_BSEIS(x) (HW_USB_OTGSC(x).B.BSEIS)

/*! @brief Format value for bitfield USB_OTGSC_BSEIS. */
#define BF_USB_OTGSC_BSEIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_OTGSC_BSEIS) & BM_USB_OTGSC_BSEIS)

/*! @brief Set the BSEIS field to a new value. */
#define BW_USB_OTGSC_BSEIS(x, v) (HW_USB_OTGSC_WR(x, (HW_USB_OTGSC_RD(x) & ~BM_USB_OTGSC_BSEIS) | BF_USB_OTGSC_BSEIS(v)))
/*@}*/

/*!
 * @name Register USB_OTGSC, field STATUS_1MS[21] (RW)
 *
 * 1 millisecond timer Interrupt Status - Read/Write to Clear. This bit is set
 * once every millisecond. Software must write a one to clear this bit.
 */
/*@{*/
#define BP_USB_OTGSC_STATUS_1MS (21U)      /*!< Bit position for USB_OTGSC_STATUS_1MS. */
#define BM_USB_OTGSC_STATUS_1MS (0x00200000U) /*!< Bit mask for USB_OTGSC_STATUS_1MS. */
#define BS_USB_OTGSC_STATUS_1MS (1U)       /*!< Bit field size in bits for USB_OTGSC_STATUS_1MS. */

/*! @brief Read current value of the USB_OTGSC_STATUS_1MS field. */
#define BR_USB_OTGSC_STATUS_1MS(x) (HW_USB_OTGSC(x).B.STATUS_1MS)

/*! @brief Format value for bitfield USB_OTGSC_STATUS_1MS. */
#define BF_USB_OTGSC_STATUS_1MS(v) ((uint32_t)((uint32_t)(v) << BP_USB_OTGSC_STATUS_1MS) & BM_USB_OTGSC_STATUS_1MS)

/*! @brief Set the STATUS_1MS field to a new value. */
#define BW_USB_OTGSC_STATUS_1MS(x, v) (HW_USB_OTGSC_WR(x, (HW_USB_OTGSC_RD(x) & ~BM_USB_OTGSC_STATUS_1MS) | BF_USB_OTGSC_STATUS_1MS(v)))
/*@}*/

/*!
 * @name Register USB_OTGSC, field DPIS[22] (RW)
 *
 * Data Pulse Interrupt Status - Read/Write to Clear. This bit is set when data
 * bus pulsing occurs on DP or DM. Data bus pulsing is only detected when
 * USBMODE.CM = Host (11) and PORTSC1(0)[PP] = 0. Software must write a one to clear
 * this bit.
 */
/*@{*/
#define BP_USB_OTGSC_DPIS    (22U)         /*!< Bit position for USB_OTGSC_DPIS. */
#define BM_USB_OTGSC_DPIS    (0x00400000U) /*!< Bit mask for USB_OTGSC_DPIS. */
#define BS_USB_OTGSC_DPIS    (1U)          /*!< Bit field size in bits for USB_OTGSC_DPIS. */

/*! @brief Read current value of the USB_OTGSC_DPIS field. */
#define BR_USB_OTGSC_DPIS(x) (HW_USB_OTGSC(x).B.DPIS)

/*! @brief Format value for bitfield USB_OTGSC_DPIS. */
#define BF_USB_OTGSC_DPIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_OTGSC_DPIS) & BM_USB_OTGSC_DPIS)

/*! @brief Set the DPIS field to a new value. */
#define BW_USB_OTGSC_DPIS(x, v) (HW_USB_OTGSC_WR(x, (HW_USB_OTGSC_RD(x) & ~BM_USB_OTGSC_DPIS) | BF_USB_OTGSC_DPIS(v)))
/*@}*/

/*!
 * @name Register USB_OTGSC, field IDIE[24] (RW)
 *
 * USB ID Interrupt Enable - Read/Write. Setting this bit enables the USB ID
 * interrupt.
 */
/*@{*/
#define BP_USB_OTGSC_IDIE    (24U)         /*!< Bit position for USB_OTGSC_IDIE. */
#define BM_USB_OTGSC_IDIE    (0x01000000U) /*!< Bit mask for USB_OTGSC_IDIE. */
#define BS_USB_OTGSC_IDIE    (1U)          /*!< Bit field size in bits for USB_OTGSC_IDIE. */

/*! @brief Read current value of the USB_OTGSC_IDIE field. */
#define BR_USB_OTGSC_IDIE(x) (HW_USB_OTGSC(x).B.IDIE)

/*! @brief Format value for bitfield USB_OTGSC_IDIE. */
#define BF_USB_OTGSC_IDIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_OTGSC_IDIE) & BM_USB_OTGSC_IDIE)

/*! @brief Set the IDIE field to a new value. */
#define BW_USB_OTGSC_IDIE(x, v) (HW_USB_OTGSC_WR(x, (HW_USB_OTGSC_RD(x) & ~BM_USB_OTGSC_IDIE) | BF_USB_OTGSC_IDIE(v)))
/*@}*/

/*!
 * @name Register USB_OTGSC, field AVVIE[25] (RW)
 *
 * A VBus Valid Interrupt Enable - Read/Write. Setting this bit enables the A
 * VBus valid interrupt.
 */
/*@{*/
#define BP_USB_OTGSC_AVVIE   (25U)         /*!< Bit position for USB_OTGSC_AVVIE. */
#define BM_USB_OTGSC_AVVIE   (0x02000000U) /*!< Bit mask for USB_OTGSC_AVVIE. */
#define BS_USB_OTGSC_AVVIE   (1U)          /*!< Bit field size in bits for USB_OTGSC_AVVIE. */

/*! @brief Read current value of the USB_OTGSC_AVVIE field. */
#define BR_USB_OTGSC_AVVIE(x) (HW_USB_OTGSC(x).B.AVVIE)

/*! @brief Format value for bitfield USB_OTGSC_AVVIE. */
#define BF_USB_OTGSC_AVVIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_OTGSC_AVVIE) & BM_USB_OTGSC_AVVIE)

/*! @brief Set the AVVIE field to a new value. */
#define BW_USB_OTGSC_AVVIE(x, v) (HW_USB_OTGSC_WR(x, (HW_USB_OTGSC_RD(x) & ~BM_USB_OTGSC_AVVIE) | BF_USB_OTGSC_AVVIE(v)))
/*@}*/

/*!
 * @name Register USB_OTGSC, field ASVIE[26] (RW)
 *
 * A Session Valid Interrupt Enable - Read/Write. Setting this bit enables the A
 * session valid interrupt.
 */
/*@{*/
#define BP_USB_OTGSC_ASVIE   (26U)         /*!< Bit position for USB_OTGSC_ASVIE. */
#define BM_USB_OTGSC_ASVIE   (0x04000000U) /*!< Bit mask for USB_OTGSC_ASVIE. */
#define BS_USB_OTGSC_ASVIE   (1U)          /*!< Bit field size in bits for USB_OTGSC_ASVIE. */

/*! @brief Read current value of the USB_OTGSC_ASVIE field. */
#define BR_USB_OTGSC_ASVIE(x) (HW_USB_OTGSC(x).B.ASVIE)

/*! @brief Format value for bitfield USB_OTGSC_ASVIE. */
#define BF_USB_OTGSC_ASVIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_OTGSC_ASVIE) & BM_USB_OTGSC_ASVIE)

/*! @brief Set the ASVIE field to a new value. */
#define BW_USB_OTGSC_ASVIE(x, v) (HW_USB_OTGSC_WR(x, (HW_USB_OTGSC_RD(x) & ~BM_USB_OTGSC_ASVIE) | BF_USB_OTGSC_ASVIE(v)))
/*@}*/

/*!
 * @name Register USB_OTGSC, field BSVIE[27] (RW)
 *
 * B Session Valid Interrupt Enable - Read/Write. Setting this bit enables the B
 * session valid interrupt.
 */
/*@{*/
#define BP_USB_OTGSC_BSVIE   (27U)         /*!< Bit position for USB_OTGSC_BSVIE. */
#define BM_USB_OTGSC_BSVIE   (0x08000000U) /*!< Bit mask for USB_OTGSC_BSVIE. */
#define BS_USB_OTGSC_BSVIE   (1U)          /*!< Bit field size in bits for USB_OTGSC_BSVIE. */

/*! @brief Read current value of the USB_OTGSC_BSVIE field. */
#define BR_USB_OTGSC_BSVIE(x) (HW_USB_OTGSC(x).B.BSVIE)

/*! @brief Format value for bitfield USB_OTGSC_BSVIE. */
#define BF_USB_OTGSC_BSVIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_OTGSC_BSVIE) & BM_USB_OTGSC_BSVIE)

/*! @brief Set the BSVIE field to a new value. */
#define BW_USB_OTGSC_BSVIE(x, v) (HW_USB_OTGSC_WR(x, (HW_USB_OTGSC_RD(x) & ~BM_USB_OTGSC_BSVIE) | BF_USB_OTGSC_BSVIE(v)))
/*@}*/

/*!
 * @name Register USB_OTGSC, field BSEIE[28] (RW)
 *
 * B Session End Interrupt Enable - Read/Write. Setting this bit enables the B
 * session end interrupt.
 */
/*@{*/
#define BP_USB_OTGSC_BSEIE   (28U)         /*!< Bit position for USB_OTGSC_BSEIE. */
#define BM_USB_OTGSC_BSEIE   (0x10000000U) /*!< Bit mask for USB_OTGSC_BSEIE. */
#define BS_USB_OTGSC_BSEIE   (1U)          /*!< Bit field size in bits for USB_OTGSC_BSEIE. */

/*! @brief Read current value of the USB_OTGSC_BSEIE field. */
#define BR_USB_OTGSC_BSEIE(x) (HW_USB_OTGSC(x).B.BSEIE)

/*! @brief Format value for bitfield USB_OTGSC_BSEIE. */
#define BF_USB_OTGSC_BSEIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_OTGSC_BSEIE) & BM_USB_OTGSC_BSEIE)

/*! @brief Set the BSEIE field to a new value. */
#define BW_USB_OTGSC_BSEIE(x, v) (HW_USB_OTGSC_WR(x, (HW_USB_OTGSC_RD(x) & ~BM_USB_OTGSC_BSEIE) | BF_USB_OTGSC_BSEIE(v)))
/*@}*/

/*!
 * @name Register USB_OTGSC, field EN_1MS[29] (RW)
 *
 * 1 millisecond timer Interrupt Enable - Read/Write
 */
/*@{*/
#define BP_USB_OTGSC_EN_1MS  (29U)         /*!< Bit position for USB_OTGSC_EN_1MS. */
#define BM_USB_OTGSC_EN_1MS  (0x20000000U) /*!< Bit mask for USB_OTGSC_EN_1MS. */
#define BS_USB_OTGSC_EN_1MS  (1U)          /*!< Bit field size in bits for USB_OTGSC_EN_1MS. */

/*! @brief Read current value of the USB_OTGSC_EN_1MS field. */
#define BR_USB_OTGSC_EN_1MS(x) (HW_USB_OTGSC(x).B.EN_1MS)

/*! @brief Format value for bitfield USB_OTGSC_EN_1MS. */
#define BF_USB_OTGSC_EN_1MS(v) ((uint32_t)((uint32_t)(v) << BP_USB_OTGSC_EN_1MS) & BM_USB_OTGSC_EN_1MS)

/*! @brief Set the EN_1MS field to a new value. */
#define BW_USB_OTGSC_EN_1MS(x, v) (HW_USB_OTGSC_WR(x, (HW_USB_OTGSC_RD(x) & ~BM_USB_OTGSC_EN_1MS) | BF_USB_OTGSC_EN_1MS(v)))
/*@}*/

/*!
 * @name Register USB_OTGSC, field DPIE[30] (RW)
 *
 * Data Pulse Interrupt Enable
 */
/*@{*/
#define BP_USB_OTGSC_DPIE    (30U)         /*!< Bit position for USB_OTGSC_DPIE. */
#define BM_USB_OTGSC_DPIE    (0x40000000U) /*!< Bit mask for USB_OTGSC_DPIE. */
#define BS_USB_OTGSC_DPIE    (1U)          /*!< Bit field size in bits for USB_OTGSC_DPIE. */

/*! @brief Read current value of the USB_OTGSC_DPIE field. */
#define BR_USB_OTGSC_DPIE(x) (HW_USB_OTGSC(x).B.DPIE)

/*! @brief Format value for bitfield USB_OTGSC_DPIE. */
#define BF_USB_OTGSC_DPIE(v) ((uint32_t)((uint32_t)(v) << BP_USB_OTGSC_DPIE) & BM_USB_OTGSC_DPIE)

/*! @brief Set the DPIE field to a new value. */
#define BW_USB_OTGSC_DPIE(x, v) (HW_USB_OTGSC_WR(x, (HW_USB_OTGSC_RD(x) & ~BM_USB_OTGSC_DPIE) | BF_USB_OTGSC_DPIE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_USBMODE - USB Device Mode
 ******************************************************************************/

/*!
 * @brief HW_USB_USBMODE - USB Device Mode (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_usb_usbmode
{
    uint32_t U;
    struct _hw_usb_usbmode_bitfields
    {
        uint32_t CM : 2;               /*!< [1:0]  */
        uint32_t ES : 1;               /*!< [2]  */
        uint32_t SLOM : 1;             /*!< [3]  */
        uint32_t SDIS : 1;             /*!< [4]  */
        uint32_t RESERVED0 : 27;       /*!< [31:5]  */
    } B;
} hw_usb_usbmode_t;

/*!
 * @name Constants and macros for entire USB_USBMODE register
 */
/*@{*/
#define HW_USB_USBMODE_ADDR(x)   ((uintptr_t)(x) + 0x1A8U)

#define HW_USB_USBMODE(x)        (*(__IO hw_usb_usbmode_t *) HW_USB_USBMODE_ADDR(x))
#define HW_USB_USBMODE_RD(x)     (HW_USB_USBMODE(x).U)
#define HW_USB_USBMODE_WR(x, v)  (HW_USB_USBMODE(x).U = (v))
#define HW_USB_USBMODE_SET(x, v) (HW_USB_USBMODE_WR(x, HW_USB_USBMODE_RD(x) |  (v)))
#define HW_USB_USBMODE_CLR(x, v) (HW_USB_USBMODE_WR(x, HW_USB_USBMODE_RD(x) & ~(v)))
#define HW_USB_USBMODE_TOG(x, v) (HW_USB_USBMODE_WR(x, HW_USB_USBMODE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_USBMODE bitfields
 */

/*!
 * @name Register USB_USBMODE, field CM[1:0] (RW)
 *
 * Controller Mode - R/WO. Controller mode is defaulted to the proper mode for
 * host only and device only implementations. For those designs that contain both
 * host & device capability, the controller defaults to an idle state and needs
 * to be initialized to the desired operating mode after reset. For combination
 * host/device controllers, this register can only be written once after reset. If
 * it is necessary to switch modes, software must reset the controller by writing
 * to the RESET bit in the USBCMD register before reprogramming this register.
 * For OTG controller core, reset value is '00b'. For Host-only controller core,
 * reset value is '11b'.
 *
 * Values:
 * - 00 - Idle [Default for combination host/device]
 * - 01 - Reserved
 * - 10 - Device Controller [Default for device only controller]
 * - 11 - Host Controller [Default for host only controller]
 */
/*@{*/
#define BP_USB_USBMODE_CM    (0U)          /*!< Bit position for USB_USBMODE_CM. */
#define BM_USB_USBMODE_CM    (0x00000003U) /*!< Bit mask for USB_USBMODE_CM. */
#define BS_USB_USBMODE_CM    (2U)          /*!< Bit field size in bits for USB_USBMODE_CM. */

/*! @brief Read current value of the USB_USBMODE_CM field. */
#define BR_USB_USBMODE_CM(x) (HW_USB_USBMODE(x).B.CM)

/*! @brief Format value for bitfield USB_USBMODE_CM. */
#define BF_USB_USBMODE_CM(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBMODE_CM) & BM_USB_USBMODE_CM)

/*! @brief Set the CM field to a new value. */
#define BW_USB_USBMODE_CM(x, v) (HW_USB_USBMODE_WR(x, (HW_USB_USBMODE_RD(x) & ~BM_USB_USBMODE_CM) | BF_USB_USBMODE_CM(v)))
/*@}*/

/*!
 * @name Register USB_USBMODE, field ES[2] (RW)
 *
 * Endian Select - Read/Write. This bit can change the byte alignment of the
 * transfer buffers to match the host microprocessor. The bit fields in the
 * microprocessor interface and the data structures are unaffected by the value of this
 * bit because they are based upon the 32-bit word. Bit Meaning
 *
 * Values:
 * - 0 - Little Endian [Default]
 * - 1 - Big Endian
 */
/*@{*/
#define BP_USB_USBMODE_ES    (2U)          /*!< Bit position for USB_USBMODE_ES. */
#define BM_USB_USBMODE_ES    (0x00000004U) /*!< Bit mask for USB_USBMODE_ES. */
#define BS_USB_USBMODE_ES    (1U)          /*!< Bit field size in bits for USB_USBMODE_ES. */

/*! @brief Read current value of the USB_USBMODE_ES field. */
#define BR_USB_USBMODE_ES(x) (HW_USB_USBMODE(x).B.ES)

/*! @brief Format value for bitfield USB_USBMODE_ES. */
#define BF_USB_USBMODE_ES(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBMODE_ES) & BM_USB_USBMODE_ES)

/*! @brief Set the ES field to a new value. */
#define BW_USB_USBMODE_ES(x, v) (HW_USB_USBMODE_WR(x, (HW_USB_USBMODE_RD(x) & ~BM_USB_USBMODE_ES) | BF_USB_USBMODE_ES(v)))
/*@}*/

/*!
 * @name Register USB_USBMODE, field SLOM[3] (RW)
 *
 * Setup Lockout Mode. In device mode, this bit controls behavior of the setup
 * lock mechanism. See Control Endpoint Operation Model .
 *
 * Values:
 * - 0 - Setup Lockouts On (default);
 * - 1 - Setup Lockouts Off (DCD requires use of Setup Data Buffer Tripwire in
 *     USBCMDUSB Command Register .
 */
/*@{*/
#define BP_USB_USBMODE_SLOM  (3U)          /*!< Bit position for USB_USBMODE_SLOM. */
#define BM_USB_USBMODE_SLOM  (0x00000008U) /*!< Bit mask for USB_USBMODE_SLOM. */
#define BS_USB_USBMODE_SLOM  (1U)          /*!< Bit field size in bits for USB_USBMODE_SLOM. */

/*! @brief Read current value of the USB_USBMODE_SLOM field. */
#define BR_USB_USBMODE_SLOM(x) (HW_USB_USBMODE(x).B.SLOM)

/*! @brief Format value for bitfield USB_USBMODE_SLOM. */
#define BF_USB_USBMODE_SLOM(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBMODE_SLOM) & BM_USB_USBMODE_SLOM)

/*! @brief Set the SLOM field to a new value. */
#define BW_USB_USBMODE_SLOM(x, v) (HW_USB_USBMODE_WR(x, (HW_USB_USBMODE_RD(x) & ~BM_USB_USBMODE_SLOM) | BF_USB_USBMODE_SLOM(v)))
/*@}*/

/*!
 * @name Register USB_USBMODE, field SDIS[4] (RW)
 *
 * Stream Disable Mode. (0 - Inactive [default]; 1 - Active) Device Mode:
 * Setting to a '1' disables double priming on both RX and TX for low bandwidth
 * systems. This mode ensures that when the RX and TX buffers are sufficient to contain
 * an entire packet that the standard double buffering scheme is disabled to
 * prevent overruns/underruns in bandwidth limited systems. Note: In High Speed Mode,
 * all packets received are responded to with a NYET handshake when stream
 * disable is active. Host Mode: Setting to a '1' ensures that overruns/underruns of
 * the latency FIFO are eliminated for low bandwidth systems where the RX and TX
 * buffers are sufficient to contain the entire packet. Enabling stream disable
 * also has the effect of ensuring the TX latency is filled to capacity before the
 * packet is launched onto the USB. Time duration to pre-fill the FIFO becomes
 * significant when stream disable is active. See TXFILLTUNINGTX FIFO Fill Tuning
 * and TXTTFILLTUNING [MPH Only] to characterize the adjustments needed for the
 * scheduler when using this feature. The use of this feature substantially limits
 * of the overall USB performance that can be achieved.
 */
/*@{*/
#define BP_USB_USBMODE_SDIS  (4U)          /*!< Bit position for USB_USBMODE_SDIS. */
#define BM_USB_USBMODE_SDIS  (0x00000010U) /*!< Bit mask for USB_USBMODE_SDIS. */
#define BS_USB_USBMODE_SDIS  (1U)          /*!< Bit field size in bits for USB_USBMODE_SDIS. */

/*! @brief Read current value of the USB_USBMODE_SDIS field. */
#define BR_USB_USBMODE_SDIS(x) (HW_USB_USBMODE(x).B.SDIS)

/*! @brief Format value for bitfield USB_USBMODE_SDIS. */
#define BF_USB_USBMODE_SDIS(v) ((uint32_t)((uint32_t)(v) << BP_USB_USBMODE_SDIS) & BM_USB_USBMODE_SDIS)

/*! @brief Set the SDIS field to a new value. */
#define BW_USB_USBMODE_SDIS(x, v) (HW_USB_USBMODE_WR(x, (HW_USB_USBMODE_RD(x) & ~BM_USB_USBMODE_SDIS) | BF_USB_USBMODE_SDIS(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_ENDPTSETUPSTAT - Endpoint Setup Status
 ******************************************************************************/

/*!
 * @brief HW_USB_ENDPTSETUPSTAT - Endpoint Setup Status (RW)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_usb_endptsetupstat
{
    uint32_t U;
    struct _hw_usb_endptsetupstat_bitfields
    {
        uint32_t ENDPTSETUPSTAT : 16;  /*!< [15:0]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_usb_endptsetupstat_t;

/*!
 * @name Constants and macros for entire USB_ENDPTSETUPSTAT register
 */
/*@{*/
#define HW_USB_ENDPTSETUPSTAT_ADDR(x) ((uintptr_t)(x) + 0x1ACU)

#define HW_USB_ENDPTSETUPSTAT(x) (*(__IO hw_usb_endptsetupstat_t *) HW_USB_ENDPTSETUPSTAT_ADDR(x))
#define HW_USB_ENDPTSETUPSTAT_RD(x) (HW_USB_ENDPTSETUPSTAT(x).U)
#define HW_USB_ENDPTSETUPSTAT_WR(x, v) (HW_USB_ENDPTSETUPSTAT(x).U = (v))
#define HW_USB_ENDPTSETUPSTAT_SET(x, v) (HW_USB_ENDPTSETUPSTAT_WR(x, HW_USB_ENDPTSETUPSTAT_RD(x) |  (v)))
#define HW_USB_ENDPTSETUPSTAT_CLR(x, v) (HW_USB_ENDPTSETUPSTAT_WR(x, HW_USB_ENDPTSETUPSTAT_RD(x) & ~(v)))
#define HW_USB_ENDPTSETUPSTAT_TOG(x, v) (HW_USB_ENDPTSETUPSTAT_WR(x, HW_USB_ENDPTSETUPSTAT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_ENDPTSETUPSTAT bitfields
 */

/*!
 * @name Register USB_ENDPTSETUPSTAT, field ENDPTSETUPSTAT[15:0] (RW)
 *
 * Setup Endpoint Status. For every setup transaction that is received, a
 * corresponding bit in this register is set to one. Software must clear or acknowledge
 * the setup transfer by writing a one to a respective bit after it has read the
 * setup data from Queue head. The response to a setup packet as in the order of
 * operations and total response time is crucial to limit bus time outs while
 * the setup lock our mechanism is engaged. See Managing EndpointsThe USB 2.0
 * specification defines an endpoint, also called a device endpoint or an address
 * endpoint as a uniquely addressable portion of a USB device that can source or sink
 * data in a communications channel between the host and the device. in the
 * Device Operational Model. This register is only used in device mode.
 */
/*@{*/
#define BP_USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT (0U) /*!< Bit position for USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT. */
#define BM_USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT (0x0000FFFFU) /*!< Bit mask for USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT. */
#define BS_USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT (16U) /*!< Bit field size in bits for USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT. */

/*! @brief Read current value of the USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT field. */
#define BR_USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT(x) (HW_USB_ENDPTSETUPSTAT(x).B.ENDPTSETUPSTAT)

/*! @brief Format value for bitfield USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT. */
#define BF_USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT) & BM_USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT)

/*! @brief Set the ENDPTSETUPSTAT field to a new value. */
#define BW_USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT(x, v) (HW_USB_ENDPTSETUPSTAT_WR(x, (HW_USB_ENDPTSETUPSTAT_RD(x) & ~BM_USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT) | BF_USB_ENDPTSETUPSTAT_ENDPTSETUPSTAT(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_ENDPTPRIME - Endpoint Prime
 ******************************************************************************/

/*!
 * @brief HW_USB_ENDPTPRIME - Endpoint Prime (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is only used in device mode. When software sets the prime bit
 * for a given endpoint, the device controller loads the transfer descriptor,
 * pointed to by the queue head, such that the endpoint is ready to transmit or
 * receive when the host sends a request (IN/OUT token). The endpoint will NAK all
 * requests from the host until the endpoint is primed. The controller will
 * automatically re-prime the endpoint with a new transfer descriptor when one is found
 * via the next_dtd pointer of the current transfer descriptor. Hence, the prime
 * bit must only be set by software when a descriptor is added to the queue head.
 */
typedef union _hw_usb_endptprime
{
    uint32_t U;
    struct _hw_usb_endptprime_bitfields
    {
        uint32_t PERB : 8;             /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t PETB : 8;             /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_endptprime_t;

/*!
 * @name Constants and macros for entire USB_ENDPTPRIME register
 */
/*@{*/
#define HW_USB_ENDPTPRIME_ADDR(x) ((uintptr_t)(x) + 0x1B0U)

#define HW_USB_ENDPTPRIME(x)     (*(__IO hw_usb_endptprime_t *) HW_USB_ENDPTPRIME_ADDR(x))
#define HW_USB_ENDPTPRIME_RD(x)  (HW_USB_ENDPTPRIME(x).U)
#define HW_USB_ENDPTPRIME_WR(x, v) (HW_USB_ENDPTPRIME(x).U = (v))
#define HW_USB_ENDPTPRIME_SET(x, v) (HW_USB_ENDPTPRIME_WR(x, HW_USB_ENDPTPRIME_RD(x) |  (v)))
#define HW_USB_ENDPTPRIME_CLR(x, v) (HW_USB_ENDPTPRIME_WR(x, HW_USB_ENDPTPRIME_RD(x) & ~(v)))
#define HW_USB_ENDPTPRIME_TOG(x, v) (HW_USB_ENDPTPRIME_WR(x, HW_USB_ENDPTPRIME_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_ENDPTPRIME bitfields
 */

/*!
 * @name Register USB_ENDPTPRIME, field PERB[7:0] (RW)
 *
 * Prime Endpoint Receive Buffer - R/WS. For each endpoint, a corresponding bit
 * is used to request a buffer prepare for a receive operation for when a USB
 * host initiates a USB OUT transaction. Software should write a one to the
 * corresponding bit whenever posting a new transfer descriptor to an endpoint queue
 * head. Hardware automatically uses this bit to begin parsing for a new transfer
 * descriptor from the queue head and prepare a receive buffer. Hardware clears this
 * bit when the associated endpoint(s) is (are) successfully primed. These bits
 * are momentarily set by hardware during hardware re-priming operations when a
 * dTD is retired, and the dQH is updated. PERB[N] - Endpoint #N, N is in 0..7
 */
/*@{*/
#define BP_USB_ENDPTPRIME_PERB (0U)        /*!< Bit position for USB_ENDPTPRIME_PERB. */
#define BM_USB_ENDPTPRIME_PERB (0x000000FFU) /*!< Bit mask for USB_ENDPTPRIME_PERB. */
#define BS_USB_ENDPTPRIME_PERB (8U)        /*!< Bit field size in bits for USB_ENDPTPRIME_PERB. */

/*! @brief Read current value of the USB_ENDPTPRIME_PERB field. */
#define BR_USB_ENDPTPRIME_PERB(x) (HW_USB_ENDPTPRIME(x).B.PERB)

/*! @brief Format value for bitfield USB_ENDPTPRIME_PERB. */
#define BF_USB_ENDPTPRIME_PERB(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTPRIME_PERB) & BM_USB_ENDPTPRIME_PERB)

/*! @brief Set the PERB field to a new value. */
#define BW_USB_ENDPTPRIME_PERB(x, v) (HW_USB_ENDPTPRIME_WR(x, (HW_USB_ENDPTPRIME_RD(x) & ~BM_USB_ENDPTPRIME_PERB) | BF_USB_ENDPTPRIME_PERB(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTPRIME, field PETB[23:16] (RW)
 *
 * Prime Endpoint Transmit Buffer - R/WS. For each endpoint a corresponding bit
 * is used to request that a buffer is prepared for a transmit operation in order
 * to respond to a USB IN/INTERRUPT transaction. Software should write a one to
 * the corresponding bit when posting a new transfer descriptor to an endpoint
 * queue head. Hardware automatically uses this bit to begin parsing for a new
 * transfer descriptor from the queue head and prepare a transmit buffer. Hardware
 * clears this bit when the associated endpoint(s) is (are) successfully primed.
 * These bits are momentarily set by hardware during hardware re-priming operations
 * when a dTD is retired, and the dQH is updated. PETB[N] - Endpoint #N, N is in
 * 0..7
 */
/*@{*/
#define BP_USB_ENDPTPRIME_PETB (16U)       /*!< Bit position for USB_ENDPTPRIME_PETB. */
#define BM_USB_ENDPTPRIME_PETB (0x00FF0000U) /*!< Bit mask for USB_ENDPTPRIME_PETB. */
#define BS_USB_ENDPTPRIME_PETB (8U)        /*!< Bit field size in bits for USB_ENDPTPRIME_PETB. */

/*! @brief Read current value of the USB_ENDPTPRIME_PETB field. */
#define BR_USB_ENDPTPRIME_PETB(x) (HW_USB_ENDPTPRIME(x).B.PETB)

/*! @brief Format value for bitfield USB_ENDPTPRIME_PETB. */
#define BF_USB_ENDPTPRIME_PETB(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTPRIME_PETB) & BM_USB_ENDPTPRIME_PETB)

/*! @brief Set the PETB field to a new value. */
#define BW_USB_ENDPTPRIME_PETB(x, v) (HW_USB_ENDPTPRIME_WR(x, (HW_USB_ENDPTPRIME_RD(x) & ~BM_USB_ENDPTPRIME_PETB) | BF_USB_ENDPTPRIME_PETB(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_ENDPTFLUSH - Endpoint Flush
 ******************************************************************************/

/*!
 * @brief HW_USB_ENDPTFLUSH - Endpoint Flush (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is only used in device mode.
 */
typedef union _hw_usb_endptflush
{
    uint32_t U;
    struct _hw_usb_endptflush_bitfields
    {
        uint32_t FERB : 8;             /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t FETB : 8;             /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_endptflush_t;

/*!
 * @name Constants and macros for entire USB_ENDPTFLUSH register
 */
/*@{*/
#define HW_USB_ENDPTFLUSH_ADDR(x) ((uintptr_t)(x) + 0x1B4U)

#define HW_USB_ENDPTFLUSH(x)     (*(__IO hw_usb_endptflush_t *) HW_USB_ENDPTFLUSH_ADDR(x))
#define HW_USB_ENDPTFLUSH_RD(x)  (HW_USB_ENDPTFLUSH(x).U)
#define HW_USB_ENDPTFLUSH_WR(x, v) (HW_USB_ENDPTFLUSH(x).U = (v))
#define HW_USB_ENDPTFLUSH_SET(x, v) (HW_USB_ENDPTFLUSH_WR(x, HW_USB_ENDPTFLUSH_RD(x) |  (v)))
#define HW_USB_ENDPTFLUSH_CLR(x, v) (HW_USB_ENDPTFLUSH_WR(x, HW_USB_ENDPTFLUSH_RD(x) & ~(v)))
#define HW_USB_ENDPTFLUSH_TOG(x, v) (HW_USB_ENDPTFLUSH_WR(x, HW_USB_ENDPTFLUSH_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_ENDPTFLUSH bitfields
 */

/*!
 * @name Register USB_ENDPTFLUSH, field FERB[7:0] (RW)
 *
 * Flush Endpoint Receive Buffer - R/WS. Writing one to a bit(s) causes the
 * assocUOGiated endpoint(s) to clear any primed buffers. If a packet is in progress
 * for one of the associated endpoints, then that transfer continues until
 * completion. Hardware clears this register after the endpoint flush operation is
 * successful. FERB[N] - Endpoint #N, N is in 0..7\
 */
/*@{*/
#define BP_USB_ENDPTFLUSH_FERB (0U)        /*!< Bit position for USB_ENDPTFLUSH_FERB. */
#define BM_USB_ENDPTFLUSH_FERB (0x000000FFU) /*!< Bit mask for USB_ENDPTFLUSH_FERB. */
#define BS_USB_ENDPTFLUSH_FERB (8U)        /*!< Bit field size in bits for USB_ENDPTFLUSH_FERB. */

/*! @brief Read current value of the USB_ENDPTFLUSH_FERB field. */
#define BR_USB_ENDPTFLUSH_FERB(x) (HW_USB_ENDPTFLUSH(x).B.FERB)

/*! @brief Format value for bitfield USB_ENDPTFLUSH_FERB. */
#define BF_USB_ENDPTFLUSH_FERB(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTFLUSH_FERB) & BM_USB_ENDPTFLUSH_FERB)

/*! @brief Set the FERB field to a new value. */
#define BW_USB_ENDPTFLUSH_FERB(x, v) (HW_USB_ENDPTFLUSH_WR(x, (HW_USB_ENDPTFLUSH_RD(x) & ~BM_USB_ENDPTFLUSH_FERB) | BF_USB_ENDPTFLUSH_FERB(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTFLUSH, field FETB[23:16] (RW)
 *
 * Flush Endpoint Transmit Buffer - R/WS. Writing one to a bit(s) in this
 * register causes the associated endpoint(s) to clear any primed buffers. If a packet
 * is in progress for one of the associated endpoints, then that transfer
 * continues until completion. Hardware clears this register after the endpoint flush
 * operation is successful. FETB[N] - Endpoint #N, N is in 0..7
 */
/*@{*/
#define BP_USB_ENDPTFLUSH_FETB (16U)       /*!< Bit position for USB_ENDPTFLUSH_FETB. */
#define BM_USB_ENDPTFLUSH_FETB (0x00FF0000U) /*!< Bit mask for USB_ENDPTFLUSH_FETB. */
#define BS_USB_ENDPTFLUSH_FETB (8U)        /*!< Bit field size in bits for USB_ENDPTFLUSH_FETB. */

/*! @brief Read current value of the USB_ENDPTFLUSH_FETB field. */
#define BR_USB_ENDPTFLUSH_FETB(x) (HW_USB_ENDPTFLUSH(x).B.FETB)

/*! @brief Format value for bitfield USB_ENDPTFLUSH_FETB. */
#define BF_USB_ENDPTFLUSH_FETB(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTFLUSH_FETB) & BM_USB_ENDPTFLUSH_FETB)

/*! @brief Set the FETB field to a new value. */
#define BW_USB_ENDPTFLUSH_FETB(x, v) (HW_USB_ENDPTFLUSH_WR(x, (HW_USB_ENDPTFLUSH_RD(x) & ~BM_USB_ENDPTFLUSH_FETB) | BF_USB_ENDPTFLUSH_FETB(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_ENDPTSTAT - Endpoint Status
 ******************************************************************************/

/*!
 * @brief HW_USB_ENDPTSTAT - Endpoint Status (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register is only used in device mode.
 */
typedef union _hw_usb_endptstat
{
    uint32_t U;
    struct _hw_usb_endptstat_bitfields
    {
        uint32_t ERBR : 8;             /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t ETBR : 8;             /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_endptstat_t;

/*!
 * @name Constants and macros for entire USB_ENDPTSTAT register
 */
/*@{*/
#define HW_USB_ENDPTSTAT_ADDR(x) ((uintptr_t)(x) + 0x1B8U)

#define HW_USB_ENDPTSTAT(x)      (*(__I hw_usb_endptstat_t *) HW_USB_ENDPTSTAT_ADDR(x))
#define HW_USB_ENDPTSTAT_RD(x)   (HW_USB_ENDPTSTAT(x).U)
/*@}*/

/*
 * Constants & macros for individual USB_ENDPTSTAT bitfields
 */

/*!
 * @name Register USB_ENDPTSTAT, field ERBR[7:0] (RO)
 *
 * Endpoint Receive Buffer Ready -- Read Only. One bit for each endpoint
 * indicates status of the respective endpoint buffer. This bit is set to a one by the
 * hardware as a response to receiving a command from a corresponding bit in the
 * ENDPRIME register. There is always a delay between setting a bit in the
 * ENDPRIME register and endpoint indicating ready. This delay time varies based upon
 * the current USB traffic and the number of bits set in the ENDPRIME register.
 * Buffer ready is cleared by USB reset, by the USB DMA system, or through the
 * ENDPTFLUSH register. These bits are momentarily cleared by hardware during hardware
 * endpoint re-priming operations when a dTD is retired, and the dQH is updated.
 * ERBR[N] - Endpoint #N, N is in 0..7
 */
/*@{*/
#define BP_USB_ENDPTSTAT_ERBR (0U)         /*!< Bit position for USB_ENDPTSTAT_ERBR. */
#define BM_USB_ENDPTSTAT_ERBR (0x000000FFU) /*!< Bit mask for USB_ENDPTSTAT_ERBR. */
#define BS_USB_ENDPTSTAT_ERBR (8U)         /*!< Bit field size in bits for USB_ENDPTSTAT_ERBR. */

/*! @brief Read current value of the USB_ENDPTSTAT_ERBR field. */
#define BR_USB_ENDPTSTAT_ERBR(x) (HW_USB_ENDPTSTAT(x).B.ERBR)
/*@}*/

/*!
 * @name Register USB_ENDPTSTAT, field ETBR[23:16] (RO)
 *
 * Endpoint Transmit Buffer Ready -- Read Only. One bit for each endpoint
 * indicates status of the respective endpoint buffer. This bit is set to one by the
 * hardware as a response to receiving a command from a corresponding bit in the
 * ENDPTPRIME register. There is always a delay between setting a bit in the
 * ENDPTPRIME register and endpoint indicating ready. This delay time varies based upon
 * the current USB traffic and the number of bits set in the ENDPRIME register.
 * Buffer ready is cleared by USB reset, by the USB DMA system, or through the
 * ENDPTFLUSH register. These bits are momentarily cleared by hardware during
 * hardware endpoint re-priming operations when a dTD is retired, and the dQH is
 * updated. ETBR[N] - Endpoint #N, N is in 0..7
 */
/*@{*/
#define BP_USB_ENDPTSTAT_ETBR (16U)        /*!< Bit position for USB_ENDPTSTAT_ETBR. */
#define BM_USB_ENDPTSTAT_ETBR (0x00FF0000U) /*!< Bit mask for USB_ENDPTSTAT_ETBR. */
#define BS_USB_ENDPTSTAT_ETBR (8U)         /*!< Bit field size in bits for USB_ENDPTSTAT_ETBR. */

/*! @brief Read current value of the USB_ENDPTSTAT_ETBR field. */
#define BR_USB_ENDPTSTAT_ETBR(x) (HW_USB_ENDPTSTAT(x).B.ETBR)
/*@}*/

/*******************************************************************************
 * HW_USB_ENDPTCOMPLETE - Endpoint Complete
 ******************************************************************************/

/*!
 * @brief HW_USB_ENDPTCOMPLETE - Endpoint Complete (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is only used in device mode.
 */
typedef union _hw_usb_endptcomplete
{
    uint32_t U;
    struct _hw_usb_endptcomplete_bitfields
    {
        uint32_t ERCE : 8;             /*!< [7:0]  */
        uint32_t RESERVED0 : 8;        /*!< [15:8]  */
        uint32_t ETCE : 8;             /*!< [23:16]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_endptcomplete_t;

/*!
 * @name Constants and macros for entire USB_ENDPTCOMPLETE register
 */
/*@{*/
#define HW_USB_ENDPTCOMPLETE_ADDR(x) ((uintptr_t)(x) + 0x1BCU)

#define HW_USB_ENDPTCOMPLETE(x)  (*(__IO hw_usb_endptcomplete_t *) HW_USB_ENDPTCOMPLETE_ADDR(x))
#define HW_USB_ENDPTCOMPLETE_RD(x) (HW_USB_ENDPTCOMPLETE(x).U)
#define HW_USB_ENDPTCOMPLETE_WR(x, v) (HW_USB_ENDPTCOMPLETE(x).U = (v))
#define HW_USB_ENDPTCOMPLETE_SET(x, v) (HW_USB_ENDPTCOMPLETE_WR(x, HW_USB_ENDPTCOMPLETE_RD(x) |  (v)))
#define HW_USB_ENDPTCOMPLETE_CLR(x, v) (HW_USB_ENDPTCOMPLETE_WR(x, HW_USB_ENDPTCOMPLETE_RD(x) & ~(v)))
#define HW_USB_ENDPTCOMPLETE_TOG(x, v) (HW_USB_ENDPTCOMPLETE_WR(x, HW_USB_ENDPTCOMPLETE_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_ENDPTCOMPLETE bitfields
 */

/*!
 * @name Register USB_ENDPTCOMPLETE, field ERCE[7:0] (RW)
 *
 * Endpoint Receive Complete Event - RW/C. Each bit indicates a received event
 * (OUT/SETUP) occurred and software should read the corresponding endpoint queue
 * to determine the transfer status. If the corresponding IOC bit is set in the
 * Transfer Descriptor, then this bit is set simultaneously with the USBINT .
 * Writing one clears the corresponding bit in this register. ERCE[N] - Endpoint #N,
 * N is in 0..7
 */
/*@{*/
#define BP_USB_ENDPTCOMPLETE_ERCE (0U)     /*!< Bit position for USB_ENDPTCOMPLETE_ERCE. */
#define BM_USB_ENDPTCOMPLETE_ERCE (0x000000FFU) /*!< Bit mask for USB_ENDPTCOMPLETE_ERCE. */
#define BS_USB_ENDPTCOMPLETE_ERCE (8U)     /*!< Bit field size in bits for USB_ENDPTCOMPLETE_ERCE. */

/*! @brief Read current value of the USB_ENDPTCOMPLETE_ERCE field. */
#define BR_USB_ENDPTCOMPLETE_ERCE(x) (HW_USB_ENDPTCOMPLETE(x).B.ERCE)

/*! @brief Format value for bitfield USB_ENDPTCOMPLETE_ERCE. */
#define BF_USB_ENDPTCOMPLETE_ERCE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCOMPLETE_ERCE) & BM_USB_ENDPTCOMPLETE_ERCE)

/*! @brief Set the ERCE field to a new value. */
#define BW_USB_ENDPTCOMPLETE_ERCE(x, v) (HW_USB_ENDPTCOMPLETE_WR(x, (HW_USB_ENDPTCOMPLETE_RD(x) & ~BM_USB_ENDPTCOMPLETE_ERCE) | BF_USB_ENDPTCOMPLETE_ERCE(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCOMPLETE, field ETCE[23:16] (RW)
 *
 * Endpoint Transmit Complete Event - R/WC. Each bit indicates a transmit event
 * (IN/INTERRUPT) occurred and software should read the corresponding endpoint
 * queue to determine the endpoint status. If the corresponding IOC bit is set in
 * the Transfer Descriptor, then this bit is set simultaneously with the USBINT .
 * Writing one clears the corresponding bit in this register. ETCE[N] - Endpoint
 * #N, N is in 0..7
 */
/*@{*/
#define BP_USB_ENDPTCOMPLETE_ETCE (16U)    /*!< Bit position for USB_ENDPTCOMPLETE_ETCE. */
#define BM_USB_ENDPTCOMPLETE_ETCE (0x00FF0000U) /*!< Bit mask for USB_ENDPTCOMPLETE_ETCE. */
#define BS_USB_ENDPTCOMPLETE_ETCE (8U)     /*!< Bit field size in bits for USB_ENDPTCOMPLETE_ETCE. */

/*! @brief Read current value of the USB_ENDPTCOMPLETE_ETCE field. */
#define BR_USB_ENDPTCOMPLETE_ETCE(x) (HW_USB_ENDPTCOMPLETE(x).B.ETCE)

/*! @brief Format value for bitfield USB_ENDPTCOMPLETE_ETCE. */
#define BF_USB_ENDPTCOMPLETE_ETCE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCOMPLETE_ETCE) & BM_USB_ENDPTCOMPLETE_ETCE)

/*! @brief Set the ETCE field to a new value. */
#define BW_USB_ENDPTCOMPLETE_ETCE(x, v) (HW_USB_ENDPTCOMPLETE_WR(x, (HW_USB_ENDPTCOMPLETE_RD(x) & ~BM_USB_ENDPTCOMPLETE_ETCE) | BF_USB_ENDPTCOMPLETE_ETCE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_ENDPTCTRL0 - Endpoint Control0
 ******************************************************************************/

/*!
 * @brief HW_USB_ENDPTCTRL0 - Endpoint Control0 (RW)
 *
 * Reset value: 0x00800080U
 *
 * Every Device implements Endpoint 0 as a control endpoint.
 */
typedef union _hw_usb_endptctrl0
{
    uint32_t U;
    struct _hw_usb_endptctrl0_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RESERVED0 : 1;        /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED1 : 3;        /*!< [6:4]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED2 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t RESERVED3 : 1;        /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED4 : 3;        /*!< [22:20]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED5 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_endptctrl0_t;

/*!
 * @name Constants and macros for entire USB_ENDPTCTRL0 register
 */
/*@{*/
#define HW_USB_ENDPTCTRL0_ADDR(x) ((uintptr_t)(x) + 0x1C0U)

#define HW_USB_ENDPTCTRL0(x)     (*(__IO hw_usb_endptctrl0_t *) HW_USB_ENDPTCTRL0_ADDR(x))
#define HW_USB_ENDPTCTRL0_RD(x)  (HW_USB_ENDPTCTRL0(x).U)
#define HW_USB_ENDPTCTRL0_WR(x, v) (HW_USB_ENDPTCTRL0(x).U = (v))
#define HW_USB_ENDPTCTRL0_SET(x, v) (HW_USB_ENDPTCTRL0_WR(x, HW_USB_ENDPTCTRL0_RD(x) |  (v)))
#define HW_USB_ENDPTCTRL0_CLR(x, v) (HW_USB_ENDPTCTRL0_WR(x, HW_USB_ENDPTCTRL0_RD(x) & ~(v)))
#define HW_USB_ENDPTCTRL0_TOG(x, v) (HW_USB_ENDPTCTRL0_WR(x, HW_USB_ENDPTCTRL0_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_ENDPTCTRL0 bitfields
 */

/*!
 * @name Register USB_ENDPTCTRL0, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * Software can write a one to this bit to force the endpoint to return a STALL
 * handshake to the Host. It continues returning STALL until the bit is cleared by
 * software or it is automatically cleared upon receipt of a new SETUP request.
 * After receiving a SETUP request, this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. There is a slight
 * delay (50 clocks max.) between the endptsetupstat being cleared and hardware
 * continuing to clear this bit. In most systems it is unlikely the dcd software will
 * observe this delay. However, should the dcd observe that the stall bit is not
 * set after writing a one to it then follow this procedure: continually write
 * this stall bit until it is set or until a newsetup has been received by checking
 * the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_ENDPTCTRL0_RXS (0U)         /*!< Bit position for USB_ENDPTCTRL0_RXS. */
#define BM_USB_ENDPTCTRL0_RXS (0x00000001U) /*!< Bit mask for USB_ENDPTCTRL0_RXS. */
#define BS_USB_ENDPTCTRL0_RXS (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL0_RXS. */

/*! @brief Read current value of the USB_ENDPTCTRL0_RXS field. */
#define BR_USB_ENDPTCTRL0_RXS(x) (HW_USB_ENDPTCTRL0(x).B.RXS)

/*! @brief Format value for bitfield USB_ENDPTCTRL0_RXS. */
#define BF_USB_ENDPTCTRL0_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL0_RXS) & BM_USB_ENDPTCTRL0_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_ENDPTCTRL0_RXS(x, v) (HW_USB_ENDPTCTRL0_WR(x, (HW_USB_ENDPTCTRL0_RD(x) & ~BM_USB_ENDPTCTRL0_RXS) | BF_USB_ENDPTCTRL0_RXS(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL0, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control Endpoint0 is fixed as a Control End
 * Point.
 */
/*@{*/
#define BP_USB_ENDPTCTRL0_RXT (2U)         /*!< Bit position for USB_ENDPTCTRL0_RXT. */
#define BM_USB_ENDPTCTRL0_RXT (0x0000000CU) /*!< Bit mask for USB_ENDPTCTRL0_RXT. */
#define BS_USB_ENDPTCTRL0_RXT (2U)         /*!< Bit field size in bits for USB_ENDPTCTRL0_RXT. */

/*! @brief Read current value of the USB_ENDPTCTRL0_RXT field. */
#define BR_USB_ENDPTCTRL0_RXT(x) (HW_USB_ENDPTCTRL0(x).B.RXT)

/*! @brief Format value for bitfield USB_ENDPTCTRL0_RXT. */
#define BF_USB_ENDPTCTRL0_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL0_RXT) & BM_USB_ENDPTCTRL0_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_ENDPTCTRL0_RXT(x, v) (HW_USB_ENDPTCTRL0_WR(x, (HW_USB_ENDPTCTRL0_RD(x) & ~BM_USB_ENDPTCTRL0_RXT) | BF_USB_ENDPTCTRL0_RXT(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL0, field RXE[7] (RW)
 *
 * RX Endpoint Enable 1 Enabled Endpoint0 is always enabled.
 */
/*@{*/
#define BP_USB_ENDPTCTRL0_RXE (7U)         /*!< Bit position for USB_ENDPTCTRL0_RXE. */
#define BM_USB_ENDPTCTRL0_RXE (0x00000080U) /*!< Bit mask for USB_ENDPTCTRL0_RXE. */
#define BS_USB_ENDPTCTRL0_RXE (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL0_RXE. */

/*! @brief Read current value of the USB_ENDPTCTRL0_RXE field. */
#define BR_USB_ENDPTCTRL0_RXE(x) (HW_USB_ENDPTCTRL0(x).B.RXE)

/*! @brief Format value for bitfield USB_ENDPTCTRL0_RXE. */
#define BF_USB_ENDPTCTRL0_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL0_RXE) & BM_USB_ENDPTCTRL0_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_ENDPTCTRL0_RXE(x, v) (HW_USB_ENDPTCTRL0_WR(x, (HW_USB_ENDPTCTRL0_RD(x) & ~BM_USB_ENDPTCTRL0_RXE) | BF_USB_ENDPTCTRL0_RXE(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL0, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK [Default] 1 End Point Stalled
 * Software can write a one to this bit to force the endpoint to return a STALL
 * handshake to the Host. It continues returning STALL until the bit is cleared by
 * software or it is automatically cleared upon receipt of a new SETUP request.
 * After receiving a SETUP request, this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared.There is a slight delay
 * (50 clocks max.) between the endptsetupstat being cleared and hardware
 * continuing to clear this bit. In most systems it is unlikely the DCD software will
 * observe this delay. However, should the dcd observe that the stall bit is not
 * set after writing a one to it then follow this procedure: continually write this
 * stall bit until it is set or until a newsetup has been received by checking
 * the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_ENDPTCTRL0_TXS (16U)        /*!< Bit position for USB_ENDPTCTRL0_TXS. */
#define BM_USB_ENDPTCTRL0_TXS (0x00010000U) /*!< Bit mask for USB_ENDPTCTRL0_TXS. */
#define BS_USB_ENDPTCTRL0_TXS (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL0_TXS. */

/*! @brief Read current value of the USB_ENDPTCTRL0_TXS field. */
#define BR_USB_ENDPTCTRL0_TXS(x) (HW_USB_ENDPTCTRL0(x).B.TXS)

/*! @brief Format value for bitfield USB_ENDPTCTRL0_TXS. */
#define BF_USB_ENDPTCTRL0_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL0_TXS) & BM_USB_ENDPTCTRL0_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_ENDPTCTRL0_TXS(x, v) (HW_USB_ENDPTCTRL0_WR(x, (HW_USB_ENDPTCTRL0_RD(x) & ~BM_USB_ENDPTCTRL0_TXS) | BF_USB_ENDPTCTRL0_TXS(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL0, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 - Control Endpoint0 is fixed as a Control
 * End Point.
 */
/*@{*/
#define BP_USB_ENDPTCTRL0_TXT (18U)        /*!< Bit position for USB_ENDPTCTRL0_TXT. */
#define BM_USB_ENDPTCTRL0_TXT (0x000C0000U) /*!< Bit mask for USB_ENDPTCTRL0_TXT. */
#define BS_USB_ENDPTCTRL0_TXT (2U)         /*!< Bit field size in bits for USB_ENDPTCTRL0_TXT. */

/*! @brief Read current value of the USB_ENDPTCTRL0_TXT field. */
#define BR_USB_ENDPTCTRL0_TXT(x) (HW_USB_ENDPTCTRL0(x).B.TXT)

/*! @brief Format value for bitfield USB_ENDPTCTRL0_TXT. */
#define BF_USB_ENDPTCTRL0_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL0_TXT) & BM_USB_ENDPTCTRL0_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_ENDPTCTRL0_TXT(x, v) (HW_USB_ENDPTCTRL0_WR(x, (HW_USB_ENDPTCTRL0_RD(x) & ~BM_USB_ENDPTCTRL0_TXT) | BF_USB_ENDPTCTRL0_TXT(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL0, field TXE[23] (RW)
 *
 * TX Endpoint Enable 1 Enabled Endpoint0 is always enabled.
 */
/*@{*/
#define BP_USB_ENDPTCTRL0_TXE (23U)        /*!< Bit position for USB_ENDPTCTRL0_TXE. */
#define BM_USB_ENDPTCTRL0_TXE (0x00800000U) /*!< Bit mask for USB_ENDPTCTRL0_TXE. */
#define BS_USB_ENDPTCTRL0_TXE (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL0_TXE. */

/*! @brief Read current value of the USB_ENDPTCTRL0_TXE field. */
#define BR_USB_ENDPTCTRL0_TXE(x) (HW_USB_ENDPTCTRL0(x).B.TXE)

/*! @brief Format value for bitfield USB_ENDPTCTRL0_TXE. */
#define BF_USB_ENDPTCTRL0_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL0_TXE) & BM_USB_ENDPTCTRL0_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_ENDPTCTRL0_TXE(x, v) (HW_USB_ENDPTCTRL0_WR(x, (HW_USB_ENDPTCTRL0_RD(x) & ~BM_USB_ENDPTCTRL0_TXE) | BF_USB_ENDPTCTRL0_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_ENDPTCTRL1 - Endpoint Control 1
 ******************************************************************************/

/*!
 * @brief HW_USB_ENDPTCTRL1 - Endpoint Control 1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 1 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_endptctrl1
{
    uint32_t U;
    struct _hw_usb_endptctrl1_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_endptctrl1_t;

/*!
 * @name Constants and macros for entire USB_ENDPTCTRL1 register
 */
/*@{*/
#define HW_USB_ENDPTCTRL1_ADDR(x) ((uintptr_t)(x) + 0x1C4U)

#define HW_USB_ENDPTCTRL1(x)     (*(__IO hw_usb_endptctrl1_t *) HW_USB_ENDPTCTRL1_ADDR(x))
#define HW_USB_ENDPTCTRL1_RD(x)  (HW_USB_ENDPTCTRL1(x).U)
#define HW_USB_ENDPTCTRL1_WR(x, v) (HW_USB_ENDPTCTRL1(x).U = (v))
#define HW_USB_ENDPTCTRL1_SET(x, v) (HW_USB_ENDPTCTRL1_WR(x, HW_USB_ENDPTCTRL1_RD(x) |  (v)))
#define HW_USB_ENDPTCTRL1_CLR(x, v) (HW_USB_ENDPTCTRL1_WR(x, HW_USB_ENDPTCTRL1_RD(x) & ~(v)))
#define HW_USB_ENDPTCTRL1_TOG(x, v) (HW_USB_ENDPTCTRL1_WR(x, HW_USB_ENDPTCTRL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_ENDPTCTRL1 bitfields
 */

/*!
 * @name Register USB_ENDPTCTRL1, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay. However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or
 * until a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_ENDPTCTRL1_RXS (0U)         /*!< Bit position for USB_ENDPTCTRL1_RXS. */
#define BM_USB_ENDPTCTRL1_RXS (0x00000001U) /*!< Bit mask for USB_ENDPTCTRL1_RXS. */
#define BS_USB_ENDPTCTRL1_RXS (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL1_RXS. */

/*! @brief Read current value of the USB_ENDPTCTRL1_RXS field. */
#define BR_USB_ENDPTCTRL1_RXS(x) (HW_USB_ENDPTCTRL1(x).B.RXS)

/*! @brief Format value for bitfield USB_ENDPTCTRL1_RXS. */
#define BF_USB_ENDPTCTRL1_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL1_RXS) & BM_USB_ENDPTCTRL1_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_ENDPTCTRL1_RXS(x, v) (HW_USB_ENDPTCTRL1_WR(x, (HW_USB_ENDPTCTRL1_RD(x) & ~BM_USB_ENDPTCTRL1_RXS) | BF_USB_ENDPTCTRL1_RXS(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL1, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_ENDPTCTRL1_RXD (1U)         /*!< Bit position for USB_ENDPTCTRL1_RXD. */
#define BM_USB_ENDPTCTRL1_RXD (0x00000002U) /*!< Bit mask for USB_ENDPTCTRL1_RXD. */
#define BS_USB_ENDPTCTRL1_RXD (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL1_RXD. */

/*! @brief Read current value of the USB_ENDPTCTRL1_RXD field. */
#define BR_USB_ENDPTCTRL1_RXD(x) (HW_USB_ENDPTCTRL1(x).B.RXD)

/*! @brief Format value for bitfield USB_ENDPTCTRL1_RXD. */
#define BF_USB_ENDPTCTRL1_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL1_RXD) & BM_USB_ENDPTCTRL1_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_ENDPTCTRL1_RXD(x, v) (HW_USB_ENDPTCTRL1_WR(x, (HW_USB_ENDPTCTRL1_RD(x) & ~BM_USB_ENDPTCTRL1_RXD) | BF_USB_ENDPTCTRL1_RXD(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL1, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_ENDPTCTRL1_RXT (2U)         /*!< Bit position for USB_ENDPTCTRL1_RXT. */
#define BM_USB_ENDPTCTRL1_RXT (0x0000000CU) /*!< Bit mask for USB_ENDPTCTRL1_RXT. */
#define BS_USB_ENDPTCTRL1_RXT (2U)         /*!< Bit field size in bits for USB_ENDPTCTRL1_RXT. */

/*! @brief Read current value of the USB_ENDPTCTRL1_RXT field. */
#define BR_USB_ENDPTCTRL1_RXT(x) (HW_USB_ENDPTCTRL1(x).B.RXT)

/*! @brief Format value for bitfield USB_ENDPTCTRL1_RXT. */
#define BF_USB_ENDPTCTRL1_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL1_RXT) & BM_USB_ENDPTCTRL1_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_ENDPTCTRL1_RXT(x, v) (HW_USB_ENDPTCTRL1_WR(x, (HW_USB_ENDPTCTRL1_RD(x) & ~BM_USB_ENDPTCTRL1_RXT) | BF_USB_ENDPTCTRL1_RXT(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL1, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_ENDPTCTRL1_RXI (5U)         /*!< Bit position for USB_ENDPTCTRL1_RXI. */
#define BM_USB_ENDPTCTRL1_RXI (0x00000020U) /*!< Bit mask for USB_ENDPTCTRL1_RXI. */
#define BS_USB_ENDPTCTRL1_RXI (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL1_RXI. */

/*! @brief Read current value of the USB_ENDPTCTRL1_RXI field. */
#define BR_USB_ENDPTCTRL1_RXI(x) (HW_USB_ENDPTCTRL1(x).B.RXI)

/*! @brief Format value for bitfield USB_ENDPTCTRL1_RXI. */
#define BF_USB_ENDPTCTRL1_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL1_RXI) & BM_USB_ENDPTCTRL1_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_ENDPTCTRL1_RXI(x, v) (HW_USB_ENDPTCTRL1_WR(x, (HW_USB_ENDPTCTRL1_RD(x) & ~BM_USB_ENDPTCTRL1_RXI) | BF_USB_ENDPTCTRL1_RXI(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL1, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_ENDPTCTRL1_RXR (6U)         /*!< Bit position for USB_ENDPTCTRL1_RXR. */
#define BM_USB_ENDPTCTRL1_RXR (0x00000040U) /*!< Bit mask for USB_ENDPTCTRL1_RXR. */
#define BS_USB_ENDPTCTRL1_RXR (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL1_RXR. */

/*! @brief Read current value of the USB_ENDPTCTRL1_RXR field. */
#define BR_USB_ENDPTCTRL1_RXR(x) (HW_USB_ENDPTCTRL1(x).B.RXR)

/*! @brief Format value for bitfield USB_ENDPTCTRL1_RXR. */
#define BF_USB_ENDPTCTRL1_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL1_RXR) & BM_USB_ENDPTCTRL1_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_ENDPTCTRL1_RXR(x, v) (HW_USB_ENDPTCTRL1_WR(x, (HW_USB_ENDPTCTRL1_RD(x) & ~BM_USB_ENDPTCTRL1_RXR) | BF_USB_ENDPTCTRL1_RXR(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL1, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_ENDPTCTRL1_RXE (7U)         /*!< Bit position for USB_ENDPTCTRL1_RXE. */
#define BM_USB_ENDPTCTRL1_RXE (0x00000080U) /*!< Bit mask for USB_ENDPTCTRL1_RXE. */
#define BS_USB_ENDPTCTRL1_RXE (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL1_RXE. */

/*! @brief Read current value of the USB_ENDPTCTRL1_RXE field. */
#define BR_USB_ENDPTCTRL1_RXE(x) (HW_USB_ENDPTCTRL1(x).B.RXE)

/*! @brief Format value for bitfield USB_ENDPTCTRL1_RXE. */
#define BF_USB_ENDPTCTRL1_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL1_RXE) & BM_USB_ENDPTCTRL1_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_ENDPTCTRL1_RXE(x, v) (HW_USB_ENDPTCTRL1_WR(x, (HW_USB_ENDPTCTRL1_RD(x) & ~BM_USB_ENDPTCTRL1_RXE) | BF_USB_ENDPTCTRL1_RXE(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL1, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay. However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_ENDPTCTRL1_TXS (16U)        /*!< Bit position for USB_ENDPTCTRL1_TXS. */
#define BM_USB_ENDPTCTRL1_TXS (0x00010000U) /*!< Bit mask for USB_ENDPTCTRL1_TXS. */
#define BS_USB_ENDPTCTRL1_TXS (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL1_TXS. */

/*! @brief Read current value of the USB_ENDPTCTRL1_TXS field. */
#define BR_USB_ENDPTCTRL1_TXS(x) (HW_USB_ENDPTCTRL1(x).B.TXS)

/*! @brief Format value for bitfield USB_ENDPTCTRL1_TXS. */
#define BF_USB_ENDPTCTRL1_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL1_TXS) & BM_USB_ENDPTCTRL1_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_ENDPTCTRL1_TXS(x, v) (HW_USB_ENDPTCTRL1_WR(x, (HW_USB_ENDPTCTRL1_RD(x) & ~BM_USB_ENDPTCTRL1_TXS) | BF_USB_ENDPTCTRL1_TXS(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL1, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_ENDPTCTRL1_TXD (17U)        /*!< Bit position for USB_ENDPTCTRL1_TXD. */
#define BM_USB_ENDPTCTRL1_TXD (0x00020000U) /*!< Bit mask for USB_ENDPTCTRL1_TXD. */
#define BS_USB_ENDPTCTRL1_TXD (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL1_TXD. */

/*! @brief Read current value of the USB_ENDPTCTRL1_TXD field. */
#define BR_USB_ENDPTCTRL1_TXD(x) (HW_USB_ENDPTCTRL1(x).B.TXD)

/*! @brief Format value for bitfield USB_ENDPTCTRL1_TXD. */
#define BF_USB_ENDPTCTRL1_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL1_TXD) & BM_USB_ENDPTCTRL1_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_ENDPTCTRL1_TXD(x, v) (HW_USB_ENDPTCTRL1_WR(x, (HW_USB_ENDPTCTRL1_RD(x) & ~BM_USB_ENDPTCTRL1_TXD) | BF_USB_ENDPTCTRL1_TXD(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL1, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_ENDPTCTRL1_TXT (18U)        /*!< Bit position for USB_ENDPTCTRL1_TXT. */
#define BM_USB_ENDPTCTRL1_TXT (0x000C0000U) /*!< Bit mask for USB_ENDPTCTRL1_TXT. */
#define BS_USB_ENDPTCTRL1_TXT (2U)         /*!< Bit field size in bits for USB_ENDPTCTRL1_TXT. */

/*! @brief Read current value of the USB_ENDPTCTRL1_TXT field. */
#define BR_USB_ENDPTCTRL1_TXT(x) (HW_USB_ENDPTCTRL1(x).B.TXT)

/*! @brief Format value for bitfield USB_ENDPTCTRL1_TXT. */
#define BF_USB_ENDPTCTRL1_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL1_TXT) & BM_USB_ENDPTCTRL1_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_ENDPTCTRL1_TXT(x, v) (HW_USB_ENDPTCTRL1_WR(x, (HW_USB_ENDPTCTRL1_RD(x) & ~BM_USB_ENDPTCTRL1_TXT) | BF_USB_ENDPTCTRL1_TXT(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL1, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_ENDPTCTRL1_TXI (21U)        /*!< Bit position for USB_ENDPTCTRL1_TXI. */
#define BM_USB_ENDPTCTRL1_TXI (0x00200000U) /*!< Bit mask for USB_ENDPTCTRL1_TXI. */
#define BS_USB_ENDPTCTRL1_TXI (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL1_TXI. */

/*! @brief Read current value of the USB_ENDPTCTRL1_TXI field. */
#define BR_USB_ENDPTCTRL1_TXI(x) (HW_USB_ENDPTCTRL1(x).B.TXI)

/*! @brief Format value for bitfield USB_ENDPTCTRL1_TXI. */
#define BF_USB_ENDPTCTRL1_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL1_TXI) & BM_USB_ENDPTCTRL1_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_ENDPTCTRL1_TXI(x, v) (HW_USB_ENDPTCTRL1_WR(x, (HW_USB_ENDPTCTRL1_RD(x) & ~BM_USB_ENDPTCTRL1_TXI) | BF_USB_ENDPTCTRL1_TXI(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL1, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_ENDPTCTRL1_TXR (22U)        /*!< Bit position for USB_ENDPTCTRL1_TXR. */
#define BM_USB_ENDPTCTRL1_TXR (0x00400000U) /*!< Bit mask for USB_ENDPTCTRL1_TXR. */
#define BS_USB_ENDPTCTRL1_TXR (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL1_TXR. */

/*! @brief Read current value of the USB_ENDPTCTRL1_TXR field. */
#define BR_USB_ENDPTCTRL1_TXR(x) (HW_USB_ENDPTCTRL1(x).B.TXR)

/*! @brief Format value for bitfield USB_ENDPTCTRL1_TXR. */
#define BF_USB_ENDPTCTRL1_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL1_TXR) & BM_USB_ENDPTCTRL1_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_ENDPTCTRL1_TXR(x, v) (HW_USB_ENDPTCTRL1_WR(x, (HW_USB_ENDPTCTRL1_RD(x) & ~BM_USB_ENDPTCTRL1_TXR) | BF_USB_ENDPTCTRL1_TXR(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL1, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_ENDPTCTRL1_TXE (23U)        /*!< Bit position for USB_ENDPTCTRL1_TXE. */
#define BM_USB_ENDPTCTRL1_TXE (0x00800000U) /*!< Bit mask for USB_ENDPTCTRL1_TXE. */
#define BS_USB_ENDPTCTRL1_TXE (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL1_TXE. */

/*! @brief Read current value of the USB_ENDPTCTRL1_TXE field. */
#define BR_USB_ENDPTCTRL1_TXE(x) (HW_USB_ENDPTCTRL1(x).B.TXE)

/*! @brief Format value for bitfield USB_ENDPTCTRL1_TXE. */
#define BF_USB_ENDPTCTRL1_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL1_TXE) & BM_USB_ENDPTCTRL1_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_ENDPTCTRL1_TXE(x, v) (HW_USB_ENDPTCTRL1_WR(x, (HW_USB_ENDPTCTRL1_RD(x) & ~BM_USB_ENDPTCTRL1_TXE) | BF_USB_ENDPTCTRL1_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_ENDPTCTRL2 - Endpoint Control 2
 ******************************************************************************/

/*!
 * @brief HW_USB_ENDPTCTRL2 - Endpoint Control 2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 2 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_endptctrl2
{
    uint32_t U;
    struct _hw_usb_endptctrl2_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_endptctrl2_t;

/*!
 * @name Constants and macros for entire USB_ENDPTCTRL2 register
 */
/*@{*/
#define HW_USB_ENDPTCTRL2_ADDR(x) ((uintptr_t)(x) + 0x1C8U)

#define HW_USB_ENDPTCTRL2(x)     (*(__IO hw_usb_endptctrl2_t *) HW_USB_ENDPTCTRL2_ADDR(x))
#define HW_USB_ENDPTCTRL2_RD(x)  (HW_USB_ENDPTCTRL2(x).U)
#define HW_USB_ENDPTCTRL2_WR(x, v) (HW_USB_ENDPTCTRL2(x).U = (v))
#define HW_USB_ENDPTCTRL2_SET(x, v) (HW_USB_ENDPTCTRL2_WR(x, HW_USB_ENDPTCTRL2_RD(x) |  (v)))
#define HW_USB_ENDPTCTRL2_CLR(x, v) (HW_USB_ENDPTCTRL2_WR(x, HW_USB_ENDPTCTRL2_RD(x) & ~(v)))
#define HW_USB_ENDPTCTRL2_TOG(x, v) (HW_USB_ENDPTCTRL2_WR(x, HW_USB_ENDPTCTRL2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_ENDPTCTRL2 bitfields
 */

/*!
 * @name Register USB_ENDPTCTRL2, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay. However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or
 * until a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_ENDPTCTRL2_RXS (0U)         /*!< Bit position for USB_ENDPTCTRL2_RXS. */
#define BM_USB_ENDPTCTRL2_RXS (0x00000001U) /*!< Bit mask for USB_ENDPTCTRL2_RXS. */
#define BS_USB_ENDPTCTRL2_RXS (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL2_RXS. */

/*! @brief Read current value of the USB_ENDPTCTRL2_RXS field. */
#define BR_USB_ENDPTCTRL2_RXS(x) (HW_USB_ENDPTCTRL2(x).B.RXS)

/*! @brief Format value for bitfield USB_ENDPTCTRL2_RXS. */
#define BF_USB_ENDPTCTRL2_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL2_RXS) & BM_USB_ENDPTCTRL2_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_ENDPTCTRL2_RXS(x, v) (HW_USB_ENDPTCTRL2_WR(x, (HW_USB_ENDPTCTRL2_RD(x) & ~BM_USB_ENDPTCTRL2_RXS) | BF_USB_ENDPTCTRL2_RXS(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL2, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_ENDPTCTRL2_RXD (1U)         /*!< Bit position for USB_ENDPTCTRL2_RXD. */
#define BM_USB_ENDPTCTRL2_RXD (0x00000002U) /*!< Bit mask for USB_ENDPTCTRL2_RXD. */
#define BS_USB_ENDPTCTRL2_RXD (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL2_RXD. */

/*! @brief Read current value of the USB_ENDPTCTRL2_RXD field. */
#define BR_USB_ENDPTCTRL2_RXD(x) (HW_USB_ENDPTCTRL2(x).B.RXD)

/*! @brief Format value for bitfield USB_ENDPTCTRL2_RXD. */
#define BF_USB_ENDPTCTRL2_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL2_RXD) & BM_USB_ENDPTCTRL2_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_ENDPTCTRL2_RXD(x, v) (HW_USB_ENDPTCTRL2_WR(x, (HW_USB_ENDPTCTRL2_RD(x) & ~BM_USB_ENDPTCTRL2_RXD) | BF_USB_ENDPTCTRL2_RXD(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL2, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_ENDPTCTRL2_RXT (2U)         /*!< Bit position for USB_ENDPTCTRL2_RXT. */
#define BM_USB_ENDPTCTRL2_RXT (0x0000000CU) /*!< Bit mask for USB_ENDPTCTRL2_RXT. */
#define BS_USB_ENDPTCTRL2_RXT (2U)         /*!< Bit field size in bits for USB_ENDPTCTRL2_RXT. */

/*! @brief Read current value of the USB_ENDPTCTRL2_RXT field. */
#define BR_USB_ENDPTCTRL2_RXT(x) (HW_USB_ENDPTCTRL2(x).B.RXT)

/*! @brief Format value for bitfield USB_ENDPTCTRL2_RXT. */
#define BF_USB_ENDPTCTRL2_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL2_RXT) & BM_USB_ENDPTCTRL2_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_ENDPTCTRL2_RXT(x, v) (HW_USB_ENDPTCTRL2_WR(x, (HW_USB_ENDPTCTRL2_RD(x) & ~BM_USB_ENDPTCTRL2_RXT) | BF_USB_ENDPTCTRL2_RXT(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL2, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_ENDPTCTRL2_RXI (5U)         /*!< Bit position for USB_ENDPTCTRL2_RXI. */
#define BM_USB_ENDPTCTRL2_RXI (0x00000020U) /*!< Bit mask for USB_ENDPTCTRL2_RXI. */
#define BS_USB_ENDPTCTRL2_RXI (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL2_RXI. */

/*! @brief Read current value of the USB_ENDPTCTRL2_RXI field. */
#define BR_USB_ENDPTCTRL2_RXI(x) (HW_USB_ENDPTCTRL2(x).B.RXI)

/*! @brief Format value for bitfield USB_ENDPTCTRL2_RXI. */
#define BF_USB_ENDPTCTRL2_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL2_RXI) & BM_USB_ENDPTCTRL2_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_ENDPTCTRL2_RXI(x, v) (HW_USB_ENDPTCTRL2_WR(x, (HW_USB_ENDPTCTRL2_RD(x) & ~BM_USB_ENDPTCTRL2_RXI) | BF_USB_ENDPTCTRL2_RXI(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL2, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_ENDPTCTRL2_RXR (6U)         /*!< Bit position for USB_ENDPTCTRL2_RXR. */
#define BM_USB_ENDPTCTRL2_RXR (0x00000040U) /*!< Bit mask for USB_ENDPTCTRL2_RXR. */
#define BS_USB_ENDPTCTRL2_RXR (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL2_RXR. */

/*! @brief Read current value of the USB_ENDPTCTRL2_RXR field. */
#define BR_USB_ENDPTCTRL2_RXR(x) (HW_USB_ENDPTCTRL2(x).B.RXR)

/*! @brief Format value for bitfield USB_ENDPTCTRL2_RXR. */
#define BF_USB_ENDPTCTRL2_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL2_RXR) & BM_USB_ENDPTCTRL2_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_ENDPTCTRL2_RXR(x, v) (HW_USB_ENDPTCTRL2_WR(x, (HW_USB_ENDPTCTRL2_RD(x) & ~BM_USB_ENDPTCTRL2_RXR) | BF_USB_ENDPTCTRL2_RXR(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL2, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_ENDPTCTRL2_RXE (7U)         /*!< Bit position for USB_ENDPTCTRL2_RXE. */
#define BM_USB_ENDPTCTRL2_RXE (0x00000080U) /*!< Bit mask for USB_ENDPTCTRL2_RXE. */
#define BS_USB_ENDPTCTRL2_RXE (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL2_RXE. */

/*! @brief Read current value of the USB_ENDPTCTRL2_RXE field. */
#define BR_USB_ENDPTCTRL2_RXE(x) (HW_USB_ENDPTCTRL2(x).B.RXE)

/*! @brief Format value for bitfield USB_ENDPTCTRL2_RXE. */
#define BF_USB_ENDPTCTRL2_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL2_RXE) & BM_USB_ENDPTCTRL2_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_ENDPTCTRL2_RXE(x, v) (HW_USB_ENDPTCTRL2_WR(x, (HW_USB_ENDPTCTRL2_RD(x) & ~BM_USB_ENDPTCTRL2_RXE) | BF_USB_ENDPTCTRL2_RXE(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL2, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay. However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_ENDPTCTRL2_TXS (16U)        /*!< Bit position for USB_ENDPTCTRL2_TXS. */
#define BM_USB_ENDPTCTRL2_TXS (0x00010000U) /*!< Bit mask for USB_ENDPTCTRL2_TXS. */
#define BS_USB_ENDPTCTRL2_TXS (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL2_TXS. */

/*! @brief Read current value of the USB_ENDPTCTRL2_TXS field. */
#define BR_USB_ENDPTCTRL2_TXS(x) (HW_USB_ENDPTCTRL2(x).B.TXS)

/*! @brief Format value for bitfield USB_ENDPTCTRL2_TXS. */
#define BF_USB_ENDPTCTRL2_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL2_TXS) & BM_USB_ENDPTCTRL2_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_ENDPTCTRL2_TXS(x, v) (HW_USB_ENDPTCTRL2_WR(x, (HW_USB_ENDPTCTRL2_RD(x) & ~BM_USB_ENDPTCTRL2_TXS) | BF_USB_ENDPTCTRL2_TXS(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL2, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_ENDPTCTRL2_TXD (17U)        /*!< Bit position for USB_ENDPTCTRL2_TXD. */
#define BM_USB_ENDPTCTRL2_TXD (0x00020000U) /*!< Bit mask for USB_ENDPTCTRL2_TXD. */
#define BS_USB_ENDPTCTRL2_TXD (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL2_TXD. */

/*! @brief Read current value of the USB_ENDPTCTRL2_TXD field. */
#define BR_USB_ENDPTCTRL2_TXD(x) (HW_USB_ENDPTCTRL2(x).B.TXD)

/*! @brief Format value for bitfield USB_ENDPTCTRL2_TXD. */
#define BF_USB_ENDPTCTRL2_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL2_TXD) & BM_USB_ENDPTCTRL2_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_ENDPTCTRL2_TXD(x, v) (HW_USB_ENDPTCTRL2_WR(x, (HW_USB_ENDPTCTRL2_RD(x) & ~BM_USB_ENDPTCTRL2_TXD) | BF_USB_ENDPTCTRL2_TXD(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL2, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_ENDPTCTRL2_TXT (18U)        /*!< Bit position for USB_ENDPTCTRL2_TXT. */
#define BM_USB_ENDPTCTRL2_TXT (0x000C0000U) /*!< Bit mask for USB_ENDPTCTRL2_TXT. */
#define BS_USB_ENDPTCTRL2_TXT (2U)         /*!< Bit field size in bits for USB_ENDPTCTRL2_TXT. */

/*! @brief Read current value of the USB_ENDPTCTRL2_TXT field. */
#define BR_USB_ENDPTCTRL2_TXT(x) (HW_USB_ENDPTCTRL2(x).B.TXT)

/*! @brief Format value for bitfield USB_ENDPTCTRL2_TXT. */
#define BF_USB_ENDPTCTRL2_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL2_TXT) & BM_USB_ENDPTCTRL2_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_ENDPTCTRL2_TXT(x, v) (HW_USB_ENDPTCTRL2_WR(x, (HW_USB_ENDPTCTRL2_RD(x) & ~BM_USB_ENDPTCTRL2_TXT) | BF_USB_ENDPTCTRL2_TXT(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL2, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_ENDPTCTRL2_TXI (21U)        /*!< Bit position for USB_ENDPTCTRL2_TXI. */
#define BM_USB_ENDPTCTRL2_TXI (0x00200000U) /*!< Bit mask for USB_ENDPTCTRL2_TXI. */
#define BS_USB_ENDPTCTRL2_TXI (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL2_TXI. */

/*! @brief Read current value of the USB_ENDPTCTRL2_TXI field. */
#define BR_USB_ENDPTCTRL2_TXI(x) (HW_USB_ENDPTCTRL2(x).B.TXI)

/*! @brief Format value for bitfield USB_ENDPTCTRL2_TXI. */
#define BF_USB_ENDPTCTRL2_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL2_TXI) & BM_USB_ENDPTCTRL2_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_ENDPTCTRL2_TXI(x, v) (HW_USB_ENDPTCTRL2_WR(x, (HW_USB_ENDPTCTRL2_RD(x) & ~BM_USB_ENDPTCTRL2_TXI) | BF_USB_ENDPTCTRL2_TXI(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL2, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_ENDPTCTRL2_TXR (22U)        /*!< Bit position for USB_ENDPTCTRL2_TXR. */
#define BM_USB_ENDPTCTRL2_TXR (0x00400000U) /*!< Bit mask for USB_ENDPTCTRL2_TXR. */
#define BS_USB_ENDPTCTRL2_TXR (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL2_TXR. */

/*! @brief Read current value of the USB_ENDPTCTRL2_TXR field. */
#define BR_USB_ENDPTCTRL2_TXR(x) (HW_USB_ENDPTCTRL2(x).B.TXR)

/*! @brief Format value for bitfield USB_ENDPTCTRL2_TXR. */
#define BF_USB_ENDPTCTRL2_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL2_TXR) & BM_USB_ENDPTCTRL2_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_ENDPTCTRL2_TXR(x, v) (HW_USB_ENDPTCTRL2_WR(x, (HW_USB_ENDPTCTRL2_RD(x) & ~BM_USB_ENDPTCTRL2_TXR) | BF_USB_ENDPTCTRL2_TXR(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL2, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_ENDPTCTRL2_TXE (23U)        /*!< Bit position for USB_ENDPTCTRL2_TXE. */
#define BM_USB_ENDPTCTRL2_TXE (0x00800000U) /*!< Bit mask for USB_ENDPTCTRL2_TXE. */
#define BS_USB_ENDPTCTRL2_TXE (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL2_TXE. */

/*! @brief Read current value of the USB_ENDPTCTRL2_TXE field. */
#define BR_USB_ENDPTCTRL2_TXE(x) (HW_USB_ENDPTCTRL2(x).B.TXE)

/*! @brief Format value for bitfield USB_ENDPTCTRL2_TXE. */
#define BF_USB_ENDPTCTRL2_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL2_TXE) & BM_USB_ENDPTCTRL2_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_ENDPTCTRL2_TXE(x, v) (HW_USB_ENDPTCTRL2_WR(x, (HW_USB_ENDPTCTRL2_RD(x) & ~BM_USB_ENDPTCTRL2_TXE) | BF_USB_ENDPTCTRL2_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_ENDPTCTRL3 - Endpoint Control 3
 ******************************************************************************/

/*!
 * @brief HW_USB_ENDPTCTRL3 - Endpoint Control 3 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 3 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_endptctrl3
{
    uint32_t U;
    struct _hw_usb_endptctrl3_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_endptctrl3_t;

/*!
 * @name Constants and macros for entire USB_ENDPTCTRL3 register
 */
/*@{*/
#define HW_USB_ENDPTCTRL3_ADDR(x) ((uintptr_t)(x) + 0x1CCU)

#define HW_USB_ENDPTCTRL3(x)     (*(__IO hw_usb_endptctrl3_t *) HW_USB_ENDPTCTRL3_ADDR(x))
#define HW_USB_ENDPTCTRL3_RD(x)  (HW_USB_ENDPTCTRL3(x).U)
#define HW_USB_ENDPTCTRL3_WR(x, v) (HW_USB_ENDPTCTRL3(x).U = (v))
#define HW_USB_ENDPTCTRL3_SET(x, v) (HW_USB_ENDPTCTRL3_WR(x, HW_USB_ENDPTCTRL3_RD(x) |  (v)))
#define HW_USB_ENDPTCTRL3_CLR(x, v) (HW_USB_ENDPTCTRL3_WR(x, HW_USB_ENDPTCTRL3_RD(x) & ~(v)))
#define HW_USB_ENDPTCTRL3_TOG(x, v) (HW_USB_ENDPTCTRL3_WR(x, HW_USB_ENDPTCTRL3_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_ENDPTCTRL3 bitfields
 */

/*!
 * @name Register USB_ENDPTCTRL3, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay. However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or
 * until a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_ENDPTCTRL3_RXS (0U)         /*!< Bit position for USB_ENDPTCTRL3_RXS. */
#define BM_USB_ENDPTCTRL3_RXS (0x00000001U) /*!< Bit mask for USB_ENDPTCTRL3_RXS. */
#define BS_USB_ENDPTCTRL3_RXS (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL3_RXS. */

/*! @brief Read current value of the USB_ENDPTCTRL3_RXS field. */
#define BR_USB_ENDPTCTRL3_RXS(x) (HW_USB_ENDPTCTRL3(x).B.RXS)

/*! @brief Format value for bitfield USB_ENDPTCTRL3_RXS. */
#define BF_USB_ENDPTCTRL3_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL3_RXS) & BM_USB_ENDPTCTRL3_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_ENDPTCTRL3_RXS(x, v) (HW_USB_ENDPTCTRL3_WR(x, (HW_USB_ENDPTCTRL3_RD(x) & ~BM_USB_ENDPTCTRL3_RXS) | BF_USB_ENDPTCTRL3_RXS(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL3, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_ENDPTCTRL3_RXD (1U)         /*!< Bit position for USB_ENDPTCTRL3_RXD. */
#define BM_USB_ENDPTCTRL3_RXD (0x00000002U) /*!< Bit mask for USB_ENDPTCTRL3_RXD. */
#define BS_USB_ENDPTCTRL3_RXD (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL3_RXD. */

/*! @brief Read current value of the USB_ENDPTCTRL3_RXD field. */
#define BR_USB_ENDPTCTRL3_RXD(x) (HW_USB_ENDPTCTRL3(x).B.RXD)

/*! @brief Format value for bitfield USB_ENDPTCTRL3_RXD. */
#define BF_USB_ENDPTCTRL3_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL3_RXD) & BM_USB_ENDPTCTRL3_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_ENDPTCTRL3_RXD(x, v) (HW_USB_ENDPTCTRL3_WR(x, (HW_USB_ENDPTCTRL3_RD(x) & ~BM_USB_ENDPTCTRL3_RXD) | BF_USB_ENDPTCTRL3_RXD(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL3, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_ENDPTCTRL3_RXT (2U)         /*!< Bit position for USB_ENDPTCTRL3_RXT. */
#define BM_USB_ENDPTCTRL3_RXT (0x0000000CU) /*!< Bit mask for USB_ENDPTCTRL3_RXT. */
#define BS_USB_ENDPTCTRL3_RXT (2U)         /*!< Bit field size in bits for USB_ENDPTCTRL3_RXT. */

/*! @brief Read current value of the USB_ENDPTCTRL3_RXT field. */
#define BR_USB_ENDPTCTRL3_RXT(x) (HW_USB_ENDPTCTRL3(x).B.RXT)

/*! @brief Format value for bitfield USB_ENDPTCTRL3_RXT. */
#define BF_USB_ENDPTCTRL3_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL3_RXT) & BM_USB_ENDPTCTRL3_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_ENDPTCTRL3_RXT(x, v) (HW_USB_ENDPTCTRL3_WR(x, (HW_USB_ENDPTCTRL3_RD(x) & ~BM_USB_ENDPTCTRL3_RXT) | BF_USB_ENDPTCTRL3_RXT(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL3, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_ENDPTCTRL3_RXI (5U)         /*!< Bit position for USB_ENDPTCTRL3_RXI. */
#define BM_USB_ENDPTCTRL3_RXI (0x00000020U) /*!< Bit mask for USB_ENDPTCTRL3_RXI. */
#define BS_USB_ENDPTCTRL3_RXI (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL3_RXI. */

/*! @brief Read current value of the USB_ENDPTCTRL3_RXI field. */
#define BR_USB_ENDPTCTRL3_RXI(x) (HW_USB_ENDPTCTRL3(x).B.RXI)

/*! @brief Format value for bitfield USB_ENDPTCTRL3_RXI. */
#define BF_USB_ENDPTCTRL3_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL3_RXI) & BM_USB_ENDPTCTRL3_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_ENDPTCTRL3_RXI(x, v) (HW_USB_ENDPTCTRL3_WR(x, (HW_USB_ENDPTCTRL3_RD(x) & ~BM_USB_ENDPTCTRL3_RXI) | BF_USB_ENDPTCTRL3_RXI(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL3, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_ENDPTCTRL3_RXR (6U)         /*!< Bit position for USB_ENDPTCTRL3_RXR. */
#define BM_USB_ENDPTCTRL3_RXR (0x00000040U) /*!< Bit mask for USB_ENDPTCTRL3_RXR. */
#define BS_USB_ENDPTCTRL3_RXR (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL3_RXR. */

/*! @brief Read current value of the USB_ENDPTCTRL3_RXR field. */
#define BR_USB_ENDPTCTRL3_RXR(x) (HW_USB_ENDPTCTRL3(x).B.RXR)

/*! @brief Format value for bitfield USB_ENDPTCTRL3_RXR. */
#define BF_USB_ENDPTCTRL3_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL3_RXR) & BM_USB_ENDPTCTRL3_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_ENDPTCTRL3_RXR(x, v) (HW_USB_ENDPTCTRL3_WR(x, (HW_USB_ENDPTCTRL3_RD(x) & ~BM_USB_ENDPTCTRL3_RXR) | BF_USB_ENDPTCTRL3_RXR(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL3, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_ENDPTCTRL3_RXE (7U)         /*!< Bit position for USB_ENDPTCTRL3_RXE. */
#define BM_USB_ENDPTCTRL3_RXE (0x00000080U) /*!< Bit mask for USB_ENDPTCTRL3_RXE. */
#define BS_USB_ENDPTCTRL3_RXE (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL3_RXE. */

/*! @brief Read current value of the USB_ENDPTCTRL3_RXE field. */
#define BR_USB_ENDPTCTRL3_RXE(x) (HW_USB_ENDPTCTRL3(x).B.RXE)

/*! @brief Format value for bitfield USB_ENDPTCTRL3_RXE. */
#define BF_USB_ENDPTCTRL3_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL3_RXE) & BM_USB_ENDPTCTRL3_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_ENDPTCTRL3_RXE(x, v) (HW_USB_ENDPTCTRL3_WR(x, (HW_USB_ENDPTCTRL3_RD(x) & ~BM_USB_ENDPTCTRL3_RXE) | BF_USB_ENDPTCTRL3_RXE(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL3, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay. However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_ENDPTCTRL3_TXS (16U)        /*!< Bit position for USB_ENDPTCTRL3_TXS. */
#define BM_USB_ENDPTCTRL3_TXS (0x00010000U) /*!< Bit mask for USB_ENDPTCTRL3_TXS. */
#define BS_USB_ENDPTCTRL3_TXS (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL3_TXS. */

/*! @brief Read current value of the USB_ENDPTCTRL3_TXS field. */
#define BR_USB_ENDPTCTRL3_TXS(x) (HW_USB_ENDPTCTRL3(x).B.TXS)

/*! @brief Format value for bitfield USB_ENDPTCTRL3_TXS. */
#define BF_USB_ENDPTCTRL3_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL3_TXS) & BM_USB_ENDPTCTRL3_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_ENDPTCTRL3_TXS(x, v) (HW_USB_ENDPTCTRL3_WR(x, (HW_USB_ENDPTCTRL3_RD(x) & ~BM_USB_ENDPTCTRL3_TXS) | BF_USB_ENDPTCTRL3_TXS(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL3, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_ENDPTCTRL3_TXD (17U)        /*!< Bit position for USB_ENDPTCTRL3_TXD. */
#define BM_USB_ENDPTCTRL3_TXD (0x00020000U) /*!< Bit mask for USB_ENDPTCTRL3_TXD. */
#define BS_USB_ENDPTCTRL3_TXD (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL3_TXD. */

/*! @brief Read current value of the USB_ENDPTCTRL3_TXD field. */
#define BR_USB_ENDPTCTRL3_TXD(x) (HW_USB_ENDPTCTRL3(x).B.TXD)

/*! @brief Format value for bitfield USB_ENDPTCTRL3_TXD. */
#define BF_USB_ENDPTCTRL3_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL3_TXD) & BM_USB_ENDPTCTRL3_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_ENDPTCTRL3_TXD(x, v) (HW_USB_ENDPTCTRL3_WR(x, (HW_USB_ENDPTCTRL3_RD(x) & ~BM_USB_ENDPTCTRL3_TXD) | BF_USB_ENDPTCTRL3_TXD(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL3, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_ENDPTCTRL3_TXT (18U)        /*!< Bit position for USB_ENDPTCTRL3_TXT. */
#define BM_USB_ENDPTCTRL3_TXT (0x000C0000U) /*!< Bit mask for USB_ENDPTCTRL3_TXT. */
#define BS_USB_ENDPTCTRL3_TXT (2U)         /*!< Bit field size in bits for USB_ENDPTCTRL3_TXT. */

/*! @brief Read current value of the USB_ENDPTCTRL3_TXT field. */
#define BR_USB_ENDPTCTRL3_TXT(x) (HW_USB_ENDPTCTRL3(x).B.TXT)

/*! @brief Format value for bitfield USB_ENDPTCTRL3_TXT. */
#define BF_USB_ENDPTCTRL3_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL3_TXT) & BM_USB_ENDPTCTRL3_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_ENDPTCTRL3_TXT(x, v) (HW_USB_ENDPTCTRL3_WR(x, (HW_USB_ENDPTCTRL3_RD(x) & ~BM_USB_ENDPTCTRL3_TXT) | BF_USB_ENDPTCTRL3_TXT(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL3, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_ENDPTCTRL3_TXI (21U)        /*!< Bit position for USB_ENDPTCTRL3_TXI. */
#define BM_USB_ENDPTCTRL3_TXI (0x00200000U) /*!< Bit mask for USB_ENDPTCTRL3_TXI. */
#define BS_USB_ENDPTCTRL3_TXI (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL3_TXI. */

/*! @brief Read current value of the USB_ENDPTCTRL3_TXI field. */
#define BR_USB_ENDPTCTRL3_TXI(x) (HW_USB_ENDPTCTRL3(x).B.TXI)

/*! @brief Format value for bitfield USB_ENDPTCTRL3_TXI. */
#define BF_USB_ENDPTCTRL3_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL3_TXI) & BM_USB_ENDPTCTRL3_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_ENDPTCTRL3_TXI(x, v) (HW_USB_ENDPTCTRL3_WR(x, (HW_USB_ENDPTCTRL3_RD(x) & ~BM_USB_ENDPTCTRL3_TXI) | BF_USB_ENDPTCTRL3_TXI(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL3, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_ENDPTCTRL3_TXR (22U)        /*!< Bit position for USB_ENDPTCTRL3_TXR. */
#define BM_USB_ENDPTCTRL3_TXR (0x00400000U) /*!< Bit mask for USB_ENDPTCTRL3_TXR. */
#define BS_USB_ENDPTCTRL3_TXR (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL3_TXR. */

/*! @brief Read current value of the USB_ENDPTCTRL3_TXR field. */
#define BR_USB_ENDPTCTRL3_TXR(x) (HW_USB_ENDPTCTRL3(x).B.TXR)

/*! @brief Format value for bitfield USB_ENDPTCTRL3_TXR. */
#define BF_USB_ENDPTCTRL3_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL3_TXR) & BM_USB_ENDPTCTRL3_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_ENDPTCTRL3_TXR(x, v) (HW_USB_ENDPTCTRL3_WR(x, (HW_USB_ENDPTCTRL3_RD(x) & ~BM_USB_ENDPTCTRL3_TXR) | BF_USB_ENDPTCTRL3_TXR(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL3, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_ENDPTCTRL3_TXE (23U)        /*!< Bit position for USB_ENDPTCTRL3_TXE. */
#define BM_USB_ENDPTCTRL3_TXE (0x00800000U) /*!< Bit mask for USB_ENDPTCTRL3_TXE. */
#define BS_USB_ENDPTCTRL3_TXE (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL3_TXE. */

/*! @brief Read current value of the USB_ENDPTCTRL3_TXE field. */
#define BR_USB_ENDPTCTRL3_TXE(x) (HW_USB_ENDPTCTRL3(x).B.TXE)

/*! @brief Format value for bitfield USB_ENDPTCTRL3_TXE. */
#define BF_USB_ENDPTCTRL3_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL3_TXE) & BM_USB_ENDPTCTRL3_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_ENDPTCTRL3_TXE(x, v) (HW_USB_ENDPTCTRL3_WR(x, (HW_USB_ENDPTCTRL3_RD(x) & ~BM_USB_ENDPTCTRL3_TXE) | BF_USB_ENDPTCTRL3_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_ENDPTCTRL4 - Endpoint Control 4
 ******************************************************************************/

/*!
 * @brief HW_USB_ENDPTCTRL4 - Endpoint Control 4 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 4 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_endptctrl4
{
    uint32_t U;
    struct _hw_usb_endptctrl4_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_endptctrl4_t;

/*!
 * @name Constants and macros for entire USB_ENDPTCTRL4 register
 */
/*@{*/
#define HW_USB_ENDPTCTRL4_ADDR(x) ((uintptr_t)(x) + 0x1D0U)

#define HW_USB_ENDPTCTRL4(x)     (*(__IO hw_usb_endptctrl4_t *) HW_USB_ENDPTCTRL4_ADDR(x))
#define HW_USB_ENDPTCTRL4_RD(x)  (HW_USB_ENDPTCTRL4(x).U)
#define HW_USB_ENDPTCTRL4_WR(x, v) (HW_USB_ENDPTCTRL4(x).U = (v))
#define HW_USB_ENDPTCTRL4_SET(x, v) (HW_USB_ENDPTCTRL4_WR(x, HW_USB_ENDPTCTRL4_RD(x) |  (v)))
#define HW_USB_ENDPTCTRL4_CLR(x, v) (HW_USB_ENDPTCTRL4_WR(x, HW_USB_ENDPTCTRL4_RD(x) & ~(v)))
#define HW_USB_ENDPTCTRL4_TOG(x, v) (HW_USB_ENDPTCTRL4_WR(x, HW_USB_ENDPTCTRL4_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_ENDPTCTRL4 bitfields
 */

/*!
 * @name Register USB_ENDPTCTRL4, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay. However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or
 * until a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_ENDPTCTRL4_RXS (0U)         /*!< Bit position for USB_ENDPTCTRL4_RXS. */
#define BM_USB_ENDPTCTRL4_RXS (0x00000001U) /*!< Bit mask for USB_ENDPTCTRL4_RXS. */
#define BS_USB_ENDPTCTRL4_RXS (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL4_RXS. */

/*! @brief Read current value of the USB_ENDPTCTRL4_RXS field. */
#define BR_USB_ENDPTCTRL4_RXS(x) (HW_USB_ENDPTCTRL4(x).B.RXS)

/*! @brief Format value for bitfield USB_ENDPTCTRL4_RXS. */
#define BF_USB_ENDPTCTRL4_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL4_RXS) & BM_USB_ENDPTCTRL4_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_ENDPTCTRL4_RXS(x, v) (HW_USB_ENDPTCTRL4_WR(x, (HW_USB_ENDPTCTRL4_RD(x) & ~BM_USB_ENDPTCTRL4_RXS) | BF_USB_ENDPTCTRL4_RXS(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL4, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_ENDPTCTRL4_RXD (1U)         /*!< Bit position for USB_ENDPTCTRL4_RXD. */
#define BM_USB_ENDPTCTRL4_RXD (0x00000002U) /*!< Bit mask for USB_ENDPTCTRL4_RXD. */
#define BS_USB_ENDPTCTRL4_RXD (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL4_RXD. */

/*! @brief Read current value of the USB_ENDPTCTRL4_RXD field. */
#define BR_USB_ENDPTCTRL4_RXD(x) (HW_USB_ENDPTCTRL4(x).B.RXD)

/*! @brief Format value for bitfield USB_ENDPTCTRL4_RXD. */
#define BF_USB_ENDPTCTRL4_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL4_RXD) & BM_USB_ENDPTCTRL4_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_ENDPTCTRL4_RXD(x, v) (HW_USB_ENDPTCTRL4_WR(x, (HW_USB_ENDPTCTRL4_RD(x) & ~BM_USB_ENDPTCTRL4_RXD) | BF_USB_ENDPTCTRL4_RXD(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL4, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_ENDPTCTRL4_RXT (2U)         /*!< Bit position for USB_ENDPTCTRL4_RXT. */
#define BM_USB_ENDPTCTRL4_RXT (0x0000000CU) /*!< Bit mask for USB_ENDPTCTRL4_RXT. */
#define BS_USB_ENDPTCTRL4_RXT (2U)         /*!< Bit field size in bits for USB_ENDPTCTRL4_RXT. */

/*! @brief Read current value of the USB_ENDPTCTRL4_RXT field. */
#define BR_USB_ENDPTCTRL4_RXT(x) (HW_USB_ENDPTCTRL4(x).B.RXT)

/*! @brief Format value for bitfield USB_ENDPTCTRL4_RXT. */
#define BF_USB_ENDPTCTRL4_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL4_RXT) & BM_USB_ENDPTCTRL4_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_ENDPTCTRL4_RXT(x, v) (HW_USB_ENDPTCTRL4_WR(x, (HW_USB_ENDPTCTRL4_RD(x) & ~BM_USB_ENDPTCTRL4_RXT) | BF_USB_ENDPTCTRL4_RXT(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL4, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_ENDPTCTRL4_RXI (5U)         /*!< Bit position for USB_ENDPTCTRL4_RXI. */
#define BM_USB_ENDPTCTRL4_RXI (0x00000020U) /*!< Bit mask for USB_ENDPTCTRL4_RXI. */
#define BS_USB_ENDPTCTRL4_RXI (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL4_RXI. */

/*! @brief Read current value of the USB_ENDPTCTRL4_RXI field. */
#define BR_USB_ENDPTCTRL4_RXI(x) (HW_USB_ENDPTCTRL4(x).B.RXI)

/*! @brief Format value for bitfield USB_ENDPTCTRL4_RXI. */
#define BF_USB_ENDPTCTRL4_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL4_RXI) & BM_USB_ENDPTCTRL4_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_ENDPTCTRL4_RXI(x, v) (HW_USB_ENDPTCTRL4_WR(x, (HW_USB_ENDPTCTRL4_RD(x) & ~BM_USB_ENDPTCTRL4_RXI) | BF_USB_ENDPTCTRL4_RXI(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL4, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_ENDPTCTRL4_RXR (6U)         /*!< Bit position for USB_ENDPTCTRL4_RXR. */
#define BM_USB_ENDPTCTRL4_RXR (0x00000040U) /*!< Bit mask for USB_ENDPTCTRL4_RXR. */
#define BS_USB_ENDPTCTRL4_RXR (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL4_RXR. */

/*! @brief Read current value of the USB_ENDPTCTRL4_RXR field. */
#define BR_USB_ENDPTCTRL4_RXR(x) (HW_USB_ENDPTCTRL4(x).B.RXR)

/*! @brief Format value for bitfield USB_ENDPTCTRL4_RXR. */
#define BF_USB_ENDPTCTRL4_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL4_RXR) & BM_USB_ENDPTCTRL4_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_ENDPTCTRL4_RXR(x, v) (HW_USB_ENDPTCTRL4_WR(x, (HW_USB_ENDPTCTRL4_RD(x) & ~BM_USB_ENDPTCTRL4_RXR) | BF_USB_ENDPTCTRL4_RXR(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL4, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_ENDPTCTRL4_RXE (7U)         /*!< Bit position for USB_ENDPTCTRL4_RXE. */
#define BM_USB_ENDPTCTRL4_RXE (0x00000080U) /*!< Bit mask for USB_ENDPTCTRL4_RXE. */
#define BS_USB_ENDPTCTRL4_RXE (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL4_RXE. */

/*! @brief Read current value of the USB_ENDPTCTRL4_RXE field. */
#define BR_USB_ENDPTCTRL4_RXE(x) (HW_USB_ENDPTCTRL4(x).B.RXE)

/*! @brief Format value for bitfield USB_ENDPTCTRL4_RXE. */
#define BF_USB_ENDPTCTRL4_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL4_RXE) & BM_USB_ENDPTCTRL4_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_ENDPTCTRL4_RXE(x, v) (HW_USB_ENDPTCTRL4_WR(x, (HW_USB_ENDPTCTRL4_RD(x) & ~BM_USB_ENDPTCTRL4_RXE) | BF_USB_ENDPTCTRL4_RXE(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL4, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay. However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_ENDPTCTRL4_TXS (16U)        /*!< Bit position for USB_ENDPTCTRL4_TXS. */
#define BM_USB_ENDPTCTRL4_TXS (0x00010000U) /*!< Bit mask for USB_ENDPTCTRL4_TXS. */
#define BS_USB_ENDPTCTRL4_TXS (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL4_TXS. */

/*! @brief Read current value of the USB_ENDPTCTRL4_TXS field. */
#define BR_USB_ENDPTCTRL4_TXS(x) (HW_USB_ENDPTCTRL4(x).B.TXS)

/*! @brief Format value for bitfield USB_ENDPTCTRL4_TXS. */
#define BF_USB_ENDPTCTRL4_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL4_TXS) & BM_USB_ENDPTCTRL4_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_ENDPTCTRL4_TXS(x, v) (HW_USB_ENDPTCTRL4_WR(x, (HW_USB_ENDPTCTRL4_RD(x) & ~BM_USB_ENDPTCTRL4_TXS) | BF_USB_ENDPTCTRL4_TXS(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL4, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_ENDPTCTRL4_TXD (17U)        /*!< Bit position for USB_ENDPTCTRL4_TXD. */
#define BM_USB_ENDPTCTRL4_TXD (0x00020000U) /*!< Bit mask for USB_ENDPTCTRL4_TXD. */
#define BS_USB_ENDPTCTRL4_TXD (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL4_TXD. */

/*! @brief Read current value of the USB_ENDPTCTRL4_TXD field. */
#define BR_USB_ENDPTCTRL4_TXD(x) (HW_USB_ENDPTCTRL4(x).B.TXD)

/*! @brief Format value for bitfield USB_ENDPTCTRL4_TXD. */
#define BF_USB_ENDPTCTRL4_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL4_TXD) & BM_USB_ENDPTCTRL4_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_ENDPTCTRL4_TXD(x, v) (HW_USB_ENDPTCTRL4_WR(x, (HW_USB_ENDPTCTRL4_RD(x) & ~BM_USB_ENDPTCTRL4_TXD) | BF_USB_ENDPTCTRL4_TXD(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL4, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_ENDPTCTRL4_TXT (18U)        /*!< Bit position for USB_ENDPTCTRL4_TXT. */
#define BM_USB_ENDPTCTRL4_TXT (0x000C0000U) /*!< Bit mask for USB_ENDPTCTRL4_TXT. */
#define BS_USB_ENDPTCTRL4_TXT (2U)         /*!< Bit field size in bits for USB_ENDPTCTRL4_TXT. */

/*! @brief Read current value of the USB_ENDPTCTRL4_TXT field. */
#define BR_USB_ENDPTCTRL4_TXT(x) (HW_USB_ENDPTCTRL4(x).B.TXT)

/*! @brief Format value for bitfield USB_ENDPTCTRL4_TXT. */
#define BF_USB_ENDPTCTRL4_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL4_TXT) & BM_USB_ENDPTCTRL4_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_ENDPTCTRL4_TXT(x, v) (HW_USB_ENDPTCTRL4_WR(x, (HW_USB_ENDPTCTRL4_RD(x) & ~BM_USB_ENDPTCTRL4_TXT) | BF_USB_ENDPTCTRL4_TXT(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL4, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_ENDPTCTRL4_TXI (21U)        /*!< Bit position for USB_ENDPTCTRL4_TXI. */
#define BM_USB_ENDPTCTRL4_TXI (0x00200000U) /*!< Bit mask for USB_ENDPTCTRL4_TXI. */
#define BS_USB_ENDPTCTRL4_TXI (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL4_TXI. */

/*! @brief Read current value of the USB_ENDPTCTRL4_TXI field. */
#define BR_USB_ENDPTCTRL4_TXI(x) (HW_USB_ENDPTCTRL4(x).B.TXI)

/*! @brief Format value for bitfield USB_ENDPTCTRL4_TXI. */
#define BF_USB_ENDPTCTRL4_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL4_TXI) & BM_USB_ENDPTCTRL4_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_ENDPTCTRL4_TXI(x, v) (HW_USB_ENDPTCTRL4_WR(x, (HW_USB_ENDPTCTRL4_RD(x) & ~BM_USB_ENDPTCTRL4_TXI) | BF_USB_ENDPTCTRL4_TXI(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL4, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_ENDPTCTRL4_TXR (22U)        /*!< Bit position for USB_ENDPTCTRL4_TXR. */
#define BM_USB_ENDPTCTRL4_TXR (0x00400000U) /*!< Bit mask for USB_ENDPTCTRL4_TXR. */
#define BS_USB_ENDPTCTRL4_TXR (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL4_TXR. */

/*! @brief Read current value of the USB_ENDPTCTRL4_TXR field. */
#define BR_USB_ENDPTCTRL4_TXR(x) (HW_USB_ENDPTCTRL4(x).B.TXR)

/*! @brief Format value for bitfield USB_ENDPTCTRL4_TXR. */
#define BF_USB_ENDPTCTRL4_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL4_TXR) & BM_USB_ENDPTCTRL4_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_ENDPTCTRL4_TXR(x, v) (HW_USB_ENDPTCTRL4_WR(x, (HW_USB_ENDPTCTRL4_RD(x) & ~BM_USB_ENDPTCTRL4_TXR) | BF_USB_ENDPTCTRL4_TXR(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL4, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_ENDPTCTRL4_TXE (23U)        /*!< Bit position for USB_ENDPTCTRL4_TXE. */
#define BM_USB_ENDPTCTRL4_TXE (0x00800000U) /*!< Bit mask for USB_ENDPTCTRL4_TXE. */
#define BS_USB_ENDPTCTRL4_TXE (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL4_TXE. */

/*! @brief Read current value of the USB_ENDPTCTRL4_TXE field. */
#define BR_USB_ENDPTCTRL4_TXE(x) (HW_USB_ENDPTCTRL4(x).B.TXE)

/*! @brief Format value for bitfield USB_ENDPTCTRL4_TXE. */
#define BF_USB_ENDPTCTRL4_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL4_TXE) & BM_USB_ENDPTCTRL4_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_ENDPTCTRL4_TXE(x, v) (HW_USB_ENDPTCTRL4_WR(x, (HW_USB_ENDPTCTRL4_RD(x) & ~BM_USB_ENDPTCTRL4_TXE) | BF_USB_ENDPTCTRL4_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_ENDPTCTRL5 - Endpoint Control 5
 ******************************************************************************/

/*!
 * @brief HW_USB_ENDPTCTRL5 - Endpoint Control 5 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 5 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_endptctrl5
{
    uint32_t U;
    struct _hw_usb_endptctrl5_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_endptctrl5_t;

/*!
 * @name Constants and macros for entire USB_ENDPTCTRL5 register
 */
/*@{*/
#define HW_USB_ENDPTCTRL5_ADDR(x) ((uintptr_t)(x) + 0x1D4U)

#define HW_USB_ENDPTCTRL5(x)     (*(__IO hw_usb_endptctrl5_t *) HW_USB_ENDPTCTRL5_ADDR(x))
#define HW_USB_ENDPTCTRL5_RD(x)  (HW_USB_ENDPTCTRL5(x).U)
#define HW_USB_ENDPTCTRL5_WR(x, v) (HW_USB_ENDPTCTRL5(x).U = (v))
#define HW_USB_ENDPTCTRL5_SET(x, v) (HW_USB_ENDPTCTRL5_WR(x, HW_USB_ENDPTCTRL5_RD(x) |  (v)))
#define HW_USB_ENDPTCTRL5_CLR(x, v) (HW_USB_ENDPTCTRL5_WR(x, HW_USB_ENDPTCTRL5_RD(x) & ~(v)))
#define HW_USB_ENDPTCTRL5_TOG(x, v) (HW_USB_ENDPTCTRL5_WR(x, HW_USB_ENDPTCTRL5_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_ENDPTCTRL5 bitfields
 */

/*!
 * @name Register USB_ENDPTCTRL5, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay. However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or
 * until a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_ENDPTCTRL5_RXS (0U)         /*!< Bit position for USB_ENDPTCTRL5_RXS. */
#define BM_USB_ENDPTCTRL5_RXS (0x00000001U) /*!< Bit mask for USB_ENDPTCTRL5_RXS. */
#define BS_USB_ENDPTCTRL5_RXS (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL5_RXS. */

/*! @brief Read current value of the USB_ENDPTCTRL5_RXS field. */
#define BR_USB_ENDPTCTRL5_RXS(x) (HW_USB_ENDPTCTRL5(x).B.RXS)

/*! @brief Format value for bitfield USB_ENDPTCTRL5_RXS. */
#define BF_USB_ENDPTCTRL5_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL5_RXS) & BM_USB_ENDPTCTRL5_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_ENDPTCTRL5_RXS(x, v) (HW_USB_ENDPTCTRL5_WR(x, (HW_USB_ENDPTCTRL5_RD(x) & ~BM_USB_ENDPTCTRL5_RXS) | BF_USB_ENDPTCTRL5_RXS(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL5, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_ENDPTCTRL5_RXD (1U)         /*!< Bit position for USB_ENDPTCTRL5_RXD. */
#define BM_USB_ENDPTCTRL5_RXD (0x00000002U) /*!< Bit mask for USB_ENDPTCTRL5_RXD. */
#define BS_USB_ENDPTCTRL5_RXD (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL5_RXD. */

/*! @brief Read current value of the USB_ENDPTCTRL5_RXD field. */
#define BR_USB_ENDPTCTRL5_RXD(x) (HW_USB_ENDPTCTRL5(x).B.RXD)

/*! @brief Format value for bitfield USB_ENDPTCTRL5_RXD. */
#define BF_USB_ENDPTCTRL5_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL5_RXD) & BM_USB_ENDPTCTRL5_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_ENDPTCTRL5_RXD(x, v) (HW_USB_ENDPTCTRL5_WR(x, (HW_USB_ENDPTCTRL5_RD(x) & ~BM_USB_ENDPTCTRL5_RXD) | BF_USB_ENDPTCTRL5_RXD(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL5, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_ENDPTCTRL5_RXT (2U)         /*!< Bit position for USB_ENDPTCTRL5_RXT. */
#define BM_USB_ENDPTCTRL5_RXT (0x0000000CU) /*!< Bit mask for USB_ENDPTCTRL5_RXT. */
#define BS_USB_ENDPTCTRL5_RXT (2U)         /*!< Bit field size in bits for USB_ENDPTCTRL5_RXT. */

/*! @brief Read current value of the USB_ENDPTCTRL5_RXT field. */
#define BR_USB_ENDPTCTRL5_RXT(x) (HW_USB_ENDPTCTRL5(x).B.RXT)

/*! @brief Format value for bitfield USB_ENDPTCTRL5_RXT. */
#define BF_USB_ENDPTCTRL5_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL5_RXT) & BM_USB_ENDPTCTRL5_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_ENDPTCTRL5_RXT(x, v) (HW_USB_ENDPTCTRL5_WR(x, (HW_USB_ENDPTCTRL5_RD(x) & ~BM_USB_ENDPTCTRL5_RXT) | BF_USB_ENDPTCTRL5_RXT(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL5, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_ENDPTCTRL5_RXI (5U)         /*!< Bit position for USB_ENDPTCTRL5_RXI. */
#define BM_USB_ENDPTCTRL5_RXI (0x00000020U) /*!< Bit mask for USB_ENDPTCTRL5_RXI. */
#define BS_USB_ENDPTCTRL5_RXI (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL5_RXI. */

/*! @brief Read current value of the USB_ENDPTCTRL5_RXI field. */
#define BR_USB_ENDPTCTRL5_RXI(x) (HW_USB_ENDPTCTRL5(x).B.RXI)

/*! @brief Format value for bitfield USB_ENDPTCTRL5_RXI. */
#define BF_USB_ENDPTCTRL5_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL5_RXI) & BM_USB_ENDPTCTRL5_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_ENDPTCTRL5_RXI(x, v) (HW_USB_ENDPTCTRL5_WR(x, (HW_USB_ENDPTCTRL5_RD(x) & ~BM_USB_ENDPTCTRL5_RXI) | BF_USB_ENDPTCTRL5_RXI(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL5, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_ENDPTCTRL5_RXR (6U)         /*!< Bit position for USB_ENDPTCTRL5_RXR. */
#define BM_USB_ENDPTCTRL5_RXR (0x00000040U) /*!< Bit mask for USB_ENDPTCTRL5_RXR. */
#define BS_USB_ENDPTCTRL5_RXR (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL5_RXR. */

/*! @brief Read current value of the USB_ENDPTCTRL5_RXR field. */
#define BR_USB_ENDPTCTRL5_RXR(x) (HW_USB_ENDPTCTRL5(x).B.RXR)

/*! @brief Format value for bitfield USB_ENDPTCTRL5_RXR. */
#define BF_USB_ENDPTCTRL5_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL5_RXR) & BM_USB_ENDPTCTRL5_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_ENDPTCTRL5_RXR(x, v) (HW_USB_ENDPTCTRL5_WR(x, (HW_USB_ENDPTCTRL5_RD(x) & ~BM_USB_ENDPTCTRL5_RXR) | BF_USB_ENDPTCTRL5_RXR(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL5, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_ENDPTCTRL5_RXE (7U)         /*!< Bit position for USB_ENDPTCTRL5_RXE. */
#define BM_USB_ENDPTCTRL5_RXE (0x00000080U) /*!< Bit mask for USB_ENDPTCTRL5_RXE. */
#define BS_USB_ENDPTCTRL5_RXE (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL5_RXE. */

/*! @brief Read current value of the USB_ENDPTCTRL5_RXE field. */
#define BR_USB_ENDPTCTRL5_RXE(x) (HW_USB_ENDPTCTRL5(x).B.RXE)

/*! @brief Format value for bitfield USB_ENDPTCTRL5_RXE. */
#define BF_USB_ENDPTCTRL5_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL5_RXE) & BM_USB_ENDPTCTRL5_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_ENDPTCTRL5_RXE(x, v) (HW_USB_ENDPTCTRL5_WR(x, (HW_USB_ENDPTCTRL5_RD(x) & ~BM_USB_ENDPTCTRL5_RXE) | BF_USB_ENDPTCTRL5_RXE(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL5, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay. However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_ENDPTCTRL5_TXS (16U)        /*!< Bit position for USB_ENDPTCTRL5_TXS. */
#define BM_USB_ENDPTCTRL5_TXS (0x00010000U) /*!< Bit mask for USB_ENDPTCTRL5_TXS. */
#define BS_USB_ENDPTCTRL5_TXS (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL5_TXS. */

/*! @brief Read current value of the USB_ENDPTCTRL5_TXS field. */
#define BR_USB_ENDPTCTRL5_TXS(x) (HW_USB_ENDPTCTRL5(x).B.TXS)

/*! @brief Format value for bitfield USB_ENDPTCTRL5_TXS. */
#define BF_USB_ENDPTCTRL5_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL5_TXS) & BM_USB_ENDPTCTRL5_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_ENDPTCTRL5_TXS(x, v) (HW_USB_ENDPTCTRL5_WR(x, (HW_USB_ENDPTCTRL5_RD(x) & ~BM_USB_ENDPTCTRL5_TXS) | BF_USB_ENDPTCTRL5_TXS(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL5, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_ENDPTCTRL5_TXD (17U)        /*!< Bit position for USB_ENDPTCTRL5_TXD. */
#define BM_USB_ENDPTCTRL5_TXD (0x00020000U) /*!< Bit mask for USB_ENDPTCTRL5_TXD. */
#define BS_USB_ENDPTCTRL5_TXD (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL5_TXD. */

/*! @brief Read current value of the USB_ENDPTCTRL5_TXD field. */
#define BR_USB_ENDPTCTRL5_TXD(x) (HW_USB_ENDPTCTRL5(x).B.TXD)

/*! @brief Format value for bitfield USB_ENDPTCTRL5_TXD. */
#define BF_USB_ENDPTCTRL5_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL5_TXD) & BM_USB_ENDPTCTRL5_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_ENDPTCTRL5_TXD(x, v) (HW_USB_ENDPTCTRL5_WR(x, (HW_USB_ENDPTCTRL5_RD(x) & ~BM_USB_ENDPTCTRL5_TXD) | BF_USB_ENDPTCTRL5_TXD(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL5, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_ENDPTCTRL5_TXT (18U)        /*!< Bit position for USB_ENDPTCTRL5_TXT. */
#define BM_USB_ENDPTCTRL5_TXT (0x000C0000U) /*!< Bit mask for USB_ENDPTCTRL5_TXT. */
#define BS_USB_ENDPTCTRL5_TXT (2U)         /*!< Bit field size in bits for USB_ENDPTCTRL5_TXT. */

/*! @brief Read current value of the USB_ENDPTCTRL5_TXT field. */
#define BR_USB_ENDPTCTRL5_TXT(x) (HW_USB_ENDPTCTRL5(x).B.TXT)

/*! @brief Format value for bitfield USB_ENDPTCTRL5_TXT. */
#define BF_USB_ENDPTCTRL5_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL5_TXT) & BM_USB_ENDPTCTRL5_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_ENDPTCTRL5_TXT(x, v) (HW_USB_ENDPTCTRL5_WR(x, (HW_USB_ENDPTCTRL5_RD(x) & ~BM_USB_ENDPTCTRL5_TXT) | BF_USB_ENDPTCTRL5_TXT(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL5, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_ENDPTCTRL5_TXI (21U)        /*!< Bit position for USB_ENDPTCTRL5_TXI. */
#define BM_USB_ENDPTCTRL5_TXI (0x00200000U) /*!< Bit mask for USB_ENDPTCTRL5_TXI. */
#define BS_USB_ENDPTCTRL5_TXI (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL5_TXI. */

/*! @brief Read current value of the USB_ENDPTCTRL5_TXI field. */
#define BR_USB_ENDPTCTRL5_TXI(x) (HW_USB_ENDPTCTRL5(x).B.TXI)

/*! @brief Format value for bitfield USB_ENDPTCTRL5_TXI. */
#define BF_USB_ENDPTCTRL5_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL5_TXI) & BM_USB_ENDPTCTRL5_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_ENDPTCTRL5_TXI(x, v) (HW_USB_ENDPTCTRL5_WR(x, (HW_USB_ENDPTCTRL5_RD(x) & ~BM_USB_ENDPTCTRL5_TXI) | BF_USB_ENDPTCTRL5_TXI(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL5, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_ENDPTCTRL5_TXR (22U)        /*!< Bit position for USB_ENDPTCTRL5_TXR. */
#define BM_USB_ENDPTCTRL5_TXR (0x00400000U) /*!< Bit mask for USB_ENDPTCTRL5_TXR. */
#define BS_USB_ENDPTCTRL5_TXR (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL5_TXR. */

/*! @brief Read current value of the USB_ENDPTCTRL5_TXR field. */
#define BR_USB_ENDPTCTRL5_TXR(x) (HW_USB_ENDPTCTRL5(x).B.TXR)

/*! @brief Format value for bitfield USB_ENDPTCTRL5_TXR. */
#define BF_USB_ENDPTCTRL5_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL5_TXR) & BM_USB_ENDPTCTRL5_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_ENDPTCTRL5_TXR(x, v) (HW_USB_ENDPTCTRL5_WR(x, (HW_USB_ENDPTCTRL5_RD(x) & ~BM_USB_ENDPTCTRL5_TXR) | BF_USB_ENDPTCTRL5_TXR(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL5, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_ENDPTCTRL5_TXE (23U)        /*!< Bit position for USB_ENDPTCTRL5_TXE. */
#define BM_USB_ENDPTCTRL5_TXE (0x00800000U) /*!< Bit mask for USB_ENDPTCTRL5_TXE. */
#define BS_USB_ENDPTCTRL5_TXE (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL5_TXE. */

/*! @brief Read current value of the USB_ENDPTCTRL5_TXE field. */
#define BR_USB_ENDPTCTRL5_TXE(x) (HW_USB_ENDPTCTRL5(x).B.TXE)

/*! @brief Format value for bitfield USB_ENDPTCTRL5_TXE. */
#define BF_USB_ENDPTCTRL5_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL5_TXE) & BM_USB_ENDPTCTRL5_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_ENDPTCTRL5_TXE(x, v) (HW_USB_ENDPTCTRL5_WR(x, (HW_USB_ENDPTCTRL5_RD(x) & ~BM_USB_ENDPTCTRL5_TXE) | BF_USB_ENDPTCTRL5_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_ENDPTCTRL6 - Endpoint Control 6
 ******************************************************************************/

/*!
 * @brief HW_USB_ENDPTCTRL6 - Endpoint Control 6 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 6 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_endptctrl6
{
    uint32_t U;
    struct _hw_usb_endptctrl6_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_endptctrl6_t;

/*!
 * @name Constants and macros for entire USB_ENDPTCTRL6 register
 */
/*@{*/
#define HW_USB_ENDPTCTRL6_ADDR(x) ((uintptr_t)(x) + 0x1D8U)

#define HW_USB_ENDPTCTRL6(x)     (*(__IO hw_usb_endptctrl6_t *) HW_USB_ENDPTCTRL6_ADDR(x))
#define HW_USB_ENDPTCTRL6_RD(x)  (HW_USB_ENDPTCTRL6(x).U)
#define HW_USB_ENDPTCTRL6_WR(x, v) (HW_USB_ENDPTCTRL6(x).U = (v))
#define HW_USB_ENDPTCTRL6_SET(x, v) (HW_USB_ENDPTCTRL6_WR(x, HW_USB_ENDPTCTRL6_RD(x) |  (v)))
#define HW_USB_ENDPTCTRL6_CLR(x, v) (HW_USB_ENDPTCTRL6_WR(x, HW_USB_ENDPTCTRL6_RD(x) & ~(v)))
#define HW_USB_ENDPTCTRL6_TOG(x, v) (HW_USB_ENDPTCTRL6_WR(x, HW_USB_ENDPTCTRL6_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_ENDPTCTRL6 bitfields
 */

/*!
 * @name Register USB_ENDPTCTRL6, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay. However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or
 * until a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_ENDPTCTRL6_RXS (0U)         /*!< Bit position for USB_ENDPTCTRL6_RXS. */
#define BM_USB_ENDPTCTRL6_RXS (0x00000001U) /*!< Bit mask for USB_ENDPTCTRL6_RXS. */
#define BS_USB_ENDPTCTRL6_RXS (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL6_RXS. */

/*! @brief Read current value of the USB_ENDPTCTRL6_RXS field. */
#define BR_USB_ENDPTCTRL6_RXS(x) (HW_USB_ENDPTCTRL6(x).B.RXS)

/*! @brief Format value for bitfield USB_ENDPTCTRL6_RXS. */
#define BF_USB_ENDPTCTRL6_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL6_RXS) & BM_USB_ENDPTCTRL6_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_ENDPTCTRL6_RXS(x, v) (HW_USB_ENDPTCTRL6_WR(x, (HW_USB_ENDPTCTRL6_RD(x) & ~BM_USB_ENDPTCTRL6_RXS) | BF_USB_ENDPTCTRL6_RXS(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL6, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_ENDPTCTRL6_RXD (1U)         /*!< Bit position for USB_ENDPTCTRL6_RXD. */
#define BM_USB_ENDPTCTRL6_RXD (0x00000002U) /*!< Bit mask for USB_ENDPTCTRL6_RXD. */
#define BS_USB_ENDPTCTRL6_RXD (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL6_RXD. */

/*! @brief Read current value of the USB_ENDPTCTRL6_RXD field. */
#define BR_USB_ENDPTCTRL6_RXD(x) (HW_USB_ENDPTCTRL6(x).B.RXD)

/*! @brief Format value for bitfield USB_ENDPTCTRL6_RXD. */
#define BF_USB_ENDPTCTRL6_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL6_RXD) & BM_USB_ENDPTCTRL6_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_ENDPTCTRL6_RXD(x, v) (HW_USB_ENDPTCTRL6_WR(x, (HW_USB_ENDPTCTRL6_RD(x) & ~BM_USB_ENDPTCTRL6_RXD) | BF_USB_ENDPTCTRL6_RXD(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL6, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_ENDPTCTRL6_RXT (2U)         /*!< Bit position for USB_ENDPTCTRL6_RXT. */
#define BM_USB_ENDPTCTRL6_RXT (0x0000000CU) /*!< Bit mask for USB_ENDPTCTRL6_RXT. */
#define BS_USB_ENDPTCTRL6_RXT (2U)         /*!< Bit field size in bits for USB_ENDPTCTRL6_RXT. */

/*! @brief Read current value of the USB_ENDPTCTRL6_RXT field. */
#define BR_USB_ENDPTCTRL6_RXT(x) (HW_USB_ENDPTCTRL6(x).B.RXT)

/*! @brief Format value for bitfield USB_ENDPTCTRL6_RXT. */
#define BF_USB_ENDPTCTRL6_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL6_RXT) & BM_USB_ENDPTCTRL6_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_ENDPTCTRL6_RXT(x, v) (HW_USB_ENDPTCTRL6_WR(x, (HW_USB_ENDPTCTRL6_RD(x) & ~BM_USB_ENDPTCTRL6_RXT) | BF_USB_ENDPTCTRL6_RXT(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL6, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_ENDPTCTRL6_RXI (5U)         /*!< Bit position for USB_ENDPTCTRL6_RXI. */
#define BM_USB_ENDPTCTRL6_RXI (0x00000020U) /*!< Bit mask for USB_ENDPTCTRL6_RXI. */
#define BS_USB_ENDPTCTRL6_RXI (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL6_RXI. */

/*! @brief Read current value of the USB_ENDPTCTRL6_RXI field. */
#define BR_USB_ENDPTCTRL6_RXI(x) (HW_USB_ENDPTCTRL6(x).B.RXI)

/*! @brief Format value for bitfield USB_ENDPTCTRL6_RXI. */
#define BF_USB_ENDPTCTRL6_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL6_RXI) & BM_USB_ENDPTCTRL6_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_ENDPTCTRL6_RXI(x, v) (HW_USB_ENDPTCTRL6_WR(x, (HW_USB_ENDPTCTRL6_RD(x) & ~BM_USB_ENDPTCTRL6_RXI) | BF_USB_ENDPTCTRL6_RXI(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL6, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_ENDPTCTRL6_RXR (6U)         /*!< Bit position for USB_ENDPTCTRL6_RXR. */
#define BM_USB_ENDPTCTRL6_RXR (0x00000040U) /*!< Bit mask for USB_ENDPTCTRL6_RXR. */
#define BS_USB_ENDPTCTRL6_RXR (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL6_RXR. */

/*! @brief Read current value of the USB_ENDPTCTRL6_RXR field. */
#define BR_USB_ENDPTCTRL6_RXR(x) (HW_USB_ENDPTCTRL6(x).B.RXR)

/*! @brief Format value for bitfield USB_ENDPTCTRL6_RXR. */
#define BF_USB_ENDPTCTRL6_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL6_RXR) & BM_USB_ENDPTCTRL6_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_ENDPTCTRL6_RXR(x, v) (HW_USB_ENDPTCTRL6_WR(x, (HW_USB_ENDPTCTRL6_RD(x) & ~BM_USB_ENDPTCTRL6_RXR) | BF_USB_ENDPTCTRL6_RXR(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL6, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_ENDPTCTRL6_RXE (7U)         /*!< Bit position for USB_ENDPTCTRL6_RXE. */
#define BM_USB_ENDPTCTRL6_RXE (0x00000080U) /*!< Bit mask for USB_ENDPTCTRL6_RXE. */
#define BS_USB_ENDPTCTRL6_RXE (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL6_RXE. */

/*! @brief Read current value of the USB_ENDPTCTRL6_RXE field. */
#define BR_USB_ENDPTCTRL6_RXE(x) (HW_USB_ENDPTCTRL6(x).B.RXE)

/*! @brief Format value for bitfield USB_ENDPTCTRL6_RXE. */
#define BF_USB_ENDPTCTRL6_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL6_RXE) & BM_USB_ENDPTCTRL6_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_ENDPTCTRL6_RXE(x, v) (HW_USB_ENDPTCTRL6_WR(x, (HW_USB_ENDPTCTRL6_RD(x) & ~BM_USB_ENDPTCTRL6_RXE) | BF_USB_ENDPTCTRL6_RXE(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL6, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay. However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_ENDPTCTRL6_TXS (16U)        /*!< Bit position for USB_ENDPTCTRL6_TXS. */
#define BM_USB_ENDPTCTRL6_TXS (0x00010000U) /*!< Bit mask for USB_ENDPTCTRL6_TXS. */
#define BS_USB_ENDPTCTRL6_TXS (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL6_TXS. */

/*! @brief Read current value of the USB_ENDPTCTRL6_TXS field. */
#define BR_USB_ENDPTCTRL6_TXS(x) (HW_USB_ENDPTCTRL6(x).B.TXS)

/*! @brief Format value for bitfield USB_ENDPTCTRL6_TXS. */
#define BF_USB_ENDPTCTRL6_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL6_TXS) & BM_USB_ENDPTCTRL6_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_ENDPTCTRL6_TXS(x, v) (HW_USB_ENDPTCTRL6_WR(x, (HW_USB_ENDPTCTRL6_RD(x) & ~BM_USB_ENDPTCTRL6_TXS) | BF_USB_ENDPTCTRL6_TXS(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL6, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_ENDPTCTRL6_TXD (17U)        /*!< Bit position for USB_ENDPTCTRL6_TXD. */
#define BM_USB_ENDPTCTRL6_TXD (0x00020000U) /*!< Bit mask for USB_ENDPTCTRL6_TXD. */
#define BS_USB_ENDPTCTRL6_TXD (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL6_TXD. */

/*! @brief Read current value of the USB_ENDPTCTRL6_TXD field. */
#define BR_USB_ENDPTCTRL6_TXD(x) (HW_USB_ENDPTCTRL6(x).B.TXD)

/*! @brief Format value for bitfield USB_ENDPTCTRL6_TXD. */
#define BF_USB_ENDPTCTRL6_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL6_TXD) & BM_USB_ENDPTCTRL6_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_ENDPTCTRL6_TXD(x, v) (HW_USB_ENDPTCTRL6_WR(x, (HW_USB_ENDPTCTRL6_RD(x) & ~BM_USB_ENDPTCTRL6_TXD) | BF_USB_ENDPTCTRL6_TXD(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL6, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_ENDPTCTRL6_TXT (18U)        /*!< Bit position for USB_ENDPTCTRL6_TXT. */
#define BM_USB_ENDPTCTRL6_TXT (0x000C0000U) /*!< Bit mask for USB_ENDPTCTRL6_TXT. */
#define BS_USB_ENDPTCTRL6_TXT (2U)         /*!< Bit field size in bits for USB_ENDPTCTRL6_TXT. */

/*! @brief Read current value of the USB_ENDPTCTRL6_TXT field. */
#define BR_USB_ENDPTCTRL6_TXT(x) (HW_USB_ENDPTCTRL6(x).B.TXT)

/*! @brief Format value for bitfield USB_ENDPTCTRL6_TXT. */
#define BF_USB_ENDPTCTRL6_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL6_TXT) & BM_USB_ENDPTCTRL6_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_ENDPTCTRL6_TXT(x, v) (HW_USB_ENDPTCTRL6_WR(x, (HW_USB_ENDPTCTRL6_RD(x) & ~BM_USB_ENDPTCTRL6_TXT) | BF_USB_ENDPTCTRL6_TXT(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL6, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_ENDPTCTRL6_TXI (21U)        /*!< Bit position for USB_ENDPTCTRL6_TXI. */
#define BM_USB_ENDPTCTRL6_TXI (0x00200000U) /*!< Bit mask for USB_ENDPTCTRL6_TXI. */
#define BS_USB_ENDPTCTRL6_TXI (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL6_TXI. */

/*! @brief Read current value of the USB_ENDPTCTRL6_TXI field. */
#define BR_USB_ENDPTCTRL6_TXI(x) (HW_USB_ENDPTCTRL6(x).B.TXI)

/*! @brief Format value for bitfield USB_ENDPTCTRL6_TXI. */
#define BF_USB_ENDPTCTRL6_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL6_TXI) & BM_USB_ENDPTCTRL6_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_ENDPTCTRL6_TXI(x, v) (HW_USB_ENDPTCTRL6_WR(x, (HW_USB_ENDPTCTRL6_RD(x) & ~BM_USB_ENDPTCTRL6_TXI) | BF_USB_ENDPTCTRL6_TXI(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL6, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_ENDPTCTRL6_TXR (22U)        /*!< Bit position for USB_ENDPTCTRL6_TXR. */
#define BM_USB_ENDPTCTRL6_TXR (0x00400000U) /*!< Bit mask for USB_ENDPTCTRL6_TXR. */
#define BS_USB_ENDPTCTRL6_TXR (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL6_TXR. */

/*! @brief Read current value of the USB_ENDPTCTRL6_TXR field. */
#define BR_USB_ENDPTCTRL6_TXR(x) (HW_USB_ENDPTCTRL6(x).B.TXR)

/*! @brief Format value for bitfield USB_ENDPTCTRL6_TXR. */
#define BF_USB_ENDPTCTRL6_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL6_TXR) & BM_USB_ENDPTCTRL6_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_ENDPTCTRL6_TXR(x, v) (HW_USB_ENDPTCTRL6_WR(x, (HW_USB_ENDPTCTRL6_RD(x) & ~BM_USB_ENDPTCTRL6_TXR) | BF_USB_ENDPTCTRL6_TXR(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL6, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_ENDPTCTRL6_TXE (23U)        /*!< Bit position for USB_ENDPTCTRL6_TXE. */
#define BM_USB_ENDPTCTRL6_TXE (0x00800000U) /*!< Bit mask for USB_ENDPTCTRL6_TXE. */
#define BS_USB_ENDPTCTRL6_TXE (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL6_TXE. */

/*! @brief Read current value of the USB_ENDPTCTRL6_TXE field. */
#define BR_USB_ENDPTCTRL6_TXE(x) (HW_USB_ENDPTCTRL6(x).B.TXE)

/*! @brief Format value for bitfield USB_ENDPTCTRL6_TXE. */
#define BF_USB_ENDPTCTRL6_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL6_TXE) & BM_USB_ENDPTCTRL6_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_ENDPTCTRL6_TXE(x, v) (HW_USB_ENDPTCTRL6_WR(x, (HW_USB_ENDPTCTRL6_RD(x) & ~BM_USB_ENDPTCTRL6_TXE) | BF_USB_ENDPTCTRL6_TXE(v)))
/*@}*/

/*******************************************************************************
 * HW_USB_ENDPTCTRL7 - Endpoint Control 7
 ******************************************************************************/

/*!
 * @brief HW_USB_ENDPTCTRL7 - Endpoint Control 7 (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is endpoint control register for endpoint 7 in device operation mode. If
 * one endpoint direction is enabled and the paired endpoint of opposite
 * direction is disabled then the unused direction type must be changed from the default
 * control-type to any other type (that is Bulk-type). leaving an unconfigured
 * endpoint control causes undefined behavior for the data pid tracking on the
 * active endpoint/direction.
 */
typedef union _hw_usb_endptctrl7
{
    uint32_t U;
    struct _hw_usb_endptctrl7_bitfields
    {
        uint32_t RXS : 1;              /*!< [0]  */
        uint32_t RXD : 1;              /*!< [1]  */
        uint32_t RXT : 2;              /*!< [3:2]  */
        uint32_t RESERVED0 : 1;        /*!< [4]  */
        uint32_t RXI : 1;              /*!< [5]  */
        uint32_t RXR : 1;              /*!< [6]  */
        uint32_t RXE : 1;              /*!< [7]  */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t TXS : 1;              /*!< [16]  */
        uint32_t TXD : 1;              /*!< [17]  */
        uint32_t TXT : 2;              /*!< [19:18]  */
        uint32_t RESERVED2 : 1;        /*!< [20]  */
        uint32_t TXI : 1;              /*!< [21]  */
        uint32_t TXR : 1;              /*!< [22]  */
        uint32_t TXE : 1;              /*!< [23]  */
        uint32_t RESERVED3 : 8;        /*!< [31:24]  */
    } B;
} hw_usb_endptctrl7_t;

/*!
 * @name Constants and macros for entire USB_ENDPTCTRL7 register
 */
/*@{*/
#define HW_USB_ENDPTCTRL7_ADDR(x) ((uintptr_t)(x) + 0x1DCU)

#define HW_USB_ENDPTCTRL7(x)     (*(__IO hw_usb_endptctrl7_t *) HW_USB_ENDPTCTRL7_ADDR(x))
#define HW_USB_ENDPTCTRL7_RD(x)  (HW_USB_ENDPTCTRL7(x).U)
#define HW_USB_ENDPTCTRL7_WR(x, v) (HW_USB_ENDPTCTRL7(x).U = (v))
#define HW_USB_ENDPTCTRL7_SET(x, v) (HW_USB_ENDPTCTRL7_WR(x, HW_USB_ENDPTCTRL7_RD(x) |  (v)))
#define HW_USB_ENDPTCTRL7_CLR(x, v) (HW_USB_ENDPTCTRL7_WR(x, HW_USB_ENDPTCTRL7_RD(x) & ~(v)))
#define HW_USB_ENDPTCTRL7_TOG(x, v) (HW_USB_ENDPTCTRL7_WR(x, HW_USB_ENDPTCTRL7_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USB_ENDPTCTRL7 bitfields
 */

/*!
 * @name Register USB_ENDPTCTRL7, field RXS[0] (RW)
 *
 * RX Endpoint Stall - Read/Write 0 End Point OK. [Default] 1 End Point Stalled
 * This bit is set automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpointand this bit will continue to be cleared
 * by hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay. However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or
 * until a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_ENDPTCTRL7_RXS (0U)         /*!< Bit position for USB_ENDPTCTRL7_RXS. */
#define BM_USB_ENDPTCTRL7_RXS (0x00000001U) /*!< Bit mask for USB_ENDPTCTRL7_RXS. */
#define BS_USB_ENDPTCTRL7_RXS (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL7_RXS. */

/*! @brief Read current value of the USB_ENDPTCTRL7_RXS field. */
#define BR_USB_ENDPTCTRL7_RXS(x) (HW_USB_ENDPTCTRL7(x).B.RXS)

/*! @brief Format value for bitfield USB_ENDPTCTRL7_RXS. */
#define BF_USB_ENDPTCTRL7_RXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL7_RXS) & BM_USB_ENDPTCTRL7_RXS)

/*! @brief Set the RXS field to a new value. */
#define BW_USB_ENDPTCTRL7_RXS(x, v) (HW_USB_ENDPTCTRL7_WR(x, (HW_USB_ENDPTCTRL7_RD(x) & ~BM_USB_ENDPTCTRL7_RXS) | BF_USB_ENDPTCTRL7_RXS(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL7, field RXD[1] (RW)
 *
 * RX Endpoint Data Sink - Read/Write - TBD 0 Dual Port Memory Buffer/DMA Engine
 * [Default] Should always be written as zero.
 */
/*@{*/
#define BP_USB_ENDPTCTRL7_RXD (1U)         /*!< Bit position for USB_ENDPTCTRL7_RXD. */
#define BM_USB_ENDPTCTRL7_RXD (0x00000002U) /*!< Bit mask for USB_ENDPTCTRL7_RXD. */
#define BS_USB_ENDPTCTRL7_RXD (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL7_RXD. */

/*! @brief Read current value of the USB_ENDPTCTRL7_RXD field. */
#define BR_USB_ENDPTCTRL7_RXD(x) (HW_USB_ENDPTCTRL7(x).B.RXD)

/*! @brief Format value for bitfield USB_ENDPTCTRL7_RXD. */
#define BF_USB_ENDPTCTRL7_RXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL7_RXD) & BM_USB_ENDPTCTRL7_RXD)

/*! @brief Set the RXD field to a new value. */
#define BW_USB_ENDPTCTRL7_RXD(x, v) (HW_USB_ENDPTCTRL7_WR(x, (HW_USB_ENDPTCTRL7_RD(x) & ~BM_USB_ENDPTCTRL7_RXD) | BF_USB_ENDPTCTRL7_RXD(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL7, field RXT[3:2] (RW)
 *
 * RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Reserved
 */
/*@{*/
#define BP_USB_ENDPTCTRL7_RXT (2U)         /*!< Bit position for USB_ENDPTCTRL7_RXT. */
#define BM_USB_ENDPTCTRL7_RXT (0x0000000CU) /*!< Bit mask for USB_ENDPTCTRL7_RXT. */
#define BS_USB_ENDPTCTRL7_RXT (2U)         /*!< Bit field size in bits for USB_ENDPTCTRL7_RXT. */

/*! @brief Read current value of the USB_ENDPTCTRL7_RXT field. */
#define BR_USB_ENDPTCTRL7_RXT(x) (HW_USB_ENDPTCTRL7(x).B.RXT)

/*! @brief Format value for bitfield USB_ENDPTCTRL7_RXT. */
#define BF_USB_ENDPTCTRL7_RXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL7_RXT) & BM_USB_ENDPTCTRL7_RXT)

/*! @brief Set the RXT field to a new value. */
#define BW_USB_ENDPTCTRL7_RXT(x, v) (HW_USB_ENDPTCTRL7_WR(x, (HW_USB_ENDPTCTRL7_RD(x) & ~BM_USB_ENDPTCTRL7_RXT) | BF_USB_ENDPTCTRL7_RXT(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL7, field RXI[5] (RW)
 *
 * RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used
 * for test and should always be written as zero. Writing a one to this bit causes
 * this endpoint to ignore the data toggle sequence and always accept data
 * packet regardless of their data PID.
 */
/*@{*/
#define BP_USB_ENDPTCTRL7_RXI (5U)         /*!< Bit position for USB_ENDPTCTRL7_RXI. */
#define BM_USB_ENDPTCTRL7_RXI (0x00000020U) /*!< Bit mask for USB_ENDPTCTRL7_RXI. */
#define BS_USB_ENDPTCTRL7_RXI (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL7_RXI. */

/*! @brief Read current value of the USB_ENDPTCTRL7_RXI field. */
#define BR_USB_ENDPTCTRL7_RXI(x) (HW_USB_ENDPTCTRL7(x).B.RXI)

/*! @brief Format value for bitfield USB_ENDPTCTRL7_RXI. */
#define BF_USB_ENDPTCTRL7_RXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL7_RXI) & BM_USB_ENDPTCTRL7_RXI)

/*! @brief Set the RXI field to a new value. */
#define BW_USB_ENDPTCTRL7_RXI(x, v) (HW_USB_ENDPTCTRL7_WR(x, (HW_USB_ENDPTCTRL7_RD(x) & ~BM_USB_ENDPTCTRL7_RXI) | BF_USB_ENDPTCTRL7_RXI(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL7, field RXR[6] (RW)
 *
 * RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the host and device.
 */
/*@{*/
#define BP_USB_ENDPTCTRL7_RXR (6U)         /*!< Bit position for USB_ENDPTCTRL7_RXR. */
#define BM_USB_ENDPTCTRL7_RXR (0x00000040U) /*!< Bit mask for USB_ENDPTCTRL7_RXR. */
#define BS_USB_ENDPTCTRL7_RXR (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL7_RXR. */

/*! @brief Read current value of the USB_ENDPTCTRL7_RXR field. */
#define BR_USB_ENDPTCTRL7_RXR(x) (HW_USB_ENDPTCTRL7(x).B.RXR)

/*! @brief Format value for bitfield USB_ENDPTCTRL7_RXR. */
#define BF_USB_ENDPTCTRL7_RXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL7_RXR) & BM_USB_ENDPTCTRL7_RXR)

/*! @brief Set the RXR field to a new value. */
#define BW_USB_ENDPTCTRL7_RXR(x, v) (HW_USB_ENDPTCTRL7_WR(x, (HW_USB_ENDPTCTRL7_RD(x) & ~BM_USB_ENDPTCTRL7_RXR) | BF_USB_ENDPTCTRL7_RXR(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL7, field RXE[7] (RW)
 *
 * RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_ENDPTCTRL7_RXE (7U)         /*!< Bit position for USB_ENDPTCTRL7_RXE. */
#define BM_USB_ENDPTCTRL7_RXE (0x00000080U) /*!< Bit mask for USB_ENDPTCTRL7_RXE. */
#define BS_USB_ENDPTCTRL7_RXE (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL7_RXE. */

/*! @brief Read current value of the USB_ENDPTCTRL7_RXE field. */
#define BR_USB_ENDPTCTRL7_RXE(x) (HW_USB_ENDPTCTRL7(x).B.RXE)

/*! @brief Format value for bitfield USB_ENDPTCTRL7_RXE. */
#define BF_USB_ENDPTCTRL7_RXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL7_RXE) & BM_USB_ENDPTCTRL7_RXE)

/*! @brief Set the RXE field to a new value. */
#define BW_USB_ENDPTCTRL7_RXE(x, v) (HW_USB_ENDPTCTRL7_WR(x, (HW_USB_ENDPTCTRL7_RD(x) & ~BM_USB_ENDPTCTRL7_RXE) | BF_USB_ENDPTCTRL7_RXE(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL7, field TXS[16] (RW)
 *
 * TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit
 * will be cleared automatically upon receipt of a SETUP request if this Endpoint
 * is configured as a Control Endpoint and this bit will continue to be cleared by
 * hardware until the associated ENDPTSETUPSTAT bit is cleared. Software can
 * write a one to this bit to force the endpoint to return a STALL handshake to the
 * Host. This control will continue to STALL until this bit is either cleared by
 * software or automatically cleared as above for control endpoints. [CONTROL
 * ENDPOINT TYPES ONLY]: there is a slight delay (50 clocks max) between the
 * ENDPTSETUPSTAT begin cleared and hardware continuing to clear this bit. In most
 * systems, it is unlikely the DCD software will observe this delay. However, should
 * the DCD observe that the stall bit is not set after writing a one to it then
 * follow this procedure: continually write this stall bit until it is set or until
 * a new setup has been received by checking the associated endptsetupstat bit.
 */
/*@{*/
#define BP_USB_ENDPTCTRL7_TXS (16U)        /*!< Bit position for USB_ENDPTCTRL7_TXS. */
#define BM_USB_ENDPTCTRL7_TXS (0x00010000U) /*!< Bit mask for USB_ENDPTCTRL7_TXS. */
#define BS_USB_ENDPTCTRL7_TXS (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL7_TXS. */

/*! @brief Read current value of the USB_ENDPTCTRL7_TXS field. */
#define BR_USB_ENDPTCTRL7_TXS(x) (HW_USB_ENDPTCTRL7(x).B.TXS)

/*! @brief Format value for bitfield USB_ENDPTCTRL7_TXS. */
#define BF_USB_ENDPTCTRL7_TXS(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL7_TXS) & BM_USB_ENDPTCTRL7_TXS)

/*! @brief Set the TXS field to a new value. */
#define BW_USB_ENDPTCTRL7_TXS(x, v) (HW_USB_ENDPTCTRL7_WR(x, (HW_USB_ENDPTCTRL7_RD(x) & ~BM_USB_ENDPTCTRL7_TXS) | BF_USB_ENDPTCTRL7_TXS(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL7, field TXD[17] (RW)
 *
 * TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine
 * [DEFAULT] Should always be written as 0.
 */
/*@{*/
#define BP_USB_ENDPTCTRL7_TXD (17U)        /*!< Bit position for USB_ENDPTCTRL7_TXD. */
#define BM_USB_ENDPTCTRL7_TXD (0x00020000U) /*!< Bit mask for USB_ENDPTCTRL7_TXD. */
#define BS_USB_ENDPTCTRL7_TXD (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL7_TXD. */

/*! @brief Read current value of the USB_ENDPTCTRL7_TXD field. */
#define BR_USB_ENDPTCTRL7_TXD(x) (HW_USB_ENDPTCTRL7(x).B.TXD)

/*! @brief Format value for bitfield USB_ENDPTCTRL7_TXD. */
#define BF_USB_ENDPTCTRL7_TXD(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL7_TXD) & BM_USB_ENDPTCTRL7_TXD)

/*! @brief Set the TXD field to a new value. */
#define BW_USB_ENDPTCTRL7_TXD(x, v) (HW_USB_ENDPTCTRL7_WR(x, (HW_USB_ENDPTCTRL7_RD(x) & ~BM_USB_ENDPTCTRL7_TXD) | BF_USB_ENDPTCTRL7_TXD(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL7, field TXT[19:18] (RW)
 *
 * TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt
 */
/*@{*/
#define BP_USB_ENDPTCTRL7_TXT (18U)        /*!< Bit position for USB_ENDPTCTRL7_TXT. */
#define BM_USB_ENDPTCTRL7_TXT (0x000C0000U) /*!< Bit mask for USB_ENDPTCTRL7_TXT. */
#define BS_USB_ENDPTCTRL7_TXT (2U)         /*!< Bit field size in bits for USB_ENDPTCTRL7_TXT. */

/*! @brief Read current value of the USB_ENDPTCTRL7_TXT field. */
#define BR_USB_ENDPTCTRL7_TXT(x) (HW_USB_ENDPTCTRL7(x).B.TXT)

/*! @brief Format value for bitfield USB_ENDPTCTRL7_TXT. */
#define BF_USB_ENDPTCTRL7_TXT(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL7_TXT) & BM_USB_ENDPTCTRL7_TXT)

/*! @brief Set the TXT field to a new value. */
#define BW_USB_ENDPTCTRL7_TXT(x, v) (HW_USB_ENDPTCTRL7_WR(x, (HW_USB_ENDPTCTRL7_RD(x) & ~BM_USB_ENDPTCTRL7_TXT) | BF_USB_ENDPTCTRL7_TXT(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL7, field TXI[21] (RW)
 *
 * TX Data Toggle Inhibit 0 PID Sequencing Enabled. [Default] 1 PID Sequencing
 * Disabled. This bit is only used for test and should always be written as zero.
 * Writing a one to this bit causes this endpoint to ignore the data toggle
 * sequence and always transmit DATA0 for a data packet.
 */
/*@{*/
#define BP_USB_ENDPTCTRL7_TXI (21U)        /*!< Bit position for USB_ENDPTCTRL7_TXI. */
#define BM_USB_ENDPTCTRL7_TXI (0x00200000U) /*!< Bit mask for USB_ENDPTCTRL7_TXI. */
#define BS_USB_ENDPTCTRL7_TXI (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL7_TXI. */

/*! @brief Read current value of the USB_ENDPTCTRL7_TXI field. */
#define BR_USB_ENDPTCTRL7_TXI(x) (HW_USB_ENDPTCTRL7(x).B.TXI)

/*! @brief Format value for bitfield USB_ENDPTCTRL7_TXI. */
#define BF_USB_ENDPTCTRL7_TXI(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL7_TXI) & BM_USB_ENDPTCTRL7_TXI)

/*! @brief Set the TXI field to a new value. */
#define BW_USB_ENDPTCTRL7_TXI(x, v) (HW_USB_ENDPTCTRL7_WR(x, (HW_USB_ENDPTCTRL7_RD(x) & ~BM_USB_ENDPTCTRL7_TXI) | BF_USB_ENDPTCTRL7_TXI(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL7, field TXR[22] (RW)
 *
 * TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a
 * configuration event is received for this Endpoint, software must write a one to this bit
 * in order to synchronize the data PID's between the Host and device.
 */
/*@{*/
#define BP_USB_ENDPTCTRL7_TXR (22U)        /*!< Bit position for USB_ENDPTCTRL7_TXR. */
#define BM_USB_ENDPTCTRL7_TXR (0x00400000U) /*!< Bit mask for USB_ENDPTCTRL7_TXR. */
#define BS_USB_ENDPTCTRL7_TXR (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL7_TXR. */

/*! @brief Read current value of the USB_ENDPTCTRL7_TXR field. */
#define BR_USB_ENDPTCTRL7_TXR(x) (HW_USB_ENDPTCTRL7(x).B.TXR)

/*! @brief Format value for bitfield USB_ENDPTCTRL7_TXR. */
#define BF_USB_ENDPTCTRL7_TXR(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL7_TXR) & BM_USB_ENDPTCTRL7_TXR)

/*! @brief Set the TXR field to a new value. */
#define BW_USB_ENDPTCTRL7_TXR(x, v) (HW_USB_ENDPTCTRL7_WR(x, (HW_USB_ENDPTCTRL7_RD(x) & ~BM_USB_ENDPTCTRL7_TXR) | BF_USB_ENDPTCTRL7_TXR(v)))
/*@}*/

/*!
 * @name Register USB_ENDPTCTRL7, field TXE[23] (RW)
 *
 * TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be
 * enabled only after it has been configured.
 */
/*@{*/
#define BP_USB_ENDPTCTRL7_TXE (23U)        /*!< Bit position for USB_ENDPTCTRL7_TXE. */
#define BM_USB_ENDPTCTRL7_TXE (0x00800000U) /*!< Bit mask for USB_ENDPTCTRL7_TXE. */
#define BS_USB_ENDPTCTRL7_TXE (1U)         /*!< Bit field size in bits for USB_ENDPTCTRL7_TXE. */

/*! @brief Read current value of the USB_ENDPTCTRL7_TXE field. */
#define BR_USB_ENDPTCTRL7_TXE(x) (HW_USB_ENDPTCTRL7(x).B.TXE)

/*! @brief Format value for bitfield USB_ENDPTCTRL7_TXE. */
#define BF_USB_ENDPTCTRL7_TXE(v) ((uint32_t)((uint32_t)(v) << BP_USB_ENDPTCTRL7_TXE) & BM_USB_ENDPTCTRL7_TXE)

/*! @brief Set the TXE field to a new value. */
#define BW_USB_ENDPTCTRL7_TXE(x, v) (HW_USB_ENDPTCTRL7_WR(x, (HW_USB_ENDPTCTRL7_RD(x) & ~BM_USB_ENDPTCTRL7_TXE) | BF_USB_ENDPTCTRL7_TXE(v)))
/*@}*/

/*
** Start of section using anonymous unions
*/

#if defined(__ARMCC_VERSION)
  #pragma push
  #pragma anon_unions
#elif defined(__GNUC__)
  /* anonymous unions are enabled by default */
#elif defined(__IAR_SYSTEMS_ICC__)
  #pragma language=extended
#else
  #error Not supported compiler type
#endif

/*******************************************************************************
 * hw_usb_t - module struct
 ******************************************************************************/
/*!
 * @brief All USB module registers.
 */
#pragma pack(1)
typedef struct _hw_usb
{
    __I hw_usb_id_t ID;                    /*!< [0x0] Identification register */
    __I hw_usb_hwgeneral_t HWGENERAL;      /*!< [0x4] Hardware General */
    __I hw_usb_hwhost_t HWHOST;            /*!< [0x8] Host Hardware Parameters */
    __I hw_usb_hwdevice_t HWDEVICE;        /*!< [0xC] Device Hardware Parameters */
    __I hw_usb_hwtxbuf_t HWTXBUF;          /*!< [0x10] TX Buffer Hardware Parameters */
    __I hw_usb_hwrxbuf_t HWRXBUF;          /*!< [0x14] RX Buffer Hardware Parameters */
    uint8_t _reserved0[104];
    __IO hw_usb_gptimer0ld_t GPTIMER0LD;   /*!< [0x80] General Purpose Timer #0 Load */
    __IO hw_usb_gptimer0ctrl_t GPTIMER0CTRL; /*!< [0x84] General Purpose Timer #0 Controller */
    __IO hw_usb_gptimer1ld_t GPTIMER1LD;   /*!< [0x88] General Purpose Timer #1 Load */
    __IO hw_usb_gptimer1ctrl_t GPTIMER1CTRL; /*!< [0x8C] General Purpose Timer #1 Controller */
    __IO hw_usb_sbuscfg_t SBUSCFG;         /*!< [0x90] System Bus Config */
    uint8_t _reserved1[108];
    __I hw_usb_caplength_t CAPLENGTH;      /*!< [0x100] Capability Registers Length */
    uint8_t _reserved2[1];
    __I hw_usb_hciversion_t HCIVERSION;    /*!< [0x102] Host Controller Interface Version */
    __I hw_usb_hcsparams_t HCSPARAMS;      /*!< [0x104] Host Controller Structural Parameters */
    __I hw_usb_hccparams_t HCCPARAMS;      /*!< [0x108] Host Controller Capability Parameters */
    uint8_t _reserved3[20];
    __I hw_usb_dciversion_t DCIVERSION;    /*!< [0x120] Device Controller Interface Version */
    uint8_t _reserved4[2];
    __I hw_usb_dccparams_t DCCPARAMS;      /*!< [0x124] Device Controller Capability Parameters */
    uint8_t _reserved5[24];
    __IO hw_usb_usbcmd_t USBCMD;           /*!< [0x140] USB Command Register */
    __IO hw_usb_usbsts_t USBSTS;           /*!< [0x144] USB Status Register */
    __IO hw_usb_usbintr_t USBINTR;         /*!< [0x148] Interrupt Enable Register */
    __IO hw_usb_frindex_t FRINDEX;         /*!< [0x14C] USB Frame Index */
    uint8_t _reserved6[4];
    union {
        __IO hw_usb_deviceaddr_t DEVICEADDR; /*!< [0x154] Device Address */
        __IO hw_usb_periodiclistbase_t PERIODICLISTBASE; /*!< [0x154] Frame List Base Address */
    };
    union {
        __IO hw_usb_asynclistaddr_t ASYNCLISTADDR; /*!< [0x158] Next Asynch. Address */
        __IO hw_usb_endptlistaddr_t ENDPTLISTADDR; /*!< [0x158] Endpoint List Address */
    };
    uint8_t _reserved7[4];
    __IO hw_usb_burstsize_t BURSTSIZE;     /*!< [0x160] Programmable Burst Size */
    __IO hw_usb_txfilltuning_t TXFILLTUNING; /*!< [0x164] TX FIFO Fill Tuning */
    uint8_t _reserved8[16];
    __IO hw_usb_endptnak_t ENDPTNAK;       /*!< [0x178] Endpoint NAK */
    __IO hw_usb_endptnaken_t ENDPTNAKEN;   /*!< [0x17C] Endpoint NAK Enable */
    __I hw_usb_configflag_t CONFIGFLAG;    /*!< [0x180] Configure Flag Register */
    __IO hw_usb_portsc1_t PORTSC1;         /*!< [0x184] Port Status & Control */
    uint8_t _reserved9[28];
    __IO hw_usb_otgsc_t OTGSC;             /*!< [0x1A4] On-The-Go Status & control */
    __IO hw_usb_usbmode_t USBMODE;         /*!< [0x1A8] USB Device Mode */
    __IO hw_usb_endptsetupstat_t ENDPTSETUPSTAT; /*!< [0x1AC] Endpoint Setup Status */
    __IO hw_usb_endptprime_t ENDPTPRIME;   /*!< [0x1B0] Endpoint Prime */
    __IO hw_usb_endptflush_t ENDPTFLUSH;   /*!< [0x1B4] Endpoint Flush */
    __I hw_usb_endptstat_t ENDPTSTAT;      /*!< [0x1B8] Endpoint Status */
    __IO hw_usb_endptcomplete_t ENDPTCOMPLETE; /*!< [0x1BC] Endpoint Complete */
    __IO hw_usb_endptctrl0_t ENDPTCTRL0;   /*!< [0x1C0] Endpoint Control0 */
    __IO hw_usb_endptctrl1_t ENDPTCTRL1;   /*!< [0x1C4] Endpoint Control 1 */
    __IO hw_usb_endptctrl2_t ENDPTCTRL2;   /*!< [0x1C8] Endpoint Control 2 */
    __IO hw_usb_endptctrl3_t ENDPTCTRL3;   /*!< [0x1CC] Endpoint Control 3 */
    __IO hw_usb_endptctrl4_t ENDPTCTRL4;   /*!< [0x1D0] Endpoint Control 4 */
    __IO hw_usb_endptctrl5_t ENDPTCTRL5;   /*!< [0x1D4] Endpoint Control 5 */
    __IO hw_usb_endptctrl6_t ENDPTCTRL6;   /*!< [0x1D8] Endpoint Control 6 */
    __IO hw_usb_endptctrl7_t ENDPTCTRL7;   /*!< [0x1DC] Endpoint Control 7 */
} hw_usb_t;
#pragma pack()

/*! @brief Macro to access all USB registers. */
/*! @param x USB module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_USB_REGS(USB_OTG1_BASE)</code>. */
#define HW_USB_REGS(x) (*(hw_usb_t *)(x))

/*
** End of section using anonymous unions
*/

#if defined(__ARMCC_VERSION)
  #pragma pop
#elif defined(__GNUC__)
  /* leave anonymous unions enabled */
#elif defined(__IAR_SYSTEMS_ICC__)
  #pragma language=default
#else
  #error Not supported compiler type
#endif

/*
 * iMX7D USBNC
 *
 * USB
 *
 * Registers defined in this header file:
 * - HW_USBNC_OTG1_CTRL1 -
 * - HW_USBNC_OTG1_CTRL2 -
 * - HW_USBNC_OTG1_PHY_CFG1 - USB OTG PHY Configuration Register 1
 * - HW_USBNC_OTG1_PHY_CFG2 - USB OTG PHY Configuration Register 2
 * - HW_USBNC_OTG1_PHY_STATUS - USB OTG PHY Status Register
 * - HW_USBNC_ADP_CFG1 -
 * - HW_USBNC_ADP_CFG2 -
 * - HW_USBNC_ADP_STATUS -
 * - HW_USBNC_OTG2_CTRL1 -
 * - HW_USBNC_OTG2_CTRL2 -
 * - HW_USBNC_OTG2_PHY_CFG1 - USB OTG PHY Configuration Register 1
 * - HW_USBNC_OTG2_PHY_CFG2 - USB OTG PHY Configuration Register 2
 * - HW_USBNC_OTG2_PHY_STATUS - USB OTG PHY Status Register
 * - HW_USBNC_HSIC_CTRL1 -
 * - HW_USBNC_HSIC_CTRL2 -
 * - HW_USBNC_UH_HSICPHY_CFG1 - USB Host HSIC PHY Configuration Register
 *
 * - hw_usbnc_t - Struct containing all module registers.
 */

#define HW_USBNC_INSTANCE_COUNT (1U) /*!< Number of instances of the USBNC module. */
#define HW_USBNC (0U) /*!< Instance number for USBNC. */
#define USBNC_BASE            (0x30B10200U) /*!< Base address for USBNC. */
/*! Array initializer of USBNC base addresses. */
#define USBNC_BASE_ADDRS      { USBNC_BASE }

/*******************************************************************************
 * HW_USBNC_OTG1_CTRL1 -
 ******************************************************************************/

/*!
 * @brief HW_USBNC_OTG1_CTRL1 -  (RW)
 *
 * Reset value: 0x30001000U
 *
 * The USB_n_PHY_CTRL1 register controls the integration specific features of
 * the USB PHY modules. These features are not directly related to basic USB
 * functionality, but control special features, interfacing on the USB ports, as well
 * as power control and wake-up functionality.
 */
typedef union _hw_usbnc_otg1_ctrl1
{
    uint32_t U;
    struct _hw_usbnc_otg1_ctrl1_bitfields
    {
        uint32_t RESERVED0 : 7;        /*!< [6:0]  */
        uint32_t OVER_CUR_DIS : 1;     /*!< [7]  */
        uint32_t OVER_CUR_POL : 1;     /*!< [8]  */
        uint32_t PWR_POL : 1;          /*!< [9]  */
        uint32_t WIE : 1;              /*!< [10]  */
        uint32_t RESERVED1 : 3;        /*!< [13:11]  */
        uint32_t WKUP_SW_EN : 1;       /*!< [14]  */
        uint32_t WKUP_SW : 1;          /*!< [15]  */
        uint32_t WKUP_ID_EN : 1;       /*!< [16]  */
        uint32_t WKUP_VBUS_EN : 1;     /*!< [17]  */
        uint32_t RESERVED2 : 11;       /*!< [28:18]  */
        uint32_t WKUP_DPDM_EN : 1;     /*!< [29]  */
        uint32_t RESERVED3 : 1;        /*!< [30]  */
        uint32_t WIR : 1;              /*!< [31]  */
    } B;
} hw_usbnc_otg1_ctrl1_t;

/*!
 * @name Constants and macros for entire USBNC_OTG1_CTRL1 register
 */
/*@{*/
#define HW_USBNC_OTG1_CTRL1_ADDR(x) ((uintptr_t)(x) + 0x200U)

#define HW_USBNC_OTG1_CTRL1(x)   (*(__IO hw_usbnc_otg1_ctrl1_t *) HW_USBNC_OTG1_CTRL1_ADDR(x))
#define HW_USBNC_OTG1_CTRL1_RD(x) (HW_USBNC_OTG1_CTRL1(x).U)
#define HW_USBNC_OTG1_CTRL1_WR(x, v) (HW_USBNC_OTG1_CTRL1(x).U = (v))
#define HW_USBNC_OTG1_CTRL1_SET(x, v) (HW_USBNC_OTG1_CTRL1_WR(x, HW_USBNC_OTG1_CTRL1_RD(x) |  (v)))
#define HW_USBNC_OTG1_CTRL1_CLR(x, v) (HW_USBNC_OTG1_CTRL1_WR(x, HW_USBNC_OTG1_CTRL1_RD(x) & ~(v)))
#define HW_USBNC_OTG1_CTRL1_TOG(x, v) (HW_USBNC_OTG1_CTRL1_WR(x, HW_USBNC_OTG1_CTRL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBNC_OTG1_CTRL1 bitfields
 */

/*!
 * @name Register USBNC_OTG1_CTRL1, field OVER_CUR_DIS[7] (RW)
 *
 * Disable Overcurrent Detection
 *
 * Values:
 * - 1 - Disables overcurrent detection
 * - 0 - Enables overcurrent detection
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL1_OVER_CUR_DIS (7U) /*!< Bit position for USBNC_OTG1_CTRL1_OVER_CUR_DIS. */
#define BM_USBNC_OTG1_CTRL1_OVER_CUR_DIS (0x00000080U) /*!< Bit mask for USBNC_OTG1_CTRL1_OVER_CUR_DIS. */
#define BS_USBNC_OTG1_CTRL1_OVER_CUR_DIS (1U) /*!< Bit field size in bits for USBNC_OTG1_CTRL1_OVER_CUR_DIS. */

/*! @brief Read current value of the USBNC_OTG1_CTRL1_OVER_CUR_DIS field. */
#define BR_USBNC_OTG1_CTRL1_OVER_CUR_DIS(x) (HW_USBNC_OTG1_CTRL1(x).B.OVER_CUR_DIS)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL1_OVER_CUR_DIS. */
#define BF_USBNC_OTG1_CTRL1_OVER_CUR_DIS(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL1_OVER_CUR_DIS) & BM_USBNC_OTG1_CTRL1_OVER_CUR_DIS)

/*! @brief Set the OVER_CUR_DIS field to a new value. */
#define BW_USBNC_OTG1_CTRL1_OVER_CUR_DIS(x, v) (HW_USBNC_OTG1_CTRL1_WR(x, (HW_USBNC_OTG1_CTRL1_RD(x) & ~BM_USBNC_OTG1_CTRL1_OVER_CUR_DIS) | BF_USBNC_OTG1_CTRL1_OVER_CUR_DIS(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL1, field OVER_CUR_POL[8] (RW)
 *
 * Polarity of Overcurrent The polarity of OTG1/OTG2 port overcurrent event
 *
 * Values:
 * - 1 - Low active (low on this signal represents an overcurrent condition)
 * - 0 - High active (high on this signal represents an overcurrent condition)
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL1_OVER_CUR_POL (8U) /*!< Bit position for USBNC_OTG1_CTRL1_OVER_CUR_POL. */
#define BM_USBNC_OTG1_CTRL1_OVER_CUR_POL (0x00000100U) /*!< Bit mask for USBNC_OTG1_CTRL1_OVER_CUR_POL. */
#define BS_USBNC_OTG1_CTRL1_OVER_CUR_POL (1U) /*!< Bit field size in bits for USBNC_OTG1_CTRL1_OVER_CUR_POL. */

/*! @brief Read current value of the USBNC_OTG1_CTRL1_OVER_CUR_POL field. */
#define BR_USBNC_OTG1_CTRL1_OVER_CUR_POL(x) (HW_USBNC_OTG1_CTRL1(x).B.OVER_CUR_POL)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL1_OVER_CUR_POL. */
#define BF_USBNC_OTG1_CTRL1_OVER_CUR_POL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL1_OVER_CUR_POL) & BM_USBNC_OTG1_CTRL1_OVER_CUR_POL)

/*! @brief Set the OVER_CUR_POL field to a new value. */
#define BW_USBNC_OTG1_CTRL1_OVER_CUR_POL(x, v) (HW_USBNC_OTG1_CTRL1_WR(x, (HW_USBNC_OTG1_CTRL1_RD(x) & ~BM_USBNC_OTG1_CTRL1_OVER_CUR_POL) | BF_USBNC_OTG1_CTRL1_OVER_CUR_POL(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL1, field PWR_POL[9] (RW)
 *
 * Power Polarity This bit should be set according to PMIC Power Pin polarity.
 *
 * Values:
 * - 1 - PMIC Power Pin is High active.
 * - 0 - PMIC Power Pin is Low active.
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL1_PWR_POL (9U)   /*!< Bit position for USBNC_OTG1_CTRL1_PWR_POL. */
#define BM_USBNC_OTG1_CTRL1_PWR_POL (0x00000200U) /*!< Bit mask for USBNC_OTG1_CTRL1_PWR_POL. */
#define BS_USBNC_OTG1_CTRL1_PWR_POL (1U)   /*!< Bit field size in bits for USBNC_OTG1_CTRL1_PWR_POL. */

/*! @brief Read current value of the USBNC_OTG1_CTRL1_PWR_POL field. */
#define BR_USBNC_OTG1_CTRL1_PWR_POL(x) (HW_USBNC_OTG1_CTRL1(x).B.PWR_POL)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL1_PWR_POL. */
#define BF_USBNC_OTG1_CTRL1_PWR_POL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL1_PWR_POL) & BM_USBNC_OTG1_CTRL1_PWR_POL)

/*! @brief Set the PWR_POL field to a new value. */
#define BW_USBNC_OTG1_CTRL1_PWR_POL(x, v) (HW_USBNC_OTG1_CTRL1_WR(x, (HW_USBNC_OTG1_CTRL1_RD(x) & ~BM_USBNC_OTG1_CTRL1_PWR_POL) | BF_USBNC_OTG1_CTRL1_PWR_POL(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL1, field WIE[10] (RW)
 *
 * Wake-up Interrupt Enable This bit enables or disables the OTG1 wake-up
 * interrupt. Disabling the interrupt also clears the Interrupt request bit. Wake-up
 * interrupt enable should be turned off after receiving a wake-up interrupt and
 * turned on again prior to going in suspend mode
 *
 * Values:
 * - 1 - Interrupt Enabled
 * - 0 - Interrupt Disabled
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL1_WIE (10U)      /*!< Bit position for USBNC_OTG1_CTRL1_WIE. */
#define BM_USBNC_OTG1_CTRL1_WIE (0x00000400U) /*!< Bit mask for USBNC_OTG1_CTRL1_WIE. */
#define BS_USBNC_OTG1_CTRL1_WIE (1U)       /*!< Bit field size in bits for USBNC_OTG1_CTRL1_WIE. */

/*! @brief Read current value of the USBNC_OTG1_CTRL1_WIE field. */
#define BR_USBNC_OTG1_CTRL1_WIE(x) (HW_USBNC_OTG1_CTRL1(x).B.WIE)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL1_WIE. */
#define BF_USBNC_OTG1_CTRL1_WIE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL1_WIE) & BM_USBNC_OTG1_CTRL1_WIE)

/*! @brief Set the WIE field to a new value. */
#define BW_USBNC_OTG1_CTRL1_WIE(x, v) (HW_USBNC_OTG1_CTRL1_WR(x, (HW_USBNC_OTG1_CTRL1_RD(x) & ~BM_USBNC_OTG1_CTRL1_WIE) | BF_USBNC_OTG1_CTRL1_WIE(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL1, field WKUP_SW_EN[14] (RW)
 *
 * Software Wake-up Enable
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL1_WKUP_SW_EN (14U) /*!< Bit position for USBNC_OTG1_CTRL1_WKUP_SW_EN. */
#define BM_USBNC_OTG1_CTRL1_WKUP_SW_EN (0x00004000U) /*!< Bit mask for USBNC_OTG1_CTRL1_WKUP_SW_EN. */
#define BS_USBNC_OTG1_CTRL1_WKUP_SW_EN (1U) /*!< Bit field size in bits for USBNC_OTG1_CTRL1_WKUP_SW_EN. */

/*! @brief Read current value of the USBNC_OTG1_CTRL1_WKUP_SW_EN field. */
#define BR_USBNC_OTG1_CTRL1_WKUP_SW_EN(x) (HW_USBNC_OTG1_CTRL1(x).B.WKUP_SW_EN)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL1_WKUP_SW_EN. */
#define BF_USBNC_OTG1_CTRL1_WKUP_SW_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL1_WKUP_SW_EN) & BM_USBNC_OTG1_CTRL1_WKUP_SW_EN)

/*! @brief Set the WKUP_SW_EN field to a new value. */
#define BW_USBNC_OTG1_CTRL1_WKUP_SW_EN(x, v) (HW_USBNC_OTG1_CTRL1_WR(x, (HW_USBNC_OTG1_CTRL1_RD(x) & ~BM_USBNC_OTG1_CTRL1_WKUP_SW_EN) | BF_USBNC_OTG1_CTRL1_WKUP_SW_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL1, field WKUP_SW[15] (RW)
 *
 * Software Wake-up
 *
 * Values:
 * - 1 - Force wake-up
 * - 0 - Inactive
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL1_WKUP_SW (15U)  /*!< Bit position for USBNC_OTG1_CTRL1_WKUP_SW. */
#define BM_USBNC_OTG1_CTRL1_WKUP_SW (0x00008000U) /*!< Bit mask for USBNC_OTG1_CTRL1_WKUP_SW. */
#define BS_USBNC_OTG1_CTRL1_WKUP_SW (1U)   /*!< Bit field size in bits for USBNC_OTG1_CTRL1_WKUP_SW. */

/*! @brief Read current value of the USBNC_OTG1_CTRL1_WKUP_SW field. */
#define BR_USBNC_OTG1_CTRL1_WKUP_SW(x) (HW_USBNC_OTG1_CTRL1(x).B.WKUP_SW)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL1_WKUP_SW. */
#define BF_USBNC_OTG1_CTRL1_WKUP_SW(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL1_WKUP_SW) & BM_USBNC_OTG1_CTRL1_WKUP_SW)

/*! @brief Set the WKUP_SW field to a new value. */
#define BW_USBNC_OTG1_CTRL1_WKUP_SW(x, v) (HW_USBNC_OTG1_CTRL1_WR(x, (HW_USBNC_OTG1_CTRL1_RD(x) & ~BM_USBNC_OTG1_CTRL1_WKUP_SW) | BF_USBNC_OTG1_CTRL1_WKUP_SW(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL1, field WKUP_ID_EN[16] (RW)
 *
 * Wake-up on ID change enable
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL1_WKUP_ID_EN (16U) /*!< Bit position for USBNC_OTG1_CTRL1_WKUP_ID_EN. */
#define BM_USBNC_OTG1_CTRL1_WKUP_ID_EN (0x00010000U) /*!< Bit mask for USBNC_OTG1_CTRL1_WKUP_ID_EN. */
#define BS_USBNC_OTG1_CTRL1_WKUP_ID_EN (1U) /*!< Bit field size in bits for USBNC_OTG1_CTRL1_WKUP_ID_EN. */

/*! @brief Read current value of the USBNC_OTG1_CTRL1_WKUP_ID_EN field. */
#define BR_USBNC_OTG1_CTRL1_WKUP_ID_EN(x) (HW_USBNC_OTG1_CTRL1(x).B.WKUP_ID_EN)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL1_WKUP_ID_EN. */
#define BF_USBNC_OTG1_CTRL1_WKUP_ID_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL1_WKUP_ID_EN) & BM_USBNC_OTG1_CTRL1_WKUP_ID_EN)

/*! @brief Set the WKUP_ID_EN field to a new value. */
#define BW_USBNC_OTG1_CTRL1_WKUP_ID_EN(x, v) (HW_USBNC_OTG1_CTRL1_WR(x, (HW_USBNC_OTG1_CTRL1_RD(x) & ~BM_USBNC_OTG1_CTRL1_WKUP_ID_EN) | BF_USBNC_OTG1_CTRL1_WKUP_ID_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL1, field WKUP_VBUS_EN[17] (RW)
 *
 * Wake-up on VBUS change enable
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL1_WKUP_VBUS_EN (17U) /*!< Bit position for USBNC_OTG1_CTRL1_WKUP_VBUS_EN. */
#define BM_USBNC_OTG1_CTRL1_WKUP_VBUS_EN (0x00020000U) /*!< Bit mask for USBNC_OTG1_CTRL1_WKUP_VBUS_EN. */
#define BS_USBNC_OTG1_CTRL1_WKUP_VBUS_EN (1U) /*!< Bit field size in bits for USBNC_OTG1_CTRL1_WKUP_VBUS_EN. */

/*! @brief Read current value of the USBNC_OTG1_CTRL1_WKUP_VBUS_EN field. */
#define BR_USBNC_OTG1_CTRL1_WKUP_VBUS_EN(x) (HW_USBNC_OTG1_CTRL1(x).B.WKUP_VBUS_EN)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL1_WKUP_VBUS_EN. */
#define BF_USBNC_OTG1_CTRL1_WKUP_VBUS_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL1_WKUP_VBUS_EN) & BM_USBNC_OTG1_CTRL1_WKUP_VBUS_EN)

/*! @brief Set the WKUP_VBUS_EN field to a new value. */
#define BW_USBNC_OTG1_CTRL1_WKUP_VBUS_EN(x, v) (HW_USBNC_OTG1_CTRL1_WR(x, (HW_USBNC_OTG1_CTRL1_RD(x) & ~BM_USBNC_OTG1_CTRL1_WKUP_VBUS_EN) | BF_USBNC_OTG1_CTRL1_WKUP_VBUS_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL1, field WKUP_DPDM_EN[29] (RW)
 *
 * Wake-up on DPDM change enable
 *
 * Values:
 * - 1 - (Default) DPDM changes wake-up to be enabled, it is for device only.
 * - 0 - DPDM changes wake-up to be disabled only when VBUS is 0.
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL1_WKUP_DPDM_EN (29U) /*!< Bit position for USBNC_OTG1_CTRL1_WKUP_DPDM_EN. */
#define BM_USBNC_OTG1_CTRL1_WKUP_DPDM_EN (0x20000000U) /*!< Bit mask for USBNC_OTG1_CTRL1_WKUP_DPDM_EN. */
#define BS_USBNC_OTG1_CTRL1_WKUP_DPDM_EN (1U) /*!< Bit field size in bits for USBNC_OTG1_CTRL1_WKUP_DPDM_EN. */

/*! @brief Read current value of the USBNC_OTG1_CTRL1_WKUP_DPDM_EN field. */
#define BR_USBNC_OTG1_CTRL1_WKUP_DPDM_EN(x) (HW_USBNC_OTG1_CTRL1(x).B.WKUP_DPDM_EN)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL1_WKUP_DPDM_EN. */
#define BF_USBNC_OTG1_CTRL1_WKUP_DPDM_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL1_WKUP_DPDM_EN) & BM_USBNC_OTG1_CTRL1_WKUP_DPDM_EN)

/*! @brief Set the WKUP_DPDM_EN field to a new value. */
#define BW_USBNC_OTG1_CTRL1_WKUP_DPDM_EN(x, v) (HW_USBNC_OTG1_CTRL1_WR(x, (HW_USBNC_OTG1_CTRL1_RD(x) & ~BM_USBNC_OTG1_CTRL1_WKUP_DPDM_EN) | BF_USBNC_OTG1_CTRL1_WKUP_DPDM_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL1, field WIR[31] (RO)
 *
 * Wake-up Interrupt Request This bit indicates that a wake-up interrupt request
 * is received on the OTG1 port. This bit is cleared by disabling the wake-up
 * interrupt (clearing bit "OWIE").
 *
 * Values:
 * - 1 - Wake-up Interrupt Request received
 * - 0 - No wake-up interrupt request received
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL1_WIR (31U)      /*!< Bit position for USBNC_OTG1_CTRL1_WIR. */
#define BM_USBNC_OTG1_CTRL1_WIR (0x80000000U) /*!< Bit mask for USBNC_OTG1_CTRL1_WIR. */
#define BS_USBNC_OTG1_CTRL1_WIR (1U)       /*!< Bit field size in bits for USBNC_OTG1_CTRL1_WIR. */

/*! @brief Read current value of the USBNC_OTG1_CTRL1_WIR field. */
#define BR_USBNC_OTG1_CTRL1_WIR(x) (HW_USBNC_OTG1_CTRL1(x).B.WIR)
/*@}*/

/*******************************************************************************
 * HW_USBNC_OTG1_CTRL2 -
 ******************************************************************************/

/*!
 * @brief HW_USBNC_OTG1_CTRL2 -  (RW)
 *
 * Reset value: 0x0F000000U
 *
 * The USB_OTGx_PHY_CTRL2 register allows observation of the UTMI Clock Valid
 * status along with control of selected inputs to the USB OTG PHY transceiver.
 * Some of these input signals may be used for USB out-of-band signaling. Customers
 * should use caution when overriding any UTMI signals since that will interfere
 * with normal USB data communication.
 */
typedef union _hw_usbnc_otg1_ctrl2
{
    uint32_t U;
    struct _hw_usbnc_otg1_ctrl2_bitfields
    {
        uint32_t VBUS_SOURCE_SEL : 2;  /*!< [1:0]  */
        uint32_t AUTURESUME_EN : 1;    /*!< [2] Auto Resume Enable */
        uint32_t LOWSPEED_EN : 1;      /*!< [3]  */
        uint32_t TERMSEL_OVERRIDE : 1; /*!< [4]  */
        uint32_t TERMSEL_OVERRIDEEN : 1; /*!< [5]  */
        uint32_t OPMODE_OVERRIDE : 2;  /*!< [7:6]  */
        uint32_t OPMODE_OVERRIDEEN : 1; /*!< [8]  */
        uint32_t XCVRSEL_OVERRIDE : 2; /*!< [10:9]  */
        uint32_t XCVRSEL_OVERRIDEEN : 1; /*!< [11]  */
        uint32_t DPPULLDOWN_OVERRIDE : 1; /*!< [12]  */
        uint32_t DPPULLDOWN_OVERRIDEEN : 1; /*!< [13]  */
        uint32_t DMPULLDOWN_OVERRIDE : 1; /*!< [14]  */
        uint32_t DMPULLDOWN_OVERRIDEEN : 1; /*!< [15]  */
        uint32_t RESERVED0 : 4;        /*!< [19:16]  */
        uint32_t DIG_ID_SEL : 1;       /*!< [20]  */
        uint32_t RESERVED1 : 10;       /*!< [30:21]  */
        uint32_t UTMI_CLK_VLD : 1;     /*!< [31]  */
    } B;
} hw_usbnc_otg1_ctrl2_t;

/*!
 * @name Constants and macros for entire USBNC_OTG1_CTRL2 register
 */
/*@{*/
#define HW_USBNC_OTG1_CTRL2_ADDR(x) ((uintptr_t)(x) + 0x204U)

#define HW_USBNC_OTG1_CTRL2(x)   (*(__IO hw_usbnc_otg1_ctrl2_t *) HW_USBNC_OTG1_CTRL2_ADDR(x))
#define HW_USBNC_OTG1_CTRL2_RD(x) (HW_USBNC_OTG1_CTRL2(x).U)
#define HW_USBNC_OTG1_CTRL2_WR(x, v) (HW_USBNC_OTG1_CTRL2(x).U = (v))
#define HW_USBNC_OTG1_CTRL2_SET(x, v) (HW_USBNC_OTG1_CTRL2_WR(x, HW_USBNC_OTG1_CTRL2_RD(x) |  (v)))
#define HW_USBNC_OTG1_CTRL2_CLR(x, v) (HW_USBNC_OTG1_CTRL2_WR(x, HW_USBNC_OTG1_CTRL2_RD(x) & ~(v)))
#define HW_USBNC_OTG1_CTRL2_TOG(x, v) (HW_USBNC_OTG1_CTRL2_WR(x, HW_USBNC_OTG1_CTRL2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBNC_OTG1_CTRL2 bitfields
 */

/*!
 * @name Register USBNC_OTG1_CTRL2, field VBUS_SOURCE_SEL[1:0] (RW)
 *
 * VBUS source select used to detect a VBUS wakeup event. This bit field is for
 * UTMI OTG PHY only (UH core and HSIC PHY have no such feature).
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL2_VBUS_SOURCE_SEL (0U) /*!< Bit position for USBNC_OTG1_CTRL2_VBUS_SOURCE_SEL. */
#define BM_USBNC_OTG1_CTRL2_VBUS_SOURCE_SEL (0x00000003U) /*!< Bit mask for USBNC_OTG1_CTRL2_VBUS_SOURCE_SEL. */
#define BS_USBNC_OTG1_CTRL2_VBUS_SOURCE_SEL (2U) /*!< Bit field size in bits for USBNC_OTG1_CTRL2_VBUS_SOURCE_SEL. */

/*! @brief Read current value of the USBNC_OTG1_CTRL2_VBUS_SOURCE_SEL field. */
#define BR_USBNC_OTG1_CTRL2_VBUS_SOURCE_SEL(x) (HW_USBNC_OTG1_CTRL2(x).B.VBUS_SOURCE_SEL)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL2_VBUS_SOURCE_SEL. */
#define BF_USBNC_OTG1_CTRL2_VBUS_SOURCE_SEL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL2_VBUS_SOURCE_SEL) & BM_USBNC_OTG1_CTRL2_VBUS_SOURCE_SEL)

/*! @brief Set the VBUS_SOURCE_SEL field to a new value. */
#define BW_USBNC_OTG1_CTRL2_VBUS_SOURCE_SEL(x, v) (HW_USBNC_OTG1_CTRL2_WR(x, (HW_USBNC_OTG1_CTRL2_RD(x) & ~(BM_USBNC_OTG1_CTRL2_VBUS_SOURCE_SEL | BM_USBNC_OTG1_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG1_CTRL2_VBUS_SOURCE_SEL(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL2, field AUTURESUME_EN[2] (RW)
 *
 * This bit field is for UTMI OTG PHY host mode only (UH core does not have this
 * feature since HSIC PHY does not support auto resume). To set USB, it will
 * send resume with 32 KHz clock when it detects remote wakeup from device. This
 * feature is useful if device drives a very short remote wakeup (minimal value is 1
 * ms for USB2 spec) and system 24 MHz is off during suspend mode.
 *
 * Values:
 * - 0 - Default
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL2_AUTURESUME_EN (2U) /*!< Bit position for USBNC_OTG1_CTRL2_AUTURESUME_EN. */
#define BM_USBNC_OTG1_CTRL2_AUTURESUME_EN (0x00000004U) /*!< Bit mask for USBNC_OTG1_CTRL2_AUTURESUME_EN. */
#define BS_USBNC_OTG1_CTRL2_AUTURESUME_EN (1U) /*!< Bit field size in bits for USBNC_OTG1_CTRL2_AUTURESUME_EN. */

/*! @brief Read current value of the USBNC_OTG1_CTRL2_AUTURESUME_EN field. */
#define BR_USBNC_OTG1_CTRL2_AUTURESUME_EN(x) (HW_USBNC_OTG1_CTRL2(x).B.AUTURESUME_EN)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL2_AUTURESUME_EN. */
#define BF_USBNC_OTG1_CTRL2_AUTURESUME_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL2_AUTURESUME_EN) & BM_USBNC_OTG1_CTRL2_AUTURESUME_EN)

/*! @brief Set the AUTURESUME_EN field to a new value. */
#define BW_USBNC_OTG1_CTRL2_AUTURESUME_EN(x, v) (HW_USBNC_OTG1_CTRL2_WR(x, (HW_USBNC_OTG1_CTRL2_RD(x) & ~(BM_USBNC_OTG1_CTRL2_AUTURESUME_EN | BM_USBNC_OTG1_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG1_CTRL2_AUTURESUME_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL2, field LOWSPEED_EN[3] (RW)
 *
 * Set if AUTURESUME_EN is set and works on low speed.
 *
 * Values:
 * - 0 - Default
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL2_LOWSPEED_EN (3U) /*!< Bit position for USBNC_OTG1_CTRL2_LOWSPEED_EN. */
#define BM_USBNC_OTG1_CTRL2_LOWSPEED_EN (0x00000008U) /*!< Bit mask for USBNC_OTG1_CTRL2_LOWSPEED_EN. */
#define BS_USBNC_OTG1_CTRL2_LOWSPEED_EN (1U) /*!< Bit field size in bits for USBNC_OTG1_CTRL2_LOWSPEED_EN. */

/*! @brief Read current value of the USBNC_OTG1_CTRL2_LOWSPEED_EN field. */
#define BR_USBNC_OTG1_CTRL2_LOWSPEED_EN(x) (HW_USBNC_OTG1_CTRL2(x).B.LOWSPEED_EN)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL2_LOWSPEED_EN. */
#define BF_USBNC_OTG1_CTRL2_LOWSPEED_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL2_LOWSPEED_EN) & BM_USBNC_OTG1_CTRL2_LOWSPEED_EN)

/*! @brief Set the LOWSPEED_EN field to a new value. */
#define BW_USBNC_OTG1_CTRL2_LOWSPEED_EN(x, v) (HW_USBNC_OTG1_CTRL2_WR(x, (HW_USBNC_OTG1_CTRL2_RD(x) & ~(BM_USBNC_OTG1_CTRL2_LOWSPEED_EN | BM_USBNC_OTG1_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG1_CTRL2_LOWSPEED_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL2, field TERMSEL_OVERRIDE[4] (RW)
 *
 * Controls the state of the UTMI TermSelect signal to the USB OTG PHY if the
 * value of USBNC_x_CTRL2[TERMSEL_OVERRIDEEN] is set to 1'b1. See the UTMI+
 * Specification for descriptions of the function of the TermSelect signal.
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDE (4U) /*!< Bit position for USBNC_OTG1_CTRL2_TERMSEL_OVERRIDE. */
#define BM_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDE (0x00000010U) /*!< Bit mask for USBNC_OTG1_CTRL2_TERMSEL_OVERRIDE. */
#define BS_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDE (1U) /*!< Bit field size in bits for USBNC_OTG1_CTRL2_TERMSEL_OVERRIDE. */

/*! @brief Read current value of the USBNC_OTG1_CTRL2_TERMSEL_OVERRIDE field. */
#define BR_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDE(x) (HW_USBNC_OTG1_CTRL2(x).B.TERMSEL_OVERRIDE)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL2_TERMSEL_OVERRIDE. */
#define BF_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDE) & BM_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDE)

/*! @brief Set the TERMSEL_OVERRIDE field to a new value. */
#define BW_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDE(x, v) (HW_USBNC_OTG1_CTRL2_WR(x, (HW_USBNC_OTG1_CTRL2_RD(x) & ~(BM_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDE | BM_USBNC_OTG1_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL2, field TERMSEL_OVERRIDEEN[5] (RW)
 *
 * Enables override of control of the UTMI TermSelect signal to the USB OTG PHY
 * instead of using the state normally set by the USB controller.
 *
 * Values:
 * - 0 - The state of the UTMI TermSelect signal to the USB PHY is set by the
 *     USB controller.
 * - 1 - The state of the UTMI TermSelect signal to the USB PHY is set by the
 *     value in the USBNC_x_CTRL2[TERMSEL_OVERRIDE] bit field.
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDEEN (5U) /*!< Bit position for USBNC_OTG1_CTRL2_TERMSEL_OVERRIDEEN. */
#define BM_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDEEN (0x00000020U) /*!< Bit mask for USBNC_OTG1_CTRL2_TERMSEL_OVERRIDEEN. */
#define BS_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDEEN (1U) /*!< Bit field size in bits for USBNC_OTG1_CTRL2_TERMSEL_OVERRIDEEN. */

/*! @brief Read current value of the USBNC_OTG1_CTRL2_TERMSEL_OVERRIDEEN field. */
#define BR_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDEEN(x) (HW_USBNC_OTG1_CTRL2(x).B.TERMSEL_OVERRIDEEN)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL2_TERMSEL_OVERRIDEEN. */
#define BF_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDEEN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDEEN) & BM_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDEEN)

/*! @brief Set the TERMSEL_OVERRIDEEN field to a new value. */
#define BW_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDEEN(x, v) (HW_USBNC_OTG1_CTRL2_WR(x, (HW_USBNC_OTG1_CTRL2_RD(x) & ~(BM_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDEEN | BM_USBNC_OTG1_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG1_CTRL2_TERMSEL_OVERRIDEEN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL2, field OPMODE_OVERRIDE[7:6] (RW)
 *
 * Controls the state of the UTMI XcvrSelect signals to the USB OTG PHY if the
 * value of USBNC_x_CTRL2[OPMODE_OVERRIDEEN] is set to 1'b1. See the UTMI+
 * Specification for descriptions of the functions of the OpMode signals.
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL2_OPMODE_OVERRIDE (6U) /*!< Bit position for USBNC_OTG1_CTRL2_OPMODE_OVERRIDE. */
#define BM_USBNC_OTG1_CTRL2_OPMODE_OVERRIDE (0x000000C0U) /*!< Bit mask for USBNC_OTG1_CTRL2_OPMODE_OVERRIDE. */
#define BS_USBNC_OTG1_CTRL2_OPMODE_OVERRIDE (2U) /*!< Bit field size in bits for USBNC_OTG1_CTRL2_OPMODE_OVERRIDE. */

/*! @brief Read current value of the USBNC_OTG1_CTRL2_OPMODE_OVERRIDE field. */
#define BR_USBNC_OTG1_CTRL2_OPMODE_OVERRIDE(x) (HW_USBNC_OTG1_CTRL2(x).B.OPMODE_OVERRIDE)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL2_OPMODE_OVERRIDE. */
#define BF_USBNC_OTG1_CTRL2_OPMODE_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL2_OPMODE_OVERRIDE) & BM_USBNC_OTG1_CTRL2_OPMODE_OVERRIDE)

/*! @brief Set the OPMODE_OVERRIDE field to a new value. */
#define BW_USBNC_OTG1_CTRL2_OPMODE_OVERRIDE(x, v) (HW_USBNC_OTG1_CTRL2_WR(x, (HW_USBNC_OTG1_CTRL2_RD(x) & ~(BM_USBNC_OTG1_CTRL2_OPMODE_OVERRIDE | BM_USBNC_OTG1_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG1_CTRL2_OPMODE_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL2, field OPMODE_OVERRIDEEN[8] (RW)
 *
 * Enables override of control of the UTMI OpMode signals to the USB OTG PHY
 * instead of using the state normally set by the USB controller.
 *
 * Values:
 * - 0 - The state of the UTMI OpMode signals to the USB PHY is set by the USB
 *     controller.
 * - 1 - The state of the UTMI OpMode signals to the USB PHY is set by the
 *     values in the USBNC_x_CTRL2[OPMODE_OVERRIDE] bit field.
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL2_OPMODE_OVERRIDEEN (8U) /*!< Bit position for USBNC_OTG1_CTRL2_OPMODE_OVERRIDEEN. */
#define BM_USBNC_OTG1_CTRL2_OPMODE_OVERRIDEEN (0x00000100U) /*!< Bit mask for USBNC_OTG1_CTRL2_OPMODE_OVERRIDEEN. */
#define BS_USBNC_OTG1_CTRL2_OPMODE_OVERRIDEEN (1U) /*!< Bit field size in bits for USBNC_OTG1_CTRL2_OPMODE_OVERRIDEEN. */

/*! @brief Read current value of the USBNC_OTG1_CTRL2_OPMODE_OVERRIDEEN field. */
#define BR_USBNC_OTG1_CTRL2_OPMODE_OVERRIDEEN(x) (HW_USBNC_OTG1_CTRL2(x).B.OPMODE_OVERRIDEEN)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL2_OPMODE_OVERRIDEEN. */
#define BF_USBNC_OTG1_CTRL2_OPMODE_OVERRIDEEN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL2_OPMODE_OVERRIDEEN) & BM_USBNC_OTG1_CTRL2_OPMODE_OVERRIDEEN)

/*! @brief Set the OPMODE_OVERRIDEEN field to a new value. */
#define BW_USBNC_OTG1_CTRL2_OPMODE_OVERRIDEEN(x, v) (HW_USBNC_OTG1_CTRL2_WR(x, (HW_USBNC_OTG1_CTRL2_RD(x) & ~(BM_USBNC_OTG1_CTRL2_OPMODE_OVERRIDEEN | BM_USBNC_OTG1_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG1_CTRL2_OPMODE_OVERRIDEEN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL2, field XCVRSEL_OVERRIDE[10:9] (RW)
 *
 * Controls the state of the UTMI XcvrSelect signals to the USB OTG PHY if the
 * value of USBNC_x_CTRL2[XCVRSEL_OVERRIDEEN] is set to 1'b1. See the UTMI+
 * Specification for descriptions of the functions of the XcvrSelect signals.
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDE (9U) /*!< Bit position for USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDE. */
#define BM_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDE (0x00000600U) /*!< Bit mask for USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDE. */
#define BS_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDE (2U) /*!< Bit field size in bits for USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDE. */

/*! @brief Read current value of the USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDE field. */
#define BR_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDE(x) (HW_USBNC_OTG1_CTRL2(x).B.XCVRSEL_OVERRIDE)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDE. */
#define BF_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDE) & BM_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDE)

/*! @brief Set the XCVRSEL_OVERRIDE field to a new value. */
#define BW_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDE(x, v) (HW_USBNC_OTG1_CTRL2_WR(x, (HW_USBNC_OTG1_CTRL2_RD(x) & ~(BM_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDE | BM_USBNC_OTG1_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL2, field XCVRSEL_OVERRIDEEN[11] (RW)
 *
 * Enables override of control of the UTMI XcvrSelect signals to the USB OTG PHY
 * instead of using the state normally set by the USB controller.
 *
 * Values:
 * - 0 - The state of the UTMI XcvrSelect signals to the USB PHY is set by the
 *     USB controller.
 * - 1 - The state of the UTMI XcvrSelect signals to the USB PHY is set by the
 *     values in the USBNC_x_CTRL2[XCVRSEL_OVERRIDE] bit field.
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDEEN (11U) /*!< Bit position for USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDEEN. */
#define BM_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDEEN (0x00000800U) /*!< Bit mask for USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDEEN. */
#define BS_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDEEN (1U) /*!< Bit field size in bits for USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDEEN. */

/*! @brief Read current value of the USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDEEN field. */
#define BR_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDEEN(x) (HW_USBNC_OTG1_CTRL2(x).B.XCVRSEL_OVERRIDEEN)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDEEN. */
#define BF_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDEEN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDEEN) & BM_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDEEN)

/*! @brief Set the XCVRSEL_OVERRIDEEN field to a new value. */
#define BW_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDEEN(x, v) (HW_USBNC_OTG1_CTRL2_WR(x, (HW_USBNC_OTG1_CTRL2_RD(x) & ~(BM_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDEEN | BM_USBNC_OTG1_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG1_CTRL2_XCVRSEL_OVERRIDEEN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL2, field DPPULLDOWN_OVERRIDE[12] (RW)
 *
 * Controls state of DP pulldown resistor if
 * USBNC_n_CTRL2[DPPULLDOWN_OVERRIDEEN] is set to 1'b1.
 *
 * Values:
 * - 0 - DP pulldown resistor disabled
 * - 1 - DP pulldown resistor enabled
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDE (12U) /*!< Bit position for USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDE. */
#define BM_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDE (0x00001000U) /*!< Bit mask for USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDE. */
#define BS_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDE (1U) /*!< Bit field size in bits for USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDE. */

/*! @brief Read current value of the USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDE field. */
#define BR_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDE(x) (HW_USBNC_OTG1_CTRL2(x).B.DPPULLDOWN_OVERRIDE)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDE. */
#define BF_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDE) & BM_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDE)

/*! @brief Set the DPPULLDOWN_OVERRIDE field to a new value. */
#define BW_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDE(x, v) (HW_USBNC_OTG1_CTRL2_WR(x, (HW_USBNC_OTG1_CTRL2_RD(x) & ~(BM_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDE | BM_USBNC_OTG1_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL2, field DPPULLDOWN_OVERRIDEEN[13] (RW)
 *
 * Enables override of control of the DP pulldown resistor instead of using the
 * state set by the USB controller.
 *
 * Values:
 * - 0 - USB controller enables/disables the DP pulldown resistor in the USB PHY.
 * - 1 - Use the value set by the USBNC_n_CTRL2[DPPULLDOWN_OVERRIDE] bit field
 *     to enable/disable the DP pulldown resistor in the USB PHY.
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDEEN (13U) /*!< Bit position for USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDEEN. */
#define BM_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDEEN (0x00002000U) /*!< Bit mask for USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDEEN. */
#define BS_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDEEN (1U) /*!< Bit field size in bits for USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDEEN. */

/*! @brief Read current value of the USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDEEN field. */
#define BR_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDEEN(x) (HW_USBNC_OTG1_CTRL2(x).B.DPPULLDOWN_OVERRIDEEN)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDEEN. */
#define BF_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDEEN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDEEN) & BM_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDEEN)

/*! @brief Set the DPPULLDOWN_OVERRIDEEN field to a new value. */
#define BW_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDEEN(x, v) (HW_USBNC_OTG1_CTRL2_WR(x, (HW_USBNC_OTG1_CTRL2_RD(x) & ~(BM_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDEEN | BM_USBNC_OTG1_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG1_CTRL2_DPPULLDOWN_OVERRIDEEN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL2, field DMPULLDOWN_OVERRIDE[14] (RW)
 *
 * Controls state of DM pulldown resistor if
 * USBNC_n_CTRL2[DMPULLDOWN_OVERRIDEEN] is set to 1'b1.
 *
 * Values:
 * - 0 - DM pulldown resistor disabled
 * - 1 - DM pulldown resistor enabled
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDE (14U) /*!< Bit position for USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDE. */
#define BM_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDE (0x00004000U) /*!< Bit mask for USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDE. */
#define BS_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDE (1U) /*!< Bit field size in bits for USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDE. */

/*! @brief Read current value of the USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDE field. */
#define BR_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDE(x) (HW_USBNC_OTG1_CTRL2(x).B.DMPULLDOWN_OVERRIDE)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDE. */
#define BF_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDE) & BM_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDE)

/*! @brief Set the DMPULLDOWN_OVERRIDE field to a new value. */
#define BW_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDE(x, v) (HW_USBNC_OTG1_CTRL2_WR(x, (HW_USBNC_OTG1_CTRL2_RD(x) & ~(BM_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDE | BM_USBNC_OTG1_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL2, field DMPULLDOWN_OVERRIDEEN[15] (RW)
 *
 * Enables override of control of the DM pulldown resistor instead of the state
 * set by the USB controller.
 *
 * Values:
 * - 0 - USB controller enables/disables the DM pulldown resistor in the USB PHY.
 * - 1 - Use the value set by the USBNC_n_CTRL2[DMPULLDOWN_OVERRIDE] bit field
 *     to enable/disable the DM pulldown resistor in the USB PHY.
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDEEN (15U) /*!< Bit position for USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDEEN. */
#define BM_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDEEN (0x00008000U) /*!< Bit mask for USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDEEN. */
#define BS_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDEEN (1U) /*!< Bit field size in bits for USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDEEN. */

/*! @brief Read current value of the USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDEEN field. */
#define BR_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDEEN(x) (HW_USBNC_OTG1_CTRL2(x).B.DMPULLDOWN_OVERRIDEEN)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDEEN. */
#define BF_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDEEN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDEEN) & BM_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDEEN)

/*! @brief Set the DMPULLDOWN_OVERRIDEEN field to a new value. */
#define BW_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDEEN(x, v) (HW_USBNC_OTG1_CTRL2_WR(x, (HW_USBNC_OTG1_CTRL2_RD(x) & ~(BM_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDEEN | BM_USBNC_OTG1_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG1_CTRL2_DMPULLDOWN_OVERRIDEEN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL2, field DIG_ID_SEL[20] (RW)
 *
 * Selects whether the USB OTG ID pin function is connected to the PHY's
 * USB_OTG*_ID pin or a GPIO pin. The ID pin state is observed on
 * USBNC_n_PHY_STATUS[ID_DIG].
 *
 * Values:
 * - 0 - Use the USB_OTG*_ID pin for the USB OTG ID pin detection
 *     function(default)
 * - 1 - Use the pin configured by the IOMUXC_USB_OTG*_ID_SELECT_INPUT register
 *     for the USB OTG ID pin detection function
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL2_DIG_ID_SEL (20U) /*!< Bit position for USBNC_OTG1_CTRL2_DIG_ID_SEL. */
#define BM_USBNC_OTG1_CTRL2_DIG_ID_SEL (0x00100000U) /*!< Bit mask for USBNC_OTG1_CTRL2_DIG_ID_SEL. */
#define BS_USBNC_OTG1_CTRL2_DIG_ID_SEL (1U) /*!< Bit field size in bits for USBNC_OTG1_CTRL2_DIG_ID_SEL. */

/*! @brief Read current value of the USBNC_OTG1_CTRL2_DIG_ID_SEL field. */
#define BR_USBNC_OTG1_CTRL2_DIG_ID_SEL(x) (HW_USBNC_OTG1_CTRL2(x).B.DIG_ID_SEL)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL2_DIG_ID_SEL. */
#define BF_USBNC_OTG1_CTRL2_DIG_ID_SEL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL2_DIG_ID_SEL) & BM_USBNC_OTG1_CTRL2_DIG_ID_SEL)

/*! @brief Set the DIG_ID_SEL field to a new value. */
#define BW_USBNC_OTG1_CTRL2_DIG_ID_SEL(x, v) (HW_USBNC_OTG1_CTRL2_WR(x, (HW_USBNC_OTG1_CTRL2_RD(x) & ~(BM_USBNC_OTG1_CTRL2_DIG_ID_SEL | BM_USBNC_OTG1_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG1_CTRL2_DIG_ID_SEL(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_CTRL2, field UTMI_CLK_VLD[31] (W1C)
 *
 * Indicate whether PHY clock is valid. Write 1 to clear
 *
 * Values:
 * - 0 - UTMI clock to USB PHY is not toggling (Default)
 * - 1 - UTMI clock to USB PHY has toggled several times
 */
/*@{*/
#define BP_USBNC_OTG1_CTRL2_UTMI_CLK_VLD (31U) /*!< Bit position for USBNC_OTG1_CTRL2_UTMI_CLK_VLD. */
#define BM_USBNC_OTG1_CTRL2_UTMI_CLK_VLD (0x80000000U) /*!< Bit mask for USBNC_OTG1_CTRL2_UTMI_CLK_VLD. */
#define BS_USBNC_OTG1_CTRL2_UTMI_CLK_VLD (1U) /*!< Bit field size in bits for USBNC_OTG1_CTRL2_UTMI_CLK_VLD. */

/*! @brief Read current value of the USBNC_OTG1_CTRL2_UTMI_CLK_VLD field. */
#define BR_USBNC_OTG1_CTRL2_UTMI_CLK_VLD(x) (HW_USBNC_OTG1_CTRL2(x).B.UTMI_CLK_VLD)

/*! @brief Format value for bitfield USBNC_OTG1_CTRL2_UTMI_CLK_VLD. */
#define BF_USBNC_OTG1_CTRL2_UTMI_CLK_VLD(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_CTRL2_UTMI_CLK_VLD) & BM_USBNC_OTG1_CTRL2_UTMI_CLK_VLD)

/*! @brief Set the UTMI_CLK_VLD field to a new value. */
#define BW_USBNC_OTG1_CTRL2_UTMI_CLK_VLD(x, v) (HW_USBNC_OTG1_CTRL2_WR(x, (HW_USBNC_OTG1_CTRL2_RD(x) & ~BM_USBNC_OTG1_CTRL2_UTMI_CLK_VLD) | BF_USBNC_OTG1_CTRL2_UTMI_CLK_VLD(v)))
/*@}*/

/*******************************************************************************
 * HW_USBNC_OTG1_PHY_CFG1 - USB OTG PHY Configuration Register 1
 ******************************************************************************/

/*!
 * @brief HW_USBNC_OTG1_PHY_CFG1 - USB OTG PHY Configuration Register 1 (RW)
 *
 * Reset value: 0x153371CBU
 *
 * The USB_OTGx_PHY_CFG1 register allows control of selected inputs to the USB
 * OTG PHY. Most of these signals are used for parametric tuning of the USB
 * transceiver functions. One signal is used to allow persistent control of the
 * USB_OTG1_CHD_B external pin.
 */
typedef union _hw_usbnc_otg1_phy_cfg1
{
    uint32_t U;
    struct _hw_usbnc_otg1_phy_cfg1_bitfields
    {
        uint32_t COMMONONN : 1;        /*!< [0] Common Block Power-Down Control */
        uint32_t FSEL : 3;             /*!< [3:1] Reference Clock Frequency Select */
        uint32_t COMPDISTUNE0 : 3;     /*!< [6:4] Disconnect Threshold Adjustment
                                        * */
        uint32_t SQRXTUNE0 : 3;        /*!< [9:7] Squelch Threshold Adjustment */
        uint32_t OTGTUNE0 : 3;         /*!< [12:10] VBUS Valid Threshold Adjustment */
        uint32_t TXHSXVTUNE0 : 2;      /*!< [14:13] Transmitter High-Speed
                                        * Crossover Adjustment */
        uint32_t RESERVED0 : 1;        /*!< [15]  */
        uint32_t TXFSLSTUNE0 : 4;      /*!< [19:16] FS/LS Source Impedance
                                        * Adjustment */
        uint32_t TXVREFTUNE0 : 4;      /*!< [23:20] HS DC Voltage Level Adjustment
                                        * */
        uint32_t TXRISETUNE0 : 2;      /*!< [25:24] HS Transmitter Rise/Fall Time
                                        * Adjustment */
        uint32_t TXRESTUNE0 : 2;       /*!< [27:26] USB Source Impedance Adjustment
                                        * */
        uint32_t TXPREEMPAMPTUNE0 : 2; /*!< [29:28] HS Treansmitter
                                        * Pre-Emphasis Current Control */
        uint32_t TXPREEMPPULSETUNE0 : 1; /*!< [30] HS Transmitter
                                        * Pre-Emphasis Duration Control */
        uint32_t CHRGDET_Megamix : 1;  /*!< [31] USB_OTG1_CHD_B output control
                                        * */
    } B;
} hw_usbnc_otg1_phy_cfg1_t;

/*!
 * @name Constants and macros for entire USBNC_OTG1_PHY_CFG1 register
 */
/*@{*/
#define HW_USBNC_OTG1_PHY_CFG1_ADDR(x) ((uintptr_t)(x) + 0x230U)

#define HW_USBNC_OTG1_PHY_CFG1(x) (*(__IO hw_usbnc_otg1_phy_cfg1_t *) HW_USBNC_OTG1_PHY_CFG1_ADDR(x))
#define HW_USBNC_OTG1_PHY_CFG1_RD(x) (HW_USBNC_OTG1_PHY_CFG1(x).U)
#define HW_USBNC_OTG1_PHY_CFG1_WR(x, v) (HW_USBNC_OTG1_PHY_CFG1(x).U = (v))
#define HW_USBNC_OTG1_PHY_CFG1_SET(x, v) (HW_USBNC_OTG1_PHY_CFG1_WR(x, HW_USBNC_OTG1_PHY_CFG1_RD(x) |  (v)))
#define HW_USBNC_OTG1_PHY_CFG1_CLR(x, v) (HW_USBNC_OTG1_PHY_CFG1_WR(x, HW_USBNC_OTG1_PHY_CFG1_RD(x) & ~(v)))
#define HW_USBNC_OTG1_PHY_CFG1_TOG(x, v) (HW_USBNC_OTG1_PHY_CFG1_WR(x, HW_USBNC_OTG1_PHY_CFG1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBNC_OTG1_PHY_CFG1 bitfields
 */

/*!
 * @name Register USBNC_OTG1_PHY_CFG1, field COMMONONN[0] (RW)
 *
 * This signal controls the power-down signals in the Bias and PLL blocks when
 * the USB OTG PHY is in Suspend or Sleep modes.
 *
 * Values:
 * - 0 - In Suspend or Sleep modes, the Bias and PLL blocks remain powered
 * - 1 - In Suspend or Sleep modes, the Bias and PLL blocks are powered down
 * - 0 -
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG1_COMMONONN (0U) /*!< Bit position for USBNC_OTG1_PHY_CFG1_COMMONONN. */
#define BM_USBNC_OTG1_PHY_CFG1_COMMONONN (0x00000001U) /*!< Bit mask for USBNC_OTG1_PHY_CFG1_COMMONONN. */
#define BS_USBNC_OTG1_PHY_CFG1_COMMONONN (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG1_COMMONONN. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG1_COMMONONN field. */
#define BR_USBNC_OTG1_PHY_CFG1_COMMONONN(x) (HW_USBNC_OTG1_PHY_CFG1(x).B.COMMONONN)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG1_COMMONONN. */
#define BF_USBNC_OTG1_PHY_CFG1_COMMONONN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG1_COMMONONN) & BM_USBNC_OTG1_PHY_CFG1_COMMONONN)

/*! @brief Set the COMMONONN field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG1_COMMONONN(x, v) (HW_USBNC_OTG1_PHY_CFG1_WR(x, (HW_USBNC_OTG1_PHY_CFG1_RD(x) & ~BM_USBNC_OTG1_PHY_CFG1_COMMONONN) | BF_USBNC_OTG1_PHY_CFG1_COMMONONN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG1, field FSEL[3:1] (RW)
 *
 * This signal selects the USB OTG PHY reference clock frequency for the USB
 * PLL. Note: This SOC is only configured for a 24MHz clock to be routed to the USB
 * OTG PHY PLL clock input. Customers should not change the value of this bit
 * field.
 *
 * Values:
 * - 000 - 9.6 MHz
 * - 001 - 10 MHz
 * - 010 - 12 MHz
 * - 011 - 19.2 MHz
 * - 100 - 20 MHz
 * - 101 - 24 MHz (only valid setting for this SOC)
 * - 110 - Reserved
 * - 111 - 50 MHz
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG1_FSEL (1U)   /*!< Bit position for USBNC_OTG1_PHY_CFG1_FSEL. */
#define BM_USBNC_OTG1_PHY_CFG1_FSEL (0x0000000EU) /*!< Bit mask for USBNC_OTG1_PHY_CFG1_FSEL. */
#define BS_USBNC_OTG1_PHY_CFG1_FSEL (3U)   /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG1_FSEL. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG1_FSEL field. */
#define BR_USBNC_OTG1_PHY_CFG1_FSEL(x) (HW_USBNC_OTG1_PHY_CFG1(x).B.FSEL)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG1_FSEL. */
#define BF_USBNC_OTG1_PHY_CFG1_FSEL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG1_FSEL) & BM_USBNC_OTG1_PHY_CFG1_FSEL)

/*! @brief Set the FSEL field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG1_FSEL(x, v) (HW_USBNC_OTG1_PHY_CFG1_WR(x, (HW_USBNC_OTG1_PHY_CFG1_RD(x) & ~BM_USBNC_OTG1_PHY_CFG1_FSEL) | BF_USBNC_OTG1_PHY_CFG1_FSEL(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG1, field COMPDISTUNE0[6:4] (RW)
 *
 * This bus adjusts the voltage level for the receiver threshold used to detect
 * a disconnect event at the host.
 *
 * Values:
 * - 000 - -6%
 * - 001 - -4.5%
 * - 010 - -3%
 * - 011 - -1.5%
 * - 100 - Design default
 * - 101 - +1.5%
 * - 110 - +3%
 * - 111 - +4.5%
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG1_COMPDISTUNE0 (4U) /*!< Bit position for USBNC_OTG1_PHY_CFG1_COMPDISTUNE0. */
#define BM_USBNC_OTG1_PHY_CFG1_COMPDISTUNE0 (0x00000070U) /*!< Bit mask for USBNC_OTG1_PHY_CFG1_COMPDISTUNE0. */
#define BS_USBNC_OTG1_PHY_CFG1_COMPDISTUNE0 (3U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG1_COMPDISTUNE0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG1_COMPDISTUNE0 field. */
#define BR_USBNC_OTG1_PHY_CFG1_COMPDISTUNE0(x) (HW_USBNC_OTG1_PHY_CFG1(x).B.COMPDISTUNE0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG1_COMPDISTUNE0. */
#define BF_USBNC_OTG1_PHY_CFG1_COMPDISTUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG1_COMPDISTUNE0) & BM_USBNC_OTG1_PHY_CFG1_COMPDISTUNE0)

/*! @brief Set the COMPDISTUNE0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG1_COMPDISTUNE0(x, v) (HW_USBNC_OTG1_PHY_CFG1_WR(x, (HW_USBNC_OTG1_PHY_CFG1_RD(x) & ~BM_USBNC_OTG1_PHY_CFG1_COMPDISTUNE0) | BF_USBNC_OTG1_PHY_CFG1_COMPDISTUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG1, field SQRXTUNE0[9:7] (RW)
 *
 * This bus adjusts the voltage level for the receiver threshold used to detect
 * valid high-speed data.
 *
 * Values:
 * - 000 - +15%
 * - 001 - +10%
 * - 010 - +5%
 * - 011 - Design default
 * - 100 - -5%
 * - 101 - -10%
 * - 110 - -15%
 * - 111 - -20%
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG1_SQRXTUNE0 (7U) /*!< Bit position for USBNC_OTG1_PHY_CFG1_SQRXTUNE0. */
#define BM_USBNC_OTG1_PHY_CFG1_SQRXTUNE0 (0x00000380U) /*!< Bit mask for USBNC_OTG1_PHY_CFG1_SQRXTUNE0. */
#define BS_USBNC_OTG1_PHY_CFG1_SQRXTUNE0 (3U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG1_SQRXTUNE0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG1_SQRXTUNE0 field. */
#define BR_USBNC_OTG1_PHY_CFG1_SQRXTUNE0(x) (HW_USBNC_OTG1_PHY_CFG1(x).B.SQRXTUNE0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG1_SQRXTUNE0. */
#define BF_USBNC_OTG1_PHY_CFG1_SQRXTUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG1_SQRXTUNE0) & BM_USBNC_OTG1_PHY_CFG1_SQRXTUNE0)

/*! @brief Set the SQRXTUNE0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG1_SQRXTUNE0(x, v) (HW_USBNC_OTG1_PHY_CFG1_WR(x, (HW_USBNC_OTG1_PHY_CFG1_RD(x) & ~BM_USBNC_OTG1_PHY_CFG1_SQRXTUNE0) | BF_USBNC_OTG1_PHY_CFG1_SQRXTUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG1, field OTGTUNE0[12:10] (RW)
 *
 * This bus adjust the voltage level for the VBUS VALID threshold.
 *
 * Values:
 * - 000 - -6%
 * - 001 - -4.5%
 * - 010 - -3%
 * - 011 - -1.5%
 * - 100 - Design default
 * - 101 - +1.5%
 * - 110 - +3%
 * - 111 - +4.5%
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG1_OTGTUNE0 (10U) /*!< Bit position for USBNC_OTG1_PHY_CFG1_OTGTUNE0. */
#define BM_USBNC_OTG1_PHY_CFG1_OTGTUNE0 (0x00001C00U) /*!< Bit mask for USBNC_OTG1_PHY_CFG1_OTGTUNE0. */
#define BS_USBNC_OTG1_PHY_CFG1_OTGTUNE0 (3U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG1_OTGTUNE0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG1_OTGTUNE0 field. */
#define BR_USBNC_OTG1_PHY_CFG1_OTGTUNE0(x) (HW_USBNC_OTG1_PHY_CFG1(x).B.OTGTUNE0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG1_OTGTUNE0. */
#define BF_USBNC_OTG1_PHY_CFG1_OTGTUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG1_OTGTUNE0) & BM_USBNC_OTG1_PHY_CFG1_OTGTUNE0)

/*! @brief Set the OTGTUNE0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG1_OTGTUNE0(x, v) (HW_USBNC_OTG1_PHY_CFG1_WR(x, (HW_USBNC_OTG1_PHY_CFG1_RD(x) & ~BM_USBNC_OTG1_PHY_CFG1_OTGTUNE0) | BF_USBNC_OTG1_PHY_CFG1_OTGTUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG1, field TXHSXVTUNE0[14:13] (RW)
 *
 * This bus adjusts the voltage at which the USB_OTG*_DP and USB_OTG*_DN signals
 * cross while transmitting in HS mode.
 *
 * Values:
 * - 00 - Reserved
 * - 01 - -15mV
 * - 10 - +15mV
 * - 11 - Design default
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG1_TXHSXVTUNE0 (13U) /*!< Bit position for USBNC_OTG1_PHY_CFG1_TXHSXVTUNE0. */
#define BM_USBNC_OTG1_PHY_CFG1_TXHSXVTUNE0 (0x00006000U) /*!< Bit mask for USBNC_OTG1_PHY_CFG1_TXHSXVTUNE0. */
#define BS_USBNC_OTG1_PHY_CFG1_TXHSXVTUNE0 (2U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG1_TXHSXVTUNE0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG1_TXHSXVTUNE0 field. */
#define BR_USBNC_OTG1_PHY_CFG1_TXHSXVTUNE0(x) (HW_USBNC_OTG1_PHY_CFG1(x).B.TXHSXVTUNE0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG1_TXHSXVTUNE0. */
#define BF_USBNC_OTG1_PHY_CFG1_TXHSXVTUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG1_TXHSXVTUNE0) & BM_USBNC_OTG1_PHY_CFG1_TXHSXVTUNE0)

/*! @brief Set the TXHSXVTUNE0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG1_TXHSXVTUNE0(x, v) (HW_USBNC_OTG1_PHY_CFG1_WR(x, (HW_USBNC_OTG1_PHY_CFG1_RD(x) & ~BM_USBNC_OTG1_PHY_CFG1_TXHSXVTUNE0) | BF_USBNC_OTG1_PHY_CFG1_TXHSXVTUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG1, field TXFSLSTUNE0[19:16] (RW)
 *
 * This bus adjusts the low- and full-speed single-ended source impedance while
 * driving high. The adjustment values listed are based on nominal process,
 * voltage, and temperature conditions.
 *
 * Values:
 * - 0000 - +5%
 * - 0001 - +2.5%
 * - 0011 - Design default
 * - 0111 - -2.5%
 * - 1111 - -5%
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG1_TXFSLSTUNE0 (16U) /*!< Bit position for USBNC_OTG1_PHY_CFG1_TXFSLSTUNE0. */
#define BM_USBNC_OTG1_PHY_CFG1_TXFSLSTUNE0 (0x000F0000U) /*!< Bit mask for USBNC_OTG1_PHY_CFG1_TXFSLSTUNE0. */
#define BS_USBNC_OTG1_PHY_CFG1_TXFSLSTUNE0 (4U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG1_TXFSLSTUNE0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG1_TXFSLSTUNE0 field. */
#define BR_USBNC_OTG1_PHY_CFG1_TXFSLSTUNE0(x) (HW_USBNC_OTG1_PHY_CFG1(x).B.TXFSLSTUNE0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG1_TXFSLSTUNE0. */
#define BF_USBNC_OTG1_PHY_CFG1_TXFSLSTUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG1_TXFSLSTUNE0) & BM_USBNC_OTG1_PHY_CFG1_TXFSLSTUNE0)

/*! @brief Set the TXFSLSTUNE0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG1_TXFSLSTUNE0(x, v) (HW_USBNC_OTG1_PHY_CFG1_WR(x, (HW_USBNC_OTG1_PHY_CFG1_RD(x) & ~BM_USBNC_OTG1_PHY_CFG1_TXFSLSTUNE0) | BF_USBNC_OTG1_PHY_CFG1_TXFSLSTUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG1, field TXVREFTUNE0[23:20] (RW)
 *
 * This bus adjust the high-speed transmitter DC level voltage.
 *
 * Values:
 * - 0000 - -6%
 * - 0001 - -4%
 * - 0010 - -2%
 * - 0011 - Design default
 * - 0100 - +2%
 * - 0101 - +4%
 * - 0110 - +6%
 * - 0111 - +8%
 * - 1000 - +10%
 * - 1001 - +12%
 * - 1010 - +14%
 * - 1011 - +16%
 * - 1100 - +18%
 * - 1101 - +20%
 * - 1110 - +22%
 * - 1111 - +24%
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG1_TXVREFTUNE0 (20U) /*!< Bit position for USBNC_OTG1_PHY_CFG1_TXVREFTUNE0. */
#define BM_USBNC_OTG1_PHY_CFG1_TXVREFTUNE0 (0x00F00000U) /*!< Bit mask for USBNC_OTG1_PHY_CFG1_TXVREFTUNE0. */
#define BS_USBNC_OTG1_PHY_CFG1_TXVREFTUNE0 (4U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG1_TXVREFTUNE0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG1_TXVREFTUNE0 field. */
#define BR_USBNC_OTG1_PHY_CFG1_TXVREFTUNE0(x) (HW_USBNC_OTG1_PHY_CFG1(x).B.TXVREFTUNE0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG1_TXVREFTUNE0. */
#define BF_USBNC_OTG1_PHY_CFG1_TXVREFTUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG1_TXVREFTUNE0) & BM_USBNC_OTG1_PHY_CFG1_TXVREFTUNE0)

/*! @brief Set the TXVREFTUNE0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG1_TXVREFTUNE0(x, v) (HW_USBNC_OTG1_PHY_CFG1_WR(x, (HW_USBNC_OTG1_PHY_CFG1_RD(x) & ~BM_USBNC_OTG1_PHY_CFG1_TXVREFTUNE0) | BF_USBNC_OTG1_PHY_CFG1_TXVREFTUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG1, field TXRISETUNE0[25:24] (RW)
 *
 * This bus adjust the rise/fall times of the high-speed transmitter waveform.
 *
 * Values:
 * - 00 - -10%
 * - 01 - Design default
 * - 10 - +15%
 * - 11 - +20%
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG1_TXRISETUNE0 (24U) /*!< Bit position for USBNC_OTG1_PHY_CFG1_TXRISETUNE0. */
#define BM_USBNC_OTG1_PHY_CFG1_TXRISETUNE0 (0x03000000U) /*!< Bit mask for USBNC_OTG1_PHY_CFG1_TXRISETUNE0. */
#define BS_USBNC_OTG1_PHY_CFG1_TXRISETUNE0 (2U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG1_TXRISETUNE0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG1_TXRISETUNE0 field. */
#define BR_USBNC_OTG1_PHY_CFG1_TXRISETUNE0(x) (HW_USBNC_OTG1_PHY_CFG1(x).B.TXRISETUNE0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG1_TXRISETUNE0. */
#define BF_USBNC_OTG1_PHY_CFG1_TXRISETUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG1_TXRISETUNE0) & BM_USBNC_OTG1_PHY_CFG1_TXRISETUNE0)

/*! @brief Set the TXRISETUNE0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG1_TXRISETUNE0(x, v) (HW_USBNC_OTG1_PHY_CFG1_WR(x, (HW_USBNC_OTG1_PHY_CFG1_RD(x) & ~BM_USBNC_OTG1_PHY_CFG1_TXRISETUNE0) | BF_USBNC_OTG1_PHY_CFG1_TXRISETUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG1, field TXRESTUNE0[27:26] (RW)
 *
 * In some applications, there can be significant series resistance on the USB
 * DP/DN path between the USB_OTG*_DP/USB_OTG*_DN pins tns and the USB cable. This
 * bus adjusts the driver source impedance to compensate for that added
 * resistance. Note: Any setting other than the design default can cause HS/FS signal
 * integrity changes along with variation across process, voltage, and temperature
 * conditions that affect compliance with USB 2.0 specification limits.
 *
 * Values:
 * - 00 - Source impedance is increased by approximately 1.5 ohm
 * - 01 - Design default
 * - 10 - Source impedance is decreased by approximately 2 ohm
 * - 11 - Source impedance is decreased by approximately 4 ohm
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG1_TXRESTUNE0 (26U) /*!< Bit position for USBNC_OTG1_PHY_CFG1_TXRESTUNE0. */
#define BM_USBNC_OTG1_PHY_CFG1_TXRESTUNE0 (0x0C000000U) /*!< Bit mask for USBNC_OTG1_PHY_CFG1_TXRESTUNE0. */
#define BS_USBNC_OTG1_PHY_CFG1_TXRESTUNE0 (2U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG1_TXRESTUNE0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG1_TXRESTUNE0 field. */
#define BR_USBNC_OTG1_PHY_CFG1_TXRESTUNE0(x) (HW_USBNC_OTG1_PHY_CFG1(x).B.TXRESTUNE0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG1_TXRESTUNE0. */
#define BF_USBNC_OTG1_PHY_CFG1_TXRESTUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG1_TXRESTUNE0) & BM_USBNC_OTG1_PHY_CFG1_TXRESTUNE0)

/*! @brief Set the TXRESTUNE0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG1_TXRESTUNE0(x, v) (HW_USBNC_OTG1_PHY_CFG1_WR(x, (HW_USBNC_OTG1_PHY_CFG1_RD(x) & ~BM_USBNC_OTG1_PHY_CFG1_TXRESTUNE0) | BF_USBNC_OTG1_PHY_CFG1_TXRESTUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG1, field TXPREEMPAMPTUNE0[29:28] (RW)
 *
 * This signal controls the amount of current sourced to the USB_OTG*_DP and
 * USB_OTG*_DN pins after a J-to-K or K-to-J transition. The HS Transmitter
 * pre-emphasis current is defined in terms of unit amounts. One unit amount is
 * approximately 600uA and is defined as 1X pre-emphasis current.
 *
 * Values:
 * - 00 - HS Transmitter pre-emphasis is disabled
 * - 01 - HS Transmitter pre-emphasis circuit sources 1X pre-emphasis current
 *     (design default)
 * - 10 - HS Transmitter pre-emphasis circuit sources 2X pre-emphasis current
 * - 11 - HS Transmitter pre-emphasis circuit sources 3X pre-emphasis current
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG1_TXPREEMPAMPTUNE0 (28U) /*!< Bit position for USBNC_OTG1_PHY_CFG1_TXPREEMPAMPTUNE0. */
#define BM_USBNC_OTG1_PHY_CFG1_TXPREEMPAMPTUNE0 (0x30000000U) /*!< Bit mask for USBNC_OTG1_PHY_CFG1_TXPREEMPAMPTUNE0. */
#define BS_USBNC_OTG1_PHY_CFG1_TXPREEMPAMPTUNE0 (2U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG1_TXPREEMPAMPTUNE0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG1_TXPREEMPAMPTUNE0 field. */
#define BR_USBNC_OTG1_PHY_CFG1_TXPREEMPAMPTUNE0(x) (HW_USBNC_OTG1_PHY_CFG1(x).B.TXPREEMPAMPTUNE0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG1_TXPREEMPAMPTUNE0. */
#define BF_USBNC_OTG1_PHY_CFG1_TXPREEMPAMPTUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG1_TXPREEMPAMPTUNE0) & BM_USBNC_OTG1_PHY_CFG1_TXPREEMPAMPTUNE0)

/*! @brief Set the TXPREEMPAMPTUNE0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG1_TXPREEMPAMPTUNE0(x, v) (HW_USBNC_OTG1_PHY_CFG1_WR(x, (HW_USBNC_OTG1_PHY_CFG1_RD(x) & ~BM_USBNC_OTG1_PHY_CFG1_TXPREEMPAMPTUNE0) | BF_USBNC_OTG1_PHY_CFG1_TXPREEMPAMPTUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG1, field TXPREEMPPULSETUNE0[30] (RW)
 *
 * This signal controls the duration for which the HS pre-emphais current is
 * sourced on the the USB_OTG*_DP and USB_OTG*DN pins. The HS Transmitter
 * pre-emphasis duration is defined in terms of unit amounts. One unit of pre-emphasis
 * duration is approximately 580ps and is defined as 1X pre-emphasis duration. This
 * signal is valid only if TXPREEMPAMPTUNE (USBNC_USB_OTGx_PHY_CFG1[29:28]) is NOT
 * set to 2'b00.
 *
 * Values:
 * - 0 - 2X, long pre-emphasis current duration (design default)
 * - 1 - 1X, short pre-emphasis current duration
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG1_TXPREEMPPULSETUNE0 (30U) /*!< Bit position for USBNC_OTG1_PHY_CFG1_TXPREEMPPULSETUNE0. */
#define BM_USBNC_OTG1_PHY_CFG1_TXPREEMPPULSETUNE0 (0x40000000U) /*!< Bit mask for USBNC_OTG1_PHY_CFG1_TXPREEMPPULSETUNE0. */
#define BS_USBNC_OTG1_PHY_CFG1_TXPREEMPPULSETUNE0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG1_TXPREEMPPULSETUNE0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG1_TXPREEMPPULSETUNE0 field. */
#define BR_USBNC_OTG1_PHY_CFG1_TXPREEMPPULSETUNE0(x) (HW_USBNC_OTG1_PHY_CFG1(x).B.TXPREEMPPULSETUNE0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG1_TXPREEMPPULSETUNE0. */
#define BF_USBNC_OTG1_PHY_CFG1_TXPREEMPPULSETUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG1_TXPREEMPPULSETUNE0) & BM_USBNC_OTG1_PHY_CFG1_TXPREEMPPULSETUNE0)

/*! @brief Set the TXPREEMPPULSETUNE0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG1_TXPREEMPPULSETUNE0(x, v) (HW_USBNC_OTG1_PHY_CFG1_WR(x, (HW_USBNC_OTG1_PHY_CFG1_RD(x) & ~BM_USBNC_OTG1_PHY_CFG1_TXPREEMPPULSETUNE0) | BF_USBNC_OTG1_PHY_CFG1_TXPREEMPPULSETUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG1, field CHRGDET_Megamix[31] (RW)
 *
 * This signal controls the state of the USB_OTG1_CHD_B external pin together
 * with the CHRGDET (USBNC_USB_OTG1_PHY_STATUS[29] signal during periods when the
 * SOC is fully powered. If either CHRGDET_Megamix or CHRGDET are set to 1'b1,
 * then USB_OTG1_CHD_B will be pulled low. If both CHRGDET_Megamix and CHRGDET are
 * set to 1'b0, then USB_OTG1_CHD_B will be pulled high by its external open-drain
 * pull-up resistor. Note: The instance of this bit field for the USB OTG2 PHY
 * does not produce results on an external pin. The R/W register bit may still be
 * used as a memory location to store results of Battery Charger detection tests
 * for USB OTG2 PHY.
 *
 * Values:
 * - 0 - The external state of USB_OTG1_CHD_B is only controlled by the state of
 *     the CHRGDET signal
 * - 1 - The external state of USB_OTG1_CHD_B is forced low
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG1_CHRGDET_Megamix (31U) /*!< Bit position for USBNC_OTG1_PHY_CFG1_CHRGDET_Megamix. */
#define BM_USBNC_OTG1_PHY_CFG1_CHRGDET_Megamix (0x80000000U) /*!< Bit mask for USBNC_OTG1_PHY_CFG1_CHRGDET_Megamix. */
#define BS_USBNC_OTG1_PHY_CFG1_CHRGDET_Megamix (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG1_CHRGDET_Megamix. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG1_CHRGDET_Megamix field. */
#define BR_USBNC_OTG1_PHY_CFG1_CHRGDET_Megamix(x) (HW_USBNC_OTG1_PHY_CFG1(x).B.CHRGDET_Megamix)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG1_CHRGDET_Megamix. */
#define BF_USBNC_OTG1_PHY_CFG1_CHRGDET_Megamix(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG1_CHRGDET_Megamix) & BM_USBNC_OTG1_PHY_CFG1_CHRGDET_Megamix)

/*! @brief Set the CHRGDET_Megamix field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG1_CHRGDET_Megamix(x, v) (HW_USBNC_OTG1_PHY_CFG1_WR(x, (HW_USBNC_OTG1_PHY_CFG1_RD(x) & ~BM_USBNC_OTG1_PHY_CFG1_CHRGDET_Megamix) | BF_USBNC_OTG1_PHY_CFG1_CHRGDET_Megamix(v)))
/*@}*/

/*******************************************************************************
 * HW_USBNC_OTG1_PHY_CFG2 - USB OTG PHY Configuration Register 2
 ******************************************************************************/

/*!
 * @brief HW_USBNC_OTG1_PHY_CFG2 - USB OTG PHY Configuration Register 2 (RW)
 *
 * Reset value: 0xF0010020U
 *
 * The USB_OTGx_PHY_CFG2 register allows control of selected inputs to the USB
 * OTG PHY. Most of these signals are used for configuration of VBUS detection,
 * ADP (Attach Detection Protocol), and Battery Charging ACA (Accesory Charging
 * Adaptor) functions.
 */
typedef union _hw_usbnc_otg1_phy_cfg2
{
    uint32_t U;
    struct _hw_usbnc_otg1_phy_cfg2_bitfields
    {
        uint32_t CHRGSEL : 1;          /*!< [0] Battery Charging Source Select */
        uint32_t VDATDETENB0 : 1;      /*!< [1] Battery Charging Attach / Connect
                                        * Detection Enable */
        uint32_t VDATSRCENB0 : 1;      /*!< [2] Battery Charging Source Select */
        uint32_t DCDENB : 1;           /*!< [3] Data Contact Detection Enable */
        uint32_t ACAENB0 : 1;          /*!< [4] ACA USB_OTG*_ID Pin Resistance
                                        * Detection Enable */
        uint32_t SLEEPM0 : 1;          /*!< [5] Sleep Mode Assertion */
        uint32_t LOOPBACKENB0 : 1;     /*!< [6] Loopback Test Enable */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t TXBITSTUFFEN0 : 1;    /*!< [8] Low-Byte Transmit Bit-Stuffing
                                        * Enable */
        uint32_t TXBITSTUFFENH0 : 1;   /*!< [9] High-Byte Transmit Bit-Stuffing
                                        * Enable */
        uint32_t OTGDISABLE0 : 1;      /*!< [10] OTG Block Disable */
        uint32_t ADPCHRG0 : 1;         /*!< [11] VBUS Input ADP Charge Enable */
        uint32_t ADPDISCHRG0 : 1;      /*!< [12] VBUS Input ADP Discharge Enable */
        uint32_t ADPPRBENB0 : 1;       /*!< [13] ADP Probe Enable */
        uint32_t VBUSVLDEXTSEL0 : 1;   /*!< [14] External VBUS Valid Select */
        uint32_t VBUSVLDEXT : 1;       /*!< [15] External VBUS Valid Indicator */
        uint32_t DRVVBUS0 : 1;         /*!< [16] VBUS Valid Comparator Enable */
        uint32_t RESERVED1 : 15;       /*!< [31:17]  */
    } B;
} hw_usbnc_otg1_phy_cfg2_t;

/*!
 * @name Constants and macros for entire USBNC_OTG1_PHY_CFG2 register
 */
/*@{*/
#define HW_USBNC_OTG1_PHY_CFG2_ADDR(x) ((uintptr_t)(x) + 0x234U)

#define HW_USBNC_OTG1_PHY_CFG2(x) (*(__IO hw_usbnc_otg1_phy_cfg2_t *) HW_USBNC_OTG1_PHY_CFG2_ADDR(x))
#define HW_USBNC_OTG1_PHY_CFG2_RD(x) (HW_USBNC_OTG1_PHY_CFG2(x).U)
#define HW_USBNC_OTG1_PHY_CFG2_WR(x, v) (HW_USBNC_OTG1_PHY_CFG2(x).U = (v))
#define HW_USBNC_OTG1_PHY_CFG2_SET(x, v) (HW_USBNC_OTG1_PHY_CFG2_WR(x, HW_USBNC_OTG1_PHY_CFG2_RD(x) |  (v)))
#define HW_USBNC_OTG1_PHY_CFG2_CLR(x, v) (HW_USBNC_OTG1_PHY_CFG2_WR(x, HW_USBNC_OTG1_PHY_CFG2_RD(x) & ~(v)))
#define HW_USBNC_OTG1_PHY_CFG2_TOG(x, v) (HW_USBNC_OTG1_PHY_CFG2_WR(x, HW_USBNC_OTG1_PHY_CFG2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBNC_OTG1_PHY_CFG2 bitfields
 */

/*!
 * @name Register USBNC_OTG1_PHY_CFG2, field CHRGSEL[0] (RW)
 *
 * This signal is used to select the Battery Charging detection connections per
 * the USB Battery Charging Specification revision 1.2. It determines which of
 * USB_OTG*_DP / USB_OTG*_DN has the VD*_SRC voltage source and which has the
 * ID*_SINK current sink. Results are reported in USBNC_USB_OTGx_PHY_STATUS[29]. Note:
 * During normal USB operation of the USB OTG PHY, set this signal to 1'b0.
 *
 * Values:
 * - 0 - VDP_SRC is connected to USB_OTG*_DP and IDM_SINK is connected to
 *     USB_OTG*_DN. Used for Primary Detection.
 * - 1 - VDM_SRC is connected to USB_OTG*_DN and IDP_SINK is connected to
 *     USB_OTG*_DP. Used for Secondary Detection.
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG2_CHRGSEL (0U) /*!< Bit position for USBNC_OTG1_PHY_CFG2_CHRGSEL. */
#define BM_USBNC_OTG1_PHY_CFG2_CHRGSEL (0x00000001U) /*!< Bit mask for USBNC_OTG1_PHY_CFG2_CHRGSEL. */
#define BS_USBNC_OTG1_PHY_CFG2_CHRGSEL (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG2_CHRGSEL. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG2_CHRGSEL field. */
#define BR_USBNC_OTG1_PHY_CFG2_CHRGSEL(x) (HW_USBNC_OTG1_PHY_CFG2(x).B.CHRGSEL)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG2_CHRGSEL. */
#define BF_USBNC_OTG1_PHY_CFG2_CHRGSEL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG2_CHRGSEL) & BM_USBNC_OTG1_PHY_CFG2_CHRGSEL)

/*! @brief Set the CHRGSEL field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG2_CHRGSEL(x, v) (HW_USBNC_OTG1_PHY_CFG2_WR(x, (HW_USBNC_OTG1_PHY_CFG2_RD(x) & ~BM_USBNC_OTG1_PHY_CFG2_CHRGSEL) | BF_USBNC_OTG1_PHY_CFG2_CHRGSEL(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG2, field VDATDETENB0[1] (RW)
 *
 * This signal is used to enable attach/connect detection per the USB Battery
 * Charging Specification revision 1.2. Results are reported by using the
 * single-ended receiver status in USBNC_USB_OTGx_PHY_STATUS[1:0]. Note: During normal USB
 * operation of the USB OTG PHY, set this signal to 1'b0.
 *
 * Values:
 * - 0 - IDP_SRC current source compliant to VLGC_HI connected to USB_OTG*_DP
 *     pin is disabled
 * - 1 - IDP_SRC current source compliant to VLGC_HI connected to USB_OTG*_DP
 *     pin is enabled
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG2_VDATDETENB0 (1U) /*!< Bit position for USBNC_OTG1_PHY_CFG2_VDATDETENB0. */
#define BM_USBNC_OTG1_PHY_CFG2_VDATDETENB0 (0x00000002U) /*!< Bit mask for USBNC_OTG1_PHY_CFG2_VDATDETENB0. */
#define BS_USBNC_OTG1_PHY_CFG2_VDATDETENB0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG2_VDATDETENB0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG2_VDATDETENB0 field. */
#define BR_USBNC_OTG1_PHY_CFG2_VDATDETENB0(x) (HW_USBNC_OTG1_PHY_CFG2(x).B.VDATDETENB0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG2_VDATDETENB0. */
#define BF_USBNC_OTG1_PHY_CFG2_VDATDETENB0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG2_VDATDETENB0) & BM_USBNC_OTG1_PHY_CFG2_VDATDETENB0)

/*! @brief Set the VDATDETENB0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG2_VDATDETENB0(x, v) (HW_USBNC_OTG1_PHY_CFG2_WR(x, (HW_USBNC_OTG1_PHY_CFG2_RD(x) & ~BM_USBNC_OTG1_PHY_CFG2_VDATDETENB0) | BF_USBNC_OTG1_PHY_CFG2_VDATDETENB0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG2, field VDATSRCENB0[2] (RW)
 *
 * This signal is used to enable the VD*_SRC voltage source and ID*SINK current
 * sink per the USB Battery Charging Specification revision 1.2. Pin selection
 * for the voltage source and the current sink are controlled by
 * USBNC_USB_OTGx_PHY_CFG2[0]. Note: During normal USB operation of the USB OTG PHY, set this
 * signal to 1'b0.
 *
 * Values:
 * - 0 - VD*_SRC and ID*_SINK are disabled
 * - 1 - VD*_SRC and ID*_SINK are enabled
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG2_VDATSRCENB0 (2U) /*!< Bit position for USBNC_OTG1_PHY_CFG2_VDATSRCENB0. */
#define BM_USBNC_OTG1_PHY_CFG2_VDATSRCENB0 (0x00000004U) /*!< Bit mask for USBNC_OTG1_PHY_CFG2_VDATSRCENB0. */
#define BS_USBNC_OTG1_PHY_CFG2_VDATSRCENB0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG2_VDATSRCENB0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG2_VDATSRCENB0 field. */
#define BR_USBNC_OTG1_PHY_CFG2_VDATSRCENB0(x) (HW_USBNC_OTG1_PHY_CFG2(x).B.VDATSRCENB0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG2_VDATSRCENB0. */
#define BF_USBNC_OTG1_PHY_CFG2_VDATSRCENB0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG2_VDATSRCENB0) & BM_USBNC_OTG1_PHY_CFG2_VDATSRCENB0)

/*! @brief Set the VDATSRCENB0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG2_VDATSRCENB0(x, v) (HW_USBNC_OTG1_PHY_CFG2_WR(x, (HW_USBNC_OTG1_PHY_CFG2_RD(x) & ~BM_USBNC_OTG1_PHY_CFG2_VDATSRCENB0) | BF_USBNC_OTG1_PHY_CFG2_VDATSRCENB0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG2, field DCDENB[3] (RW)
 *
 * This signal enables current sourcing on the USB_OTG*_DP pin and pull-down
 * resistaince on the USB_OTG*_DN pin for Data Contact Detect (DCD) per the USB
 * Battery Charging Specification revision 1.2. Note: During normal USB operation of
 * the USB OTG PHY, set this signal to 1'b0.
 *
 * Values:
 * - 0 - IDP_SRC current and RDM_DWN pull-down resistance are disabled
 * - 1 - IDP_SRC current and RDM_DWN pull-down resistance are enabled
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG2_DCDENB (3U) /*!< Bit position for USBNC_OTG1_PHY_CFG2_DCDENB. */
#define BM_USBNC_OTG1_PHY_CFG2_DCDENB (0x00000008U) /*!< Bit mask for USBNC_OTG1_PHY_CFG2_DCDENB. */
#define BS_USBNC_OTG1_PHY_CFG2_DCDENB (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG2_DCDENB. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG2_DCDENB field. */
#define BR_USBNC_OTG1_PHY_CFG2_DCDENB(x) (HW_USBNC_OTG1_PHY_CFG2(x).B.DCDENB)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG2_DCDENB. */
#define BF_USBNC_OTG1_PHY_CFG2_DCDENB(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG2_DCDENB) & BM_USBNC_OTG1_PHY_CFG2_DCDENB)

/*! @brief Set the DCDENB field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG2_DCDENB(x, v) (HW_USBNC_OTG1_PHY_CFG2_WR(x, (HW_USBNC_OTG1_PHY_CFG2_RD(x) & ~BM_USBNC_OTG1_PHY_CFG2_DCDENB) | BF_USBNC_OTG1_PHY_CFG2_DCDENB(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG2, field ACAENB0[4] (RW)
 *
 * This signal enables the circuitry to detect resistance on the USB_OTG*_ID pin
 * if the USB cable is connected to an ACA (Acessory Charger Adaptor). When
 * ACAENB0 is set to 1'b1, IDPULLUP0 (USB_OTGSC[26]) is overridden and set to 1'b0
 * internally to the USB OTG PHY. The RID* results are reported in
 * USBNC_USB_OTGx_PHY_STATUS[28:24].
 *
 * Values:
 * - 0 - Disables detection of resistance on the USB_OTG*_ID pin
 * - 1 - Enables detection of resistance on the USB_OTG*_ID pin
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG2_ACAENB0 (4U) /*!< Bit position for USBNC_OTG1_PHY_CFG2_ACAENB0. */
#define BM_USBNC_OTG1_PHY_CFG2_ACAENB0 (0x00000010U) /*!< Bit mask for USBNC_OTG1_PHY_CFG2_ACAENB0. */
#define BS_USBNC_OTG1_PHY_CFG2_ACAENB0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG2_ACAENB0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG2_ACAENB0 field. */
#define BR_USBNC_OTG1_PHY_CFG2_ACAENB0(x) (HW_USBNC_OTG1_PHY_CFG2(x).B.ACAENB0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG2_ACAENB0. */
#define BF_USBNC_OTG1_PHY_CFG2_ACAENB0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG2_ACAENB0) & BM_USBNC_OTG1_PHY_CFG2_ACAENB0)

/*! @brief Set the ACAENB0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG2_ACAENB0(x, v) (HW_USBNC_OTG1_PHY_CFG2_WR(x, (HW_USBNC_OTG1_PHY_CFG2_RD(x) & ~BM_USBNC_OTG1_PHY_CFG2_ACAENB0) | BF_USBNC_OTG1_PHY_CFG2_ACAENB0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG2, field SLEEPM0[5] (RW)
 *
 * Asserting this signal places the USB OTG PHY in Sleep mode accourding to the
 * USB 2.0 Link Power Management (LPM) addendum to the USB 2.0 specification. In
 * Sleep mode, the transmitter is tri-stated and the USB OTG PHY circuits used in
 * this SOC are powered down. Note:The USB controller used in this SOC does not
 * support LPM operation. Leave this bit set to 1'b1 for normal operation.
 *
 * Values:
 * - 0 - Sleep mode
 * - 1 - Normal operating mode
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG2_SLEEPM0 (5U) /*!< Bit position for USBNC_OTG1_PHY_CFG2_SLEEPM0. */
#define BM_USBNC_OTG1_PHY_CFG2_SLEEPM0 (0x00000020U) /*!< Bit mask for USBNC_OTG1_PHY_CFG2_SLEEPM0. */
#define BS_USBNC_OTG1_PHY_CFG2_SLEEPM0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG2_SLEEPM0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG2_SLEEPM0 field. */
#define BR_USBNC_OTG1_PHY_CFG2_SLEEPM0(x) (HW_USBNC_OTG1_PHY_CFG2(x).B.SLEEPM0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG2_SLEEPM0. */
#define BF_USBNC_OTG1_PHY_CFG2_SLEEPM0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG2_SLEEPM0) & BM_USBNC_OTG1_PHY_CFG2_SLEEPM0)

/*! @brief Set the SLEEPM0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG2_SLEEPM0(x, v) (HW_USBNC_OTG1_PHY_CFG2_WR(x, (HW_USBNC_OTG1_PHY_CFG2_RD(x) & ~BM_USBNC_OTG1_PHY_CFG2_SLEEPM0) | BF_USBNC_OTG1_PHY_CFG2_SLEEPM0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG2, field LOOPBACKENB0[6] (RW)
 *
 * This signal places the USB OTG PHY in Loopback mode, which enables the
 * receive and transmit logic concurrently. Loopback mode is for test purposes only; it
 * cannot be used for normal operation.
 *
 * Values:
 * - 0 - During data transmission, the receive logic is disabled
 * - 1 - During data transmission, the receive logic is enabled
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG2_LOOPBACKENB0 (6U) /*!< Bit position for USBNC_OTG1_PHY_CFG2_LOOPBACKENB0. */
#define BM_USBNC_OTG1_PHY_CFG2_LOOPBACKENB0 (0x00000040U) /*!< Bit mask for USBNC_OTG1_PHY_CFG2_LOOPBACKENB0. */
#define BS_USBNC_OTG1_PHY_CFG2_LOOPBACKENB0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG2_LOOPBACKENB0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG2_LOOPBACKENB0 field. */
#define BR_USBNC_OTG1_PHY_CFG2_LOOPBACKENB0(x) (HW_USBNC_OTG1_PHY_CFG2(x).B.LOOPBACKENB0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG2_LOOPBACKENB0. */
#define BF_USBNC_OTG1_PHY_CFG2_LOOPBACKENB0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG2_LOOPBACKENB0) & BM_USBNC_OTG1_PHY_CFG2_LOOPBACKENB0)

/*! @brief Set the LOOPBACKENB0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG2_LOOPBACKENB0(x, v) (HW_USBNC_OTG1_PHY_CFG2_WR(x, (HW_USBNC_OTG1_PHY_CFG2_RD(x) & ~BM_USBNC_OTG1_PHY_CFG2_LOOPBACKENB0) | BF_USBNC_OTG1_PHY_CFG2_LOOPBACKENB0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG2, field TXBITSTUFFEN0[8] (RW)
 *
 * This controller signal controls bit stuffing on DATAIN[7:0] when OPMODE[1:0]
 * = 2'b11. For more information on the use of this setting see UTMI+
 * Specification Section 2.2.1.12 .
 *
 * Values:
 * - 0 - Bit stuffing is disabled
 * - 1 - Bit stuffing is enabled
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG2_TXBITSTUFFEN0 (8U) /*!< Bit position for USBNC_OTG1_PHY_CFG2_TXBITSTUFFEN0. */
#define BM_USBNC_OTG1_PHY_CFG2_TXBITSTUFFEN0 (0x00000100U) /*!< Bit mask for USBNC_OTG1_PHY_CFG2_TXBITSTUFFEN0. */
#define BS_USBNC_OTG1_PHY_CFG2_TXBITSTUFFEN0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG2_TXBITSTUFFEN0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG2_TXBITSTUFFEN0 field. */
#define BR_USBNC_OTG1_PHY_CFG2_TXBITSTUFFEN0(x) (HW_USBNC_OTG1_PHY_CFG2(x).B.TXBITSTUFFEN0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG2_TXBITSTUFFEN0. */
#define BF_USBNC_OTG1_PHY_CFG2_TXBITSTUFFEN0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG2_TXBITSTUFFEN0) & BM_USBNC_OTG1_PHY_CFG2_TXBITSTUFFEN0)

/*! @brief Set the TXBITSTUFFEN0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG2_TXBITSTUFFEN0(x, v) (HW_USBNC_OTG1_PHY_CFG2_WR(x, (HW_USBNC_OTG1_PHY_CFG2_RD(x) & ~BM_USBNC_OTG1_PHY_CFG2_TXBITSTUFFEN0) | BF_USBNC_OTG1_PHY_CFG2_TXBITSTUFFEN0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG2, field TXBITSTUFFENH0[9] (RW)
 *
 * This controller signal controls bit stuffing on DATAINH[7:0] when OPMODE[1:0]
 * = 2'b11. For more information on the use of this setting see UTMI+
 * Specification Section 2.2.1.12 .
 *
 * Values:
 * - 0 - Bit stuffing is disabled
 * - 1 - Bit stuffing is enabled
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG2_TXBITSTUFFENH0 (9U) /*!< Bit position for USBNC_OTG1_PHY_CFG2_TXBITSTUFFENH0. */
#define BM_USBNC_OTG1_PHY_CFG2_TXBITSTUFFENH0 (0x00000200U) /*!< Bit mask for USBNC_OTG1_PHY_CFG2_TXBITSTUFFENH0. */
#define BS_USBNC_OTG1_PHY_CFG2_TXBITSTUFFENH0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG2_TXBITSTUFFENH0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG2_TXBITSTUFFENH0 field. */
#define BR_USBNC_OTG1_PHY_CFG2_TXBITSTUFFENH0(x) (HW_USBNC_OTG1_PHY_CFG2(x).B.TXBITSTUFFENH0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG2_TXBITSTUFFENH0. */
#define BF_USBNC_OTG1_PHY_CFG2_TXBITSTUFFENH0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG2_TXBITSTUFFENH0) & BM_USBNC_OTG1_PHY_CFG2_TXBITSTUFFENH0)

/*! @brief Set the TXBITSTUFFENH0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG2_TXBITSTUFFENH0(x, v) (HW_USBNC_OTG1_PHY_CFG2_WR(x, (HW_USBNC_OTG1_PHY_CFG2_RD(x) & ~BM_USBNC_OTG1_PHY_CFG2_TXBITSTUFFENH0) | BF_USBNC_OTG1_PHY_CFG2_TXBITSTUFFENH0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG2, field OTGDISABLE0[10] (RW)
 *
 * This signal powers down the VBUS Valid comparator. It does not control power
 * to the Session Valid comparator, ADP Probe and Sense comparators, or the ID
 * detection circuitry.
 *
 * Values:
 * - 0 - The OTG block is powered up
 * - 1 - The OTG block is powered down
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG2_OTGDISABLE0 (10U) /*!< Bit position for USBNC_OTG1_PHY_CFG2_OTGDISABLE0. */
#define BM_USBNC_OTG1_PHY_CFG2_OTGDISABLE0 (0x00000400U) /*!< Bit mask for USBNC_OTG1_PHY_CFG2_OTGDISABLE0. */
#define BS_USBNC_OTG1_PHY_CFG2_OTGDISABLE0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG2_OTGDISABLE0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG2_OTGDISABLE0 field. */
#define BR_USBNC_OTG1_PHY_CFG2_OTGDISABLE0(x) (HW_USBNC_OTG1_PHY_CFG2(x).B.OTGDISABLE0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG2_OTGDISABLE0. */
#define BF_USBNC_OTG1_PHY_CFG2_OTGDISABLE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG2_OTGDISABLE0) & BM_USBNC_OTG1_PHY_CFG2_OTGDISABLE0)

/*! @brief Set the OTGDISABLE0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG2_OTGDISABLE0(x, v) (HW_USBNC_OTG1_PHY_CFG2_WR(x, (HW_USBNC_OTG1_PHY_CFG2_RD(x) & ~BM_USBNC_OTG1_PHY_CFG2_OTGDISABLE0) | BF_USBNC_OTG1_PHY_CFG2_OTGDISABLE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG2, field ADPCHRG0[11] (RW)
 *
 * This signal controls charging the USB_OTG*_VBUS pin during ADP. The IADP_SRC
 * current is >1.1mA and <1.65mA.
 *
 * Values:
 * - 0 - Disables charging USB_OTG*_VBUS during ADP
 * - 1 - Disables charging USB_OTG*_VBUS during ADP
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG2_ADPCHRG0 (11U) /*!< Bit position for USBNC_OTG1_PHY_CFG2_ADPCHRG0. */
#define BM_USBNC_OTG1_PHY_CFG2_ADPCHRG0 (0x00000800U) /*!< Bit mask for USBNC_OTG1_PHY_CFG2_ADPCHRG0. */
#define BS_USBNC_OTG1_PHY_CFG2_ADPCHRG0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG2_ADPCHRG0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG2_ADPCHRG0 field. */
#define BR_USBNC_OTG1_PHY_CFG2_ADPCHRG0(x) (HW_USBNC_OTG1_PHY_CFG2(x).B.ADPCHRG0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG2_ADPCHRG0. */
#define BF_USBNC_OTG1_PHY_CFG2_ADPCHRG0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG2_ADPCHRG0) & BM_USBNC_OTG1_PHY_CFG2_ADPCHRG0)

/*! @brief Set the ADPCHRG0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG2_ADPCHRG0(x, v) (HW_USBNC_OTG1_PHY_CFG2_WR(x, (HW_USBNC_OTG1_PHY_CFG2_RD(x) & ~BM_USBNC_OTG1_PHY_CFG2_ADPCHRG0) | BF_USBNC_OTG1_PHY_CFG2_ADPCHRG0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG2, field ADPDISCHRG0[12] (RW)
 *
 * This signal controls discharging the USB_OTG*_VBUS pin during ADP. The
 * IADP_SINK current is >1.1mA and <2.0mA.
 *
 * Values:
 * - 0 - Disables discharging USB_OTG*_VBUS during ADP
 * - 1 - Enables discharging USB_OTG*_VBUS during ADP
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG2_ADPDISCHRG0 (12U) /*!< Bit position for USBNC_OTG1_PHY_CFG2_ADPDISCHRG0. */
#define BM_USBNC_OTG1_PHY_CFG2_ADPDISCHRG0 (0x00001000U) /*!< Bit mask for USBNC_OTG1_PHY_CFG2_ADPDISCHRG0. */
#define BS_USBNC_OTG1_PHY_CFG2_ADPDISCHRG0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG2_ADPDISCHRG0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG2_ADPDISCHRG0 field. */
#define BR_USBNC_OTG1_PHY_CFG2_ADPDISCHRG0(x) (HW_USBNC_OTG1_PHY_CFG2(x).B.ADPDISCHRG0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG2_ADPDISCHRG0. */
#define BF_USBNC_OTG1_PHY_CFG2_ADPDISCHRG0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG2_ADPDISCHRG0) & BM_USBNC_OTG1_PHY_CFG2_ADPDISCHRG0)

/*! @brief Set the ADPDISCHRG0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG2_ADPDISCHRG0(x, v) (HW_USBNC_OTG1_PHY_CFG2_WR(x, (HW_USBNC_OTG1_PHY_CFG2_RD(x) & ~BM_USBNC_OTG1_PHY_CFG2_ADPDISCHRG0) | BF_USBNC_OTG1_PHY_CFG2_ADPDISCHRG0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG2, field ADPPRBENB0[13] (RW)
 *
 * This signal determines whether the ADP (Attach Detection Protocol) Probe
 * comparator on the USB_OTG*_VBUS pin is enabled. The ADP Probe threshold is > 0.6V
 * and < 0.75V on this USB PHY.
 *
 * Values:
 * - 0 - ADP Probe comparator is disabled
 * - 1 - ADP Probe comparator is enabled
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG2_ADPPRBENB0 (13U) /*!< Bit position for USBNC_OTG1_PHY_CFG2_ADPPRBENB0. */
#define BM_USBNC_OTG1_PHY_CFG2_ADPPRBENB0 (0x00002000U) /*!< Bit mask for USBNC_OTG1_PHY_CFG2_ADPPRBENB0. */
#define BS_USBNC_OTG1_PHY_CFG2_ADPPRBENB0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG2_ADPPRBENB0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG2_ADPPRBENB0 field. */
#define BR_USBNC_OTG1_PHY_CFG2_ADPPRBENB0(x) (HW_USBNC_OTG1_PHY_CFG2(x).B.ADPPRBENB0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG2_ADPPRBENB0. */
#define BF_USBNC_OTG1_PHY_CFG2_ADPPRBENB0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG2_ADPPRBENB0) & BM_USBNC_OTG1_PHY_CFG2_ADPPRBENB0)

/*! @brief Set the ADPPRBENB0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG2_ADPPRBENB0(x, v) (HW_USBNC_OTG1_PHY_CFG2_WR(x, (HW_USBNC_OTG1_PHY_CFG2_RD(x) & ~BM_USBNC_OTG1_PHY_CFG2_ADPPRBENB0) | BF_USBNC_OTG1_PHY_CFG2_ADPPRBENB0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG2, field VBUSVLDEXTSEL0[14] (RW)
 *
 * This signal selects whether the VBUSVLDEXT input
 * (USBNC_USB_OTGx_PHY_CFG2[15]) or the internal Session Valid comparator in the USB OTG PHY is used to check
 * if the VBUS signal on USB_OTG*_VBUS is valid and to enable the pull-up
 * resistor on the USB_OTG*_DP pin. The activation of the pull-up resistor on the
 * USB_OTG*_DP pin also depends on the state of the XCVRSEL, OPMODE, TERMSEL,
 * DPPULLDOWN, and DMPULLDOWN signals in the UTMI bus per the UTMI+ specification.
 *
 * Values:
 * - 0 - The USB OTG PHY internal Session Valid comparator is used to enable the
 *     pull-up resistor on the USB_OTG*_DP pin
 * - 1 - The VBUSVLDEXT signal is used to enable the pull-up resistor on the
 *     USB_OTG*_DP pin
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG2_VBUSVLDEXTSEL0 (14U) /*!< Bit position for USBNC_OTG1_PHY_CFG2_VBUSVLDEXTSEL0. */
#define BM_USBNC_OTG1_PHY_CFG2_VBUSVLDEXTSEL0 (0x00004000U) /*!< Bit mask for USBNC_OTG1_PHY_CFG2_VBUSVLDEXTSEL0. */
#define BS_USBNC_OTG1_PHY_CFG2_VBUSVLDEXTSEL0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG2_VBUSVLDEXTSEL0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG2_VBUSVLDEXTSEL0 field. */
#define BR_USBNC_OTG1_PHY_CFG2_VBUSVLDEXTSEL0(x) (HW_USBNC_OTG1_PHY_CFG2(x).B.VBUSVLDEXTSEL0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG2_VBUSVLDEXTSEL0. */
#define BF_USBNC_OTG1_PHY_CFG2_VBUSVLDEXTSEL0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG2_VBUSVLDEXTSEL0) & BM_USBNC_OTG1_PHY_CFG2_VBUSVLDEXTSEL0)

/*! @brief Set the VBUSVLDEXTSEL0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG2_VBUSVLDEXTSEL0(x, v) (HW_USBNC_OTG1_PHY_CFG2_WR(x, (HW_USBNC_OTG1_PHY_CFG2_RD(x) & ~BM_USBNC_OTG1_PHY_CFG2_VBUSVLDEXTSEL0) | BF_USBNC_OTG1_PHY_CFG2_VBUSVLDEXTSEL0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG2, field VBUSVLDEXT[15] (RW)
 *
 * This signal is used if a VBUS Valid signal generated from a circuit outside
 * the USB OTG PHY is desired. If the USB OTG PHY is configured for Device mode
 * and VBUSVLDEXTSEL0 (USBNC_USB_OTGx_PHY_CFG2[14] is set to 1'b1, VBUSVLD
 * indicated whether the VBUS signal on the USB cable is valid and enables the pull-up
 * resistor on USB_OTG1_DP. This signal has no effect when the USB OTG PHY is
 * configured for Host mode.
 *
 * Values:
 * - 0 - The VBUS signal sensed outside the USB OTG PHY is not valid, and the
 *     pull-up resistor on USB_OTG*_DP is disabled
 * - 1 - The VBUS signal sensed outside the USB OTG PHY is valid, and the
 *     pull-up resistor on USB_OTG*_DP is enabled
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG2_VBUSVLDEXT (15U) /*!< Bit position for USBNC_OTG1_PHY_CFG2_VBUSVLDEXT. */
#define BM_USBNC_OTG1_PHY_CFG2_VBUSVLDEXT (0x00008000U) /*!< Bit mask for USBNC_OTG1_PHY_CFG2_VBUSVLDEXT. */
#define BS_USBNC_OTG1_PHY_CFG2_VBUSVLDEXT (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG2_VBUSVLDEXT. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG2_VBUSVLDEXT field. */
#define BR_USBNC_OTG1_PHY_CFG2_VBUSVLDEXT(x) (HW_USBNC_OTG1_PHY_CFG2(x).B.VBUSVLDEXT)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG2_VBUSVLDEXT. */
#define BF_USBNC_OTG1_PHY_CFG2_VBUSVLDEXT(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG2_VBUSVLDEXT) & BM_USBNC_OTG1_PHY_CFG2_VBUSVLDEXT)

/*! @brief Set the VBUSVLDEXT field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG2_VBUSVLDEXT(x, v) (HW_USBNC_OTG1_PHY_CFG2_WR(x, (HW_USBNC_OTG1_PHY_CFG2_RD(x) & ~BM_USBNC_OTG1_PHY_CFG2_VBUSVLDEXT) | BF_USBNC_OTG1_PHY_CFG2_VBUSVLDEXT(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_CFG2, field DRVVBUS0[16] (RW)
 *
 * This signal controls the USB OTG PHY VBUS Valid comparator which indicates
 * whether the voltage on the USB_OTG*_VBUS pin is below the VBUS Valid threshold.
 * The VBUS Valid threshold is nominally 4.75V on this USB PHY. The VBUS Valid
 * threshold can be adjusted using the USBNC_OTGn_PHY_CFG1[OTGTUNE0] bit field.
 * Status of the VBUS Valid comparator, when it is enabled, is reported on the
 * USBNC_OTGn_PHY_STATUS[VBUS_VLD] bit. When OTGDISABLE0
 * (USBNC_USB_OTGx_PHY_CFG2[10])is set to 1'b0 and DRVVBUS0 is set to 1'b1, the Bandgap circuitry and VBUS
 * Valid comparator are powered, even in Suspend or Sleep mode. DRVVBUS0 should be
 * reset to 1'b0 when the internal VBUS Valid comparator is not required, to
 * reduce quiescent current in Suspend or Sleep mode.
 *
 * Values:
 * - 0 - The VBUS Valid comparator is disabled
 * - 1 - The VBUS Valid comparator is enabled
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_CFG2_DRVVBUS0 (16U) /*!< Bit position for USBNC_OTG1_PHY_CFG2_DRVVBUS0. */
#define BM_USBNC_OTG1_PHY_CFG2_DRVVBUS0 (0x00010000U) /*!< Bit mask for USBNC_OTG1_PHY_CFG2_DRVVBUS0. */
#define BS_USBNC_OTG1_PHY_CFG2_DRVVBUS0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_CFG2_DRVVBUS0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_CFG2_DRVVBUS0 field. */
#define BR_USBNC_OTG1_PHY_CFG2_DRVVBUS0(x) (HW_USBNC_OTG1_PHY_CFG2(x).B.DRVVBUS0)

/*! @brief Format value for bitfield USBNC_OTG1_PHY_CFG2_DRVVBUS0. */
#define BF_USBNC_OTG1_PHY_CFG2_DRVVBUS0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG1_PHY_CFG2_DRVVBUS0) & BM_USBNC_OTG1_PHY_CFG2_DRVVBUS0)

/*! @brief Set the DRVVBUS0 field to a new value. */
#define BW_USBNC_OTG1_PHY_CFG2_DRVVBUS0(x, v) (HW_USBNC_OTG1_PHY_CFG2_WR(x, (HW_USBNC_OTG1_PHY_CFG2_RD(x) & ~BM_USBNC_OTG1_PHY_CFG2_DRVVBUS0) | BF_USBNC_OTG1_PHY_CFG2_DRVVBUS0(v)))
/*@}*/

/*******************************************************************************
 * HW_USBNC_OTG1_PHY_STATUS - USB OTG PHY Status Register
 ******************************************************************************/

/*!
 * @brief HW_USBNC_OTG1_PHY_STATUS - USB OTG PHY Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The USB_OTGx_PHY_STATUS register allows visibility of selected outputs of the
 * USB OTG PHY. These signals are used for some VBUS detection, ADP (Attach
 * Detection Protocol), and Battery Charging ACA (Accesory Charging Adaptor)
 * functions.
 */
typedef union _hw_usbnc_otg1_phy_status
{
    uint32_t U;
    struct _hw_usbnc_otg1_phy_status_bitfields
    {
        uint32_t LINE_STATE : 2;       /*!< [1:0] Line State Indicator outputs from
                                        * USB OTG PHY */
        uint32_t SESS_VLD : 1;         /*!< [2] OTG Device Session Valid Indicator
                                        * from USB OTG PHY */
        uint32_t VBUS_VLD : 1;         /*!< [3] VBUS Valid Indicator from USB OTG PHY
                                        * */
        uint32_t ID_DIG : 1;           /*!< [4] Micro- or Mini- A/B Plug Indicator */
        uint32_t HOST_DISCONNECT : 1;  /*!< [5] Peripheral Disconnect
                                        * Indicator */
        uint32_t RESERVED0 : 18;       /*!< [23:6]  */
        uint32_t RIDC0 : 1;            /*!< [24] ACA USB_OTG*_ID Pin Resistance
                                        * Indicator */
        uint32_t RIDB0 : 1;            /*!< [25] ACA USB_OTG*_ID Pin Resistance
                                        * Indicator */
        uint32_t RIDA0 : 1;            /*!< [26] ACA USB_OTG*_ID Pin Resistance
                                        * Indicator */
        uint32_t RIDGND0 : 1;          /*!< [27] ACA USB_OTG*_ID Pin Resistance
                                        * Indicator */
        uint32_t RIDFLOAT0 : 1;        /*!< [28] ACA USB_OTG*_ID Pin Resistance
                                        * Indicator */
        uint32_t CHRGDET : 1;          /*!< [29] Battery Charger Detection Output */
        uint32_t ADPPRB0 : 1;          /*!< [30] ADP Probe Indicator */
        uint32_t ADPSNS0 : 1;          /*!< [31] ADP Sense Indicator */
    } B;
} hw_usbnc_otg1_phy_status_t;

/*!
 * @name Constants and macros for entire USBNC_OTG1_PHY_STATUS register
 */
/*@{*/
#define HW_USBNC_OTG1_PHY_STATUS_ADDR(x) ((uintptr_t)(x) + 0x23CU)

#define HW_USBNC_OTG1_PHY_STATUS(x) (*(__I hw_usbnc_otg1_phy_status_t *) HW_USBNC_OTG1_PHY_STATUS_ADDR(x))
#define HW_USBNC_OTG1_PHY_STATUS_RD(x) (HW_USBNC_OTG1_PHY_STATUS(x).U)
/*@}*/

/*
 * Constants & macros for individual USBNC_OTG1_PHY_STATUS bitfields
 */

/*!
 * @name Register USBNC_OTG1_PHY_STATUS, field LINE_STATE[1:0] (RO)
 *
 * These signals reflect the state of the single-ended receivers as defined by
 * the UTMI+ Specification. In Suspend or Sleep mode, this bus is a
 * combinatatorial output (directly reflecting the current state of DN and DP, respectively.
 * During normal high-speed packet transfers, the line indicates a high-speed J
 * state.
 *
 * Values:
 * - 00 - SE0 (DP low, DN low)
 * - 01 - J state for high-speed and full-speed USB traffic; K state for
 *     low-speed USB traffic (DP high, DN low)
 * - 10 - K state for high-speed and full-speed USB traffic; J state for
 *     low-speed USB traffic (DP low, DN high)
 * - 11 - SE1 (DP high, DN high)
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_STATUS_LINE_STATE (0U) /*!< Bit position for USBNC_OTG1_PHY_STATUS_LINE_STATE. */
#define BM_USBNC_OTG1_PHY_STATUS_LINE_STATE (0x00000003U) /*!< Bit mask for USBNC_OTG1_PHY_STATUS_LINE_STATE. */
#define BS_USBNC_OTG1_PHY_STATUS_LINE_STATE (2U) /*!< Bit field size in bits for USBNC_OTG1_PHY_STATUS_LINE_STATE. */

/*! @brief Read current value of the USBNC_OTG1_PHY_STATUS_LINE_STATE field. */
#define BR_USBNC_OTG1_PHY_STATUS_LINE_STATE(x) (HW_USBNC_OTG1_PHY_STATUS(x).B.LINE_STATE)
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_STATUS, field SESS_VLD[2] (RO)
 *
 * This signal is the output from the USB OTG PHY Session Valid comparator and
 * indicates whether the voltage on the USB_OTG*_VBUS pin is below the OTG Device
 * Session Valid threshold. The Session Valid threshold is > 0.8V and < 2.0V on
 * this USB PHY.
 *
 * Values:
 * - 0 - The voltage on USB_OTG*_VBUS is below the OTG Device Session Valid
 *     threshold
 * - 1 - The voltage on USB_OTG*_VBUS is above the OTG Device Session Valid
 *     threshold
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_STATUS_SESS_VLD (2U) /*!< Bit position for USBNC_OTG1_PHY_STATUS_SESS_VLD. */
#define BM_USBNC_OTG1_PHY_STATUS_SESS_VLD (0x00000004U) /*!< Bit mask for USBNC_OTG1_PHY_STATUS_SESS_VLD. */
#define BS_USBNC_OTG1_PHY_STATUS_SESS_VLD (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_STATUS_SESS_VLD. */

/*! @brief Read current value of the USBNC_OTG1_PHY_STATUS_SESS_VLD field. */
#define BR_USBNC_OTG1_PHY_STATUS_SESS_VLD(x) (HW_USBNC_OTG1_PHY_STATUS(x).B.SESS_VLD)
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_STATUS, field VBUS_VLD[3] (RO)
 *
 * This signal is the output from the USB OTG PHY VBUS Valid comparator and
 * indicates whether the voltage on the USB_OTG*_VBUS pin is below the VBUS Valid
 * threshold. The threshold is 4.75V but can be adjusted with OTGTUNE0
 * (USBNC_USB_PHY_CFG1[12:10]). The USB OTG PHY VBUS Valid comparator is enabled or disabled
 * depending on the states of register bits USBNC_USB_OTGx_PHY_CFG2[10] and
 * USBNC_USB_OTGx_PHY_CFG2[16].
 *
 * Values:
 * - 0 - The voltage on USB_OTG*_VBUS is below the VBUS Valid threshold
 * - 1 - The voltage on USB_OTG*_VBUS is above the VBUS Valid threshold
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_STATUS_VBUS_VLD (3U) /*!< Bit position for USBNC_OTG1_PHY_STATUS_VBUS_VLD. */
#define BM_USBNC_OTG1_PHY_STATUS_VBUS_VLD (0x00000008U) /*!< Bit mask for USBNC_OTG1_PHY_STATUS_VBUS_VLD. */
#define BS_USBNC_OTG1_PHY_STATUS_VBUS_VLD (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_STATUS_VBUS_VLD. */

/*! @brief Read current value of the USBNC_OTG1_PHY_STATUS_VBUS_VLD field. */
#define BR_USBNC_OTG1_PHY_STATUS_VBUS_VLD(x) (HW_USBNC_OTG1_PHY_STATUS(x).B.VBUS_VLD)
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_STATUS, field ID_DIG[4] (RO)
 *
 * This signal is the output from the ID pin A/B detector, which determines
 * whether the resistance from the USB_OTG*_ID pin to VSS is grounded (10 ohm maximum
 * for a Micro- or Mini-A plug) or floating (1 Megohm minimum for a Micro- or
 * Mini- B plug). The USB OTG PHY internal ID pin A/B detector circuit is enabled
 * or disabled depending on the states of register bits USBC_n_OTGSC[5] and
 * USBNC_USB_OTGx_PHY_CFG2[4]. Selection of whether to use the USB OTG PHY ID pin A/B
 * detector or a GPIO pin ID detector is determined by the state of the
 * USBNC_n_CTRL2[DIG_ID_SEL] bit field.
 *
 * Values:
 * - 0 - The connnected plug is a Micro- or Mini-A plug
 * - 1 - The connnected plug is a Micro- or Mini-B plug
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_STATUS_ID_DIG (4U) /*!< Bit position for USBNC_OTG1_PHY_STATUS_ID_DIG. */
#define BM_USBNC_OTG1_PHY_STATUS_ID_DIG (0x00000010U) /*!< Bit mask for USBNC_OTG1_PHY_STATUS_ID_DIG. */
#define BS_USBNC_OTG1_PHY_STATUS_ID_DIG (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_STATUS_ID_DIG. */

/*! @brief Read current value of the USBNC_OTG1_PHY_STATUS_ID_DIG field. */
#define BR_USBNC_OTG1_PHY_STATUS_ID_DIG(x) (HW_USBNC_OTG1_PHY_STATUS(x).B.ID_DIG)
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_STATUS, field HOST_DISCONNECT[5] (RO)
 *
 * This signal indicates to the USB_OTGx controller that a peripheral has been
 * disconnected from or connected to the USB cable. In high-speed host operation,
 * HOST_DISCONNECT is updated only at the end of SOF packet transmission. In FS
 * and LS host operations, HOST_DISCONNECT is updated according to UTMI+
 * Specification, Section 2.2.1.10. This output is valid only when the USB OTG PHY and
 * associated USB controller are configured to Host mode by setting
 * USBC_n_USBMODE[1:0] to 2'b11.
 *
 * Values:
 * - 0 - Peripheral is connected
 * - 1 - No peripheral is connected
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_STATUS_HOST_DISCONNECT (5U) /*!< Bit position for USBNC_OTG1_PHY_STATUS_HOST_DISCONNECT. */
#define BM_USBNC_OTG1_PHY_STATUS_HOST_DISCONNECT (0x00000020U) /*!< Bit mask for USBNC_OTG1_PHY_STATUS_HOST_DISCONNECT. */
#define BS_USBNC_OTG1_PHY_STATUS_HOST_DISCONNECT (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_STATUS_HOST_DISCONNECT. */

/*! @brief Read current value of the USBNC_OTG1_PHY_STATUS_HOST_DISCONNECT field. */
#define BR_USBNC_OTG1_PHY_STATUS_HOST_DISCONNECT(x) (HW_USBNC_OTG1_PHY_STATUS(x).B.HOST_DISCONNECT)
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_STATUS, field RIDC0[24] (RO)
 *
 * For USB Charger Detection, indicates whether the USB_OTG*_ID pin connected to
 * an ACA is within the RID_C) range.
 *
 * Values:
 * - 0 - ACA OTG_ID pin resistance is >= RID_B (min) and <= RID_GND max
 * - 1 - ACA OTG_ID pin resistance is >= RID_C (min) and <= RID_C max
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_STATUS_RIDC0 (24U) /*!< Bit position for USBNC_OTG1_PHY_STATUS_RIDC0. */
#define BM_USBNC_OTG1_PHY_STATUS_RIDC0 (0x01000000U) /*!< Bit mask for USBNC_OTG1_PHY_STATUS_RIDC0. */
#define BS_USBNC_OTG1_PHY_STATUS_RIDC0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_STATUS_RIDC0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_STATUS_RIDC0 field. */
#define BR_USBNC_OTG1_PHY_STATUS_RIDC0(x) (HW_USBNC_OTG1_PHY_STATUS(x).B.RIDC0)
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_STATUS, field RIDB0[25] (RO)
 *
 * For USB Charger Detection, indicates whether the USB_OTG*_ID pin connected to
 * an ACA is within the RID_B) range.
 *
 * Values:
 * - 0 - ACA OTG_ID pin resistance is >= RID_A (min) and <= RID_C max
 * - 1 - ACA OTG_ID pin resistance is >= RID_B (min) and <= RID_B max
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_STATUS_RIDB0 (25U) /*!< Bit position for USBNC_OTG1_PHY_STATUS_RIDB0. */
#define BM_USBNC_OTG1_PHY_STATUS_RIDB0 (0x02000000U) /*!< Bit mask for USBNC_OTG1_PHY_STATUS_RIDB0. */
#define BS_USBNC_OTG1_PHY_STATUS_RIDB0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_STATUS_RIDB0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_STATUS_RIDB0 field. */
#define BR_USBNC_OTG1_PHY_STATUS_RIDB0(x) (HW_USBNC_OTG1_PHY_STATUS(x).B.RIDB0)
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_STATUS, field RIDA0[26] (RO)
 *
 * For USB Charger Detection, indicates whether the USB_OTG*_ID pin connected to
 * an ACA is within the RID_A) range.
 *
 * Values:
 * - 0 - ACA OTG_ID pin resistance is >= RID_FLOAT (min) and <= RID_B max
 * - 1 - ACA OTG_ID pin resistance is >= RID_A (min) and <= RID_A max
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_STATUS_RIDA0 (26U) /*!< Bit position for USBNC_OTG1_PHY_STATUS_RIDA0. */
#define BM_USBNC_OTG1_PHY_STATUS_RIDA0 (0x04000000U) /*!< Bit mask for USBNC_OTG1_PHY_STATUS_RIDA0. */
#define BS_USBNC_OTG1_PHY_STATUS_RIDA0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_STATUS_RIDA0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_STATUS_RIDA0 field. */
#define BR_USBNC_OTG1_PHY_STATUS_RIDA0(x) (HW_USBNC_OTG1_PHY_STATUS(x).B.RIDA0)
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_STATUS, field RIDGND0[27] (RO)
 *
 * For USB Charger Detection, indicates whether the USB_OTG*_ID pin connected to
 * an ACA is grounded (has resistance < RID_GND).
 *
 * Values:
 * - 0 - ACA OTG_ID pin resistance is >= RID_C (min)
 * - 1 - ACA OTG_ID pin resistance is <= RID_GND (max)
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_STATUS_RIDGND0 (27U) /*!< Bit position for USBNC_OTG1_PHY_STATUS_RIDGND0. */
#define BM_USBNC_OTG1_PHY_STATUS_RIDGND0 (0x08000000U) /*!< Bit mask for USBNC_OTG1_PHY_STATUS_RIDGND0. */
#define BS_USBNC_OTG1_PHY_STATUS_RIDGND0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_STATUS_RIDGND0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_STATUS_RIDGND0 field. */
#define BR_USBNC_OTG1_PHY_STATUS_RIDGND0(x) (HW_USBNC_OTG1_PHY_STATUS(x).B.RIDGND0)
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_STATUS, field RIDFLOAT0[28] (RO)
 *
 * For USB Charger Detection, indicates whether the USB_OTG*_ID pin connected to
 * an ACA is floating (has resistance > RID_FLOAT).
 *
 * Values:
 * - 0 - ACA OTG_ID pin resistance is <= RID_A (max)
 * - 1 - ACA OTG_ID pin resistance is >= RID_FLOAT (min)
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_STATUS_RIDFLOAT0 (28U) /*!< Bit position for USBNC_OTG1_PHY_STATUS_RIDFLOAT0. */
#define BM_USBNC_OTG1_PHY_STATUS_RIDFLOAT0 (0x10000000U) /*!< Bit mask for USBNC_OTG1_PHY_STATUS_RIDFLOAT0. */
#define BS_USBNC_OTG1_PHY_STATUS_RIDFLOAT0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_STATUS_RIDFLOAT0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_STATUS_RIDFLOAT0 field. */
#define BR_USBNC_OTG1_PHY_STATUS_RIDFLOAT0(x) (HW_USBNC_OTG1_PHY_STATUS(x).B.RIDFLOAT0)
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_STATUS, field CHRGDET[29] (RO)
 *
 * This signal indicates whether the voltage level on USB_OTG*_DP or USB_OTG*_DN
 * is greater than VDAT_REF as defined in the USB Battery Charger, Revision 1.2
 * Specification. The selection of which USB data pins have the VD*_SRC and the
 * ID*_SINK sources is controlled by register bit USBNC_USB_OTGx_CFG2[0]. The
 * CHRGDET register bit is only valid when USBNC_USB_OTGx_CFG2[2:1] is set to 2'b11.
 *
 * Values:
 * - 0 - VD* < VDAT_REF
 * - 1 - VD* > VDAT_REF
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_STATUS_CHRGDET (29U) /*!< Bit position for USBNC_OTG1_PHY_STATUS_CHRGDET. */
#define BM_USBNC_OTG1_PHY_STATUS_CHRGDET (0x20000000U) /*!< Bit mask for USBNC_OTG1_PHY_STATUS_CHRGDET. */
#define BS_USBNC_OTG1_PHY_STATUS_CHRGDET (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_STATUS_CHRGDET. */

/*! @brief Read current value of the USBNC_OTG1_PHY_STATUS_CHRGDET field. */
#define BR_USBNC_OTG1_PHY_STATUS_CHRGDET(x) (HW_USBNC_OTG1_PHY_STATUS(x).B.CHRGDET)
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_STATUS, field ADPPRB0[30] (RO)
 *
 * This signal is output from the USB OTG PHY ADP Probe comparator and indicates
 * whether the voltage on the USB_OTG*_VBUS pin is below the ADP probing voltage.
 *
 * Values:
 * - 0 - The voltage on USB_OTG*_VBUS is below the ADP probing voltage
 * - 1 - The voltage on USB_OTG*_VBUS is above the ADP probing voltage
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_STATUS_ADPPRB0 (30U) /*!< Bit position for USBNC_OTG1_PHY_STATUS_ADPPRB0. */
#define BM_USBNC_OTG1_PHY_STATUS_ADPPRB0 (0x40000000U) /*!< Bit mask for USBNC_OTG1_PHY_STATUS_ADPPRB0. */
#define BS_USBNC_OTG1_PHY_STATUS_ADPPRB0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_STATUS_ADPPRB0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_STATUS_ADPPRB0 field. */
#define BR_USBNC_OTG1_PHY_STATUS_ADPPRB0(x) (HW_USBNC_OTG1_PHY_STATUS(x).B.ADPPRB0)
/*@}*/

/*!
 * @name Register USBNC_OTG1_PHY_STATUS, field ADPSNS0[31] (RO)
 *
 * This signal is output from the USB OTG PHY ADP Sense comparator and indicates
 * whether the voltage on the USB_OTG*_VBUS pin is below the ADP sensing voltage.
 *
 * Values:
 * - 0 - The voltage on USB_OTG*_VBUS is below the ADP sensing voltage
 * - 1 - The voltage on USB_OTG*_VBUS is above the ADP sensing voltage
 */
/*@{*/
#define BP_USBNC_OTG1_PHY_STATUS_ADPSNS0 (31U) /*!< Bit position for USBNC_OTG1_PHY_STATUS_ADPSNS0. */
#define BM_USBNC_OTG1_PHY_STATUS_ADPSNS0 (0x80000000U) /*!< Bit mask for USBNC_OTG1_PHY_STATUS_ADPSNS0. */
#define BS_USBNC_OTG1_PHY_STATUS_ADPSNS0 (1U) /*!< Bit field size in bits for USBNC_OTG1_PHY_STATUS_ADPSNS0. */

/*! @brief Read current value of the USBNC_OTG1_PHY_STATUS_ADPSNS0 field. */
#define BR_USBNC_OTG1_PHY_STATUS_ADPSNS0(x) (HW_USBNC_OTG1_PHY_STATUS(x).B.ADPSNS0)
/*@}*/

/*******************************************************************************
 * HW_USBNC_ADP_CFG1 -
 ******************************************************************************/

/*!
 * @brief HW_USBNC_ADP_CFG1 -  (RW)
 *
 * Reset value: 0x0000C000U
 */
typedef union _hw_usbnc_adp_cfg1
{
    uint32_t U;
    struct _hw_usbnc_adp_cfg1_bitfields
    {
        uint32_t ADP_WAIT : 18;        /*!< [17:0]  */
        uint32_t RESERVED0 : 2;        /*!< [19:18]  */
        uint32_t TIMER_EN : 1;         /*!< [20] ADP Timer Test Enable */
        uint32_t ADP_SNS_INT_EN : 1;   /*!< [21] ADP Sense Interrupt Enable */
        uint32_t ADP_PRB_INT_EN : 1;   /*!< [22]  */
        uint32_t ADP_PRB_EN : 1;       /*!< [23]  */
        uint32_t RESERVED1 : 8;        /*!< [31:24]  */
    } B;
} hw_usbnc_adp_cfg1_t;

/*!
 * @name Constants and macros for entire USBNC_ADP_CFG1 register
 */
/*@{*/
#define HW_USBNC_ADP_CFG1_ADDR(x) ((uintptr_t)(x) + 0x250U)

#define HW_USBNC_ADP_CFG1(x)     (*(__IO hw_usbnc_adp_cfg1_t *) HW_USBNC_ADP_CFG1_ADDR(x))
#define HW_USBNC_ADP_CFG1_RD(x)  (HW_USBNC_ADP_CFG1(x).U)
#define HW_USBNC_ADP_CFG1_WR(x, v) (HW_USBNC_ADP_CFG1(x).U = (v))
#define HW_USBNC_ADP_CFG1_SET(x, v) (HW_USBNC_ADP_CFG1_WR(x, HW_USBNC_ADP_CFG1_RD(x) |  (v)))
#define HW_USBNC_ADP_CFG1_CLR(x, v) (HW_USBNC_ADP_CFG1_WR(x, HW_USBNC_ADP_CFG1_RD(x) & ~(v)))
#define HW_USBNC_ADP_CFG1_TOG(x, v) (HW_USBNC_ADP_CFG1_WR(x, HW_USBNC_ADP_CFG1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBNC_ADP_CFG1 bitfields
 */

/*!
 * @name Register USBNC_ADP_CFG1, field ADP_WAIT[17:0] (RW)
 *
 * Delay between 2 ADP probe, default value is about 1.5 s in 32 KHz.
 */
/*@{*/
#define BP_USBNC_ADP_CFG1_ADP_WAIT (0U)    /*!< Bit position for USBNC_ADP_CFG1_ADP_WAIT. */
#define BM_USBNC_ADP_CFG1_ADP_WAIT (0x0003FFFFU) /*!< Bit mask for USBNC_ADP_CFG1_ADP_WAIT. */
#define BS_USBNC_ADP_CFG1_ADP_WAIT (18U)   /*!< Bit field size in bits for USBNC_ADP_CFG1_ADP_WAIT. */

/*! @brief Read current value of the USBNC_ADP_CFG1_ADP_WAIT field. */
#define BR_USBNC_ADP_CFG1_ADP_WAIT(x) (HW_USBNC_ADP_CFG1(x).B.ADP_WAIT)

/*! @brief Format value for bitfield USBNC_ADP_CFG1_ADP_WAIT. */
#define BF_USBNC_ADP_CFG1_ADP_WAIT(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_ADP_CFG1_ADP_WAIT) & BM_USBNC_ADP_CFG1_ADP_WAIT)

/*! @brief Set the ADP_WAIT field to a new value. */
#define BW_USBNC_ADP_CFG1_ADP_WAIT(x, v) (HW_USBNC_ADP_CFG1_WR(x, (HW_USBNC_ADP_CFG1_RD(x) & ~BM_USBNC_ADP_CFG1_ADP_WAIT) | BF_USBNC_ADP_CFG1_ADP_WAIT(v)))
/*@}*/

/*!
 * @name Register USBNC_ADP_CFG1, field TIMER_EN[20] (RW)
 *
 * Set will start the internal 18-bit counter.
 *
 * Values:
 * - 0 - Default
 */
/*@{*/
#define BP_USBNC_ADP_CFG1_TIMER_EN (20U)   /*!< Bit position for USBNC_ADP_CFG1_TIMER_EN. */
#define BM_USBNC_ADP_CFG1_TIMER_EN (0x00100000U) /*!< Bit mask for USBNC_ADP_CFG1_TIMER_EN. */
#define BS_USBNC_ADP_CFG1_TIMER_EN (1U)    /*!< Bit field size in bits for USBNC_ADP_CFG1_TIMER_EN. */

/*! @brief Read current value of the USBNC_ADP_CFG1_TIMER_EN field. */
#define BR_USBNC_ADP_CFG1_TIMER_EN(x) (HW_USBNC_ADP_CFG1(x).B.TIMER_EN)

/*! @brief Format value for bitfield USBNC_ADP_CFG1_TIMER_EN. */
#define BF_USBNC_ADP_CFG1_TIMER_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_ADP_CFG1_TIMER_EN) & BM_USBNC_ADP_CFG1_TIMER_EN)

/*! @brief Set the TIMER_EN field to a new value. */
#define BW_USBNC_ADP_CFG1_TIMER_EN(x, v) (HW_USBNC_ADP_CFG1_WR(x, (HW_USBNC_ADP_CFG1_RD(x) & ~BM_USBNC_ADP_CFG1_TIMER_EN) | BF_USBNC_ADP_CFG1_TIMER_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_ADP_CFG1, field ADP_SNS_INT_EN[21] (RW)
 *
 * Values:
 * - 0 - Default
 */
/*@{*/
#define BP_USBNC_ADP_CFG1_ADP_SNS_INT_EN (21U) /*!< Bit position for USBNC_ADP_CFG1_ADP_SNS_INT_EN. */
#define BM_USBNC_ADP_CFG1_ADP_SNS_INT_EN (0x00200000U) /*!< Bit mask for USBNC_ADP_CFG1_ADP_SNS_INT_EN. */
#define BS_USBNC_ADP_CFG1_ADP_SNS_INT_EN (1U) /*!< Bit field size in bits for USBNC_ADP_CFG1_ADP_SNS_INT_EN. */

/*! @brief Read current value of the USBNC_ADP_CFG1_ADP_SNS_INT_EN field. */
#define BR_USBNC_ADP_CFG1_ADP_SNS_INT_EN(x) (HW_USBNC_ADP_CFG1(x).B.ADP_SNS_INT_EN)

/*! @brief Format value for bitfield USBNC_ADP_CFG1_ADP_SNS_INT_EN. */
#define BF_USBNC_ADP_CFG1_ADP_SNS_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_ADP_CFG1_ADP_SNS_INT_EN) & BM_USBNC_ADP_CFG1_ADP_SNS_INT_EN)

/*! @brief Set the ADP_SNS_INT_EN field to a new value. */
#define BW_USBNC_ADP_CFG1_ADP_SNS_INT_EN(x, v) (HW_USBNC_ADP_CFG1_WR(x, (HW_USBNC_ADP_CFG1_RD(x) & ~BM_USBNC_ADP_CFG1_ADP_SNS_INT_EN) | BF_USBNC_ADP_CFG1_ADP_SNS_INT_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_ADP_CFG1, field ADP_PRB_INT_EN[22] (RW)
 *
 * ADP probe interrupt enable
 *
 * Values:
 * - 0 - Default
 */
/*@{*/
#define BP_USBNC_ADP_CFG1_ADP_PRB_INT_EN (22U) /*!< Bit position for USBNC_ADP_CFG1_ADP_PRB_INT_EN. */
#define BM_USBNC_ADP_CFG1_ADP_PRB_INT_EN (0x00400000U) /*!< Bit mask for USBNC_ADP_CFG1_ADP_PRB_INT_EN. */
#define BS_USBNC_ADP_CFG1_ADP_PRB_INT_EN (1U) /*!< Bit field size in bits for USBNC_ADP_CFG1_ADP_PRB_INT_EN. */

/*! @brief Read current value of the USBNC_ADP_CFG1_ADP_PRB_INT_EN field. */
#define BR_USBNC_ADP_CFG1_ADP_PRB_INT_EN(x) (HW_USBNC_ADP_CFG1(x).B.ADP_PRB_INT_EN)

/*! @brief Format value for bitfield USBNC_ADP_CFG1_ADP_PRB_INT_EN. */
#define BF_USBNC_ADP_CFG1_ADP_PRB_INT_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_ADP_CFG1_ADP_PRB_INT_EN) & BM_USBNC_ADP_CFG1_ADP_PRB_INT_EN)

/*! @brief Set the ADP_PRB_INT_EN field to a new value. */
#define BW_USBNC_ADP_CFG1_ADP_PRB_INT_EN(x, v) (HW_USBNC_ADP_CFG1_WR(x, (HW_USBNC_ADP_CFG1_RD(x) & ~BM_USBNC_ADP_CFG1_ADP_PRB_INT_EN) | BF_USBNC_ADP_CFG1_ADP_PRB_INT_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_ADP_CFG1, field ADP_PRB_EN[23] (RW)
 *
 * Set to enable the ADP probe sequence
 *
 * Values:
 * - 0 - Default
 */
/*@{*/
#define BP_USBNC_ADP_CFG1_ADP_PRB_EN (23U) /*!< Bit position for USBNC_ADP_CFG1_ADP_PRB_EN. */
#define BM_USBNC_ADP_CFG1_ADP_PRB_EN (0x00800000U) /*!< Bit mask for USBNC_ADP_CFG1_ADP_PRB_EN. */
#define BS_USBNC_ADP_CFG1_ADP_PRB_EN (1U)  /*!< Bit field size in bits for USBNC_ADP_CFG1_ADP_PRB_EN. */

/*! @brief Read current value of the USBNC_ADP_CFG1_ADP_PRB_EN field. */
#define BR_USBNC_ADP_CFG1_ADP_PRB_EN(x) (HW_USBNC_ADP_CFG1(x).B.ADP_PRB_EN)

/*! @brief Format value for bitfield USBNC_ADP_CFG1_ADP_PRB_EN. */
#define BF_USBNC_ADP_CFG1_ADP_PRB_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_ADP_CFG1_ADP_PRB_EN) & BM_USBNC_ADP_CFG1_ADP_PRB_EN)

/*! @brief Set the ADP_PRB_EN field to a new value. */
#define BW_USBNC_ADP_CFG1_ADP_PRB_EN(x, v) (HW_USBNC_ADP_CFG1_WR(x, (HW_USBNC_ADP_CFG1_RD(x) & ~BM_USBNC_ADP_CFG1_ADP_PRB_EN) | BF_USBNC_ADP_CFG1_ADP_PRB_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_USBNC_ADP_CFG2 -
 ******************************************************************************/

/*!
 * @brief HW_USBNC_ADP_CFG2 -  (RW)
 *
 * Reset value: 0x00464010U
 */
typedef union _hw_usbnc_adp_cfg2
{
    uint32_t U;
    struct _hw_usbnc_adp_cfg2_bitfields
    {
        uint32_t ADP_CHRG_DELTA : 7;   /*!< [6:0]  */
        uint32_t ADP_CHRG_SWCMP : 1;   /*!< [7]  */
        uint32_t ADP_CHRG_SWTIME : 8;  /*!< [15:8]  */
        uint32_t ADP_DISCHG_TIME : 8;  /*!< [23:16] ADP Discharge time */
        uint32_t RESERVED0 : 8;        /*!< [31:24]  */
    } B;
} hw_usbnc_adp_cfg2_t;

/*!
 * @name Constants and macros for entire USBNC_ADP_CFG2 register
 */
/*@{*/
#define HW_USBNC_ADP_CFG2_ADDR(x) ((uintptr_t)(x) + 0x254U)

#define HW_USBNC_ADP_CFG2(x)     (*(__IO hw_usbnc_adp_cfg2_t *) HW_USBNC_ADP_CFG2_ADDR(x))
#define HW_USBNC_ADP_CFG2_RD(x)  (HW_USBNC_ADP_CFG2(x).U)
#define HW_USBNC_ADP_CFG2_WR(x, v) (HW_USBNC_ADP_CFG2(x).U = (v))
#define HW_USBNC_ADP_CFG2_SET(x, v) (HW_USBNC_ADP_CFG2_WR(x, HW_USBNC_ADP_CFG2_RD(x) |  (v)))
#define HW_USBNC_ADP_CFG2_CLR(x, v) (HW_USBNC_ADP_CFG2_WR(x, HW_USBNC_ADP_CFG2_RD(x) & ~(v)))
#define HW_USBNC_ADP_CFG2_TOG(x, v) (HW_USBNC_ADP_CFG2_WR(x, HW_USBNC_ADP_CFG2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBNC_ADP_CFG2 bitfields
 */

/*!
 * @name Register USBNC_ADP_CFG2, field ADP_CHRG_DELTA[6:0] (RW)
 *
 * ADP charge time compare If diffence is larger than ADP_CHG_DELTA, it
 * generates ADP_PROBE interrupt.
 */
/*@{*/
#define BP_USBNC_ADP_CFG2_ADP_CHRG_DELTA (0U) /*!< Bit position for USBNC_ADP_CFG2_ADP_CHRG_DELTA. */
#define BM_USBNC_ADP_CFG2_ADP_CHRG_DELTA (0x0000007FU) /*!< Bit mask for USBNC_ADP_CFG2_ADP_CHRG_DELTA. */
#define BS_USBNC_ADP_CFG2_ADP_CHRG_DELTA (7U) /*!< Bit field size in bits for USBNC_ADP_CFG2_ADP_CHRG_DELTA. */

/*! @brief Read current value of the USBNC_ADP_CFG2_ADP_CHRG_DELTA field. */
#define BR_USBNC_ADP_CFG2_ADP_CHRG_DELTA(x) (HW_USBNC_ADP_CFG2(x).B.ADP_CHRG_DELTA)

/*! @brief Format value for bitfield USBNC_ADP_CFG2_ADP_CHRG_DELTA. */
#define BF_USBNC_ADP_CFG2_ADP_CHRG_DELTA(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_ADP_CFG2_ADP_CHRG_DELTA) & BM_USBNC_ADP_CFG2_ADP_CHRG_DELTA)

/*! @brief Set the ADP_CHRG_DELTA field to a new value. */
#define BW_USBNC_ADP_CFG2_ADP_CHRG_DELTA(x, v) (HW_USBNC_ADP_CFG2_WR(x, (HW_USBNC_ADP_CFG2_RD(x) & ~BM_USBNC_ADP_CFG2_ADP_CHRG_DELTA) | BF_USBNC_ADP_CFG2_ADP_CHRG_DELTA(v)))
/*@}*/

/*!
 * @name Register USBNC_ADP_CFG2, field ADP_CHRG_SWCMP[7] (RW)
 *
 * If set, HW uses ADP_CHRG_SWTIME to compare. If clear, HW compares current
 * charge time with n-2 (see otg2 spec).
 *
 * Values:
 * - 0 - Default
 */
/*@{*/
#define BP_USBNC_ADP_CFG2_ADP_CHRG_SWCMP (7U) /*!< Bit position for USBNC_ADP_CFG2_ADP_CHRG_SWCMP. */
#define BM_USBNC_ADP_CFG2_ADP_CHRG_SWCMP (0x00000080U) /*!< Bit mask for USBNC_ADP_CFG2_ADP_CHRG_SWCMP. */
#define BS_USBNC_ADP_CFG2_ADP_CHRG_SWCMP (1U) /*!< Bit field size in bits for USBNC_ADP_CFG2_ADP_CHRG_SWCMP. */

/*! @brief Read current value of the USBNC_ADP_CFG2_ADP_CHRG_SWCMP field. */
#define BR_USBNC_ADP_CFG2_ADP_CHRG_SWCMP(x) (HW_USBNC_ADP_CFG2(x).B.ADP_CHRG_SWCMP)

/*! @brief Format value for bitfield USBNC_ADP_CFG2_ADP_CHRG_SWCMP. */
#define BF_USBNC_ADP_CFG2_ADP_CHRG_SWCMP(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_ADP_CFG2_ADP_CHRG_SWCMP) & BM_USBNC_ADP_CFG2_ADP_CHRG_SWCMP)

/*! @brief Set the ADP_CHRG_SWCMP field to a new value. */
#define BW_USBNC_ADP_CFG2_ADP_CHRG_SWCMP(x, v) (HW_USBNC_ADP_CFG2_WR(x, (HW_USBNC_ADP_CFG2_RD(x) & ~BM_USBNC_ADP_CFG2_ADP_CHRG_SWCMP) | BF_USBNC_ADP_CFG2_ADP_CHRG_SWCMP(v)))
/*@}*/

/*!
 * @name Register USBNC_ADP_CFG2, field ADP_CHRG_SWTIME[15:8] (RW)
 *
 * ADP charge time assigned by software
 */
/*@{*/
#define BP_USBNC_ADP_CFG2_ADP_CHRG_SWTIME (8U) /*!< Bit position for USBNC_ADP_CFG2_ADP_CHRG_SWTIME. */
#define BM_USBNC_ADP_CFG2_ADP_CHRG_SWTIME (0x0000FF00U) /*!< Bit mask for USBNC_ADP_CFG2_ADP_CHRG_SWTIME. */
#define BS_USBNC_ADP_CFG2_ADP_CHRG_SWTIME (8U) /*!< Bit field size in bits for USBNC_ADP_CFG2_ADP_CHRG_SWTIME. */

/*! @brief Read current value of the USBNC_ADP_CFG2_ADP_CHRG_SWTIME field. */
#define BR_USBNC_ADP_CFG2_ADP_CHRG_SWTIME(x) (HW_USBNC_ADP_CFG2(x).B.ADP_CHRG_SWTIME)

/*! @brief Format value for bitfield USBNC_ADP_CFG2_ADP_CHRG_SWTIME. */
#define BF_USBNC_ADP_CFG2_ADP_CHRG_SWTIME(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_ADP_CFG2_ADP_CHRG_SWTIME) & BM_USBNC_ADP_CFG2_ADP_CHRG_SWTIME)

/*! @brief Set the ADP_CHRG_SWTIME field to a new value. */
#define BW_USBNC_ADP_CFG2_ADP_CHRG_SWTIME(x, v) (HW_USBNC_ADP_CFG2_WR(x, (HW_USBNC_ADP_CFG2_RD(x) & ~BM_USBNC_ADP_CFG2_ADP_CHRG_SWTIME) | BF_USBNC_ADP_CFG2_ADP_CHRG_SWTIME(v)))
/*@}*/

/*!
 * @name Register USBNC_ADP_CFG2, field ADP_DISCHG_TIME[23:16] (RW)
 *
 * Default value is about 2.2 ms in 32 KHz.
 */
/*@{*/
#define BP_USBNC_ADP_CFG2_ADP_DISCHG_TIME (16U) /*!< Bit position for USBNC_ADP_CFG2_ADP_DISCHG_TIME. */
#define BM_USBNC_ADP_CFG2_ADP_DISCHG_TIME (0x00FF0000U) /*!< Bit mask for USBNC_ADP_CFG2_ADP_DISCHG_TIME. */
#define BS_USBNC_ADP_CFG2_ADP_DISCHG_TIME (8U) /*!< Bit field size in bits for USBNC_ADP_CFG2_ADP_DISCHG_TIME. */

/*! @brief Read current value of the USBNC_ADP_CFG2_ADP_DISCHG_TIME field. */
#define BR_USBNC_ADP_CFG2_ADP_DISCHG_TIME(x) (HW_USBNC_ADP_CFG2(x).B.ADP_DISCHG_TIME)

/*! @brief Format value for bitfield USBNC_ADP_CFG2_ADP_DISCHG_TIME. */
#define BF_USBNC_ADP_CFG2_ADP_DISCHG_TIME(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_ADP_CFG2_ADP_DISCHG_TIME) & BM_USBNC_ADP_CFG2_ADP_DISCHG_TIME)

/*! @brief Set the ADP_DISCHG_TIME field to a new value. */
#define BW_USBNC_ADP_CFG2_ADP_DISCHG_TIME(x, v) (HW_USBNC_ADP_CFG2_WR(x, (HW_USBNC_ADP_CFG2_RD(x) & ~BM_USBNC_ADP_CFG2_ADP_DISCHG_TIME) | BF_USBNC_ADP_CFG2_ADP_DISCHG_TIME(v)))
/*@}*/

/*******************************************************************************
 * HW_USBNC_ADP_STATUS -
 ******************************************************************************/

/*!
 * @brief HW_USBNC_ADP_STATUS -  (RO)
 *
 * Reset value: 0x00000000U
 */
typedef union _hw_usbnc_adp_status
{
    uint32_t U;
    struct _hw_usbnc_adp_status_bitfields
    {
        uint32_t ADP_PRB_TIMR : 8;     /*!< [7:0] ADP Probe Time */
        uint32_t ADP_CNT : 18;         /*!< [25:8] ADP Internal 18-bit Counter */
        uint32_t ADP_SNS_INT : 1;      /*!< [26] ADP Sense Interrupt Status */
        uint32_t ADP_PRB_INT : 1;      /*!< [27] ADP Probe Interrupt Status */
        uint32_t RESERVED0 : 4;        /*!< [31:28]  */
    } B;
} hw_usbnc_adp_status_t;

/*!
 * @name Constants and macros for entire USBNC_ADP_STATUS register
 */
/*@{*/
#define HW_USBNC_ADP_STATUS_ADDR(x) ((uintptr_t)(x) + 0x258U)

#define HW_USBNC_ADP_STATUS(x)   (*(__I hw_usbnc_adp_status_t *) HW_USBNC_ADP_STATUS_ADDR(x))
#define HW_USBNC_ADP_STATUS_RD(x) (HW_USBNC_ADP_STATUS(x).U)
/*@}*/

/*
 * Constants & macros for individual USBNC_ADP_STATUS bitfields
 */

/*!
 * @name Register USBNC_ADP_STATUS, field ADP_PRB_TIMR[7:0] (RO)
 *
 * It latchs the internal counter when PHY indicates ADP_PROBE.
 *
 * Values:
 * - 0 - Default
 */
/*@{*/
#define BP_USBNC_ADP_STATUS_ADP_PRB_TIMR (0U) /*!< Bit position for USBNC_ADP_STATUS_ADP_PRB_TIMR. */
#define BM_USBNC_ADP_STATUS_ADP_PRB_TIMR (0x000000FFU) /*!< Bit mask for USBNC_ADP_STATUS_ADP_PRB_TIMR. */
#define BS_USBNC_ADP_STATUS_ADP_PRB_TIMR (8U) /*!< Bit field size in bits for USBNC_ADP_STATUS_ADP_PRB_TIMR. */

/*! @brief Read current value of the USBNC_ADP_STATUS_ADP_PRB_TIMR field. */
#define BR_USBNC_ADP_STATUS_ADP_PRB_TIMR(x) (HW_USBNC_ADP_STATUS(x).B.ADP_PRB_TIMR)
/*@}*/

/*!
 * @name Register USBNC_ADP_STATUS, field ADP_CNT[25:8] (RO)
 *
 * It counts when ADP_PRB_EN or TIMER_TEST_EN is set cleared if both ADP_PRB_EN
 * and TIMER_TEST_EN are 0, or internal state machine change internal state
 * machine:
 */
/*@{*/
#define BP_USBNC_ADP_STATUS_ADP_CNT (8U)   /*!< Bit position for USBNC_ADP_STATUS_ADP_CNT. */
#define BM_USBNC_ADP_STATUS_ADP_CNT (0x03FFFF00U) /*!< Bit mask for USBNC_ADP_STATUS_ADP_CNT. */
#define BS_USBNC_ADP_STATUS_ADP_CNT (18U)  /*!< Bit field size in bits for USBNC_ADP_STATUS_ADP_CNT. */

/*! @brief Read current value of the USBNC_ADP_STATUS_ADP_CNT field. */
#define BR_USBNC_ADP_STATUS_ADP_CNT(x) (HW_USBNC_ADP_STATUS(x).B.ADP_CNT)
/*@}*/

/*!
 * @name Register USBNC_ADP_STATUS, field ADP_SNS_INT[26] (RO)
 *
 * Set when PHY detect ADP sense cleared by clear ADP_SNS_INT_EN
 *
 * Values:
 * - 0 - Default
 */
/*@{*/
#define BP_USBNC_ADP_STATUS_ADP_SNS_INT (26U) /*!< Bit position for USBNC_ADP_STATUS_ADP_SNS_INT. */
#define BM_USBNC_ADP_STATUS_ADP_SNS_INT (0x04000000U) /*!< Bit mask for USBNC_ADP_STATUS_ADP_SNS_INT. */
#define BS_USBNC_ADP_STATUS_ADP_SNS_INT (1U) /*!< Bit field size in bits for USBNC_ADP_STATUS_ADP_SNS_INT. */

/*! @brief Read current value of the USBNC_ADP_STATUS_ADP_SNS_INT field. */
#define BR_USBNC_ADP_STATUS_ADP_SNS_INT(x) (HW_USBNC_ADP_STATUS(x).B.ADP_SNS_INT)
/*@}*/

/*!
 * @name Register USBNC_ADP_STATUS, field ADP_PRB_INT[27] (RO)
 *
 * Set when ADP charge time exceed [ADP_CHG_MIN, ADP_CHG_MAX] cleared by CLEAR
 * ADP_PRB_INT_EN
 *
 * Values:
 * - 0 - Default
 */
/*@{*/
#define BP_USBNC_ADP_STATUS_ADP_PRB_INT (27U) /*!< Bit position for USBNC_ADP_STATUS_ADP_PRB_INT. */
#define BM_USBNC_ADP_STATUS_ADP_PRB_INT (0x08000000U) /*!< Bit mask for USBNC_ADP_STATUS_ADP_PRB_INT. */
#define BS_USBNC_ADP_STATUS_ADP_PRB_INT (1U) /*!< Bit field size in bits for USBNC_ADP_STATUS_ADP_PRB_INT. */

/*! @brief Read current value of the USBNC_ADP_STATUS_ADP_PRB_INT field. */
#define BR_USBNC_ADP_STATUS_ADP_PRB_INT(x) (HW_USBNC_ADP_STATUS(x).B.ADP_PRB_INT)
/*@}*/

/*******************************************************************************
 * HW_USBNC_OTG2_CTRL1 -
 ******************************************************************************/

/*!
 * @brief HW_USBNC_OTG2_CTRL1 -  (RW)
 *
 * Reset value: 0x30001000U
 *
 * The USB_n_PHY_CTRL1 register controls the integration specific features of
 * the USB PHY modules. These features are not directly related to basic USB
 * functionality, but control special features, interfacing on the USB ports, as well
 * as power control and wake-up functionality.
 */
typedef union _hw_usbnc_otg2_ctrl1
{
    uint32_t U;
    struct _hw_usbnc_otg2_ctrl1_bitfields
    {
        uint32_t RESERVED0 : 7;        /*!< [6:0]  */
        uint32_t OVER_CUR_DIS : 1;     /*!< [7]  */
        uint32_t OVER_CUR_POL : 1;     /*!< [8]  */
        uint32_t PWR_POL : 1;          /*!< [9]  */
        uint32_t WIE : 1;              /*!< [10]  */
        uint32_t RESERVED1 : 3;        /*!< [13:11]  */
        uint32_t WKUP_SW_EN : 1;       /*!< [14]  */
        uint32_t WKUP_SW : 1;          /*!< [15]  */
        uint32_t WKUP_ID_EN : 1;       /*!< [16]  */
        uint32_t WKUP_VBUS_EN : 1;     /*!< [17]  */
        uint32_t RESERVED2 : 11;       /*!< [28:18]  */
        uint32_t WKUP_DPDM_EN : 1;     /*!< [29]  */
        uint32_t RESERVED3 : 1;        /*!< [30]  */
        uint32_t WIR : 1;              /*!< [31]  */
    } B;
} hw_usbnc_otg2_ctrl1_t;

/*!
 * @name Constants and macros for entire USBNC_OTG2_CTRL1 register
 */
/*@{*/
#define HW_USBNC_OTG2_CTRL1_ADDR(x) ((uintptr_t)(x) + 0x10200U)

#define HW_USBNC_OTG2_CTRL1(x)   (*(__IO hw_usbnc_otg2_ctrl1_t *) HW_USBNC_OTG2_CTRL1_ADDR(x))
#define HW_USBNC_OTG2_CTRL1_RD(x) (HW_USBNC_OTG2_CTRL1(x).U)
#define HW_USBNC_OTG2_CTRL1_WR(x, v) (HW_USBNC_OTG2_CTRL1(x).U = (v))
#define HW_USBNC_OTG2_CTRL1_SET(x, v) (HW_USBNC_OTG2_CTRL1_WR(x, HW_USBNC_OTG2_CTRL1_RD(x) |  (v)))
#define HW_USBNC_OTG2_CTRL1_CLR(x, v) (HW_USBNC_OTG2_CTRL1_WR(x, HW_USBNC_OTG2_CTRL1_RD(x) & ~(v)))
#define HW_USBNC_OTG2_CTRL1_TOG(x, v) (HW_USBNC_OTG2_CTRL1_WR(x, HW_USBNC_OTG2_CTRL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBNC_OTG2_CTRL1 bitfields
 */

/*!
 * @name Register USBNC_OTG2_CTRL1, field OVER_CUR_DIS[7] (RW)
 *
 * Disable Overcurrent Detection
 *
 * Values:
 * - 1 - Disables overcurrent detection
 * - 0 - Enables overcurrent detection
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL1_OVER_CUR_DIS (7U) /*!< Bit position for USBNC_OTG2_CTRL1_OVER_CUR_DIS. */
#define BM_USBNC_OTG2_CTRL1_OVER_CUR_DIS (0x00000080U) /*!< Bit mask for USBNC_OTG2_CTRL1_OVER_CUR_DIS. */
#define BS_USBNC_OTG2_CTRL1_OVER_CUR_DIS (1U) /*!< Bit field size in bits for USBNC_OTG2_CTRL1_OVER_CUR_DIS. */

/*! @brief Read current value of the USBNC_OTG2_CTRL1_OVER_CUR_DIS field. */
#define BR_USBNC_OTG2_CTRL1_OVER_CUR_DIS(x) (HW_USBNC_OTG2_CTRL1(x).B.OVER_CUR_DIS)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL1_OVER_CUR_DIS. */
#define BF_USBNC_OTG2_CTRL1_OVER_CUR_DIS(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL1_OVER_CUR_DIS) & BM_USBNC_OTG2_CTRL1_OVER_CUR_DIS)

/*! @brief Set the OVER_CUR_DIS field to a new value. */
#define BW_USBNC_OTG2_CTRL1_OVER_CUR_DIS(x, v) (HW_USBNC_OTG2_CTRL1_WR(x, (HW_USBNC_OTG2_CTRL1_RD(x) & ~BM_USBNC_OTG2_CTRL1_OVER_CUR_DIS) | BF_USBNC_OTG2_CTRL1_OVER_CUR_DIS(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL1, field OVER_CUR_POL[8] (RW)
 *
 * Polarity of Overcurrent The polarity of OTG1/OTG2 port overcurrent event
 *
 * Values:
 * - 1 - Low active (low on this signal represents an overcurrent condition)
 * - 0 - High active (high on this signal represents an overcurrent condition)
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL1_OVER_CUR_POL (8U) /*!< Bit position for USBNC_OTG2_CTRL1_OVER_CUR_POL. */
#define BM_USBNC_OTG2_CTRL1_OVER_CUR_POL (0x00000100U) /*!< Bit mask for USBNC_OTG2_CTRL1_OVER_CUR_POL. */
#define BS_USBNC_OTG2_CTRL1_OVER_CUR_POL (1U) /*!< Bit field size in bits for USBNC_OTG2_CTRL1_OVER_CUR_POL. */

/*! @brief Read current value of the USBNC_OTG2_CTRL1_OVER_CUR_POL field. */
#define BR_USBNC_OTG2_CTRL1_OVER_CUR_POL(x) (HW_USBNC_OTG2_CTRL1(x).B.OVER_CUR_POL)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL1_OVER_CUR_POL. */
#define BF_USBNC_OTG2_CTRL1_OVER_CUR_POL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL1_OVER_CUR_POL) & BM_USBNC_OTG2_CTRL1_OVER_CUR_POL)

/*! @brief Set the OVER_CUR_POL field to a new value. */
#define BW_USBNC_OTG2_CTRL1_OVER_CUR_POL(x, v) (HW_USBNC_OTG2_CTRL1_WR(x, (HW_USBNC_OTG2_CTRL1_RD(x) & ~BM_USBNC_OTG2_CTRL1_OVER_CUR_POL) | BF_USBNC_OTG2_CTRL1_OVER_CUR_POL(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL1, field PWR_POL[9] (RW)
 *
 * Power Polarity This bit should be set according to PMIC Power Pin polarity.
 *
 * Values:
 * - 1 - PMIC Power Pin is High active.
 * - 0 - PMIC Power Pin is Low active.
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL1_PWR_POL (9U)   /*!< Bit position for USBNC_OTG2_CTRL1_PWR_POL. */
#define BM_USBNC_OTG2_CTRL1_PWR_POL (0x00000200U) /*!< Bit mask for USBNC_OTG2_CTRL1_PWR_POL. */
#define BS_USBNC_OTG2_CTRL1_PWR_POL (1U)   /*!< Bit field size in bits for USBNC_OTG2_CTRL1_PWR_POL. */

/*! @brief Read current value of the USBNC_OTG2_CTRL1_PWR_POL field. */
#define BR_USBNC_OTG2_CTRL1_PWR_POL(x) (HW_USBNC_OTG2_CTRL1(x).B.PWR_POL)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL1_PWR_POL. */
#define BF_USBNC_OTG2_CTRL1_PWR_POL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL1_PWR_POL) & BM_USBNC_OTG2_CTRL1_PWR_POL)

/*! @brief Set the PWR_POL field to a new value. */
#define BW_USBNC_OTG2_CTRL1_PWR_POL(x, v) (HW_USBNC_OTG2_CTRL1_WR(x, (HW_USBNC_OTG2_CTRL1_RD(x) & ~BM_USBNC_OTG2_CTRL1_PWR_POL) | BF_USBNC_OTG2_CTRL1_PWR_POL(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL1, field WIE[10] (RW)
 *
 * Wake-up Interrupt Enable This bit enables or disables the OTG1 wake-up
 * interrupt. Disabling the interrupt also clears the Interrupt request bit. Wake-up
 * interrupt enable should be turned off after receiving a wake-up interrupt and
 * turned on again prior to going in suspend mode
 *
 * Values:
 * - 1 - Interrupt Enabled
 * - 0 - Interrupt Disabled
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL1_WIE (10U)      /*!< Bit position for USBNC_OTG2_CTRL1_WIE. */
#define BM_USBNC_OTG2_CTRL1_WIE (0x00000400U) /*!< Bit mask for USBNC_OTG2_CTRL1_WIE. */
#define BS_USBNC_OTG2_CTRL1_WIE (1U)       /*!< Bit field size in bits for USBNC_OTG2_CTRL1_WIE. */

/*! @brief Read current value of the USBNC_OTG2_CTRL1_WIE field. */
#define BR_USBNC_OTG2_CTRL1_WIE(x) (HW_USBNC_OTG2_CTRL1(x).B.WIE)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL1_WIE. */
#define BF_USBNC_OTG2_CTRL1_WIE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL1_WIE) & BM_USBNC_OTG2_CTRL1_WIE)

/*! @brief Set the WIE field to a new value. */
#define BW_USBNC_OTG2_CTRL1_WIE(x, v) (HW_USBNC_OTG2_CTRL1_WR(x, (HW_USBNC_OTG2_CTRL1_RD(x) & ~BM_USBNC_OTG2_CTRL1_WIE) | BF_USBNC_OTG2_CTRL1_WIE(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL1, field WKUP_SW_EN[14] (RW)
 *
 * Software Wake-up Enable
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL1_WKUP_SW_EN (14U) /*!< Bit position for USBNC_OTG2_CTRL1_WKUP_SW_EN. */
#define BM_USBNC_OTG2_CTRL1_WKUP_SW_EN (0x00004000U) /*!< Bit mask for USBNC_OTG2_CTRL1_WKUP_SW_EN. */
#define BS_USBNC_OTG2_CTRL1_WKUP_SW_EN (1U) /*!< Bit field size in bits for USBNC_OTG2_CTRL1_WKUP_SW_EN. */

/*! @brief Read current value of the USBNC_OTG2_CTRL1_WKUP_SW_EN field. */
#define BR_USBNC_OTG2_CTRL1_WKUP_SW_EN(x) (HW_USBNC_OTG2_CTRL1(x).B.WKUP_SW_EN)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL1_WKUP_SW_EN. */
#define BF_USBNC_OTG2_CTRL1_WKUP_SW_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL1_WKUP_SW_EN) & BM_USBNC_OTG2_CTRL1_WKUP_SW_EN)

/*! @brief Set the WKUP_SW_EN field to a new value. */
#define BW_USBNC_OTG2_CTRL1_WKUP_SW_EN(x, v) (HW_USBNC_OTG2_CTRL1_WR(x, (HW_USBNC_OTG2_CTRL1_RD(x) & ~BM_USBNC_OTG2_CTRL1_WKUP_SW_EN) | BF_USBNC_OTG2_CTRL1_WKUP_SW_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL1, field WKUP_SW[15] (RW)
 *
 * Software Wake-up
 *
 * Values:
 * - 1 - Force wake-up
 * - 0 - Inactive
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL1_WKUP_SW (15U)  /*!< Bit position for USBNC_OTG2_CTRL1_WKUP_SW. */
#define BM_USBNC_OTG2_CTRL1_WKUP_SW (0x00008000U) /*!< Bit mask for USBNC_OTG2_CTRL1_WKUP_SW. */
#define BS_USBNC_OTG2_CTRL1_WKUP_SW (1U)   /*!< Bit field size in bits for USBNC_OTG2_CTRL1_WKUP_SW. */

/*! @brief Read current value of the USBNC_OTG2_CTRL1_WKUP_SW field. */
#define BR_USBNC_OTG2_CTRL1_WKUP_SW(x) (HW_USBNC_OTG2_CTRL1(x).B.WKUP_SW)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL1_WKUP_SW. */
#define BF_USBNC_OTG2_CTRL1_WKUP_SW(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL1_WKUP_SW) & BM_USBNC_OTG2_CTRL1_WKUP_SW)

/*! @brief Set the WKUP_SW field to a new value. */
#define BW_USBNC_OTG2_CTRL1_WKUP_SW(x, v) (HW_USBNC_OTG2_CTRL1_WR(x, (HW_USBNC_OTG2_CTRL1_RD(x) & ~BM_USBNC_OTG2_CTRL1_WKUP_SW) | BF_USBNC_OTG2_CTRL1_WKUP_SW(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL1, field WKUP_ID_EN[16] (RW)
 *
 * Wake-up on ID change enable
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL1_WKUP_ID_EN (16U) /*!< Bit position for USBNC_OTG2_CTRL1_WKUP_ID_EN. */
#define BM_USBNC_OTG2_CTRL1_WKUP_ID_EN (0x00010000U) /*!< Bit mask for USBNC_OTG2_CTRL1_WKUP_ID_EN. */
#define BS_USBNC_OTG2_CTRL1_WKUP_ID_EN (1U) /*!< Bit field size in bits for USBNC_OTG2_CTRL1_WKUP_ID_EN. */

/*! @brief Read current value of the USBNC_OTG2_CTRL1_WKUP_ID_EN field. */
#define BR_USBNC_OTG2_CTRL1_WKUP_ID_EN(x) (HW_USBNC_OTG2_CTRL1(x).B.WKUP_ID_EN)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL1_WKUP_ID_EN. */
#define BF_USBNC_OTG2_CTRL1_WKUP_ID_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL1_WKUP_ID_EN) & BM_USBNC_OTG2_CTRL1_WKUP_ID_EN)

/*! @brief Set the WKUP_ID_EN field to a new value. */
#define BW_USBNC_OTG2_CTRL1_WKUP_ID_EN(x, v) (HW_USBNC_OTG2_CTRL1_WR(x, (HW_USBNC_OTG2_CTRL1_RD(x) & ~BM_USBNC_OTG2_CTRL1_WKUP_ID_EN) | BF_USBNC_OTG2_CTRL1_WKUP_ID_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL1, field WKUP_VBUS_EN[17] (RW)
 *
 * Wake-up on VBUS change enable
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL1_WKUP_VBUS_EN (17U) /*!< Bit position for USBNC_OTG2_CTRL1_WKUP_VBUS_EN. */
#define BM_USBNC_OTG2_CTRL1_WKUP_VBUS_EN (0x00020000U) /*!< Bit mask for USBNC_OTG2_CTRL1_WKUP_VBUS_EN. */
#define BS_USBNC_OTG2_CTRL1_WKUP_VBUS_EN (1U) /*!< Bit field size in bits for USBNC_OTG2_CTRL1_WKUP_VBUS_EN. */

/*! @brief Read current value of the USBNC_OTG2_CTRL1_WKUP_VBUS_EN field. */
#define BR_USBNC_OTG2_CTRL1_WKUP_VBUS_EN(x) (HW_USBNC_OTG2_CTRL1(x).B.WKUP_VBUS_EN)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL1_WKUP_VBUS_EN. */
#define BF_USBNC_OTG2_CTRL1_WKUP_VBUS_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL1_WKUP_VBUS_EN) & BM_USBNC_OTG2_CTRL1_WKUP_VBUS_EN)

/*! @brief Set the WKUP_VBUS_EN field to a new value. */
#define BW_USBNC_OTG2_CTRL1_WKUP_VBUS_EN(x, v) (HW_USBNC_OTG2_CTRL1_WR(x, (HW_USBNC_OTG2_CTRL1_RD(x) & ~BM_USBNC_OTG2_CTRL1_WKUP_VBUS_EN) | BF_USBNC_OTG2_CTRL1_WKUP_VBUS_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL1, field WKUP_DPDM_EN[29] (RW)
 *
 * Wake-up on DPDM change enable
 *
 * Values:
 * - 1 - (Default) DPDM changes wake-up to be enabled, it is for device only.
 * - 0 - DPDM changes wake-up to be disabled only when VBUS is 0.
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL1_WKUP_DPDM_EN (29U) /*!< Bit position for USBNC_OTG2_CTRL1_WKUP_DPDM_EN. */
#define BM_USBNC_OTG2_CTRL1_WKUP_DPDM_EN (0x20000000U) /*!< Bit mask for USBNC_OTG2_CTRL1_WKUP_DPDM_EN. */
#define BS_USBNC_OTG2_CTRL1_WKUP_DPDM_EN (1U) /*!< Bit field size in bits for USBNC_OTG2_CTRL1_WKUP_DPDM_EN. */

/*! @brief Read current value of the USBNC_OTG2_CTRL1_WKUP_DPDM_EN field. */
#define BR_USBNC_OTG2_CTRL1_WKUP_DPDM_EN(x) (HW_USBNC_OTG2_CTRL1(x).B.WKUP_DPDM_EN)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL1_WKUP_DPDM_EN. */
#define BF_USBNC_OTG2_CTRL1_WKUP_DPDM_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL1_WKUP_DPDM_EN) & BM_USBNC_OTG2_CTRL1_WKUP_DPDM_EN)

/*! @brief Set the WKUP_DPDM_EN field to a new value. */
#define BW_USBNC_OTG2_CTRL1_WKUP_DPDM_EN(x, v) (HW_USBNC_OTG2_CTRL1_WR(x, (HW_USBNC_OTG2_CTRL1_RD(x) & ~BM_USBNC_OTG2_CTRL1_WKUP_DPDM_EN) | BF_USBNC_OTG2_CTRL1_WKUP_DPDM_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL1, field WIR[31] (RO)
 *
 * Wake-up Interrupt Request This bit indicates that a wake-up interrupt request
 * is received on the OTG1 port. This bit is cleared by disabling the wake-up
 * interrupt (clearing bit "OWIE").
 *
 * Values:
 * - 1 - Wake-up Interrupt Request received
 * - 0 - No wake-up interrupt request received
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL1_WIR (31U)      /*!< Bit position for USBNC_OTG2_CTRL1_WIR. */
#define BM_USBNC_OTG2_CTRL1_WIR (0x80000000U) /*!< Bit mask for USBNC_OTG2_CTRL1_WIR. */
#define BS_USBNC_OTG2_CTRL1_WIR (1U)       /*!< Bit field size in bits for USBNC_OTG2_CTRL1_WIR. */

/*! @brief Read current value of the USBNC_OTG2_CTRL1_WIR field. */
#define BR_USBNC_OTG2_CTRL1_WIR(x) (HW_USBNC_OTG2_CTRL1(x).B.WIR)
/*@}*/

/*******************************************************************************
 * HW_USBNC_OTG2_CTRL2 -
 ******************************************************************************/

/*!
 * @brief HW_USBNC_OTG2_CTRL2 -  (RW)
 *
 * Reset value: 0x0F000000U
 *
 * The USB_OTGx_PHY_CTRL2 register allows observation of the UTMI Clock Valid
 * status along with control of selected inputs to the USB OTG PHY transceiver.
 * Some of these input signals may be used for USB out-of-band signaling. Customers
 * should use caution when overriding any UTMI signals since that will interfere
 * with normal USB data communication.
 */
typedef union _hw_usbnc_otg2_ctrl2
{
    uint32_t U;
    struct _hw_usbnc_otg2_ctrl2_bitfields
    {
        uint32_t VBUS_SOURCE_SEL : 2;  /*!< [1:0]  */
        uint32_t AUTURESUME_EN : 1;    /*!< [2] Auto Resume Enable */
        uint32_t LOWSPEED_EN : 1;      /*!< [3]  */
        uint32_t TERMSEL_OVERRIDE : 1; /*!< [4]  */
        uint32_t TERMSEL_OVERRIDEEN : 1; /*!< [5]  */
        uint32_t OPMODE_OVERRIDE : 2;  /*!< [7:6]  */
        uint32_t OPMODE_OVERRIDEEN : 1; /*!< [8]  */
        uint32_t XCVRSEL_OVERRIDE : 2; /*!< [10:9]  */
        uint32_t XCVRSEL_OVERRIDEEN : 1; /*!< [11]  */
        uint32_t DPPULLDOWN_OVERRIDE : 1; /*!< [12]  */
        uint32_t DPPULLDOWN_OVERRIDEEN : 1; /*!< [13]  */
        uint32_t DMPULLDOWN_OVERRIDE : 1; /*!< [14]  */
        uint32_t DMPULLDOWN_OVERRIDEEN : 1; /*!< [15]  */
        uint32_t RESERVED0 : 4;        /*!< [19:16]  */
        uint32_t DIG_ID_SEL : 1;       /*!< [20]  */
        uint32_t RESERVED1 : 10;       /*!< [30:21]  */
        uint32_t UTMI_CLK_VLD : 1;     /*!< [31]  */
    } B;
} hw_usbnc_otg2_ctrl2_t;

/*!
 * @name Constants and macros for entire USBNC_OTG2_CTRL2 register
 */
/*@{*/
#define HW_USBNC_OTG2_CTRL2_ADDR(x) ((uintptr_t)(x) + 0x10204U)

#define HW_USBNC_OTG2_CTRL2(x)   (*(__IO hw_usbnc_otg2_ctrl2_t *) HW_USBNC_OTG2_CTRL2_ADDR(x))
#define HW_USBNC_OTG2_CTRL2_RD(x) (HW_USBNC_OTG2_CTRL2(x).U)
#define HW_USBNC_OTG2_CTRL2_WR(x, v) (HW_USBNC_OTG2_CTRL2(x).U = (v))
#define HW_USBNC_OTG2_CTRL2_SET(x, v) (HW_USBNC_OTG2_CTRL2_WR(x, HW_USBNC_OTG2_CTRL2_RD(x) |  (v)))
#define HW_USBNC_OTG2_CTRL2_CLR(x, v) (HW_USBNC_OTG2_CTRL2_WR(x, HW_USBNC_OTG2_CTRL2_RD(x) & ~(v)))
#define HW_USBNC_OTG2_CTRL2_TOG(x, v) (HW_USBNC_OTG2_CTRL2_WR(x, HW_USBNC_OTG2_CTRL2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBNC_OTG2_CTRL2 bitfields
 */

/*!
 * @name Register USBNC_OTG2_CTRL2, field VBUS_SOURCE_SEL[1:0] (RW)
 *
 * VBUS source select used to detect a VBUS wakeup event. This bit field is for
 * UTMI OTG PHY only (UH core and HSIC PHY have no such feature).
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL2_VBUS_SOURCE_SEL (0U) /*!< Bit position for USBNC_OTG2_CTRL2_VBUS_SOURCE_SEL. */
#define BM_USBNC_OTG2_CTRL2_VBUS_SOURCE_SEL (0x00000003U) /*!< Bit mask for USBNC_OTG2_CTRL2_VBUS_SOURCE_SEL. */
#define BS_USBNC_OTG2_CTRL2_VBUS_SOURCE_SEL (2U) /*!< Bit field size in bits for USBNC_OTG2_CTRL2_VBUS_SOURCE_SEL. */

/*! @brief Read current value of the USBNC_OTG2_CTRL2_VBUS_SOURCE_SEL field. */
#define BR_USBNC_OTG2_CTRL2_VBUS_SOURCE_SEL(x) (HW_USBNC_OTG2_CTRL2(x).B.VBUS_SOURCE_SEL)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL2_VBUS_SOURCE_SEL. */
#define BF_USBNC_OTG2_CTRL2_VBUS_SOURCE_SEL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL2_VBUS_SOURCE_SEL) & BM_USBNC_OTG2_CTRL2_VBUS_SOURCE_SEL)

/*! @brief Set the VBUS_SOURCE_SEL field to a new value. */
#define BW_USBNC_OTG2_CTRL2_VBUS_SOURCE_SEL(x, v) (HW_USBNC_OTG2_CTRL2_WR(x, (HW_USBNC_OTG2_CTRL2_RD(x) & ~(BM_USBNC_OTG2_CTRL2_VBUS_SOURCE_SEL | BM_USBNC_OTG2_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG2_CTRL2_VBUS_SOURCE_SEL(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL2, field AUTURESUME_EN[2] (RW)
 *
 * This bit field is for UTMI OTG PHY host mode only (UH core does not have this
 * feature since HSIC PHY does not support auto resume). To set USB, it will
 * send resume with 32 KHz clock when it detects remote wakeup from device. This
 * feature is useful if device drives a very short remote wakeup (minimal value is 1
 * ms for USB2 spec) and system 24 MHz is off during suspend mode.
 *
 * Values:
 * - 0 - Default
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL2_AUTURESUME_EN (2U) /*!< Bit position for USBNC_OTG2_CTRL2_AUTURESUME_EN. */
#define BM_USBNC_OTG2_CTRL2_AUTURESUME_EN (0x00000004U) /*!< Bit mask for USBNC_OTG2_CTRL2_AUTURESUME_EN. */
#define BS_USBNC_OTG2_CTRL2_AUTURESUME_EN (1U) /*!< Bit field size in bits for USBNC_OTG2_CTRL2_AUTURESUME_EN. */

/*! @brief Read current value of the USBNC_OTG2_CTRL2_AUTURESUME_EN field. */
#define BR_USBNC_OTG2_CTRL2_AUTURESUME_EN(x) (HW_USBNC_OTG2_CTRL2(x).B.AUTURESUME_EN)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL2_AUTURESUME_EN. */
#define BF_USBNC_OTG2_CTRL2_AUTURESUME_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL2_AUTURESUME_EN) & BM_USBNC_OTG2_CTRL2_AUTURESUME_EN)

/*! @brief Set the AUTURESUME_EN field to a new value. */
#define BW_USBNC_OTG2_CTRL2_AUTURESUME_EN(x, v) (HW_USBNC_OTG2_CTRL2_WR(x, (HW_USBNC_OTG2_CTRL2_RD(x) & ~(BM_USBNC_OTG2_CTRL2_AUTURESUME_EN | BM_USBNC_OTG2_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG2_CTRL2_AUTURESUME_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL2, field LOWSPEED_EN[3] (RW)
 *
 * Set if AUTURESUME_EN is set and works on low speed.
 *
 * Values:
 * - 0 - Default
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL2_LOWSPEED_EN (3U) /*!< Bit position for USBNC_OTG2_CTRL2_LOWSPEED_EN. */
#define BM_USBNC_OTG2_CTRL2_LOWSPEED_EN (0x00000008U) /*!< Bit mask for USBNC_OTG2_CTRL2_LOWSPEED_EN. */
#define BS_USBNC_OTG2_CTRL2_LOWSPEED_EN (1U) /*!< Bit field size in bits for USBNC_OTG2_CTRL2_LOWSPEED_EN. */

/*! @brief Read current value of the USBNC_OTG2_CTRL2_LOWSPEED_EN field. */
#define BR_USBNC_OTG2_CTRL2_LOWSPEED_EN(x) (HW_USBNC_OTG2_CTRL2(x).B.LOWSPEED_EN)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL2_LOWSPEED_EN. */
#define BF_USBNC_OTG2_CTRL2_LOWSPEED_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL2_LOWSPEED_EN) & BM_USBNC_OTG2_CTRL2_LOWSPEED_EN)

/*! @brief Set the LOWSPEED_EN field to a new value. */
#define BW_USBNC_OTG2_CTRL2_LOWSPEED_EN(x, v) (HW_USBNC_OTG2_CTRL2_WR(x, (HW_USBNC_OTG2_CTRL2_RD(x) & ~(BM_USBNC_OTG2_CTRL2_LOWSPEED_EN | BM_USBNC_OTG2_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG2_CTRL2_LOWSPEED_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL2, field TERMSEL_OVERRIDE[4] (RW)
 *
 * Controls the state of the UTMI TermSelect signal to the USB OTG PHY if the
 * value of USBNC_x_CTRL2[TERMSEL_OVERRIDEEN] is set to 1'b1. See the UTMI+
 * Specification for descriptions of the function of the TermSelect signal.
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDE (4U) /*!< Bit position for USBNC_OTG2_CTRL2_TERMSEL_OVERRIDE. */
#define BM_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDE (0x00000010U) /*!< Bit mask for USBNC_OTG2_CTRL2_TERMSEL_OVERRIDE. */
#define BS_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDE (1U) /*!< Bit field size in bits for USBNC_OTG2_CTRL2_TERMSEL_OVERRIDE. */

/*! @brief Read current value of the USBNC_OTG2_CTRL2_TERMSEL_OVERRIDE field. */
#define BR_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDE(x) (HW_USBNC_OTG2_CTRL2(x).B.TERMSEL_OVERRIDE)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL2_TERMSEL_OVERRIDE. */
#define BF_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDE) & BM_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDE)

/*! @brief Set the TERMSEL_OVERRIDE field to a new value. */
#define BW_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDE(x, v) (HW_USBNC_OTG2_CTRL2_WR(x, (HW_USBNC_OTG2_CTRL2_RD(x) & ~(BM_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDE | BM_USBNC_OTG2_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL2, field TERMSEL_OVERRIDEEN[5] (RW)
 *
 * Enables override of control of the UTMI TermSelect signal to the USB OTG PHY
 * instead of using the state normally set by the USB controller.
 *
 * Values:
 * - 0 - The state of the UTMI TermSelect signal to the USB PHY is set by the
 *     USB controller.
 * - 1 - The state of the UTMI TermSelect signal to the USB PHY is set by the
 *     value in the USBNC_x_CTRL2[TERMSEL_OVERRIDE] bit field.
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDEEN (5U) /*!< Bit position for USBNC_OTG2_CTRL2_TERMSEL_OVERRIDEEN. */
#define BM_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDEEN (0x00000020U) /*!< Bit mask for USBNC_OTG2_CTRL2_TERMSEL_OVERRIDEEN. */
#define BS_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDEEN (1U) /*!< Bit field size in bits for USBNC_OTG2_CTRL2_TERMSEL_OVERRIDEEN. */

/*! @brief Read current value of the USBNC_OTG2_CTRL2_TERMSEL_OVERRIDEEN field. */
#define BR_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDEEN(x) (HW_USBNC_OTG2_CTRL2(x).B.TERMSEL_OVERRIDEEN)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL2_TERMSEL_OVERRIDEEN. */
#define BF_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDEEN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDEEN) & BM_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDEEN)

/*! @brief Set the TERMSEL_OVERRIDEEN field to a new value. */
#define BW_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDEEN(x, v) (HW_USBNC_OTG2_CTRL2_WR(x, (HW_USBNC_OTG2_CTRL2_RD(x) & ~(BM_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDEEN | BM_USBNC_OTG2_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG2_CTRL2_TERMSEL_OVERRIDEEN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL2, field OPMODE_OVERRIDE[7:6] (RW)
 *
 * Controls the state of the UTMI XcvrSelect signals to the USB OTG PHY if the
 * value of USBNC_x_CTRL2[OPMODE_OVERRIDEEN] is set to 1'b1. See the UTMI+
 * Specification for descriptions of the functions of the OpMode signals.
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL2_OPMODE_OVERRIDE (6U) /*!< Bit position for USBNC_OTG2_CTRL2_OPMODE_OVERRIDE. */
#define BM_USBNC_OTG2_CTRL2_OPMODE_OVERRIDE (0x000000C0U) /*!< Bit mask for USBNC_OTG2_CTRL2_OPMODE_OVERRIDE. */
#define BS_USBNC_OTG2_CTRL2_OPMODE_OVERRIDE (2U) /*!< Bit field size in bits for USBNC_OTG2_CTRL2_OPMODE_OVERRIDE. */

/*! @brief Read current value of the USBNC_OTG2_CTRL2_OPMODE_OVERRIDE field. */
#define BR_USBNC_OTG2_CTRL2_OPMODE_OVERRIDE(x) (HW_USBNC_OTG2_CTRL2(x).B.OPMODE_OVERRIDE)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL2_OPMODE_OVERRIDE. */
#define BF_USBNC_OTG2_CTRL2_OPMODE_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL2_OPMODE_OVERRIDE) & BM_USBNC_OTG2_CTRL2_OPMODE_OVERRIDE)

/*! @brief Set the OPMODE_OVERRIDE field to a new value. */
#define BW_USBNC_OTG2_CTRL2_OPMODE_OVERRIDE(x, v) (HW_USBNC_OTG2_CTRL2_WR(x, (HW_USBNC_OTG2_CTRL2_RD(x) & ~(BM_USBNC_OTG2_CTRL2_OPMODE_OVERRIDE | BM_USBNC_OTG2_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG2_CTRL2_OPMODE_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL2, field OPMODE_OVERRIDEEN[8] (RW)
 *
 * Enables override of control of the UTMI OpMode signals to the USB OTG PHY
 * instead of using the state normally set by the USB controller.
 *
 * Values:
 * - 0 - The state of the UTMI OpMode signals to the USB PHY is set by the USB
 *     controller.
 * - 1 - The state of the UTMI OpMode signals to the USB PHY is set by the
 *     values in the USBNC_x_CTRL2[OPMODE_OVERRIDE] bit field.
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL2_OPMODE_OVERRIDEEN (8U) /*!< Bit position for USBNC_OTG2_CTRL2_OPMODE_OVERRIDEEN. */
#define BM_USBNC_OTG2_CTRL2_OPMODE_OVERRIDEEN (0x00000100U) /*!< Bit mask for USBNC_OTG2_CTRL2_OPMODE_OVERRIDEEN. */
#define BS_USBNC_OTG2_CTRL2_OPMODE_OVERRIDEEN (1U) /*!< Bit field size in bits for USBNC_OTG2_CTRL2_OPMODE_OVERRIDEEN. */

/*! @brief Read current value of the USBNC_OTG2_CTRL2_OPMODE_OVERRIDEEN field. */
#define BR_USBNC_OTG2_CTRL2_OPMODE_OVERRIDEEN(x) (HW_USBNC_OTG2_CTRL2(x).B.OPMODE_OVERRIDEEN)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL2_OPMODE_OVERRIDEEN. */
#define BF_USBNC_OTG2_CTRL2_OPMODE_OVERRIDEEN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL2_OPMODE_OVERRIDEEN) & BM_USBNC_OTG2_CTRL2_OPMODE_OVERRIDEEN)

/*! @brief Set the OPMODE_OVERRIDEEN field to a new value. */
#define BW_USBNC_OTG2_CTRL2_OPMODE_OVERRIDEEN(x, v) (HW_USBNC_OTG2_CTRL2_WR(x, (HW_USBNC_OTG2_CTRL2_RD(x) & ~(BM_USBNC_OTG2_CTRL2_OPMODE_OVERRIDEEN | BM_USBNC_OTG2_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG2_CTRL2_OPMODE_OVERRIDEEN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL2, field XCVRSEL_OVERRIDE[10:9] (RW)
 *
 * Controls the state of the UTMI XcvrSelect signals to the USB OTG PHY if the
 * value of USBNC_x_CTRL2[XCVRSEL_OVERRIDEEN] is set to 1'b1. See the UTMI+
 * Specification for descriptions of the functions of the XcvrSelect signals.
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDE (9U) /*!< Bit position for USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDE. */
#define BM_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDE (0x00000600U) /*!< Bit mask for USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDE. */
#define BS_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDE (2U) /*!< Bit field size in bits for USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDE. */

/*! @brief Read current value of the USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDE field. */
#define BR_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDE(x) (HW_USBNC_OTG2_CTRL2(x).B.XCVRSEL_OVERRIDE)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDE. */
#define BF_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDE) & BM_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDE)

/*! @brief Set the XCVRSEL_OVERRIDE field to a new value. */
#define BW_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDE(x, v) (HW_USBNC_OTG2_CTRL2_WR(x, (HW_USBNC_OTG2_CTRL2_RD(x) & ~(BM_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDE | BM_USBNC_OTG2_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL2, field XCVRSEL_OVERRIDEEN[11] (RW)
 *
 * Enables override of control of the UTMI XcvrSelect signals to the USB OTG PHY
 * instead of using the state normally set by the USB controller.
 *
 * Values:
 * - 0 - The state of the UTMI XcvrSelect signals to the USB PHY is set by the
 *     USB controller.
 * - 1 - The state of the UTMI XcvrSelect signals to the USB PHY is set by the
 *     values in the USBNC_x_CTRL2[XCVRSEL_OVERRIDE] bit field.
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDEEN (11U) /*!< Bit position for USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDEEN. */
#define BM_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDEEN (0x00000800U) /*!< Bit mask for USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDEEN. */
#define BS_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDEEN (1U) /*!< Bit field size in bits for USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDEEN. */

/*! @brief Read current value of the USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDEEN field. */
#define BR_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDEEN(x) (HW_USBNC_OTG2_CTRL2(x).B.XCVRSEL_OVERRIDEEN)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDEEN. */
#define BF_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDEEN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDEEN) & BM_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDEEN)

/*! @brief Set the XCVRSEL_OVERRIDEEN field to a new value. */
#define BW_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDEEN(x, v) (HW_USBNC_OTG2_CTRL2_WR(x, (HW_USBNC_OTG2_CTRL2_RD(x) & ~(BM_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDEEN | BM_USBNC_OTG2_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG2_CTRL2_XCVRSEL_OVERRIDEEN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL2, field DPPULLDOWN_OVERRIDE[12] (RW)
 *
 * Controls state of DP pulldown resistor if
 * USBNC_n_CTRL2[DPPULLDOWN_OVERRIDEEN] is set to 1'b1.
 *
 * Values:
 * - 0 - DP pulldown resistor disabled
 * - 1 - DP pulldown resistor enabled
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDE (12U) /*!< Bit position for USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDE. */
#define BM_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDE (0x00001000U) /*!< Bit mask for USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDE. */
#define BS_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDE (1U) /*!< Bit field size in bits for USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDE. */

/*! @brief Read current value of the USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDE field. */
#define BR_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDE(x) (HW_USBNC_OTG2_CTRL2(x).B.DPPULLDOWN_OVERRIDE)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDE. */
#define BF_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDE) & BM_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDE)

/*! @brief Set the DPPULLDOWN_OVERRIDE field to a new value. */
#define BW_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDE(x, v) (HW_USBNC_OTG2_CTRL2_WR(x, (HW_USBNC_OTG2_CTRL2_RD(x) & ~(BM_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDE | BM_USBNC_OTG2_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL2, field DPPULLDOWN_OVERRIDEEN[13] (RW)
 *
 * Enables override of control of the DP pulldown resistor instead of using the
 * state set by the USB controller.
 *
 * Values:
 * - 0 - USB controller enables/disables the DP pulldown resistor in the USB PHY.
 * - 1 - Use the value set by the USBNC_n_CTRL2[DPPULLDOWN_OVERRIDE] bit field
 *     to enable/disable the DP pulldown resistor in the USB PHY.
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDEEN (13U) /*!< Bit position for USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDEEN. */
#define BM_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDEEN (0x00002000U) /*!< Bit mask for USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDEEN. */
#define BS_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDEEN (1U) /*!< Bit field size in bits for USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDEEN. */

/*! @brief Read current value of the USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDEEN field. */
#define BR_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDEEN(x) (HW_USBNC_OTG2_CTRL2(x).B.DPPULLDOWN_OVERRIDEEN)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDEEN. */
#define BF_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDEEN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDEEN) & BM_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDEEN)

/*! @brief Set the DPPULLDOWN_OVERRIDEEN field to a new value. */
#define BW_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDEEN(x, v) (HW_USBNC_OTG2_CTRL2_WR(x, (HW_USBNC_OTG2_CTRL2_RD(x) & ~(BM_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDEEN | BM_USBNC_OTG2_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG2_CTRL2_DPPULLDOWN_OVERRIDEEN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL2, field DMPULLDOWN_OVERRIDE[14] (RW)
 *
 * Controls state of DM pulldown resistor if
 * USBNC_n_CTRL2[DMPULLDOWN_OVERRIDEEN] is set to 1'b1.
 *
 * Values:
 * - 0 - DM pulldown resistor disabled
 * - 1 - DM pulldown resistor enabled
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDE (14U) /*!< Bit position for USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDE. */
#define BM_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDE (0x00004000U) /*!< Bit mask for USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDE. */
#define BS_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDE (1U) /*!< Bit field size in bits for USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDE. */

/*! @brief Read current value of the USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDE field. */
#define BR_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDE(x) (HW_USBNC_OTG2_CTRL2(x).B.DMPULLDOWN_OVERRIDE)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDE. */
#define BF_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDE) & BM_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDE)

/*! @brief Set the DMPULLDOWN_OVERRIDE field to a new value. */
#define BW_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDE(x, v) (HW_USBNC_OTG2_CTRL2_WR(x, (HW_USBNC_OTG2_CTRL2_RD(x) & ~(BM_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDE | BM_USBNC_OTG2_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL2, field DMPULLDOWN_OVERRIDEEN[15] (RW)
 *
 * Enables override of control of the DM pulldown resistor instead of the state
 * set by the USB controller.
 *
 * Values:
 * - 0 - USB controller enables/disables the DM pulldown resistor in the USB PHY.
 * - 1 - Use the value set by the USBNC_n_CTRL2[DMPULLDOWN_OVERRIDE] bit field
 *     to enable/disable the DM pulldown resistor in the USB PHY.
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDEEN (15U) /*!< Bit position for USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDEEN. */
#define BM_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDEEN (0x00008000U) /*!< Bit mask for USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDEEN. */
#define BS_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDEEN (1U) /*!< Bit field size in bits for USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDEEN. */

/*! @brief Read current value of the USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDEEN field. */
#define BR_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDEEN(x) (HW_USBNC_OTG2_CTRL2(x).B.DMPULLDOWN_OVERRIDEEN)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDEEN. */
#define BF_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDEEN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDEEN) & BM_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDEEN)

/*! @brief Set the DMPULLDOWN_OVERRIDEEN field to a new value. */
#define BW_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDEEN(x, v) (HW_USBNC_OTG2_CTRL2_WR(x, (HW_USBNC_OTG2_CTRL2_RD(x) & ~(BM_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDEEN | BM_USBNC_OTG2_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG2_CTRL2_DMPULLDOWN_OVERRIDEEN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL2, field DIG_ID_SEL[20] (RW)
 *
 * Selects whether the USB OTG ID pin function is connected to the PHY's
 * USB_OTG*_ID pin or a GPIO pin. The ID pin state is observed on
 * USBNC_n_PHY_STATUS[ID_DIG].
 *
 * Values:
 * - 0 - Use the USB_OTG*_ID pin for the USB OTG ID pin detection
 *     function(default)
 * - 1 - Use the pin configured by the IOMUXC_USB_OTG*_ID_SELECT_INPUT register
 *     for the USB OTG ID pin detection function
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL2_DIG_ID_SEL (20U) /*!< Bit position for USBNC_OTG2_CTRL2_DIG_ID_SEL. */
#define BM_USBNC_OTG2_CTRL2_DIG_ID_SEL (0x00100000U) /*!< Bit mask for USBNC_OTG2_CTRL2_DIG_ID_SEL. */
#define BS_USBNC_OTG2_CTRL2_DIG_ID_SEL (1U) /*!< Bit field size in bits for USBNC_OTG2_CTRL2_DIG_ID_SEL. */

/*! @brief Read current value of the USBNC_OTG2_CTRL2_DIG_ID_SEL field. */
#define BR_USBNC_OTG2_CTRL2_DIG_ID_SEL(x) (HW_USBNC_OTG2_CTRL2(x).B.DIG_ID_SEL)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL2_DIG_ID_SEL. */
#define BF_USBNC_OTG2_CTRL2_DIG_ID_SEL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL2_DIG_ID_SEL) & BM_USBNC_OTG2_CTRL2_DIG_ID_SEL)

/*! @brief Set the DIG_ID_SEL field to a new value. */
#define BW_USBNC_OTG2_CTRL2_DIG_ID_SEL(x, v) (HW_USBNC_OTG2_CTRL2_WR(x, (HW_USBNC_OTG2_CTRL2_RD(x) & ~(BM_USBNC_OTG2_CTRL2_DIG_ID_SEL | BM_USBNC_OTG2_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_OTG2_CTRL2_DIG_ID_SEL(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_CTRL2, field UTMI_CLK_VLD[31] (W1C)
 *
 * Indicate whether PHY clock is valid. Write 1 to clear
 *
 * Values:
 * - 0 - UTMI clock to USB PHY is not toggling (Default)
 * - 1 - UTMI clock to USB PHY has toggled several times
 */
/*@{*/
#define BP_USBNC_OTG2_CTRL2_UTMI_CLK_VLD (31U) /*!< Bit position for USBNC_OTG2_CTRL2_UTMI_CLK_VLD. */
#define BM_USBNC_OTG2_CTRL2_UTMI_CLK_VLD (0x80000000U) /*!< Bit mask for USBNC_OTG2_CTRL2_UTMI_CLK_VLD. */
#define BS_USBNC_OTG2_CTRL2_UTMI_CLK_VLD (1U) /*!< Bit field size in bits for USBNC_OTG2_CTRL2_UTMI_CLK_VLD. */

/*! @brief Read current value of the USBNC_OTG2_CTRL2_UTMI_CLK_VLD field. */
#define BR_USBNC_OTG2_CTRL2_UTMI_CLK_VLD(x) (HW_USBNC_OTG2_CTRL2(x).B.UTMI_CLK_VLD)

/*! @brief Format value for bitfield USBNC_OTG2_CTRL2_UTMI_CLK_VLD. */
#define BF_USBNC_OTG2_CTRL2_UTMI_CLK_VLD(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_CTRL2_UTMI_CLK_VLD) & BM_USBNC_OTG2_CTRL2_UTMI_CLK_VLD)

/*! @brief Set the UTMI_CLK_VLD field to a new value. */
#define BW_USBNC_OTG2_CTRL2_UTMI_CLK_VLD(x, v) (HW_USBNC_OTG2_CTRL2_WR(x, (HW_USBNC_OTG2_CTRL2_RD(x) & ~BM_USBNC_OTG2_CTRL2_UTMI_CLK_VLD) | BF_USBNC_OTG2_CTRL2_UTMI_CLK_VLD(v)))
/*@}*/

/*******************************************************************************
 * HW_USBNC_OTG2_PHY_CFG1 - USB OTG PHY Configuration Register 1
 ******************************************************************************/

/*!
 * @brief HW_USBNC_OTG2_PHY_CFG1 - USB OTG PHY Configuration Register 1 (RW)
 *
 * Reset value: 0x153371CBU
 *
 * The USB_OTGx_PHY_CFG1 register allows control of selected inputs to the USB
 * OTG PHY. Most of these signals are used for parametric tuning of the USB
 * transceiver functions. One signal is used to allow persistent control of the
 * USB_OTG1_CHD_B external pin.
 */
typedef union _hw_usbnc_otg2_phy_cfg1
{
    uint32_t U;
    struct _hw_usbnc_otg2_phy_cfg1_bitfields
    {
        uint32_t COMMONONN : 1;        /*!< [0] Common Block Power-Down Control */
        uint32_t FSEL : 3;             /*!< [3:1] Reference Clock Frequency Select */
        uint32_t COMPDISTUNE0 : 3;     /*!< [6:4] Disconnect Threshold Adjustment
                                        * */
        uint32_t SQRXTUNE0 : 3;        /*!< [9:7] Squelch Threshold Adjustment */
        uint32_t OTGTUNE0 : 3;         /*!< [12:10] VBUS Valid Threshold Adjustment */
        uint32_t TXHSXVTUNE0 : 2;      /*!< [14:13] Transmitter High-Speed
                                        * Crossover Adjustment */
        uint32_t RESERVED0 : 1;        /*!< [15]  */
        uint32_t TXFSLSTUNE0 : 4;      /*!< [19:16] FS/LS Source Impedance
                                        * Adjustment */
        uint32_t TXVREFTUNE0 : 4;      /*!< [23:20] HS DC Voltage Level Adjustment
                                        * */
        uint32_t TXRISETUNE0 : 2;      /*!< [25:24] HS Transmitter Rise/Fall Time
                                        * Adjustment */
        uint32_t TXRESTUNE0 : 2;       /*!< [27:26] USB Source Impedance Adjustment
                                        * */
        uint32_t TXPREEMPAMPTUNE0 : 2; /*!< [29:28] HS Treansmitter
                                        * Pre-Emphasis Current Control */
        uint32_t TXPREEMPPULSETUNE0 : 1; /*!< [30] HS Transmitter
                                        * Pre-Emphasis Duration Control */
        uint32_t CHRGDET_Megamix : 1;  /*!< [31] USB_OTG1_CHD_B output control
                                        * */
    } B;
} hw_usbnc_otg2_phy_cfg1_t;

/*!
 * @name Constants and macros for entire USBNC_OTG2_PHY_CFG1 register
 */
/*@{*/
#define HW_USBNC_OTG2_PHY_CFG1_ADDR(x) ((uintptr_t)(x) + 0x10230U)

#define HW_USBNC_OTG2_PHY_CFG1(x) (*(__IO hw_usbnc_otg2_phy_cfg1_t *) HW_USBNC_OTG2_PHY_CFG1_ADDR(x))
#define HW_USBNC_OTG2_PHY_CFG1_RD(x) (HW_USBNC_OTG2_PHY_CFG1(x).U)
#define HW_USBNC_OTG2_PHY_CFG1_WR(x, v) (HW_USBNC_OTG2_PHY_CFG1(x).U = (v))
#define HW_USBNC_OTG2_PHY_CFG1_SET(x, v) (HW_USBNC_OTG2_PHY_CFG1_WR(x, HW_USBNC_OTG2_PHY_CFG1_RD(x) |  (v)))
#define HW_USBNC_OTG2_PHY_CFG1_CLR(x, v) (HW_USBNC_OTG2_PHY_CFG1_WR(x, HW_USBNC_OTG2_PHY_CFG1_RD(x) & ~(v)))
#define HW_USBNC_OTG2_PHY_CFG1_TOG(x, v) (HW_USBNC_OTG2_PHY_CFG1_WR(x, HW_USBNC_OTG2_PHY_CFG1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBNC_OTG2_PHY_CFG1 bitfields
 */

/*!
 * @name Register USBNC_OTG2_PHY_CFG1, field COMMONONN[0] (RW)
 *
 * This signal controls the power-down signals in the Bias and PLL blocks when
 * the USB OTG PHY is in Suspend or Sleep modes.
 *
 * Values:
 * - 0 - In Suspend or Sleep modes, the Bias and PLL blocks remain powered
 * - 1 - In Suspend or Sleep modes, the Bias and PLL blocks are powered down
 * - 0 -
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG1_COMMONONN (0U) /*!< Bit position for USBNC_OTG2_PHY_CFG1_COMMONONN. */
#define BM_USBNC_OTG2_PHY_CFG1_COMMONONN (0x00000001U) /*!< Bit mask for USBNC_OTG2_PHY_CFG1_COMMONONN. */
#define BS_USBNC_OTG2_PHY_CFG1_COMMONONN (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG1_COMMONONN. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG1_COMMONONN field. */
#define BR_USBNC_OTG2_PHY_CFG1_COMMONONN(x) (HW_USBNC_OTG2_PHY_CFG1(x).B.COMMONONN)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG1_COMMONONN. */
#define BF_USBNC_OTG2_PHY_CFG1_COMMONONN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG1_COMMONONN) & BM_USBNC_OTG2_PHY_CFG1_COMMONONN)

/*! @brief Set the COMMONONN field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG1_COMMONONN(x, v) (HW_USBNC_OTG2_PHY_CFG1_WR(x, (HW_USBNC_OTG2_PHY_CFG1_RD(x) & ~BM_USBNC_OTG2_PHY_CFG1_COMMONONN) | BF_USBNC_OTG2_PHY_CFG1_COMMONONN(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG1, field FSEL[3:1] (RW)
 *
 * This signal selects the USB OTG PHY reference clock frequency for the USB
 * PLL. Note: This SOC is only configured for a 24MHz clock to be routed to the USB
 * OTG PHY PLL clock input. Customers should not change the value of this bit
 * field.
 *
 * Values:
 * - 000 - 9.6 MHz
 * - 001 - 10 MHz
 * - 010 - 12 MHz
 * - 011 - 19.2 MHz
 * - 100 - 20 MHz
 * - 101 - 24 MHz (only valid setting for this SOC)
 * - 110 - Reserved
 * - 111 - 50 MHz
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG1_FSEL (1U)   /*!< Bit position for USBNC_OTG2_PHY_CFG1_FSEL. */
#define BM_USBNC_OTG2_PHY_CFG1_FSEL (0x0000000EU) /*!< Bit mask for USBNC_OTG2_PHY_CFG1_FSEL. */
#define BS_USBNC_OTG2_PHY_CFG1_FSEL (3U)   /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG1_FSEL. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG1_FSEL field. */
#define BR_USBNC_OTG2_PHY_CFG1_FSEL(x) (HW_USBNC_OTG2_PHY_CFG1(x).B.FSEL)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG1_FSEL. */
#define BF_USBNC_OTG2_PHY_CFG1_FSEL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG1_FSEL) & BM_USBNC_OTG2_PHY_CFG1_FSEL)

/*! @brief Set the FSEL field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG1_FSEL(x, v) (HW_USBNC_OTG2_PHY_CFG1_WR(x, (HW_USBNC_OTG2_PHY_CFG1_RD(x) & ~BM_USBNC_OTG2_PHY_CFG1_FSEL) | BF_USBNC_OTG2_PHY_CFG1_FSEL(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG1, field COMPDISTUNE0[6:4] (RW)
 *
 * This bus adjusts the voltage level for the receiver threshold used to detect
 * a disconnect event at the host.
 *
 * Values:
 * - 000 - -6%
 * - 001 - -4.5%
 * - 010 - -3%
 * - 011 - -1.5%
 * - 100 - Design default
 * - 101 - +1.5%
 * - 110 - +3%
 * - 111 - +4.5%
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG1_COMPDISTUNE0 (4U) /*!< Bit position for USBNC_OTG2_PHY_CFG1_COMPDISTUNE0. */
#define BM_USBNC_OTG2_PHY_CFG1_COMPDISTUNE0 (0x00000070U) /*!< Bit mask for USBNC_OTG2_PHY_CFG1_COMPDISTUNE0. */
#define BS_USBNC_OTG2_PHY_CFG1_COMPDISTUNE0 (3U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG1_COMPDISTUNE0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG1_COMPDISTUNE0 field. */
#define BR_USBNC_OTG2_PHY_CFG1_COMPDISTUNE0(x) (HW_USBNC_OTG2_PHY_CFG1(x).B.COMPDISTUNE0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG1_COMPDISTUNE0. */
#define BF_USBNC_OTG2_PHY_CFG1_COMPDISTUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG1_COMPDISTUNE0) & BM_USBNC_OTG2_PHY_CFG1_COMPDISTUNE0)

/*! @brief Set the COMPDISTUNE0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG1_COMPDISTUNE0(x, v) (HW_USBNC_OTG2_PHY_CFG1_WR(x, (HW_USBNC_OTG2_PHY_CFG1_RD(x) & ~BM_USBNC_OTG2_PHY_CFG1_COMPDISTUNE0) | BF_USBNC_OTG2_PHY_CFG1_COMPDISTUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG1, field SQRXTUNE0[9:7] (RW)
 *
 * This bus adjusts the voltage level for the receiver threshold used to detect
 * valid high-speed data.
 *
 * Values:
 * - 000 - +15%
 * - 001 - +10%
 * - 010 - +5%
 * - 011 - Design default
 * - 100 - -5%
 * - 101 - -10%
 * - 110 - -15%
 * - 111 - -20%
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG1_SQRXTUNE0 (7U) /*!< Bit position for USBNC_OTG2_PHY_CFG1_SQRXTUNE0. */
#define BM_USBNC_OTG2_PHY_CFG1_SQRXTUNE0 (0x00000380U) /*!< Bit mask for USBNC_OTG2_PHY_CFG1_SQRXTUNE0. */
#define BS_USBNC_OTG2_PHY_CFG1_SQRXTUNE0 (3U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG1_SQRXTUNE0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG1_SQRXTUNE0 field. */
#define BR_USBNC_OTG2_PHY_CFG1_SQRXTUNE0(x) (HW_USBNC_OTG2_PHY_CFG1(x).B.SQRXTUNE0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG1_SQRXTUNE0. */
#define BF_USBNC_OTG2_PHY_CFG1_SQRXTUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG1_SQRXTUNE0) & BM_USBNC_OTG2_PHY_CFG1_SQRXTUNE0)

/*! @brief Set the SQRXTUNE0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG1_SQRXTUNE0(x, v) (HW_USBNC_OTG2_PHY_CFG1_WR(x, (HW_USBNC_OTG2_PHY_CFG1_RD(x) & ~BM_USBNC_OTG2_PHY_CFG1_SQRXTUNE0) | BF_USBNC_OTG2_PHY_CFG1_SQRXTUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG1, field OTGTUNE0[12:10] (RW)
 *
 * This bus adjust the voltage level for the VBUS VALID threshold.
 *
 * Values:
 * - 000 - -6%
 * - 001 - -4.5%
 * - 010 - -3%
 * - 011 - -1.5%
 * - 100 - Design default
 * - 101 - +1.5%
 * - 110 - +3%
 * - 111 - +4.5%
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG1_OTGTUNE0 (10U) /*!< Bit position for USBNC_OTG2_PHY_CFG1_OTGTUNE0. */
#define BM_USBNC_OTG2_PHY_CFG1_OTGTUNE0 (0x00001C00U) /*!< Bit mask for USBNC_OTG2_PHY_CFG1_OTGTUNE0. */
#define BS_USBNC_OTG2_PHY_CFG1_OTGTUNE0 (3U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG1_OTGTUNE0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG1_OTGTUNE0 field. */
#define BR_USBNC_OTG2_PHY_CFG1_OTGTUNE0(x) (HW_USBNC_OTG2_PHY_CFG1(x).B.OTGTUNE0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG1_OTGTUNE0. */
#define BF_USBNC_OTG2_PHY_CFG1_OTGTUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG1_OTGTUNE0) & BM_USBNC_OTG2_PHY_CFG1_OTGTUNE0)

/*! @brief Set the OTGTUNE0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG1_OTGTUNE0(x, v) (HW_USBNC_OTG2_PHY_CFG1_WR(x, (HW_USBNC_OTG2_PHY_CFG1_RD(x) & ~BM_USBNC_OTG2_PHY_CFG1_OTGTUNE0) | BF_USBNC_OTG2_PHY_CFG1_OTGTUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG1, field TXHSXVTUNE0[14:13] (RW)
 *
 * This bus adjusts the voltage at which the USB_OTG*_DP and USB_OTG*_DN signals
 * cross while transmitting in HS mode.
 *
 * Values:
 * - 00 - Reserved
 * - 01 - -15mV
 * - 10 - +15mV
 * - 11 - Design default
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG1_TXHSXVTUNE0 (13U) /*!< Bit position for USBNC_OTG2_PHY_CFG1_TXHSXVTUNE0. */
#define BM_USBNC_OTG2_PHY_CFG1_TXHSXVTUNE0 (0x00006000U) /*!< Bit mask for USBNC_OTG2_PHY_CFG1_TXHSXVTUNE0. */
#define BS_USBNC_OTG2_PHY_CFG1_TXHSXVTUNE0 (2U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG1_TXHSXVTUNE0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG1_TXHSXVTUNE0 field. */
#define BR_USBNC_OTG2_PHY_CFG1_TXHSXVTUNE0(x) (HW_USBNC_OTG2_PHY_CFG1(x).B.TXHSXVTUNE0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG1_TXHSXVTUNE0. */
#define BF_USBNC_OTG2_PHY_CFG1_TXHSXVTUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG1_TXHSXVTUNE0) & BM_USBNC_OTG2_PHY_CFG1_TXHSXVTUNE0)

/*! @brief Set the TXHSXVTUNE0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG1_TXHSXVTUNE0(x, v) (HW_USBNC_OTG2_PHY_CFG1_WR(x, (HW_USBNC_OTG2_PHY_CFG1_RD(x) & ~BM_USBNC_OTG2_PHY_CFG1_TXHSXVTUNE0) | BF_USBNC_OTG2_PHY_CFG1_TXHSXVTUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG1, field TXFSLSTUNE0[19:16] (RW)
 *
 * This bus adjusts the low- and full-speed single-ended source impedance while
 * driving high. The adjustment values listed are based on nominal process,
 * voltage, and temperature conditions.
 *
 * Values:
 * - 0000 - +5%
 * - 0001 - +2.5%
 * - 0011 - Design default
 * - 0111 - -2.5%
 * - 1111 - -5%
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG1_TXFSLSTUNE0 (16U) /*!< Bit position for USBNC_OTG2_PHY_CFG1_TXFSLSTUNE0. */
#define BM_USBNC_OTG2_PHY_CFG1_TXFSLSTUNE0 (0x000F0000U) /*!< Bit mask for USBNC_OTG2_PHY_CFG1_TXFSLSTUNE0. */
#define BS_USBNC_OTG2_PHY_CFG1_TXFSLSTUNE0 (4U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG1_TXFSLSTUNE0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG1_TXFSLSTUNE0 field. */
#define BR_USBNC_OTG2_PHY_CFG1_TXFSLSTUNE0(x) (HW_USBNC_OTG2_PHY_CFG1(x).B.TXFSLSTUNE0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG1_TXFSLSTUNE0. */
#define BF_USBNC_OTG2_PHY_CFG1_TXFSLSTUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG1_TXFSLSTUNE0) & BM_USBNC_OTG2_PHY_CFG1_TXFSLSTUNE0)

/*! @brief Set the TXFSLSTUNE0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG1_TXFSLSTUNE0(x, v) (HW_USBNC_OTG2_PHY_CFG1_WR(x, (HW_USBNC_OTG2_PHY_CFG1_RD(x) & ~BM_USBNC_OTG2_PHY_CFG1_TXFSLSTUNE0) | BF_USBNC_OTG2_PHY_CFG1_TXFSLSTUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG1, field TXVREFTUNE0[23:20] (RW)
 *
 * This bus adjust the high-speed transmitter DC level voltage.
 *
 * Values:
 * - 0000 - -6%
 * - 0001 - -4%
 * - 0010 - -2%
 * - 0011 - Design default
 * - 0100 - +2%
 * - 0101 - +4%
 * - 0110 - +6%
 * - 0111 - +8%
 * - 1000 - +10%
 * - 1001 - +12%
 * - 1010 - +14%
 * - 1011 - +16%
 * - 1100 - +18%
 * - 1101 - +20%
 * - 1110 - +22%
 * - 1111 - +24%
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG1_TXVREFTUNE0 (20U) /*!< Bit position for USBNC_OTG2_PHY_CFG1_TXVREFTUNE0. */
#define BM_USBNC_OTG2_PHY_CFG1_TXVREFTUNE0 (0x00F00000U) /*!< Bit mask for USBNC_OTG2_PHY_CFG1_TXVREFTUNE0. */
#define BS_USBNC_OTG2_PHY_CFG1_TXVREFTUNE0 (4U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG1_TXVREFTUNE0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG1_TXVREFTUNE0 field. */
#define BR_USBNC_OTG2_PHY_CFG1_TXVREFTUNE0(x) (HW_USBNC_OTG2_PHY_CFG1(x).B.TXVREFTUNE0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG1_TXVREFTUNE0. */
#define BF_USBNC_OTG2_PHY_CFG1_TXVREFTUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG1_TXVREFTUNE0) & BM_USBNC_OTG2_PHY_CFG1_TXVREFTUNE0)

/*! @brief Set the TXVREFTUNE0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG1_TXVREFTUNE0(x, v) (HW_USBNC_OTG2_PHY_CFG1_WR(x, (HW_USBNC_OTG2_PHY_CFG1_RD(x) & ~BM_USBNC_OTG2_PHY_CFG1_TXVREFTUNE0) | BF_USBNC_OTG2_PHY_CFG1_TXVREFTUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG1, field TXRISETUNE0[25:24] (RW)
 *
 * This bus adjust the rise/fall times of the high-speed transmitter waveform.
 *
 * Values:
 * - 00 - -10%
 * - 01 - Design default
 * - 10 - +15%
 * - 11 - +20%
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG1_TXRISETUNE0 (24U) /*!< Bit position for USBNC_OTG2_PHY_CFG1_TXRISETUNE0. */
#define BM_USBNC_OTG2_PHY_CFG1_TXRISETUNE0 (0x03000000U) /*!< Bit mask for USBNC_OTG2_PHY_CFG1_TXRISETUNE0. */
#define BS_USBNC_OTG2_PHY_CFG1_TXRISETUNE0 (2U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG1_TXRISETUNE0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG1_TXRISETUNE0 field. */
#define BR_USBNC_OTG2_PHY_CFG1_TXRISETUNE0(x) (HW_USBNC_OTG2_PHY_CFG1(x).B.TXRISETUNE0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG1_TXRISETUNE0. */
#define BF_USBNC_OTG2_PHY_CFG1_TXRISETUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG1_TXRISETUNE0) & BM_USBNC_OTG2_PHY_CFG1_TXRISETUNE0)

/*! @brief Set the TXRISETUNE0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG1_TXRISETUNE0(x, v) (HW_USBNC_OTG2_PHY_CFG1_WR(x, (HW_USBNC_OTG2_PHY_CFG1_RD(x) & ~BM_USBNC_OTG2_PHY_CFG1_TXRISETUNE0) | BF_USBNC_OTG2_PHY_CFG1_TXRISETUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG1, field TXRESTUNE0[27:26] (RW)
 *
 * In some applications, there can be significant series resistance on the USB
 * DP/DN path between the USB_OTG*_DP/USB_OTG*_DN pins tns and the USB cable. This
 * bus adjusts the driver source impedance to compensate for that added
 * resistance. Note: Any setting other than the design default can cause HS/FS signal
 * integrity changes along with variation across process, voltage, and temperature
 * conditions that affect compliance with USB 2.0 specification limits.
 *
 * Values:
 * - 00 - Source impedance is increased by approximately 1.5 ohm
 * - 01 - Design default
 * - 10 - Source impedance is decreased by approximately 2 ohm
 * - 11 - Source impedance is decreased by approximately 4 ohm
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG1_TXRESTUNE0 (26U) /*!< Bit position for USBNC_OTG2_PHY_CFG1_TXRESTUNE0. */
#define BM_USBNC_OTG2_PHY_CFG1_TXRESTUNE0 (0x0C000000U) /*!< Bit mask for USBNC_OTG2_PHY_CFG1_TXRESTUNE0. */
#define BS_USBNC_OTG2_PHY_CFG1_TXRESTUNE0 (2U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG1_TXRESTUNE0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG1_TXRESTUNE0 field. */
#define BR_USBNC_OTG2_PHY_CFG1_TXRESTUNE0(x) (HW_USBNC_OTG2_PHY_CFG1(x).B.TXRESTUNE0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG1_TXRESTUNE0. */
#define BF_USBNC_OTG2_PHY_CFG1_TXRESTUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG1_TXRESTUNE0) & BM_USBNC_OTG2_PHY_CFG1_TXRESTUNE0)

/*! @brief Set the TXRESTUNE0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG1_TXRESTUNE0(x, v) (HW_USBNC_OTG2_PHY_CFG1_WR(x, (HW_USBNC_OTG2_PHY_CFG1_RD(x) & ~BM_USBNC_OTG2_PHY_CFG1_TXRESTUNE0) | BF_USBNC_OTG2_PHY_CFG1_TXRESTUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG1, field TXPREEMPAMPTUNE0[29:28] (RW)
 *
 * This signal controls the amount of current sourced to the USB_OTG*_DP and
 * USB_OTG*_DN pins after a J-to-K or K-to-J transition. The HS Transmitter
 * pre-emphasis current is defined in terms of unit amounts. One unit amount is
 * approximately 600uA and is defined as 1X pre-emphasis current.
 *
 * Values:
 * - 00 - HS Transmitter pre-emphasis is disabled
 * - 01 - HS Transmitter pre-emphasis circuit sources 1X pre-emphasis current
 *     (design default)
 * - 10 - HS Transmitter pre-emphasis circuit sources 2X pre-emphasis current
 * - 11 - HS Transmitter pre-emphasis circuit sources 3X pre-emphasis current
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG1_TXPREEMPAMPTUNE0 (28U) /*!< Bit position for USBNC_OTG2_PHY_CFG1_TXPREEMPAMPTUNE0. */
#define BM_USBNC_OTG2_PHY_CFG1_TXPREEMPAMPTUNE0 (0x30000000U) /*!< Bit mask for USBNC_OTG2_PHY_CFG1_TXPREEMPAMPTUNE0. */
#define BS_USBNC_OTG2_PHY_CFG1_TXPREEMPAMPTUNE0 (2U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG1_TXPREEMPAMPTUNE0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG1_TXPREEMPAMPTUNE0 field. */
#define BR_USBNC_OTG2_PHY_CFG1_TXPREEMPAMPTUNE0(x) (HW_USBNC_OTG2_PHY_CFG1(x).B.TXPREEMPAMPTUNE0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG1_TXPREEMPAMPTUNE0. */
#define BF_USBNC_OTG2_PHY_CFG1_TXPREEMPAMPTUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG1_TXPREEMPAMPTUNE0) & BM_USBNC_OTG2_PHY_CFG1_TXPREEMPAMPTUNE0)

/*! @brief Set the TXPREEMPAMPTUNE0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG1_TXPREEMPAMPTUNE0(x, v) (HW_USBNC_OTG2_PHY_CFG1_WR(x, (HW_USBNC_OTG2_PHY_CFG1_RD(x) & ~BM_USBNC_OTG2_PHY_CFG1_TXPREEMPAMPTUNE0) | BF_USBNC_OTG2_PHY_CFG1_TXPREEMPAMPTUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG1, field TXPREEMPPULSETUNE0[30] (RW)
 *
 * This signal controls the duration for which the HS pre-emphais current is
 * sourced on the the USB_OTG*_DP and USB_OTG*DN pins. The HS Transmitter
 * pre-emphasis duration is defined in terms of unit amounts. One unit of pre-emphasis
 * duration is approximately 580ps and is defined as 1X pre-emphasis duration. This
 * signal is valid only if TXPREEMPAMPTUNE (USBNC_USB_OTGx_PHY_CFG1[29:28]) is NOT
 * set to 2'b00.
 *
 * Values:
 * - 0 - 2X, long pre-emphasis current duration (design default)
 * - 1 - 1X, short pre-emphasis current duration
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG1_TXPREEMPPULSETUNE0 (30U) /*!< Bit position for USBNC_OTG2_PHY_CFG1_TXPREEMPPULSETUNE0. */
#define BM_USBNC_OTG2_PHY_CFG1_TXPREEMPPULSETUNE0 (0x40000000U) /*!< Bit mask for USBNC_OTG2_PHY_CFG1_TXPREEMPPULSETUNE0. */
#define BS_USBNC_OTG2_PHY_CFG1_TXPREEMPPULSETUNE0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG1_TXPREEMPPULSETUNE0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG1_TXPREEMPPULSETUNE0 field. */
#define BR_USBNC_OTG2_PHY_CFG1_TXPREEMPPULSETUNE0(x) (HW_USBNC_OTG2_PHY_CFG1(x).B.TXPREEMPPULSETUNE0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG1_TXPREEMPPULSETUNE0. */
#define BF_USBNC_OTG2_PHY_CFG1_TXPREEMPPULSETUNE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG1_TXPREEMPPULSETUNE0) & BM_USBNC_OTG2_PHY_CFG1_TXPREEMPPULSETUNE0)

/*! @brief Set the TXPREEMPPULSETUNE0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG1_TXPREEMPPULSETUNE0(x, v) (HW_USBNC_OTG2_PHY_CFG1_WR(x, (HW_USBNC_OTG2_PHY_CFG1_RD(x) & ~BM_USBNC_OTG2_PHY_CFG1_TXPREEMPPULSETUNE0) | BF_USBNC_OTG2_PHY_CFG1_TXPREEMPPULSETUNE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG1, field CHRGDET_Megamix[31] (RW)
 *
 * This signal controls the state of the USB_OTG1_CHD_B external pin together
 * with the CHRGDET (USBNC_USB_OTG1_PHY_STATUS[29] signal during periods when the
 * SOC is fully powered. If either CHRGDET_Megamix or CHRGDET are set to 1'b1,
 * then USB_OTG1_CHD_B will be pulled low. If both CHRGDET_Megamix and CHRGDET are
 * set to 1'b0, then USB_OTG1_CHD_B will be pulled high by its external open-drain
 * pull-up resistor. Note: The instance of this bit field for the USB OTG2 PHY
 * does not produce results on an external pin. The R/W register bit may still be
 * used as a memory location to store results of Battery Charger detection tests
 * for USB OTG2 PHY.
 *
 * Values:
 * - 0 - The external state of USB_OTG1_CHD_B is only controlled by the state of
 *     the CHRGDET signal
 * - 1 - The external state of USB_OTG1_CHD_B is forced low
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG1_CHRGDET_Megamix (31U) /*!< Bit position for USBNC_OTG2_PHY_CFG1_CHRGDET_Megamix. */
#define BM_USBNC_OTG2_PHY_CFG1_CHRGDET_Megamix (0x80000000U) /*!< Bit mask for USBNC_OTG2_PHY_CFG1_CHRGDET_Megamix. */
#define BS_USBNC_OTG2_PHY_CFG1_CHRGDET_Megamix (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG1_CHRGDET_Megamix. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG1_CHRGDET_Megamix field. */
#define BR_USBNC_OTG2_PHY_CFG1_CHRGDET_Megamix(x) (HW_USBNC_OTG2_PHY_CFG1(x).B.CHRGDET_Megamix)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG1_CHRGDET_Megamix. */
#define BF_USBNC_OTG2_PHY_CFG1_CHRGDET_Megamix(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG1_CHRGDET_Megamix) & BM_USBNC_OTG2_PHY_CFG1_CHRGDET_Megamix)

/*! @brief Set the CHRGDET_Megamix field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG1_CHRGDET_Megamix(x, v) (HW_USBNC_OTG2_PHY_CFG1_WR(x, (HW_USBNC_OTG2_PHY_CFG1_RD(x) & ~BM_USBNC_OTG2_PHY_CFG1_CHRGDET_Megamix) | BF_USBNC_OTG2_PHY_CFG1_CHRGDET_Megamix(v)))
/*@}*/

/*******************************************************************************
 * HW_USBNC_OTG2_PHY_CFG2 - USB OTG PHY Configuration Register 2
 ******************************************************************************/

/*!
 * @brief HW_USBNC_OTG2_PHY_CFG2 - USB OTG PHY Configuration Register 2 (RW)
 *
 * Reset value: 0xF0010020U
 *
 * The USB_OTGx_PHY_CFG2 register allows control of selected inputs to the USB
 * OTG PHY. Most of these signals are used for configuration of VBUS detection,
 * ADP (Attach Detection Protocol), and Battery Charging ACA (Accesory Charging
 * Adaptor) functions.
 */
typedef union _hw_usbnc_otg2_phy_cfg2
{
    uint32_t U;
    struct _hw_usbnc_otg2_phy_cfg2_bitfields
    {
        uint32_t CHRGSEL : 1;          /*!< [0] Battery Charging Source Select */
        uint32_t VDATDETENB0 : 1;      /*!< [1] Battery Charging Attach / Connect
                                        * Detection Enable */
        uint32_t VDATSRCENB0 : 1;      /*!< [2] Battery Charging Source Select */
        uint32_t DCDENB : 1;           /*!< [3] Data Contact Detection Enable */
        uint32_t ACAENB0 : 1;          /*!< [4] ACA USB_OTG*_ID Pin Resistance
                                        * Detection Enable */
        uint32_t SLEEPM0 : 1;          /*!< [5] Sleep Mode Assertion */
        uint32_t LOOPBACKENB0 : 1;     /*!< [6] Loopback Test Enable */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t TXBITSTUFFEN0 : 1;    /*!< [8] Low-Byte Transmit Bit-Stuffing
                                        * Enable */
        uint32_t TXBITSTUFFENH0 : 1;   /*!< [9] High-Byte Transmit Bit-Stuffing
                                        * Enable */
        uint32_t OTGDISABLE0 : 1;      /*!< [10] OTG Block Disable */
        uint32_t ADPCHRG0 : 1;         /*!< [11] VBUS Input ADP Charge Enable */
        uint32_t ADPDISCHRG0 : 1;      /*!< [12] VBUS Input ADP Discharge Enable */
        uint32_t ADPPRBENB0 : 1;       /*!< [13] ADP Probe Enable */
        uint32_t VBUSVLDEXTSEL0 : 1;   /*!< [14] External VBUS Valid Select */
        uint32_t VBUSVLDEXT : 1;       /*!< [15] External VBUS Valid Indicator */
        uint32_t DRVVBUS0 : 1;         /*!< [16] VBUS Valid Comparator Enable */
        uint32_t RESERVED1 : 15;       /*!< [31:17]  */
    } B;
} hw_usbnc_otg2_phy_cfg2_t;

/*!
 * @name Constants and macros for entire USBNC_OTG2_PHY_CFG2 register
 */
/*@{*/
#define HW_USBNC_OTG2_PHY_CFG2_ADDR(x) ((uintptr_t)(x) + 0x10234U)

#define HW_USBNC_OTG2_PHY_CFG2(x) (*(__IO hw_usbnc_otg2_phy_cfg2_t *) HW_USBNC_OTG2_PHY_CFG2_ADDR(x))
#define HW_USBNC_OTG2_PHY_CFG2_RD(x) (HW_USBNC_OTG2_PHY_CFG2(x).U)
#define HW_USBNC_OTG2_PHY_CFG2_WR(x, v) (HW_USBNC_OTG2_PHY_CFG2(x).U = (v))
#define HW_USBNC_OTG2_PHY_CFG2_SET(x, v) (HW_USBNC_OTG2_PHY_CFG2_WR(x, HW_USBNC_OTG2_PHY_CFG2_RD(x) |  (v)))
#define HW_USBNC_OTG2_PHY_CFG2_CLR(x, v) (HW_USBNC_OTG2_PHY_CFG2_WR(x, HW_USBNC_OTG2_PHY_CFG2_RD(x) & ~(v)))
#define HW_USBNC_OTG2_PHY_CFG2_TOG(x, v) (HW_USBNC_OTG2_PHY_CFG2_WR(x, HW_USBNC_OTG2_PHY_CFG2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBNC_OTG2_PHY_CFG2 bitfields
 */

/*!
 * @name Register USBNC_OTG2_PHY_CFG2, field CHRGSEL[0] (RW)
 *
 * This signal is used to select the Battery Charging detection connections per
 * the USB Battery Charging Specification revision 1.2. It determines which of
 * USB_OTG*_DP / USB_OTG*_DN has the VD*_SRC voltage source and which has the
 * ID*_SINK current sink. Results are reported in USBNC_USB_OTGx_PHY_STATUS[29]. Note:
 * During normal USB operation of the USB OTG PHY, set this signal to 1'b0.
 *
 * Values:
 * - 0 - VDP_SRC is connected to USB_OTG*_DP and IDM_SINK is connected to
 *     USB_OTG*_DN. Used for Primary Detection.
 * - 1 - VDM_SRC is connected to USB_OTG*_DN and IDP_SINK is connected to
 *     USB_OTG*_DP. Used for Secondary Detection.
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG2_CHRGSEL (0U) /*!< Bit position for USBNC_OTG2_PHY_CFG2_CHRGSEL. */
#define BM_USBNC_OTG2_PHY_CFG2_CHRGSEL (0x00000001U) /*!< Bit mask for USBNC_OTG2_PHY_CFG2_CHRGSEL. */
#define BS_USBNC_OTG2_PHY_CFG2_CHRGSEL (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG2_CHRGSEL. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG2_CHRGSEL field. */
#define BR_USBNC_OTG2_PHY_CFG2_CHRGSEL(x) (HW_USBNC_OTG2_PHY_CFG2(x).B.CHRGSEL)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG2_CHRGSEL. */
#define BF_USBNC_OTG2_PHY_CFG2_CHRGSEL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG2_CHRGSEL) & BM_USBNC_OTG2_PHY_CFG2_CHRGSEL)

/*! @brief Set the CHRGSEL field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG2_CHRGSEL(x, v) (HW_USBNC_OTG2_PHY_CFG2_WR(x, (HW_USBNC_OTG2_PHY_CFG2_RD(x) & ~BM_USBNC_OTG2_PHY_CFG2_CHRGSEL) | BF_USBNC_OTG2_PHY_CFG2_CHRGSEL(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG2, field VDATDETENB0[1] (RW)
 *
 * This signal is used to enable attach/connect detection per the USB Battery
 * Charging Specification revision 1.2. Results are reported by using the
 * single-ended receiver status in USBNC_USB_OTGx_PHY_STATUS[1:0]. Note: During normal USB
 * operation of the USB OTG PHY, set this signal to 1'b0.
 *
 * Values:
 * - 0 - IDP_SRC current source compliant to VLGC_HI connected to USB_OTG*_DP
 *     pin is disabled
 * - 1 - IDP_SRC current source compliant to VLGC_HI connected to USB_OTG*_DP
 *     pin is enabled
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG2_VDATDETENB0 (1U) /*!< Bit position for USBNC_OTG2_PHY_CFG2_VDATDETENB0. */
#define BM_USBNC_OTG2_PHY_CFG2_VDATDETENB0 (0x00000002U) /*!< Bit mask for USBNC_OTG2_PHY_CFG2_VDATDETENB0. */
#define BS_USBNC_OTG2_PHY_CFG2_VDATDETENB0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG2_VDATDETENB0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG2_VDATDETENB0 field. */
#define BR_USBNC_OTG2_PHY_CFG2_VDATDETENB0(x) (HW_USBNC_OTG2_PHY_CFG2(x).B.VDATDETENB0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG2_VDATDETENB0. */
#define BF_USBNC_OTG2_PHY_CFG2_VDATDETENB0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG2_VDATDETENB0) & BM_USBNC_OTG2_PHY_CFG2_VDATDETENB0)

/*! @brief Set the VDATDETENB0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG2_VDATDETENB0(x, v) (HW_USBNC_OTG2_PHY_CFG2_WR(x, (HW_USBNC_OTG2_PHY_CFG2_RD(x) & ~BM_USBNC_OTG2_PHY_CFG2_VDATDETENB0) | BF_USBNC_OTG2_PHY_CFG2_VDATDETENB0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG2, field VDATSRCENB0[2] (RW)
 *
 * This signal is used to enable the VD*_SRC voltage source and ID*SINK current
 * sink per the USB Battery Charging Specification revision 1.2. Pin selection
 * for the voltage source and the current sink are controlled by
 * USBNC_USB_OTGx_PHY_CFG2[0]. Note: During normal USB operation of the USB OTG PHY, set this
 * signal to 1'b0.
 *
 * Values:
 * - 0 - VD*_SRC and ID*_SINK are disabled
 * - 1 - VD*_SRC and ID*_SINK are enabled
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG2_VDATSRCENB0 (2U) /*!< Bit position for USBNC_OTG2_PHY_CFG2_VDATSRCENB0. */
#define BM_USBNC_OTG2_PHY_CFG2_VDATSRCENB0 (0x00000004U) /*!< Bit mask for USBNC_OTG2_PHY_CFG2_VDATSRCENB0. */
#define BS_USBNC_OTG2_PHY_CFG2_VDATSRCENB0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG2_VDATSRCENB0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG2_VDATSRCENB0 field. */
#define BR_USBNC_OTG2_PHY_CFG2_VDATSRCENB0(x) (HW_USBNC_OTG2_PHY_CFG2(x).B.VDATSRCENB0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG2_VDATSRCENB0. */
#define BF_USBNC_OTG2_PHY_CFG2_VDATSRCENB0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG2_VDATSRCENB0) & BM_USBNC_OTG2_PHY_CFG2_VDATSRCENB0)

/*! @brief Set the VDATSRCENB0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG2_VDATSRCENB0(x, v) (HW_USBNC_OTG2_PHY_CFG2_WR(x, (HW_USBNC_OTG2_PHY_CFG2_RD(x) & ~BM_USBNC_OTG2_PHY_CFG2_VDATSRCENB0) | BF_USBNC_OTG2_PHY_CFG2_VDATSRCENB0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG2, field DCDENB[3] (RW)
 *
 * This signal enables current sourcing on the USB_OTG*_DP pin and pull-down
 * resistaince on the USB_OTG*_DN pin for Data Contact Detect (DCD) per the USB
 * Battery Charging Specification revision 1.2. Note: During normal USB operation of
 * the USB OTG PHY, set this signal to 1'b0.
 *
 * Values:
 * - 0 - IDP_SRC current and RDM_DWN pull-down resistance are disabled
 * - 1 - IDP_SRC current and RDM_DWN pull-down resistance are enabled
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG2_DCDENB (3U) /*!< Bit position for USBNC_OTG2_PHY_CFG2_DCDENB. */
#define BM_USBNC_OTG2_PHY_CFG2_DCDENB (0x00000008U) /*!< Bit mask for USBNC_OTG2_PHY_CFG2_DCDENB. */
#define BS_USBNC_OTG2_PHY_CFG2_DCDENB (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG2_DCDENB. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG2_DCDENB field. */
#define BR_USBNC_OTG2_PHY_CFG2_DCDENB(x) (HW_USBNC_OTG2_PHY_CFG2(x).B.DCDENB)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG2_DCDENB. */
#define BF_USBNC_OTG2_PHY_CFG2_DCDENB(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG2_DCDENB) & BM_USBNC_OTG2_PHY_CFG2_DCDENB)

/*! @brief Set the DCDENB field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG2_DCDENB(x, v) (HW_USBNC_OTG2_PHY_CFG2_WR(x, (HW_USBNC_OTG2_PHY_CFG2_RD(x) & ~BM_USBNC_OTG2_PHY_CFG2_DCDENB) | BF_USBNC_OTG2_PHY_CFG2_DCDENB(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG2, field ACAENB0[4] (RW)
 *
 * This signal enables the circuitry to detect resistance on the USB_OTG*_ID pin
 * if the USB cable is connected to an ACA (Acessory Charger Adaptor). When
 * ACAENB0 is set to 1'b1, IDPULLUP0 (USB_OTGSC[26]) is overridden and set to 1'b0
 * internally to the USB OTG PHY. The RID* results are reported in
 * USBNC_USB_OTGx_PHY_STATUS[28:24].
 *
 * Values:
 * - 0 - Disables detection of resistance on the USB_OTG*_ID pin
 * - 1 - Enables detection of resistance on the USB_OTG*_ID pin
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG2_ACAENB0 (4U) /*!< Bit position for USBNC_OTG2_PHY_CFG2_ACAENB0. */
#define BM_USBNC_OTG2_PHY_CFG2_ACAENB0 (0x00000010U) /*!< Bit mask for USBNC_OTG2_PHY_CFG2_ACAENB0. */
#define BS_USBNC_OTG2_PHY_CFG2_ACAENB0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG2_ACAENB0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG2_ACAENB0 field. */
#define BR_USBNC_OTG2_PHY_CFG2_ACAENB0(x) (HW_USBNC_OTG2_PHY_CFG2(x).B.ACAENB0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG2_ACAENB0. */
#define BF_USBNC_OTG2_PHY_CFG2_ACAENB0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG2_ACAENB0) & BM_USBNC_OTG2_PHY_CFG2_ACAENB0)

/*! @brief Set the ACAENB0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG2_ACAENB0(x, v) (HW_USBNC_OTG2_PHY_CFG2_WR(x, (HW_USBNC_OTG2_PHY_CFG2_RD(x) & ~BM_USBNC_OTG2_PHY_CFG2_ACAENB0) | BF_USBNC_OTG2_PHY_CFG2_ACAENB0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG2, field SLEEPM0[5] (RW)
 *
 * Asserting this signal places the USB OTG PHY in Sleep mode accourding to the
 * USB 2.0 Link Power Management (LPM) addendum to the USB 2.0 specification. In
 * Sleep mode, the transmitter is tri-stated and the USB OTG PHY circuits used in
 * this SOC are powered down. Note:The USB controller used in this SOC does not
 * support LPM operation. Leave this bit set to 1'b1 for normal operation.
 *
 * Values:
 * - 0 - Sleep mode
 * - 1 - Normal operating mode
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG2_SLEEPM0 (5U) /*!< Bit position for USBNC_OTG2_PHY_CFG2_SLEEPM0. */
#define BM_USBNC_OTG2_PHY_CFG2_SLEEPM0 (0x00000020U) /*!< Bit mask for USBNC_OTG2_PHY_CFG2_SLEEPM0. */
#define BS_USBNC_OTG2_PHY_CFG2_SLEEPM0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG2_SLEEPM0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG2_SLEEPM0 field. */
#define BR_USBNC_OTG2_PHY_CFG2_SLEEPM0(x) (HW_USBNC_OTG2_PHY_CFG2(x).B.SLEEPM0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG2_SLEEPM0. */
#define BF_USBNC_OTG2_PHY_CFG2_SLEEPM0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG2_SLEEPM0) & BM_USBNC_OTG2_PHY_CFG2_SLEEPM0)

/*! @brief Set the SLEEPM0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG2_SLEEPM0(x, v) (HW_USBNC_OTG2_PHY_CFG2_WR(x, (HW_USBNC_OTG2_PHY_CFG2_RD(x) & ~BM_USBNC_OTG2_PHY_CFG2_SLEEPM0) | BF_USBNC_OTG2_PHY_CFG2_SLEEPM0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG2, field LOOPBACKENB0[6] (RW)
 *
 * This signal places the USB OTG PHY in Loopback mode, which enables the
 * receive and transmit logic concurrently. Loopback mode is for test purposes only; it
 * cannot be used for normal operation.
 *
 * Values:
 * - 0 - During data transmission, the receive logic is disabled
 * - 1 - During data transmission, the receive logic is enabled
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG2_LOOPBACKENB0 (6U) /*!< Bit position for USBNC_OTG2_PHY_CFG2_LOOPBACKENB0. */
#define BM_USBNC_OTG2_PHY_CFG2_LOOPBACKENB0 (0x00000040U) /*!< Bit mask for USBNC_OTG2_PHY_CFG2_LOOPBACKENB0. */
#define BS_USBNC_OTG2_PHY_CFG2_LOOPBACKENB0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG2_LOOPBACKENB0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG2_LOOPBACKENB0 field. */
#define BR_USBNC_OTG2_PHY_CFG2_LOOPBACKENB0(x) (HW_USBNC_OTG2_PHY_CFG2(x).B.LOOPBACKENB0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG2_LOOPBACKENB0. */
#define BF_USBNC_OTG2_PHY_CFG2_LOOPBACKENB0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG2_LOOPBACKENB0) & BM_USBNC_OTG2_PHY_CFG2_LOOPBACKENB0)

/*! @brief Set the LOOPBACKENB0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG2_LOOPBACKENB0(x, v) (HW_USBNC_OTG2_PHY_CFG2_WR(x, (HW_USBNC_OTG2_PHY_CFG2_RD(x) & ~BM_USBNC_OTG2_PHY_CFG2_LOOPBACKENB0) | BF_USBNC_OTG2_PHY_CFG2_LOOPBACKENB0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG2, field TXBITSTUFFEN0[8] (RW)
 *
 * This controller signal controls bit stuffing on DATAIN[7:0] when OPMODE[1:0]
 * = 2'b11. For more information on the use of this setting see UTMI+
 * Specification Section 2.2.1.12 .
 *
 * Values:
 * - 0 - Bit stuffing is disabled
 * - 1 - Bit stuffing is enabled
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG2_TXBITSTUFFEN0 (8U) /*!< Bit position for USBNC_OTG2_PHY_CFG2_TXBITSTUFFEN0. */
#define BM_USBNC_OTG2_PHY_CFG2_TXBITSTUFFEN0 (0x00000100U) /*!< Bit mask for USBNC_OTG2_PHY_CFG2_TXBITSTUFFEN0. */
#define BS_USBNC_OTG2_PHY_CFG2_TXBITSTUFFEN0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG2_TXBITSTUFFEN0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG2_TXBITSTUFFEN0 field. */
#define BR_USBNC_OTG2_PHY_CFG2_TXBITSTUFFEN0(x) (HW_USBNC_OTG2_PHY_CFG2(x).B.TXBITSTUFFEN0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG2_TXBITSTUFFEN0. */
#define BF_USBNC_OTG2_PHY_CFG2_TXBITSTUFFEN0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG2_TXBITSTUFFEN0) & BM_USBNC_OTG2_PHY_CFG2_TXBITSTUFFEN0)

/*! @brief Set the TXBITSTUFFEN0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG2_TXBITSTUFFEN0(x, v) (HW_USBNC_OTG2_PHY_CFG2_WR(x, (HW_USBNC_OTG2_PHY_CFG2_RD(x) & ~BM_USBNC_OTG2_PHY_CFG2_TXBITSTUFFEN0) | BF_USBNC_OTG2_PHY_CFG2_TXBITSTUFFEN0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG2, field TXBITSTUFFENH0[9] (RW)
 *
 * This controller signal controls bit stuffing on DATAINH[7:0] when OPMODE[1:0]
 * = 2'b11. For more information on the use of this setting see UTMI+
 * Specification Section 2.2.1.12 .
 *
 * Values:
 * - 0 - Bit stuffing is disabled
 * - 1 - Bit stuffing is enabled
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG2_TXBITSTUFFENH0 (9U) /*!< Bit position for USBNC_OTG2_PHY_CFG2_TXBITSTUFFENH0. */
#define BM_USBNC_OTG2_PHY_CFG2_TXBITSTUFFENH0 (0x00000200U) /*!< Bit mask for USBNC_OTG2_PHY_CFG2_TXBITSTUFFENH0. */
#define BS_USBNC_OTG2_PHY_CFG2_TXBITSTUFFENH0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG2_TXBITSTUFFENH0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG2_TXBITSTUFFENH0 field. */
#define BR_USBNC_OTG2_PHY_CFG2_TXBITSTUFFENH0(x) (HW_USBNC_OTG2_PHY_CFG2(x).B.TXBITSTUFFENH0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG2_TXBITSTUFFENH0. */
#define BF_USBNC_OTG2_PHY_CFG2_TXBITSTUFFENH0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG2_TXBITSTUFFENH0) & BM_USBNC_OTG2_PHY_CFG2_TXBITSTUFFENH0)

/*! @brief Set the TXBITSTUFFENH0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG2_TXBITSTUFFENH0(x, v) (HW_USBNC_OTG2_PHY_CFG2_WR(x, (HW_USBNC_OTG2_PHY_CFG2_RD(x) & ~BM_USBNC_OTG2_PHY_CFG2_TXBITSTUFFENH0) | BF_USBNC_OTG2_PHY_CFG2_TXBITSTUFFENH0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG2, field OTGDISABLE0[10] (RW)
 *
 * This signal powers down the VBUS Valid comparator. It does not control power
 * to the Session Valid comparator, ADP Probe and Sense comparators, or the ID
 * detection circuitry.
 *
 * Values:
 * - 0 - The OTG block is powered up
 * - 1 - The OTG block is powered down
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG2_OTGDISABLE0 (10U) /*!< Bit position for USBNC_OTG2_PHY_CFG2_OTGDISABLE0. */
#define BM_USBNC_OTG2_PHY_CFG2_OTGDISABLE0 (0x00000400U) /*!< Bit mask for USBNC_OTG2_PHY_CFG2_OTGDISABLE0. */
#define BS_USBNC_OTG2_PHY_CFG2_OTGDISABLE0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG2_OTGDISABLE0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG2_OTGDISABLE0 field. */
#define BR_USBNC_OTG2_PHY_CFG2_OTGDISABLE0(x) (HW_USBNC_OTG2_PHY_CFG2(x).B.OTGDISABLE0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG2_OTGDISABLE0. */
#define BF_USBNC_OTG2_PHY_CFG2_OTGDISABLE0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG2_OTGDISABLE0) & BM_USBNC_OTG2_PHY_CFG2_OTGDISABLE0)

/*! @brief Set the OTGDISABLE0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG2_OTGDISABLE0(x, v) (HW_USBNC_OTG2_PHY_CFG2_WR(x, (HW_USBNC_OTG2_PHY_CFG2_RD(x) & ~BM_USBNC_OTG2_PHY_CFG2_OTGDISABLE0) | BF_USBNC_OTG2_PHY_CFG2_OTGDISABLE0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG2, field ADPCHRG0[11] (RW)
 *
 * This signal controls charging the USB_OTG*_VBUS pin during ADP. The IADP_SRC
 * current is >1.1mA and <1.65mA.
 *
 * Values:
 * - 0 - Disables charging USB_OTG*_VBUS during ADP
 * - 1 - Disables charging USB_OTG*_VBUS during ADP
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG2_ADPCHRG0 (11U) /*!< Bit position for USBNC_OTG2_PHY_CFG2_ADPCHRG0. */
#define BM_USBNC_OTG2_PHY_CFG2_ADPCHRG0 (0x00000800U) /*!< Bit mask for USBNC_OTG2_PHY_CFG2_ADPCHRG0. */
#define BS_USBNC_OTG2_PHY_CFG2_ADPCHRG0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG2_ADPCHRG0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG2_ADPCHRG0 field. */
#define BR_USBNC_OTG2_PHY_CFG2_ADPCHRG0(x) (HW_USBNC_OTG2_PHY_CFG2(x).B.ADPCHRG0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG2_ADPCHRG0. */
#define BF_USBNC_OTG2_PHY_CFG2_ADPCHRG0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG2_ADPCHRG0) & BM_USBNC_OTG2_PHY_CFG2_ADPCHRG0)

/*! @brief Set the ADPCHRG0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG2_ADPCHRG0(x, v) (HW_USBNC_OTG2_PHY_CFG2_WR(x, (HW_USBNC_OTG2_PHY_CFG2_RD(x) & ~BM_USBNC_OTG2_PHY_CFG2_ADPCHRG0) | BF_USBNC_OTG2_PHY_CFG2_ADPCHRG0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG2, field ADPDISCHRG0[12] (RW)
 *
 * This signal controls discharging the USB_OTG*_VBUS pin during ADP. The
 * IADP_SINK current is >1.1mA and <2.0mA.
 *
 * Values:
 * - 0 - Disables discharging USB_OTG*_VBUS during ADP
 * - 1 - Enables discharging USB_OTG*_VBUS during ADP
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG2_ADPDISCHRG0 (12U) /*!< Bit position for USBNC_OTG2_PHY_CFG2_ADPDISCHRG0. */
#define BM_USBNC_OTG2_PHY_CFG2_ADPDISCHRG0 (0x00001000U) /*!< Bit mask for USBNC_OTG2_PHY_CFG2_ADPDISCHRG0. */
#define BS_USBNC_OTG2_PHY_CFG2_ADPDISCHRG0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG2_ADPDISCHRG0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG2_ADPDISCHRG0 field. */
#define BR_USBNC_OTG2_PHY_CFG2_ADPDISCHRG0(x) (HW_USBNC_OTG2_PHY_CFG2(x).B.ADPDISCHRG0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG2_ADPDISCHRG0. */
#define BF_USBNC_OTG2_PHY_CFG2_ADPDISCHRG0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG2_ADPDISCHRG0) & BM_USBNC_OTG2_PHY_CFG2_ADPDISCHRG0)

/*! @brief Set the ADPDISCHRG0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG2_ADPDISCHRG0(x, v) (HW_USBNC_OTG2_PHY_CFG2_WR(x, (HW_USBNC_OTG2_PHY_CFG2_RD(x) & ~BM_USBNC_OTG2_PHY_CFG2_ADPDISCHRG0) | BF_USBNC_OTG2_PHY_CFG2_ADPDISCHRG0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG2, field ADPPRBENB0[13] (RW)
 *
 * This signal determines whether the ADP (Attach Detection Protocol) Probe
 * comparator on the USB_OTG*_VBUS pin is enabled. The ADP Probe threshold is > 0.6V
 * and < 0.75V on this USB PHY.
 *
 * Values:
 * - 0 - ADP Probe comparator is disabled
 * - 1 - ADP Probe comparator is enabled
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG2_ADPPRBENB0 (13U) /*!< Bit position for USBNC_OTG2_PHY_CFG2_ADPPRBENB0. */
#define BM_USBNC_OTG2_PHY_CFG2_ADPPRBENB0 (0x00002000U) /*!< Bit mask for USBNC_OTG2_PHY_CFG2_ADPPRBENB0. */
#define BS_USBNC_OTG2_PHY_CFG2_ADPPRBENB0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG2_ADPPRBENB0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG2_ADPPRBENB0 field. */
#define BR_USBNC_OTG2_PHY_CFG2_ADPPRBENB0(x) (HW_USBNC_OTG2_PHY_CFG2(x).B.ADPPRBENB0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG2_ADPPRBENB0. */
#define BF_USBNC_OTG2_PHY_CFG2_ADPPRBENB0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG2_ADPPRBENB0) & BM_USBNC_OTG2_PHY_CFG2_ADPPRBENB0)

/*! @brief Set the ADPPRBENB0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG2_ADPPRBENB0(x, v) (HW_USBNC_OTG2_PHY_CFG2_WR(x, (HW_USBNC_OTG2_PHY_CFG2_RD(x) & ~BM_USBNC_OTG2_PHY_CFG2_ADPPRBENB0) | BF_USBNC_OTG2_PHY_CFG2_ADPPRBENB0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG2, field VBUSVLDEXTSEL0[14] (RW)
 *
 * This signal selects whether the VBUSVLDEXT input
 * (USBNC_USB_OTGx_PHY_CFG2[15]) or the internal Session Valid comparator in the USB OTG PHY is used to check
 * if the VBUS signal on USB_OTG*_VBUS is valid and to enable the pull-up
 * resistor on the USB_OTG*_DP pin. The activation of the pull-up resistor on the
 * USB_OTG*_DP pin also depends on the state of the XCVRSEL, OPMODE, TERMSEL,
 * DPPULLDOWN, and DMPULLDOWN signals in the UTMI bus per the UTMI+ specification.
 *
 * Values:
 * - 0 - The USB OTG PHY internal Session Valid comparator is used to enable the
 *     pull-up resistor on the USB_OTG*_DP pin
 * - 1 - The VBUSVLDEXT signal is used to enable the pull-up resistor on the
 *     USB_OTG*_DP pin
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG2_VBUSVLDEXTSEL0 (14U) /*!< Bit position for USBNC_OTG2_PHY_CFG2_VBUSVLDEXTSEL0. */
#define BM_USBNC_OTG2_PHY_CFG2_VBUSVLDEXTSEL0 (0x00004000U) /*!< Bit mask for USBNC_OTG2_PHY_CFG2_VBUSVLDEXTSEL0. */
#define BS_USBNC_OTG2_PHY_CFG2_VBUSVLDEXTSEL0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG2_VBUSVLDEXTSEL0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG2_VBUSVLDEXTSEL0 field. */
#define BR_USBNC_OTG2_PHY_CFG2_VBUSVLDEXTSEL0(x) (HW_USBNC_OTG2_PHY_CFG2(x).B.VBUSVLDEXTSEL0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG2_VBUSVLDEXTSEL0. */
#define BF_USBNC_OTG2_PHY_CFG2_VBUSVLDEXTSEL0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG2_VBUSVLDEXTSEL0) & BM_USBNC_OTG2_PHY_CFG2_VBUSVLDEXTSEL0)

/*! @brief Set the VBUSVLDEXTSEL0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG2_VBUSVLDEXTSEL0(x, v) (HW_USBNC_OTG2_PHY_CFG2_WR(x, (HW_USBNC_OTG2_PHY_CFG2_RD(x) & ~BM_USBNC_OTG2_PHY_CFG2_VBUSVLDEXTSEL0) | BF_USBNC_OTG2_PHY_CFG2_VBUSVLDEXTSEL0(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG2, field VBUSVLDEXT[15] (RW)
 *
 * This signal is used if a VBUS Valid signal generated from a circuit outside
 * the USB OTG PHY is desired. If the USB OTG PHY is configured for Device mode
 * and VBUSVLDEXTSEL0 (USBNC_USB_OTGx_PHY_CFG2[14] is set to 1'b1, VBUSVLD
 * indicated whether the VBUS signal on the USB cable is valid and enables the pull-up
 * resistor on USB_OTG1_DP. This signal has no effect when the USB OTG PHY is
 * configured for Host mode.
 *
 * Values:
 * - 0 - The VBUS signal sensed outside the USB OTG PHY is not valid, and the
 *     pull-up resistor on USB_OTG*_DP is disabled
 * - 1 - The VBUS signal sensed outside the USB OTG PHY is valid, and the
 *     pull-up resistor on USB_OTG*_DP is enabled
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG2_VBUSVLDEXT (15U) /*!< Bit position for USBNC_OTG2_PHY_CFG2_VBUSVLDEXT. */
#define BM_USBNC_OTG2_PHY_CFG2_VBUSVLDEXT (0x00008000U) /*!< Bit mask for USBNC_OTG2_PHY_CFG2_VBUSVLDEXT. */
#define BS_USBNC_OTG2_PHY_CFG2_VBUSVLDEXT (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG2_VBUSVLDEXT. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG2_VBUSVLDEXT field. */
#define BR_USBNC_OTG2_PHY_CFG2_VBUSVLDEXT(x) (HW_USBNC_OTG2_PHY_CFG2(x).B.VBUSVLDEXT)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG2_VBUSVLDEXT. */
#define BF_USBNC_OTG2_PHY_CFG2_VBUSVLDEXT(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG2_VBUSVLDEXT) & BM_USBNC_OTG2_PHY_CFG2_VBUSVLDEXT)

/*! @brief Set the VBUSVLDEXT field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG2_VBUSVLDEXT(x, v) (HW_USBNC_OTG2_PHY_CFG2_WR(x, (HW_USBNC_OTG2_PHY_CFG2_RD(x) & ~BM_USBNC_OTG2_PHY_CFG2_VBUSVLDEXT) | BF_USBNC_OTG2_PHY_CFG2_VBUSVLDEXT(v)))
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_CFG2, field DRVVBUS0[16] (RW)
 *
 * This signal controls the USB OTG PHY VBUS Valid comparator which indicates
 * whether the voltage on the USB_OTG*_VBUS pin is below the VBUS Valid threshold.
 * The VBUS Valid threshold is nominally 4.75V on this USB PHY. The VBUS Valid
 * threshold can be adjusted using the USBNC_OTGn_PHY_CFG1[OTGTUNE0] bit field.
 * Status of the VBUS Valid comparator, when it is enabled, is reported on the
 * USBNC_OTGn_PHY_STATUS[VBUS_VLD] bit. When OTGDISABLE0
 * (USBNC_USB_OTGx_PHY_CFG2[10])is set to 1'b0 and DRVVBUS0 is set to 1'b1, the Bandgap circuitry and VBUS
 * Valid comparator are powered, even in Suspend or Sleep mode. DRVVBUS0 should be
 * reset to 1'b0 when the internal VBUS Valid comparator is not required, to
 * reduce quiescent current in Suspend or Sleep mode.
 *
 * Values:
 * - 0 - The VBUS Valid comparator is disabled
 * - 1 - The VBUS Valid comparator is enabled
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_CFG2_DRVVBUS0 (16U) /*!< Bit position for USBNC_OTG2_PHY_CFG2_DRVVBUS0. */
#define BM_USBNC_OTG2_PHY_CFG2_DRVVBUS0 (0x00010000U) /*!< Bit mask for USBNC_OTG2_PHY_CFG2_DRVVBUS0. */
#define BS_USBNC_OTG2_PHY_CFG2_DRVVBUS0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_CFG2_DRVVBUS0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_CFG2_DRVVBUS0 field. */
#define BR_USBNC_OTG2_PHY_CFG2_DRVVBUS0(x) (HW_USBNC_OTG2_PHY_CFG2(x).B.DRVVBUS0)

/*! @brief Format value for bitfield USBNC_OTG2_PHY_CFG2_DRVVBUS0. */
#define BF_USBNC_OTG2_PHY_CFG2_DRVVBUS0(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_OTG2_PHY_CFG2_DRVVBUS0) & BM_USBNC_OTG2_PHY_CFG2_DRVVBUS0)

/*! @brief Set the DRVVBUS0 field to a new value. */
#define BW_USBNC_OTG2_PHY_CFG2_DRVVBUS0(x, v) (HW_USBNC_OTG2_PHY_CFG2_WR(x, (HW_USBNC_OTG2_PHY_CFG2_RD(x) & ~BM_USBNC_OTG2_PHY_CFG2_DRVVBUS0) | BF_USBNC_OTG2_PHY_CFG2_DRVVBUS0(v)))
/*@}*/

/*******************************************************************************
 * HW_USBNC_OTG2_PHY_STATUS - USB OTG PHY Status Register
 ******************************************************************************/

/*!
 * @brief HW_USBNC_OTG2_PHY_STATUS - USB OTG PHY Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The USB_OTGx_PHY_STATUS register allows visibility of selected outputs of the
 * USB OTG PHY. These signals are used for some VBUS detection, ADP (Attach
 * Detection Protocol), and Battery Charging ACA (Accesory Charging Adaptor)
 * functions.
 */
typedef union _hw_usbnc_otg2_phy_status
{
    uint32_t U;
    struct _hw_usbnc_otg2_phy_status_bitfields
    {
        uint32_t LINE_STATE : 2;       /*!< [1:0] Line State Indicator outputs from
                                        * USB OTG PHY */
        uint32_t SESS_VLD : 1;         /*!< [2] OTG Device Session Valid Indicator
                                        * from USB OTG PHY */
        uint32_t VBUS_VLD : 1;         /*!< [3] VBUS Valid Indicator from USB OTG PHY
                                        * */
        uint32_t ID_DIG : 1;           /*!< [4] Micro- or Mini- A/B Plug Indicator */
        uint32_t HOST_DISCONNECT : 1;  /*!< [5] Peripheral Disconnect
                                        * Indicator */
        uint32_t RESERVED0 : 18;       /*!< [23:6]  */
        uint32_t RIDC0 : 1;            /*!< [24] ACA USB_OTG*_ID Pin Resistance
                                        * Indicator */
        uint32_t RIDB0 : 1;            /*!< [25] ACA USB_OTG*_ID Pin Resistance
                                        * Indicator */
        uint32_t RIDA0 : 1;            /*!< [26] ACA USB_OTG*_ID Pin Resistance
                                        * Indicator */
        uint32_t RIDGND0 : 1;          /*!< [27] ACA USB_OTG*_ID Pin Resistance
                                        * Indicator */
        uint32_t RIDFLOAT0 : 1;        /*!< [28] ACA USB_OTG*_ID Pin Resistance
                                        * Indicator */
        uint32_t CHRGDET : 1;          /*!< [29] Battery Charger Detection Output */
        uint32_t ADPPRB0 : 1;          /*!< [30] ADP Probe Indicator */
        uint32_t ADPSNS0 : 1;          /*!< [31] ADP Sense Indicator */
    } B;
} hw_usbnc_otg2_phy_status_t;

/*!
 * @name Constants and macros for entire USBNC_OTG2_PHY_STATUS register
 */
/*@{*/
#define HW_USBNC_OTG2_PHY_STATUS_ADDR(x) ((uintptr_t)(x) + 0x1023CU)

#define HW_USBNC_OTG2_PHY_STATUS(x) (*(__I hw_usbnc_otg2_phy_status_t *) HW_USBNC_OTG2_PHY_STATUS_ADDR(x))
#define HW_USBNC_OTG2_PHY_STATUS_RD(x) (HW_USBNC_OTG2_PHY_STATUS(x).U)
/*@}*/

/*
 * Constants & macros for individual USBNC_OTG2_PHY_STATUS bitfields
 */

/*!
 * @name Register USBNC_OTG2_PHY_STATUS, field LINE_STATE[1:0] (RO)
 *
 * These signals reflect the state of the single-ended receivers as defined by
 * the UTMI+ Specification. In Suspend or Sleep mode, this bus is a
 * combinatatorial output (directly reflecting the current state of DN and DP, respectively.
 * During normal high-speed packet transfers, the line indicates a high-speed J
 * state.
 *
 * Values:
 * - 00 - SE0 (DP low, DN low)
 * - 01 - J state for high-speed and full-speed USB traffic; K state for
 *     low-speed USB traffic (DP high, DN low)
 * - 10 - K state for high-speed and full-speed USB traffic; J state for
 *     low-speed USB traffic (DP low, DN high)
 * - 11 - SE1 (DP high, DN high)
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_STATUS_LINE_STATE (0U) /*!< Bit position for USBNC_OTG2_PHY_STATUS_LINE_STATE. */
#define BM_USBNC_OTG2_PHY_STATUS_LINE_STATE (0x00000003U) /*!< Bit mask for USBNC_OTG2_PHY_STATUS_LINE_STATE. */
#define BS_USBNC_OTG2_PHY_STATUS_LINE_STATE (2U) /*!< Bit field size in bits for USBNC_OTG2_PHY_STATUS_LINE_STATE. */

/*! @brief Read current value of the USBNC_OTG2_PHY_STATUS_LINE_STATE field. */
#define BR_USBNC_OTG2_PHY_STATUS_LINE_STATE(x) (HW_USBNC_OTG2_PHY_STATUS(x).B.LINE_STATE)
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_STATUS, field SESS_VLD[2] (RO)
 *
 * This signal is the output from the USB OTG PHY Session Valid comparator and
 * indicates whether the voltage on the USB_OTG*_VBUS pin is below the OTG Device
 * Session Valid threshold. The Session Valid threshold is > 0.8V and < 2.0V on
 * this USB PHY.
 *
 * Values:
 * - 0 - The voltage on USB_OTG*_VBUS is below the OTG Device Session Valid
 *     threshold
 * - 1 - The voltage on USB_OTG*_VBUS is above the OTG Device Session Valid
 *     threshold
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_STATUS_SESS_VLD (2U) /*!< Bit position for USBNC_OTG2_PHY_STATUS_SESS_VLD. */
#define BM_USBNC_OTG2_PHY_STATUS_SESS_VLD (0x00000004U) /*!< Bit mask for USBNC_OTG2_PHY_STATUS_SESS_VLD. */
#define BS_USBNC_OTG2_PHY_STATUS_SESS_VLD (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_STATUS_SESS_VLD. */

/*! @brief Read current value of the USBNC_OTG2_PHY_STATUS_SESS_VLD field. */
#define BR_USBNC_OTG2_PHY_STATUS_SESS_VLD(x) (HW_USBNC_OTG2_PHY_STATUS(x).B.SESS_VLD)
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_STATUS, field VBUS_VLD[3] (RO)
 *
 * This signal is the output from the USB OTG PHY VBUS Valid comparator and
 * indicates whether the voltage on the USB_OTG*_VBUS pin is below the VBUS Valid
 * threshold. The threshold is 4.75V but can be adjusted with OTGTUNE0
 * (USBNC_USB_PHY_CFG1[12:10]). The USB OTG PHY VBUS Valid comparator is enabled or disabled
 * depending on the states of register bits USBNC_USB_OTGx_PHY_CFG2[10] and
 * USBNC_USB_OTGx_PHY_CFG2[16].
 *
 * Values:
 * - 0 - The voltage on USB_OTG*_VBUS is below the VBUS Valid threshold
 * - 1 - The voltage on USB_OTG*_VBUS is above the VBUS Valid threshold
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_STATUS_VBUS_VLD (3U) /*!< Bit position for USBNC_OTG2_PHY_STATUS_VBUS_VLD. */
#define BM_USBNC_OTG2_PHY_STATUS_VBUS_VLD (0x00000008U) /*!< Bit mask for USBNC_OTG2_PHY_STATUS_VBUS_VLD. */
#define BS_USBNC_OTG2_PHY_STATUS_VBUS_VLD (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_STATUS_VBUS_VLD. */

/*! @brief Read current value of the USBNC_OTG2_PHY_STATUS_VBUS_VLD field. */
#define BR_USBNC_OTG2_PHY_STATUS_VBUS_VLD(x) (HW_USBNC_OTG2_PHY_STATUS(x).B.VBUS_VLD)
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_STATUS, field ID_DIG[4] (RO)
 *
 * This signal is the output from the ID pin A/B detector, which determines
 * whether the resistance from the USB_OTG*_ID pin to VSS is grounded (10 ohm maximum
 * for a Micro- or Mini-A plug) or floating (1 Megohm minimum for a Micro- or
 * Mini- B plug). The USB OTG PHY internal ID pin A/B detector circuit is enabled
 * or disabled depending on the states of register bits USBC_n_OTGSC[5] and
 * USBNC_USB_OTGx_PHY_CFG2[4]. Selection of whether to use the USB OTG PHY ID pin A/B
 * detector or a GPIO pin ID detector is determined by the state of the
 * USBNC_n_CTRL2[DIG_ID_SEL] bit field.
 *
 * Values:
 * - 0 - The connnected plug is a Micro- or Mini-A plug
 * - 1 - The connnected plug is a Micro- or Mini-B plug
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_STATUS_ID_DIG (4U) /*!< Bit position for USBNC_OTG2_PHY_STATUS_ID_DIG. */
#define BM_USBNC_OTG2_PHY_STATUS_ID_DIG (0x00000010U) /*!< Bit mask for USBNC_OTG2_PHY_STATUS_ID_DIG. */
#define BS_USBNC_OTG2_PHY_STATUS_ID_DIG (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_STATUS_ID_DIG. */

/*! @brief Read current value of the USBNC_OTG2_PHY_STATUS_ID_DIG field. */
#define BR_USBNC_OTG2_PHY_STATUS_ID_DIG(x) (HW_USBNC_OTG2_PHY_STATUS(x).B.ID_DIG)
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_STATUS, field HOST_DISCONNECT[5] (RO)
 *
 * This signal indicates to the USB_OTGx controller that a peripheral has been
 * disconnected from or connected to the USB cable. In high-speed host operation,
 * HOST_DISCONNECT is updated only at the end of SOF packet transmission. In FS
 * and LS host operations, HOST_DISCONNECT is updated according to UTMI+
 * Specification, Section 2.2.1.10. This output is valid only when the USB OTG PHY and
 * associated USB controller are configured to Host mode by setting
 * USBC_n_USBMODE[1:0] to 2'b11.
 *
 * Values:
 * - 0 - Peripheral is connected
 * - 1 - No peripheral is connected
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_STATUS_HOST_DISCONNECT (5U) /*!< Bit position for USBNC_OTG2_PHY_STATUS_HOST_DISCONNECT. */
#define BM_USBNC_OTG2_PHY_STATUS_HOST_DISCONNECT (0x00000020U) /*!< Bit mask for USBNC_OTG2_PHY_STATUS_HOST_DISCONNECT. */
#define BS_USBNC_OTG2_PHY_STATUS_HOST_DISCONNECT (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_STATUS_HOST_DISCONNECT. */

/*! @brief Read current value of the USBNC_OTG2_PHY_STATUS_HOST_DISCONNECT field. */
#define BR_USBNC_OTG2_PHY_STATUS_HOST_DISCONNECT(x) (HW_USBNC_OTG2_PHY_STATUS(x).B.HOST_DISCONNECT)
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_STATUS, field RIDC0[24] (RO)
 *
 * For USB Charger Detection, indicates whether the USB_OTG*_ID pin connected to
 * an ACA is within the RID_C) range.
 *
 * Values:
 * - 0 - ACA OTG_ID pin resistance is >= RID_B (min) and <= RID_GND max
 * - 1 - ACA OTG_ID pin resistance is >= RID_C (min) and <= RID_C max
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_STATUS_RIDC0 (24U) /*!< Bit position for USBNC_OTG2_PHY_STATUS_RIDC0. */
#define BM_USBNC_OTG2_PHY_STATUS_RIDC0 (0x01000000U) /*!< Bit mask for USBNC_OTG2_PHY_STATUS_RIDC0. */
#define BS_USBNC_OTG2_PHY_STATUS_RIDC0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_STATUS_RIDC0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_STATUS_RIDC0 field. */
#define BR_USBNC_OTG2_PHY_STATUS_RIDC0(x) (HW_USBNC_OTG2_PHY_STATUS(x).B.RIDC0)
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_STATUS, field RIDB0[25] (RO)
 *
 * For USB Charger Detection, indicates whether the USB_OTG*_ID pin connected to
 * an ACA is within the RID_B) range.
 *
 * Values:
 * - 0 - ACA OTG_ID pin resistance is >= RID_A (min) and <= RID_C max
 * - 1 - ACA OTG_ID pin resistance is >= RID_B (min) and <= RID_B max
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_STATUS_RIDB0 (25U) /*!< Bit position for USBNC_OTG2_PHY_STATUS_RIDB0. */
#define BM_USBNC_OTG2_PHY_STATUS_RIDB0 (0x02000000U) /*!< Bit mask for USBNC_OTG2_PHY_STATUS_RIDB0. */
#define BS_USBNC_OTG2_PHY_STATUS_RIDB0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_STATUS_RIDB0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_STATUS_RIDB0 field. */
#define BR_USBNC_OTG2_PHY_STATUS_RIDB0(x) (HW_USBNC_OTG2_PHY_STATUS(x).B.RIDB0)
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_STATUS, field RIDA0[26] (RO)
 *
 * For USB Charger Detection, indicates whether the USB_OTG*_ID pin connected to
 * an ACA is within the RID_A) range.
 *
 * Values:
 * - 0 - ACA OTG_ID pin resistance is >= RID_FLOAT (min) and <= RID_B max
 * - 1 - ACA OTG_ID pin resistance is >= RID_A (min) and <= RID_A max
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_STATUS_RIDA0 (26U) /*!< Bit position for USBNC_OTG2_PHY_STATUS_RIDA0. */
#define BM_USBNC_OTG2_PHY_STATUS_RIDA0 (0x04000000U) /*!< Bit mask for USBNC_OTG2_PHY_STATUS_RIDA0. */
#define BS_USBNC_OTG2_PHY_STATUS_RIDA0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_STATUS_RIDA0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_STATUS_RIDA0 field. */
#define BR_USBNC_OTG2_PHY_STATUS_RIDA0(x) (HW_USBNC_OTG2_PHY_STATUS(x).B.RIDA0)
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_STATUS, field RIDGND0[27] (RO)
 *
 * For USB Charger Detection, indicates whether the USB_OTG*_ID pin connected to
 * an ACA is grounded (has resistance < RID_GND).
 *
 * Values:
 * - 0 - ACA OTG_ID pin resistance is >= RID_C (min)
 * - 1 - ACA OTG_ID pin resistance is <= RID_GND (max)
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_STATUS_RIDGND0 (27U) /*!< Bit position for USBNC_OTG2_PHY_STATUS_RIDGND0. */
#define BM_USBNC_OTG2_PHY_STATUS_RIDGND0 (0x08000000U) /*!< Bit mask for USBNC_OTG2_PHY_STATUS_RIDGND0. */
#define BS_USBNC_OTG2_PHY_STATUS_RIDGND0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_STATUS_RIDGND0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_STATUS_RIDGND0 field. */
#define BR_USBNC_OTG2_PHY_STATUS_RIDGND0(x) (HW_USBNC_OTG2_PHY_STATUS(x).B.RIDGND0)
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_STATUS, field RIDFLOAT0[28] (RO)
 *
 * For USB Charger Detection, indicates whether the USB_OTG*_ID pin connected to
 * an ACA is floating (has resistance > RID_FLOAT).
 *
 * Values:
 * - 0 - ACA OTG_ID pin resistance is <= RID_A (max)
 * - 1 - ACA OTG_ID pin resistance is >= RID_FLOAT (min)
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_STATUS_RIDFLOAT0 (28U) /*!< Bit position for USBNC_OTG2_PHY_STATUS_RIDFLOAT0. */
#define BM_USBNC_OTG2_PHY_STATUS_RIDFLOAT0 (0x10000000U) /*!< Bit mask for USBNC_OTG2_PHY_STATUS_RIDFLOAT0. */
#define BS_USBNC_OTG2_PHY_STATUS_RIDFLOAT0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_STATUS_RIDFLOAT0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_STATUS_RIDFLOAT0 field. */
#define BR_USBNC_OTG2_PHY_STATUS_RIDFLOAT0(x) (HW_USBNC_OTG2_PHY_STATUS(x).B.RIDFLOAT0)
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_STATUS, field CHRGDET[29] (RO)
 *
 * This signal indicates whether the voltage level on USB_OTG*_DP or USB_OTG*_DN
 * is greater than VDAT_REF as defined in the USB Battery Charger, Revision 1.2
 * Specification. The selection of which USB data pins have the VD*_SRC and the
 * ID*_SINK sources is controlled by register bit USBNC_USB_OTGx_CFG2[0]. The
 * CHRGDET register bit is only valid when USBNC_USB_OTGx_CFG2[2:1] is set to 2'b11.
 *
 * Values:
 * - 0 - VD* < VDAT_REF
 * - 1 - VD* > VDAT_REF
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_STATUS_CHRGDET (29U) /*!< Bit position for USBNC_OTG2_PHY_STATUS_CHRGDET. */
#define BM_USBNC_OTG2_PHY_STATUS_CHRGDET (0x20000000U) /*!< Bit mask for USBNC_OTG2_PHY_STATUS_CHRGDET. */
#define BS_USBNC_OTG2_PHY_STATUS_CHRGDET (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_STATUS_CHRGDET. */

/*! @brief Read current value of the USBNC_OTG2_PHY_STATUS_CHRGDET field. */
#define BR_USBNC_OTG2_PHY_STATUS_CHRGDET(x) (HW_USBNC_OTG2_PHY_STATUS(x).B.CHRGDET)
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_STATUS, field ADPPRB0[30] (RO)
 *
 * This signal is output from the USB OTG PHY ADP Probe comparator and indicates
 * whether the voltage on the USB_OTG*_VBUS pin is below the ADP probing voltage.
 *
 * Values:
 * - 0 - The voltage on USB_OTG*_VBUS is below the ADP probing voltage
 * - 1 - The voltage on USB_OTG*_VBUS is above the ADP probing voltage
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_STATUS_ADPPRB0 (30U) /*!< Bit position for USBNC_OTG2_PHY_STATUS_ADPPRB0. */
#define BM_USBNC_OTG2_PHY_STATUS_ADPPRB0 (0x40000000U) /*!< Bit mask for USBNC_OTG2_PHY_STATUS_ADPPRB0. */
#define BS_USBNC_OTG2_PHY_STATUS_ADPPRB0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_STATUS_ADPPRB0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_STATUS_ADPPRB0 field. */
#define BR_USBNC_OTG2_PHY_STATUS_ADPPRB0(x) (HW_USBNC_OTG2_PHY_STATUS(x).B.ADPPRB0)
/*@}*/

/*!
 * @name Register USBNC_OTG2_PHY_STATUS, field ADPSNS0[31] (RO)
 *
 * This signal is output from the USB OTG PHY ADP Sense comparator and indicates
 * whether the voltage on the USB_OTG*_VBUS pin is below the ADP sensing voltage.
 *
 * Values:
 * - 0 - The voltage on USB_OTG*_VBUS is below the ADP sensing voltage
 * - 1 - The voltage on USB_OTG*_VBUS is above the ADP sensing voltage
 */
/*@{*/
#define BP_USBNC_OTG2_PHY_STATUS_ADPSNS0 (31U) /*!< Bit position for USBNC_OTG2_PHY_STATUS_ADPSNS0. */
#define BM_USBNC_OTG2_PHY_STATUS_ADPSNS0 (0x80000000U) /*!< Bit mask for USBNC_OTG2_PHY_STATUS_ADPSNS0. */
#define BS_USBNC_OTG2_PHY_STATUS_ADPSNS0 (1U) /*!< Bit field size in bits for USBNC_OTG2_PHY_STATUS_ADPSNS0. */

/*! @brief Read current value of the USBNC_OTG2_PHY_STATUS_ADPSNS0 field. */
#define BR_USBNC_OTG2_PHY_STATUS_ADPSNS0(x) (HW_USBNC_OTG2_PHY_STATUS(x).B.ADPSNS0)
/*@}*/

/*******************************************************************************
 * HW_USBNC_HSIC_CTRL1 -
 ******************************************************************************/

/*!
 * @brief HW_USBNC_HSIC_CTRL1 -  (RW)
 *
 * Reset value: 0x30001000U
 *
 * The USB_n_PHY_CTRL1 register controls the integration specific features of
 * the USB PHY modules. These features are not directly related to basic USB
 * functionality, but control special features, interfacing on the USB ports, as well
 * as power control and wake-up functionality.
 */
typedef union _hw_usbnc_hsic_ctrl1
{
    uint32_t U;
    struct _hw_usbnc_hsic_ctrl1_bitfields
    {
        uint32_t RESERVED0 : 7;        /*!< [6:0]  */
        uint32_t OVER_CUR_DIS : 1;     /*!< [7]  */
        uint32_t OVER_CUR_POL : 1;     /*!< [8]  */
        uint32_t PWR_POL : 1;          /*!< [9]  */
        uint32_t WIE : 1;              /*!< [10]  */
        uint32_t RESERVED1 : 3;        /*!< [13:11]  */
        uint32_t WKUP_SW_EN : 1;       /*!< [14]  */
        uint32_t WKUP_SW : 1;          /*!< [15]  */
        uint32_t WKUP_ID_EN : 1;       /*!< [16]  */
        uint32_t WKUP_VBUS_EN : 1;     /*!< [17]  */
        uint32_t RESERVED2 : 11;       /*!< [28:18]  */
        uint32_t WKUP_DPDM_EN : 1;     /*!< [29]  */
        uint32_t RESERVED3 : 1;        /*!< [30]  */
        uint32_t WIR : 1;              /*!< [31]  */
    } B;
} hw_usbnc_hsic_ctrl1_t;

/*!
 * @name Constants and macros for entire USBNC_HSIC_CTRL1 register
 */
/*@{*/
#define HW_USBNC_HSIC_CTRL1_ADDR(x) ((uintptr_t)(x) + 0x20200U)

#define HW_USBNC_HSIC_CTRL1(x)   (*(__IO hw_usbnc_hsic_ctrl1_t *) HW_USBNC_HSIC_CTRL1_ADDR(x))
#define HW_USBNC_HSIC_CTRL1_RD(x) (HW_USBNC_HSIC_CTRL1(x).U)
#define HW_USBNC_HSIC_CTRL1_WR(x, v) (HW_USBNC_HSIC_CTRL1(x).U = (v))
#define HW_USBNC_HSIC_CTRL1_SET(x, v) (HW_USBNC_HSIC_CTRL1_WR(x, HW_USBNC_HSIC_CTRL1_RD(x) |  (v)))
#define HW_USBNC_HSIC_CTRL1_CLR(x, v) (HW_USBNC_HSIC_CTRL1_WR(x, HW_USBNC_HSIC_CTRL1_RD(x) & ~(v)))
#define HW_USBNC_HSIC_CTRL1_TOG(x, v) (HW_USBNC_HSIC_CTRL1_WR(x, HW_USBNC_HSIC_CTRL1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBNC_HSIC_CTRL1 bitfields
 */

/*!
 * @name Register USBNC_HSIC_CTRL1, field OVER_CUR_DIS[7] (RW)
 *
 * Disable Overcurrent Detection
 *
 * Values:
 * - 1 - Disables overcurrent detection
 * - 0 - Enables overcurrent detection
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL1_OVER_CUR_DIS (7U) /*!< Bit position for USBNC_HSIC_CTRL1_OVER_CUR_DIS. */
#define BM_USBNC_HSIC_CTRL1_OVER_CUR_DIS (0x00000080U) /*!< Bit mask for USBNC_HSIC_CTRL1_OVER_CUR_DIS. */
#define BS_USBNC_HSIC_CTRL1_OVER_CUR_DIS (1U) /*!< Bit field size in bits for USBNC_HSIC_CTRL1_OVER_CUR_DIS. */

/*! @brief Read current value of the USBNC_HSIC_CTRL1_OVER_CUR_DIS field. */
#define BR_USBNC_HSIC_CTRL1_OVER_CUR_DIS(x) (HW_USBNC_HSIC_CTRL1(x).B.OVER_CUR_DIS)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL1_OVER_CUR_DIS. */
#define BF_USBNC_HSIC_CTRL1_OVER_CUR_DIS(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL1_OVER_CUR_DIS) & BM_USBNC_HSIC_CTRL1_OVER_CUR_DIS)

/*! @brief Set the OVER_CUR_DIS field to a new value. */
#define BW_USBNC_HSIC_CTRL1_OVER_CUR_DIS(x, v) (HW_USBNC_HSIC_CTRL1_WR(x, (HW_USBNC_HSIC_CTRL1_RD(x) & ~BM_USBNC_HSIC_CTRL1_OVER_CUR_DIS) | BF_USBNC_HSIC_CTRL1_OVER_CUR_DIS(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL1, field OVER_CUR_POL[8] (RW)
 *
 * Polarity of Overcurrent The polarity of OTG1/OTG2 port overcurrent event
 *
 * Values:
 * - 1 - Low active (low on this signal represents an overcurrent condition)
 * - 0 - High active (high on this signal represents an overcurrent condition)
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL1_OVER_CUR_POL (8U) /*!< Bit position for USBNC_HSIC_CTRL1_OVER_CUR_POL. */
#define BM_USBNC_HSIC_CTRL1_OVER_CUR_POL (0x00000100U) /*!< Bit mask for USBNC_HSIC_CTRL1_OVER_CUR_POL. */
#define BS_USBNC_HSIC_CTRL1_OVER_CUR_POL (1U) /*!< Bit field size in bits for USBNC_HSIC_CTRL1_OVER_CUR_POL. */

/*! @brief Read current value of the USBNC_HSIC_CTRL1_OVER_CUR_POL field. */
#define BR_USBNC_HSIC_CTRL1_OVER_CUR_POL(x) (HW_USBNC_HSIC_CTRL1(x).B.OVER_CUR_POL)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL1_OVER_CUR_POL. */
#define BF_USBNC_HSIC_CTRL1_OVER_CUR_POL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL1_OVER_CUR_POL) & BM_USBNC_HSIC_CTRL1_OVER_CUR_POL)

/*! @brief Set the OVER_CUR_POL field to a new value. */
#define BW_USBNC_HSIC_CTRL1_OVER_CUR_POL(x, v) (HW_USBNC_HSIC_CTRL1_WR(x, (HW_USBNC_HSIC_CTRL1_RD(x) & ~BM_USBNC_HSIC_CTRL1_OVER_CUR_POL) | BF_USBNC_HSIC_CTRL1_OVER_CUR_POL(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL1, field PWR_POL[9] (RW)
 *
 * Power Polarity This bit should be set according to PMIC Power Pin polarity.
 *
 * Values:
 * - 1 - PMIC Power Pin is High active.
 * - 0 - PMIC Power Pin is Low active.
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL1_PWR_POL (9U)   /*!< Bit position for USBNC_HSIC_CTRL1_PWR_POL. */
#define BM_USBNC_HSIC_CTRL1_PWR_POL (0x00000200U) /*!< Bit mask for USBNC_HSIC_CTRL1_PWR_POL. */
#define BS_USBNC_HSIC_CTRL1_PWR_POL (1U)   /*!< Bit field size in bits for USBNC_HSIC_CTRL1_PWR_POL. */

/*! @brief Read current value of the USBNC_HSIC_CTRL1_PWR_POL field. */
#define BR_USBNC_HSIC_CTRL1_PWR_POL(x) (HW_USBNC_HSIC_CTRL1(x).B.PWR_POL)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL1_PWR_POL. */
#define BF_USBNC_HSIC_CTRL1_PWR_POL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL1_PWR_POL) & BM_USBNC_HSIC_CTRL1_PWR_POL)

/*! @brief Set the PWR_POL field to a new value. */
#define BW_USBNC_HSIC_CTRL1_PWR_POL(x, v) (HW_USBNC_HSIC_CTRL1_WR(x, (HW_USBNC_HSIC_CTRL1_RD(x) & ~BM_USBNC_HSIC_CTRL1_PWR_POL) | BF_USBNC_HSIC_CTRL1_PWR_POL(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL1, field WIE[10] (RW)
 *
 * Wake-up Interrupt Enable This bit enables or disables the OTG1 wake-up
 * interrupt. Disabling the interrupt also clears the Interrupt request bit. Wake-up
 * interrupt enable should be turned off after receiving a wake-up interrupt and
 * turned on again prior to going in suspend mode
 *
 * Values:
 * - 1 - Interrupt Enabled
 * - 0 - Interrupt Disabled
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL1_WIE (10U)      /*!< Bit position for USBNC_HSIC_CTRL1_WIE. */
#define BM_USBNC_HSIC_CTRL1_WIE (0x00000400U) /*!< Bit mask for USBNC_HSIC_CTRL1_WIE. */
#define BS_USBNC_HSIC_CTRL1_WIE (1U)       /*!< Bit field size in bits for USBNC_HSIC_CTRL1_WIE. */

/*! @brief Read current value of the USBNC_HSIC_CTRL1_WIE field. */
#define BR_USBNC_HSIC_CTRL1_WIE(x) (HW_USBNC_HSIC_CTRL1(x).B.WIE)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL1_WIE. */
#define BF_USBNC_HSIC_CTRL1_WIE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL1_WIE) & BM_USBNC_HSIC_CTRL1_WIE)

/*! @brief Set the WIE field to a new value. */
#define BW_USBNC_HSIC_CTRL1_WIE(x, v) (HW_USBNC_HSIC_CTRL1_WR(x, (HW_USBNC_HSIC_CTRL1_RD(x) & ~BM_USBNC_HSIC_CTRL1_WIE) | BF_USBNC_HSIC_CTRL1_WIE(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL1, field WKUP_SW_EN[14] (RW)
 *
 * Software Wake-up Enable
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL1_WKUP_SW_EN (14U) /*!< Bit position for USBNC_HSIC_CTRL1_WKUP_SW_EN. */
#define BM_USBNC_HSIC_CTRL1_WKUP_SW_EN (0x00004000U) /*!< Bit mask for USBNC_HSIC_CTRL1_WKUP_SW_EN. */
#define BS_USBNC_HSIC_CTRL1_WKUP_SW_EN (1U) /*!< Bit field size in bits for USBNC_HSIC_CTRL1_WKUP_SW_EN. */

/*! @brief Read current value of the USBNC_HSIC_CTRL1_WKUP_SW_EN field. */
#define BR_USBNC_HSIC_CTRL1_WKUP_SW_EN(x) (HW_USBNC_HSIC_CTRL1(x).B.WKUP_SW_EN)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL1_WKUP_SW_EN. */
#define BF_USBNC_HSIC_CTRL1_WKUP_SW_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL1_WKUP_SW_EN) & BM_USBNC_HSIC_CTRL1_WKUP_SW_EN)

/*! @brief Set the WKUP_SW_EN field to a new value. */
#define BW_USBNC_HSIC_CTRL1_WKUP_SW_EN(x, v) (HW_USBNC_HSIC_CTRL1_WR(x, (HW_USBNC_HSIC_CTRL1_RD(x) & ~BM_USBNC_HSIC_CTRL1_WKUP_SW_EN) | BF_USBNC_HSIC_CTRL1_WKUP_SW_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL1, field WKUP_SW[15] (RW)
 *
 * Software Wake-up
 *
 * Values:
 * - 1 - Force wake-up
 * - 0 - Inactive
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL1_WKUP_SW (15U)  /*!< Bit position for USBNC_HSIC_CTRL1_WKUP_SW. */
#define BM_USBNC_HSIC_CTRL1_WKUP_SW (0x00008000U) /*!< Bit mask for USBNC_HSIC_CTRL1_WKUP_SW. */
#define BS_USBNC_HSIC_CTRL1_WKUP_SW (1U)   /*!< Bit field size in bits for USBNC_HSIC_CTRL1_WKUP_SW. */

/*! @brief Read current value of the USBNC_HSIC_CTRL1_WKUP_SW field. */
#define BR_USBNC_HSIC_CTRL1_WKUP_SW(x) (HW_USBNC_HSIC_CTRL1(x).B.WKUP_SW)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL1_WKUP_SW. */
#define BF_USBNC_HSIC_CTRL1_WKUP_SW(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL1_WKUP_SW) & BM_USBNC_HSIC_CTRL1_WKUP_SW)

/*! @brief Set the WKUP_SW field to a new value. */
#define BW_USBNC_HSIC_CTRL1_WKUP_SW(x, v) (HW_USBNC_HSIC_CTRL1_WR(x, (HW_USBNC_HSIC_CTRL1_RD(x) & ~BM_USBNC_HSIC_CTRL1_WKUP_SW) | BF_USBNC_HSIC_CTRL1_WKUP_SW(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL1, field WKUP_ID_EN[16] (RW)
 *
 * Wake-up on ID change enable
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL1_WKUP_ID_EN (16U) /*!< Bit position for USBNC_HSIC_CTRL1_WKUP_ID_EN. */
#define BM_USBNC_HSIC_CTRL1_WKUP_ID_EN (0x00010000U) /*!< Bit mask for USBNC_HSIC_CTRL1_WKUP_ID_EN. */
#define BS_USBNC_HSIC_CTRL1_WKUP_ID_EN (1U) /*!< Bit field size in bits for USBNC_HSIC_CTRL1_WKUP_ID_EN. */

/*! @brief Read current value of the USBNC_HSIC_CTRL1_WKUP_ID_EN field. */
#define BR_USBNC_HSIC_CTRL1_WKUP_ID_EN(x) (HW_USBNC_HSIC_CTRL1(x).B.WKUP_ID_EN)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL1_WKUP_ID_EN. */
#define BF_USBNC_HSIC_CTRL1_WKUP_ID_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL1_WKUP_ID_EN) & BM_USBNC_HSIC_CTRL1_WKUP_ID_EN)

/*! @brief Set the WKUP_ID_EN field to a new value. */
#define BW_USBNC_HSIC_CTRL1_WKUP_ID_EN(x, v) (HW_USBNC_HSIC_CTRL1_WR(x, (HW_USBNC_HSIC_CTRL1_RD(x) & ~BM_USBNC_HSIC_CTRL1_WKUP_ID_EN) | BF_USBNC_HSIC_CTRL1_WKUP_ID_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL1, field WKUP_VBUS_EN[17] (RW)
 *
 * Wake-up on VBUS change enable
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL1_WKUP_VBUS_EN (17U) /*!< Bit position for USBNC_HSIC_CTRL1_WKUP_VBUS_EN. */
#define BM_USBNC_HSIC_CTRL1_WKUP_VBUS_EN (0x00020000U) /*!< Bit mask for USBNC_HSIC_CTRL1_WKUP_VBUS_EN. */
#define BS_USBNC_HSIC_CTRL1_WKUP_VBUS_EN (1U) /*!< Bit field size in bits for USBNC_HSIC_CTRL1_WKUP_VBUS_EN. */

/*! @brief Read current value of the USBNC_HSIC_CTRL1_WKUP_VBUS_EN field. */
#define BR_USBNC_HSIC_CTRL1_WKUP_VBUS_EN(x) (HW_USBNC_HSIC_CTRL1(x).B.WKUP_VBUS_EN)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL1_WKUP_VBUS_EN. */
#define BF_USBNC_HSIC_CTRL1_WKUP_VBUS_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL1_WKUP_VBUS_EN) & BM_USBNC_HSIC_CTRL1_WKUP_VBUS_EN)

/*! @brief Set the WKUP_VBUS_EN field to a new value. */
#define BW_USBNC_HSIC_CTRL1_WKUP_VBUS_EN(x, v) (HW_USBNC_HSIC_CTRL1_WR(x, (HW_USBNC_HSIC_CTRL1_RD(x) & ~BM_USBNC_HSIC_CTRL1_WKUP_VBUS_EN) | BF_USBNC_HSIC_CTRL1_WKUP_VBUS_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL1, field WKUP_DPDM_EN[29] (RW)
 *
 * Wake-up on DPDM change enable
 *
 * Values:
 * - 1 - (Default) DPDM changes wake-up to be enabled, it is for device only.
 * - 0 - DPDM changes wake-up to be disabled only when VBUS is 0.
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL1_WKUP_DPDM_EN (29U) /*!< Bit position for USBNC_HSIC_CTRL1_WKUP_DPDM_EN. */
#define BM_USBNC_HSIC_CTRL1_WKUP_DPDM_EN (0x20000000U) /*!< Bit mask for USBNC_HSIC_CTRL1_WKUP_DPDM_EN. */
#define BS_USBNC_HSIC_CTRL1_WKUP_DPDM_EN (1U) /*!< Bit field size in bits for USBNC_HSIC_CTRL1_WKUP_DPDM_EN. */

/*! @brief Read current value of the USBNC_HSIC_CTRL1_WKUP_DPDM_EN field. */
#define BR_USBNC_HSIC_CTRL1_WKUP_DPDM_EN(x) (HW_USBNC_HSIC_CTRL1(x).B.WKUP_DPDM_EN)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL1_WKUP_DPDM_EN. */
#define BF_USBNC_HSIC_CTRL1_WKUP_DPDM_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL1_WKUP_DPDM_EN) & BM_USBNC_HSIC_CTRL1_WKUP_DPDM_EN)

/*! @brief Set the WKUP_DPDM_EN field to a new value. */
#define BW_USBNC_HSIC_CTRL1_WKUP_DPDM_EN(x, v) (HW_USBNC_HSIC_CTRL1_WR(x, (HW_USBNC_HSIC_CTRL1_RD(x) & ~BM_USBNC_HSIC_CTRL1_WKUP_DPDM_EN) | BF_USBNC_HSIC_CTRL1_WKUP_DPDM_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL1, field WIR[31] (RO)
 *
 * Wake-up Interrupt Request This bit indicates that a wake-up interrupt request
 * is received on the OTG1 port. This bit is cleared by disabling the wake-up
 * interrupt (clearing bit "OWIE").
 *
 * Values:
 * - 1 - Wake-up Interrupt Request received
 * - 0 - No wake-up interrupt request received
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL1_WIR (31U)      /*!< Bit position for USBNC_HSIC_CTRL1_WIR. */
#define BM_USBNC_HSIC_CTRL1_WIR (0x80000000U) /*!< Bit mask for USBNC_HSIC_CTRL1_WIR. */
#define BS_USBNC_HSIC_CTRL1_WIR (1U)       /*!< Bit field size in bits for USBNC_HSIC_CTRL1_WIR. */

/*! @brief Read current value of the USBNC_HSIC_CTRL1_WIR field. */
#define BR_USBNC_HSIC_CTRL1_WIR(x) (HW_USBNC_HSIC_CTRL1(x).B.WIR)
/*@}*/

/*******************************************************************************
 * HW_USBNC_HSIC_CTRL2 -
 ******************************************************************************/

/*!
 * @brief HW_USBNC_HSIC_CTRL2 -  (RW)
 *
 * Reset value: 0x0F000000U
 *
 * The USB_OTGx_PHY_CTRL2 register allows observation of the UTMI Clock Valid
 * status along with control of selected inputs to the USB OTG PHY transceiver.
 * Some of these input signals may be used for USB out-of-band signaling. Customers
 * should use caution when overriding any UTMI signals since that will interfere
 * with normal USB data communication.
 */
typedef union _hw_usbnc_hsic_ctrl2
{
    uint32_t U;
    struct _hw_usbnc_hsic_ctrl2_bitfields
    {
        uint32_t VBUS_SOURCE_SEL : 2;  /*!< [1:0]  */
        uint32_t AUTURESUME_EN : 1;    /*!< [2] Auto Resume Enable */
        uint32_t LOWSPEED_EN : 1;      /*!< [3]  */
        uint32_t TERMSEL_OVERRIDE : 1; /*!< [4]  */
        uint32_t TERMSEL_OVERRIDEEN : 1; /*!< [5]  */
        uint32_t OPMODE_OVERRIDE : 2;  /*!< [7:6]  */
        uint32_t OPMODE_OVERRIDEEN : 1; /*!< [8]  */
        uint32_t XCVRSEL_OVERRIDE : 2; /*!< [10:9]  */
        uint32_t XCVRSEL_OVERRIDEEN : 1; /*!< [11]  */
        uint32_t DPPULLDOWN_OVERRIDE : 1; /*!< [12]  */
        uint32_t DPPULLDOWN_OVERRIDEEN : 1; /*!< [13]  */
        uint32_t DMPULLDOWN_OVERRIDE : 1; /*!< [14]  */
        uint32_t DMPULLDOWN_OVERRIDEEN : 1; /*!< [15]  */
        uint32_t RESERVED0 : 4;        /*!< [19:16]  */
        uint32_t DIG_ID_SEL : 1;       /*!< [20]  */
        uint32_t RESERVED1 : 10;       /*!< [30:21]  */
        uint32_t UTMI_CLK_VLD : 1;     /*!< [31]  */
    } B;
} hw_usbnc_hsic_ctrl2_t;

/*!
 * @name Constants and macros for entire USBNC_HSIC_CTRL2 register
 */
/*@{*/
#define HW_USBNC_HSIC_CTRL2_ADDR(x) ((uintptr_t)(x) + 0x20204U)

#define HW_USBNC_HSIC_CTRL2(x)   (*(__IO hw_usbnc_hsic_ctrl2_t *) HW_USBNC_HSIC_CTRL2_ADDR(x))
#define HW_USBNC_HSIC_CTRL2_RD(x) (HW_USBNC_HSIC_CTRL2(x).U)
#define HW_USBNC_HSIC_CTRL2_WR(x, v) (HW_USBNC_HSIC_CTRL2(x).U = (v))
#define HW_USBNC_HSIC_CTRL2_SET(x, v) (HW_USBNC_HSIC_CTRL2_WR(x, HW_USBNC_HSIC_CTRL2_RD(x) |  (v)))
#define HW_USBNC_HSIC_CTRL2_CLR(x, v) (HW_USBNC_HSIC_CTRL2_WR(x, HW_USBNC_HSIC_CTRL2_RD(x) & ~(v)))
#define HW_USBNC_HSIC_CTRL2_TOG(x, v) (HW_USBNC_HSIC_CTRL2_WR(x, HW_USBNC_HSIC_CTRL2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBNC_HSIC_CTRL2 bitfields
 */

/*!
 * @name Register USBNC_HSIC_CTRL2, field VBUS_SOURCE_SEL[1:0] (RW)
 *
 * VBUS source select used to detect a VBUS wakeup event. This bit field is for
 * UTMI OTG PHY only (UH core and HSIC PHY have no such feature).
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL2_VBUS_SOURCE_SEL (0U) /*!< Bit position for USBNC_HSIC_CTRL2_VBUS_SOURCE_SEL. */
#define BM_USBNC_HSIC_CTRL2_VBUS_SOURCE_SEL (0x00000003U) /*!< Bit mask for USBNC_HSIC_CTRL2_VBUS_SOURCE_SEL. */
#define BS_USBNC_HSIC_CTRL2_VBUS_SOURCE_SEL (2U) /*!< Bit field size in bits for USBNC_HSIC_CTRL2_VBUS_SOURCE_SEL. */

/*! @brief Read current value of the USBNC_HSIC_CTRL2_VBUS_SOURCE_SEL field. */
#define BR_USBNC_HSIC_CTRL2_VBUS_SOURCE_SEL(x) (HW_USBNC_HSIC_CTRL2(x).B.VBUS_SOURCE_SEL)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL2_VBUS_SOURCE_SEL. */
#define BF_USBNC_HSIC_CTRL2_VBUS_SOURCE_SEL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL2_VBUS_SOURCE_SEL) & BM_USBNC_HSIC_CTRL2_VBUS_SOURCE_SEL)

/*! @brief Set the VBUS_SOURCE_SEL field to a new value. */
#define BW_USBNC_HSIC_CTRL2_VBUS_SOURCE_SEL(x, v) (HW_USBNC_HSIC_CTRL2_WR(x, (HW_USBNC_HSIC_CTRL2_RD(x) & ~(BM_USBNC_HSIC_CTRL2_VBUS_SOURCE_SEL | BM_USBNC_HSIC_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_HSIC_CTRL2_VBUS_SOURCE_SEL(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL2, field AUTURESUME_EN[2] (RW)
 *
 * This bit field is for UTMI OTG PHY host mode only (UH core does not have this
 * feature since HSIC PHY does not support auto resume). To set USB, it will
 * send resume with 32 KHz clock when it detects remote wakeup from device. This
 * feature is useful if device drives a very short remote wakeup (minimal value is 1
 * ms for USB2 spec) and system 24 MHz is off during suspend mode.
 *
 * Values:
 * - 0 - Default
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL2_AUTURESUME_EN (2U) /*!< Bit position for USBNC_HSIC_CTRL2_AUTURESUME_EN. */
#define BM_USBNC_HSIC_CTRL2_AUTURESUME_EN (0x00000004U) /*!< Bit mask for USBNC_HSIC_CTRL2_AUTURESUME_EN. */
#define BS_USBNC_HSIC_CTRL2_AUTURESUME_EN (1U) /*!< Bit field size in bits for USBNC_HSIC_CTRL2_AUTURESUME_EN. */

/*! @brief Read current value of the USBNC_HSIC_CTRL2_AUTURESUME_EN field. */
#define BR_USBNC_HSIC_CTRL2_AUTURESUME_EN(x) (HW_USBNC_HSIC_CTRL2(x).B.AUTURESUME_EN)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL2_AUTURESUME_EN. */
#define BF_USBNC_HSIC_CTRL2_AUTURESUME_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL2_AUTURESUME_EN) & BM_USBNC_HSIC_CTRL2_AUTURESUME_EN)

/*! @brief Set the AUTURESUME_EN field to a new value. */
#define BW_USBNC_HSIC_CTRL2_AUTURESUME_EN(x, v) (HW_USBNC_HSIC_CTRL2_WR(x, (HW_USBNC_HSIC_CTRL2_RD(x) & ~(BM_USBNC_HSIC_CTRL2_AUTURESUME_EN | BM_USBNC_HSIC_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_HSIC_CTRL2_AUTURESUME_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL2, field LOWSPEED_EN[3] (RW)
 *
 * Set if AUTURESUME_EN is set and works on low speed.
 *
 * Values:
 * - 0 - Default
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL2_LOWSPEED_EN (3U) /*!< Bit position for USBNC_HSIC_CTRL2_LOWSPEED_EN. */
#define BM_USBNC_HSIC_CTRL2_LOWSPEED_EN (0x00000008U) /*!< Bit mask for USBNC_HSIC_CTRL2_LOWSPEED_EN. */
#define BS_USBNC_HSIC_CTRL2_LOWSPEED_EN (1U) /*!< Bit field size in bits for USBNC_HSIC_CTRL2_LOWSPEED_EN. */

/*! @brief Read current value of the USBNC_HSIC_CTRL2_LOWSPEED_EN field. */
#define BR_USBNC_HSIC_CTRL2_LOWSPEED_EN(x) (HW_USBNC_HSIC_CTRL2(x).B.LOWSPEED_EN)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL2_LOWSPEED_EN. */
#define BF_USBNC_HSIC_CTRL2_LOWSPEED_EN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL2_LOWSPEED_EN) & BM_USBNC_HSIC_CTRL2_LOWSPEED_EN)

/*! @brief Set the LOWSPEED_EN field to a new value. */
#define BW_USBNC_HSIC_CTRL2_LOWSPEED_EN(x, v) (HW_USBNC_HSIC_CTRL2_WR(x, (HW_USBNC_HSIC_CTRL2_RD(x) & ~(BM_USBNC_HSIC_CTRL2_LOWSPEED_EN | BM_USBNC_HSIC_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_HSIC_CTRL2_LOWSPEED_EN(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL2, field TERMSEL_OVERRIDE[4] (RW)
 *
 * Controls the state of the UTMI TermSelect signal to the USB OTG PHY if the
 * value of USBNC_x_CTRL2[TERMSEL_OVERRIDEEN] is set to 1'b1. See the UTMI+
 * Specification for descriptions of the function of the TermSelect signal.
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDE (4U) /*!< Bit position for USBNC_HSIC_CTRL2_TERMSEL_OVERRIDE. */
#define BM_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDE (0x00000010U) /*!< Bit mask for USBNC_HSIC_CTRL2_TERMSEL_OVERRIDE. */
#define BS_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDE (1U) /*!< Bit field size in bits for USBNC_HSIC_CTRL2_TERMSEL_OVERRIDE. */

/*! @brief Read current value of the USBNC_HSIC_CTRL2_TERMSEL_OVERRIDE field. */
#define BR_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDE(x) (HW_USBNC_HSIC_CTRL2(x).B.TERMSEL_OVERRIDE)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL2_TERMSEL_OVERRIDE. */
#define BF_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDE) & BM_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDE)

/*! @brief Set the TERMSEL_OVERRIDE field to a new value. */
#define BW_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDE(x, v) (HW_USBNC_HSIC_CTRL2_WR(x, (HW_USBNC_HSIC_CTRL2_RD(x) & ~(BM_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDE | BM_USBNC_HSIC_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL2, field TERMSEL_OVERRIDEEN[5] (RW)
 *
 * Enables override of control of the UTMI TermSelect signal to the USB OTG PHY
 * instead of using the state normally set by the USB controller.
 *
 * Values:
 * - 0 - The state of the UTMI TermSelect signal to the USB PHY is set by the
 *     USB controller.
 * - 1 - The state of the UTMI TermSelect signal to the USB PHY is set by the
 *     value in the USBNC_x_CTRL2[TERMSEL_OVERRIDE] bit field.
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDEEN (5U) /*!< Bit position for USBNC_HSIC_CTRL2_TERMSEL_OVERRIDEEN. */
#define BM_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDEEN (0x00000020U) /*!< Bit mask for USBNC_HSIC_CTRL2_TERMSEL_OVERRIDEEN. */
#define BS_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDEEN (1U) /*!< Bit field size in bits for USBNC_HSIC_CTRL2_TERMSEL_OVERRIDEEN. */

/*! @brief Read current value of the USBNC_HSIC_CTRL2_TERMSEL_OVERRIDEEN field. */
#define BR_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDEEN(x) (HW_USBNC_HSIC_CTRL2(x).B.TERMSEL_OVERRIDEEN)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL2_TERMSEL_OVERRIDEEN. */
#define BF_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDEEN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDEEN) & BM_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDEEN)

/*! @brief Set the TERMSEL_OVERRIDEEN field to a new value. */
#define BW_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDEEN(x, v) (HW_USBNC_HSIC_CTRL2_WR(x, (HW_USBNC_HSIC_CTRL2_RD(x) & ~(BM_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDEEN | BM_USBNC_HSIC_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_HSIC_CTRL2_TERMSEL_OVERRIDEEN(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL2, field OPMODE_OVERRIDE[7:6] (RW)
 *
 * Controls the state of the UTMI XcvrSelect signals to the USB OTG PHY if the
 * value of USBNC_x_CTRL2[OPMODE_OVERRIDEEN] is set to 1'b1. See the UTMI+
 * Specification for descriptions of the functions of the OpMode signals.
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL2_OPMODE_OVERRIDE (6U) /*!< Bit position for USBNC_HSIC_CTRL2_OPMODE_OVERRIDE. */
#define BM_USBNC_HSIC_CTRL2_OPMODE_OVERRIDE (0x000000C0U) /*!< Bit mask for USBNC_HSIC_CTRL2_OPMODE_OVERRIDE. */
#define BS_USBNC_HSIC_CTRL2_OPMODE_OVERRIDE (2U) /*!< Bit field size in bits for USBNC_HSIC_CTRL2_OPMODE_OVERRIDE. */

/*! @brief Read current value of the USBNC_HSIC_CTRL2_OPMODE_OVERRIDE field. */
#define BR_USBNC_HSIC_CTRL2_OPMODE_OVERRIDE(x) (HW_USBNC_HSIC_CTRL2(x).B.OPMODE_OVERRIDE)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL2_OPMODE_OVERRIDE. */
#define BF_USBNC_HSIC_CTRL2_OPMODE_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL2_OPMODE_OVERRIDE) & BM_USBNC_HSIC_CTRL2_OPMODE_OVERRIDE)

/*! @brief Set the OPMODE_OVERRIDE field to a new value. */
#define BW_USBNC_HSIC_CTRL2_OPMODE_OVERRIDE(x, v) (HW_USBNC_HSIC_CTRL2_WR(x, (HW_USBNC_HSIC_CTRL2_RD(x) & ~(BM_USBNC_HSIC_CTRL2_OPMODE_OVERRIDE | BM_USBNC_HSIC_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_HSIC_CTRL2_OPMODE_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL2, field OPMODE_OVERRIDEEN[8] (RW)
 *
 * Enables override of control of the UTMI OpMode signals to the USB OTG PHY
 * instead of using the state normally set by the USB controller.
 *
 * Values:
 * - 0 - The state of the UTMI OpMode signals to the USB PHY is set by the USB
 *     controller.
 * - 1 - The state of the UTMI OpMode signals to the USB PHY is set by the
 *     values in the USBNC_x_CTRL2[OPMODE_OVERRIDE] bit field.
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL2_OPMODE_OVERRIDEEN (8U) /*!< Bit position for USBNC_HSIC_CTRL2_OPMODE_OVERRIDEEN. */
#define BM_USBNC_HSIC_CTRL2_OPMODE_OVERRIDEEN (0x00000100U) /*!< Bit mask for USBNC_HSIC_CTRL2_OPMODE_OVERRIDEEN. */
#define BS_USBNC_HSIC_CTRL2_OPMODE_OVERRIDEEN (1U) /*!< Bit field size in bits for USBNC_HSIC_CTRL2_OPMODE_OVERRIDEEN. */

/*! @brief Read current value of the USBNC_HSIC_CTRL2_OPMODE_OVERRIDEEN field. */
#define BR_USBNC_HSIC_CTRL2_OPMODE_OVERRIDEEN(x) (HW_USBNC_HSIC_CTRL2(x).B.OPMODE_OVERRIDEEN)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL2_OPMODE_OVERRIDEEN. */
#define BF_USBNC_HSIC_CTRL2_OPMODE_OVERRIDEEN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL2_OPMODE_OVERRIDEEN) & BM_USBNC_HSIC_CTRL2_OPMODE_OVERRIDEEN)

/*! @brief Set the OPMODE_OVERRIDEEN field to a new value. */
#define BW_USBNC_HSIC_CTRL2_OPMODE_OVERRIDEEN(x, v) (HW_USBNC_HSIC_CTRL2_WR(x, (HW_USBNC_HSIC_CTRL2_RD(x) & ~(BM_USBNC_HSIC_CTRL2_OPMODE_OVERRIDEEN | BM_USBNC_HSIC_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_HSIC_CTRL2_OPMODE_OVERRIDEEN(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL2, field XCVRSEL_OVERRIDE[10:9] (RW)
 *
 * Controls the state of the UTMI XcvrSelect signals to the USB OTG PHY if the
 * value of USBNC_x_CTRL2[XCVRSEL_OVERRIDEEN] is set to 1'b1. See the UTMI+
 * Specification for descriptions of the functions of the XcvrSelect signals.
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDE (9U) /*!< Bit position for USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDE. */
#define BM_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDE (0x00000600U) /*!< Bit mask for USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDE. */
#define BS_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDE (2U) /*!< Bit field size in bits for USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDE. */

/*! @brief Read current value of the USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDE field. */
#define BR_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDE(x) (HW_USBNC_HSIC_CTRL2(x).B.XCVRSEL_OVERRIDE)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDE. */
#define BF_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDE) & BM_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDE)

/*! @brief Set the XCVRSEL_OVERRIDE field to a new value. */
#define BW_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDE(x, v) (HW_USBNC_HSIC_CTRL2_WR(x, (HW_USBNC_HSIC_CTRL2_RD(x) & ~(BM_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDE | BM_USBNC_HSIC_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL2, field XCVRSEL_OVERRIDEEN[11] (RW)
 *
 * Enables override of control of the UTMI XcvrSelect signals to the USB OTG PHY
 * instead of using the state normally set by the USB controller.
 *
 * Values:
 * - 0 - The state of the UTMI XcvrSelect signals to the USB PHY is set by the
 *     USB controller.
 * - 1 - The state of the UTMI XcvrSelect signals to the USB PHY is set by the
 *     values in the USBNC_x_CTRL2[XCVRSEL_OVERRIDE] bit field.
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDEEN (11U) /*!< Bit position for USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDEEN. */
#define BM_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDEEN (0x00000800U) /*!< Bit mask for USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDEEN. */
#define BS_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDEEN (1U) /*!< Bit field size in bits for USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDEEN. */

/*! @brief Read current value of the USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDEEN field. */
#define BR_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDEEN(x) (HW_USBNC_HSIC_CTRL2(x).B.XCVRSEL_OVERRIDEEN)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDEEN. */
#define BF_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDEEN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDEEN) & BM_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDEEN)

/*! @brief Set the XCVRSEL_OVERRIDEEN field to a new value. */
#define BW_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDEEN(x, v) (HW_USBNC_HSIC_CTRL2_WR(x, (HW_USBNC_HSIC_CTRL2_RD(x) & ~(BM_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDEEN | BM_USBNC_HSIC_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_HSIC_CTRL2_XCVRSEL_OVERRIDEEN(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL2, field DPPULLDOWN_OVERRIDE[12] (RW)
 *
 * Controls state of DP pulldown resistor if
 * USBNC_n_CTRL2[DPPULLDOWN_OVERRIDEEN] is set to 1'b1.
 *
 * Values:
 * - 0 - DP pulldown resistor disabled
 * - 1 - DP pulldown resistor enabled
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDE (12U) /*!< Bit position for USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDE. */
#define BM_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDE (0x00001000U) /*!< Bit mask for USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDE. */
#define BS_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDE (1U) /*!< Bit field size in bits for USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDE. */

/*! @brief Read current value of the USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDE field. */
#define BR_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDE(x) (HW_USBNC_HSIC_CTRL2(x).B.DPPULLDOWN_OVERRIDE)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDE. */
#define BF_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDE) & BM_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDE)

/*! @brief Set the DPPULLDOWN_OVERRIDE field to a new value. */
#define BW_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDE(x, v) (HW_USBNC_HSIC_CTRL2_WR(x, (HW_USBNC_HSIC_CTRL2_RD(x) & ~(BM_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDE | BM_USBNC_HSIC_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL2, field DPPULLDOWN_OVERRIDEEN[13] (RW)
 *
 * Enables override of control of the DP pulldown resistor instead of using the
 * state set by the USB controller.
 *
 * Values:
 * - 0 - USB controller enables/disables the DP pulldown resistor in the USB PHY.
 * - 1 - Use the value set by the USBNC_n_CTRL2[DPPULLDOWN_OVERRIDE] bit field
 *     to enable/disable the DP pulldown resistor in the USB PHY.
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDEEN (13U) /*!< Bit position for USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDEEN. */
#define BM_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDEEN (0x00002000U) /*!< Bit mask for USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDEEN. */
#define BS_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDEEN (1U) /*!< Bit field size in bits for USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDEEN. */

/*! @brief Read current value of the USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDEEN field. */
#define BR_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDEEN(x) (HW_USBNC_HSIC_CTRL2(x).B.DPPULLDOWN_OVERRIDEEN)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDEEN. */
#define BF_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDEEN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDEEN) & BM_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDEEN)

/*! @brief Set the DPPULLDOWN_OVERRIDEEN field to a new value. */
#define BW_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDEEN(x, v) (HW_USBNC_HSIC_CTRL2_WR(x, (HW_USBNC_HSIC_CTRL2_RD(x) & ~(BM_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDEEN | BM_USBNC_HSIC_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_HSIC_CTRL2_DPPULLDOWN_OVERRIDEEN(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL2, field DMPULLDOWN_OVERRIDE[14] (RW)
 *
 * Controls state of DM pulldown resistor if
 * USBNC_n_CTRL2[DMPULLDOWN_OVERRIDEEN] is set to 1'b1.
 *
 * Values:
 * - 0 - DM pulldown resistor disabled
 * - 1 - DM pulldown resistor enabled
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDE (14U) /*!< Bit position for USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDE. */
#define BM_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDE (0x00004000U) /*!< Bit mask for USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDE. */
#define BS_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDE (1U) /*!< Bit field size in bits for USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDE. */

/*! @brief Read current value of the USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDE field. */
#define BR_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDE(x) (HW_USBNC_HSIC_CTRL2(x).B.DMPULLDOWN_OVERRIDE)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDE. */
#define BF_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDE) & BM_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDE)

/*! @brief Set the DMPULLDOWN_OVERRIDE field to a new value. */
#define BW_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDE(x, v) (HW_USBNC_HSIC_CTRL2_WR(x, (HW_USBNC_HSIC_CTRL2_RD(x) & ~(BM_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDE | BM_USBNC_HSIC_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL2, field DMPULLDOWN_OVERRIDEEN[15] (RW)
 *
 * Enables override of control of the DM pulldown resistor instead of the state
 * set by the USB controller.
 *
 * Values:
 * - 0 - USB controller enables/disables the DM pulldown resistor in the USB PHY.
 * - 1 - Use the value set by the USBNC_n_CTRL2[DMPULLDOWN_OVERRIDE] bit field
 *     to enable/disable the DM pulldown resistor in the USB PHY.
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDEEN (15U) /*!< Bit position for USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDEEN. */
#define BM_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDEEN (0x00008000U) /*!< Bit mask for USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDEEN. */
#define BS_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDEEN (1U) /*!< Bit field size in bits for USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDEEN. */

/*! @brief Read current value of the USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDEEN field. */
#define BR_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDEEN(x) (HW_USBNC_HSIC_CTRL2(x).B.DMPULLDOWN_OVERRIDEEN)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDEEN. */
#define BF_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDEEN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDEEN) & BM_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDEEN)

/*! @brief Set the DMPULLDOWN_OVERRIDEEN field to a new value. */
#define BW_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDEEN(x, v) (HW_USBNC_HSIC_CTRL2_WR(x, (HW_USBNC_HSIC_CTRL2_RD(x) & ~(BM_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDEEN | BM_USBNC_HSIC_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_HSIC_CTRL2_DMPULLDOWN_OVERRIDEEN(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL2, field DIG_ID_SEL[20] (RW)
 *
 * Selects whether the USB OTG ID pin function is connected to the PHY's
 * USB_OTG*_ID pin or a GPIO pin. The ID pin state is observed on
 * USBNC_n_PHY_STATUS[ID_DIG].
 *
 * Values:
 * - 0 - Use the USB_OTG*_ID pin for the USB OTG ID pin detection
 *     function(default)
 * - 1 - Use the pin configured by the IOMUXC_USB_OTG*_ID_SELECT_INPUT register
 *     for the USB OTG ID pin detection function
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL2_DIG_ID_SEL (20U) /*!< Bit position for USBNC_HSIC_CTRL2_DIG_ID_SEL. */
#define BM_USBNC_HSIC_CTRL2_DIG_ID_SEL (0x00100000U) /*!< Bit mask for USBNC_HSIC_CTRL2_DIG_ID_SEL. */
#define BS_USBNC_HSIC_CTRL2_DIG_ID_SEL (1U) /*!< Bit field size in bits for USBNC_HSIC_CTRL2_DIG_ID_SEL. */

/*! @brief Read current value of the USBNC_HSIC_CTRL2_DIG_ID_SEL field. */
#define BR_USBNC_HSIC_CTRL2_DIG_ID_SEL(x) (HW_USBNC_HSIC_CTRL2(x).B.DIG_ID_SEL)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL2_DIG_ID_SEL. */
#define BF_USBNC_HSIC_CTRL2_DIG_ID_SEL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL2_DIG_ID_SEL) & BM_USBNC_HSIC_CTRL2_DIG_ID_SEL)

/*! @brief Set the DIG_ID_SEL field to a new value. */
#define BW_USBNC_HSIC_CTRL2_DIG_ID_SEL(x, v) (HW_USBNC_HSIC_CTRL2_WR(x, (HW_USBNC_HSIC_CTRL2_RD(x) & ~(BM_USBNC_HSIC_CTRL2_DIG_ID_SEL | BM_USBNC_HSIC_CTRL2_UTMI_CLK_VLD)) | BF_USBNC_HSIC_CTRL2_DIG_ID_SEL(v)))
/*@}*/

/*!
 * @name Register USBNC_HSIC_CTRL2, field UTMI_CLK_VLD[31] (W1C)
 *
 * Indicate whether PHY clock is valid. Write 1 to clear
 *
 * Values:
 * - 0 - UTMI clock to USB PHY is not toggling (Default)
 * - 1 - UTMI clock to USB PHY has toggled several times
 */
/*@{*/
#define BP_USBNC_HSIC_CTRL2_UTMI_CLK_VLD (31U) /*!< Bit position for USBNC_HSIC_CTRL2_UTMI_CLK_VLD. */
#define BM_USBNC_HSIC_CTRL2_UTMI_CLK_VLD (0x80000000U) /*!< Bit mask for USBNC_HSIC_CTRL2_UTMI_CLK_VLD. */
#define BS_USBNC_HSIC_CTRL2_UTMI_CLK_VLD (1U) /*!< Bit field size in bits for USBNC_HSIC_CTRL2_UTMI_CLK_VLD. */

/*! @brief Read current value of the USBNC_HSIC_CTRL2_UTMI_CLK_VLD field. */
#define BR_USBNC_HSIC_CTRL2_UTMI_CLK_VLD(x) (HW_USBNC_HSIC_CTRL2(x).B.UTMI_CLK_VLD)

/*! @brief Format value for bitfield USBNC_HSIC_CTRL2_UTMI_CLK_VLD. */
#define BF_USBNC_HSIC_CTRL2_UTMI_CLK_VLD(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_HSIC_CTRL2_UTMI_CLK_VLD) & BM_USBNC_HSIC_CTRL2_UTMI_CLK_VLD)

/*! @brief Set the UTMI_CLK_VLD field to a new value. */
#define BW_USBNC_HSIC_CTRL2_UTMI_CLK_VLD(x, v) (HW_USBNC_HSIC_CTRL2_WR(x, (HW_USBNC_HSIC_CTRL2_RD(x) & ~BM_USBNC_HSIC_CTRL2_UTMI_CLK_VLD) | BF_USBNC_HSIC_CTRL2_UTMI_CLK_VLD(v)))
/*@}*/

/*******************************************************************************
 * HW_USBNC_UH_HSICPHY_CFG1 - USB Host HSIC PHY Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_USBNC_UH_HSICPHY_CFG1 - USB Host HSIC PHY Configuration Register (RW)
 *
 * Reset value: 0xC2243A1DU
 *
 * This register provides functional and parametric settings for the USB UH HSIC
 * PHY. Customers should not need to alter the settings on this register but it
 * will be used for characterization of the USB_H_DATA and USB_H_STROBE pins.
 */
typedef union _hw_usbnc_uh_hsicphy_cfg1
{
    uint32_t U;
    struct _hw_usbnc_uh_hsicphy_cfg1_bitfields
    {
        uint32_t COMMONONN : 1;        /*!< [0]  */
        uint32_t LOOPBACKENB : 1;      /*!< [1]  */
        uint32_t DPPULLDOWN : 1;       /*!< [2]  */
        uint32_t DMPULLDOWN : 1;       /*!< [3]  */
        uint32_t SLEEPM : 1;           /*!< [4]  */
        uint32_t TXBITSTUFFEN : 1;     /*!< [5] Low-Byte Transmit Bit-Stuffing
                                        * Enable */
        uint32_t TXBITSTUFFENH : 1;    /*!< [6] High-Byte Transmit Bit-Stuffing
                                        * Enable */
        uint32_t RESERVED0 : 1;        /*!< [7]  */
        uint32_t TXRPUTUNE : 2;        /*!< [9:8]  */
        uint32_t TXRPDTUNE : 2;        /*!< [11:10]  */
        uint32_t TXSRTUNE : 4;         /*!< [15:12]  */
        uint32_t REFCLKDIV : 7;        /*!< [22:16]  */
        uint32_t RESERVED1 : 1;        /*!< [23]  */
        uint32_t REFCLKSEL : 2;        /*!< [25:24]  */
        uint32_t RESERVED2 : 6;        /*!< [31:26]  */
    } B;
} hw_usbnc_uh_hsicphy_cfg1_t;

/*!
 * @name Constants and macros for entire USBNC_UH_HSICPHY_CFG1 register
 */
/*@{*/
#define HW_USBNC_UH_HSICPHY_CFG1_ADDR(x) ((uintptr_t)(x) + 0x20240U)

#define HW_USBNC_UH_HSICPHY_CFG1(x) (*(__IO hw_usbnc_uh_hsicphy_cfg1_t *) HW_USBNC_UH_HSICPHY_CFG1_ADDR(x))
#define HW_USBNC_UH_HSICPHY_CFG1_RD(x) (HW_USBNC_UH_HSICPHY_CFG1(x).U)
#define HW_USBNC_UH_HSICPHY_CFG1_WR(x, v) (HW_USBNC_UH_HSICPHY_CFG1(x).U = (v))
#define HW_USBNC_UH_HSICPHY_CFG1_SET(x, v) (HW_USBNC_UH_HSICPHY_CFG1_WR(x, HW_USBNC_UH_HSICPHY_CFG1_RD(x) |  (v)))
#define HW_USBNC_UH_HSICPHY_CFG1_CLR(x, v) (HW_USBNC_UH_HSICPHY_CFG1_WR(x, HW_USBNC_UH_HSICPHY_CFG1_RD(x) & ~(v)))
#define HW_USBNC_UH_HSICPHY_CFG1_TOG(x, v) (HW_USBNC_UH_HSICPHY_CFG1_WR(x, HW_USBNC_UH_HSICPHY_CFG1_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual USBNC_UH_HSICPHY_CFG1 bitfields
 */

/*!
 * @name Register USBNC_UH_HSICPHY_CFG1, field COMMONONN[0] (RW)
 *
 * This clock configuration setting should not be changed and must remain at
 * 1'b1.
 */
/*@{*/
#define BP_USBNC_UH_HSICPHY_CFG1_COMMONONN (0U) /*!< Bit position for USBNC_UH_HSICPHY_CFG1_COMMONONN. */
#define BM_USBNC_UH_HSICPHY_CFG1_COMMONONN (0x00000001U) /*!< Bit mask for USBNC_UH_HSICPHY_CFG1_COMMONONN. */
#define BS_USBNC_UH_HSICPHY_CFG1_COMMONONN (1U) /*!< Bit field size in bits for USBNC_UH_HSICPHY_CFG1_COMMONONN. */

/*! @brief Read current value of the USBNC_UH_HSICPHY_CFG1_COMMONONN field. */
#define BR_USBNC_UH_HSICPHY_CFG1_COMMONONN(x) (HW_USBNC_UH_HSICPHY_CFG1(x).B.COMMONONN)

/*! @brief Format value for bitfield USBNC_UH_HSICPHY_CFG1_COMMONONN. */
#define BF_USBNC_UH_HSICPHY_CFG1_COMMONONN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_UH_HSICPHY_CFG1_COMMONONN) & BM_USBNC_UH_HSICPHY_CFG1_COMMONONN)

/*! @brief Set the COMMONONN field to a new value. */
#define BW_USBNC_UH_HSICPHY_CFG1_COMMONONN(x, v) (HW_USBNC_UH_HSICPHY_CFG1_WR(x, (HW_USBNC_UH_HSICPHY_CFG1_RD(x) & ~BM_USBNC_UH_HSICPHY_CFG1_COMMONONN) | BF_USBNC_UH_HSICPHY_CFG1_COMMONONN(v)))
/*@}*/

/*!
 * @name Register USBNC_UH_HSICPHY_CFG1, field LOOPBACKENB[1] (RW)
 *
 * Loopback test enable. This controller signal places the HSIC PHY in Loopback
 * mode, which enables the receive and transmit logic concurrently. Note:
 * Loopback mode is for test purposes only; it cannot be used for normal operation.
 *
 * Values:
 * - 0 - During data transmission, the receive logic is disabled
 * - 1 - During data transmission, the receive logic is enabled
 */
/*@{*/
#define BP_USBNC_UH_HSICPHY_CFG1_LOOPBACKENB (1U) /*!< Bit position for USBNC_UH_HSICPHY_CFG1_LOOPBACKENB. */
#define BM_USBNC_UH_HSICPHY_CFG1_LOOPBACKENB (0x00000002U) /*!< Bit mask for USBNC_UH_HSICPHY_CFG1_LOOPBACKENB. */
#define BS_USBNC_UH_HSICPHY_CFG1_LOOPBACKENB (1U) /*!< Bit field size in bits for USBNC_UH_HSICPHY_CFG1_LOOPBACKENB. */

/*! @brief Read current value of the USBNC_UH_HSICPHY_CFG1_LOOPBACKENB field. */
#define BR_USBNC_UH_HSICPHY_CFG1_LOOPBACKENB(x) (HW_USBNC_UH_HSICPHY_CFG1(x).B.LOOPBACKENB)

/*! @brief Format value for bitfield USBNC_UH_HSICPHY_CFG1_LOOPBACKENB. */
#define BF_USBNC_UH_HSICPHY_CFG1_LOOPBACKENB(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_UH_HSICPHY_CFG1_LOOPBACKENB) & BM_USBNC_UH_HSICPHY_CFG1_LOOPBACKENB)

/*! @brief Set the LOOPBACKENB field to a new value. */
#define BW_USBNC_UH_HSICPHY_CFG1_LOOPBACKENB(x, v) (HW_USBNC_UH_HSICPHY_CFG1_WR(x, (HW_USBNC_UH_HSICPHY_CFG1_RD(x) & ~BM_USBNC_UH_HSICPHY_CFG1_LOOPBACKENB) | BF_USBNC_UH_HSICPHY_CFG1_LOOPBACKENB(v)))
/*@}*/

/*!
 * @name Register USBNC_UH_HSICPHY_CFG1, field DPPULLDOWN[2] (RW)
 *
 * Bus keeper resistors enable. If both DPPULLDOWN and DMPULLDOWN are set to
 * 1'b1, the HSIC PHY is configured to operate as a Host. Otherwise, the HSIC PHY is
 * configured to operate as a Device. Since the controller for the USB UH HSIC
 * port only operates as a USB Host, these signals should not be reset to 1'b0 .
 *
 * Values:
 * - 0 - Disable bus keeper resistors
 * - 1 - Enable bus keeper resistors
 */
/*@{*/
#define BP_USBNC_UH_HSICPHY_CFG1_DPPULLDOWN (2U) /*!< Bit position for USBNC_UH_HSICPHY_CFG1_DPPULLDOWN. */
#define BM_USBNC_UH_HSICPHY_CFG1_DPPULLDOWN (0x00000004U) /*!< Bit mask for USBNC_UH_HSICPHY_CFG1_DPPULLDOWN. */
#define BS_USBNC_UH_HSICPHY_CFG1_DPPULLDOWN (1U) /*!< Bit field size in bits for USBNC_UH_HSICPHY_CFG1_DPPULLDOWN. */

/*! @brief Read current value of the USBNC_UH_HSICPHY_CFG1_DPPULLDOWN field. */
#define BR_USBNC_UH_HSICPHY_CFG1_DPPULLDOWN(x) (HW_USBNC_UH_HSICPHY_CFG1(x).B.DPPULLDOWN)

/*! @brief Format value for bitfield USBNC_UH_HSICPHY_CFG1_DPPULLDOWN. */
#define BF_USBNC_UH_HSICPHY_CFG1_DPPULLDOWN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_UH_HSICPHY_CFG1_DPPULLDOWN) & BM_USBNC_UH_HSICPHY_CFG1_DPPULLDOWN)

/*! @brief Set the DPPULLDOWN field to a new value. */
#define BW_USBNC_UH_HSICPHY_CFG1_DPPULLDOWN(x, v) (HW_USBNC_UH_HSICPHY_CFG1_WR(x, (HW_USBNC_UH_HSICPHY_CFG1_RD(x) & ~BM_USBNC_UH_HSICPHY_CFG1_DPPULLDOWN) | BF_USBNC_UH_HSICPHY_CFG1_DPPULLDOWN(v)))
/*@}*/

/*!
 * @name Register USBNC_UH_HSICPHY_CFG1, field DMPULLDOWN[3] (RW)
 *
 * Bus keeper resistors enable. If both DPPULLDOWN and DMPULLDOWN are set to
 * 1'b1, the HSIC PHY is configured to operate as a Host. Otherwise, the HSIC PHY is
 * configured to operate as a Device. Since the controller for the USB UH HSIC
 * port only operates as a USB Host, these signals should not be reset to 1'b0 .
 *
 * Values:
 * - 0 - Disable bus keeper resistors
 * - 1 - Enable bus keeper resistors
 */
/*@{*/
#define BP_USBNC_UH_HSICPHY_CFG1_DMPULLDOWN (3U) /*!< Bit position for USBNC_UH_HSICPHY_CFG1_DMPULLDOWN. */
#define BM_USBNC_UH_HSICPHY_CFG1_DMPULLDOWN (0x00000008U) /*!< Bit mask for USBNC_UH_HSICPHY_CFG1_DMPULLDOWN. */
#define BS_USBNC_UH_HSICPHY_CFG1_DMPULLDOWN (1U) /*!< Bit field size in bits for USBNC_UH_HSICPHY_CFG1_DMPULLDOWN. */

/*! @brief Read current value of the USBNC_UH_HSICPHY_CFG1_DMPULLDOWN field. */
#define BR_USBNC_UH_HSICPHY_CFG1_DMPULLDOWN(x) (HW_USBNC_UH_HSICPHY_CFG1(x).B.DMPULLDOWN)

/*! @brief Format value for bitfield USBNC_UH_HSICPHY_CFG1_DMPULLDOWN. */
#define BF_USBNC_UH_HSICPHY_CFG1_DMPULLDOWN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_UH_HSICPHY_CFG1_DMPULLDOWN) & BM_USBNC_UH_HSICPHY_CFG1_DMPULLDOWN)

/*! @brief Set the DMPULLDOWN field to a new value. */
#define BW_USBNC_UH_HSICPHY_CFG1_DMPULLDOWN(x, v) (HW_USBNC_UH_HSICPHY_CFG1_WR(x, (HW_USBNC_UH_HSICPHY_CFG1_RD(x) & ~BM_USBNC_UH_HSICPHY_CFG1_DMPULLDOWN) | BF_USBNC_UH_HSICPHY_CFG1_DMPULLDOWN(v)))
/*@}*/

/*!
 * @name Register USBNC_UH_HSICPHY_CFG1, field SLEEPM[4] (RW)
 *
 * Sleeep mode assertion. Reseting this signal laces the USB UH HSIC PHY in
 * Sleep mode. Since the controller used for the HSB UH HSIC port does not support
 * USB 2.0 Link Power Management (LPM) this bit field should remain at 1'b1.
 *
 * Values:
 * - 0 - Sleep mode
 * - 1 - Normal operating mode
 */
/*@{*/
#define BP_USBNC_UH_HSICPHY_CFG1_SLEEPM (4U) /*!< Bit position for USBNC_UH_HSICPHY_CFG1_SLEEPM. */
#define BM_USBNC_UH_HSICPHY_CFG1_SLEEPM (0x00000010U) /*!< Bit mask for USBNC_UH_HSICPHY_CFG1_SLEEPM. */
#define BS_USBNC_UH_HSICPHY_CFG1_SLEEPM (1U) /*!< Bit field size in bits for USBNC_UH_HSICPHY_CFG1_SLEEPM. */

/*! @brief Read current value of the USBNC_UH_HSICPHY_CFG1_SLEEPM field. */
#define BR_USBNC_UH_HSICPHY_CFG1_SLEEPM(x) (HW_USBNC_UH_HSICPHY_CFG1(x).B.SLEEPM)

/*! @brief Format value for bitfield USBNC_UH_HSICPHY_CFG1_SLEEPM. */
#define BF_USBNC_UH_HSICPHY_CFG1_SLEEPM(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_UH_HSICPHY_CFG1_SLEEPM) & BM_USBNC_UH_HSICPHY_CFG1_SLEEPM)

/*! @brief Set the SLEEPM field to a new value. */
#define BW_USBNC_UH_HSICPHY_CFG1_SLEEPM(x, v) (HW_USBNC_UH_HSICPHY_CFG1_WR(x, (HW_USBNC_UH_HSICPHY_CFG1_RD(x) & ~BM_USBNC_UH_HSICPHY_CFG1_SLEEPM) | BF_USBNC_UH_HSICPHY_CFG1_SLEEPM(v)))
/*@}*/

/*!
 * @name Register USBNC_UH_HSICPHY_CFG1, field TXBITSTUFFEN[5] (RW)
 *
 * This controller signal controls bit stuffing on DATAIN[7:0] when OPMODE[1:0]
 * = 2'b11. For more information on the use of this setting see UTMI+
 * Specification Section 2.2.1.12 .
 *
 * Values:
 * - 0 - Bit stuffing is disabled
 * - 1 - Bit stuffing is enabled
 */
/*@{*/
#define BP_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFEN (5U) /*!< Bit position for USBNC_UH_HSICPHY_CFG1_TXBITSTUFFEN. */
#define BM_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFEN (0x00000020U) /*!< Bit mask for USBNC_UH_HSICPHY_CFG1_TXBITSTUFFEN. */
#define BS_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFEN (1U) /*!< Bit field size in bits for USBNC_UH_HSICPHY_CFG1_TXBITSTUFFEN. */

/*! @brief Read current value of the USBNC_UH_HSICPHY_CFG1_TXBITSTUFFEN field. */
#define BR_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFEN(x) (HW_USBNC_UH_HSICPHY_CFG1(x).B.TXBITSTUFFEN)

/*! @brief Format value for bitfield USBNC_UH_HSICPHY_CFG1_TXBITSTUFFEN. */
#define BF_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFEN(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFEN) & BM_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFEN)

/*! @brief Set the TXBITSTUFFEN field to a new value. */
#define BW_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFEN(x, v) (HW_USBNC_UH_HSICPHY_CFG1_WR(x, (HW_USBNC_UH_HSICPHY_CFG1_RD(x) & ~BM_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFEN) | BF_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFEN(v)))
/*@}*/

/*!
 * @name Register USBNC_UH_HSICPHY_CFG1, field TXBITSTUFFENH[6] (RW)
 *
 * This controller signal controls bit stuffing on DATAINH[7:0] when OPMODE[1:0]
 * = 2'b11. For more information on the use of this setting see UTMI+
 * Specification Section 2.2.1.12 .
 *
 * Values:
 * - 0 - Bit stuffing is disabled
 * - 1 - Bit stuffing is enabled
 */
/*@{*/
#define BP_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFENH (6U) /*!< Bit position for USBNC_UH_HSICPHY_CFG1_TXBITSTUFFENH. */
#define BM_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFENH (0x00000040U) /*!< Bit mask for USBNC_UH_HSICPHY_CFG1_TXBITSTUFFENH. */
#define BS_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFENH (1U) /*!< Bit field size in bits for USBNC_UH_HSICPHY_CFG1_TXBITSTUFFENH. */

/*! @brief Read current value of the USBNC_UH_HSICPHY_CFG1_TXBITSTUFFENH field. */
#define BR_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFENH(x) (HW_USBNC_UH_HSICPHY_CFG1(x).B.TXBITSTUFFENH)

/*! @brief Format value for bitfield USBNC_UH_HSICPHY_CFG1_TXBITSTUFFENH. */
#define BF_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFENH(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFENH) & BM_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFENH)

/*! @brief Set the TXBITSTUFFENH field to a new value. */
#define BW_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFENH(x, v) (HW_USBNC_UH_HSICPHY_CFG1_WR(x, (HW_USBNC_UH_HSICPHY_CFG1_RD(x) & ~BM_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFENH) | BF_USBNC_UH_HSICPHY_CFG1_TXBITSTUFFENH(v)))
/*@}*/

/*!
 * @name Register USBNC_UH_HSICPHY_CFG1, field TXRPUTUNE[9:8] (RW)
 *
 * Driver pull-up single-ended source impedance adjustment for USB_H_DATA and
 * USB_H_STROBE pins when driving high.
 *
 * Values:
 * - 00 - +11%
 * - 01 - +5%
 * - 10 - Design default
 * - 11 - -5%
 */
/*@{*/
#define BP_USBNC_UH_HSICPHY_CFG1_TXRPUTUNE (8U) /*!< Bit position for USBNC_UH_HSICPHY_CFG1_TXRPUTUNE. */
#define BM_USBNC_UH_HSICPHY_CFG1_TXRPUTUNE (0x00000300U) /*!< Bit mask for USBNC_UH_HSICPHY_CFG1_TXRPUTUNE. */
#define BS_USBNC_UH_HSICPHY_CFG1_TXRPUTUNE (2U) /*!< Bit field size in bits for USBNC_UH_HSICPHY_CFG1_TXRPUTUNE. */

/*! @brief Read current value of the USBNC_UH_HSICPHY_CFG1_TXRPUTUNE field. */
#define BR_USBNC_UH_HSICPHY_CFG1_TXRPUTUNE(x) (HW_USBNC_UH_HSICPHY_CFG1(x).B.TXRPUTUNE)

/*! @brief Format value for bitfield USBNC_UH_HSICPHY_CFG1_TXRPUTUNE. */
#define BF_USBNC_UH_HSICPHY_CFG1_TXRPUTUNE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_UH_HSICPHY_CFG1_TXRPUTUNE) & BM_USBNC_UH_HSICPHY_CFG1_TXRPUTUNE)

/*! @brief Set the TXRPUTUNE field to a new value. */
#define BW_USBNC_UH_HSICPHY_CFG1_TXRPUTUNE(x, v) (HW_USBNC_UH_HSICPHY_CFG1_WR(x, (HW_USBNC_UH_HSICPHY_CFG1_RD(x) & ~BM_USBNC_UH_HSICPHY_CFG1_TXRPUTUNE) | BF_USBNC_UH_HSICPHY_CFG1_TXRPUTUNE(v)))
/*@}*/

/*!
 * @name Register USBNC_UH_HSICPHY_CFG1, field TXRPDTUNE[11:10] (RW)
 *
 * Driver pull-down single-ended source impedance adjustment for USB_H_DATA and
 * USB_H_STROBE pins when driving low.
 *
 * Values:
 * - 00 - +11%
 * - 01 - +5%
 * - 10 - Design default
 * - 11 - -5%
 */
/*@{*/
#define BP_USBNC_UH_HSICPHY_CFG1_TXRPDTUNE (10U) /*!< Bit position for USBNC_UH_HSICPHY_CFG1_TXRPDTUNE. */
#define BM_USBNC_UH_HSICPHY_CFG1_TXRPDTUNE (0x00000C00U) /*!< Bit mask for USBNC_UH_HSICPHY_CFG1_TXRPDTUNE. */
#define BS_USBNC_UH_HSICPHY_CFG1_TXRPDTUNE (2U) /*!< Bit field size in bits for USBNC_UH_HSICPHY_CFG1_TXRPDTUNE. */

/*! @brief Read current value of the USBNC_UH_HSICPHY_CFG1_TXRPDTUNE field. */
#define BR_USBNC_UH_HSICPHY_CFG1_TXRPDTUNE(x) (HW_USBNC_UH_HSICPHY_CFG1(x).B.TXRPDTUNE)

/*! @brief Format value for bitfield USBNC_UH_HSICPHY_CFG1_TXRPDTUNE. */
#define BF_USBNC_UH_HSICPHY_CFG1_TXRPDTUNE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_UH_HSICPHY_CFG1_TXRPDTUNE) & BM_USBNC_UH_HSICPHY_CFG1_TXRPDTUNE)

/*! @brief Set the TXRPDTUNE field to a new value. */
#define BW_USBNC_UH_HSICPHY_CFG1_TXRPDTUNE(x, v) (HW_USBNC_UH_HSICPHY_CFG1_WR(x, (HW_USBNC_UH_HSICPHY_CFG1_RD(x) & ~BM_USBNC_UH_HSICPHY_CFG1_TXRPDTUNE) | BF_USBNC_UH_HSICPHY_CFG1_TXRPDTUNE(v)))
/*@}*/

/*!
 * @name Register USBNC_UH_HSICPHY_CFG1, field TXSRTUNE[15:12] (RW)
 *
 * Driver slew rate adjustment for USB_H_DATA and USB_H_STROBE pins.
 *
 * Values:
 * - 0000 - -20%
 * - 0001 - -10%
 * - 0011 - Design default
 * - 0111 - +10%
 * - 1111 - +20%
 */
/*@{*/
#define BP_USBNC_UH_HSICPHY_CFG1_TXSRTUNE (12U) /*!< Bit position for USBNC_UH_HSICPHY_CFG1_TXSRTUNE. */
#define BM_USBNC_UH_HSICPHY_CFG1_TXSRTUNE (0x0000F000U) /*!< Bit mask for USBNC_UH_HSICPHY_CFG1_TXSRTUNE. */
#define BS_USBNC_UH_HSICPHY_CFG1_TXSRTUNE (4U) /*!< Bit field size in bits for USBNC_UH_HSICPHY_CFG1_TXSRTUNE. */

/*! @brief Read current value of the USBNC_UH_HSICPHY_CFG1_TXSRTUNE field. */
#define BR_USBNC_UH_HSICPHY_CFG1_TXSRTUNE(x) (HW_USBNC_UH_HSICPHY_CFG1(x).B.TXSRTUNE)

/*! @brief Format value for bitfield USBNC_UH_HSICPHY_CFG1_TXSRTUNE. */
#define BF_USBNC_UH_HSICPHY_CFG1_TXSRTUNE(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_UH_HSICPHY_CFG1_TXSRTUNE) & BM_USBNC_UH_HSICPHY_CFG1_TXSRTUNE)

/*! @brief Set the TXSRTUNE field to a new value. */
#define BW_USBNC_UH_HSICPHY_CFG1_TXSRTUNE(x, v) (HW_USBNC_UH_HSICPHY_CFG1_WR(x, (HW_USBNC_UH_HSICPHY_CFG1_RD(x) & ~BM_USBNC_UH_HSICPHY_CFG1_TXSRTUNE) | BF_USBNC_UH_HSICPHY_CFG1_TXSRTUNE(v)))
/*@}*/

/*!
 * @name Register USBNC_UH_HSICPHY_CFG1, field REFCLKDIV[22:16] (RW)
 *
 * Reference clock frequency select. This bus selects the HSIC PHY reference
 * clock frequency. The value must remain static during normal operation.
 *
 * Values:
 * - 0100100 - 12 MHz (Default)
 * - 0011100 - 15 MHz
 * - 0011010 - 16 MHz
 * - 0010101 - 19.2 MHz
 * - 0010100 - 20 MHz
 */
/*@{*/
#define BP_USBNC_UH_HSICPHY_CFG1_REFCLKDIV (16U) /*!< Bit position for USBNC_UH_HSICPHY_CFG1_REFCLKDIV. */
#define BM_USBNC_UH_HSICPHY_CFG1_REFCLKDIV (0x007F0000U) /*!< Bit mask for USBNC_UH_HSICPHY_CFG1_REFCLKDIV. */
#define BS_USBNC_UH_HSICPHY_CFG1_REFCLKDIV (7U) /*!< Bit field size in bits for USBNC_UH_HSICPHY_CFG1_REFCLKDIV. */

/*! @brief Read current value of the USBNC_UH_HSICPHY_CFG1_REFCLKDIV field. */
#define BR_USBNC_UH_HSICPHY_CFG1_REFCLKDIV(x) (HW_USBNC_UH_HSICPHY_CFG1(x).B.REFCLKDIV)

/*! @brief Format value for bitfield USBNC_UH_HSICPHY_CFG1_REFCLKDIV. */
#define BF_USBNC_UH_HSICPHY_CFG1_REFCLKDIV(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_UH_HSICPHY_CFG1_REFCLKDIV) & BM_USBNC_UH_HSICPHY_CFG1_REFCLKDIV)

/*! @brief Set the REFCLKDIV field to a new value. */
#define BW_USBNC_UH_HSICPHY_CFG1_REFCLKDIV(x, v) (HW_USBNC_UH_HSICPHY_CFG1_WR(x, (HW_USBNC_UH_HSICPHY_CFG1_RD(x) & ~BM_USBNC_UH_HSICPHY_CFG1_REFCLKDIV) | BF_USBNC_UH_HSICPHY_CFG1_REFCLKDIV(v)))
/*@}*/

/*!
 * @name Register USBNC_UH_HSICPHY_CFG1, field REFCLKSEL[25:24] (RW)
 *
 * Reference clock select. Leave this field set to 2'b10. Operation with other
 * settings is undefined.
 */
/*@{*/
#define BP_USBNC_UH_HSICPHY_CFG1_REFCLKSEL (24U) /*!< Bit position for USBNC_UH_HSICPHY_CFG1_REFCLKSEL. */
#define BM_USBNC_UH_HSICPHY_CFG1_REFCLKSEL (0x03000000U) /*!< Bit mask for USBNC_UH_HSICPHY_CFG1_REFCLKSEL. */
#define BS_USBNC_UH_HSICPHY_CFG1_REFCLKSEL (2U) /*!< Bit field size in bits for USBNC_UH_HSICPHY_CFG1_REFCLKSEL. */

/*! @brief Read current value of the USBNC_UH_HSICPHY_CFG1_REFCLKSEL field. */
#define BR_USBNC_UH_HSICPHY_CFG1_REFCLKSEL(x) (HW_USBNC_UH_HSICPHY_CFG1(x).B.REFCLKSEL)

/*! @brief Format value for bitfield USBNC_UH_HSICPHY_CFG1_REFCLKSEL. */
#define BF_USBNC_UH_HSICPHY_CFG1_REFCLKSEL(v) ((uint32_t)((uint32_t)(v) << BP_USBNC_UH_HSICPHY_CFG1_REFCLKSEL) & BM_USBNC_UH_HSICPHY_CFG1_REFCLKSEL)

/*! @brief Set the REFCLKSEL field to a new value. */
#define BW_USBNC_UH_HSICPHY_CFG1_REFCLKSEL(x, v) (HW_USBNC_UH_HSICPHY_CFG1_WR(x, (HW_USBNC_UH_HSICPHY_CFG1_RD(x) & ~BM_USBNC_UH_HSICPHY_CFG1_REFCLKSEL) | BF_USBNC_UH_HSICPHY_CFG1_REFCLKSEL(v)))
/*@}*/

/*******************************************************************************
 * hw_usbnc_t - module struct
 ******************************************************************************/
/*!
 * @brief All USBNC module registers.
 */
#pragma pack(1)
typedef struct _hw_usbnc
{
    uint8_t _reserved0[512];
    __IO hw_usbnc_otg1_ctrl1_t OTG1_CTRL1; /*!< [0x200]  */
    __IO hw_usbnc_otg1_ctrl2_t OTG1_CTRL2; /*!< [0x204]  */
    uint8_t _reserved1[40];
    __IO hw_usbnc_otg1_phy_cfg1_t OTG1_PHY_CFG1; /*!< [0x230] USB OTG PHY Configuration Register 1 */
    __IO hw_usbnc_otg1_phy_cfg2_t OTG1_PHY_CFG2; /*!< [0x234] USB OTG PHY Configuration Register 2 */
    uint8_t _reserved2[4];
    __I hw_usbnc_otg1_phy_status_t OTG1_PHY_STATUS; /*!< [0x23C] USB OTG PHY Status Register */
    uint8_t _reserved3[16];
    __IO hw_usbnc_adp_cfg1_t ADP_CFG1;     /*!< [0x250]  */
    __IO hw_usbnc_adp_cfg2_t ADP_CFG2;     /*!< [0x254]  */
    __I hw_usbnc_adp_status_t ADP_STATUS;  /*!< [0x258]  */
    uint8_t _reserved4[65444];
    __IO hw_usbnc_otg2_ctrl1_t OTG2_CTRL1; /*!< [0x10200]  */
    __IO hw_usbnc_otg2_ctrl2_t OTG2_CTRL2; /*!< [0x10204]  */
    uint8_t _reserved5[40];
    __IO hw_usbnc_otg2_phy_cfg1_t OTG2_PHY_CFG1; /*!< [0x10230] USB OTG PHY Configuration Register 1 */
    __IO hw_usbnc_otg2_phy_cfg2_t OTG2_PHY_CFG2; /*!< [0x10234] USB OTG PHY Configuration Register 2 */
    uint8_t _reserved6[4];
    __I hw_usbnc_otg2_phy_status_t OTG2_PHY_STATUS; /*!< [0x1023C] USB OTG PHY Status Register */
    uint8_t _reserved7[65472];
    __IO hw_usbnc_hsic_ctrl1_t HSIC_CTRL1; /*!< [0x20200]  */
    __IO hw_usbnc_hsic_ctrl2_t HSIC_CTRL2; /*!< [0x20204]  */
    uint8_t _reserved8[56];
    __IO hw_usbnc_uh_hsicphy_cfg1_t UH_HSICPHY_CFG1; /*!< [0x20240] USB Host HSIC PHY Configuration Register */
} hw_usbnc_t;
#pragma pack()

/*! @brief Macro to access all USBNC registers. */
/*! @param x USBNC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_USBNC_REGS(USBNC_BASE)</code>. */
#define HW_USBNC_REGS(x) (*(hw_usbnc_t *)(x))

/*
 * iMX7D WDOG
 *
 * Watchdog Timer (WDOG)
 *
 * Registers defined in this header file:
 * - HW_WDOG_WCR - Watchdog Control Register
 * - HW_WDOG_WSR - Watchdog Service Register
 * - HW_WDOG_WRSR - Watchdog Reset Status Register
 * - HW_WDOG_WICR - Watchdog Interrupt Control Register
 * - HW_WDOG_WMCR - Watchdog Miscellaneous Control Register
 *
 * - hw_wdog_t - Struct containing all module registers.
 */

#define HW_WDOG_INSTANCE_COUNT (4U) /*!< Number of instances of the WDOG module. */
#define HW_WDOG1 (0U) /*!< Instance number for WDOG1. */
#define HW_WDOG2 (1U) /*!< Instance number for WDOG2. */
#define HW_WDOG3 (2U) /*!< Instance number for WDOG3. */
#define HW_WDOG4 (3U) /*!< Instance number for WDOG4. */
#define WDOG1_BASE            (0x30280000U) /*!< Base address for WDOG1. */
#define WDOG2_BASE            (0x30290000U) /*!< Base address for WDOG2. */
#define WDOG3_BASE            (0x302A0000U) /*!< Base address for WDOG3. */
#define WDOG4_BASE            (0x302B0000U) /*!< Base address for WDOG4. */
/*! Array initializer of WDOG base addresses. */
#define WDOG_BASE_ADDRS       { WDOG1_BASE, WDOG2_BASE, WDOG3_BASE, WDOG4_BASE }

/*******************************************************************************
 * HW_WDOG_WCR - Watchdog Control Register
 ******************************************************************************/

/*!
 * @brief HW_WDOG_WCR - Watchdog Control Register (RW)
 *
 * Reset value: 0x0030U
 *
 * The Watchdog Control Register (WDOG_WCR) controls the WDOG operation. WDZST,
 * WDBG and WDW are write-once only bits. Once the software does a write access
 * to these bits, they will be locked and cannot be reprogrammed until the next
 * system reset assertion. WDE is a write one once only bit. Once software performs
 * a write "1" operation to this bit it cannot be reset/cleared until the next
 * system reset. WDT is also a write one once only bit. Once software performs a
 * write "1" operation to this bit it cannot be reset/cleared until the next POR.
 * This bit does not get reset/cleared due to any system reset.
 */
typedef union _hw_wdog_wcr
{
    uint16_t U;
    struct _hw_wdog_wcr_bitfields
    {
        uint16_t WDZST : 1;            /*!< [0]  */
        uint16_t WDBG : 1;             /*!< [1]  */
        uint16_t WDE : 1;              /*!< [2]  */
        uint16_t WDT : 1;              /*!< [3]  */
        uint16_t SRS : 1;              /*!< [4]  */
        uint16_t WDA : 1;              /*!< [5]  */
        uint16_t SRE : 1;              /*!< [6] software reset extension, an option way to
                                        * generate software reset */
        uint16_t WDW : 1;              /*!< [7]  */
        uint16_t WT : 8;               /*!< [15:8]  */
    } B;
} hw_wdog_wcr_t;

/*!
 * @name Constants and macros for entire WDOG_WCR register
 */
/*@{*/
#define HW_WDOG_WCR_ADDR(x)      ((uintptr_t)(x) + 0x0U)

#define HW_WDOG_WCR(x)           (*(__IO hw_wdog_wcr_t *) HW_WDOG_WCR_ADDR(x))
#define HW_WDOG_WCR_RD(x)        (HW_WDOG_WCR(x).U)
#define HW_WDOG_WCR_WR(x, v)     (HW_WDOG_WCR(x).U = (v))
#define HW_WDOG_WCR_SET(x, v)    (HW_WDOG_WCR_WR(x, HW_WDOG_WCR_RD(x) |  (v)))
#define HW_WDOG_WCR_CLR(x, v)    (HW_WDOG_WCR_WR(x, HW_WDOG_WCR_RD(x) & ~(v)))
#define HW_WDOG_WCR_TOG(x, v)    (HW_WDOG_WCR_WR(x, HW_WDOG_WCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual WDOG_WCR bitfields
 */

/*!
 * @name Register WDOG_WCR, field WDZST[0] (RW)
 *
 * Watchdog Low Power. Determines the operation of the WDOG during low-power
 * modes. This bit is write once-only. The WDOG can continue/suspend the timer
 * operation in the low-power modes (STOP and DOZE mode).
 *
 * Values:
 * - 0 - Continue timer operation (Default).
 * - 1 - Suspend the watchdog timer.
 */
/*@{*/
#define BP_WDOG_WCR_WDZST    (0U)          /*!< Bit position for WDOG_WCR_WDZST. */
#define BM_WDOG_WCR_WDZST    (0x0001U)     /*!< Bit mask for WDOG_WCR_WDZST. */
#define BS_WDOG_WCR_WDZST    (1U)          /*!< Bit field size in bits for WDOG_WCR_WDZST. */

/*! @brief Read current value of the WDOG_WCR_WDZST field. */
#define BR_WDOG_WCR_WDZST(x) (HW_WDOG_WCR(x).B.WDZST)

/*! @brief Format value for bitfield WDOG_WCR_WDZST. */
#define BF_WDOG_WCR_WDZST(v) ((uint16_t)((uint16_t)(v) << BP_WDOG_WCR_WDZST) & BM_WDOG_WCR_WDZST)

/*! @brief Set the WDZST field to a new value. */
#define BW_WDOG_WCR_WDZST(x, v) (HW_WDOG_WCR_WR(x, (HW_WDOG_WCR_RD(x) & ~BM_WDOG_WCR_WDZST) | BF_WDOG_WCR_WDZST(v)))
/*@}*/

/*!
 * @name Register WDOG_WCR, field WDBG[1] (RW)
 *
 * Watchdog DEBUG Enable. Determines the operation of the WDOG during DEBUG
 * mode. This bit is write once only.
 *
 * Values:
 * - 0 - Continue WDOG timer operation (Default).
 * - 1 - Suspend the watchdog timer.
 */
/*@{*/
#define BP_WDOG_WCR_WDBG     (1U)          /*!< Bit position for WDOG_WCR_WDBG. */
#define BM_WDOG_WCR_WDBG     (0x0002U)     /*!< Bit mask for WDOG_WCR_WDBG. */
#define BS_WDOG_WCR_WDBG     (1U)          /*!< Bit field size in bits for WDOG_WCR_WDBG. */

/*! @brief Read current value of the WDOG_WCR_WDBG field. */
#define BR_WDOG_WCR_WDBG(x)  (HW_WDOG_WCR(x).B.WDBG)

/*! @brief Format value for bitfield WDOG_WCR_WDBG. */
#define BF_WDOG_WCR_WDBG(v)  ((uint16_t)((uint16_t)(v) << BP_WDOG_WCR_WDBG) & BM_WDOG_WCR_WDBG)

/*! @brief Set the WDBG field to a new value. */
#define BW_WDOG_WCR_WDBG(x, v) (HW_WDOG_WCR_WR(x, (HW_WDOG_WCR_RD(x) & ~BM_WDOG_WCR_WDBG) | BF_WDOG_WCR_WDBG(v)))
/*@}*/

/*!
 * @name Register WDOG_WCR, field WDE[2] (RW)
 *
 * Watchdog Enable. Enables or disables the WDOG block. This is a write one once
 * only bit. It is not possible to clear this bit by a software write, once the
 * bit is set. This bit can be set/reset in debug mode (exception).
 *
 * Values:
 * - 0 - Disable the Watchdog (Default).
 * - 1 - Enable the Watchdog.
 */
/*@{*/
#define BP_WDOG_WCR_WDE      (2U)          /*!< Bit position for WDOG_WCR_WDE. */
#define BM_WDOG_WCR_WDE      (0x0004U)     /*!< Bit mask for WDOG_WCR_WDE. */
#define BS_WDOG_WCR_WDE      (1U)          /*!< Bit field size in bits for WDOG_WCR_WDE. */

/*! @brief Read current value of the WDOG_WCR_WDE field. */
#define BR_WDOG_WCR_WDE(x)   (HW_WDOG_WCR(x).B.WDE)

/*! @brief Format value for bitfield WDOG_WCR_WDE. */
#define BF_WDOG_WCR_WDE(v)   ((uint16_t)((uint16_t)(v) << BP_WDOG_WCR_WDE) & BM_WDOG_WCR_WDE)

/*! @brief Set the WDE field to a new value. */
#define BW_WDOG_WCR_WDE(x, v) (HW_WDOG_WCR_WR(x, (HW_WDOG_WCR_RD(x) & ~BM_WDOG_WCR_WDE) | BF_WDOG_WCR_WDE(v)))
/*@}*/

/*!
 * @name Register WDOG_WCR, field WDT[3] (RW)
 *
 * WDOG_B Time-out assertion. Determines if the WDOG_B gets asserted upon a
 * Watchdog Time-out Event. This is a write-one once only bit. There is no effect on
 * WDOG_RESET_B_DEB (WDOG Reset) upon writing on this bit. WDOG_B gets asserted
 * along with WDOG_RESET_B_DEB if this bit is set.
 *
 * Values:
 * - 0 - No effect on WDOG_B (Default).
 * - 1 - Assert WDOG_B upon a Watchdog Time-out event.
 */
/*@{*/
#define BP_WDOG_WCR_WDT      (3U)          /*!< Bit position for WDOG_WCR_WDT. */
#define BM_WDOG_WCR_WDT      (0x0008U)     /*!< Bit mask for WDOG_WCR_WDT. */
#define BS_WDOG_WCR_WDT      (1U)          /*!< Bit field size in bits for WDOG_WCR_WDT. */

/*! @brief Read current value of the WDOG_WCR_WDT field. */
#define BR_WDOG_WCR_WDT(x)   (HW_WDOG_WCR(x).B.WDT)

/*! @brief Format value for bitfield WDOG_WCR_WDT. */
#define BF_WDOG_WCR_WDT(v)   ((uint16_t)((uint16_t)(v) << BP_WDOG_WCR_WDT) & BM_WDOG_WCR_WDT)

/*! @brief Set the WDT field to a new value. */
#define BW_WDOG_WCR_WDT(x, v) (HW_WDOG_WCR_WR(x, (HW_WDOG_WCR_RD(x) & ~BM_WDOG_WCR_WDT) | BF_WDOG_WCR_WDT(v)))
/*@}*/

/*!
 * @name Register WDOG_WCR, field SRS[4] (RW)
 *
 * Software Reset Signal. Controls the software assertion of the WDOG-generated
 * reset signal WDOG_RESET_B_DEB . This bit automatically resets to "1" after it
 * has been asserted to "0". This bit does not generate the software reset to the
 * block.
 *
 * Values:
 * - 0 - Assert system reset signal.
 * - 1 - No effect on the system (Default).
 */
/*@{*/
#define BP_WDOG_WCR_SRS      (4U)          /*!< Bit position for WDOG_WCR_SRS. */
#define BM_WDOG_WCR_SRS      (0x0010U)     /*!< Bit mask for WDOG_WCR_SRS. */
#define BS_WDOG_WCR_SRS      (1U)          /*!< Bit field size in bits for WDOG_WCR_SRS. */

/*! @brief Read current value of the WDOG_WCR_SRS field. */
#define BR_WDOG_WCR_SRS(x)   (HW_WDOG_WCR(x).B.SRS)

/*! @brief Format value for bitfield WDOG_WCR_SRS. */
#define BF_WDOG_WCR_SRS(v)   ((uint16_t)((uint16_t)(v) << BP_WDOG_WCR_SRS) & BM_WDOG_WCR_SRS)

/*! @brief Set the SRS field to a new value. */
#define BW_WDOG_WCR_SRS(x, v) (HW_WDOG_WCR_WR(x, (HW_WDOG_WCR_RD(x) & ~BM_WDOG_WCR_SRS) | BF_WDOG_WCR_SRS(v)))
/*@}*/

/*!
 * @name Register WDOG_WCR, field WDA[5] (RW)
 *
 * WDOG_B assertion. Controls the software assertion of the WDOG_B signal.
 *
 * Values:
 * - 0 - Assert WDOG_B output.
 * - 1 - No effect on system (Default).
 */
/*@{*/
#define BP_WDOG_WCR_WDA      (5U)          /*!< Bit position for WDOG_WCR_WDA. */
#define BM_WDOG_WCR_WDA      (0x0020U)     /*!< Bit mask for WDOG_WCR_WDA. */
#define BS_WDOG_WCR_WDA      (1U)          /*!< Bit field size in bits for WDOG_WCR_WDA. */

/*! @brief Read current value of the WDOG_WCR_WDA field. */
#define BR_WDOG_WCR_WDA(x)   (HW_WDOG_WCR(x).B.WDA)

/*! @brief Format value for bitfield WDOG_WCR_WDA. */
#define BF_WDOG_WCR_WDA(v)   ((uint16_t)((uint16_t)(v) << BP_WDOG_WCR_WDA) & BM_WDOG_WCR_WDA)

/*! @brief Set the WDA field to a new value. */
#define BW_WDOG_WCR_WDA(x, v) (HW_WDOG_WCR_WR(x, (HW_WDOG_WCR_RD(x) & ~BM_WDOG_WCR_WDA) | BF_WDOG_WCR_WDA(v)))
/*@}*/

/*!
 * @name Register WDOG_WCR, field SRE[6] (RW)
 *
 * adopt a new way to generate a more robust software reset. This bit can be
 * set/clear with IP bus and will be reset with power-on reset .
 *
 * Values:
 * - 0 - using original way to generate software reset (default)
 * - 1 - using new way to generate software reset.
 */
/*@{*/
#define BP_WDOG_WCR_SRE      (6U)          /*!< Bit position for WDOG_WCR_SRE. */
#define BM_WDOG_WCR_SRE      (0x0040U)     /*!< Bit mask for WDOG_WCR_SRE. */
#define BS_WDOG_WCR_SRE      (1U)          /*!< Bit field size in bits for WDOG_WCR_SRE. */

/*! @brief Read current value of the WDOG_WCR_SRE field. */
#define BR_WDOG_WCR_SRE(x)   (HW_WDOG_WCR(x).B.SRE)

/*! @brief Format value for bitfield WDOG_WCR_SRE. */
#define BF_WDOG_WCR_SRE(v)   ((uint16_t)((uint16_t)(v) << BP_WDOG_WCR_SRE) & BM_WDOG_WCR_SRE)

/*! @brief Set the SRE field to a new value. */
#define BW_WDOG_WCR_SRE(x, v) (HW_WDOG_WCR_WR(x, (HW_WDOG_WCR_RD(x) & ~BM_WDOG_WCR_SRE) | BF_WDOG_WCR_SRE(v)))
/*@}*/

/*!
 * @name Register WDOG_WCR, field WDW[7] (RW)
 *
 * Watchdog Disable for Wait. This bit determines the operation of WDOG during
 * Low Power WAIT mode. This is a write once only bit.
 *
 * Values:
 * - 0 - Continue WDOG timer operation (Default).
 * - 1 - Suspend WDOG timer operation.
 */
/*@{*/
#define BP_WDOG_WCR_WDW      (7U)          /*!< Bit position for WDOG_WCR_WDW. */
#define BM_WDOG_WCR_WDW      (0x0080U)     /*!< Bit mask for WDOG_WCR_WDW. */
#define BS_WDOG_WCR_WDW      (1U)          /*!< Bit field size in bits for WDOG_WCR_WDW. */

/*! @brief Read current value of the WDOG_WCR_WDW field. */
#define BR_WDOG_WCR_WDW(x)   (HW_WDOG_WCR(x).B.WDW)

/*! @brief Format value for bitfield WDOG_WCR_WDW. */
#define BF_WDOG_WCR_WDW(v)   ((uint16_t)((uint16_t)(v) << BP_WDOG_WCR_WDW) & BM_WDOG_WCR_WDW)

/*! @brief Set the WDW field to a new value. */
#define BW_WDOG_WCR_WDW(x, v) (HW_WDOG_WCR_WR(x, (HW_WDOG_WCR_RD(x) & ~BM_WDOG_WCR_WDW) | BF_WDOG_WCR_WDW(v)))
/*@}*/

/*!
 * @name Register WDOG_WCR, field WT[15:8] (RW)
 *
 * Watchdog Time-out Field. This 8-bit field contains the time-out value that is
 * loaded into the Watchdog counter after the service routine has been performed
 * or after the Watchdog is enabled. After reset, WT[7:0] must have a value
 * written to it before enabling the Watchdog otherwise count value of zero which is
 * 0.5 seconds is loaded into the counter. The time-out value can be written at
 * any point of time but it is loaded to the counter at the time when WDOG is
 * enabled or after the service routine has been performed. For more information see
 * Timeout eventThe WDOG provides timeout periods from 0.5 to 128 seconds with a
 * time resolution of 0.5 seconds. .
 *
 * Values:
 * - 0 - - 0.5 Seconds (Default).
 * - 1 - - 1.0 Seconds.
 * - 10 - - 1.5 Seconds.
 * - 11 - - 2.0 Seconds.
 * - 11111111 - - 128 Seconds.
 */
/*@{*/
#define BP_WDOG_WCR_WT       (8U)          /*!< Bit position for WDOG_WCR_WT. */
#define BM_WDOG_WCR_WT       (0xFF00U)     /*!< Bit mask for WDOG_WCR_WT. */
#define BS_WDOG_WCR_WT       (8U)          /*!< Bit field size in bits for WDOG_WCR_WT. */

/*! @brief Read current value of the WDOG_WCR_WT field. */
#define BR_WDOG_WCR_WT(x)    (HW_WDOG_WCR(x).B.WT)

/*! @brief Format value for bitfield WDOG_WCR_WT. */
#define BF_WDOG_WCR_WT(v)    ((uint16_t)((uint16_t)(v) << BP_WDOG_WCR_WT) & BM_WDOG_WCR_WT)

/*! @brief Set the WT field to a new value. */
#define BW_WDOG_WCR_WT(x, v) (HW_WDOG_WCR_WR(x, (HW_WDOG_WCR_RD(x) & ~BM_WDOG_WCR_WT) | BF_WDOG_WCR_WT(v)))
/*@}*/

/*******************************************************************************
 * HW_WDOG_WSR - Watchdog Service Register
 ******************************************************************************/

/*!
 * @brief HW_WDOG_WSR - Watchdog Service Register (RW)
 *
 * Reset value: 0x0000U
 *
 * When enabled, the WDOG requires that a service sequence be written to the
 * Watchdog Service Register (WSR) to prevent the timeout condition. Executing the
 * service sequence will reload the WDOG timeout counter.
 */
typedef union _hw_wdog_wsr
{
    uint16_t U;
    struct _hw_wdog_wsr_bitfields
    {
        uint16_t WSR : 16;             /*!< [15:0]  */
    } B;
} hw_wdog_wsr_t;

/*!
 * @name Constants and macros for entire WDOG_WSR register
 */
/*@{*/
#define HW_WDOG_WSR_ADDR(x)      ((uintptr_t)(x) + 0x2U)

#define HW_WDOG_WSR(x)           (*(__IO hw_wdog_wsr_t *) HW_WDOG_WSR_ADDR(x))
#define HW_WDOG_WSR_RD(x)        (HW_WDOG_WSR(x).U)
#define HW_WDOG_WSR_WR(x, v)     (HW_WDOG_WSR(x).U = (v))
#define HW_WDOG_WSR_SET(x, v)    (HW_WDOG_WSR_WR(x, HW_WDOG_WSR_RD(x) |  (v)))
#define HW_WDOG_WSR_CLR(x, v)    (HW_WDOG_WSR_WR(x, HW_WDOG_WSR_RD(x) & ~(v)))
#define HW_WDOG_WSR_TOG(x, v)    (HW_WDOG_WSR_WR(x, HW_WDOG_WSR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual WDOG_WSR bitfields
 */

/*!
 * @name Register WDOG_WSR, field WSR[15:0] (RW)
 *
 * Watchdog Service Register. This 16-bit field contains the Watchdog service
 * sequence. Both writes must occur in the order listed prior to the time-out, but
 * any number of instructions can be executed between the two writes. The service
 * sequence must be performed as follows:
 *
 * Values:
 * - 101010101010101 - Write to the Watchdog Service Register (WDOG_WSR).
 * - 1010101010101010 - Write to the Watchdog Service Register (WDOG_WSR).
 */
/*@{*/
#define BP_WDOG_WSR_WSR      (0U)          /*!< Bit position for WDOG_WSR_WSR. */
#define BM_WDOG_WSR_WSR      (0xFFFFU)     /*!< Bit mask for WDOG_WSR_WSR. */
#define BS_WDOG_WSR_WSR      (16U)         /*!< Bit field size in bits for WDOG_WSR_WSR. */

/*! @brief Read current value of the WDOG_WSR_WSR field. */
#define BR_WDOG_WSR_WSR(x)   (HW_WDOG_WSR(x).U)

/*! @brief Format value for bitfield WDOG_WSR_WSR. */
#define BF_WDOG_WSR_WSR(v)   ((uint16_t)((uint16_t)(v) << BP_WDOG_WSR_WSR) & BM_WDOG_WSR_WSR)

/*! @brief Set the WSR field to a new value. */
#define BW_WDOG_WSR_WSR(x, v) (HW_WDOG_WSR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_WDOG_WRSR - Watchdog Reset Status Register
 ******************************************************************************/

/*!
 * @brief HW_WDOG_WRSR - Watchdog Reset Status Register (RO)
 *
 * Reset value: 0x0000U
 *
 * The WRSR is a read-only register that records the source of the output reset
 * assertion. It is not cleared by a hard reset. Therefore, only one bit in the
 * WRSR will always be asserted high. The register will always indicate the source
 * of the last reset generated due to WDOG. Read access to this register is with
 * one wait state. Any write performed on this register will generate a
 * Peripheral Bus Error . A reset can be generated by the following sources, as listed in
 * priority from highest to lowest: Watchdog Time-out Software Reset
 */
typedef union _hw_wdog_wrsr
{
    uint16_t U;
    struct _hw_wdog_wrsr_bitfields
    {
        uint16_t SFTW : 1;             /*!< [0]  */
        uint16_t TOUT : 1;             /*!< [1]  */
        uint16_t RESERVED0 : 2;        /*!< [3:2]  */
        uint16_t POR : 1;              /*!< [4]  */
        uint16_t RESERVED1 : 11;       /*!< [15:5]  */
    } B;
} hw_wdog_wrsr_t;

/*!
 * @name Constants and macros for entire WDOG_WRSR register
 */
/*@{*/
#define HW_WDOG_WRSR_ADDR(x)     ((uintptr_t)(x) + 0x4U)

#define HW_WDOG_WRSR(x)          (*(__I hw_wdog_wrsr_t *) HW_WDOG_WRSR_ADDR(x))
#define HW_WDOG_WRSR_RD(x)       (HW_WDOG_WRSR(x).U)
/*@}*/

/*
 * Constants & macros for individual WDOG_WRSR bitfields
 */

/*!
 * @name Register WDOG_WRSR, field SFTW[0] (RO)
 *
 * Software Reset. Indicates whether the reset is the result of a WDOG software
 * reset by asserting SRS bit
 *
 * Values:
 * - 0 - Reset is not the result of a software reset.
 * - 1 - Reset is the result of a software reset.
 */
/*@{*/
#define BP_WDOG_WRSR_SFTW    (0U)          /*!< Bit position for WDOG_WRSR_SFTW. */
#define BM_WDOG_WRSR_SFTW    (0x0001U)     /*!< Bit mask for WDOG_WRSR_SFTW. */
#define BS_WDOG_WRSR_SFTW    (1U)          /*!< Bit field size in bits for WDOG_WRSR_SFTW. */

/*! @brief Read current value of the WDOG_WRSR_SFTW field. */
#define BR_WDOG_WRSR_SFTW(x) (HW_WDOG_WRSR(x).B.SFTW)
/*@}*/

/*!
 * @name Register WDOG_WRSR, field TOUT[1] (RO)
 *
 * Timeout. Indicates whether the reset is the result of a WDOG timeout.
 *
 * Values:
 * - 0 - Reset is not the result of a WDOG timeout.
 * - 1 - Reset is the result of a WDOG timeout.
 */
/*@{*/
#define BP_WDOG_WRSR_TOUT    (1U)          /*!< Bit position for WDOG_WRSR_TOUT. */
#define BM_WDOG_WRSR_TOUT    (0x0002U)     /*!< Bit mask for WDOG_WRSR_TOUT. */
#define BS_WDOG_WRSR_TOUT    (1U)          /*!< Bit field size in bits for WDOG_WRSR_TOUT. */

/*! @brief Read current value of the WDOG_WRSR_TOUT field. */
#define BR_WDOG_WRSR_TOUT(x) (HW_WDOG_WRSR(x).B.TOUT)
/*@}*/

/*!
 * @name Register WDOG_WRSR, field POR[4] (RO)
 *
 * Power On Reset. Indicates whether the reset is the result of a power on reset.
 *
 * Values:
 * - 0 - Reset is not the result of a power on reset.
 * - 1 - Reset is the result of a power on reset.
 */
/*@{*/
#define BP_WDOG_WRSR_POR     (4U)          /*!< Bit position for WDOG_WRSR_POR. */
#define BM_WDOG_WRSR_POR     (0x0010U)     /*!< Bit mask for WDOG_WRSR_POR. */
#define BS_WDOG_WRSR_POR     (1U)          /*!< Bit field size in bits for WDOG_WRSR_POR. */

/*! @brief Read current value of the WDOG_WRSR_POR field. */
#define BR_WDOG_WRSR_POR(x)  (HW_WDOG_WRSR(x).B.POR)
/*@}*/

/*******************************************************************************
 * HW_WDOG_WICR - Watchdog Interrupt Control Register
 ******************************************************************************/

/*!
 * @brief HW_WDOG_WICR - Watchdog Interrupt Control Register (RW)
 *
 * Reset value: 0x0004U
 *
 * The WDOG_WICR controls the WDOG interrupt generation.
 */
typedef union _hw_wdog_wicr
{
    uint16_t U;
    struct _hw_wdog_wicr_bitfields
    {
        uint16_t WICT : 8;             /*!< [7:0]  */
        uint16_t RESERVED0 : 6;        /*!< [13:8]  */
        uint16_t WTIS : 1;             /*!< [14]  */
        uint16_t WIE : 1;              /*!< [15]  */
    } B;
} hw_wdog_wicr_t;

/*!
 * @name Constants and macros for entire WDOG_WICR register
 */
/*@{*/
#define HW_WDOG_WICR_ADDR(x)     ((uintptr_t)(x) + 0x6U)

#define HW_WDOG_WICR(x)          (*(__IO hw_wdog_wicr_t *) HW_WDOG_WICR_ADDR(x))
#define HW_WDOG_WICR_RD(x)       (HW_WDOG_WICR(x).U)
#define HW_WDOG_WICR_WR(x, v)    (HW_WDOG_WICR(x).U = (v))
#define HW_WDOG_WICR_SET(x, v)   (HW_WDOG_WICR_WR(x, HW_WDOG_WICR_RD(x) |  (v)))
#define HW_WDOG_WICR_CLR(x, v)   (HW_WDOG_WICR_WR(x, HW_WDOG_WICR_RD(x) & ~(v)))
#define HW_WDOG_WICR_TOG(x, v)   (HW_WDOG_WICR_WR(x, HW_WDOG_WICR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual WDOG_WICR bitfields
 */

/*!
 * @name Register WDOG_WICR, field WICT[7:0] (RW)
 *
 * Watchdog Interrupt Count Time-out (WICT) field determines, how long before
 * the counter time-out must the interrupt occur. The reset value is 0x04 implies
 * interrupt will occur 2 seconds before time-out. The maximum value that can be
 * programmed to WICT field is 127.5 seconds with a resolution of 0.5 seconds.
 * This field is write once only. Once the software does a write access to this
 * field, it will get locked and cannot be reprogrammed until the next system reset
 * assertion.
 *
 * Values:
 * - 0 - WICT[7:0] = Time duration between interrupt and time-out is 0 seconds.
 * - 1 - WICT[7:0] = Time duration between interrupt and time-out is 0.5 seconds.
 * - 100 - WICT[7:0] = Time duration between interrupt and time-out is 2 seconds
 *     (Default).
 * - 11111111 - WICT[7:0] = Time duration between interrupt and time-out is
 *     127.5 seconds.
 */
/*@{*/
#define BP_WDOG_WICR_WICT    (0U)          /*!< Bit position for WDOG_WICR_WICT. */
#define BM_WDOG_WICR_WICT    (0x00FFU)     /*!< Bit mask for WDOG_WICR_WICT. */
#define BS_WDOG_WICR_WICT    (8U)          /*!< Bit field size in bits for WDOG_WICR_WICT. */

/*! @brief Read current value of the WDOG_WICR_WICT field. */
#define BR_WDOG_WICR_WICT(x) (HW_WDOG_WICR(x).B.WICT)

/*! @brief Format value for bitfield WDOG_WICR_WICT. */
#define BF_WDOG_WICR_WICT(v) ((uint16_t)((uint16_t)(v) << BP_WDOG_WICR_WICT) & BM_WDOG_WICR_WICT)

/*! @brief Set the WICT field to a new value. */
#define BW_WDOG_WICR_WICT(x, v) (HW_WDOG_WICR_WR(x, (HW_WDOG_WICR_RD(x) & ~(BM_WDOG_WICR_WICT | BM_WDOG_WICR_WTIS)) | BF_WDOG_WICR_WICT(v)))
/*@}*/

/*!
 * @name Register WDOG_WICR, field WTIS[14] (W1C)
 *
 * Watchdog TImer Interrupt Status bit will reflect the timer interrupt status,
 * whether interrupt has occurred or not. Once the interrupt has been triggered
 * software must clear this bit by writing 1 to it.
 *
 * Values:
 * - 0 - No interrupt has occurred (Default).
 * - 1 - Interrupt has occurred
 */
/*@{*/
#define BP_WDOG_WICR_WTIS    (14U)         /*!< Bit position for WDOG_WICR_WTIS. */
#define BM_WDOG_WICR_WTIS    (0x4000U)     /*!< Bit mask for WDOG_WICR_WTIS. */
#define BS_WDOG_WICR_WTIS    (1U)          /*!< Bit field size in bits for WDOG_WICR_WTIS. */

/*! @brief Read current value of the WDOG_WICR_WTIS field. */
#define BR_WDOG_WICR_WTIS(x) (HW_WDOG_WICR(x).B.WTIS)

/*! @brief Format value for bitfield WDOG_WICR_WTIS. */
#define BF_WDOG_WICR_WTIS(v) ((uint16_t)((uint16_t)(v) << BP_WDOG_WICR_WTIS) & BM_WDOG_WICR_WTIS)

/*! @brief Set the WTIS field to a new value. */
#define BW_WDOG_WICR_WTIS(x, v) (HW_WDOG_WICR_WR(x, (HW_WDOG_WICR_RD(x) & ~BM_WDOG_WICR_WTIS) | BF_WDOG_WICR_WTIS(v)))
/*@}*/

/*!
 * @name Register WDOG_WICR, field WIE[15] (RW)
 *
 * Watchdog Timer Interrupt enable bit. Reset value is 0. This bit is a write
 * once only bit. Once the software does a write access to this bit, it will get
 * locked and cannot be reprogrammed until the next system reset assertion
 *
 * Values:
 * - 0 - Disable Interrupt (Default).
 * - 1 - Enable Interrupt.
 */
/*@{*/
#define BP_WDOG_WICR_WIE     (15U)         /*!< Bit position for WDOG_WICR_WIE. */
#define BM_WDOG_WICR_WIE     (0x8000U)     /*!< Bit mask for WDOG_WICR_WIE. */
#define BS_WDOG_WICR_WIE     (1U)          /*!< Bit field size in bits for WDOG_WICR_WIE. */

/*! @brief Read current value of the WDOG_WICR_WIE field. */
#define BR_WDOG_WICR_WIE(x)  (HW_WDOG_WICR(x).B.WIE)

/*! @brief Format value for bitfield WDOG_WICR_WIE. */
#define BF_WDOG_WICR_WIE(v)  ((uint16_t)((uint16_t)(v) << BP_WDOG_WICR_WIE) & BM_WDOG_WICR_WIE)

/*! @brief Set the WIE field to a new value. */
#define BW_WDOG_WICR_WIE(x, v) (HW_WDOG_WICR_WR(x, (HW_WDOG_WICR_RD(x) & ~(BM_WDOG_WICR_WIE | BM_WDOG_WICR_WTIS)) | BF_WDOG_WICR_WIE(v)))
/*@}*/

/*******************************************************************************
 * HW_WDOG_WMCR - Watchdog Miscellaneous Control Register
 ******************************************************************************/

/*!
 * @brief HW_WDOG_WMCR - Watchdog Miscellaneous Control Register (RW)
 *
 * Reset value: 0x0001U
 *
 * WDOG_WMCR Controls the Power Down counter operation.
 */
typedef union _hw_wdog_wmcr
{
    uint16_t U;
    struct _hw_wdog_wmcr_bitfields
    {
        uint16_t PDE : 1;              /*!< [0]  */
        uint16_t RESERVED0 : 15;       /*!< [15:1]  */
    } B;
} hw_wdog_wmcr_t;

/*!
 * @name Constants and macros for entire WDOG_WMCR register
 */
/*@{*/
#define HW_WDOG_WMCR_ADDR(x)     ((uintptr_t)(x) + 0x8U)

#define HW_WDOG_WMCR(x)          (*(__IO hw_wdog_wmcr_t *) HW_WDOG_WMCR_ADDR(x))
#define HW_WDOG_WMCR_RD(x)       (HW_WDOG_WMCR(x).U)
#define HW_WDOG_WMCR_WR(x, v)    (HW_WDOG_WMCR(x).U = (v))
#define HW_WDOG_WMCR_SET(x, v)   (HW_WDOG_WMCR_WR(x, HW_WDOG_WMCR_RD(x) |  (v)))
#define HW_WDOG_WMCR_CLR(x, v)   (HW_WDOG_WMCR_WR(x, HW_WDOG_WMCR_RD(x) & ~(v)))
#define HW_WDOG_WMCR_TOG(x, v)   (HW_WDOG_WMCR_WR(x, HW_WDOG_WMCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual WDOG_WMCR bitfields
 */

/*!
 * @name Register WDOG_WMCR, field PDE[0] (RW)
 *
 * Power Down Enable bit. Reset value of this bit is 1, which means the power
 * down counter inside the WDOG is enabled after reset. The software must write 0
 * to this bit to disable the counter within 16 seconds of reset de-assertion.
 * Once disabled this counter cannot be enabled again. See Power-down counter
 * eventThe power-down counter inside WDOG will be enabled out of reset. This counter
 * has a fixed timeout value of 16 seconds, after which it will drive the WDOG_B
 * signal low. for operation of this counter. This bit is write-one once only bit.
 * Once software sets this bit it cannot be reset until the next system reset.
 *
 * Values:
 * - 0 - Power Down Counter of WDOG is disabled.
 * - 1 - Power Down Counter of WDOG is enabled (Default).
 */
/*@{*/
#define BP_WDOG_WMCR_PDE     (0U)          /*!< Bit position for WDOG_WMCR_PDE. */
#define BM_WDOG_WMCR_PDE     (0x0001U)     /*!< Bit mask for WDOG_WMCR_PDE. */
#define BS_WDOG_WMCR_PDE     (1U)          /*!< Bit field size in bits for WDOG_WMCR_PDE. */

/*! @brief Read current value of the WDOG_WMCR_PDE field. */
#define BR_WDOG_WMCR_PDE(x)  (HW_WDOG_WMCR(x).B.PDE)

/*! @brief Format value for bitfield WDOG_WMCR_PDE. */
#define BF_WDOG_WMCR_PDE(v)  ((uint16_t)((uint16_t)(v) << BP_WDOG_WMCR_PDE) & BM_WDOG_WMCR_PDE)

/*! @brief Set the PDE field to a new value. */
#define BW_WDOG_WMCR_PDE(x, v) (HW_WDOG_WMCR_WR(x, (HW_WDOG_WMCR_RD(x) & ~BM_WDOG_WMCR_PDE) | BF_WDOG_WMCR_PDE(v)))
/*@}*/

/*******************************************************************************
 * hw_wdog_t - module struct
 ******************************************************************************/
/*!
 * @brief All WDOG module registers.
 */
#pragma pack(1)
typedef struct _hw_wdog
{
    __IO hw_wdog_wcr_t WCR;                /*!< [0x0] Watchdog Control Register */
    __IO hw_wdog_wsr_t WSR;                /*!< [0x2] Watchdog Service Register */
    __I hw_wdog_wrsr_t WRSR;               /*!< [0x4] Watchdog Reset Status Register */
    __IO hw_wdog_wicr_t WICR;              /*!< [0x6] Watchdog Interrupt Control Register */
    __IO hw_wdog_wmcr_t WMCR;              /*!< [0x8] Watchdog Miscellaneous Control Register */
} hw_wdog_t;
#pragma pack()

/*! @brief Macro to access all WDOG registers. */
/*! @param x WDOG module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_WDOG_REGS(WDOG1_BASE)</code>. */
#define HW_WDOG_REGS(x) (*(hw_wdog_t *)(x))

/*
 * iMX7D XTALOSC
 *
 * Crystal Oscillator (XTALOSC)
 *
 * Registers defined in this header file:
 * - HW_XTALOSC_CTRL_24M - Anadig 24M Oscillator Control Register
 * - HW_XTALOSC_RCOSC_CONFIG0 - Anadig 24MHz RC Osc. config0 Register
 * - HW_XTALOSC_RCOSC_CONFIG1 - Anadig 24MHz RC Osc. config1 Register
 * - HW_XTALOSC_RCOSC_CONFIG2 - Anadig 24MHz RC Osc. config2 Register
 * - HW_XTALOSC_OSC_32K - 32K Oscillator Control Register
 *
 * - hw_xtalosc_t - Struct containing all module registers.
 */

#define HW_XTALOSC_INSTANCE_COUNT (1U) /*!< Number of instances of the XTALOSC module. */
#define HW_XTALOSC (0U) /*!< Instance number for XTALOSC. */
#define XTALOSC_BASE          (0x30360000U) /*!< Base address for XTALOSC. */
/*! Array initializer of XTALOSC base addresses. */
#define XTALOSC_BASE_ADDRS    { XTALOSC_BASE }

/*******************************************************************************
 * HW_XTALOSC_CTRL_24M - Anadig 24M Oscillator Control Register
 ******************************************************************************/

/*!
 * @brief HW_XTALOSC_CTRL_24M - Anadig 24M Oscillator Control Register (RW)
 *
 * Reset value: 0x0000222AU
 *
 * The enable bit is useful kill the output clocks while keeping the oscillator
 * working. Naturally, it is good practice to disable the oscillator before
 * powering down.
 */
typedef union _hw_xtalosc_ctrl_24m
{
    uint32_t U;
    struct _hw_xtalosc_ctrl_24m_bitfields
    {
        uint32_t XTAL_24M_PWD : 1;     /*!< [0]  */
        uint32_t XTAL_24M_EN : 1;      /*!< [1]  */
        uint32_t OSC_XTALOK : 1;       /*!< [2]  */
        uint32_t OSC_XTALOK_EN : 1;    /*!< [3]  */
        uint32_t CLKGATE_CTRL : 1;     /*!< [4]  */
        uint32_t CLKGATE_DELAY : 3;    /*!< [7:5]  */
        uint32_t RCOSC_CG_OVERRIDE : 1; /*!< [8]  */
        uint32_t XTALOSC_PWRUP_DELAY : 2; /*!< [10:9]  */
        uint32_t XTALOSC_PWRUP_STAT : 1; /*!< [11]  */
        uint32_t OSC_SEL : 1;          /*!< [12]  */
        uint32_t RC_OSC_EN : 1;        /*!< [13]  */
        uint32_t RESERVED0 : 1;        /*!< [14]  */
        uint32_t XTAL_MISC : 16;       /*!< [30:15]  */
        uint32_t RESERVED1 : 1;        /*!< [31]  */
    } B;
} hw_xtalosc_ctrl_24m_t;

/*!
 * @name Constants and macros for entire XTALOSC_CTRL_24M register
 */
/*@{*/
#define HW_XTALOSC_CTRL_24M_ADDR(x) ((uintptr_t)(x) + 0x0U)
#define HW_XTALOSC_CTRL_24M_SET_ADDR(x) (HW_XTALOSC_CTRL_24M_ADDR(x) + 0x4U)
#define HW_XTALOSC_CTRL_24M_CLR_ADDR(x) (HW_XTALOSC_CTRL_24M_ADDR(x) + 0x8U)
#define HW_XTALOSC_CTRL_24M_TOG_ADDR(x) (HW_XTALOSC_CTRL_24M_ADDR(x) + 0xCU)

#define HW_XTALOSC_CTRL_24M(x)   (*(__IO hw_xtalosc_ctrl_24m_t *) HW_XTALOSC_CTRL_24M_ADDR(x))
#define HW_XTALOSC_CTRL_24M_RD(x) (HW_XTALOSC_CTRL_24M(x).U)
#define HW_XTALOSC_CTRL_24M_WR(x, v) (HW_XTALOSC_CTRL_24M(x).U = (v))
#define HW_XTALOSC_CTRL_24M_SET(x, v) ((*(uint32_t *) HW_XTALOSC_CTRL_24M_SET_ADDR(x)) = (v))
#define HW_XTALOSC_CTRL_24M_CLR(x, v) ((*(uint32_t *) HW_XTALOSC_CTRL_24M_CLR_ADDR(x)) = (v))
#define HW_XTALOSC_CTRL_24M_TOG(x, v) ((*(uint32_t *) HW_XTALOSC_CTRL_24M_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual XTALOSC_CTRL_24M bitfields
 */

/*!
 * @name Register XTALOSC_CTRL_24M, field XTAL_24M_PWD[0] (RW)
 *
 * This field powers down the 24M crystal oscillator if set true.
 */
/*@{*/
#define BP_XTALOSC_CTRL_24M_XTAL_24M_PWD (0U) /*!< Bit position for XTALOSC_CTRL_24M_XTAL_24M_PWD. */
#define BM_XTALOSC_CTRL_24M_XTAL_24M_PWD (0x00000001U) /*!< Bit mask for XTALOSC_CTRL_24M_XTAL_24M_PWD. */
#define BS_XTALOSC_CTRL_24M_XTAL_24M_PWD (1U) /*!< Bit field size in bits for XTALOSC_CTRL_24M_XTAL_24M_PWD. */

/*! @brief Read current value of the XTALOSC_CTRL_24M_XTAL_24M_PWD field. */
#define BR_XTALOSC_CTRL_24M_XTAL_24M_PWD(x) (HW_XTALOSC_CTRL_24M(x).B.XTAL_24M_PWD)

/*! @brief Format value for bitfield XTALOSC_CTRL_24M_XTAL_24M_PWD. */
#define BF_XTALOSC_CTRL_24M_XTAL_24M_PWD(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_CTRL_24M_XTAL_24M_PWD) & BM_XTALOSC_CTRL_24M_XTAL_24M_PWD)

/*! @brief Set the XTAL_24M_PWD field to a new value. */
#define BW_XTALOSC_CTRL_24M_XTAL_24M_PWD(x, v) (HW_XTALOSC_CTRL_24M_WR(x, (HW_XTALOSC_CTRL_24M_RD(x) & ~BM_XTALOSC_CTRL_24M_XTAL_24M_PWD) | BF_XTALOSC_CTRL_24M_XTAL_24M_PWD(v)))
/*@}*/

/*!
 * @name Register XTALOSC_CTRL_24M, field XTAL_24M_EN[1] (RW)
 *
 * This field controls the clock gate at the output of the oscillator. 1 =
 * enabled
 */
/*@{*/
#define BP_XTALOSC_CTRL_24M_XTAL_24M_EN (1U) /*!< Bit position for XTALOSC_CTRL_24M_XTAL_24M_EN. */
#define BM_XTALOSC_CTRL_24M_XTAL_24M_EN (0x00000002U) /*!< Bit mask for XTALOSC_CTRL_24M_XTAL_24M_EN. */
#define BS_XTALOSC_CTRL_24M_XTAL_24M_EN (1U) /*!< Bit field size in bits for XTALOSC_CTRL_24M_XTAL_24M_EN. */

/*! @brief Read current value of the XTALOSC_CTRL_24M_XTAL_24M_EN field. */
#define BR_XTALOSC_CTRL_24M_XTAL_24M_EN(x) (HW_XTALOSC_CTRL_24M(x).B.XTAL_24M_EN)

/*! @brief Format value for bitfield XTALOSC_CTRL_24M_XTAL_24M_EN. */
#define BF_XTALOSC_CTRL_24M_XTAL_24M_EN(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_CTRL_24M_XTAL_24M_EN) & BM_XTALOSC_CTRL_24M_XTAL_24M_EN)

/*! @brief Set the XTAL_24M_EN field to a new value. */
#define BW_XTALOSC_CTRL_24M_XTAL_24M_EN(x, v) (HW_XTALOSC_CTRL_24M_WR(x, (HW_XTALOSC_CTRL_24M_RD(x) & ~BM_XTALOSC_CTRL_24M_XTAL_24M_EN) | BF_XTALOSC_CTRL_24M_XTAL_24M_EN(v)))
/*@}*/

/*!
 * @name Register XTALOSC_CTRL_24M, field OSC_XTALOK[2] (RO)
 *
 * Status bit which signals that the output of the 24MHz crystal oscillator is
 * stable.
 */
/*@{*/
#define BP_XTALOSC_CTRL_24M_OSC_XTALOK (2U) /*!< Bit position for XTALOSC_CTRL_24M_OSC_XTALOK. */
#define BM_XTALOSC_CTRL_24M_OSC_XTALOK (0x00000004U) /*!< Bit mask for XTALOSC_CTRL_24M_OSC_XTALOK. */
#define BS_XTALOSC_CTRL_24M_OSC_XTALOK (1U) /*!< Bit field size in bits for XTALOSC_CTRL_24M_OSC_XTALOK. */

/*! @brief Read current value of the XTALOSC_CTRL_24M_OSC_XTALOK field. */
#define BR_XTALOSC_CTRL_24M_OSC_XTALOK(x) (HW_XTALOSC_CTRL_24M(x).B.OSC_XTALOK)
/*@}*/

/*!
 * @name Register XTALOSC_CTRL_24M, field OSC_XTALOK_EN[3] (RW)
 *
 * Enable the xtalok detection circuitry.
 */
/*@{*/
#define BP_XTALOSC_CTRL_24M_OSC_XTALOK_EN (3U) /*!< Bit position for XTALOSC_CTRL_24M_OSC_XTALOK_EN. */
#define BM_XTALOSC_CTRL_24M_OSC_XTALOK_EN (0x00000008U) /*!< Bit mask for XTALOSC_CTRL_24M_OSC_XTALOK_EN. */
#define BS_XTALOSC_CTRL_24M_OSC_XTALOK_EN (1U) /*!< Bit field size in bits for XTALOSC_CTRL_24M_OSC_XTALOK_EN. */

/*! @brief Read current value of the XTALOSC_CTRL_24M_OSC_XTALOK_EN field. */
#define BR_XTALOSC_CTRL_24M_OSC_XTALOK_EN(x) (HW_XTALOSC_CTRL_24M(x).B.OSC_XTALOK_EN)

/*! @brief Format value for bitfield XTALOSC_CTRL_24M_OSC_XTALOK_EN. */
#define BF_XTALOSC_CTRL_24M_OSC_XTALOK_EN(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_CTRL_24M_OSC_XTALOK_EN) & BM_XTALOSC_CTRL_24M_OSC_XTALOK_EN)

/*! @brief Set the OSC_XTALOK_EN field to a new value. */
#define BW_XTALOSC_CTRL_24M_OSC_XTALOK_EN(x, v) (HW_XTALOSC_CTRL_24M_WR(x, (HW_XTALOSC_CTRL_24M_RD(x) & ~BM_XTALOSC_CTRL_24M_OSC_XTALOK_EN) | BF_XTALOSC_CTRL_24M_OSC_XTALOK_EN(v)))
/*@}*/

/*!
 * @name Register XTALOSC_CTRL_24M, field CLKGATE_CTRL[4] (RW)
 *
 * This bit allows disabling the clock gate (always un-gated) for the xtal 24MHz
 * clock that clocks the digital logic in the analog block. 0x0 - Allow the
 * logic to automatically gate the clock when the xtal is powered down. 0x1 - Prevent
 * the logic from ever gating off the clock. Under normal operating conditions,
 * if the RCOsc is sourcing the 24MHz clk, this setting is ignored and the clock
 * gate will not be gated. Note: Do not change this field during a low power
 * event. This control is not a bit that the user would normally need to modify.
 */
/*@{*/
#define BP_XTALOSC_CTRL_24M_CLKGATE_CTRL (4U) /*!< Bit position for XTALOSC_CTRL_24M_CLKGATE_CTRL. */
#define BM_XTALOSC_CTRL_24M_CLKGATE_CTRL (0x00000010U) /*!< Bit mask for XTALOSC_CTRL_24M_CLKGATE_CTRL. */
#define BS_XTALOSC_CTRL_24M_CLKGATE_CTRL (1U) /*!< Bit field size in bits for XTALOSC_CTRL_24M_CLKGATE_CTRL. */

/*! @brief Read current value of the XTALOSC_CTRL_24M_CLKGATE_CTRL field. */
#define BR_XTALOSC_CTRL_24M_CLKGATE_CTRL(x) (HW_XTALOSC_CTRL_24M(x).B.CLKGATE_CTRL)

/*! @brief Format value for bitfield XTALOSC_CTRL_24M_CLKGATE_CTRL. */
#define BF_XTALOSC_CTRL_24M_CLKGATE_CTRL(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_CTRL_24M_CLKGATE_CTRL) & BM_XTALOSC_CTRL_24M_CLKGATE_CTRL)

/*! @brief Set the CLKGATE_CTRL field to a new value. */
#define BW_XTALOSC_CTRL_24M_CLKGATE_CTRL(x, v) (HW_XTALOSC_CTRL_24M_WR(x, (HW_XTALOSC_CTRL_24M_RD(x) & ~BM_XTALOSC_CTRL_24M_CLKGATE_CTRL) | BF_XTALOSC_CTRL_24M_CLKGATE_CTRL(v)))
/*@}*/

/*!
 * @name Register XTALOSC_CTRL_24M, field CLKGATE_DELAY[7:5] (RW)
 *
 * This field specifies the delay between powering up the xtal 24MHz clock and
 * release the clock to the digital logic inside the analog block. 0x0 - 0.5 ms;
 * 0x1 - 1 ms; 0x2 - 2 ms; 0x3 - 3 ms; 0x4 - 4 ms; 0x5 - 5 ms; 0x6 - 6 ms; 0x7 - 7
 * ms. Note: Do not change this field during a low power event. This is not a
 * field that the user would normally need to modify.
 */
/*@{*/
#define BP_XTALOSC_CTRL_24M_CLKGATE_DELAY (5U) /*!< Bit position for XTALOSC_CTRL_24M_CLKGATE_DELAY. */
#define BM_XTALOSC_CTRL_24M_CLKGATE_DELAY (0x000000E0U) /*!< Bit mask for XTALOSC_CTRL_24M_CLKGATE_DELAY. */
#define BS_XTALOSC_CTRL_24M_CLKGATE_DELAY (3U) /*!< Bit field size in bits for XTALOSC_CTRL_24M_CLKGATE_DELAY. */

/*! @brief Read current value of the XTALOSC_CTRL_24M_CLKGATE_DELAY field. */
#define BR_XTALOSC_CTRL_24M_CLKGATE_DELAY(x) (HW_XTALOSC_CTRL_24M(x).B.CLKGATE_DELAY)

/*! @brief Format value for bitfield XTALOSC_CTRL_24M_CLKGATE_DELAY. */
#define BF_XTALOSC_CTRL_24M_CLKGATE_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_CTRL_24M_CLKGATE_DELAY) & BM_XTALOSC_CTRL_24M_CLKGATE_DELAY)

/*! @brief Set the CLKGATE_DELAY field to a new value. */
#define BW_XTALOSC_CTRL_24M_CLKGATE_DELAY(x, v) (HW_XTALOSC_CTRL_24M_WR(x, (HW_XTALOSC_CTRL_24M_RD(x) & ~BM_XTALOSC_CTRL_24M_CLKGATE_DELAY) | BF_XTALOSC_CTRL_24M_CLKGATE_DELAY(v)))
/*@}*/

/*!
 * @name Register XTALOSC_CTRL_24M, field RCOSC_CG_OVERRIDE[8] (RW)
 *
 * For debug purposes only. This bit effects clock gating of certain digital
 * logic clocked by the 24MHz clk.
 */
/*@{*/
#define BP_XTALOSC_CTRL_24M_RCOSC_CG_OVERRIDE (8U) /*!< Bit position for XTALOSC_CTRL_24M_RCOSC_CG_OVERRIDE. */
#define BM_XTALOSC_CTRL_24M_RCOSC_CG_OVERRIDE (0x00000100U) /*!< Bit mask for XTALOSC_CTRL_24M_RCOSC_CG_OVERRIDE. */
#define BS_XTALOSC_CTRL_24M_RCOSC_CG_OVERRIDE (1U) /*!< Bit field size in bits for XTALOSC_CTRL_24M_RCOSC_CG_OVERRIDE. */

/*! @brief Read current value of the XTALOSC_CTRL_24M_RCOSC_CG_OVERRIDE field. */
#define BR_XTALOSC_CTRL_24M_RCOSC_CG_OVERRIDE(x) (HW_XTALOSC_CTRL_24M(x).B.RCOSC_CG_OVERRIDE)

/*! @brief Format value for bitfield XTALOSC_CTRL_24M_RCOSC_CG_OVERRIDE. */
#define BF_XTALOSC_CTRL_24M_RCOSC_CG_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_CTRL_24M_RCOSC_CG_OVERRIDE) & BM_XTALOSC_CTRL_24M_RCOSC_CG_OVERRIDE)

/*! @brief Set the RCOSC_CG_OVERRIDE field to a new value. */
#define BW_XTALOSC_CTRL_24M_RCOSC_CG_OVERRIDE(x, v) (HW_XTALOSC_CTRL_24M_WR(x, (HW_XTALOSC_CTRL_24M_RD(x) & ~BM_XTALOSC_CTRL_24M_RCOSC_CG_OVERRIDE) | BF_XTALOSC_CTRL_24M_RCOSC_CG_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register XTALOSC_CTRL_24M, field XTALOSC_PWRUP_DELAY[10:9] (RW)
 *
 * Specifies the time delay between when the 24MHz xtal is powered up until it
 * is stable and ready to use. 0 - 0.25ms; 1 - 0.5ms; 2 - 1ms; 3 - 2ms.
 */
/*@{*/
#define BP_XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY (9U) /*!< Bit position for XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY. */
#define BM_XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY (0x00000600U) /*!< Bit mask for XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY. */
#define BS_XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY (2U) /*!< Bit field size in bits for XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY. */

/*! @brief Read current value of the XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY field. */
#define BR_XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY(x) (HW_XTALOSC_CTRL_24M(x).B.XTALOSC_PWRUP_DELAY)

/*! @brief Format value for bitfield XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY. */
#define BF_XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY) & BM_XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY)

/*! @brief Set the XTALOSC_PWRUP_DELAY field to a new value. */
#define BW_XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY(x, v) (HW_XTALOSC_CTRL_24M_WR(x, (HW_XTALOSC_CTRL_24M_RD(x) & ~BM_XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY) | BF_XTALOSC_CTRL_24M_XTALOSC_PWRUP_DELAY(v)))
/*@}*/

/*!
 * @name Register XTALOSC_CTRL_24M, field XTALOSC_PWRUP_STAT[11] (RO)
 *
 * Status of the 24MHz xtal oscillator. 0 - not stable; 1 - Stable and ready to
 * use.
 */
/*@{*/
#define BP_XTALOSC_CTRL_24M_XTALOSC_PWRUP_STAT (11U) /*!< Bit position for XTALOSC_CTRL_24M_XTALOSC_PWRUP_STAT. */
#define BM_XTALOSC_CTRL_24M_XTALOSC_PWRUP_STAT (0x00000800U) /*!< Bit mask for XTALOSC_CTRL_24M_XTALOSC_PWRUP_STAT. */
#define BS_XTALOSC_CTRL_24M_XTALOSC_PWRUP_STAT (1U) /*!< Bit field size in bits for XTALOSC_CTRL_24M_XTALOSC_PWRUP_STAT. */

/*! @brief Read current value of the XTALOSC_CTRL_24M_XTALOSC_PWRUP_STAT field. */
#define BR_XTALOSC_CTRL_24M_XTALOSC_PWRUP_STAT(x) (HW_XTALOSC_CTRL_24M(x).B.XTALOSC_PWRUP_STAT)
/*@}*/

/*!
 * @name Register XTALOSC_CTRL_24M, field OSC_SEL[12] (RW)
 *
 * Select the source for the 24MHz clock. 0 - xtal osc.; 1 - RC osc.
 */
/*@{*/
#define BP_XTALOSC_CTRL_24M_OSC_SEL (12U)  /*!< Bit position for XTALOSC_CTRL_24M_OSC_SEL. */
#define BM_XTALOSC_CTRL_24M_OSC_SEL (0x00001000U) /*!< Bit mask for XTALOSC_CTRL_24M_OSC_SEL. */
#define BS_XTALOSC_CTRL_24M_OSC_SEL (1U)   /*!< Bit field size in bits for XTALOSC_CTRL_24M_OSC_SEL. */

/*! @brief Read current value of the XTALOSC_CTRL_24M_OSC_SEL field. */
#define BR_XTALOSC_CTRL_24M_OSC_SEL(x) (HW_XTALOSC_CTRL_24M(x).B.OSC_SEL)

/*! @brief Format value for bitfield XTALOSC_CTRL_24M_OSC_SEL. */
#define BF_XTALOSC_CTRL_24M_OSC_SEL(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_CTRL_24M_OSC_SEL) & BM_XTALOSC_CTRL_24M_OSC_SEL)

/*! @brief Set the OSC_SEL field to a new value. */
#define BW_XTALOSC_CTRL_24M_OSC_SEL(x, v) (HW_XTALOSC_CTRL_24M_WR(x, (HW_XTALOSC_CTRL_24M_RD(x) & ~BM_XTALOSC_CTRL_24M_OSC_SEL) | BF_XTALOSC_CTRL_24M_OSC_SEL(v)))
/*@}*/

/*!
 * @name Register XTALOSC_CTRL_24M, field RC_OSC_EN[13] (RW)
 *
 * RC osc. enable control. 0- turn off the RC osc. 24MHz clock; 1- turn on the
 * RC osc. clock.
 */
/*@{*/
#define BP_XTALOSC_CTRL_24M_RC_OSC_EN (13U) /*!< Bit position for XTALOSC_CTRL_24M_RC_OSC_EN. */
#define BM_XTALOSC_CTRL_24M_RC_OSC_EN (0x00002000U) /*!< Bit mask for XTALOSC_CTRL_24M_RC_OSC_EN. */
#define BS_XTALOSC_CTRL_24M_RC_OSC_EN (1U) /*!< Bit field size in bits for XTALOSC_CTRL_24M_RC_OSC_EN. */

/*! @brief Read current value of the XTALOSC_CTRL_24M_RC_OSC_EN field. */
#define BR_XTALOSC_CTRL_24M_RC_OSC_EN(x) (HW_XTALOSC_CTRL_24M(x).B.RC_OSC_EN)

/*! @brief Format value for bitfield XTALOSC_CTRL_24M_RC_OSC_EN. */
#define BF_XTALOSC_CTRL_24M_RC_OSC_EN(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_CTRL_24M_RC_OSC_EN) & BM_XTALOSC_CTRL_24M_RC_OSC_EN)

/*! @brief Set the RC_OSC_EN field to a new value. */
#define BW_XTALOSC_CTRL_24M_RC_OSC_EN(x, v) (HW_XTALOSC_CTRL_24M_WR(x, (HW_XTALOSC_CTRL_24M_RD(x) & ~BM_XTALOSC_CTRL_24M_RC_OSC_EN) | BF_XTALOSC_CTRL_24M_RC_OSC_EN(v)))
/*@}*/

/*!
 * @name Register XTALOSC_CTRL_24M, field XTAL_MISC[30:15] (RW)
 *
 * Misc control bits for 24m xtal osc
 */
/*@{*/
#define BP_XTALOSC_CTRL_24M_XTAL_MISC (15U) /*!< Bit position for XTALOSC_CTRL_24M_XTAL_MISC. */
#define BM_XTALOSC_CTRL_24M_XTAL_MISC (0x7FFF8000U) /*!< Bit mask for XTALOSC_CTRL_24M_XTAL_MISC. */
#define BS_XTALOSC_CTRL_24M_XTAL_MISC (16U) /*!< Bit field size in bits for XTALOSC_CTRL_24M_XTAL_MISC. */

/*! @brief Read current value of the XTALOSC_CTRL_24M_XTAL_MISC field. */
#define BR_XTALOSC_CTRL_24M_XTAL_MISC(x) (HW_XTALOSC_CTRL_24M(x).B.XTAL_MISC)

/*! @brief Format value for bitfield XTALOSC_CTRL_24M_XTAL_MISC. */
#define BF_XTALOSC_CTRL_24M_XTAL_MISC(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_CTRL_24M_XTAL_MISC) & BM_XTALOSC_CTRL_24M_XTAL_MISC)

/*! @brief Set the XTAL_MISC field to a new value. */
#define BW_XTALOSC_CTRL_24M_XTAL_MISC(x, v) (HW_XTALOSC_CTRL_24M_WR(x, (HW_XTALOSC_CTRL_24M_RD(x) & ~BM_XTALOSC_CTRL_24M_XTAL_MISC) | BF_XTALOSC_CTRL_24M_XTAL_MISC(v)))
/*@}*/




/*******************************************************************************
 * HW_XTALOSC_RCOSC_CONFIG0 - Anadig 24MHz RC Osc. config0 Register
 ******************************************************************************/

/*!
 * @brief HW_XTALOSC_RCOSC_CONFIG0 - Anadig 24MHz RC Osc. config0 Register (RW)
 *
 * Reset value: 0x00022930U
 *
 * This register is used to configure the 24MHz RC oscillator.
 */
typedef union _hw_xtalosc_rcosc_config0
{
    uint32_t U;
    struct _hw_xtalosc_rcosc_config0_bitfields
    {
        uint32_t TUNE_START : 1;       /*!< [0]  */
        uint32_t TUNE_ENABLE : 1;      /*!< [1]  */
        uint32_t TUNE_BYPASS : 1;      /*!< [2]  */
        uint32_t TUNE_INVERT : 1;      /*!< [3]  */
        uint32_t RC_OSC_PROG : 8;      /*!< [11:4]  */
        uint32_t HYST_PLUS : 4;        /*!< [15:12]  */
        uint32_t HYST_MINUS : 4;       /*!< [19:16]  */
        uint32_t RESERVED0 : 4;        /*!< [23:20]  */
        uint32_t RC_OSC_PROG_CUR : 8;  /*!< [31:24]  */
    } B;
} hw_xtalosc_rcosc_config0_t;

/*!
 * @name Constants and macros for entire XTALOSC_RCOSC_CONFIG0 register
 */
/*@{*/
#define HW_XTALOSC_RCOSC_CONFIG0_ADDR(x) ((uintptr_t)(x) + 0x10U)
#define HW_XTALOSC_RCOSC_CONFIG0_SET_ADDR(x) (HW_XTALOSC_RCOSC_CONFIG0_ADDR(x) + 0x4U)
#define HW_XTALOSC_RCOSC_CONFIG0_CLR_ADDR(x) (HW_XTALOSC_RCOSC_CONFIG0_ADDR(x) + 0x8U)
#define HW_XTALOSC_RCOSC_CONFIG0_TOG_ADDR(x) (HW_XTALOSC_RCOSC_CONFIG0_ADDR(x) + 0xCU)

#define HW_XTALOSC_RCOSC_CONFIG0(x) (*(__IO hw_xtalosc_rcosc_config0_t *) HW_XTALOSC_RCOSC_CONFIG0_ADDR(x))
#define HW_XTALOSC_RCOSC_CONFIG0_RD(x) (HW_XTALOSC_RCOSC_CONFIG0(x).U)
#define HW_XTALOSC_RCOSC_CONFIG0_WR(x, v) (HW_XTALOSC_RCOSC_CONFIG0(x).U = (v))
#define HW_XTALOSC_RCOSC_CONFIG0_SET(x, v) ((*(uint32_t *) HW_XTALOSC_RCOSC_CONFIG0_SET_ADDR(x)) = (v))
#define HW_XTALOSC_RCOSC_CONFIG0_CLR(x, v) ((*(uint32_t *) HW_XTALOSC_RCOSC_CONFIG0_CLR_ADDR(x)) = (v))
#define HW_XTALOSC_RCOSC_CONFIG0_TOG(x, v) ((*(uint32_t *) HW_XTALOSC_RCOSC_CONFIG0_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual XTALOSC_RCOSC_CONFIG0 bitfields
 */

/*!
 * @name Register XTALOSC_RCOSC_CONFIG0, field TUNE_START[0] (RW)
 *
 * Start/stop bit for the RC tuning calculation logic. If stopped the tuning
 * logic is reset.
 */
/*@{*/
#define BP_XTALOSC_RCOSC_CONFIG0_TUNE_START (0U) /*!< Bit position for XTALOSC_RCOSC_CONFIG0_TUNE_START. */
#define BM_XTALOSC_RCOSC_CONFIG0_TUNE_START (0x00000001U) /*!< Bit mask for XTALOSC_RCOSC_CONFIG0_TUNE_START. */
#define BS_XTALOSC_RCOSC_CONFIG0_TUNE_START (1U) /*!< Bit field size in bits for XTALOSC_RCOSC_CONFIG0_TUNE_START. */

/*! @brief Read current value of the XTALOSC_RCOSC_CONFIG0_TUNE_START field. */
#define BR_XTALOSC_RCOSC_CONFIG0_TUNE_START(x) (HW_XTALOSC_RCOSC_CONFIG0(x).B.TUNE_START)

/*! @brief Format value for bitfield XTALOSC_RCOSC_CONFIG0_TUNE_START. */
#define BF_XTALOSC_RCOSC_CONFIG0_TUNE_START(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_RCOSC_CONFIG0_TUNE_START) & BM_XTALOSC_RCOSC_CONFIG0_TUNE_START)

/*! @brief Set the TUNE_START field to a new value. */
#define BW_XTALOSC_RCOSC_CONFIG0_TUNE_START(x, v) (HW_XTALOSC_RCOSC_CONFIG0_WR(x, (HW_XTALOSC_RCOSC_CONFIG0_RD(x) & ~BM_XTALOSC_RCOSC_CONFIG0_TUNE_START) | BF_XTALOSC_RCOSC_CONFIG0_TUNE_START(v)))
/*@}*/

/*!
 * @name Register XTALOSC_RCOSC_CONFIG0, field TUNE_ENABLE[1] (RW)
 *
 * Enables the tuning logic to calculate new RC tuning values. Disabling
 * essentially freezes the state of the calculation.
 */
/*@{*/
#define BP_XTALOSC_RCOSC_CONFIG0_TUNE_ENABLE (1U) /*!< Bit position for XTALOSC_RCOSC_CONFIG0_TUNE_ENABLE. */
#define BM_XTALOSC_RCOSC_CONFIG0_TUNE_ENABLE (0x00000002U) /*!< Bit mask for XTALOSC_RCOSC_CONFIG0_TUNE_ENABLE. */
#define BS_XTALOSC_RCOSC_CONFIG0_TUNE_ENABLE (1U) /*!< Bit field size in bits for XTALOSC_RCOSC_CONFIG0_TUNE_ENABLE. */

/*! @brief Read current value of the XTALOSC_RCOSC_CONFIG0_TUNE_ENABLE field. */
#define BR_XTALOSC_RCOSC_CONFIG0_TUNE_ENABLE(x) (HW_XTALOSC_RCOSC_CONFIG0(x).B.TUNE_ENABLE)

/*! @brief Format value for bitfield XTALOSC_RCOSC_CONFIG0_TUNE_ENABLE. */
#define BF_XTALOSC_RCOSC_CONFIG0_TUNE_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_RCOSC_CONFIG0_TUNE_ENABLE) & BM_XTALOSC_RCOSC_CONFIG0_TUNE_ENABLE)

/*! @brief Set the TUNE_ENABLE field to a new value. */
#define BW_XTALOSC_RCOSC_CONFIG0_TUNE_ENABLE(x, v) (HW_XTALOSC_RCOSC_CONFIG0_WR(x, (HW_XTALOSC_RCOSC_CONFIG0_RD(x) & ~BM_XTALOSC_RCOSC_CONFIG0_TUNE_ENABLE) | BF_XTALOSC_RCOSC_CONFIG0_TUNE_ENABLE(v)))
/*@}*/

/*!
 * @name Register XTALOSC_RCOSC_CONFIG0, field TUNE_BYPASS[2] (RW)
 *
 * Bypasses any calculated RC tuning value and uses the programmed register
 * value.
 */
/*@{*/
#define BP_XTALOSC_RCOSC_CONFIG0_TUNE_BYPASS (2U) /*!< Bit position for XTALOSC_RCOSC_CONFIG0_TUNE_BYPASS. */
#define BM_XTALOSC_RCOSC_CONFIG0_TUNE_BYPASS (0x00000004U) /*!< Bit mask for XTALOSC_RCOSC_CONFIG0_TUNE_BYPASS. */
#define BS_XTALOSC_RCOSC_CONFIG0_TUNE_BYPASS (1U) /*!< Bit field size in bits for XTALOSC_RCOSC_CONFIG0_TUNE_BYPASS. */

/*! @brief Read current value of the XTALOSC_RCOSC_CONFIG0_TUNE_BYPASS field. */
#define BR_XTALOSC_RCOSC_CONFIG0_TUNE_BYPASS(x) (HW_XTALOSC_RCOSC_CONFIG0(x).B.TUNE_BYPASS)

/*! @brief Format value for bitfield XTALOSC_RCOSC_CONFIG0_TUNE_BYPASS. */
#define BF_XTALOSC_RCOSC_CONFIG0_TUNE_BYPASS(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_RCOSC_CONFIG0_TUNE_BYPASS) & BM_XTALOSC_RCOSC_CONFIG0_TUNE_BYPASS)

/*! @brief Set the TUNE_BYPASS field to a new value. */
#define BW_XTALOSC_RCOSC_CONFIG0_TUNE_BYPASS(x, v) (HW_XTALOSC_RCOSC_CONFIG0_WR(x, (HW_XTALOSC_RCOSC_CONFIG0_RD(x) & ~BM_XTALOSC_RCOSC_CONFIG0_TUNE_BYPASS) | BF_XTALOSC_RCOSC_CONFIG0_TUNE_BYPASS(v)))
/*@}*/

/*!
 * @name Register XTALOSC_RCOSC_CONFIG0, field TUNE_INVERT[3] (RW)
 *
 * Invert the stepping of the calculated RC tuning value.
 */
/*@{*/
#define BP_XTALOSC_RCOSC_CONFIG0_TUNE_INVERT (3U) /*!< Bit position for XTALOSC_RCOSC_CONFIG0_TUNE_INVERT. */
#define BM_XTALOSC_RCOSC_CONFIG0_TUNE_INVERT (0x00000008U) /*!< Bit mask for XTALOSC_RCOSC_CONFIG0_TUNE_INVERT. */
#define BS_XTALOSC_RCOSC_CONFIG0_TUNE_INVERT (1U) /*!< Bit field size in bits for XTALOSC_RCOSC_CONFIG0_TUNE_INVERT. */

/*! @brief Read current value of the XTALOSC_RCOSC_CONFIG0_TUNE_INVERT field. */
#define BR_XTALOSC_RCOSC_CONFIG0_TUNE_INVERT(x) (HW_XTALOSC_RCOSC_CONFIG0(x).B.TUNE_INVERT)

/*! @brief Format value for bitfield XTALOSC_RCOSC_CONFIG0_TUNE_INVERT. */
#define BF_XTALOSC_RCOSC_CONFIG0_TUNE_INVERT(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_RCOSC_CONFIG0_TUNE_INVERT) & BM_XTALOSC_RCOSC_CONFIG0_TUNE_INVERT)

/*! @brief Set the TUNE_INVERT field to a new value. */
#define BW_XTALOSC_RCOSC_CONFIG0_TUNE_INVERT(x, v) (HW_XTALOSC_RCOSC_CONFIG0_WR(x, (HW_XTALOSC_RCOSC_CONFIG0_RD(x) & ~BM_XTALOSC_RCOSC_CONFIG0_TUNE_INVERT) | BF_XTALOSC_RCOSC_CONFIG0_TUNE_INVERT(v)))
/*@}*/

/*!
 * @name Register XTALOSC_RCOSC_CONFIG0, field RC_OSC_PROG[11:4] (RW)
 *
 * RC osc. tuning values.
 */
/*@{*/
#define BP_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG (4U) /*!< Bit position for XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG. */
#define BM_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG (0x00000FF0U) /*!< Bit mask for XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG. */
#define BS_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG (8U) /*!< Bit field size in bits for XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG. */

/*! @brief Read current value of the XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG field. */
#define BR_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG(x) (HW_XTALOSC_RCOSC_CONFIG0(x).B.RC_OSC_PROG)

/*! @brief Format value for bitfield XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG. */
#define BF_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG) & BM_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG)

/*! @brief Set the RC_OSC_PROG field to a new value. */
#define BW_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG(x, v) (HW_XTALOSC_RCOSC_CONFIG0_WR(x, (HW_XTALOSC_RCOSC_CONFIG0_RD(x) & ~BM_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG) | BF_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG(v)))
/*@}*/

/*!
 * @name Register XTALOSC_RCOSC_CONFIG0, field HYST_PLUS[15:12] (RW)
 *
 * Positive hysteresis value. Added to target value before comparison. This,
 * along with HYST_MINUS creates a range.
 */
/*@{*/
#define BP_XTALOSC_RCOSC_CONFIG0_HYST_PLUS (12U) /*!< Bit position for XTALOSC_RCOSC_CONFIG0_HYST_PLUS. */
#define BM_XTALOSC_RCOSC_CONFIG0_HYST_PLUS (0x0000F000U) /*!< Bit mask for XTALOSC_RCOSC_CONFIG0_HYST_PLUS. */
#define BS_XTALOSC_RCOSC_CONFIG0_HYST_PLUS (4U) /*!< Bit field size in bits for XTALOSC_RCOSC_CONFIG0_HYST_PLUS. */

/*! @brief Read current value of the XTALOSC_RCOSC_CONFIG0_HYST_PLUS field. */
#define BR_XTALOSC_RCOSC_CONFIG0_HYST_PLUS(x) (HW_XTALOSC_RCOSC_CONFIG0(x).B.HYST_PLUS)

/*! @brief Format value for bitfield XTALOSC_RCOSC_CONFIG0_HYST_PLUS. */
#define BF_XTALOSC_RCOSC_CONFIG0_HYST_PLUS(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_RCOSC_CONFIG0_HYST_PLUS) & BM_XTALOSC_RCOSC_CONFIG0_HYST_PLUS)

/*! @brief Set the HYST_PLUS field to a new value. */
#define BW_XTALOSC_RCOSC_CONFIG0_HYST_PLUS(x, v) (HW_XTALOSC_RCOSC_CONFIG0_WR(x, (HW_XTALOSC_RCOSC_CONFIG0_RD(x) & ~BM_XTALOSC_RCOSC_CONFIG0_HYST_PLUS) | BF_XTALOSC_RCOSC_CONFIG0_HYST_PLUS(v)))
/*@}*/

/*!
 * @name Register XTALOSC_RCOSC_CONFIG0, field HYST_MINUS[19:16] (RW)
 *
 * Negative hysteresis value. Subtracted from target value before comparison.
 * This, along with HYST_PLUS creates a range.
 */
/*@{*/
#define BP_XTALOSC_RCOSC_CONFIG0_HYST_MINUS (16U) /*!< Bit position for XTALOSC_RCOSC_CONFIG0_HYST_MINUS. */
#define BM_XTALOSC_RCOSC_CONFIG0_HYST_MINUS (0x000F0000U) /*!< Bit mask for XTALOSC_RCOSC_CONFIG0_HYST_MINUS. */
#define BS_XTALOSC_RCOSC_CONFIG0_HYST_MINUS (4U) /*!< Bit field size in bits for XTALOSC_RCOSC_CONFIG0_HYST_MINUS. */

/*! @brief Read current value of the XTALOSC_RCOSC_CONFIG0_HYST_MINUS field. */
#define BR_XTALOSC_RCOSC_CONFIG0_HYST_MINUS(x) (HW_XTALOSC_RCOSC_CONFIG0(x).B.HYST_MINUS)

/*! @brief Format value for bitfield XTALOSC_RCOSC_CONFIG0_HYST_MINUS. */
#define BF_XTALOSC_RCOSC_CONFIG0_HYST_MINUS(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_RCOSC_CONFIG0_HYST_MINUS) & BM_XTALOSC_RCOSC_CONFIG0_HYST_MINUS)

/*! @brief Set the HYST_MINUS field to a new value. */
#define BW_XTALOSC_RCOSC_CONFIG0_HYST_MINUS(x, v) (HW_XTALOSC_RCOSC_CONFIG0_WR(x, (HW_XTALOSC_RCOSC_CONFIG0_RD(x) & ~BM_XTALOSC_RCOSC_CONFIG0_HYST_MINUS) | BF_XTALOSC_RCOSC_CONFIG0_HYST_MINUS(v)))
/*@}*/

/*!
 * @name Register XTALOSC_RCOSC_CONFIG0, field RC_OSC_PROG_CUR[31:24] (RW)
 *
 * The current tuning value in use.
 */
/*@{*/
#define BP_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR (24U) /*!< Bit position for XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR. */
#define BM_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR (0xFF000000U) /*!< Bit mask for XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR. */
#define BS_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR (8U) /*!< Bit field size in bits for XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR. */

/*! @brief Read current value of the XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR field. */
#define BR_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR(x) (HW_XTALOSC_RCOSC_CONFIG0(x).B.RC_OSC_PROG_CUR)

/*! @brief Format value for bitfield XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR. */
#define BF_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR) & BM_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR)

/*! @brief Set the RC_OSC_PROG_CUR field to a new value. */
#define BW_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR(x, v) (HW_XTALOSC_RCOSC_CONFIG0_WR(x, (HW_XTALOSC_RCOSC_CONFIG0_RD(x) & ~BM_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR) | BF_XTALOSC_RCOSC_CONFIG0_RC_OSC_PROG_CUR(v)))
/*@}*/




/*******************************************************************************
 * HW_XTALOSC_RCOSC_CONFIG1 - Anadig 24MHz RC Osc. config1 Register
 ******************************************************************************/

/*!
 * @brief HW_XTALOSC_RCOSC_CONFIG1 - Anadig 24MHz RC Osc. config1 Register (RW)
 *
 * Reset value: 0x000002FAU
 *
 * This register is used to configure the 24MHz RC oscillator.
 */
typedef union _hw_xtalosc_rcosc_config1
{
    uint32_t U;
    struct _hw_xtalosc_rcosc_config1_bitfields
    {
        uint32_t COUNT_RC_TRG : 12;    /*!< [11:0]  */
        uint32_t RESERVED0 : 8;        /*!< [19:12]  */
        uint32_t COUNT_RC_CUR : 12;    /*!< [31:20]  */
    } B;
} hw_xtalosc_rcosc_config1_t;

/*!
 * @name Constants and macros for entire XTALOSC_RCOSC_CONFIG1 register
 */
/*@{*/
#define HW_XTALOSC_RCOSC_CONFIG1_ADDR(x) ((uintptr_t)(x) + 0x20U)
#define HW_XTALOSC_RCOSC_CONFIG1_SET_ADDR(x) (HW_XTALOSC_RCOSC_CONFIG1_ADDR(x) + 0x4U)
#define HW_XTALOSC_RCOSC_CONFIG1_CLR_ADDR(x) (HW_XTALOSC_RCOSC_CONFIG1_ADDR(x) + 0x8U)
#define HW_XTALOSC_RCOSC_CONFIG1_TOG_ADDR(x) (HW_XTALOSC_RCOSC_CONFIG1_ADDR(x) + 0xCU)

#define HW_XTALOSC_RCOSC_CONFIG1(x) (*(__IO hw_xtalosc_rcosc_config1_t *) HW_XTALOSC_RCOSC_CONFIG1_ADDR(x))
#define HW_XTALOSC_RCOSC_CONFIG1_RD(x) (HW_XTALOSC_RCOSC_CONFIG1(x).U)
#define HW_XTALOSC_RCOSC_CONFIG1_WR(x, v) (HW_XTALOSC_RCOSC_CONFIG1(x).U = (v))
#define HW_XTALOSC_RCOSC_CONFIG1_SET(x, v) ((*(uint32_t *) HW_XTALOSC_RCOSC_CONFIG1_SET_ADDR(x)) = (v))
#define HW_XTALOSC_RCOSC_CONFIG1_CLR(x, v) ((*(uint32_t *) HW_XTALOSC_RCOSC_CONFIG1_CLR_ADDR(x)) = (v))
#define HW_XTALOSC_RCOSC_CONFIG1_TOG(x, v) ((*(uint32_t *) HW_XTALOSC_RCOSC_CONFIG1_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual XTALOSC_RCOSC_CONFIG1 bitfields
 */

/*!
 * @name Register XTALOSC_RCOSC_CONFIG1, field COUNT_RC_TRG[11:0] (RW)
 *
 * The target count used to tune the RC OSC frequency. Essentially the number of
 * desired RC Osc clock cycles within 1 32KHz clock cycle.
 */
/*@{*/
#define BP_XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG (0U) /*!< Bit position for XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG. */
#define BM_XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG (0x00000FFFU) /*!< Bit mask for XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG. */
#define BS_XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG (12U) /*!< Bit field size in bits for XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG. */

/*! @brief Read current value of the XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG field. */
#define BR_XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG(x) (HW_XTALOSC_RCOSC_CONFIG1(x).B.COUNT_RC_TRG)

/*! @brief Format value for bitfield XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG. */
#define BF_XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG) & BM_XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG)

/*! @brief Set the COUNT_RC_TRG field to a new value. */
#define BW_XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG(x, v) (HW_XTALOSC_RCOSC_CONFIG1_WR(x, (HW_XTALOSC_RCOSC_CONFIG1_RD(x) & ~BM_XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG) | BF_XTALOSC_RCOSC_CONFIG1_COUNT_RC_TRG(v)))
/*@}*/

/*!
 * @name Register XTALOSC_RCOSC_CONFIG1, field COUNT_RC_CUR[31:20] (RW)
 *
 * The current tuning value in use.
 */
/*@{*/
#define BP_XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR (20U) /*!< Bit position for XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR. */
#define BM_XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR (0xFFF00000U) /*!< Bit mask for XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR. */
#define BS_XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR (12U) /*!< Bit field size in bits for XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR. */

/*! @brief Read current value of the XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR field. */
#define BR_XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR(x) (HW_XTALOSC_RCOSC_CONFIG1(x).B.COUNT_RC_CUR)

/*! @brief Format value for bitfield XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR. */
#define BF_XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR) & BM_XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR)

/*! @brief Set the COUNT_RC_CUR field to a new value. */
#define BW_XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR(x, v) (HW_XTALOSC_RCOSC_CONFIG1_WR(x, (HW_XTALOSC_RCOSC_CONFIG1_RD(x) & ~BM_XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR) | BF_XTALOSC_RCOSC_CONFIG1_COUNT_RC_CUR(v)))
/*@}*/




/*******************************************************************************
 * HW_XTALOSC_RCOSC_CONFIG2 - Anadig 24MHz RC Osc. config2 Register
 ******************************************************************************/

/*!
 * @brief HW_XTALOSC_RCOSC_CONFIG2 - Anadig 24MHz RC Osc. config2 Register (RW)
 *
 * Reset value: 0x000302EEU
 *
 * This register is used to configure the 24MHz RC oscillator.
 */
typedef union _hw_xtalosc_rcosc_config2
{
    uint32_t U;
    struct _hw_xtalosc_rcosc_config2_bitfields
    {
        uint32_t COUNT_1M_TRG : 12;    /*!< [11:0]  */
        uint32_t RESERVED0 : 4;        /*!< [15:12]  */
        uint32_t ENABLE_1M : 1;        /*!< [16]  */
        uint32_t MUX_1M : 1;           /*!< [17]  */
        uint32_t RESERVED1 : 13;       /*!< [30:18]  */
        uint32_t CLK_1M_ERR_FL : 1;    /*!< [31]  */
    } B;
} hw_xtalosc_rcosc_config2_t;

/*!
 * @name Constants and macros for entire XTALOSC_RCOSC_CONFIG2 register
 */
/*@{*/
#define HW_XTALOSC_RCOSC_CONFIG2_ADDR(x) ((uintptr_t)(x) + 0x30U)
#define HW_XTALOSC_RCOSC_CONFIG2_SET_ADDR(x) (HW_XTALOSC_RCOSC_CONFIG2_ADDR(x) + 0x4U)
#define HW_XTALOSC_RCOSC_CONFIG2_CLR_ADDR(x) (HW_XTALOSC_RCOSC_CONFIG2_ADDR(x) + 0x8U)
#define HW_XTALOSC_RCOSC_CONFIG2_TOG_ADDR(x) (HW_XTALOSC_RCOSC_CONFIG2_ADDR(x) + 0xCU)

#define HW_XTALOSC_RCOSC_CONFIG2(x) (*(__IO hw_xtalosc_rcosc_config2_t *) HW_XTALOSC_RCOSC_CONFIG2_ADDR(x))
#define HW_XTALOSC_RCOSC_CONFIG2_RD(x) (HW_XTALOSC_RCOSC_CONFIG2(x).U)
#define HW_XTALOSC_RCOSC_CONFIG2_WR(x, v) (HW_XTALOSC_RCOSC_CONFIG2(x).U = (v))
#define HW_XTALOSC_RCOSC_CONFIG2_SET(x, v) ((*(uint32_t *) HW_XTALOSC_RCOSC_CONFIG2_SET_ADDR(x)) = (v))
#define HW_XTALOSC_RCOSC_CONFIG2_CLR(x, v) ((*(uint32_t *) HW_XTALOSC_RCOSC_CONFIG2_CLR_ADDR(x)) = (v))
#define HW_XTALOSC_RCOSC_CONFIG2_TOG(x, v) ((*(uint32_t *) HW_XTALOSC_RCOSC_CONFIG2_TOG_ADDR(x)) = (v))
/*@}*/

/*
 * Constants & macros for individual XTALOSC_RCOSC_CONFIG2 bitfields
 */

/*!
 * @name Register XTALOSC_RCOSC_CONFIG2, field COUNT_1M_TRG[11:0] (RW)
 *
 * The target count used to tune the RC OSC frequency. Essentially the number of
 * desired RC Osc clock cycles within 1 32KHz clock cycles
 */
/*@{*/
#define BP_XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG (0U) /*!< Bit position for XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG. */
#define BM_XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG (0x00000FFFU) /*!< Bit mask for XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG. */
#define BS_XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG (12U) /*!< Bit field size in bits for XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG. */

/*! @brief Read current value of the XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG field. */
#define BR_XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG(x) (HW_XTALOSC_RCOSC_CONFIG2(x).B.COUNT_1M_TRG)

/*! @brief Format value for bitfield XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG. */
#define BF_XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG) & BM_XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG)

/*! @brief Set the COUNT_1M_TRG field to a new value. */
#define BW_XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG(x, v) (HW_XTALOSC_RCOSC_CONFIG2_WR(x, (HW_XTALOSC_RCOSC_CONFIG2_RD(x) & ~BM_XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG) | BF_XTALOSC_RCOSC_CONFIG2_COUNT_1M_TRG(v)))
/*@}*/

/*!
 * @name Register XTALOSC_RCOSC_CONFIG2, field ENABLE_1M[16] (RW)
 *
 * Enable the 1MHz clock output. 0 - disabled; 1 - enabled.
 */
/*@{*/
#define BP_XTALOSC_RCOSC_CONFIG2_ENABLE_1M (16U) /*!< Bit position for XTALOSC_RCOSC_CONFIG2_ENABLE_1M. */
#define BM_XTALOSC_RCOSC_CONFIG2_ENABLE_1M (0x00010000U) /*!< Bit mask for XTALOSC_RCOSC_CONFIG2_ENABLE_1M. */
#define BS_XTALOSC_RCOSC_CONFIG2_ENABLE_1M (1U) /*!< Bit field size in bits for XTALOSC_RCOSC_CONFIG2_ENABLE_1M. */

/*! @brief Read current value of the XTALOSC_RCOSC_CONFIG2_ENABLE_1M field. */
#define BR_XTALOSC_RCOSC_CONFIG2_ENABLE_1M(x) (HW_XTALOSC_RCOSC_CONFIG2(x).B.ENABLE_1M)

/*! @brief Format value for bitfield XTALOSC_RCOSC_CONFIG2_ENABLE_1M. */
#define BF_XTALOSC_RCOSC_CONFIG2_ENABLE_1M(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_RCOSC_CONFIG2_ENABLE_1M) & BM_XTALOSC_RCOSC_CONFIG2_ENABLE_1M)

/*! @brief Set the ENABLE_1M field to a new value. */
#define BW_XTALOSC_RCOSC_CONFIG2_ENABLE_1M(x, v) (HW_XTALOSC_RCOSC_CONFIG2_WR(x, (HW_XTALOSC_RCOSC_CONFIG2_RD(x) & ~BM_XTALOSC_RCOSC_CONFIG2_ENABLE_1M) | BF_XTALOSC_RCOSC_CONFIG2_ENABLE_1M(v)))
/*@}*/

/*!
 * @name Register XTALOSC_RCOSC_CONFIG2, field MUX_1M[17] (RW)
 *
 * Mux the corrected or uncorrected 1MHz clock to the output. 0 - .
 */
/*@{*/
#define BP_XTALOSC_RCOSC_CONFIG2_MUX_1M (17U) /*!< Bit position for XTALOSC_RCOSC_CONFIG2_MUX_1M. */
#define BM_XTALOSC_RCOSC_CONFIG2_MUX_1M (0x00020000U) /*!< Bit mask for XTALOSC_RCOSC_CONFIG2_MUX_1M. */
#define BS_XTALOSC_RCOSC_CONFIG2_MUX_1M (1U) /*!< Bit field size in bits for XTALOSC_RCOSC_CONFIG2_MUX_1M. */

/*! @brief Read current value of the XTALOSC_RCOSC_CONFIG2_MUX_1M field. */
#define BR_XTALOSC_RCOSC_CONFIG2_MUX_1M(x) (HW_XTALOSC_RCOSC_CONFIG2(x).B.MUX_1M)

/*! @brief Format value for bitfield XTALOSC_RCOSC_CONFIG2_MUX_1M. */
#define BF_XTALOSC_RCOSC_CONFIG2_MUX_1M(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_RCOSC_CONFIG2_MUX_1M) & BM_XTALOSC_RCOSC_CONFIG2_MUX_1M)

/*! @brief Set the MUX_1M field to a new value. */
#define BW_XTALOSC_RCOSC_CONFIG2_MUX_1M(x, v) (HW_XTALOSC_RCOSC_CONFIG2_WR(x, (HW_XTALOSC_RCOSC_CONFIG2_RD(x) & ~BM_XTALOSC_RCOSC_CONFIG2_MUX_1M) | BF_XTALOSC_RCOSC_CONFIG2_MUX_1M(v)))
/*@}*/

/*!
 * @name Register XTALOSC_RCOSC_CONFIG2, field CLK_1M_ERR_FL[31] (RW)
 *
 * Flag indicates that the count_1m count wasn't reached within 1 32KHz period.
 * This is intended as feedback to software that the OSC_CONFIG2_COUNT_1M_TRG
 * value is too high for the RC Osc frequency. Write 1 to this field to clear.
 */
/*@{*/
#define BP_XTALOSC_RCOSC_CONFIG2_CLK_1M_ERR_FL (31U) /*!< Bit position for XTALOSC_RCOSC_CONFIG2_CLK_1M_ERR_FL. */
#define BM_XTALOSC_RCOSC_CONFIG2_CLK_1M_ERR_FL (0x80000000U) /*!< Bit mask for XTALOSC_RCOSC_CONFIG2_CLK_1M_ERR_FL. */
#define BS_XTALOSC_RCOSC_CONFIG2_CLK_1M_ERR_FL (1U) /*!< Bit field size in bits for XTALOSC_RCOSC_CONFIG2_CLK_1M_ERR_FL. */

/*! @brief Read current value of the XTALOSC_RCOSC_CONFIG2_CLK_1M_ERR_FL field. */
#define BR_XTALOSC_RCOSC_CONFIG2_CLK_1M_ERR_FL(x) (HW_XTALOSC_RCOSC_CONFIG2(x).B.CLK_1M_ERR_FL)

/*! @brief Format value for bitfield XTALOSC_RCOSC_CONFIG2_CLK_1M_ERR_FL. */
#define BF_XTALOSC_RCOSC_CONFIG2_CLK_1M_ERR_FL(v) ((uint32_t)((uint32_t)(v) << BP_XTALOSC_RCOSC_CONFIG2_CLK_1M_ERR_FL) & BM_XTALOSC_RCOSC_CONFIG2_CLK_1M_ERR_FL)

/*! @brief Set the CLK_1M_ERR_FL field to a new value. */
#define BW_XTALOSC_RCOSC_CONFIG2_CLK_1M_ERR_FL(x, v) (HW_XTALOSC_RCOSC_CONFIG2_WR(x, (HW_XTALOSC_RCOSC_CONFIG2_RD(x) & ~BM_XTALOSC_RCOSC_CONFIG2_CLK_1M_ERR_FL) | BF_XTALOSC_RCOSC_CONFIG2_CLK_1M_ERR_FL(v)))
/*@}*/




/*******************************************************************************
 * HW_XTALOSC_OSC_32K - 32K Oscillator Control Register
 ******************************************************************************/

/*!
 * @brief HW_XTALOSC_OSC_32K - 32K Oscillator Control Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The 32K low precision oscillator is only enabled when the frequency on the
 * RTC xtal oscillator is determined to be out of range. This detection is done
 * automatically.
 */
typedef union _hw_xtalosc_osc_32k
{
    uint32_t U;
    struct _hw_xtalosc_osc_32k_bitfields
    {
        uint32_t RTC_XTAL_SOURCE : 1;  /*!< [0]  */
        uint32_t RESERVED0 : 31;       /*!< [31:1]  */
    } B;
} hw_xtalosc_osc_32k_t;

/*!
 * @name Constants and macros for entire XTALOSC_OSC_32K register
 */
/*@{*/
#define HW_XTALOSC_OSC_32K_ADDR(x) ((uintptr_t)(x) + 0x50U)
#define HW_XTALOSC_OSC_32K_SET_ADDR(x) (HW_XTALOSC_OSC_32K_ADDR(x) + 0x4U)
#define HW_XTALOSC_OSC_32K_CLR_ADDR(x) (HW_XTALOSC_OSC_32K_ADDR(x) + 0x8U)
#define HW_XTALOSC_OSC_32K_TOG_ADDR(x) (HW_XTALOSC_OSC_32K_ADDR(x) + 0xCU)

#define HW_XTALOSC_OSC_32K(x)    (*(__I hw_xtalosc_osc_32k_t *) HW_XTALOSC_OSC_32K_ADDR(x))
#define HW_XTALOSC_OSC_32K_RD(x) (HW_XTALOSC_OSC_32K(x).U)
/*@}*/

/*
 * Constants & macros for individual XTALOSC_OSC_32K bitfields
 */

/*!
 * @name Register XTALOSC_OSC_32K, field RTC_XTAL_SOURCE[0] (RO)
 *
 * This field indicates which chip source is being used for the rtc clock. 0 -
 * internal ring oscillator, 1 - rtc_xtal.
 */
/*@{*/
#define BP_XTALOSC_OSC_32K_RTC_XTAL_SOURCE (0U) /*!< Bit position for XTALOSC_OSC_32K_RTC_XTAL_SOURCE. */
#define BM_XTALOSC_OSC_32K_RTC_XTAL_SOURCE (0x00000001U) /*!< Bit mask for XTALOSC_OSC_32K_RTC_XTAL_SOURCE. */
#define BS_XTALOSC_OSC_32K_RTC_XTAL_SOURCE (1U) /*!< Bit field size in bits for XTALOSC_OSC_32K_RTC_XTAL_SOURCE. */

/*! @brief Read current value of the XTALOSC_OSC_32K_RTC_XTAL_SOURCE field. */
#define BR_XTALOSC_OSC_32K_RTC_XTAL_SOURCE(x) (HW_XTALOSC_OSC_32K(x).B.RTC_XTAL_SOURCE)
/*@}*/




/*******************************************************************************
 * hw_xtalosc_t - module struct
 ******************************************************************************/
/*!
 * @brief All XTALOSC module registers.
 */
#pragma pack(1)
typedef struct _hw_xtalosc
{
    __IO hw_xtalosc_ctrl_24m_t CTRL_24M;   /*!< [0x0] Anadig 24M Oscillator Control Register */
    uint8_t _reserved0[12];
    __IO hw_xtalosc_rcosc_config0_t RCOSC_CONFIG0; /*!< [0x10] Anadig 24MHz RC Osc. config0 Register */
    uint8_t _reserved1[12];
    __IO hw_xtalosc_rcosc_config1_t RCOSC_CONFIG1; /*!< [0x20] Anadig 24MHz RC Osc. config1 Register */
    uint8_t _reserved2[12];
    __IO hw_xtalosc_rcosc_config2_t RCOSC_CONFIG2; /*!< [0x30] Anadig 24MHz RC Osc. config2 Register */
    uint8_t _reserved3[28];
    __I hw_xtalosc_osc_32k_t OSC_32K;      /*!< [0x50] 32K Oscillator Control Register */
} hw_xtalosc_t;
#pragma pack()

/*! @brief Macro to access all XTALOSC registers. */
/*! @param x XTALOSC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_XTALOSC_REGS(XTALOSC_BASE)</code>. */
#define HW_XTALOSC_REGS(x) (*(hw_xtalosc_t *)(x))

/*
 * iMX7D uSDHC
 *
 * Ultra Secured Digital Host Controller (uSDHC)
 *
 * Registers defined in this header file:
 * - HW_uSDHC_DS_ADDR - DMA System Address
 * - HW_uSDHC_BLK_ATT - Block Attributes
 * - HW_uSDHC_CMD_ARG - Command Argument
 * - HW_uSDHC_CMD_XFR_TYP - Command Transfer Type
 * - HW_uSDHC_CMD_RSP0 - Command Response0
 * - HW_uSDHC_CMD_RSP1 - Command Response1
 * - HW_uSDHC_CMD_RSP2 - Command Response2
 * - HW_uSDHC_CMD_RSP3 - Command Response3
 * - HW_uSDHC_DATA_BUFF_ACC_PORT - Data Buffer Access Port
 * - HW_uSDHC_PRES_STATE - Present State
 * - HW_uSDHC_PROT_CTRL - Protocol Control
 * - HW_uSDHC_SYS_CTRL - System Control
 * - HW_uSDHC_INT_STATUS - Interrupt Status
 * - HW_uSDHC_INT_STATUS_EN - Interrupt Status Enable
 * - HW_uSDHC_INT_SIGNAL_EN - Interrupt Signal Enable
 * - HW_uSDHC_AUTOCMD12_ERR_STATUS - Auto CMD12 Error Status
 * - HW_uSDHC_HOST_CTRL_CAP - Host Controller Capabilities
 * - HW_uSDHC_WTMK_LVL - Watermark Level
 * - HW_uSDHC_MIX_CTRL - Mixer Control
 * - HW_uSDHC_FORCE_EVENT - Force Event
 * - HW_uSDHC_ADMA_ERR_STATUS - ADMA Error Status Register
 * - HW_uSDHC_ADMA_SYS_ADDR - ADMA System Address
 * - HW_uSDHC_DLL_CTRL - DLL (Delay Line) Control
 * - HW_uSDHC_DLL_STATUS - DLL Status
 * - HW_uSDHC_CLK_TUNE_CTRL_STATUS - CLK Tuning Control and Status
 * - HW_uSDHC_STROBE_DLL_CTRL - Strobe DLL Control
 * - HW_uSDHC_STROBE_DLL_STATUS - Strobe DLL Status
 * - HW_uSDHC_VEND_SPEC - Vendor Specific Register
 * - HW_uSDHC_MMC_BOOT - MMC Boot Register
 * - HW_uSDHC_VEND_SPEC2 - Vendor Specific 2 Register
 * - HW_uSDHC_TUNING_CTRL - Tuning Control Register
 *
 * - hw_usdhc_t - Struct containing all module registers.
 */

#define HW_uSDHC_INSTANCE_COUNT (3U) /*!< Number of instances of the uSDHC module. */
#define HW_uSDHC1 (0U) /*!< Instance number for uSDHC1. */
#define HW_uSDHC2 (1U) /*!< Instance number for uSDHC2. */
#define HW_uSDHC3 (2U) /*!< Instance number for uSDHC3. */
#define uSDHC1_BASE           (0x30B40000U) /*!< Base address for uSDHC1. */
#define uSDHC2_BASE           (0x30B50000U) /*!< Base address for uSDHC2. */
#define uSDHC3_BASE           (0x30B60000U) /*!< Base address for uSDHC3. */
/*! Array initializer of uSDHC base addresses. */
#define USDHC_BASE_ADDRS      { uSDHC1_BASE, uSDHC2_BASE, uSDHC3_BASE }

/*******************************************************************************
 * HW_uSDHC_DS_ADDR - DMA System Address
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_DS_ADDR - DMA System Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the physical system memory address used for DMA
 * transfers.
 */
typedef union _hw_usdhc_ds_addr
{
    uint32_t U;
    struct _hw_usdhc_ds_addr_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t DS_ADDR : 30;         /*!< [31:2]  */
    } B;
} hw_usdhc_ds_addr_t;

/*!
 * @name Constants and macros for entire uSDHC_DS_ADDR register
 */
/*@{*/
#define HW_uSDHC_DS_ADDR_ADDR(x) ((uintptr_t)(x) + 0x0U)

#define HW_uSDHC_DS_ADDR(x)      (*(__IO hw_usdhc_ds_addr_t *) HW_uSDHC_DS_ADDR_ADDR(x))
#define HW_uSDHC_DS_ADDR_RD(x)   (HW_uSDHC_DS_ADDR(x).U)
#define HW_uSDHC_DS_ADDR_WR(x, v) (HW_uSDHC_DS_ADDR(x).U = (v))
#define HW_uSDHC_DS_ADDR_SET(x, v) (HW_uSDHC_DS_ADDR_WR(x, HW_uSDHC_DS_ADDR_RD(x) |  (v)))
#define HW_uSDHC_DS_ADDR_CLR(x, v) (HW_uSDHC_DS_ADDR_WR(x, HW_uSDHC_DS_ADDR_RD(x) & ~(v)))
#define HW_uSDHC_DS_ADDR_TOG(x, v) (HW_uSDHC_DS_ADDR_WR(x, HW_uSDHC_DS_ADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_DS_ADDR bitfields
 */

/*!
 * @name Register uSDHC_DS_ADDR, field DS_ADDR[31:2] (RW)
 *
 * DMA System Address: This register contains the 32-bit system memory address
 * for a DMA transfer. Since the address must be word (4 bytes) aligned, the least
 * 2 bits are reserved, always 0. When the uSDHC stops a DMA transfer, this
 * register points to the system address of the next contiguous data position. It can
 * be accessed only when no transaction is executing (i.e. after a transaction
 * has stopped). Read operation during transfers may return an invalid value. The
 * Host Driver shall initialize this register before starting a DMA transaction.
 * After DMA has stopped, the system address of the next contiguous data position
 * can be read from this register. This register is protected during a data
 * transfer. When data lines are active, write to this register is ignored. The Host
 * driver shall wait, until the DLA bit in the Present State register is cleared,
 * before writing to this register. The uSDHC internal DMA does not support a
 * virtual memory system. It only supports continuous physical memory access. And
 * due to AHB burst limitations, if the burst must cross the 1 KB boundary, uSDHC
 * will automatically change SEQ burst type to NSEQ. Since this register supports
 * dynamic address reflecting, when TC bit is set, it automatically alters the
 * value of internal address counter, so SW cannot change this register when TC
 * bit is set. Such restriction is also listed in Software Restrictions .
 */
/*@{*/
#define BP_uSDHC_DS_ADDR_DS_ADDR (2U)      /*!< Bit position for uSDHC_DS_ADDR_DS_ADDR. */
#define BM_uSDHC_DS_ADDR_DS_ADDR (0xFFFFFFFCU) /*!< Bit mask for uSDHC_DS_ADDR_DS_ADDR. */
#define BS_uSDHC_DS_ADDR_DS_ADDR (30U)     /*!< Bit field size in bits for uSDHC_DS_ADDR_DS_ADDR. */

/*! @brief Read current value of the uSDHC_DS_ADDR_DS_ADDR field. */
#define BR_uSDHC_DS_ADDR_DS_ADDR(x) (HW_uSDHC_DS_ADDR(x).B.DS_ADDR)

/*! @brief Format value for bitfield uSDHC_DS_ADDR_DS_ADDR. */
#define BF_uSDHC_DS_ADDR_DS_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DS_ADDR_DS_ADDR) & BM_uSDHC_DS_ADDR_DS_ADDR)

/*! @brief Set the DS_ADDR field to a new value. */
#define BW_uSDHC_DS_ADDR_DS_ADDR(x, v) (HW_uSDHC_DS_ADDR_WR(x, (HW_uSDHC_DS_ADDR_RD(x) & ~BM_uSDHC_DS_ADDR_DS_ADDR) | BF_uSDHC_DS_ADDR_DS_ADDR(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_BLK_ATT - Block Attributes
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_BLK_ATT - Block Attributes (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to configure the number of data blocks and the number
 * of bytes in each block.
 */
typedef union _hw_usdhc_blk_att
{
    uint32_t U;
    struct _hw_usdhc_blk_att_bitfields
    {
        uint32_t BLKSIZE : 13;         /*!< [12:0]  */
        uint32_t RESERVED0 : 3;        /*!< [15:13]  */
        uint32_t BLKCNT : 16;          /*!< [31:16]  */
    } B;
} hw_usdhc_blk_att_t;

/*!
 * @name Constants and macros for entire uSDHC_BLK_ATT register
 */
/*@{*/
#define HW_uSDHC_BLK_ATT_ADDR(x) ((uintptr_t)(x) + 0x4U)

#define HW_uSDHC_BLK_ATT(x)      (*(__IO hw_usdhc_blk_att_t *) HW_uSDHC_BLK_ATT_ADDR(x))
#define HW_uSDHC_BLK_ATT_RD(x)   (HW_uSDHC_BLK_ATT(x).U)
#define HW_uSDHC_BLK_ATT_WR(x, v) (HW_uSDHC_BLK_ATT(x).U = (v))
#define HW_uSDHC_BLK_ATT_SET(x, v) (HW_uSDHC_BLK_ATT_WR(x, HW_uSDHC_BLK_ATT_RD(x) |  (v)))
#define HW_uSDHC_BLK_ATT_CLR(x, v) (HW_uSDHC_BLK_ATT_WR(x, HW_uSDHC_BLK_ATT_RD(x) & ~(v)))
#define HW_uSDHC_BLK_ATT_TOG(x, v) (HW_uSDHC_BLK_ATT_WR(x, HW_uSDHC_BLK_ATT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_BLK_ATT bitfields
 */

/*!
 * @name Register uSDHC_BLK_ATT, field BLKSIZE[12:0] (RW)
 *
 * Transfer Block Size: This register specifies the block size for block data
 * transfers. Values ranging from 1 byte up to the maximum buffer size can be set.
 * It can be accessed only when no transaction is executing (i.e. after a
 * transaction has stopped). Read operations during transfers may return an invalid
 * value, and write operations will be ignored.
 *
 * Values:
 * - 1000 - 4096 Bytes
 * - 001 - 1 Byte
 * - 000 - No data transfer
 */
/*@{*/
#define BP_uSDHC_BLK_ATT_BLKSIZE (0U)      /*!< Bit position for uSDHC_BLK_ATT_BLKSIZE. */
#define BM_uSDHC_BLK_ATT_BLKSIZE (0x00001FFFU) /*!< Bit mask for uSDHC_BLK_ATT_BLKSIZE. */
#define BS_uSDHC_BLK_ATT_BLKSIZE (13U)     /*!< Bit field size in bits for uSDHC_BLK_ATT_BLKSIZE. */

/*! @brief Read current value of the uSDHC_BLK_ATT_BLKSIZE field. */
#define BR_uSDHC_BLK_ATT_BLKSIZE(x) (HW_uSDHC_BLK_ATT(x).B.BLKSIZE)

/*! @brief Format value for bitfield uSDHC_BLK_ATT_BLKSIZE. */
#define BF_uSDHC_BLK_ATT_BLKSIZE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_BLK_ATT_BLKSIZE) & BM_uSDHC_BLK_ATT_BLKSIZE)

/*! @brief Set the BLKSIZE field to a new value. */
#define BW_uSDHC_BLK_ATT_BLKSIZE(x, v) (HW_uSDHC_BLK_ATT_WR(x, (HW_uSDHC_BLK_ATT_RD(x) & ~BM_uSDHC_BLK_ATT_BLKSIZE) | BF_uSDHC_BLK_ATT_BLKSIZE(v)))
/*@}*/

/*!
 * @name Register uSDHC_BLK_ATT, field BLKCNT[31:16] (RW)
 *
 * Blocks Count For Current Transfer: This register is enabled when the Block
 * Count Enable bit in the Transfer Mode register is set to 1 and is valid only for
 * multiple block transfers. For single block transfer, this register will
 * always read as 1. The Host Driver shall set this register to a value between 1 and
 * the maximum block count. The uSDHC decrements the block count after each block
 * transfer and stops when the count reaches zero. Setting the block count to 0
 * results in no data blocks being transferred. This register should be accessed
 * only when no transaction is executing (i.e. after transactions are stopped).
 * During data transfer, read operations on this register may return an invalid
 * value and write operations are ignored. When saving transfer content as a result
 * of a Suspend command, the number of blocks yet to be transferred can be
 * determined by reading this register. The reading of this register should be applied
 * after transfer is paused by stop at block gap operation and before sending
 * the command marked as suspend. This is because when Suspend command is sent out,
 * uSDHC will regard the current transfer is aborted and change BLKCNT register
 * back to its original value instead of keeping the dynamical indicator of
 * remained block count. When restoring transfer content prior to issuing a Resume
 * command, the Host Driver shall restore the previously saved block count. Although
 * the BLKCNT field is 0 after reset, the read of reset value is 0x1. This is
 * because when MSBSEL bit is indicating a single block transfer, the read value of
 * BLKCNT is always 1.
 *
 * Values:
 * - 0001 - 1 block
 * - 0000 - Stop Count
 */
/*@{*/
#define BP_uSDHC_BLK_ATT_BLKCNT (16U)      /*!< Bit position for uSDHC_BLK_ATT_BLKCNT. */
#define BM_uSDHC_BLK_ATT_BLKCNT (0xFFFF0000U) /*!< Bit mask for uSDHC_BLK_ATT_BLKCNT. */
#define BS_uSDHC_BLK_ATT_BLKCNT (16U)      /*!< Bit field size in bits for uSDHC_BLK_ATT_BLKCNT. */

/*! @brief Read current value of the uSDHC_BLK_ATT_BLKCNT field. */
#define BR_uSDHC_BLK_ATT_BLKCNT(x) (HW_uSDHC_BLK_ATT(x).B.BLKCNT)

/*! @brief Format value for bitfield uSDHC_BLK_ATT_BLKCNT. */
#define BF_uSDHC_BLK_ATT_BLKCNT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_BLK_ATT_BLKCNT) & BM_uSDHC_BLK_ATT_BLKCNT)

/*! @brief Set the BLKCNT field to a new value. */
#define BW_uSDHC_BLK_ATT_BLKCNT(x, v) (HW_uSDHC_BLK_ATT_WR(x, (HW_uSDHC_BLK_ATT_RD(x) & ~BM_uSDHC_BLK_ATT_BLKCNT) | BF_uSDHC_BLK_ATT_BLKCNT(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_CMD_ARG - Command Argument
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_CMD_ARG - Command Argument (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the SD / MMC Command Argument. .
 */
typedef union _hw_usdhc_cmd_arg
{
    uint32_t U;
    struct _hw_usdhc_cmd_arg_bitfields
    {
        uint32_t CMDARG : 32;          /*!< [31:0] Command Argument */
    } B;
} hw_usdhc_cmd_arg_t;

/*!
 * @name Constants and macros for entire uSDHC_CMD_ARG register
 */
/*@{*/
#define HW_uSDHC_CMD_ARG_ADDR(x) ((uintptr_t)(x) + 0x8U)

#define HW_uSDHC_CMD_ARG(x)      (*(__IO hw_usdhc_cmd_arg_t *) HW_uSDHC_CMD_ARG_ADDR(x))
#define HW_uSDHC_CMD_ARG_RD(x)   (HW_uSDHC_CMD_ARG(x).U)
#define HW_uSDHC_CMD_ARG_WR(x, v) (HW_uSDHC_CMD_ARG(x).U = (v))
#define HW_uSDHC_CMD_ARG_SET(x, v) (HW_uSDHC_CMD_ARG_WR(x, HW_uSDHC_CMD_ARG_RD(x) |  (v)))
#define HW_uSDHC_CMD_ARG_CLR(x, v) (HW_uSDHC_CMD_ARG_WR(x, HW_uSDHC_CMD_ARG_RD(x) & ~(v)))
#define HW_uSDHC_CMD_ARG_TOG(x, v) (HW_uSDHC_CMD_ARG_WR(x, HW_uSDHC_CMD_ARG_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_CMD_ARG bitfields
 */

/*!
 * @name Register uSDHC_CMD_ARG, field CMDARG[31:0] (RW)
 *
 * The SD / MMC Command Argument is specified as bits 39-8 of the Command Format
 * in the SD or MMC Specification.This register is write protected when the
 * Command Inhibit (CMD) bit in the Present State register is set.
 */
/*@{*/
#define BP_uSDHC_CMD_ARG_CMDARG (0U)       /*!< Bit position for uSDHC_CMD_ARG_CMDARG. */
#define BM_uSDHC_CMD_ARG_CMDARG (0xFFFFFFFFU) /*!< Bit mask for uSDHC_CMD_ARG_CMDARG. */
#define BS_uSDHC_CMD_ARG_CMDARG (32U)      /*!< Bit field size in bits for uSDHC_CMD_ARG_CMDARG. */

/*! @brief Read current value of the uSDHC_CMD_ARG_CMDARG field. */
#define BR_uSDHC_CMD_ARG_CMDARG(x) (HW_uSDHC_CMD_ARG(x).U)

/*! @brief Format value for bitfield uSDHC_CMD_ARG_CMDARG. */
#define BF_uSDHC_CMD_ARG_CMDARG(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CMD_ARG_CMDARG) & BM_uSDHC_CMD_ARG_CMDARG)

/*! @brief Set the CMDARG field to a new value. */
#define BW_uSDHC_CMD_ARG_CMDARG(x, v) (HW_uSDHC_CMD_ARG_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_CMD_XFR_TYP - Command Transfer Type
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_CMD_XFR_TYP - Command Transfer Type (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to control the operation of data transfers. The Host
 * Driver shall set this register before issuing a command followed by a data
 * transfer, or before issuing a Resume command. To prevent data loss, the uSDHC
 * prevents writing to the bits, that are involved in the data transfer of this
 * register, when data transfer is active. These bits are DPSEL, MBSEL, DTDSEL, AC12EN,
 * BCEN and DMAEN. The Host Driver shall check the Command Inhibit DAT bit
 * (CDIHB) and the Command Inhibit CMD bit (CIHB) in the Present State register before
 * writing to this register. When the CDIHB bit in the Present State register is
 * set, any attempt to send a command with data by writing to this register is
 * ignored; when the CIHB bit is set, any write to this register is ignored. On
 * sending commands with data transfer invovled, it is mandatory that the block
 * size is non-zero. Block count must also be non-zero, or indicated as single block
 * transfer (bit 5 of this register is '0' when written), or block count is
 * disabled (bit 1 of this register is '0' when written), otherwise uSDHC will ignore
 * the sending of this command and do nothing. For write command, with all above
 * restrictions, it is also mandatory that the write protect switch is not
 * active (WPSPL bit of Present State Register is '1'), otherwise uSDHC will also
 * ignore the command. If the commands with data transfer does not receive the
 * response in 64 clock cycles, i.e., response time-out, uSDHC will regard the external
 * device does not accept the command and abort the data transfer. In this
 * scenario, the driver should issue the command again to re-try the transfer. It is
 * also possible that for some reason the card responds the command but uSDHC does
 * not receive the response, and if it is internal DMA (either simple DMA or
 * ADMA) read operation, the external system memory is over-written by the internal
 * DMA with data sent back from the card. The table below shows the summary of
 * how register settings determine the type of data transfer. Transfer Type
 * Register Setting for Various Transfer Types Multi/Single Block Select Block Count
 * Enable Block Count Function 0 Don't Care Don't Care Single Transfer 1 0 Don't
 * Care Infinite Transfer 1 1 Positive Number Multiple Transfer 1 1 Zero No Data
 * Transfer The table below shows the relationship between the Command Index Check
 * Enable and the Command CRC Check Enable, in regards to the Response Type bits
 * as well as the name of the response type. Relationship Between Parameters and
 * the Name of the Response Type Response Type Index Check Enable CRC Check Enable
 * Name of Response Type 00 0 0 No Response 01 0 1 R2 10 0 0 R3,R4 10 1 1
 * R1,R5,R6 11 1 1 R1b,R5b In the SDIO specification, response type notation for R5b is
 * not defined. R5 includes R5b in the SDIO specification. But R5b is defined in
 * this specification to specify that the uSDHC will check the busy status after
 * receiving a response. For example, usually CMD52 is used with R5, but the I/O
 * abort command shall be used with R5b. The CRC field for R3 and R4 is expected
 * to be all 1 bits. The CRC check shall be disabled for these response types.
 */
typedef union _hw_usdhc_cmd_xfr_typ
{
    uint32_t U;
    struct _hw_usdhc_cmd_xfr_typ_bitfields
    {
        uint32_t RESERVED0 : 16;       /*!< [15:0]  */
        uint32_t RSPTYP : 2;           /*!< [17:16] Response Type Select */
        uint32_t RESERVED1 : 1;        /*!< [18]  */
        uint32_t CCCEN : 1;            /*!< [19] Command CRC Check Enable */
        uint32_t CICEN : 1;            /*!< [20] Command Index Check Enable */
        uint32_t DPSEL : 1;            /*!< [21] Data Present Select */
        uint32_t CMDTYP : 2;           /*!< [23:22] Command Type */
        uint32_t CMDINX : 6;           /*!< [29:24] Command Index */
        uint32_t RESERVED2 : 2;        /*!< [31:30]  */
    } B;
} hw_usdhc_cmd_xfr_typ_t;

/*!
 * @name Constants and macros for entire uSDHC_CMD_XFR_TYP register
 */
/*@{*/
#define HW_uSDHC_CMD_XFR_TYP_ADDR(x) ((uintptr_t)(x) + 0xCU)

#define HW_uSDHC_CMD_XFR_TYP(x)  (*(__IO hw_usdhc_cmd_xfr_typ_t *) HW_uSDHC_CMD_XFR_TYP_ADDR(x))
#define HW_uSDHC_CMD_XFR_TYP_RD(x) (HW_uSDHC_CMD_XFR_TYP(x).U)
#define HW_uSDHC_CMD_XFR_TYP_WR(x, v) (HW_uSDHC_CMD_XFR_TYP(x).U = (v))
#define HW_uSDHC_CMD_XFR_TYP_SET(x, v) (HW_uSDHC_CMD_XFR_TYP_WR(x, HW_uSDHC_CMD_XFR_TYP_RD(x) |  (v)))
#define HW_uSDHC_CMD_XFR_TYP_CLR(x, v) (HW_uSDHC_CMD_XFR_TYP_WR(x, HW_uSDHC_CMD_XFR_TYP_RD(x) & ~(v)))
#define HW_uSDHC_CMD_XFR_TYP_TOG(x, v) (HW_uSDHC_CMD_XFR_TYP_WR(x, HW_uSDHC_CMD_XFR_TYP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_CMD_XFR_TYP bitfields
 */

/*!
 * @name Register uSDHC_CMD_XFR_TYP, field RSPTYP[17:16] (RW)
 *
 * Values:
 * - 00 - No Response
 * - 01 - Response Length 136
 * - 10 - Response Length 48
 * - 11 - Response Length 48, check Busy after response
 */
/*@{*/
#define BP_uSDHC_CMD_XFR_TYP_RSPTYP (16U)  /*!< Bit position for uSDHC_CMD_XFR_TYP_RSPTYP. */
#define BM_uSDHC_CMD_XFR_TYP_RSPTYP (0x00030000U) /*!< Bit mask for uSDHC_CMD_XFR_TYP_RSPTYP. */
#define BS_uSDHC_CMD_XFR_TYP_RSPTYP (2U)   /*!< Bit field size in bits for uSDHC_CMD_XFR_TYP_RSPTYP. */

/*! @brief Read current value of the uSDHC_CMD_XFR_TYP_RSPTYP field. */
#define BR_uSDHC_CMD_XFR_TYP_RSPTYP(x) (HW_uSDHC_CMD_XFR_TYP(x).B.RSPTYP)

/*! @brief Format value for bitfield uSDHC_CMD_XFR_TYP_RSPTYP. */
#define BF_uSDHC_CMD_XFR_TYP_RSPTYP(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CMD_XFR_TYP_RSPTYP) & BM_uSDHC_CMD_XFR_TYP_RSPTYP)

/*! @brief Set the RSPTYP field to a new value. */
#define BW_uSDHC_CMD_XFR_TYP_RSPTYP(x, v) (HW_uSDHC_CMD_XFR_TYP_WR(x, (HW_uSDHC_CMD_XFR_TYP_RD(x) & ~BM_uSDHC_CMD_XFR_TYP_RSPTYP) | BF_uSDHC_CMD_XFR_TYP_RSPTYP(v)))
/*@}*/

/*!
 * @name Register uSDHC_CMD_XFR_TYP, field CCCEN[19] (RW)
 *
 * If this bit is set to 1, the uSDHC shall check the CRC field in the response.
 * If an error is detected, it is reported as a Command CRC Error. If this bit
 * is set to 0, the CRC field is not checked. The number of bits checked by the
 * CRC field value changes according to the length of the response. (Refer to
 * RSPTYP[1:0] and CMD_XFR_TYPCommand Transfer Type .)
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_uSDHC_CMD_XFR_TYP_CCCEN (19U)   /*!< Bit position for uSDHC_CMD_XFR_TYP_CCCEN. */
#define BM_uSDHC_CMD_XFR_TYP_CCCEN (0x00080000U) /*!< Bit mask for uSDHC_CMD_XFR_TYP_CCCEN. */
#define BS_uSDHC_CMD_XFR_TYP_CCCEN (1U)    /*!< Bit field size in bits for uSDHC_CMD_XFR_TYP_CCCEN. */

/*! @brief Read current value of the uSDHC_CMD_XFR_TYP_CCCEN field. */
#define BR_uSDHC_CMD_XFR_TYP_CCCEN(x) (HW_uSDHC_CMD_XFR_TYP(x).B.CCCEN)

/*! @brief Format value for bitfield uSDHC_CMD_XFR_TYP_CCCEN. */
#define BF_uSDHC_CMD_XFR_TYP_CCCEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CMD_XFR_TYP_CCCEN) & BM_uSDHC_CMD_XFR_TYP_CCCEN)

/*! @brief Set the CCCEN field to a new value. */
#define BW_uSDHC_CMD_XFR_TYP_CCCEN(x, v) (HW_uSDHC_CMD_XFR_TYP_WR(x, (HW_uSDHC_CMD_XFR_TYP_RD(x) & ~BM_uSDHC_CMD_XFR_TYP_CCCEN) | BF_uSDHC_CMD_XFR_TYP_CCCEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_CMD_XFR_TYP, field CICEN[20] (RW)
 *
 * If this bit is set to 1, the uSDHC will check the Index field in the response
 * to see if it has the same value as the command index. If it is not, it is
 * reported as a Command Index Error. If this bit is set to 0, the Index field is
 * not checked.
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_uSDHC_CMD_XFR_TYP_CICEN (20U)   /*!< Bit position for uSDHC_CMD_XFR_TYP_CICEN. */
#define BM_uSDHC_CMD_XFR_TYP_CICEN (0x00100000U) /*!< Bit mask for uSDHC_CMD_XFR_TYP_CICEN. */
#define BS_uSDHC_CMD_XFR_TYP_CICEN (1U)    /*!< Bit field size in bits for uSDHC_CMD_XFR_TYP_CICEN. */

/*! @brief Read current value of the uSDHC_CMD_XFR_TYP_CICEN field. */
#define BR_uSDHC_CMD_XFR_TYP_CICEN(x) (HW_uSDHC_CMD_XFR_TYP(x).B.CICEN)

/*! @brief Format value for bitfield uSDHC_CMD_XFR_TYP_CICEN. */
#define BF_uSDHC_CMD_XFR_TYP_CICEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CMD_XFR_TYP_CICEN) & BM_uSDHC_CMD_XFR_TYP_CICEN)

/*! @brief Set the CICEN field to a new value. */
#define BW_uSDHC_CMD_XFR_TYP_CICEN(x, v) (HW_uSDHC_CMD_XFR_TYP_WR(x, (HW_uSDHC_CMD_XFR_TYP_RD(x) & ~BM_uSDHC_CMD_XFR_TYP_CICEN) | BF_uSDHC_CMD_XFR_TYP_CICEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_CMD_XFR_TYP, field DPSEL[21] (RW)
 *
 * This bit is set to 1 to indicate that data is present and shall be
 * transferred using the DATA line. It is set to 0 for the following: Commands using only
 * the CMD line (e.g. CMD52). Commands with no data transfer, but using the busy
 * signal on DATA0 line (R1b or R5b e.g. CMD38) In resume command, this bit shall
 * be set, and other bits in this register shall be set the same as when the
 * transfer was initially launched. When the Write Protect switch is on, (i.e. the
 * WPSPL bit is active as '0'), any command with a write operation will be ignored.
 * That is to say, when this bit is set, while the DTDSEL bit is 0, writes to
 * the register Transfer Type are ignored.
 *
 * Values:
 * - 1 - Data Present
 * - 0 - No Data Present
 */
/*@{*/
#define BP_uSDHC_CMD_XFR_TYP_DPSEL (21U)   /*!< Bit position for uSDHC_CMD_XFR_TYP_DPSEL. */
#define BM_uSDHC_CMD_XFR_TYP_DPSEL (0x00200000U) /*!< Bit mask for uSDHC_CMD_XFR_TYP_DPSEL. */
#define BS_uSDHC_CMD_XFR_TYP_DPSEL (1U)    /*!< Bit field size in bits for uSDHC_CMD_XFR_TYP_DPSEL. */

/*! @brief Read current value of the uSDHC_CMD_XFR_TYP_DPSEL field. */
#define BR_uSDHC_CMD_XFR_TYP_DPSEL(x) (HW_uSDHC_CMD_XFR_TYP(x).B.DPSEL)

/*! @brief Format value for bitfield uSDHC_CMD_XFR_TYP_DPSEL. */
#define BF_uSDHC_CMD_XFR_TYP_DPSEL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CMD_XFR_TYP_DPSEL) & BM_uSDHC_CMD_XFR_TYP_DPSEL)

/*! @brief Set the DPSEL field to a new value. */
#define BW_uSDHC_CMD_XFR_TYP_DPSEL(x, v) (HW_uSDHC_CMD_XFR_TYP_WR(x, (HW_uSDHC_CMD_XFR_TYP_RD(x) & ~BM_uSDHC_CMD_XFR_TYP_DPSEL) | BF_uSDHC_CMD_XFR_TYP_DPSEL(v)))
/*@}*/

/*!
 * @name Register uSDHC_CMD_XFR_TYP, field CMDTYP[23:22] (RW)
 *
 * There are three types of special commands: Suspend, Resume and Abort. These
 * bits shall be set to 00b for all other commands. Suspend Command: If the
 * Suspend command succeeds, the uSDHC shall assume that the card bus has been released
 * and that it is possible to issue the next command which uses the DATA line.
 * Since the uSDHC does not monitor the content of command response, it does not
 * know if the Suspend command succeeded or not. It is the Host Driver's
 * responsibility to check the status of the Suspend command and send another command
 * marked as Suspend to inform the uSDHC that a Suspend command was successfully
 * issued. Refer to Suspend ResumeThe uSDHC supports the Suspend Resume operations of
 * SDIO cards, although slightly differently than the suggested implementation
 * of Suspend in the SDIO card specification. for more details. After the end bit
 * of command is sent, the uSDHC de-asserts Read Wait for read transactions and
 * stops checking busy for write transactions. In 4-bit mode, the interrupt cycle
 * starts. If the Suspend command fails, the uSDHC will maintain its current
 * state, and the Host Driver shall restart the transfer by setting the Continue
 * Request bit in the Protocol Control register. Resume Command: The Host Driver
 * re-starts the data transfer by restoring the registers saved before sending the
 * Suspend Command and then sends the Resume Command. The uSDHC will check for a
 * pending busy state before starting write transfers. Abort Command: If this
 * command is set when executing a read transfer, the uSDHC will stop reads to the
 * buffer. If this command is set when executing a write transfer, the uSDHC will
 * stop driving the DATA line. After issuing the Abort command, the Host Driver
 * should issue a software reset (Abort Transaction).
 *
 * Values:
 * - 11 - Abort CMD12, CMD52 for writing I/O Abort in CCCR
 * - 10 - Resume CMD52 for writing Function Select in CCCR
 * - 01 - Suspend CMD52 for writing Bus Suspend in CCCR
 * - 00 - Normal Other commands
 */
/*@{*/
#define BP_uSDHC_CMD_XFR_TYP_CMDTYP (22U)  /*!< Bit position for uSDHC_CMD_XFR_TYP_CMDTYP. */
#define BM_uSDHC_CMD_XFR_TYP_CMDTYP (0x00C00000U) /*!< Bit mask for uSDHC_CMD_XFR_TYP_CMDTYP. */
#define BS_uSDHC_CMD_XFR_TYP_CMDTYP (2U)   /*!< Bit field size in bits for uSDHC_CMD_XFR_TYP_CMDTYP. */

/*! @brief Read current value of the uSDHC_CMD_XFR_TYP_CMDTYP field. */
#define BR_uSDHC_CMD_XFR_TYP_CMDTYP(x) (HW_uSDHC_CMD_XFR_TYP(x).B.CMDTYP)

/*! @brief Format value for bitfield uSDHC_CMD_XFR_TYP_CMDTYP. */
#define BF_uSDHC_CMD_XFR_TYP_CMDTYP(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CMD_XFR_TYP_CMDTYP) & BM_uSDHC_CMD_XFR_TYP_CMDTYP)

/*! @brief Set the CMDTYP field to a new value. */
#define BW_uSDHC_CMD_XFR_TYP_CMDTYP(x, v) (HW_uSDHC_CMD_XFR_TYP_WR(x, (HW_uSDHC_CMD_XFR_TYP_RD(x) & ~BM_uSDHC_CMD_XFR_TYP_CMDTYP) | BF_uSDHC_CMD_XFR_TYP_CMDTYP(v)))
/*@}*/

/*!
 * @name Register uSDHC_CMD_XFR_TYP, field CMDINX[29:24] (RW)
 *
 * These bits shall be set to the command number that is specified in bits 45-40
 * of the Command-Format in the SD Memory Card Physical Layer Specification and
 * SDIO Card Specification.
 */
/*@{*/
#define BP_uSDHC_CMD_XFR_TYP_CMDINX (24U)  /*!< Bit position for uSDHC_CMD_XFR_TYP_CMDINX. */
#define BM_uSDHC_CMD_XFR_TYP_CMDINX (0x3F000000U) /*!< Bit mask for uSDHC_CMD_XFR_TYP_CMDINX. */
#define BS_uSDHC_CMD_XFR_TYP_CMDINX (6U)   /*!< Bit field size in bits for uSDHC_CMD_XFR_TYP_CMDINX. */

/*! @brief Read current value of the uSDHC_CMD_XFR_TYP_CMDINX field. */
#define BR_uSDHC_CMD_XFR_TYP_CMDINX(x) (HW_uSDHC_CMD_XFR_TYP(x).B.CMDINX)

/*! @brief Format value for bitfield uSDHC_CMD_XFR_TYP_CMDINX. */
#define BF_uSDHC_CMD_XFR_TYP_CMDINX(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CMD_XFR_TYP_CMDINX) & BM_uSDHC_CMD_XFR_TYP_CMDINX)

/*! @brief Set the CMDINX field to a new value. */
#define BW_uSDHC_CMD_XFR_TYP_CMDINX(x, v) (HW_uSDHC_CMD_XFR_TYP_WR(x, (HW_uSDHC_CMD_XFR_TYP_RD(x) & ~BM_uSDHC_CMD_XFR_TYP_CMDINX) | BF_uSDHC_CMD_XFR_TYP_CMDINX(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_CMD_RSP0 - Command Response0
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_CMD_RSP0 - Command Response0 (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to store part 0 of the response bits from the card.
 */
typedef union _hw_usdhc_cmd_rsp0
{
    uint32_t U;
    struct _hw_usdhc_cmd_rsp0_bitfields
    {
        uint32_t CMDRSP0 : 32;         /*!< [31:0] Command Response 0 */
    } B;
} hw_usdhc_cmd_rsp0_t;

/*!
 * @name Constants and macros for entire uSDHC_CMD_RSP0 register
 */
/*@{*/
#define HW_uSDHC_CMD_RSP0_ADDR(x) ((uintptr_t)(x) + 0x10U)

#define HW_uSDHC_CMD_RSP0(x)     (*(__I hw_usdhc_cmd_rsp0_t *) HW_uSDHC_CMD_RSP0_ADDR(x))
#define HW_uSDHC_CMD_RSP0_RD(x)  (HW_uSDHC_CMD_RSP0(x).U)
/*@}*/

/*
 * Constants & macros for individual uSDHC_CMD_RSP0 bitfields
 */

/*!
 * @name Register uSDHC_CMD_RSP0, field CMDRSP0[31:0] (RO)
 *
 * Refer to CMD_RSP3Command Response3 for the mapping of command responses from
 * the SD Bus to this register for each response type.
 */
/*@{*/
#define BP_uSDHC_CMD_RSP0_CMDRSP0 (0U)     /*!< Bit position for uSDHC_CMD_RSP0_CMDRSP0. */
#define BM_uSDHC_CMD_RSP0_CMDRSP0 (0xFFFFFFFFU) /*!< Bit mask for uSDHC_CMD_RSP0_CMDRSP0. */
#define BS_uSDHC_CMD_RSP0_CMDRSP0 (32U)    /*!< Bit field size in bits for uSDHC_CMD_RSP0_CMDRSP0. */

/*! @brief Read current value of the uSDHC_CMD_RSP0_CMDRSP0 field. */
#define BR_uSDHC_CMD_RSP0_CMDRSP0(x) (HW_uSDHC_CMD_RSP0(x).U)
/*@}*/

/*******************************************************************************
 * HW_uSDHC_CMD_RSP1 - Command Response1
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_CMD_RSP1 - Command Response1 (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to store part 1 of the response bits from the card.
 */
typedef union _hw_usdhc_cmd_rsp1
{
    uint32_t U;
    struct _hw_usdhc_cmd_rsp1_bitfields
    {
        uint32_t CMDRSP1 : 32;         /*!< [31:0] Command Response 1 */
    } B;
} hw_usdhc_cmd_rsp1_t;

/*!
 * @name Constants and macros for entire uSDHC_CMD_RSP1 register
 */
/*@{*/
#define HW_uSDHC_CMD_RSP1_ADDR(x) ((uintptr_t)(x) + 0x14U)

#define HW_uSDHC_CMD_RSP1(x)     (*(__I hw_usdhc_cmd_rsp1_t *) HW_uSDHC_CMD_RSP1_ADDR(x))
#define HW_uSDHC_CMD_RSP1_RD(x)  (HW_uSDHC_CMD_RSP1(x).U)
/*@}*/

/*
 * Constants & macros for individual uSDHC_CMD_RSP1 bitfields
 */

/*!
 * @name Register uSDHC_CMD_RSP1, field CMDRSP1[31:0] (RO)
 *
 * Refer to CMD_RSP3Command Response3 for the mapping of command responses from
 * the SD Bus to this register for each response type.
 */
/*@{*/
#define BP_uSDHC_CMD_RSP1_CMDRSP1 (0U)     /*!< Bit position for uSDHC_CMD_RSP1_CMDRSP1. */
#define BM_uSDHC_CMD_RSP1_CMDRSP1 (0xFFFFFFFFU) /*!< Bit mask for uSDHC_CMD_RSP1_CMDRSP1. */
#define BS_uSDHC_CMD_RSP1_CMDRSP1 (32U)    /*!< Bit field size in bits for uSDHC_CMD_RSP1_CMDRSP1. */

/*! @brief Read current value of the uSDHC_CMD_RSP1_CMDRSP1 field. */
#define BR_uSDHC_CMD_RSP1_CMDRSP1(x) (HW_uSDHC_CMD_RSP1(x).U)
/*@}*/

/*******************************************************************************
 * HW_uSDHC_CMD_RSP2 - Command Response2
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_CMD_RSP2 - Command Response2 (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to store part 2 of the response bits from the card.
 */
typedef union _hw_usdhc_cmd_rsp2
{
    uint32_t U;
    struct _hw_usdhc_cmd_rsp2_bitfields
    {
        uint32_t CMDRSP2 : 32;         /*!< [31:0] Command Response 2 */
    } B;
} hw_usdhc_cmd_rsp2_t;

/*!
 * @name Constants and macros for entire uSDHC_CMD_RSP2 register
 */
/*@{*/
#define HW_uSDHC_CMD_RSP2_ADDR(x) ((uintptr_t)(x) + 0x18U)

#define HW_uSDHC_CMD_RSP2(x)     (*(__I hw_usdhc_cmd_rsp2_t *) HW_uSDHC_CMD_RSP2_ADDR(x))
#define HW_uSDHC_CMD_RSP2_RD(x)  (HW_uSDHC_CMD_RSP2(x).U)
/*@}*/

/*
 * Constants & macros for individual uSDHC_CMD_RSP2 bitfields
 */

/*!
 * @name Register uSDHC_CMD_RSP2, field CMDRSP2[31:0] (RO)
 *
 * Refer to CMD_RSP3Command Response3 for the mapping of command responses from
 * the SD Bus to this register for each response type.
 */
/*@{*/
#define BP_uSDHC_CMD_RSP2_CMDRSP2 (0U)     /*!< Bit position for uSDHC_CMD_RSP2_CMDRSP2. */
#define BM_uSDHC_CMD_RSP2_CMDRSP2 (0xFFFFFFFFU) /*!< Bit mask for uSDHC_CMD_RSP2_CMDRSP2. */
#define BS_uSDHC_CMD_RSP2_CMDRSP2 (32U)    /*!< Bit field size in bits for uSDHC_CMD_RSP2_CMDRSP2. */

/*! @brief Read current value of the uSDHC_CMD_RSP2_CMDRSP2 field. */
#define BR_uSDHC_CMD_RSP2_CMDRSP2(x) (HW_uSDHC_CMD_RSP2(x).U)
/*@}*/

/*******************************************************************************
 * HW_uSDHC_CMD_RSP3 - Command Response3
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_CMD_RSP3 - Command Response3 (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to store part 3 of the response bits from the card. The
 * table below describes the mapping of command responses from the SD Bus to
 * Command Response registers for each response type. In the table, R[ ] refers to a
 * bit range within the response data as transmitted on the SD Bus. Response Bit
 * Definition for Each Response Type Response Type Meaning of Response Response
 * Field Response Register R1,R1b (normal response) Card Status R[39:8] CMDRSP0
 * R1b (Auto CMD12 response) Card Status for Auto CMD12 R[39:8] CMDRSP3 R2 (CID,
 * CSD register) CID/CSD register [127:8] R[127:8] {CMDRSP3[23:0], CMDRSP2,
 * CMDRSP1, CMDRSP0} R3 (OCR register) OCR register for memory R[39:8] CMDRSP0 R4 (OCR
 * register) OCR register for I/O etc. R[39:8] CMDRSP0 R5, R5b SDIO response
 * R[39:8] CMDRSP0 R6 (Publish RCA) New Published RCA[31:16] and card status[15:0]
 * R[39:9] CMDRSP0 This table shows that most responses with a length of 48
 * (R[47:0]) have 32-bits of the response data (R[39:8]) stored in the CMDRSP0 register.
 * Responses of type R1b (Auto CMD12 responses) have response data bits
 * (R[39:8]) stored in the CMDRSP3 register. Responses with length 136 (R[135:0]) have
 * 120-bits of the response data (R[127:8]) stored in the CMDRSP0, 1, 2, and 3
 * registers. To be able to read the response status efficiently, the uSDHC only
 * stores part of the response data in the Command Response registers. This enables
 * the Host Driver to efficiently read 32-bits of response data in one read cycle
 * on a 32-bit bus system. Parts of the response, the Index field and the CRC,
 * are checked by the uSDHC (as specified by the Command Index Check Enable and the
 * Command CRC Check Enable bits in the Transfer Type register) and generate an
 * error interrupt if any error is detected. The bit range for the CRC check
 * depends on the response length. If the response length is 48, the uSDHC will check
 * R[47:1], and if the response length is 136 the uSDHC will check R[119:1].
 * Since the uSDHC may have a multiple block data transfer executing concurrently
 * with a CMD_wo_DAT command, the uSDHC stores the Auto CMD12 response in the
 * CMDRSP3 register. The CMD_wo_DAT response is stored in CMDRSP0. This allows the
 * uSDHC to avoid overwriting the Auto CMD12 response with the CMD_wo_DAT and vice
 * versa. When the uSDHC modifies part of the Command Response registers, as shown
 * in the table above, it preserves the unmodified bits.
 */
typedef union _hw_usdhc_cmd_rsp3
{
    uint32_t U;
    struct _hw_usdhc_cmd_rsp3_bitfields
    {
        uint32_t CMDRSP3 : 32;         /*!< [31:0] Command Response 3 */
    } B;
} hw_usdhc_cmd_rsp3_t;

/*!
 * @name Constants and macros for entire uSDHC_CMD_RSP3 register
 */
/*@{*/
#define HW_uSDHC_CMD_RSP3_ADDR(x) ((uintptr_t)(x) + 0x1CU)

#define HW_uSDHC_CMD_RSP3(x)     (*(__I hw_usdhc_cmd_rsp3_t *) HW_uSDHC_CMD_RSP3_ADDR(x))
#define HW_uSDHC_CMD_RSP3_RD(x)  (HW_uSDHC_CMD_RSP3(x).U)
/*@}*/

/*
 * Constants & macros for individual uSDHC_CMD_RSP3 bitfields
 */

/*!
 * @name Register uSDHC_CMD_RSP3, field CMDRSP3[31:0] (RO)
 *
 * Refer to CMD_RSP3Command Response3 for the mapping of command responses from
 * the SD Bus to this register for each response type.
 */
/*@{*/
#define BP_uSDHC_CMD_RSP3_CMDRSP3 (0U)     /*!< Bit position for uSDHC_CMD_RSP3_CMDRSP3. */
#define BM_uSDHC_CMD_RSP3_CMDRSP3 (0xFFFFFFFFU) /*!< Bit mask for uSDHC_CMD_RSP3_CMDRSP3. */
#define BS_uSDHC_CMD_RSP3_CMDRSP3 (32U)    /*!< Bit field size in bits for uSDHC_CMD_RSP3_CMDRSP3. */

/*! @brief Read current value of the uSDHC_CMD_RSP3_CMDRSP3 field. */
#define BR_uSDHC_CMD_RSP3_CMDRSP3(x) (HW_uSDHC_CMD_RSP3(x).U)
/*@}*/

/*******************************************************************************
 * HW_uSDHC_DATA_BUFF_ACC_PORT - Data Buffer Access Port
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_DATA_BUFF_ACC_PORT - Data Buffer Access Port (RW)
 *
 * Reset value: 0x00000000U
 *
 * This is a 32-bit data port register used to access the internal buffer.
 */
typedef union _hw_usdhc_data_buff_acc_port
{
    uint32_t U;
    struct _hw_usdhc_data_buff_acc_port_bitfields
    {
        uint32_t DATCONT : 32;         /*!< [31:0] Data Content */
    } B;
} hw_usdhc_data_buff_acc_port_t;

/*!
 * @name Constants and macros for entire uSDHC_DATA_BUFF_ACC_PORT register
 */
/*@{*/
#define HW_uSDHC_DATA_BUFF_ACC_PORT_ADDR(x) ((uintptr_t)(x) + 0x20U)

#define HW_uSDHC_DATA_BUFF_ACC_PORT(x) (*(__IO hw_usdhc_data_buff_acc_port_t *) HW_uSDHC_DATA_BUFF_ACC_PORT_ADDR(x))
#define HW_uSDHC_DATA_BUFF_ACC_PORT_RD(x) (HW_uSDHC_DATA_BUFF_ACC_PORT(x).U)
#define HW_uSDHC_DATA_BUFF_ACC_PORT_WR(x, v) (HW_uSDHC_DATA_BUFF_ACC_PORT(x).U = (v))
#define HW_uSDHC_DATA_BUFF_ACC_PORT_SET(x, v) (HW_uSDHC_DATA_BUFF_ACC_PORT_WR(x, HW_uSDHC_DATA_BUFF_ACC_PORT_RD(x) |  (v)))
#define HW_uSDHC_DATA_BUFF_ACC_PORT_CLR(x, v) (HW_uSDHC_DATA_BUFF_ACC_PORT_WR(x, HW_uSDHC_DATA_BUFF_ACC_PORT_RD(x) & ~(v)))
#define HW_uSDHC_DATA_BUFF_ACC_PORT_TOG(x, v) (HW_uSDHC_DATA_BUFF_ACC_PORT_WR(x, HW_uSDHC_DATA_BUFF_ACC_PORT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_DATA_BUFF_ACC_PORT bitfields
 */

/*!
 * @name Register uSDHC_DATA_BUFF_ACC_PORT, field DATCONT[31:0] (RW)
 *
 * The Buffer Data Port register is for 32-bit data access by the ARM platform
 * or the external DMA. When the internal DMA is enabled, any write to this
 * register is ignored, and any read from this register will always yield 0s.
 */
/*@{*/
#define BP_uSDHC_DATA_BUFF_ACC_PORT_DATCONT (0U) /*!< Bit position for uSDHC_DATA_BUFF_ACC_PORT_DATCONT. */
#define BM_uSDHC_DATA_BUFF_ACC_PORT_DATCONT (0xFFFFFFFFU) /*!< Bit mask for uSDHC_DATA_BUFF_ACC_PORT_DATCONT. */
#define BS_uSDHC_DATA_BUFF_ACC_PORT_DATCONT (32U) /*!< Bit field size in bits for uSDHC_DATA_BUFF_ACC_PORT_DATCONT. */

/*! @brief Read current value of the uSDHC_DATA_BUFF_ACC_PORT_DATCONT field. */
#define BR_uSDHC_DATA_BUFF_ACC_PORT_DATCONT(x) (HW_uSDHC_DATA_BUFF_ACC_PORT(x).U)

/*! @brief Format value for bitfield uSDHC_DATA_BUFF_ACC_PORT_DATCONT. */
#define BF_uSDHC_DATA_BUFF_ACC_PORT_DATCONT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DATA_BUFF_ACC_PORT_DATCONT) & BM_uSDHC_DATA_BUFF_ACC_PORT_DATCONT)

/*! @brief Set the DATCONT field to a new value. */
#define BW_uSDHC_DATA_BUFF_ACC_PORT_DATCONT(x, v) (HW_uSDHC_DATA_BUFF_ACC_PORT_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_PRES_STATE - Present State
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_PRES_STATE - Present State (RO)
 *
 * Reset value: 0x00008080U
 *
 * The Host Driver can get status of the uSDHC from this 32-bit read only
 * register. The Host Driver can issue CMD0, CMD12, CMD13 (for memory) and CMD52 (for
 * SDIO) when the DATA lines are busy during a data transfer. These commands can
 * be issued when Command Inhibit (CMD) is set to zero. Other commands shall be
 * issued when Command Inhibit (DATA) is set to zero. Possible changes to the SD
 * Physical Specification may add other commands to this list in the future. Note:
 * the reset value of Present State Register depend on testbench connectivity.
 */
typedef union _hw_usdhc_pres_state
{
    uint32_t U;
    struct _hw_usdhc_pres_state_bitfields
    {
        uint32_t CIHB : 1;             /*!< [0] Command Inhibit (CMD) */
        uint32_t CDIHB : 1;            /*!< [1] Command Inhibit (DATA) */
        uint32_t DLA : 1;              /*!< [2] Data Line Active */
        uint32_t SDSTB : 1;            /*!< [3] SD Clock Stable */
        uint32_t IPGOFF : 1;           /*!< [4] IPG_CLK Gated Off Internally */
        uint32_t HCKOFF : 1;           /*!< [5] HCLK Gated Off Internally */
        uint32_t PEROFF : 1;           /*!< [6] IPG_PERCLK Gated Off Internally */
        uint32_t SDOFF : 1;            /*!< [7] SD Clock Gated Off Internally */
        uint32_t WTA : 1;              /*!< [8] Write Transfer Active */
        uint32_t RTA : 1;              /*!< [9] Read Transfer Active */
        uint32_t BWEN : 1;             /*!< [10] Buffer Write Enable */
        uint32_t BREN : 1;             /*!< [11] Buffer Read Enable */
        uint32_t RTR : 1;              /*!< [12] Re-Tuning Request (only for SD3.0 SDR104
                                        * mode) */
        uint32_t RESERVED0 : 2;        /*!< [14:13]  */
        uint32_t TSCD : 1;             /*!< [15] Tape Select Change Done */
        uint32_t CINST : 1;            /*!< [16] Card Inserted */
        uint32_t RESERVED1 : 1;        /*!< [17]  */
        uint32_t CDPL : 1;             /*!< [18] Card Detect Pin Level */
        uint32_t WPSPL : 1;            /*!< [19] Write Protect Switch Pin Level */
        uint32_t RESERVED2 : 3;        /*!< [22:20]  */
        uint32_t CLSL : 1;             /*!< [23] CMD Line Signal Level */
        uint32_t DLSL : 8;             /*!< [31:24] DATA[7:0] Line Signal Level */
    } B;
} hw_usdhc_pres_state_t;

/*!
 * @name Constants and macros for entire uSDHC_PRES_STATE register
 */
/*@{*/
#define HW_uSDHC_PRES_STATE_ADDR(x) ((uintptr_t)(x) + 0x24U)

#define HW_uSDHC_PRES_STATE(x)   (*(__I hw_usdhc_pres_state_t *) HW_uSDHC_PRES_STATE_ADDR(x))
#define HW_uSDHC_PRES_STATE_RD(x) (HW_uSDHC_PRES_STATE(x).U)
/*@}*/

/*
 * Constants & macros for individual uSDHC_PRES_STATE bitfields
 */

/*!
 * @name Register uSDHC_PRES_STATE, field CIHB[0] (RO)
 *
 * If this status bit is 0, it indicates that the CMD line is not in use and the
 * uSDHC can issue a SD / MMC Command using the CMD line. This bit is set also
 * immediately after the Transfer Type register is written. This bit is cleared
 * when the command response is received. Even if the Command Inhibit (DATA) is set
 * to 1, Commands using only the CMD line can be issued if this bit is 0.
 * Changing from 1 to 0 generates a Command Complete interrupt in the Interrupt Status
 * register. If the uSDHC cannot issue the command because of a command conflict
 * error (Refer to Command CRC Error) or because of a Command Not Issued By Auto
 * CMD12 Error, this bit will remain 1 and the Command Complete is not set. The
 * Status of issuing an Auto CMD12 does not show on this bit.
 *
 * Values:
 * - 1 - Cannot issue command
 * - 0 - Can issue command using only CMD line
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_CIHB (0U)      /*!< Bit position for uSDHC_PRES_STATE_CIHB. */
#define BM_uSDHC_PRES_STATE_CIHB (0x00000001U) /*!< Bit mask for uSDHC_PRES_STATE_CIHB. */
#define BS_uSDHC_PRES_STATE_CIHB (1U)      /*!< Bit field size in bits for uSDHC_PRES_STATE_CIHB. */

/*! @brief Read current value of the uSDHC_PRES_STATE_CIHB field. */
#define BR_uSDHC_PRES_STATE_CIHB(x) (HW_uSDHC_PRES_STATE(x).B.CIHB)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field CDIHB[1] (RO)
 *
 * This status bit is generated if either the DAT Line Active or the Read
 * Transfer Active is set to 1. If this bit is 0, it indicates that the uSDHC can issue
 * the next SD / MMC Command. Commands with a busy signal belong to Command
 * Inhibit (DATA) (for example. R1b, R5b type). Changing from 1 to 0 generates a
 * Transfer Complete interrupt in the Interrupt Status register. The SD Host Driver
 * can save registers for a suspend transaction after this bit has changed from 1
 * to 0.
 *
 * Values:
 * - 1 - Cannot issue command which uses the DATA line
 * - 0 - Can issue command which uses the DATA line
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_CDIHB (1U)     /*!< Bit position for uSDHC_PRES_STATE_CDIHB. */
#define BM_uSDHC_PRES_STATE_CDIHB (0x00000002U) /*!< Bit mask for uSDHC_PRES_STATE_CDIHB. */
#define BS_uSDHC_PRES_STATE_CDIHB (1U)     /*!< Bit field size in bits for uSDHC_PRES_STATE_CDIHB. */

/*! @brief Read current value of the uSDHC_PRES_STATE_CDIHB field. */
#define BR_uSDHC_PRES_STATE_CDIHB(x) (HW_uSDHC_PRES_STATE(x).B.CDIHB)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field DLA[2] (RO)
 *
 * This status bit indicates whether one of the DATA lines on the SD Bus is in
 * use. In the case of read transactions: This status indicates if a read transfer
 * is executing on the SD Bus. Changes in this value from 1 to 0, between data
 * blocks, generates a Block Gap Event interrupt in the Interrupt Status register.
 * This bit will be set in either of the following cases: After the end bit of
 * the read command. When writing a 1 to the Continue Request bit in the Protocol
 * Control register to restart a read transfer. This bit will be cleared in
 * either of the following cases: (1) When the end bit of the last data block is sent
 * from the SD Bus to the uSDHC. (2) When the Read Wait state is stopped by a
 * Suspend command and the DATA2 line is released. The uSDHC will wait at the next
 * block gap by driving Read Wait at the start of the interrupt cycle. If the Read
 * Wait signal is already driven (data buffer cannot receive data), the uSDHC
 * can wait for a current block gap by continuing to drive the Read Wait signal. It
 * is necessary to support Read Wait in order to use the suspend / resume
 * function. This bit will remain 1 during Read Wait. In the case of write
 * transactions: This status indicates that a write transfer is executing on the SD Bus.
 * Changes in this value from 1 to 0 generate a Transfer Complete interrupt in the
 * Interrupt Status register. This bit will be set in either of the following
 * cases: After the end bit of the write command. When writing to 1 to the Continue
 * Request bit in the Protocol Control register to continue a write transfer. This
 * bit will be cleared in either of the following cases: When the SD card
 * releases Write Busy of the last data block, the uSDHC will also detect if the output
 * is not busy. If the SD card does not drive the busy signal after the CRC
 * status is received, the uSDHC shall assume the card drive "Not Busy". When the SD
 * card releases write busy, prior to waiting for write transfer, and as a result
 * of a Stop At Block Gap Request. In the case of command with busy pending: This
 * status indicates that a busy state follows the command and the data line is
 * in use. This bit will be cleared when the DATA0 line is released.
 *
 * Values:
 * - 1 - DATA Line Active
 * - 0 - DATA Line Inactive
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_DLA (2U)       /*!< Bit position for uSDHC_PRES_STATE_DLA. */
#define BM_uSDHC_PRES_STATE_DLA (0x00000004U) /*!< Bit mask for uSDHC_PRES_STATE_DLA. */
#define BS_uSDHC_PRES_STATE_DLA (1U)       /*!< Bit field size in bits for uSDHC_PRES_STATE_DLA. */

/*! @brief Read current value of the uSDHC_PRES_STATE_DLA field. */
#define BR_uSDHC_PRES_STATE_DLA(x) (HW_uSDHC_PRES_STATE(x).B.DLA)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field SDSTB[3] (RO)
 *
 * This status bit indicates that the internal card clock is stable. This bit is
 * for the Host Driver to poll clock status when changing the clock frequency.
 * It is recommended to clear FRC_SDCLK_ON bit in System Control register to
 * remove glitches on the card clock when the frequency is changing. Before changing
 * clock divisor value(SDCLKFS or DVS), Host Driver should make sure the SDSTB bit
 * is high.
 *
 * Values:
 * - 1 - Clock is stable.
 * - 0 - Clock is changing frequency and not stable.
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_SDSTB (3U)     /*!< Bit position for uSDHC_PRES_STATE_SDSTB. */
#define BM_uSDHC_PRES_STATE_SDSTB (0x00000008U) /*!< Bit mask for uSDHC_PRES_STATE_SDSTB. */
#define BS_uSDHC_PRES_STATE_SDSTB (1U)     /*!< Bit field size in bits for uSDHC_PRES_STATE_SDSTB. */

/*! @brief Read current value of the uSDHC_PRES_STATE_SDSTB field. */
#define BR_uSDHC_PRES_STATE_SDSTB(x) (HW_uSDHC_PRES_STATE(x).B.SDSTB)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field IPGOFF[4] (RO)
 *
 * This status bit indicates that the ipg_clk is internally gated off. This bit
 * is for the Host Driver to debug.
 *
 * Values:
 * - 1 - IPG_CLK is gated off.
 * - 0 - IPG_CLK is active.
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_IPGOFF (4U)    /*!< Bit position for uSDHC_PRES_STATE_IPGOFF. */
#define BM_uSDHC_PRES_STATE_IPGOFF (0x00000010U) /*!< Bit mask for uSDHC_PRES_STATE_IPGOFF. */
#define BS_uSDHC_PRES_STATE_IPGOFF (1U)    /*!< Bit field size in bits for uSDHC_PRES_STATE_IPGOFF. */

/*! @brief Read current value of the uSDHC_PRES_STATE_IPGOFF field. */
#define BR_uSDHC_PRES_STATE_IPGOFF(x) (HW_uSDHC_PRES_STATE(x).B.IPGOFF)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field HCKOFF[5] (RO)
 *
 * This status bit indicates that the HCLK is internally gated off. This bit is
 * for the Host Driver to debug during a data transfer.
 *
 * Values:
 * - 1 - HCLK is gated off.
 * - 0 - HCLK is active.
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_HCKOFF (5U)    /*!< Bit position for uSDHC_PRES_STATE_HCKOFF. */
#define BM_uSDHC_PRES_STATE_HCKOFF (0x00000020U) /*!< Bit mask for uSDHC_PRES_STATE_HCKOFF. */
#define BS_uSDHC_PRES_STATE_HCKOFF (1U)    /*!< Bit field size in bits for uSDHC_PRES_STATE_HCKOFF. */

/*! @brief Read current value of the uSDHC_PRES_STATE_HCKOFF field. */
#define BR_uSDHC_PRES_STATE_HCKOFF(x) (HW_uSDHC_PRES_STATE(x).B.HCKOFF)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field PEROFF[6] (RO)
 *
 * This status bit indicates that the IPG_PERCLK is internally gated off. This
 * bit is for the Host Driver to debug transaction on the SD bus. When
 * IPG_CLK_SOFT_EN is cleared, IPG_PERCLK will be gated off, otherwise IPG_PERCLK will be
 * always active.
 *
 * Values:
 * - 1 - IPG_PERCLK is gated off.
 * - 0 - IPG_PERCLK is active.
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_PEROFF (6U)    /*!< Bit position for uSDHC_PRES_STATE_PEROFF. */
#define BM_uSDHC_PRES_STATE_PEROFF (0x00000040U) /*!< Bit mask for uSDHC_PRES_STATE_PEROFF. */
#define BS_uSDHC_PRES_STATE_PEROFF (1U)    /*!< Bit field size in bits for uSDHC_PRES_STATE_PEROFF. */

/*! @brief Read current value of the uSDHC_PRES_STATE_PEROFF field. */
#define BR_uSDHC_PRES_STATE_PEROFF(x) (HW_uSDHC_PRES_STATE(x).B.PEROFF)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field SDOFF[7] (RO)
 *
 * This status bit indicates that the SD Clock is internally gated off, because
 * of buffer over / under-run or read pause without read wait assertion, or the
 * driver set FRC_SDCLK_ON bit is 0 to stop the SD clock in idle status. Set
 * IPG_PERCLK_SOFT_EN and CARD_CLK_SOFT_EN to 0 also gate off SD clock. This bit is
 * for the Host Driver to debug data transaction on the SD bus.
 *
 * Values:
 * - 1 - SD Clock is gated off.
 * - 0 - SD Clock is active.
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_SDOFF (7U)     /*!< Bit position for uSDHC_PRES_STATE_SDOFF. */
#define BM_uSDHC_PRES_STATE_SDOFF (0x00000080U) /*!< Bit mask for uSDHC_PRES_STATE_SDOFF. */
#define BS_uSDHC_PRES_STATE_SDOFF (1U)     /*!< Bit field size in bits for uSDHC_PRES_STATE_SDOFF. */

/*! @brief Read current value of the uSDHC_PRES_STATE_SDOFF field. */
#define BR_uSDHC_PRES_STATE_SDOFF(x) (HW_uSDHC_PRES_STATE(x).B.SDOFF)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field WTA[8] (RO)
 *
 * This status bit indicates a write transfer is active. If this bit is 0, it
 * means no valid write data exists in the uSDHC. This bit is set in either of the
 * following cases: After the end bit of the write command. When writing 1 to the
 * Continue Request bit in the Protocol Control register to restart a write
 * transfer. This bit is cleared in either of the following cases: After getting the
 * CRC status of the last data block as specified by the transfer count (Single
 * and Multiple). After getting the CRC status of any block where data
 * transmission is about to be stopped by a Stop At Block Gap Request. During a write
 * transaction, a Block Gap Event interrupt is generated when this bit is changed to 0,
 * as result of the Stop At Block Gap Request being set. This status is useful
 * for the Host Driver in determining when to issue commands during Write Busy
 * state.
 *
 * Values:
 * - 1 - Transferring data
 * - 0 - No valid data
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_WTA (8U)       /*!< Bit position for uSDHC_PRES_STATE_WTA. */
#define BM_uSDHC_PRES_STATE_WTA (0x00000100U) /*!< Bit mask for uSDHC_PRES_STATE_WTA. */
#define BS_uSDHC_PRES_STATE_WTA (1U)       /*!< Bit field size in bits for uSDHC_PRES_STATE_WTA. */

/*! @brief Read current value of the uSDHC_PRES_STATE_WTA field. */
#define BR_uSDHC_PRES_STATE_WTA(x) (HW_uSDHC_PRES_STATE(x).B.WTA)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field RTA[9] (RO)
 *
 * This status bit is used for detecting completion of a read transfer. This bit
 * is set for either of the following conditions: After the end bit of the read
 * command. When writing a 1 to the Continue Request bit in the Protocol Control
 * register to restart a read transfer. A Transfer Complete interrupt is
 * generated when this bit changes to 0. This bit is cleared for either of the following
 * conditions: When the last data block as specified by block length is
 * transferred to the System, i.e. all data are read away from uSDHC internal buffer. When
 * all valid data blocks have been transferred from uSDHC internal buffer to the
 * System and no current block transfers are being sent as a result of the Stop
 * At Block Gap Request being set to 1.
 *
 * Values:
 * - 1 - Transferring data
 * - 0 - No valid data
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_RTA (9U)       /*!< Bit position for uSDHC_PRES_STATE_RTA. */
#define BM_uSDHC_PRES_STATE_RTA (0x00000200U) /*!< Bit mask for uSDHC_PRES_STATE_RTA. */
#define BS_uSDHC_PRES_STATE_RTA (1U)       /*!< Bit field size in bits for uSDHC_PRES_STATE_RTA. */

/*! @brief Read current value of the uSDHC_PRES_STATE_RTA field. */
#define BR_uSDHC_PRES_STATE_RTA(x) (HW_uSDHC_PRES_STATE(x).B.RTA)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field BWEN[10] (RO)
 *
 * This status bit is used for non-DMA write transfers. The uSDHC implements an
 * internal buffer to transfer data efficiently. This read only flag indicates if
 * space is available for write data. If this bit is 1, valid data greater than
 * the watermark level can be written to the buffer. A change of this bit from 1
 * to 0 occurs when some writes to the buffer(write DATPORT(Base + 0x20)) are
 * made and the buffer hasn't valid space greater than the watermark level. A change
 * of this bit from 0 to 1 occurs when the buffer can hold valid data greater
 * than the write watermark level and the Buffer Write Ready interrupt is generated
 * and enabled.
 *
 * Values:
 * - 1 - Write enable
 * - 0 - Write disable
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_BWEN (10U)     /*!< Bit position for uSDHC_PRES_STATE_BWEN. */
#define BM_uSDHC_PRES_STATE_BWEN (0x00000400U) /*!< Bit mask for uSDHC_PRES_STATE_BWEN. */
#define BS_uSDHC_PRES_STATE_BWEN (1U)      /*!< Bit field size in bits for uSDHC_PRES_STATE_BWEN. */

/*! @brief Read current value of the uSDHC_PRES_STATE_BWEN field. */
#define BR_uSDHC_PRES_STATE_BWEN(x) (HW_uSDHC_PRES_STATE(x).B.BWEN)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field BREN[11] (RO)
 *
 * This status bit is used for non-DMA read transfers. The uSDHC implements an
 * internal buffer to transfer data efficiently. This read only flag indicates
 * that valid data exists in the host side buffer. If this bit is high, valid data
 * greater than the watermark level exist in the buffer. A change of this bit from
 * 1 to 0 occurs when some reads from the buffer(read DATPORT (Base + 0x20)) are
 * made and the buffer hasn't valid data greater than the watermark level. A
 * change of this bit from 0 to1 occurs when there is enough valid data ready in the
 * buffer and the Buffer Read Ready interrupt has been generated and enabled.
 *
 * Values:
 * - 1 - Read enable
 * - 0 - Read disable
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_BREN (11U)     /*!< Bit position for uSDHC_PRES_STATE_BREN. */
#define BM_uSDHC_PRES_STATE_BREN (0x00000800U) /*!< Bit mask for uSDHC_PRES_STATE_BREN. */
#define BS_uSDHC_PRES_STATE_BREN (1U)      /*!< Bit field size in bits for uSDHC_PRES_STATE_BREN. */

/*! @brief Read current value of the uSDHC_PRES_STATE_BREN field. */
#define BR_uSDHC_PRES_STATE_BREN(x) (HW_uSDHC_PRES_STATE(x).B.BREN)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field RTR[12] (RO)
 *
 * Host Controller may request Host Driver to execute re-tuning sequence by
 * setting this bit when the data window is shifted by temperature drift and a tuned
 * sampling point does not have a good margin to receive correct data. This bit
 * is cleared when a command is issued with setting Execute Tuning bit in
 * MIXER_CTRL register. Changing of this bit from 0 to 1 generates Re-Tuning Event. Refer
 * to Interrupt status registers for more detail. This bit isn't set to 1 if
 * Sampling Clock Select in the MIXER_CTRL register is set to 0 (using fixed
 * sampling clock).
 *
 * Values:
 * - 1 - Sampling clock needs re-tuning
 * - 0 - Fixed or well tuned sampling clock
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_RTR (12U)      /*!< Bit position for uSDHC_PRES_STATE_RTR. */
#define BM_uSDHC_PRES_STATE_RTR (0x00001000U) /*!< Bit mask for uSDHC_PRES_STATE_RTR. */
#define BS_uSDHC_PRES_STATE_RTR (1U)       /*!< Bit field size in bits for uSDHC_PRES_STATE_RTR. */

/*! @brief Read current value of the uSDHC_PRES_STATE_RTR field. */
#define BR_uSDHC_PRES_STATE_RTR(x) (HW_uSDHC_PRES_STATE(x).B.RTR)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field TSCD[15] (RO)
 *
 * This bit indicates the dealy setting is effective after write
 * CLK_TUNE_CTRL_STATUS register.
 *
 * Values:
 * - 1 - Delay cell select change is finished.
 * - 0 - Delay cell select change is not finished.
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_TSCD (15U)     /*!< Bit position for uSDHC_PRES_STATE_TSCD. */
#define BM_uSDHC_PRES_STATE_TSCD (0x00008000U) /*!< Bit mask for uSDHC_PRES_STATE_TSCD. */
#define BS_uSDHC_PRES_STATE_TSCD (1U)      /*!< Bit field size in bits for uSDHC_PRES_STATE_TSCD. */

/*! @brief Read current value of the uSDHC_PRES_STATE_TSCD field. */
#define BR_uSDHC_PRES_STATE_TSCD(x) (HW_uSDHC_PRES_STATE(x).B.TSCD)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field CINST[16] (RO)
 *
 * This bit indicates whether a card has been inserted. The uSDHC debounces this
 * signal so that the Host Driver will not need to wait for it to stabilize.
 * Changing from a 0 to 1 generates a Card Insertion interrupt in the Interrupt
 * Status register. Changing from a 1 to 0 generates a Card Removal interrupt in the
 * Interrupt Status register. A write to the Force Event Register does not effect
 * this bit. The Software Reset For All in the System Control register does not
 * effect this bit. A software reset does not effect this bit.
 *
 * Values:
 * - 1 - Card Inserted
 * - 0 - Power on Reset or No Card
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_CINST (16U)    /*!< Bit position for uSDHC_PRES_STATE_CINST. */
#define BM_uSDHC_PRES_STATE_CINST (0x00010000U) /*!< Bit mask for uSDHC_PRES_STATE_CINST. */
#define BS_uSDHC_PRES_STATE_CINST (1U)     /*!< Bit field size in bits for uSDHC_PRES_STATE_CINST. */

/*! @brief Read current value of the uSDHC_PRES_STATE_CINST field. */
#define BR_uSDHC_PRES_STATE_CINST(x) (HW_uSDHC_PRES_STATE(x).B.CINST)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field CDPL[18] (RO)
 *
 * This bit reflects the inverse value of the CD_B pin for the card socket.
 * Debouncing is not performed on this bit. This bit may be valid, but is not
 * guaranteed, because of propagation delay. Use of this bit is limited to testing since
 * it must be debounced by software. A software reset does not effect this bit.
 * A write to the Force Event Register does not effect this bit. The reset value
 * is effected by the external card detection pin. This bit shows the value on
 * the CD_B pin (i.e. when a card is inserted in the socket, it is 0 on the CD_B
 * input, and consequently the CDPL reads 1.)
 *
 * Values:
 * - 1 - Card present (CD_B = 0)
 * - 0 - No card present (CD_B = 1)
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_CDPL (18U)     /*!< Bit position for uSDHC_PRES_STATE_CDPL. */
#define BM_uSDHC_PRES_STATE_CDPL (0x00040000U) /*!< Bit mask for uSDHC_PRES_STATE_CDPL. */
#define BS_uSDHC_PRES_STATE_CDPL (1U)      /*!< Bit field size in bits for uSDHC_PRES_STATE_CDPL. */

/*! @brief Read current value of the uSDHC_PRES_STATE_CDPL field. */
#define BR_uSDHC_PRES_STATE_CDPL(x) (HW_uSDHC_PRES_STATE(x).B.CDPL)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field WPSPL[19] (RO)
 *
 * The Write Protect Switch is supported for memory and combo cards.This bit
 * reflects the inverted value of the WP pin of the card socket. A software reset
 * does not affect this bit. The reset value is effected by the external write
 * protect switch. If the WP pin is not used, it should be tied low, so that the
 * reset value of this bit is high and write is enabled.
 *
 * Values:
 * - 1 - Write enabled (WP = 0)
 * - 0 - Write protected (WP = 1)
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_WPSPL (19U)    /*!< Bit position for uSDHC_PRES_STATE_WPSPL. */
#define BM_uSDHC_PRES_STATE_WPSPL (0x00080000U) /*!< Bit mask for uSDHC_PRES_STATE_WPSPL. */
#define BS_uSDHC_PRES_STATE_WPSPL (1U)     /*!< Bit field size in bits for uSDHC_PRES_STATE_WPSPL. */

/*! @brief Read current value of the uSDHC_PRES_STATE_WPSPL field. */
#define BR_uSDHC_PRES_STATE_WPSPL(x) (HW_uSDHC_PRES_STATE(x).B.WPSPL)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field CLSL[23] (RO)
 *
 * This status is used to check the CMD line level to recover from errors, and
 * for debugging. The reset value is affected by the external pull-up / pull-down
 * resistor, by default, the read value of this bit after reset is 1'b1, when the
 * command line is pulled up.
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_CLSL (23U)     /*!< Bit position for uSDHC_PRES_STATE_CLSL. */
#define BM_uSDHC_PRES_STATE_CLSL (0x00800000U) /*!< Bit mask for uSDHC_PRES_STATE_CLSL. */
#define BS_uSDHC_PRES_STATE_CLSL (1U)      /*!< Bit field size in bits for uSDHC_PRES_STATE_CLSL. */

/*! @brief Read current value of the uSDHC_PRES_STATE_CLSL field. */
#define BR_uSDHC_PRES_STATE_CLSL(x) (HW_uSDHC_PRES_STATE(x).B.CLSL)
/*@}*/

/*!
 * @name Register uSDHC_PRES_STATE, field DLSL[31:24] (RO)
 *
 * This status is used to check the DATA line level to recover from errors, and
 * for debugging.This is especially useful in detecting the busy signal level
 * from DATA0. The reset value is affected by the external pull-up / pull-down
 * resistors. By default, the read value of this bit field after reset is 8'b11110111,
 * when DATA3 is pulled down and the other lines are pulled up.
 */
/*@{*/
#define BP_uSDHC_PRES_STATE_DLSL (24U)     /*!< Bit position for uSDHC_PRES_STATE_DLSL. */
#define BM_uSDHC_PRES_STATE_DLSL (0xFF000000U) /*!< Bit mask for uSDHC_PRES_STATE_DLSL. */
#define BS_uSDHC_PRES_STATE_DLSL (8U)      /*!< Bit field size in bits for uSDHC_PRES_STATE_DLSL. */

/*! @brief Read current value of the uSDHC_PRES_STATE_DLSL field. */
#define BR_uSDHC_PRES_STATE_DLSL(x) (HW_uSDHC_PRES_STATE(x).B.DLSL)
/*@}*/

/*******************************************************************************
 * HW_uSDHC_PROT_CTRL - Protocol Control
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_PROT_CTRL - Protocol Control (RW)
 *
 * Reset value: 0x08800020U
 *
 * There are three cases to restart the transfer after stop at the block gap.
 * Which case is appropriate depends on whether the uSDHC issues a Suspend command
 * or the SD card accepts the Suspend command. If the Host Driver does not issue
 * a Suspend command, the Continue Request shall be used to restart the transfer.
 * If the Host Driver issues a Suspend command and the SD card accepts it, a
 * Resume command shall be used to restart the transfer. If the Host Driver issues a
 * Suspend command and the SD card does not accept it, the Continue Request
 * shall be used to restart the transfer. Any time Stop At Block Gap Request stops
 * the data transfer, the Host Driver shall wait for a Transfer Complete (in the
 * Interrupt Status register), before attempting to restart the transfer. When
 * restarting the data transfer by Continue Request, the Host Driver shall clear the
 * Stop At Block Gap Request before or simultaneously.
 */
typedef union _hw_usdhc_prot_ctrl
{
    uint32_t U;
    struct _hw_usdhc_prot_ctrl_bitfields
    {
        uint32_t LCTL : 1;             /*!< [0] LED Control */
        uint32_t DTW : 2;              /*!< [2:1] Data Transfer Width */
        uint32_t D3CD : 1;             /*!< [3] DATA3 as Card Detection Pin */
        uint32_t EMODE : 2;            /*!< [5:4] Endian Mode */
        uint32_t CDTL : 1;             /*!< [6] Card Detect Test Level */
        uint32_t CDSS : 1;             /*!< [7] Card Detect Signal Selection */
        uint32_t DMASEL : 2;           /*!< [9:8] DMA Select */
        uint32_t RESERVED0 : 6;        /*!< [15:10]  */
        uint32_t SABGREQ : 1;          /*!< [16] Stop At Block Gap Request */
        uint32_t CREQ : 1;             /*!< [17] Continue Request */
        uint32_t RWCTL : 1;            /*!< [18] Read Wait Control */
        uint32_t IABG : 1;             /*!< [19] Interrupt At Block Gap */
        uint32_t RD_DONE_NO_8CLK : 1;  /*!< [20]  */
        uint32_t RESERVED1 : 3;        /*!< [23:21]  */
        uint32_t WECINT : 1;           /*!< [24] Wakeup Event Enable On Card Interrupt
                                        * */
        uint32_t WECINS : 1;           /*!< [25] Wakeup Event Enable On SD Card
                                        * Insertion */
        uint32_t WECRM : 1;            /*!< [26] Wakeup Event Enable On SD Card Removal
                                        * */
        uint32_t BURST_LEN_EN : 3;     /*!< [29:27] BURST length enable for INCR,
                                        * INCR4 / INCR8 / INCR16, INCR4-WRAP / INCR8-WRAP / INCR16-WRAP */
        uint32_t NON_EXACT_BLK_RD : 1; /*!< [30]  */
        uint32_t RESERVED2 : 1;        /*!< [31]  */
    } B;
} hw_usdhc_prot_ctrl_t;

/*!
 * @name Constants and macros for entire uSDHC_PROT_CTRL register
 */
/*@{*/
#define HW_uSDHC_PROT_CTRL_ADDR(x) ((uintptr_t)(x) + 0x28U)

#define HW_uSDHC_PROT_CTRL(x)    (*(__IO hw_usdhc_prot_ctrl_t *) HW_uSDHC_PROT_CTRL_ADDR(x))
#define HW_uSDHC_PROT_CTRL_RD(x) (HW_uSDHC_PROT_CTRL(x).U)
#define HW_uSDHC_PROT_CTRL_WR(x, v) (HW_uSDHC_PROT_CTRL(x).U = (v))
#define HW_uSDHC_PROT_CTRL_SET(x, v) (HW_uSDHC_PROT_CTRL_WR(x, HW_uSDHC_PROT_CTRL_RD(x) |  (v)))
#define HW_uSDHC_PROT_CTRL_CLR(x, v) (HW_uSDHC_PROT_CTRL_WR(x, HW_uSDHC_PROT_CTRL_RD(x) & ~(v)))
#define HW_uSDHC_PROT_CTRL_TOG(x, v) (HW_uSDHC_PROT_CTRL_WR(x, HW_uSDHC_PROT_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_PROT_CTRL bitfields
 */

/*!
 * @name Register uSDHC_PROT_CTRL, field LCTL[0] (RW)
 *
 * This bit, fully controlled by the Host Driver, is used to caution the user
 * not to remove the card while the card is being accessed. If the software is
 * going to issue multiple SD commands, this bit can be set during all these
 * transactions. It is not necessary to change for each transaction. When the software
 * issues multiple SD commands, setting the bit once before the first command is
 * sufficient: it is not necessary to reset the bit between commands.
 *
 * Values:
 * - 1 - LED on
 * - 0 - LED off
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_LCTL (0U)       /*!< Bit position for uSDHC_PROT_CTRL_LCTL. */
#define BM_uSDHC_PROT_CTRL_LCTL (0x00000001U) /*!< Bit mask for uSDHC_PROT_CTRL_LCTL. */
#define BS_uSDHC_PROT_CTRL_LCTL (1U)       /*!< Bit field size in bits for uSDHC_PROT_CTRL_LCTL. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_LCTL field. */
#define BR_uSDHC_PROT_CTRL_LCTL(x) (HW_uSDHC_PROT_CTRL(x).B.LCTL)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_LCTL. */
#define BF_uSDHC_PROT_CTRL_LCTL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_LCTL) & BM_uSDHC_PROT_CTRL_LCTL)

/*! @brief Set the LCTL field to a new value. */
#define BW_uSDHC_PROT_CTRL_LCTL(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_LCTL) | BF_uSDHC_PROT_CTRL_LCTL(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field DTW[2:1] (RW)
 *
 * This bit selects the data width of the SD bus for a data transfer. The Host
 * Driver shall set it to match the data width of the card. Possible Data transfer
 * Width is 1-bit, 4-bits or 8-bits.
 *
 * Values:
 * - 10 - 8-bit mode
 * - 01 - 4-bit mode
 * - 00 - 1-bit mode
 * - 11 - Reserved
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_DTW (1U)        /*!< Bit position for uSDHC_PROT_CTRL_DTW. */
#define BM_uSDHC_PROT_CTRL_DTW (0x00000006U) /*!< Bit mask for uSDHC_PROT_CTRL_DTW. */
#define BS_uSDHC_PROT_CTRL_DTW (2U)        /*!< Bit field size in bits for uSDHC_PROT_CTRL_DTW. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_DTW field. */
#define BR_uSDHC_PROT_CTRL_DTW(x) (HW_uSDHC_PROT_CTRL(x).B.DTW)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_DTW. */
#define BF_uSDHC_PROT_CTRL_DTW(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_DTW) & BM_uSDHC_PROT_CTRL_DTW)

/*! @brief Set the DTW field to a new value. */
#define BW_uSDHC_PROT_CTRL_DTW(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_DTW) | BF_uSDHC_PROT_CTRL_DTW(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field D3CD[3] (RW)
 *
 * If this bit is set, DATA3 should be pulled down to act as a card detection
 * pin. Be cautious when using this feature, because DATA3 is also a chip-select
 * for the SPI mode. A pull-down on this pin and CMD0 may set the card into the SPI
 * mode, which the uSDHC does not support.
 *
 * Values:
 * - 1 - DATA3 as Card Detection Pin
 * - 0 - DATA3 does not monitor Card Insertion
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_D3CD (3U)       /*!< Bit position for uSDHC_PROT_CTRL_D3CD. */
#define BM_uSDHC_PROT_CTRL_D3CD (0x00000008U) /*!< Bit mask for uSDHC_PROT_CTRL_D3CD. */
#define BS_uSDHC_PROT_CTRL_D3CD (1U)       /*!< Bit field size in bits for uSDHC_PROT_CTRL_D3CD. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_D3CD field. */
#define BR_uSDHC_PROT_CTRL_D3CD(x) (HW_uSDHC_PROT_CTRL(x).B.D3CD)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_D3CD. */
#define BF_uSDHC_PROT_CTRL_D3CD(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_D3CD) & BM_uSDHC_PROT_CTRL_D3CD)

/*! @brief Set the D3CD field to a new value. */
#define BW_uSDHC_PROT_CTRL_D3CD(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_D3CD) | BF_uSDHC_PROT_CTRL_D3CD(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field EMODE[5:4] (RW)
 *
 * The uSDHC supports all three endian modes in data transfer. Refer to Data
 * BufferThe uSDHC uses one configurable data buffer to transfer data between the
 * system bus (IP Bus or AHB Bus) and the SD card in an optimized manner,
 * maximizing throughput between the two clock domains (IP peripheral clock and the master
 * clock). for more details.
 *
 * Values:
 * - 00 - Big Endian Mode
 * - 01 - Half Word Big Endian Mode
 * - 10 - Little Endian Mode
 * - 11 - Reserved
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_EMODE (4U)      /*!< Bit position for uSDHC_PROT_CTRL_EMODE. */
#define BM_uSDHC_PROT_CTRL_EMODE (0x00000030U) /*!< Bit mask for uSDHC_PROT_CTRL_EMODE. */
#define BS_uSDHC_PROT_CTRL_EMODE (2U)      /*!< Bit field size in bits for uSDHC_PROT_CTRL_EMODE. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_EMODE field. */
#define BR_uSDHC_PROT_CTRL_EMODE(x) (HW_uSDHC_PROT_CTRL(x).B.EMODE)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_EMODE. */
#define BF_uSDHC_PROT_CTRL_EMODE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_EMODE) & BM_uSDHC_PROT_CTRL_EMODE)

/*! @brief Set the EMODE field to a new value. */
#define BW_uSDHC_PROT_CTRL_EMODE(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_EMODE) | BF_uSDHC_PROT_CTRL_EMODE(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field CDTL[6] (RW)
 *
 * This is bit is enabled while the Card Detection Signal Selection is set to 1
 * and it indicates card insertion.
 *
 * Values:
 * - 1 - Card Detect Test Level is 1, card inserted
 * - 0 - Card Detect Test Level is 0, no card inserted
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_CDTL (6U)       /*!< Bit position for uSDHC_PROT_CTRL_CDTL. */
#define BM_uSDHC_PROT_CTRL_CDTL (0x00000040U) /*!< Bit mask for uSDHC_PROT_CTRL_CDTL. */
#define BS_uSDHC_PROT_CTRL_CDTL (1U)       /*!< Bit field size in bits for uSDHC_PROT_CTRL_CDTL. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_CDTL field. */
#define BR_uSDHC_PROT_CTRL_CDTL(x) (HW_uSDHC_PROT_CTRL(x).B.CDTL)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_CDTL. */
#define BF_uSDHC_PROT_CTRL_CDTL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_CDTL) & BM_uSDHC_PROT_CTRL_CDTL)

/*! @brief Set the CDTL field to a new value. */
#define BW_uSDHC_PROT_CTRL_CDTL(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_CDTL) | BF_uSDHC_PROT_CTRL_CDTL(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field CDSS[7] (RW)
 *
 * This bit selects the source for the card detection.
 *
 * Values:
 * - 1 - Card Detection Test Level is selected (for test purpose).
 * - 0 - Card Detection Level is selected (for normal purpose).
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_CDSS (7U)       /*!< Bit position for uSDHC_PROT_CTRL_CDSS. */
#define BM_uSDHC_PROT_CTRL_CDSS (0x00000080U) /*!< Bit mask for uSDHC_PROT_CTRL_CDSS. */
#define BS_uSDHC_PROT_CTRL_CDSS (1U)       /*!< Bit field size in bits for uSDHC_PROT_CTRL_CDSS. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_CDSS field. */
#define BR_uSDHC_PROT_CTRL_CDSS(x) (HW_uSDHC_PROT_CTRL(x).B.CDSS)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_CDSS. */
#define BF_uSDHC_PROT_CTRL_CDSS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_CDSS) & BM_uSDHC_PROT_CTRL_CDSS)

/*! @brief Set the CDSS field to a new value. */
#define BW_uSDHC_PROT_CTRL_CDSS(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_CDSS) | BF_uSDHC_PROT_CTRL_CDSS(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field DMASEL[9:8] (RW)
 *
 * This field is valid while DMA (SDMA or ADMA) is enabled and selects the DMA
 * operation.
 *
 * Values:
 * - 00 - No DMA or Simple DMA is selected
 * - 01 - ADMA1 is selected
 * - 10 - ADMA2 is selected
 * - 11 - reserved
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_DMASEL (8U)     /*!< Bit position for uSDHC_PROT_CTRL_DMASEL. */
#define BM_uSDHC_PROT_CTRL_DMASEL (0x00000300U) /*!< Bit mask for uSDHC_PROT_CTRL_DMASEL. */
#define BS_uSDHC_PROT_CTRL_DMASEL (2U)     /*!< Bit field size in bits for uSDHC_PROT_CTRL_DMASEL. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_DMASEL field. */
#define BR_uSDHC_PROT_CTRL_DMASEL(x) (HW_uSDHC_PROT_CTRL(x).B.DMASEL)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_DMASEL. */
#define BF_uSDHC_PROT_CTRL_DMASEL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_DMASEL) & BM_uSDHC_PROT_CTRL_DMASEL)

/*! @brief Set the DMASEL field to a new value. */
#define BW_uSDHC_PROT_CTRL_DMASEL(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_DMASEL) | BF_uSDHC_PROT_CTRL_DMASEL(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field SABGREQ[16] (RW)
 *
 * This bit is used to stop executing a transaction at the next block gap for
 * both DMA and non-DMA transfers. Until the Transfer Complete is set to 1,
 * indicating a transfer completion, the Host Driver shall leave this bit set to 1.
 * Clearing both the Stop At Block Gap Request and Continue Request does not cause
 * the transaction to restart. Read Wait is used to stop the read transaction at
 * the block gap. The uSDHC will honor the Stop At Block Gap Request for write
 * transfers, but for read transfers it requires that the SDIO card support Read
 * Wait. Therefore, the Host Driver shall not set this bit during read transfers
 * unless the SDIO card supports Read Wait and has set the Read Wait Control to 1,
 * otherwise the uSDHC will stop the SD bus clock to pause the read operation
 * during block gap. In the case of write transfers in which the Host Driver writes
 * data to the Data Port register, the Host Driver shall set this bit after all
 * block data is written. If this bit is set to 1, the Host Driver shall not write
 * data to the Data Port register after a block is sent. Once this bit is set, the
 * Host Driver shall not clear this bit before the Transfer Complete bit in
 * Interrupt Status Register is set, otherwise the uSDHCs behavior is undefined. This
 * bit effects Read Transfer Active, Write Transfer Active, DATA Line Active and
 * Command Inhibit (DATA) in the Present State register.
 *
 * Values:
 * - 1 - Stop
 * - 0 - Transfer
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_SABGREQ (16U)   /*!< Bit position for uSDHC_PROT_CTRL_SABGREQ. */
#define BM_uSDHC_PROT_CTRL_SABGREQ (0x00010000U) /*!< Bit mask for uSDHC_PROT_CTRL_SABGREQ. */
#define BS_uSDHC_PROT_CTRL_SABGREQ (1U)    /*!< Bit field size in bits for uSDHC_PROT_CTRL_SABGREQ. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_SABGREQ field. */
#define BR_uSDHC_PROT_CTRL_SABGREQ(x) (HW_uSDHC_PROT_CTRL(x).B.SABGREQ)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_SABGREQ. */
#define BF_uSDHC_PROT_CTRL_SABGREQ(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_SABGREQ) & BM_uSDHC_PROT_CTRL_SABGREQ)

/*! @brief Set the SABGREQ field to a new value. */
#define BW_uSDHC_PROT_CTRL_SABGREQ(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_SABGREQ) | BF_uSDHC_PROT_CTRL_SABGREQ(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field CREQ[17] (RW)
 *
 * This bit is used to restart a transaction which was stopped using the Stop At
 * Block Gap Request. When a Suspend operation is not accepted by the card, it
 * is also by setting this bit to restart the paused transfer. To cancel stop at
 * the block gap, set Stop At Block Gap Request to 0 and set this bit to 1 to
 * restart the transfer. The uSDHC automatically clears this bit, therefore it is not
 * necessary for the Host Driver to set this bit to 0. If both Stop At Block Gap
 * Request and this bit are 1, the continue request is ignored.
 *
 * Values:
 * - 1 - Restart
 * - 0 - No effect
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_CREQ (17U)      /*!< Bit position for uSDHC_PROT_CTRL_CREQ. */
#define BM_uSDHC_PROT_CTRL_CREQ (0x00020000U) /*!< Bit mask for uSDHC_PROT_CTRL_CREQ. */
#define BS_uSDHC_PROT_CTRL_CREQ (1U)       /*!< Bit field size in bits for uSDHC_PROT_CTRL_CREQ. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_CREQ field. */
#define BR_uSDHC_PROT_CTRL_CREQ(x) (HW_uSDHC_PROT_CTRL(x).B.CREQ)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_CREQ. */
#define BF_uSDHC_PROT_CTRL_CREQ(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_CREQ) & BM_uSDHC_PROT_CTRL_CREQ)

/*! @brief Set the CREQ field to a new value. */
#define BW_uSDHC_PROT_CTRL_CREQ(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_CREQ) | BF_uSDHC_PROT_CTRL_CREQ(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field RWCTL[18] (RW)
 *
 * The read wait function is optional for SDIO cards. If the card supports read
 * wait, set this bit to enable use of the read wait protocol to stop read data
 * using the DATA2 line. Otherwise the uSDHC has to stop the SD Clock to hold read
 * data, which restricts commands generation. When the Host Driver detects an
 * SDIO card insertion, it shall set this bit according to the CCCR of the card. If
 * the card does not support read wait, this bit shall never be set to 1,
 * otherwise DATA line conflicts may occur. If this bit is set to 0, stop at block gap
 * during read operation is also supported, but the uSDHC will stop the SD Clock
 * to pause reading operation.
 *
 * Values:
 * - 1 - Enable Read Wait Control, and assert Read Wait without stopping SD
 *     Clock at block gap when SABGREQ bit is set
 * - 0 - Disable Read Wait Control, and stop SD Clock at block gap when SABGREQ
 *     bit is set
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_RWCTL (18U)     /*!< Bit position for uSDHC_PROT_CTRL_RWCTL. */
#define BM_uSDHC_PROT_CTRL_RWCTL (0x00040000U) /*!< Bit mask for uSDHC_PROT_CTRL_RWCTL. */
#define BS_uSDHC_PROT_CTRL_RWCTL (1U)      /*!< Bit field size in bits for uSDHC_PROT_CTRL_RWCTL. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_RWCTL field. */
#define BR_uSDHC_PROT_CTRL_RWCTL(x) (HW_uSDHC_PROT_CTRL(x).B.RWCTL)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_RWCTL. */
#define BF_uSDHC_PROT_CTRL_RWCTL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_RWCTL) & BM_uSDHC_PROT_CTRL_RWCTL)

/*! @brief Set the RWCTL field to a new value. */
#define BW_uSDHC_PROT_CTRL_RWCTL(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_RWCTL) | BF_uSDHC_PROT_CTRL_RWCTL(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field IABG[19] (RW)
 *
 * This bit is valid only in 4-bit mode, of the SDIO card, and selects a sample
 * point in the interrupt cycle. Setting to 1 enables interrupt detection at the
 * block gap for a multiple block transfer. Setting to 0 disables interrupt
 * detection during a multiple block transfer. If the SDIO card cannot signal an
 * interrupt during a multiple block transfer, this bit should be set to 0 to avoid an
 * inadvertent interrupt. When the Host Driver detects an SDIO card insertion,
 * it shall set this bit according to the CCCR of the card.
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Disabled
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_IABG (19U)      /*!< Bit position for uSDHC_PROT_CTRL_IABG. */
#define BM_uSDHC_PROT_CTRL_IABG (0x00080000U) /*!< Bit mask for uSDHC_PROT_CTRL_IABG. */
#define BS_uSDHC_PROT_CTRL_IABG (1U)       /*!< Bit field size in bits for uSDHC_PROT_CTRL_IABG. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_IABG field. */
#define BR_uSDHC_PROT_CTRL_IABG(x) (HW_uSDHC_PROT_CTRL(x).B.IABG)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_IABG. */
#define BF_uSDHC_PROT_CTRL_IABG(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_IABG) & BM_uSDHC_PROT_CTRL_IABG)

/*! @brief Set the IABG field to a new value. */
#define BW_uSDHC_PROT_CTRL_IABG(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_IABG) | BF_uSDHC_PROT_CTRL_IABG(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field RD_DONE_NO_8CLK[20] (RW)
 *
 * Read done no 8 clock: According to the SD/MMC spec, for read data
 * transaction, 8 clocks are needed after the end bit of the last data block. So, by
 * default(RD_DONE_NO_8CLK=0), 8 clocks will be active after the end bit of the last
 * read data transaction. However, this 8 clocks should not be active if user wants
 * to use stop at block gap(include the auto stop at block gap in boot mode)
 * feature for read and the RWCTL bit(bit18) is not enabled. In this case, software
 * should set RD_DONE_NO_8CLK to avoid this 8 clocks. Otherwise, the device may
 * send extra data to uSDHC while uSDHC ignores these data. In a summary, this bit
 * should be set only if the use case needs to use stop at block gap feature
 * while the device can't support the read wait feature.
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK (20U) /*!< Bit position for uSDHC_PROT_CTRL_RD_DONE_NO_8CLK. */
#define BM_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK (0x00100000U) /*!< Bit mask for uSDHC_PROT_CTRL_RD_DONE_NO_8CLK. */
#define BS_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK (1U) /*!< Bit field size in bits for uSDHC_PROT_CTRL_RD_DONE_NO_8CLK. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_RD_DONE_NO_8CLK field. */
#define BR_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK(x) (HW_uSDHC_PROT_CTRL(x).B.RD_DONE_NO_8CLK)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_RD_DONE_NO_8CLK. */
#define BF_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK) & BM_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK)

/*! @brief Set the RD_DONE_NO_8CLK field to a new value. */
#define BW_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK) | BF_uSDHC_PROT_CTRL_RD_DONE_NO_8CLK(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field WECINT[24] (RW)
 *
 * This bit enables a wakeup event, via a Card Interrupt, in the Interrupt
 * Status register. This bit can be set to 1 if FN_WUS (Wake Up Support) in CIS is set
 * to 1. When this bit is set, the Card Interrupt Status and the uSDHC interrupt
 * can be asserted without CLK toggling. When the wakeup feature is not enabled,
 * the CLK must be active in order to assert the Card Interrupt Status and the
 * uSDHC interrupt.
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_WECINT (24U)    /*!< Bit position for uSDHC_PROT_CTRL_WECINT. */
#define BM_uSDHC_PROT_CTRL_WECINT (0x01000000U) /*!< Bit mask for uSDHC_PROT_CTRL_WECINT. */
#define BS_uSDHC_PROT_CTRL_WECINT (1U)     /*!< Bit field size in bits for uSDHC_PROT_CTRL_WECINT. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_WECINT field. */
#define BR_uSDHC_PROT_CTRL_WECINT(x) (HW_uSDHC_PROT_CTRL(x).B.WECINT)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_WECINT. */
#define BF_uSDHC_PROT_CTRL_WECINT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_WECINT) & BM_uSDHC_PROT_CTRL_WECINT)

/*! @brief Set the WECINT field to a new value. */
#define BW_uSDHC_PROT_CTRL_WECINT(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_WECINT) | BF_uSDHC_PROT_CTRL_WECINT(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field WECINS[25] (RW)
 *
 * This bit enables a wakeup event, via a Card Insertion, in the Interrupt
 * Status register. FN_WUS (Wake Up Support) in CIS does not effect this bit. When
 * this bit is set, the Card Insertion Status and the uSDHC interrupt can be
 * asserted without CLK toggling. When the wakeup feature is not enabled, the CLK must
 * be active in order to assert the Card Insertion Status and the uSDHC interrupt.
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_WECINS (25U)    /*!< Bit position for uSDHC_PROT_CTRL_WECINS. */
#define BM_uSDHC_PROT_CTRL_WECINS (0x02000000U) /*!< Bit mask for uSDHC_PROT_CTRL_WECINS. */
#define BS_uSDHC_PROT_CTRL_WECINS (1U)     /*!< Bit field size in bits for uSDHC_PROT_CTRL_WECINS. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_WECINS field. */
#define BR_uSDHC_PROT_CTRL_WECINS(x) (HW_uSDHC_PROT_CTRL(x).B.WECINS)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_WECINS. */
#define BF_uSDHC_PROT_CTRL_WECINS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_WECINS) & BM_uSDHC_PROT_CTRL_WECINS)

/*! @brief Set the WECINS field to a new value. */
#define BW_uSDHC_PROT_CTRL_WECINS(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_WECINS) | BF_uSDHC_PROT_CTRL_WECINS(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field WECRM[26] (RW)
 *
 * This bit enables a wakeup event, via a Card Removal, in the Interrupt Status
 * register. FN_WUS (Wake Up Support) in CIS does not effect this bit. When this
 * bit is set, the Card Removal Status and the uSDHC interrupt can be asserted
 * without CLK toggling. When the wakeup feature is not enabled, the CLK must be
 * active in order to assert the Card Removal Status and the uSDHC interrupt.
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_WECRM (26U)     /*!< Bit position for uSDHC_PROT_CTRL_WECRM. */
#define BM_uSDHC_PROT_CTRL_WECRM (0x04000000U) /*!< Bit mask for uSDHC_PROT_CTRL_WECRM. */
#define BS_uSDHC_PROT_CTRL_WECRM (1U)      /*!< Bit field size in bits for uSDHC_PROT_CTRL_WECRM. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_WECRM field. */
#define BR_uSDHC_PROT_CTRL_WECRM(x) (HW_uSDHC_PROT_CTRL(x).B.WECRM)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_WECRM. */
#define BF_uSDHC_PROT_CTRL_WECRM(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_WECRM) & BM_uSDHC_PROT_CTRL_WECRM)

/*! @brief Set the WECRM field to a new value. */
#define BW_uSDHC_PROT_CTRL_WECRM(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_WECRM) | BF_uSDHC_PROT_CTRL_WECRM(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field BURST_LEN_EN[29:27] (RW)
 *
 * This is used to enable / disable the burst length for the external AHB2AXI
 * bridge. It is useful especially for INCR transfer because without burst length
 * indicator, the AHB2AXI bridge does not know the burst length in advance.
 * Without burst length indicator, AHB INCR transfers can only be converted to SINGLEs
 * on the AXI side.
 *
 * Values:
 * - xx1 - Burst length is enabled for INCR
 * - x1x - Burst length is enabled for INCR4 / INCR8 / INCR16
 * - 1xx - Burst length is enabled for INCR4-WRAP / INCR8-WRAP / INCR16-WRAP
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_BURST_LEN_EN (27U) /*!< Bit position for uSDHC_PROT_CTRL_BURST_LEN_EN. */
#define BM_uSDHC_PROT_CTRL_BURST_LEN_EN (0x38000000U) /*!< Bit mask for uSDHC_PROT_CTRL_BURST_LEN_EN. */
#define BS_uSDHC_PROT_CTRL_BURST_LEN_EN (3U) /*!< Bit field size in bits for uSDHC_PROT_CTRL_BURST_LEN_EN. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_BURST_LEN_EN field. */
#define BR_uSDHC_PROT_CTRL_BURST_LEN_EN(x) (HW_uSDHC_PROT_CTRL(x).B.BURST_LEN_EN)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_BURST_LEN_EN. */
#define BF_uSDHC_PROT_CTRL_BURST_LEN_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_BURST_LEN_EN) & BM_uSDHC_PROT_CTRL_BURST_LEN_EN)

/*! @brief Set the BURST_LEN_EN field to a new value. */
#define BW_uSDHC_PROT_CTRL_BURST_LEN_EN(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_BURST_LEN_EN) | BF_uSDHC_PROT_CTRL_BURST_LEN_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_PROT_CTRL, field NON_EXACT_BLK_RD[30] (RW)
 *
 * Current block read is non-exact block read. It is only used for SDIO.
 *
 * Values:
 * - 1 - The block read is non-exact block read. Host driver needs to issue
 *     abort command to terminate this multi-block read.
 * - 0 - The block read is exact block read. Host driver doesn't need to issue
 *     abort command to terminate this multi-block read.
 */
/*@{*/
#define BP_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD (30U) /*!< Bit position for uSDHC_PROT_CTRL_NON_EXACT_BLK_RD. */
#define BM_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD (0x40000000U) /*!< Bit mask for uSDHC_PROT_CTRL_NON_EXACT_BLK_RD. */
#define BS_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD (1U) /*!< Bit field size in bits for uSDHC_PROT_CTRL_NON_EXACT_BLK_RD. */

/*! @brief Read current value of the uSDHC_PROT_CTRL_NON_EXACT_BLK_RD field. */
#define BR_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD(x) (HW_uSDHC_PROT_CTRL(x).B.NON_EXACT_BLK_RD)

/*! @brief Format value for bitfield uSDHC_PROT_CTRL_NON_EXACT_BLK_RD. */
#define BF_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD) & BM_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD)

/*! @brief Set the NON_EXACT_BLK_RD field to a new value. */
#define BW_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD(x, v) (HW_uSDHC_PROT_CTRL_WR(x, (HW_uSDHC_PROT_CTRL_RD(x) & ~BM_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD) | BF_uSDHC_PROT_CTRL_NON_EXACT_BLK_RD(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_SYS_CTRL - System Control
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_SYS_CTRL - System Control (RW)
 *
 * Reset value: 0x8080800FU
 */
typedef union _hw_usdhc_sys_ctrl
{
    uint32_t U;
    struct _hw_usdhc_sys_ctrl_bitfields
    {
        uint32_t RESERVED0 : 4;        /*!< [3:0]  */
        uint32_t DVS : 4;              /*!< [7:4] Divisor */
        uint32_t SDCLKFS : 8;          /*!< [15:8] SDCLK Frequency Select */
        uint32_t DTOCV : 4;            /*!< [19:16] Data Timeout Counter Value */
        uint32_t RESERVED1 : 3;        /*!< [22:20]  */
        uint32_t IPP_RST_N : 1;        /*!< [23]  */
        uint32_t RSTA : 1;             /*!< [24] Software Reset For ALL */
        uint32_t RSTC : 1;             /*!< [25] Software Reset For CMD Line */
        uint32_t RSTD : 1;             /*!< [26] Software Reset For DATA Line */
        uint32_t INITA : 1;            /*!< [27] Initialization Active */
        uint32_t RSTT : 1;             /*!< [28] Reset Tuning */
        uint32_t RESERVED2 : 3;        /*!< [31:29]  */
    } B;
} hw_usdhc_sys_ctrl_t;

/*!
 * @name Constants and macros for entire uSDHC_SYS_CTRL register
 */
/*@{*/
#define HW_uSDHC_SYS_CTRL_ADDR(x) ((uintptr_t)(x) + 0x2CU)

#define HW_uSDHC_SYS_CTRL(x)     (*(__IO hw_usdhc_sys_ctrl_t *) HW_uSDHC_SYS_CTRL_ADDR(x))
#define HW_uSDHC_SYS_CTRL_RD(x)  (HW_uSDHC_SYS_CTRL(x).U)
#define HW_uSDHC_SYS_CTRL_WR(x, v) (HW_uSDHC_SYS_CTRL(x).U = (v))
#define HW_uSDHC_SYS_CTRL_SET(x, v) (HW_uSDHC_SYS_CTRL_WR(x, HW_uSDHC_SYS_CTRL_RD(x) |  (v)))
#define HW_uSDHC_SYS_CTRL_CLR(x, v) (HW_uSDHC_SYS_CTRL_WR(x, HW_uSDHC_SYS_CTRL_RD(x) & ~(v)))
#define HW_uSDHC_SYS_CTRL_TOG(x, v) (HW_uSDHC_SYS_CTRL_WR(x, HW_uSDHC_SYS_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_SYS_CTRL bitfields
 */

/*!
 * @name Register uSDHC_SYS_CTRL, field DVS[7:4] (RW)
 *
 * This register is used to provide a more exact divisor to generate the desired
 * SD clock frequency. Note the divider can even support odd divisors without
 * deterioration of duty cycle. Before changing clock divisor value(SDCLKFS or
 * DVS), Host Driver should make sure the SDSTB bit is high. The setting are as
 * following:
 *
 * Values:
 * - 0000 - Divide-by-1
 * - 0001 - Divide-by-2
 * - 1110 - Divide-by-15
 * - 1111 - Divide-by-16
 */
/*@{*/
#define BP_uSDHC_SYS_CTRL_DVS (4U)         /*!< Bit position for uSDHC_SYS_CTRL_DVS. */
#define BM_uSDHC_SYS_CTRL_DVS (0x000000F0U) /*!< Bit mask for uSDHC_SYS_CTRL_DVS. */
#define BS_uSDHC_SYS_CTRL_DVS (4U)         /*!< Bit field size in bits for uSDHC_SYS_CTRL_DVS. */

/*! @brief Read current value of the uSDHC_SYS_CTRL_DVS field. */
#define BR_uSDHC_SYS_CTRL_DVS(x) (HW_uSDHC_SYS_CTRL(x).B.DVS)

/*! @brief Format value for bitfield uSDHC_SYS_CTRL_DVS. */
#define BF_uSDHC_SYS_CTRL_DVS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_SYS_CTRL_DVS) & BM_uSDHC_SYS_CTRL_DVS)

/*! @brief Set the DVS field to a new value. */
#define BW_uSDHC_SYS_CTRL_DVS(x, v) (HW_uSDHC_SYS_CTRL_WR(x, (HW_uSDHC_SYS_CTRL_RD(x) & ~BM_uSDHC_SYS_CTRL_DVS) | BF_uSDHC_SYS_CTRL_DVS(v)))
/*@}*/

/*!
 * @name Register uSDHC_SYS_CTRL, field SDCLKFS[15:8] (RW)
 *
 * This register is used to select the frequency of the SDCLK pin. The frequency
 * is not programmed directly, rather this register holds the prescaler (this
 * register) and divisor (next register) of the Base Clock Frequency register. I n
 * Single Data Rate mode(DDR_EN bit of MIXERCTRL is '0') Only the following
 * settings are allowed: 80h) Base clock divided by 256 40h) Base clock divided by 128
 * 20h) Base clock divided by 64 10h) Base clock divided by 32 08h) Base clock
 * divided by 16 04h) Base clock divided by 8 02h) Base clock divided by 4 01h)
 * Base clock divided by 2 00h) Base clock divided by 1 W hile in Dual Data Rate
 * mode(DDR_EN bit of MIXERCTRL is '1') Only the following settings are allowed:
 * 80h) Base clock divided by 512 40h) Base clock divided by 256 20h) Base clock
 * divided by 128 10h) Base clock divided by 64 08h) Base clock divided by 32 04h)
 * Base clock divided by 16 02h) Base clock divided by 8 01h) Base clock divided
 * by 4 00h) Base clock divided by 2 W hen S/W changes the DDR_EN bit, SDCLKFS
 * may need to be changed also ! In Single Data Rate mode, setting 00h bypasses the
 * frequency prescaler of the SD Clock. Multiple bits must not be set, or the
 * behavior of this prescaler is undefined. The two default divider values can be
 * calculated by the frequency of ipg_perclk and the following Divisor bits. The
 * frequency of SDCLK is set by the following formula: Clock Frequency = (Base
 * Clock) / (prescaler x divisor) For example, in Single Data Rate mode, if the Base
 * Clock Frequency is 96 MHz, and the target frequency is 25 MHz, then choosing
 * the prescaler value of 01h and divisor value of 1h will yield 24 MHz, which is
 * the nearest frequency less than or equal to the target. Similarly, to
 * approach a clock value of 400 kHz, the prescaler value of 08h and divisor value of eh
 * yields the exact clock value of 400 kHz. The reset value of this bit field is
 * 80h, so if the input Base Clock (ipg_perclk) is about 96 MHz, the default SD
 * Clock after reset is 375 kHz. According to the SD Physical Specification
 * Version 1.1 and the SDIO Card Specification Version 1.2, the maximum SD Clock
 * frequency is 50 MHz and shall never exceed this limit. B efore changing clock
 * divisor value(SDCLKFS or DVS), Host Driver should make sure the SDSTB bit is high.
 * If setting SDCLKFS and DVS can generate same clock frequency,(For example, in
 * SDR mode, SDCLKFS = 01h is same as DVS = 01h.) SDCLKFS is highly recommended.
 */
/*@{*/
#define BP_uSDHC_SYS_CTRL_SDCLKFS (8U)     /*!< Bit position for uSDHC_SYS_CTRL_SDCLKFS. */
#define BM_uSDHC_SYS_CTRL_SDCLKFS (0x0000FF00U) /*!< Bit mask for uSDHC_SYS_CTRL_SDCLKFS. */
#define BS_uSDHC_SYS_CTRL_SDCLKFS (8U)     /*!< Bit field size in bits for uSDHC_SYS_CTRL_SDCLKFS. */

/*! @brief Read current value of the uSDHC_SYS_CTRL_SDCLKFS field. */
#define BR_uSDHC_SYS_CTRL_SDCLKFS(x) (HW_uSDHC_SYS_CTRL(x).B.SDCLKFS)

/*! @brief Format value for bitfield uSDHC_SYS_CTRL_SDCLKFS. */
#define BF_uSDHC_SYS_CTRL_SDCLKFS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_SYS_CTRL_SDCLKFS) & BM_uSDHC_SYS_CTRL_SDCLKFS)

/*! @brief Set the SDCLKFS field to a new value. */
#define BW_uSDHC_SYS_CTRL_SDCLKFS(x, v) (HW_uSDHC_SYS_CTRL_WR(x, (HW_uSDHC_SYS_CTRL_RD(x) & ~BM_uSDHC_SYS_CTRL_SDCLKFS) | BF_uSDHC_SYS_CTRL_SDCLKFS(v)))
/*@}*/

/*!
 * @name Register uSDHC_SYS_CTRL, field DTOCV[19:16] (RW)
 *
 * This value determines the interval by which DAT line timeouts are detected.
 * Refer to the Data Timeout Error bit in the Interrupt Status register for
 * information on factors that dictate time-out generation. Time-out clock frequency
 * will be generated by dividing the base clock SDCLK value by this value. The Host
 * Driver can clear the Data Timeout Error Status Enable (in the Interrupt
 * Status Enable register) to prevent inadvertent time-out events.
 *
 * Values:
 * - 1111 - SDCLK x 2 28
 * - 1110 - SDCLK x 2 2 7
 * - 0001 - SDCLK x 2 14
 * - 0000 - SDCLK x 2 1 3
 */
/*@{*/
#define BP_uSDHC_SYS_CTRL_DTOCV (16U)      /*!< Bit position for uSDHC_SYS_CTRL_DTOCV. */
#define BM_uSDHC_SYS_CTRL_DTOCV (0x000F0000U) /*!< Bit mask for uSDHC_SYS_CTRL_DTOCV. */
#define BS_uSDHC_SYS_CTRL_DTOCV (4U)       /*!< Bit field size in bits for uSDHC_SYS_CTRL_DTOCV. */

/*! @brief Read current value of the uSDHC_SYS_CTRL_DTOCV field. */
#define BR_uSDHC_SYS_CTRL_DTOCV(x) (HW_uSDHC_SYS_CTRL(x).B.DTOCV)

/*! @brief Format value for bitfield uSDHC_SYS_CTRL_DTOCV. */
#define BF_uSDHC_SYS_CTRL_DTOCV(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_SYS_CTRL_DTOCV) & BM_uSDHC_SYS_CTRL_DTOCV)

/*! @brief Set the DTOCV field to a new value. */
#define BW_uSDHC_SYS_CTRL_DTOCV(x, v) (HW_uSDHC_SYS_CTRL_WR(x, (HW_uSDHC_SYS_CTRL_RD(x) & ~BM_uSDHC_SYS_CTRL_DTOCV) | BF_uSDHC_SYS_CTRL_DTOCV(v)))
/*@}*/

/*!
 * @name Register uSDHC_SYS_CTRL, field IPP_RST_N[23] (RW)
 *
 * This register's value will be output to CARD from pad directly for hardware
 * reset of the card if the card supports this feature.
 */
/*@{*/
#define BP_uSDHC_SYS_CTRL_IPP_RST_N (23U)  /*!< Bit position for uSDHC_SYS_CTRL_IPP_RST_N. */
#define BM_uSDHC_SYS_CTRL_IPP_RST_N (0x00800000U) /*!< Bit mask for uSDHC_SYS_CTRL_IPP_RST_N. */
#define BS_uSDHC_SYS_CTRL_IPP_RST_N (1U)   /*!< Bit field size in bits for uSDHC_SYS_CTRL_IPP_RST_N. */

/*! @brief Read current value of the uSDHC_SYS_CTRL_IPP_RST_N field. */
#define BR_uSDHC_SYS_CTRL_IPP_RST_N(x) (HW_uSDHC_SYS_CTRL(x).B.IPP_RST_N)

/*! @brief Format value for bitfield uSDHC_SYS_CTRL_IPP_RST_N. */
#define BF_uSDHC_SYS_CTRL_IPP_RST_N(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_SYS_CTRL_IPP_RST_N) & BM_uSDHC_SYS_CTRL_IPP_RST_N)

/*! @brief Set the IPP_RST_N field to a new value. */
#define BW_uSDHC_SYS_CTRL_IPP_RST_N(x, v) (HW_uSDHC_SYS_CTRL_WR(x, (HW_uSDHC_SYS_CTRL_RD(x) & ~BM_uSDHC_SYS_CTRL_IPP_RST_N) | BF_uSDHC_SYS_CTRL_IPP_RST_N(v)))
/*@}*/

/*!
 * @name Register uSDHC_SYS_CTRL, field RSTA[24] (RW)
 *
 * This reset effects the entire Host Controller except for the card detection
 * circuit. Register bits of type ROC, RW, RW1C, RWAC are cleared. During its
 * initialization, the Host Driver shall set this bit to 1 to reset the uSDHC. The
 * uSDHC shall reset this bit to 0 when the capabilities registers are valid and
 * the Host Driver can read them. Additional use of Software Reset For All does not
 * affect the value of the Capabilities registers. After this bit is set, it is
 * recommended that the Host Driver reset the external card and re-initialize it.
 * After this bit is set, SW should wait for self-clear. In tuning process,
 * after every CMD19 is finished, this bit will be set to retest the uSDHC. When
 * reset, SW must make sure there is no incomplete data transferring. If there is
 * data transfer going on, SW need wait TC or DC uSDHC_INT_STATUS register is set.
 *
 * Values:
 * - 1 - Reset
 * - 0 - No Reset
 */
/*@{*/
#define BP_uSDHC_SYS_CTRL_RSTA (24U)       /*!< Bit position for uSDHC_SYS_CTRL_RSTA. */
#define BM_uSDHC_SYS_CTRL_RSTA (0x01000000U) /*!< Bit mask for uSDHC_SYS_CTRL_RSTA. */
#define BS_uSDHC_SYS_CTRL_RSTA (1U)        /*!< Bit field size in bits for uSDHC_SYS_CTRL_RSTA. */

/*! @brief Read current value of the uSDHC_SYS_CTRL_RSTA field. */
#define BR_uSDHC_SYS_CTRL_RSTA(x) (HW_uSDHC_SYS_CTRL(x).B.RSTA)

/*! @brief Format value for bitfield uSDHC_SYS_CTRL_RSTA. */
#define BF_uSDHC_SYS_CTRL_RSTA(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_SYS_CTRL_RSTA) & BM_uSDHC_SYS_CTRL_RSTA)

/*! @brief Set the RSTA field to a new value. */
#define BW_uSDHC_SYS_CTRL_RSTA(x, v) (HW_uSDHC_SYS_CTRL_WR(x, (HW_uSDHC_SYS_CTRL_RD(x) & ~BM_uSDHC_SYS_CTRL_RSTA) | BF_uSDHC_SYS_CTRL_RSTA(v)))
/*@}*/

/*!
 * @name Register uSDHC_SYS_CTRL, field RSTC[25] (RW)
 *
 * Only part of the command circuit is reset. After this bit is set, SW waits
 * for self-clear. The following registers and bits are cleared by this bit:
 * Present State register Command Inhibit (CMD) Interrupt Status register Command
 * Complete
 *
 * Values:
 * - 1 - Reset
 * - 0 - No Reset
 */
/*@{*/
#define BP_uSDHC_SYS_CTRL_RSTC (25U)       /*!< Bit position for uSDHC_SYS_CTRL_RSTC. */
#define BM_uSDHC_SYS_CTRL_RSTC (0x02000000U) /*!< Bit mask for uSDHC_SYS_CTRL_RSTC. */
#define BS_uSDHC_SYS_CTRL_RSTC (1U)        /*!< Bit field size in bits for uSDHC_SYS_CTRL_RSTC. */

/*! @brief Read current value of the uSDHC_SYS_CTRL_RSTC field. */
#define BR_uSDHC_SYS_CTRL_RSTC(x) (HW_uSDHC_SYS_CTRL(x).B.RSTC)

/*! @brief Format value for bitfield uSDHC_SYS_CTRL_RSTC. */
#define BF_uSDHC_SYS_CTRL_RSTC(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_SYS_CTRL_RSTC) & BM_uSDHC_SYS_CTRL_RSTC)

/*! @brief Set the RSTC field to a new value. */
#define BW_uSDHC_SYS_CTRL_RSTC(x, v) (HW_uSDHC_SYS_CTRL_WR(x, (HW_uSDHC_SYS_CTRL_RD(x) & ~BM_uSDHC_SYS_CTRL_RSTC) | BF_uSDHC_SYS_CTRL_RSTC(v)))
/*@}*/

/*!
 * @name Register uSDHC_SYS_CTRL, field RSTD[26] (RW)
 *
 * Only part of the data circuit is reset. DMA circuit is also reset. After this
 * bit is set, SW waits for self-clear. The following registers and bits are
 * cleared by this bit: Data Port register Buffer is cleared and initialized.
 * Present State register Buffer Read Enable Buffer Write Enable Read Transfer Active
 * Write Transfer Active DATA Line Active Command Inhibit (DATA) Protocol Control
 * register Continue Request Stop At Block Gap Request Interrupt Status register
 * Buffer Read Ready Buffer Write Ready DMA Interrupt Block Gap Event Transfer
 * Complete When reset, SW must make sure there is no incomplete data transferring.
 * If there is data transfer going on, SW need wait TC or DC uSDHC_INT_STATUS
 * register is set.
 *
 * Values:
 * - 1 - Reset
 * - 0 - No Reset
 */
/*@{*/
#define BP_uSDHC_SYS_CTRL_RSTD (26U)       /*!< Bit position for uSDHC_SYS_CTRL_RSTD. */
#define BM_uSDHC_SYS_CTRL_RSTD (0x04000000U) /*!< Bit mask for uSDHC_SYS_CTRL_RSTD. */
#define BS_uSDHC_SYS_CTRL_RSTD (1U)        /*!< Bit field size in bits for uSDHC_SYS_CTRL_RSTD. */

/*! @brief Read current value of the uSDHC_SYS_CTRL_RSTD field. */
#define BR_uSDHC_SYS_CTRL_RSTD(x) (HW_uSDHC_SYS_CTRL(x).B.RSTD)

/*! @brief Format value for bitfield uSDHC_SYS_CTRL_RSTD. */
#define BF_uSDHC_SYS_CTRL_RSTD(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_SYS_CTRL_RSTD) & BM_uSDHC_SYS_CTRL_RSTD)

/*! @brief Set the RSTD field to a new value. */
#define BW_uSDHC_SYS_CTRL_RSTD(x, v) (HW_uSDHC_SYS_CTRL_WR(x, (HW_uSDHC_SYS_CTRL_RD(x) & ~BM_uSDHC_SYS_CTRL_RSTD) | BF_uSDHC_SYS_CTRL_RSTD(v)))
/*@}*/

/*!
 * @name Register uSDHC_SYS_CTRL, field INITA[27] (RW)
 *
 * When this bit is set, 80 SD-Clocks are sent to the card. After the 80 clocks
 * are sent, this bit is self cleared. This bit is very useful during the card
 * power-up period when 74 SD-Clocks are needed and the clock auto gating feature
 * is enabled. Writing 1 to this bit when this bit is already 1 has no effect.
 * Writing 0 to this bit at any time has no effect. When either of the CIHB and
 * CDIHB bits in the Present State Register are set, writing 1 to this bit is ignored
 * (i.e. when command line or data lines are active, write to this bit is not
 * allowed). On the otherhand, when this bit is set, i.e., during intialization
 * active period, it is allowed to issue command, and the command bit stream will
 * appear on the CMD pad after all 80 clock cycles are done. So when this command
 * ends, the driver can make sure the 80 clock cycles are sent out. This is very
 * useful when the driver needs send 80 cycles to the card and does not want to
 * wait till this bit is self cleared.
 */
/*@{*/
#define BP_uSDHC_SYS_CTRL_INITA (27U)      /*!< Bit position for uSDHC_SYS_CTRL_INITA. */
#define BM_uSDHC_SYS_CTRL_INITA (0x08000000U) /*!< Bit mask for uSDHC_SYS_CTRL_INITA. */
#define BS_uSDHC_SYS_CTRL_INITA (1U)       /*!< Bit field size in bits for uSDHC_SYS_CTRL_INITA. */

/*! @brief Read current value of the uSDHC_SYS_CTRL_INITA field. */
#define BR_uSDHC_SYS_CTRL_INITA(x) (HW_uSDHC_SYS_CTRL(x).B.INITA)

/*! @brief Format value for bitfield uSDHC_SYS_CTRL_INITA. */
#define BF_uSDHC_SYS_CTRL_INITA(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_SYS_CTRL_INITA) & BM_uSDHC_SYS_CTRL_INITA)

/*! @brief Set the INITA field to a new value. */
#define BW_uSDHC_SYS_CTRL_INITA(x, v) (HW_uSDHC_SYS_CTRL_WR(x, (HW_uSDHC_SYS_CTRL_RD(x) & ~BM_uSDHC_SYS_CTRL_INITA) | BF_uSDHC_SYS_CTRL_INITA(v)))
/*@}*/

/*!
 * @name Register uSDHC_SYS_CTRL, field RSTT[28] (RW)
 *
 * When set this bit to 1, it will reset tuning circuit. After tuning circuits
 * are reset, bit value is 0. Clearing execute_tuning bit in AUTOCMD12_ERR_STATUS
 * will also set this bit to 1 to reset tuning circuit
 */
/*@{*/
#define BP_uSDHC_SYS_CTRL_RSTT (28U)       /*!< Bit position for uSDHC_SYS_CTRL_RSTT. */
#define BM_uSDHC_SYS_CTRL_RSTT (0x10000000U) /*!< Bit mask for uSDHC_SYS_CTRL_RSTT. */
#define BS_uSDHC_SYS_CTRL_RSTT (1U)        /*!< Bit field size in bits for uSDHC_SYS_CTRL_RSTT. */

/*! @brief Read current value of the uSDHC_SYS_CTRL_RSTT field. */
#define BR_uSDHC_SYS_CTRL_RSTT(x) (HW_uSDHC_SYS_CTRL(x).B.RSTT)

/*! @brief Format value for bitfield uSDHC_SYS_CTRL_RSTT. */
#define BF_uSDHC_SYS_CTRL_RSTT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_SYS_CTRL_RSTT) & BM_uSDHC_SYS_CTRL_RSTT)

/*! @brief Set the RSTT field to a new value. */
#define BW_uSDHC_SYS_CTRL_RSTT(x, v) (HW_uSDHC_SYS_CTRL_WR(x, (HW_uSDHC_SYS_CTRL_RD(x) & ~BM_uSDHC_SYS_CTRL_RSTT) | BF_uSDHC_SYS_CTRL_RSTT(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_INT_STATUS - Interrupt Status
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_INT_STATUS - Interrupt Status (RW)
 *
 * Reset value: 0x00000000U
 *
 * An interrupt is generated when the Normal Interrupt Signal Enable is enabled
 * and at least one of the status bits is set to 1. For all bits, writing 1 to a
 * bit clears it; writing to 0 keeps the bit unchanged. More than one status can
 * be cleared with a single register write. For Card Interrupt, before writing 1
 * to clear, it is required that the card stops asserting the interrupt, meaning
 * that when the Card Driver services the interrupt condition, otherwise the CINT
 * bit will be asserted again. The table below shows the relationship between
 * the Command Timeout Error and the Command Complete. uSDHC Status for Command
 * Timeout Error/Command Complete Bit Combinations Command Complete Command Timeout
 * Error Meaning of the Status 0 0 X X 1 Response not received within 64 SDCLK
 * cycles 1 0 Response received The table below shows the relationship between the
 * Transfer Complete and the Data Timeout Error. uSDHC Status for Data Timeout
 * Error/Transfer Complete Bit Combinations Transfer Complete Data Timeout Error
 * Meaning of the Status 0 0 X 0 1 Timeout occurred during transfer 1 X Data
 * Transfer Complete The table below shows the relationship between the Command CRC
 * Error and Command Timeout Error. uSDHC Status for Command CRC Error/Command
 * Timeout Error Bit Combinations Command Complete Command Timeout Error Meaning of
 * the Status 0 0 No error 0 1 Response Timeout Error 1 0 Response CRC Error 1 1
 * CMD line conflict
 */
typedef union _hw_usdhc_int_status
{
    uint32_t U;
    struct _hw_usdhc_int_status_bitfields
    {
        uint32_t CC : 1;               /*!< [0] Command Complete */
        uint32_t TC : 1;               /*!< [1] Transfer Complete */
        uint32_t BGE : 1;              /*!< [2] Block Gap Event */
        uint32_t DINT : 1;             /*!< [3] DMA Interrupt */
        uint32_t BWR : 1;              /*!< [4] Buffer Write Ready */
        uint32_t BRR : 1;              /*!< [5] Buffer Read Ready */
        uint32_t CINS : 1;             /*!< [6] Card Insertion */
        uint32_t CRM : 1;              /*!< [7] Card Removal */
        uint32_t CINT : 1;             /*!< [8] Card Interrupt */
        uint32_t RESERVED0 : 3;        /*!< [11:9]  */
        uint32_t RTE : 1;              /*!< [12] Re-Tuning Event: (only for SD3.0 SDR104
                                        * mode) */
        uint32_t RESERVED1 : 1;        /*!< [13]  */
        uint32_t TP : 1;               /*!< [14] Tuning Pass:(only for SD3.0 SDR104 mode) */
        uint32_t RESERVED2 : 1;        /*!< [15]  */
        uint32_t CTOE : 1;             /*!< [16] Command Timeout Error */
        uint32_t CCE : 1;              /*!< [17] Command CRC Error */
        uint32_t CEBE : 1;             /*!< [18] Command End Bit Error */
        uint32_t CIE : 1;              /*!< [19] Command Index Error */
        uint32_t DTOE : 1;             /*!< [20] Data Timeout Error */
        uint32_t DCE : 1;              /*!< [21] Data CRC Error */
        uint32_t DEBE : 1;             /*!< [22] Data End Bit Error */
        uint32_t RESERVED3 : 1;        /*!< [23]  */
        uint32_t AC12E : 1;            /*!< [24] Auto CMD12 Error */
        uint32_t RESERVED4 : 1;        /*!< [25]  */
        uint32_t TNE : 1;              /*!< [26] Tuning Error: (only for SD3.0 SDR104
                                        * mode) */
        uint32_t RESERVED5 : 1;        /*!< [27]  */
        uint32_t DMAE : 1;             /*!< [28] DMA Error */
        uint32_t RESERVED6 : 3;        /*!< [31:29]  */
    } B;
} hw_usdhc_int_status_t;

/*!
 * @name Constants and macros for entire uSDHC_INT_STATUS register
 */
/*@{*/
#define HW_uSDHC_INT_STATUS_ADDR(x) ((uintptr_t)(x) + 0x30U)

#define HW_uSDHC_INT_STATUS(x)   (*(__IO hw_usdhc_int_status_t *) HW_uSDHC_INT_STATUS_ADDR(x))
#define HW_uSDHC_INT_STATUS_RD(x) (HW_uSDHC_INT_STATUS(x).U)
#define HW_uSDHC_INT_STATUS_WR(x, v) (HW_uSDHC_INT_STATUS(x).U = (v))
#define HW_uSDHC_INT_STATUS_SET(x, v) (HW_uSDHC_INT_STATUS_WR(x, HW_uSDHC_INT_STATUS_RD(x) |  (v)))
#define HW_uSDHC_INT_STATUS_CLR(x, v) (HW_uSDHC_INT_STATUS_WR(x, HW_uSDHC_INT_STATUS_RD(x) & ~(v)))
#define HW_uSDHC_INT_STATUS_TOG(x, v) (HW_uSDHC_INT_STATUS_WR(x, HW_uSDHC_INT_STATUS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_INT_STATUS bitfields
 */

/*!
 * @name Register uSDHC_INT_STATUS, field CC[0] (W1C)
 *
 * This bit is set when you receive the end bit of the command response (except
 * Auto CMD12). Refer to the Command Inhibit (CMD) in the Present State register.
 * This bit will be not asserted in tuning process.
 *
 * Values:
 * - 1 - Command complete
 * - 0 - Command not complete
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_CC (0U)        /*!< Bit position for uSDHC_INT_STATUS_CC. */
#define BM_uSDHC_INT_STATUS_CC (0x00000001U) /*!< Bit mask for uSDHC_INT_STATUS_CC. */
#define BS_uSDHC_INT_STATUS_CC (1U)        /*!< Bit field size in bits for uSDHC_INT_STATUS_CC. */

/*! @brief Read current value of the uSDHC_INT_STATUS_CC field. */
#define BR_uSDHC_INT_STATUS_CC(x) (HW_uSDHC_INT_STATUS(x).B.CC)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_CC. */
#define BF_uSDHC_INT_STATUS_CC(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_CC) & BM_uSDHC_INT_STATUS_CC)

/*! @brief Set the CC field to a new value. */
#define BW_uSDHC_INT_STATUS_CC(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_CC(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field TC[1] (W1C)
 *
 * This bit is set when a read or write transfer is completed. In the case of a
 * Read Transaction: This bit is set at the falling edge of the Read Transfer
 * Active Status. There are two cases in which this interrupt is generated. The
 * first is when a data transfer is completed as specified by the data length (after
 * the last data has been read to the Host System). The second is when data has
 * stopped at the block gap and completed the data transfer by setting the Stop At
 * Block Gap Request bit in the Protocol Control register (after valid data has
 * been read to the Host System). In the case of a Write Transaction: This bit is
 * set at the falling edge of the DATA Line Active Status. There are two cases
 * in which this interrupt is generated. The first is when the last data is
 * written to the SD card as specified by the data length and the busy signal is
 * released. The second is when data transfers are stopped at the block gap, by setting
 * the Stop At Block Gap Request bit in the Protocol Control register, and the
 * data transfers are completed. (after valid data is written to the SD card and
 * the busy signal released). In the case of a command with busy, this bit is set
 * when busy is deasserted. This bit will be not asserted in tuning process.
 *
 * Values:
 * - 1 - Transfer complete
 * - 0 - Transfer not complete
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_TC (1U)        /*!< Bit position for uSDHC_INT_STATUS_TC. */
#define BM_uSDHC_INT_STATUS_TC (0x00000002U) /*!< Bit mask for uSDHC_INT_STATUS_TC. */
#define BS_uSDHC_INT_STATUS_TC (1U)        /*!< Bit field size in bits for uSDHC_INT_STATUS_TC. */

/*! @brief Read current value of the uSDHC_INT_STATUS_TC field. */
#define BR_uSDHC_INT_STATUS_TC(x) (HW_uSDHC_INT_STATUS(x).B.TC)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_TC. */
#define BF_uSDHC_INT_STATUS_TC(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_TC) & BM_uSDHC_INT_STATUS_TC)

/*! @brief Set the TC field to a new value. */
#define BW_uSDHC_INT_STATUS_TC(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_TC(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field BGE[2] (W1C)
 *
 * If the Stop At Block Gap Request bit in the Protocol Control register is set,
 * this bit is set when a read or write transaction is stopped at a block gap.
 * If Stop At Block Gap Request is not set to 1, this bit is not set to 1. In the
 * case of a Read Transaction: This bit is set at the falling edge of the DATA
 * Line Active Status (When the transaction is stopped at SD Bus timing). The Read
 * Wait must be supported in order to use this function. In the case of Write
 * Transaction: This bit is set at the falling edge of Write Transfer Active Status
 * (After getting CRC status at SD Bus timing).
 *
 * Values:
 * - 1 - Transaction stopped at block gap
 * - 0 - No block gap event
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_BGE (2U)       /*!< Bit position for uSDHC_INT_STATUS_BGE. */
#define BM_uSDHC_INT_STATUS_BGE (0x00000004U) /*!< Bit mask for uSDHC_INT_STATUS_BGE. */
#define BS_uSDHC_INT_STATUS_BGE (1U)       /*!< Bit field size in bits for uSDHC_INT_STATUS_BGE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_BGE field. */
#define BR_uSDHC_INT_STATUS_BGE(x) (HW_uSDHC_INT_STATUS(x).B.BGE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_BGE. */
#define BF_uSDHC_INT_STATUS_BGE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_BGE) & BM_uSDHC_INT_STATUS_BGE)

/*! @brief Set the BGE field to a new value. */
#define BW_uSDHC_INT_STATUS_BGE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_BGE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field DINT[3] (W1C)
 *
 * Occurs only when the internal DMA finishes the data transfer successfully.
 * Whenever errors occur during data transfer, this bit will not be set. Instead,
 * the DMAE bit will be set. Either Simple DMA or ADMA finishes data transferring,
 * this bit will be set.
 *
 * Values:
 * - 1 - DMA Interrupt is generated
 * - 0 - No DMA Interrupt
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_DINT (3U)      /*!< Bit position for uSDHC_INT_STATUS_DINT. */
#define BM_uSDHC_INT_STATUS_DINT (0x00000008U) /*!< Bit mask for uSDHC_INT_STATUS_DINT. */
#define BS_uSDHC_INT_STATUS_DINT (1U)      /*!< Bit field size in bits for uSDHC_INT_STATUS_DINT. */

/*! @brief Read current value of the uSDHC_INT_STATUS_DINT field. */
#define BR_uSDHC_INT_STATUS_DINT(x) (HW_uSDHC_INT_STATUS(x).B.DINT)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_DINT. */
#define BF_uSDHC_INT_STATUS_DINT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_DINT) & BM_uSDHC_INT_STATUS_DINT)

/*! @brief Set the DINT field to a new value. */
#define BW_uSDHC_INT_STATUS_DINT(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_DINT(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field BWR[4] (W1C)
 *
 * This status bit is set if the Buffer Write Enable bit, in the Present State
 * register, changes from 0 to 1. Refer to the Buffer Write Enable bit in the
 * Present State register for additional information.
 *
 * Values:
 * - 1 - Ready to write buffer:
 * - 0 - Not ready to write buffer
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_BWR (4U)       /*!< Bit position for uSDHC_INT_STATUS_BWR. */
#define BM_uSDHC_INT_STATUS_BWR (0x00000010U) /*!< Bit mask for uSDHC_INT_STATUS_BWR. */
#define BS_uSDHC_INT_STATUS_BWR (1U)       /*!< Bit field size in bits for uSDHC_INT_STATUS_BWR. */

/*! @brief Read current value of the uSDHC_INT_STATUS_BWR field. */
#define BR_uSDHC_INT_STATUS_BWR(x) (HW_uSDHC_INT_STATUS(x).B.BWR)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_BWR. */
#define BF_uSDHC_INT_STATUS_BWR(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_BWR) & BM_uSDHC_INT_STATUS_BWR)

/*! @brief Set the BWR field to a new value. */
#define BW_uSDHC_INT_STATUS_BWR(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_BWR(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field BRR[5] (W1C)
 *
 * This status bit is set if the Buffer Read Enable bit, in the Present State
 * register, changes from 0 to 1. Refer to the Buffer Read Enable bit in the
 * Present State register for additional information. This bit indicates that cmd19 is
 * finished in tuning process.
 *
 * Values:
 * - 1 - Ready to read buffer
 * - 0 - Not ready to read buffer
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_BRR (5U)       /*!< Bit position for uSDHC_INT_STATUS_BRR. */
#define BM_uSDHC_INT_STATUS_BRR (0x00000020U) /*!< Bit mask for uSDHC_INT_STATUS_BRR. */
#define BS_uSDHC_INT_STATUS_BRR (1U)       /*!< Bit field size in bits for uSDHC_INT_STATUS_BRR. */

/*! @brief Read current value of the uSDHC_INT_STATUS_BRR field. */
#define BR_uSDHC_INT_STATUS_BRR(x) (HW_uSDHC_INT_STATUS(x).B.BRR)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_BRR. */
#define BF_uSDHC_INT_STATUS_BRR(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_BRR) & BM_uSDHC_INT_STATUS_BRR)

/*! @brief Set the BRR field to a new value. */
#define BW_uSDHC_INT_STATUS_BRR(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_BRR(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field CINS[6] (W1C)
 *
 * This status bit is set if the Card Inserted bit in the Present State register
 * changes from 0 to 1. When the Host Driver writes this bit to 1 to clear this
 * status, the status of the Card Inserted in the Present State register should
 * be confirmed. Because the card state may possibly be changed when the Host
 * Driver clears this bit and the interrupt event may not be generated. When this bit
 * is cleared, it will be set again if a card is inserted. In order to leave it
 * cleared, clear the Card Inserted Status Enable bit in Interrupt Status Enable
 * register.
 *
 * Values:
 * - 1 - Card inserted
 * - 0 - Card state unstable or removed
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_CINS (6U)      /*!< Bit position for uSDHC_INT_STATUS_CINS. */
#define BM_uSDHC_INT_STATUS_CINS (0x00000040U) /*!< Bit mask for uSDHC_INT_STATUS_CINS. */
#define BS_uSDHC_INT_STATUS_CINS (1U)      /*!< Bit field size in bits for uSDHC_INT_STATUS_CINS. */

/*! @brief Read current value of the uSDHC_INT_STATUS_CINS field. */
#define BR_uSDHC_INT_STATUS_CINS(x) (HW_uSDHC_INT_STATUS(x).B.CINS)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_CINS. */
#define BF_uSDHC_INT_STATUS_CINS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_CINS) & BM_uSDHC_INT_STATUS_CINS)

/*! @brief Set the CINS field to a new value. */
#define BW_uSDHC_INT_STATUS_CINS(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_CINS(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field CRM[7] (W1C)
 *
 * This status bit is set if the Card Inserted bit in the Present State register
 * changes from 1 to 0. When the Host Driver writes this bit to 1 to clear this
 * status, the status of the Card Inserted in the Present State register should
 * be confirmed. Because the card state may possibly be changed when the Host
 * Driver clears this bit and the interrupt event may not be generated. When this bit
 * is cleared, it will be set again if no card is inserted. In order to leave it
 * cleared, clear the Card Removal Status Enable bit in Interrupt Status Enable
 * register.
 *
 * Values:
 * - 1 - Card removed
 * - 0 - Card state unstable or inserted
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_CRM (7U)       /*!< Bit position for uSDHC_INT_STATUS_CRM. */
#define BM_uSDHC_INT_STATUS_CRM (0x00000080U) /*!< Bit mask for uSDHC_INT_STATUS_CRM. */
#define BS_uSDHC_INT_STATUS_CRM (1U)       /*!< Bit field size in bits for uSDHC_INT_STATUS_CRM. */

/*! @brief Read current value of the uSDHC_INT_STATUS_CRM field. */
#define BR_uSDHC_INT_STATUS_CRM(x) (HW_uSDHC_INT_STATUS(x).B.CRM)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_CRM. */
#define BF_uSDHC_INT_STATUS_CRM(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_CRM) & BM_uSDHC_INT_STATUS_CRM)

/*! @brief Set the CRM field to a new value. */
#define BW_uSDHC_INT_STATUS_CRM(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_CRM(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field CINT[8] (W1C)
 *
 * This status bit is set when an interrupt signal is detected from the external
 * card. In 1-bit mode, the uSDHC will detect the Card Interrupt without the SD
 * Clock to support wakeup. In 4-bit mode, the card interrupt signal is sampled
 * during the interrupt cycle, so the interrupt from card can only be sampled
 * during interrupt cycle, introducing some delay between the interrupt signal from
 * the SDIO card and the interrupt to the Host System. Writing this bit to 1 can
 * clear this bit, but as the interrupt source from the SDIO card does not clear,
 * this bit is set again. In order to clear this bit, it is required to reset the
 * interrupt source from the external card followed by a writing 1 to this bit.
 * When this status has been set, and the Host Driver needs to service this
 * interrupt, the Card Interrupt Signal Enable in the Interrupt Signal Enable register
 * should be 0 to stop driving the interrupt signal to the Host System. After
 * completion of the card interrupt service (It should reset the interrupt sources
 * in the SDIO card and the interrupt signal may not be asserted), write 1 to
 * clear this bit, set the Card Interrupt Signal Enable to 1, and start sampling the
 * interrupt signal again.
 *
 * Values:
 * - 1 - Generate Card Interrupt
 * - 0 - No Card Interrupt
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_CINT (8U)      /*!< Bit position for uSDHC_INT_STATUS_CINT. */
#define BM_uSDHC_INT_STATUS_CINT (0x00000100U) /*!< Bit mask for uSDHC_INT_STATUS_CINT. */
#define BS_uSDHC_INT_STATUS_CINT (1U)      /*!< Bit field size in bits for uSDHC_INT_STATUS_CINT. */

/*! @brief Read current value of the uSDHC_INT_STATUS_CINT field. */
#define BR_uSDHC_INT_STATUS_CINT(x) (HW_uSDHC_INT_STATUS(x).B.CINT)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_CINT. */
#define BF_uSDHC_INT_STATUS_CINT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_CINT) & BM_uSDHC_INT_STATUS_CINT)

/*! @brief Set the CINT field to a new value. */
#define BW_uSDHC_INT_STATUS_CINT(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_CINT(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field RTE[12] (W1C)
 *
 * This status is set if Re-Tuning Request in the Present State register changes
 * from 0 to 1. Host Controller requests Host Driver to perform re-tuning for
 * next data transfer. Current data transfer (not large block count) can be
 * completed without re-tuning.
 *
 * Values:
 * - 1 - Re-Tuning should be performed
 * - 0 - Re-Tuning is not required
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_RTE (12U)      /*!< Bit position for uSDHC_INT_STATUS_RTE. */
#define BM_uSDHC_INT_STATUS_RTE (0x00001000U) /*!< Bit mask for uSDHC_INT_STATUS_RTE. */
#define BS_uSDHC_INT_STATUS_RTE (1U)       /*!< Bit field size in bits for uSDHC_INT_STATUS_RTE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_RTE field. */
#define BR_uSDHC_INT_STATUS_RTE(x) (HW_uSDHC_INT_STATUS(x).B.RTE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_RTE. */
#define BF_uSDHC_INT_STATUS_RTE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_RTE) & BM_uSDHC_INT_STATUS_RTE)

/*! @brief Set the RTE field to a new value. */
#define BW_uSDHC_INT_STATUS_RTE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_RTE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field TP[14] (W1C)
 *
 * Current CMD19 transfer is done successfully. That is, current sampling point
 * is correct.
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_TP (14U)       /*!< Bit position for uSDHC_INT_STATUS_TP. */
#define BM_uSDHC_INT_STATUS_TP (0x00004000U) /*!< Bit mask for uSDHC_INT_STATUS_TP. */
#define BS_uSDHC_INT_STATUS_TP (1U)        /*!< Bit field size in bits for uSDHC_INT_STATUS_TP. */

/*! @brief Read current value of the uSDHC_INT_STATUS_TP field. */
#define BR_uSDHC_INT_STATUS_TP(x) (HW_uSDHC_INT_STATUS(x).B.TP)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_TP. */
#define BF_uSDHC_INT_STATUS_TP(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_TP) & BM_uSDHC_INT_STATUS_TP)

/*! @brief Set the TP field to a new value. */
#define BW_uSDHC_INT_STATUS_TP(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_TP(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field CTOE[16] (W1C)
 *
 * Occurs only if no response is returned within 64 SDCLK cycles from the end
 * bit of the command. If the uSDHC detects a CMD line conflict, in which case a
 * Command CRC Error shall also be set (as shown in INT_STATUSInterrupt Status ),
 * this bit shall be set without waiting for 64 SDCLK cycles. This is because the
 * command will be aborted by the uSDHC. This bit will be not asserted in tuning
 * process.
 *
 * Values:
 * - 1 - Time out
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_CTOE (16U)     /*!< Bit position for uSDHC_INT_STATUS_CTOE. */
#define BM_uSDHC_INT_STATUS_CTOE (0x00010000U) /*!< Bit mask for uSDHC_INT_STATUS_CTOE. */
#define BS_uSDHC_INT_STATUS_CTOE (1U)      /*!< Bit field size in bits for uSDHC_INT_STATUS_CTOE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_CTOE field. */
#define BR_uSDHC_INT_STATUS_CTOE(x) (HW_uSDHC_INT_STATUS(x).B.CTOE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_CTOE. */
#define BF_uSDHC_INT_STATUS_CTOE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_CTOE) & BM_uSDHC_INT_STATUS_CTOE)

/*! @brief Set the CTOE field to a new value. */
#define BW_uSDHC_INT_STATUS_CTOE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_CTOE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field CCE[17] (W1C)
 *
 * Command CRC Error is generated in two cases. If a response is returned and
 * the Command Timeout Error is set to 0 (indicating no time-out), this bit is set
 * when detecting a CRC error in the command response. The uSDHC detects a CMD
 * line conflict by monitoring the CMD line when a command is issued. If the uSDHC
 * drives the CMD line to 1, but detects 0 on the CMD line at the next SDCLK
 * edge, then the uSDHC shall abort the command (Stop driving CMD line) and set this
 * bit to 1. The Command Timeout Error shall also be set to 1 to distinguish CMD
 * line conflict. This bit will be not asserted in tuning process.
 *
 * Values:
 * - 1 - CRC Error Generated.
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_CCE (17U)      /*!< Bit position for uSDHC_INT_STATUS_CCE. */
#define BM_uSDHC_INT_STATUS_CCE (0x00020000U) /*!< Bit mask for uSDHC_INT_STATUS_CCE. */
#define BS_uSDHC_INT_STATUS_CCE (1U)       /*!< Bit field size in bits for uSDHC_INT_STATUS_CCE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_CCE field. */
#define BR_uSDHC_INT_STATUS_CCE(x) (HW_uSDHC_INT_STATUS(x).B.CCE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_CCE. */
#define BF_uSDHC_INT_STATUS_CCE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_CCE) & BM_uSDHC_INT_STATUS_CCE)

/*! @brief Set the CCE field to a new value. */
#define BW_uSDHC_INT_STATUS_CCE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_CCE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field CEBE[18] (W1C)
 *
 * Occurs when detecting that the end bit of a command response is 0. This bit
 * will be not asserted in tuning process.
 *
 * Values:
 * - 1 - End Bit Error Generated
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_CEBE (18U)     /*!< Bit position for uSDHC_INT_STATUS_CEBE. */
#define BM_uSDHC_INT_STATUS_CEBE (0x00040000U) /*!< Bit mask for uSDHC_INT_STATUS_CEBE. */
#define BS_uSDHC_INT_STATUS_CEBE (1U)      /*!< Bit field size in bits for uSDHC_INT_STATUS_CEBE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_CEBE field. */
#define BR_uSDHC_INT_STATUS_CEBE(x) (HW_uSDHC_INT_STATUS(x).B.CEBE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_CEBE. */
#define BF_uSDHC_INT_STATUS_CEBE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_CEBE) & BM_uSDHC_INT_STATUS_CEBE)

/*! @brief Set the CEBE field to a new value. */
#define BW_uSDHC_INT_STATUS_CEBE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_CEBE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field CIE[19] (W1C)
 *
 * Occurs if a Command Index error occurs in the command response. This bit will
 * be not asserted in tuning process.
 *
 * Values:
 * - 1 - Error
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_CIE (19U)      /*!< Bit position for uSDHC_INT_STATUS_CIE. */
#define BM_uSDHC_INT_STATUS_CIE (0x00080000U) /*!< Bit mask for uSDHC_INT_STATUS_CIE. */
#define BS_uSDHC_INT_STATUS_CIE (1U)       /*!< Bit field size in bits for uSDHC_INT_STATUS_CIE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_CIE field. */
#define BR_uSDHC_INT_STATUS_CIE(x) (HW_uSDHC_INT_STATUS(x).B.CIE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_CIE. */
#define BF_uSDHC_INT_STATUS_CIE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_CIE) & BM_uSDHC_INT_STATUS_CIE)

/*! @brief Set the CIE field to a new value. */
#define BW_uSDHC_INT_STATUS_CIE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_CIE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field DTOE[20] (W1C)
 *
 * Occurs when detecting one of following time-out conditions. Busy time-out for
 * R1b, R5b type Busy time-out after Write CRC status Read Data time-out. This
 * bit will be not asserted in tuning process.
 *
 * Values:
 * - 1 - Time out
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_DTOE (20U)     /*!< Bit position for uSDHC_INT_STATUS_DTOE. */
#define BM_uSDHC_INT_STATUS_DTOE (0x00100000U) /*!< Bit mask for uSDHC_INT_STATUS_DTOE. */
#define BS_uSDHC_INT_STATUS_DTOE (1U)      /*!< Bit field size in bits for uSDHC_INT_STATUS_DTOE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_DTOE field. */
#define BR_uSDHC_INT_STATUS_DTOE(x) (HW_uSDHC_INT_STATUS(x).B.DTOE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_DTOE. */
#define BF_uSDHC_INT_STATUS_DTOE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_DTOE) & BM_uSDHC_INT_STATUS_DTOE)

/*! @brief Set the DTOE field to a new value. */
#define BW_uSDHC_INT_STATUS_DTOE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_DTOE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field DCE[21] (W1C)
 *
 * Occurs when detecting a CRC error when transferring read data, which uses the
 * DATA line, or when detecting the Write CRC status having a value other than
 * 010. This bit will be not asserted in tuning process.
 *
 * Values:
 * - 1 - Error
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_DCE (21U)      /*!< Bit position for uSDHC_INT_STATUS_DCE. */
#define BM_uSDHC_INT_STATUS_DCE (0x00200000U) /*!< Bit mask for uSDHC_INT_STATUS_DCE. */
#define BS_uSDHC_INT_STATUS_DCE (1U)       /*!< Bit field size in bits for uSDHC_INT_STATUS_DCE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_DCE field. */
#define BR_uSDHC_INT_STATUS_DCE(x) (HW_uSDHC_INT_STATUS(x).B.DCE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_DCE. */
#define BF_uSDHC_INT_STATUS_DCE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_DCE) & BM_uSDHC_INT_STATUS_DCE)

/*! @brief Set the DCE field to a new value. */
#define BW_uSDHC_INT_STATUS_DCE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_DCE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field DEBE[22] (W1C)
 *
 * Occurs either when detecting 0 at the end bit position of read data, which
 * uses the DATA line, or at the end bit position of the CRC. This bit will be not
 * asserted in tuning process.
 *
 * Values:
 * - 1 - Error
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_DEBE (22U)     /*!< Bit position for uSDHC_INT_STATUS_DEBE. */
#define BM_uSDHC_INT_STATUS_DEBE (0x00400000U) /*!< Bit mask for uSDHC_INT_STATUS_DEBE. */
#define BS_uSDHC_INT_STATUS_DEBE (1U)      /*!< Bit field size in bits for uSDHC_INT_STATUS_DEBE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_DEBE field. */
#define BR_uSDHC_INT_STATUS_DEBE(x) (HW_uSDHC_INT_STATUS(x).B.DEBE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_DEBE. */
#define BF_uSDHC_INT_STATUS_DEBE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_DEBE) & BM_uSDHC_INT_STATUS_DEBE)

/*! @brief Set the DEBE field to a new value. */
#define BW_uSDHC_INT_STATUS_DEBE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_DEBE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field AC12E[24] (W1C)
 *
 * Occurs when detecting that one of the bits in the Auto CMD12 Error Status
 * register has changed from 0 to 1. This bit is set to 1, not only when the errors
 * in Auto CMD12 occur, but also when the Auto CMD12 is not executed due to the
 * previous command error.
 *
 * Values:
 * - 1 - Error
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_AC12E (24U)    /*!< Bit position for uSDHC_INT_STATUS_AC12E. */
#define BM_uSDHC_INT_STATUS_AC12E (0x01000000U) /*!< Bit mask for uSDHC_INT_STATUS_AC12E. */
#define BS_uSDHC_INT_STATUS_AC12E (1U)     /*!< Bit field size in bits for uSDHC_INT_STATUS_AC12E. */

/*! @brief Read current value of the uSDHC_INT_STATUS_AC12E field. */
#define BR_uSDHC_INT_STATUS_AC12E(x) (HW_uSDHC_INT_STATUS(x).B.AC12E)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_AC12E. */
#define BF_uSDHC_INT_STATUS_AC12E(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_AC12E) & BM_uSDHC_INT_STATUS_AC12E)

/*! @brief Set the AC12E field to a new value. */
#define BW_uSDHC_INT_STATUS_AC12E(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_AC12E(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field TNE[26] (W1C)
 *
 * This bit is set when an unrecoverable error is detected in a tuning circuit.
 * By detecting Tuning Error, Host Driver needs to abort a command executing and
 * perform tuning.
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_TNE (26U)      /*!< Bit position for uSDHC_INT_STATUS_TNE. */
#define BM_uSDHC_INT_STATUS_TNE (0x04000000U) /*!< Bit mask for uSDHC_INT_STATUS_TNE. */
#define BS_uSDHC_INT_STATUS_TNE (1U)       /*!< Bit field size in bits for uSDHC_INT_STATUS_TNE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_TNE field. */
#define BR_uSDHC_INT_STATUS_TNE(x) (HW_uSDHC_INT_STATUS(x).B.TNE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_TNE. */
#define BF_uSDHC_INT_STATUS_TNE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_TNE) & BM_uSDHC_INT_STATUS_TNE)

/*! @brief Set the TNE field to a new value. */
#define BW_uSDHC_INT_STATUS_TNE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_TNE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_DMAE)) | BF_uSDHC_INT_STATUS_TNE(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS, field DMAE[28] (W1C)
 *
 * Occurs when an Internal DMA transfer has failed. This bit is set to 1, when
 * some error occurs in the data transfer. This error can be caused by either
 * Simple DMA or ADMA, depending on which DMA is in use. The value in DMA System
 * Address register is the next fetch address where the error occurs. Since any error
 * corrupts the whole data block, the Host Driver shall re-start the transfer
 * from the corrupted block boundary. The address of the block boundary can be
 * calculated either from the current DS_ADDR value or from the remaining number of
 * blocks and the block size.
 *
 * Values:
 * - 1 - Error
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_DMAE (28U)     /*!< Bit position for uSDHC_INT_STATUS_DMAE. */
#define BM_uSDHC_INT_STATUS_DMAE (0x10000000U) /*!< Bit mask for uSDHC_INT_STATUS_DMAE. */
#define BS_uSDHC_INT_STATUS_DMAE (1U)      /*!< Bit field size in bits for uSDHC_INT_STATUS_DMAE. */

/*! @brief Read current value of the uSDHC_INT_STATUS_DMAE field. */
#define BR_uSDHC_INT_STATUS_DMAE(x) (HW_uSDHC_INT_STATUS(x).B.DMAE)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_DMAE. */
#define BF_uSDHC_INT_STATUS_DMAE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_DMAE) & BM_uSDHC_INT_STATUS_DMAE)

/*! @brief Set the DMAE field to a new value. */
#define BW_uSDHC_INT_STATUS_DMAE(x, v) (HW_uSDHC_INT_STATUS_WR(x, (HW_uSDHC_INT_STATUS_RD(x) & ~(BM_uSDHC_INT_STATUS_DMAE | BM_uSDHC_INT_STATUS_CC | BM_uSDHC_INT_STATUS_TC | BM_uSDHC_INT_STATUS_BGE | BM_uSDHC_INT_STATUS_DINT | BM_uSDHC_INT_STATUS_BWR | BM_uSDHC_INT_STATUS_BRR | BM_uSDHC_INT_STATUS_CINS | BM_uSDHC_INT_STATUS_CRM | BM_uSDHC_INT_STATUS_CINT | BM_uSDHC_INT_STATUS_RTE | BM_uSDHC_INT_STATUS_TP | BM_uSDHC_INT_STATUS_CTOE | BM_uSDHC_INT_STATUS_CCE | BM_uSDHC_INT_STATUS_CEBE | BM_uSDHC_INT_STATUS_CIE | BM_uSDHC_INT_STATUS_DTOE | BM_uSDHC_INT_STATUS_DCE | BM_uSDHC_INT_STATUS_DEBE | BM_uSDHC_INT_STATUS_AC12E | BM_uSDHC_INT_STATUS_TNE)) | BF_uSDHC_INT_STATUS_DMAE(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_INT_STATUS_EN - Interrupt Status Enable
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_INT_STATUS_EN - Interrupt Status Enable (RW)
 *
 * Reset value: 0x00000000U
 *
 * Setting the bits in this register to 1 enables the corresponding Interrupt
 * Status to be set by the specified event. If any bit is cleared, the
 * corresponding Interrupt Status bit is also cleared (i.e. when the bit in this register is
 * cleared, the corresponding bit in Interrupt Status Register is always 0).
 * Depending on IABG bit setting, uSDHC may be programmed to sample the card
 * interrupt signal during the interrupt period and hold its value in the flip-flop.
 * There will be some delays on the Card Interrupt, asserted from the card, to the
 * time the Host System is informed. To detect a CMD line conflict, the Host Driver
 * must set both Command Timeout Error Status Enable and Command CRC Error
 * Status Enable to 1.
 */
typedef union _hw_usdhc_int_status_en
{
    uint32_t U;
    struct _hw_usdhc_int_status_en_bitfields
    {
        uint32_t CCSEN : 1;            /*!< [0] Command Complete Status Enable */
        uint32_t TCSEN : 1;            /*!< [1] Transfer Complete Status Enable */
        uint32_t BGESEN : 1;           /*!< [2] Block Gap Event Status Enable */
        uint32_t DINTSEN : 1;          /*!< [3] DMA Interrupt Status Enable */
        uint32_t BWRSEN : 1;           /*!< [4] Buffer Write Ready Status Enable */
        uint32_t BRRSEN : 1;           /*!< [5] Buffer Read Ready Status Enable */
        uint32_t CINSSEN : 1;          /*!< [6] Card Insertion Status Enable */
        uint32_t CRMSEN : 1;           /*!< [7] Card Removal Status Enable */
        uint32_t CINTSEN : 1;          /*!< [8] Card Interrupt Status Enable */
        uint32_t RESERVED0 : 3;        /*!< [11:9]  */
        uint32_t RTESEN : 1;           /*!< [12] Re-Tuning Event Status Enable */
        uint32_t RESERVED1 : 1;        /*!< [13]  */
        uint32_t TPSEN : 1;            /*!< [14] Tuning Pass Status Enable */
        uint32_t RESERVED2 : 1;        /*!< [15]  */
        uint32_t CTOESEN : 1;          /*!< [16] Command Timeout Error Status Enable */
        uint32_t CCESEN : 1;           /*!< [17] Command CRC Error Status Enable */
        uint32_t CEBESEN : 1;          /*!< [18] Command End Bit Error Status Enable */
        uint32_t CIESEN : 1;           /*!< [19] Command Index Error Status Enable */
        uint32_t DTOESEN : 1;          /*!< [20] Data Timeout Error Status Enable */
        uint32_t DCESEN : 1;           /*!< [21] Data CRC Error Status Enable */
        uint32_t DEBESEN : 1;          /*!< [22] Data End Bit Error Status Enable */
        uint32_t RESERVED3 : 1;        /*!< [23]  */
        uint32_t AC12ESEN : 1;         /*!< [24] Auto CMD12 Error Status Enable */
        uint32_t RESERVED4 : 1;        /*!< [25]  */
        uint32_t TNESEN : 1;           /*!< [26] Tuning Error Status Enable */
        uint32_t RESERVED5 : 1;        /*!< [27]  */
        uint32_t DMAESEN : 1;          /*!< [28] DMA Error Status Enable */
        uint32_t RESERVED6 : 3;        /*!< [31:29]  */
    } B;
} hw_usdhc_int_status_en_t;

/*!
 * @name Constants and macros for entire uSDHC_INT_STATUS_EN register
 */
/*@{*/
#define HW_uSDHC_INT_STATUS_EN_ADDR(x) ((uintptr_t)(x) + 0x34U)

#define HW_uSDHC_INT_STATUS_EN(x) (*(__IO hw_usdhc_int_status_en_t *) HW_uSDHC_INT_STATUS_EN_ADDR(x))
#define HW_uSDHC_INT_STATUS_EN_RD(x) (HW_uSDHC_INT_STATUS_EN(x).U)
#define HW_uSDHC_INT_STATUS_EN_WR(x, v) (HW_uSDHC_INT_STATUS_EN(x).U = (v))
#define HW_uSDHC_INT_STATUS_EN_SET(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, HW_uSDHC_INT_STATUS_EN_RD(x) |  (v)))
#define HW_uSDHC_INT_STATUS_EN_CLR(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, HW_uSDHC_INT_STATUS_EN_RD(x) & ~(v)))
#define HW_uSDHC_INT_STATUS_EN_TOG(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, HW_uSDHC_INT_STATUS_EN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_INT_STATUS_EN bitfields
 */

/*!
 * @name Register uSDHC_INT_STATUS_EN, field CCSEN[0] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_CCSEN (0U)  /*!< Bit position for uSDHC_INT_STATUS_EN_CCSEN. */
#define BM_uSDHC_INT_STATUS_EN_CCSEN (0x00000001U) /*!< Bit mask for uSDHC_INT_STATUS_EN_CCSEN. */
#define BS_uSDHC_INT_STATUS_EN_CCSEN (1U)  /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_CCSEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_CCSEN field. */
#define BR_uSDHC_INT_STATUS_EN_CCSEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.CCSEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_CCSEN. */
#define BF_uSDHC_INT_STATUS_EN_CCSEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_CCSEN) & BM_uSDHC_INT_STATUS_EN_CCSEN)

/*! @brief Set the CCSEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_CCSEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_CCSEN) | BF_uSDHC_INT_STATUS_EN_CCSEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field TCSEN[1] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_TCSEN (1U)  /*!< Bit position for uSDHC_INT_STATUS_EN_TCSEN. */
#define BM_uSDHC_INT_STATUS_EN_TCSEN (0x00000002U) /*!< Bit mask for uSDHC_INT_STATUS_EN_TCSEN. */
#define BS_uSDHC_INT_STATUS_EN_TCSEN (1U)  /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_TCSEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_TCSEN field. */
#define BR_uSDHC_INT_STATUS_EN_TCSEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.TCSEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_TCSEN. */
#define BF_uSDHC_INT_STATUS_EN_TCSEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_TCSEN) & BM_uSDHC_INT_STATUS_EN_TCSEN)

/*! @brief Set the TCSEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_TCSEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_TCSEN) | BF_uSDHC_INT_STATUS_EN_TCSEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field BGESEN[2] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_BGESEN (2U) /*!< Bit position for uSDHC_INT_STATUS_EN_BGESEN. */
#define BM_uSDHC_INT_STATUS_EN_BGESEN (0x00000004U) /*!< Bit mask for uSDHC_INT_STATUS_EN_BGESEN. */
#define BS_uSDHC_INT_STATUS_EN_BGESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_BGESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_BGESEN field. */
#define BR_uSDHC_INT_STATUS_EN_BGESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.BGESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_BGESEN. */
#define BF_uSDHC_INT_STATUS_EN_BGESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_BGESEN) & BM_uSDHC_INT_STATUS_EN_BGESEN)

/*! @brief Set the BGESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_BGESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_BGESEN) | BF_uSDHC_INT_STATUS_EN_BGESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field DINTSEN[3] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_DINTSEN (3U) /*!< Bit position for uSDHC_INT_STATUS_EN_DINTSEN. */
#define BM_uSDHC_INT_STATUS_EN_DINTSEN (0x00000008U) /*!< Bit mask for uSDHC_INT_STATUS_EN_DINTSEN. */
#define BS_uSDHC_INT_STATUS_EN_DINTSEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_DINTSEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_DINTSEN field. */
#define BR_uSDHC_INT_STATUS_EN_DINTSEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.DINTSEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_DINTSEN. */
#define BF_uSDHC_INT_STATUS_EN_DINTSEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_DINTSEN) & BM_uSDHC_INT_STATUS_EN_DINTSEN)

/*! @brief Set the DINTSEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_DINTSEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_DINTSEN) | BF_uSDHC_INT_STATUS_EN_DINTSEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field BWRSEN[4] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_BWRSEN (4U) /*!< Bit position for uSDHC_INT_STATUS_EN_BWRSEN. */
#define BM_uSDHC_INT_STATUS_EN_BWRSEN (0x00000010U) /*!< Bit mask for uSDHC_INT_STATUS_EN_BWRSEN. */
#define BS_uSDHC_INT_STATUS_EN_BWRSEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_BWRSEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_BWRSEN field. */
#define BR_uSDHC_INT_STATUS_EN_BWRSEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.BWRSEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_BWRSEN. */
#define BF_uSDHC_INT_STATUS_EN_BWRSEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_BWRSEN) & BM_uSDHC_INT_STATUS_EN_BWRSEN)

/*! @brief Set the BWRSEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_BWRSEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_BWRSEN) | BF_uSDHC_INT_STATUS_EN_BWRSEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field BRRSEN[5] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_BRRSEN (5U) /*!< Bit position for uSDHC_INT_STATUS_EN_BRRSEN. */
#define BM_uSDHC_INT_STATUS_EN_BRRSEN (0x00000020U) /*!< Bit mask for uSDHC_INT_STATUS_EN_BRRSEN. */
#define BS_uSDHC_INT_STATUS_EN_BRRSEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_BRRSEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_BRRSEN field. */
#define BR_uSDHC_INT_STATUS_EN_BRRSEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.BRRSEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_BRRSEN. */
#define BF_uSDHC_INT_STATUS_EN_BRRSEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_BRRSEN) & BM_uSDHC_INT_STATUS_EN_BRRSEN)

/*! @brief Set the BRRSEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_BRRSEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_BRRSEN) | BF_uSDHC_INT_STATUS_EN_BRRSEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field CINSSEN[6] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_CINSSEN (6U) /*!< Bit position for uSDHC_INT_STATUS_EN_CINSSEN. */
#define BM_uSDHC_INT_STATUS_EN_CINSSEN (0x00000040U) /*!< Bit mask for uSDHC_INT_STATUS_EN_CINSSEN. */
#define BS_uSDHC_INT_STATUS_EN_CINSSEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_CINSSEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_CINSSEN field. */
#define BR_uSDHC_INT_STATUS_EN_CINSSEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.CINSSEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_CINSSEN. */
#define BF_uSDHC_INT_STATUS_EN_CINSSEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_CINSSEN) & BM_uSDHC_INT_STATUS_EN_CINSSEN)

/*! @brief Set the CINSSEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_CINSSEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_CINSSEN) | BF_uSDHC_INT_STATUS_EN_CINSSEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field CRMSEN[7] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_CRMSEN (7U) /*!< Bit position for uSDHC_INT_STATUS_EN_CRMSEN. */
#define BM_uSDHC_INT_STATUS_EN_CRMSEN (0x00000080U) /*!< Bit mask for uSDHC_INT_STATUS_EN_CRMSEN. */
#define BS_uSDHC_INT_STATUS_EN_CRMSEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_CRMSEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_CRMSEN field. */
#define BR_uSDHC_INT_STATUS_EN_CRMSEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.CRMSEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_CRMSEN. */
#define BF_uSDHC_INT_STATUS_EN_CRMSEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_CRMSEN) & BM_uSDHC_INT_STATUS_EN_CRMSEN)

/*! @brief Set the CRMSEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_CRMSEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_CRMSEN) | BF_uSDHC_INT_STATUS_EN_CRMSEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field CINTSEN[8] (RW)
 *
 * If this bit is set to 0, the uSDHC will clear the interrupt request to the
 * system. The Card Interrupt detection is stopped when this bit is cleared and
 * restarted when this bit is set to 1. The Host Driver should clear the Card
 * Interrupt Status Enable before servicing the Card Interrupt and should set this bit
 * again after all interrupt requests from the card are cleared to prevent
 * inadvertent interrupts.
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_CINTSEN (8U) /*!< Bit position for uSDHC_INT_STATUS_EN_CINTSEN. */
#define BM_uSDHC_INT_STATUS_EN_CINTSEN (0x00000100U) /*!< Bit mask for uSDHC_INT_STATUS_EN_CINTSEN. */
#define BS_uSDHC_INT_STATUS_EN_CINTSEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_CINTSEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_CINTSEN field. */
#define BR_uSDHC_INT_STATUS_EN_CINTSEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.CINTSEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_CINTSEN. */
#define BF_uSDHC_INT_STATUS_EN_CINTSEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_CINTSEN) & BM_uSDHC_INT_STATUS_EN_CINTSEN)

/*! @brief Set the CINTSEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_CINTSEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_CINTSEN) | BF_uSDHC_INT_STATUS_EN_CINTSEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field RTESEN[12] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_RTESEN (12U) /*!< Bit position for uSDHC_INT_STATUS_EN_RTESEN. */
#define BM_uSDHC_INT_STATUS_EN_RTESEN (0x00001000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_RTESEN. */
#define BS_uSDHC_INT_STATUS_EN_RTESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_RTESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_RTESEN field. */
#define BR_uSDHC_INT_STATUS_EN_RTESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.RTESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_RTESEN. */
#define BF_uSDHC_INT_STATUS_EN_RTESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_RTESEN) & BM_uSDHC_INT_STATUS_EN_RTESEN)

/*! @brief Set the RTESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_RTESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_RTESEN) | BF_uSDHC_INT_STATUS_EN_RTESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field TPSEN[14] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_TPSEN (14U) /*!< Bit position for uSDHC_INT_STATUS_EN_TPSEN. */
#define BM_uSDHC_INT_STATUS_EN_TPSEN (0x00004000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_TPSEN. */
#define BS_uSDHC_INT_STATUS_EN_TPSEN (1U)  /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_TPSEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_TPSEN field. */
#define BR_uSDHC_INT_STATUS_EN_TPSEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.TPSEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_TPSEN. */
#define BF_uSDHC_INT_STATUS_EN_TPSEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_TPSEN) & BM_uSDHC_INT_STATUS_EN_TPSEN)

/*! @brief Set the TPSEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_TPSEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_TPSEN) | BF_uSDHC_INT_STATUS_EN_TPSEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field CTOESEN[16] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_CTOESEN (16U) /*!< Bit position for uSDHC_INT_STATUS_EN_CTOESEN. */
#define BM_uSDHC_INT_STATUS_EN_CTOESEN (0x00010000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_CTOESEN. */
#define BS_uSDHC_INT_STATUS_EN_CTOESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_CTOESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_CTOESEN field. */
#define BR_uSDHC_INT_STATUS_EN_CTOESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.CTOESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_CTOESEN. */
#define BF_uSDHC_INT_STATUS_EN_CTOESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_CTOESEN) & BM_uSDHC_INT_STATUS_EN_CTOESEN)

/*! @brief Set the CTOESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_CTOESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_CTOESEN) | BF_uSDHC_INT_STATUS_EN_CTOESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field CCESEN[17] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_CCESEN (17U) /*!< Bit position for uSDHC_INT_STATUS_EN_CCESEN. */
#define BM_uSDHC_INT_STATUS_EN_CCESEN (0x00020000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_CCESEN. */
#define BS_uSDHC_INT_STATUS_EN_CCESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_CCESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_CCESEN field. */
#define BR_uSDHC_INT_STATUS_EN_CCESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.CCESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_CCESEN. */
#define BF_uSDHC_INT_STATUS_EN_CCESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_CCESEN) & BM_uSDHC_INT_STATUS_EN_CCESEN)

/*! @brief Set the CCESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_CCESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_CCESEN) | BF_uSDHC_INT_STATUS_EN_CCESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field CEBESEN[18] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_CEBESEN (18U) /*!< Bit position for uSDHC_INT_STATUS_EN_CEBESEN. */
#define BM_uSDHC_INT_STATUS_EN_CEBESEN (0x00040000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_CEBESEN. */
#define BS_uSDHC_INT_STATUS_EN_CEBESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_CEBESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_CEBESEN field. */
#define BR_uSDHC_INT_STATUS_EN_CEBESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.CEBESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_CEBESEN. */
#define BF_uSDHC_INT_STATUS_EN_CEBESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_CEBESEN) & BM_uSDHC_INT_STATUS_EN_CEBESEN)

/*! @brief Set the CEBESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_CEBESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_CEBESEN) | BF_uSDHC_INT_STATUS_EN_CEBESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field CIESEN[19] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_CIESEN (19U) /*!< Bit position for uSDHC_INT_STATUS_EN_CIESEN. */
#define BM_uSDHC_INT_STATUS_EN_CIESEN (0x00080000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_CIESEN. */
#define BS_uSDHC_INT_STATUS_EN_CIESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_CIESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_CIESEN field. */
#define BR_uSDHC_INT_STATUS_EN_CIESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.CIESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_CIESEN. */
#define BF_uSDHC_INT_STATUS_EN_CIESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_CIESEN) & BM_uSDHC_INT_STATUS_EN_CIESEN)

/*! @brief Set the CIESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_CIESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_CIESEN) | BF_uSDHC_INT_STATUS_EN_CIESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field DTOESEN[20] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_DTOESEN (20U) /*!< Bit position for uSDHC_INT_STATUS_EN_DTOESEN. */
#define BM_uSDHC_INT_STATUS_EN_DTOESEN (0x00100000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_DTOESEN. */
#define BS_uSDHC_INT_STATUS_EN_DTOESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_DTOESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_DTOESEN field. */
#define BR_uSDHC_INT_STATUS_EN_DTOESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.DTOESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_DTOESEN. */
#define BF_uSDHC_INT_STATUS_EN_DTOESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_DTOESEN) & BM_uSDHC_INT_STATUS_EN_DTOESEN)

/*! @brief Set the DTOESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_DTOESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_DTOESEN) | BF_uSDHC_INT_STATUS_EN_DTOESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field DCESEN[21] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_DCESEN (21U) /*!< Bit position for uSDHC_INT_STATUS_EN_DCESEN. */
#define BM_uSDHC_INT_STATUS_EN_DCESEN (0x00200000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_DCESEN. */
#define BS_uSDHC_INT_STATUS_EN_DCESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_DCESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_DCESEN field. */
#define BR_uSDHC_INT_STATUS_EN_DCESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.DCESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_DCESEN. */
#define BF_uSDHC_INT_STATUS_EN_DCESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_DCESEN) & BM_uSDHC_INT_STATUS_EN_DCESEN)

/*! @brief Set the DCESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_DCESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_DCESEN) | BF_uSDHC_INT_STATUS_EN_DCESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field DEBESEN[22] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_DEBESEN (22U) /*!< Bit position for uSDHC_INT_STATUS_EN_DEBESEN. */
#define BM_uSDHC_INT_STATUS_EN_DEBESEN (0x00400000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_DEBESEN. */
#define BS_uSDHC_INT_STATUS_EN_DEBESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_DEBESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_DEBESEN field. */
#define BR_uSDHC_INT_STATUS_EN_DEBESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.DEBESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_DEBESEN. */
#define BF_uSDHC_INT_STATUS_EN_DEBESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_DEBESEN) & BM_uSDHC_INT_STATUS_EN_DEBESEN)

/*! @brief Set the DEBESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_DEBESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_DEBESEN) | BF_uSDHC_INT_STATUS_EN_DEBESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field AC12ESEN[24] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_AC12ESEN (24U) /*!< Bit position for uSDHC_INT_STATUS_EN_AC12ESEN. */
#define BM_uSDHC_INT_STATUS_EN_AC12ESEN (0x01000000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_AC12ESEN. */
#define BS_uSDHC_INT_STATUS_EN_AC12ESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_AC12ESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_AC12ESEN field. */
#define BR_uSDHC_INT_STATUS_EN_AC12ESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.AC12ESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_AC12ESEN. */
#define BF_uSDHC_INT_STATUS_EN_AC12ESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_AC12ESEN) & BM_uSDHC_INT_STATUS_EN_AC12ESEN)

/*! @brief Set the AC12ESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_AC12ESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_AC12ESEN) | BF_uSDHC_INT_STATUS_EN_AC12ESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field TNESEN[26] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_TNESEN (26U) /*!< Bit position for uSDHC_INT_STATUS_EN_TNESEN. */
#define BM_uSDHC_INT_STATUS_EN_TNESEN (0x04000000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_TNESEN. */
#define BS_uSDHC_INT_STATUS_EN_TNESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_TNESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_TNESEN field. */
#define BR_uSDHC_INT_STATUS_EN_TNESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.TNESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_TNESEN. */
#define BF_uSDHC_INT_STATUS_EN_TNESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_TNESEN) & BM_uSDHC_INT_STATUS_EN_TNESEN)

/*! @brief Set the TNESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_TNESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_TNESEN) | BF_uSDHC_INT_STATUS_EN_TNESEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_STATUS_EN, field DMAESEN[28] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_STATUS_EN_DMAESEN (28U) /*!< Bit position for uSDHC_INT_STATUS_EN_DMAESEN. */
#define BM_uSDHC_INT_STATUS_EN_DMAESEN (0x10000000U) /*!< Bit mask for uSDHC_INT_STATUS_EN_DMAESEN. */
#define BS_uSDHC_INT_STATUS_EN_DMAESEN (1U) /*!< Bit field size in bits for uSDHC_INT_STATUS_EN_DMAESEN. */

/*! @brief Read current value of the uSDHC_INT_STATUS_EN_DMAESEN field. */
#define BR_uSDHC_INT_STATUS_EN_DMAESEN(x) (HW_uSDHC_INT_STATUS_EN(x).B.DMAESEN)

/*! @brief Format value for bitfield uSDHC_INT_STATUS_EN_DMAESEN. */
#define BF_uSDHC_INT_STATUS_EN_DMAESEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_STATUS_EN_DMAESEN) & BM_uSDHC_INT_STATUS_EN_DMAESEN)

/*! @brief Set the DMAESEN field to a new value. */
#define BW_uSDHC_INT_STATUS_EN_DMAESEN(x, v) (HW_uSDHC_INT_STATUS_EN_WR(x, (HW_uSDHC_INT_STATUS_EN_RD(x) & ~BM_uSDHC_INT_STATUS_EN_DMAESEN) | BF_uSDHC_INT_STATUS_EN_DMAESEN(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_INT_SIGNAL_EN - Interrupt Signal Enable
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_INT_SIGNAL_EN - Interrupt Signal Enable (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is used to select which interrupt status is indicated to the
 * Host System as the interrupt. These status bits all share the same interrupt
 * line. Setting any of these bits to 1 enables interrupt generation. The
 * corresponding Status register bit will generate an interrupt when the corresponding
 * interrupt signal enable bit is set.
 */
typedef union _hw_usdhc_int_signal_en
{
    uint32_t U;
    struct _hw_usdhc_int_signal_en_bitfields
    {
        uint32_t CCIEN : 1;            /*!< [0] Command Complete Interrupt Enable */
        uint32_t TCIEN : 1;            /*!< [1] Transfer Complete Interrupt Enable */
        uint32_t BGEIEN : 1;           /*!< [2] Block Gap Event Interrupt Enable */
        uint32_t DINTIEN : 1;          /*!< [3] DMA Interrupt Enable */
        uint32_t BWRIEN : 1;           /*!< [4] Buffer Write Ready Interrupt Enable */
        uint32_t BRRIEN : 1;           /*!< [5] Buffer Read Ready Interrupt Enable */
        uint32_t CINSIEN : 1;          /*!< [6] Card Insertion Interrupt Enable */
        uint32_t CRMIEN : 1;           /*!< [7] Card Removal Interrupt Enable */
        uint32_t CINTIEN : 1;          /*!< [8] Card Interrupt Interrupt Enable */
        uint32_t RESERVED0 : 3;        /*!< [11:9]  */
        uint32_t RTEIEN : 1;           /*!< [12] Re-Tuning Event Interrupt Enable */
        uint32_t RESERVED1 : 1;        /*!< [13]  */
        uint32_t TPIEN : 1;            /*!< [14] Tuning Pass Interrupt Enable */
        uint32_t RESERVED2 : 1;        /*!< [15]  */
        uint32_t CTOEIEN : 1;          /*!< [16] Command Timeout Error Interrupt
                                        * Enable */
        uint32_t CCEIEN : 1;           /*!< [17] Command CRC Error Interrupt Enable */
        uint32_t CEBEIEN : 1;          /*!< [18] Command End Bit Error Interrupt
                                        * Enable */
        uint32_t CIEIEN : 1;           /*!< [19] Command Index Error Interrupt Enable */
        uint32_t DTOEIEN : 1;          /*!< [20] Data Timeout Error Interrupt Enable */
        uint32_t DCEIEN : 1;           /*!< [21] Data CRC Error Interrupt Enable */
        uint32_t DEBEIEN : 1;          /*!< [22] Data End Bit Error Interrupt Enable */
        uint32_t RESERVED3 : 1;        /*!< [23]  */
        uint32_t AC12EIEN : 1;         /*!< [24] Auto CMD12 Error Interrupt Enable */
        uint32_t RESERVED4 : 1;        /*!< [25]  */
        uint32_t TNEIEN : 1;           /*!< [26] Tuning Error Interrupt Enable */
        uint32_t RESERVED5 : 1;        /*!< [27]  */
        uint32_t DMAEIEN : 1;          /*!< [28] DMA Error Interrupt Enable */
        uint32_t RESERVED6 : 3;        /*!< [31:29]  */
    } B;
} hw_usdhc_int_signal_en_t;

/*!
 * @name Constants and macros for entire uSDHC_INT_SIGNAL_EN register
 */
/*@{*/
#define HW_uSDHC_INT_SIGNAL_EN_ADDR(x) ((uintptr_t)(x) + 0x38U)

#define HW_uSDHC_INT_SIGNAL_EN(x) (*(__IO hw_usdhc_int_signal_en_t *) HW_uSDHC_INT_SIGNAL_EN_ADDR(x))
#define HW_uSDHC_INT_SIGNAL_EN_RD(x) (HW_uSDHC_INT_SIGNAL_EN(x).U)
#define HW_uSDHC_INT_SIGNAL_EN_WR(x, v) (HW_uSDHC_INT_SIGNAL_EN(x).U = (v))
#define HW_uSDHC_INT_SIGNAL_EN_SET(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, HW_uSDHC_INT_SIGNAL_EN_RD(x) |  (v)))
#define HW_uSDHC_INT_SIGNAL_EN_CLR(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~(v)))
#define HW_uSDHC_INT_SIGNAL_EN_TOG(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, HW_uSDHC_INT_SIGNAL_EN_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_INT_SIGNAL_EN bitfields
 */

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field CCIEN[0] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_CCIEN (0U)  /*!< Bit position for uSDHC_INT_SIGNAL_EN_CCIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_CCIEN (0x00000001U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_CCIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_CCIEN (1U)  /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_CCIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_CCIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_CCIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.CCIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_CCIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_CCIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_CCIEN) & BM_uSDHC_INT_SIGNAL_EN_CCIEN)

/*! @brief Set the CCIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_CCIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_CCIEN) | BF_uSDHC_INT_SIGNAL_EN_CCIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field TCIEN[1] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_TCIEN (1U)  /*!< Bit position for uSDHC_INT_SIGNAL_EN_TCIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_TCIEN (0x00000002U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_TCIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_TCIEN (1U)  /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_TCIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_TCIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_TCIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.TCIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_TCIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_TCIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_TCIEN) & BM_uSDHC_INT_SIGNAL_EN_TCIEN)

/*! @brief Set the TCIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_TCIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_TCIEN) | BF_uSDHC_INT_SIGNAL_EN_TCIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field BGEIEN[2] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_BGEIEN (2U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_BGEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_BGEIEN (0x00000004U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_BGEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_BGEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_BGEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_BGEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_BGEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.BGEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_BGEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_BGEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_BGEIEN) & BM_uSDHC_INT_SIGNAL_EN_BGEIEN)

/*! @brief Set the BGEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_BGEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_BGEIEN) | BF_uSDHC_INT_SIGNAL_EN_BGEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field DINTIEN[3] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_DINTIEN (3U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_DINTIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_DINTIEN (0x00000008U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_DINTIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_DINTIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_DINTIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_DINTIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_DINTIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.DINTIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_DINTIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_DINTIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_DINTIEN) & BM_uSDHC_INT_SIGNAL_EN_DINTIEN)

/*! @brief Set the DINTIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_DINTIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_DINTIEN) | BF_uSDHC_INT_SIGNAL_EN_DINTIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field BWRIEN[4] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_BWRIEN (4U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_BWRIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_BWRIEN (0x00000010U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_BWRIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_BWRIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_BWRIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_BWRIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_BWRIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.BWRIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_BWRIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_BWRIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_BWRIEN) & BM_uSDHC_INT_SIGNAL_EN_BWRIEN)

/*! @brief Set the BWRIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_BWRIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_BWRIEN) | BF_uSDHC_INT_SIGNAL_EN_BWRIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field BRRIEN[5] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_BRRIEN (5U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_BRRIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_BRRIEN (0x00000020U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_BRRIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_BRRIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_BRRIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_BRRIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_BRRIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.BRRIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_BRRIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_BRRIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_BRRIEN) & BM_uSDHC_INT_SIGNAL_EN_BRRIEN)

/*! @brief Set the BRRIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_BRRIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_BRRIEN) | BF_uSDHC_INT_SIGNAL_EN_BRRIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field CINSIEN[6] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_CINSIEN (6U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_CINSIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_CINSIEN (0x00000040U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_CINSIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_CINSIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_CINSIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_CINSIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_CINSIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.CINSIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_CINSIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_CINSIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_CINSIEN) & BM_uSDHC_INT_SIGNAL_EN_CINSIEN)

/*! @brief Set the CINSIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_CINSIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_CINSIEN) | BF_uSDHC_INT_SIGNAL_EN_CINSIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field CRMIEN[7] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_CRMIEN (7U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_CRMIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_CRMIEN (0x00000080U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_CRMIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_CRMIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_CRMIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_CRMIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_CRMIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.CRMIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_CRMIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_CRMIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_CRMIEN) & BM_uSDHC_INT_SIGNAL_EN_CRMIEN)

/*! @brief Set the CRMIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_CRMIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_CRMIEN) | BF_uSDHC_INT_SIGNAL_EN_CRMIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field CINTIEN[8] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_CINTIEN (8U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_CINTIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_CINTIEN (0x00000100U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_CINTIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_CINTIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_CINTIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_CINTIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_CINTIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.CINTIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_CINTIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_CINTIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_CINTIEN) & BM_uSDHC_INT_SIGNAL_EN_CINTIEN)

/*! @brief Set the CINTIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_CINTIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_CINTIEN) | BF_uSDHC_INT_SIGNAL_EN_CINTIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field RTEIEN[12] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_RTEIEN (12U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_RTEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_RTEIEN (0x00001000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_RTEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_RTEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_RTEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_RTEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_RTEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.RTEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_RTEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_RTEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_RTEIEN) & BM_uSDHC_INT_SIGNAL_EN_RTEIEN)

/*! @brief Set the RTEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_RTEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_RTEIEN) | BF_uSDHC_INT_SIGNAL_EN_RTEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field TPIEN[14] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_TPIEN (14U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_TPIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_TPIEN (0x00004000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_TPIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_TPIEN (1U)  /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_TPIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_TPIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_TPIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.TPIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_TPIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_TPIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_TPIEN) & BM_uSDHC_INT_SIGNAL_EN_TPIEN)

/*! @brief Set the TPIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_TPIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_TPIEN) | BF_uSDHC_INT_SIGNAL_EN_TPIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field CTOEIEN[16] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_CTOEIEN (16U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_CTOEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_CTOEIEN (0x00010000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_CTOEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_CTOEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_CTOEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_CTOEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_CTOEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.CTOEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_CTOEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_CTOEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_CTOEIEN) & BM_uSDHC_INT_SIGNAL_EN_CTOEIEN)

/*! @brief Set the CTOEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_CTOEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_CTOEIEN) | BF_uSDHC_INT_SIGNAL_EN_CTOEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field CCEIEN[17] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_CCEIEN (17U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_CCEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_CCEIEN (0x00020000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_CCEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_CCEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_CCEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_CCEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_CCEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.CCEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_CCEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_CCEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_CCEIEN) & BM_uSDHC_INT_SIGNAL_EN_CCEIEN)

/*! @brief Set the CCEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_CCEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_CCEIEN) | BF_uSDHC_INT_SIGNAL_EN_CCEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field CEBEIEN[18] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_CEBEIEN (18U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_CEBEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_CEBEIEN (0x00040000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_CEBEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_CEBEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_CEBEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_CEBEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_CEBEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.CEBEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_CEBEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_CEBEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_CEBEIEN) & BM_uSDHC_INT_SIGNAL_EN_CEBEIEN)

/*! @brief Set the CEBEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_CEBEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_CEBEIEN) | BF_uSDHC_INT_SIGNAL_EN_CEBEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field CIEIEN[19] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_CIEIEN (19U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_CIEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_CIEIEN (0x00080000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_CIEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_CIEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_CIEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_CIEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_CIEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.CIEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_CIEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_CIEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_CIEIEN) & BM_uSDHC_INT_SIGNAL_EN_CIEIEN)

/*! @brief Set the CIEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_CIEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_CIEIEN) | BF_uSDHC_INT_SIGNAL_EN_CIEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field DTOEIEN[20] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_DTOEIEN (20U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_DTOEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_DTOEIEN (0x00100000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_DTOEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_DTOEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_DTOEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_DTOEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_DTOEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.DTOEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_DTOEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_DTOEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_DTOEIEN) & BM_uSDHC_INT_SIGNAL_EN_DTOEIEN)

/*! @brief Set the DTOEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_DTOEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_DTOEIEN) | BF_uSDHC_INT_SIGNAL_EN_DTOEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field DCEIEN[21] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_DCEIEN (21U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_DCEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_DCEIEN (0x00200000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_DCEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_DCEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_DCEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_DCEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_DCEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.DCEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_DCEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_DCEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_DCEIEN) & BM_uSDHC_INT_SIGNAL_EN_DCEIEN)

/*! @brief Set the DCEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_DCEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_DCEIEN) | BF_uSDHC_INT_SIGNAL_EN_DCEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field DEBEIEN[22] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_DEBEIEN (22U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_DEBEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_DEBEIEN (0x00400000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_DEBEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_DEBEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_DEBEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_DEBEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_DEBEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.DEBEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_DEBEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_DEBEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_DEBEIEN) & BM_uSDHC_INT_SIGNAL_EN_DEBEIEN)

/*! @brief Set the DEBEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_DEBEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_DEBEIEN) | BF_uSDHC_INT_SIGNAL_EN_DEBEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field AC12EIEN[24] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_AC12EIEN (24U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_AC12EIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_AC12EIEN (0x01000000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_AC12EIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_AC12EIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_AC12EIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_AC12EIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_AC12EIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.AC12EIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_AC12EIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_AC12EIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_AC12EIEN) & BM_uSDHC_INT_SIGNAL_EN_AC12EIEN)

/*! @brief Set the AC12EIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_AC12EIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_AC12EIEN) | BF_uSDHC_INT_SIGNAL_EN_AC12EIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field TNEIEN[26] (RW)
 *
 * Values:
 * - 1 - Enabled
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_TNEIEN (26U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_TNEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_TNEIEN (0x04000000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_TNEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_TNEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_TNEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_TNEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_TNEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.TNEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_TNEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_TNEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_TNEIEN) & BM_uSDHC_INT_SIGNAL_EN_TNEIEN)

/*! @brief Set the TNEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_TNEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_TNEIEN) | BF_uSDHC_INT_SIGNAL_EN_TNEIEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_INT_SIGNAL_EN, field DMAEIEN[28] (RW)
 *
 * Values:
 * - 1 - Enable
 * - 0 - Masked
 */
/*@{*/
#define BP_uSDHC_INT_SIGNAL_EN_DMAEIEN (28U) /*!< Bit position for uSDHC_INT_SIGNAL_EN_DMAEIEN. */
#define BM_uSDHC_INT_SIGNAL_EN_DMAEIEN (0x10000000U) /*!< Bit mask for uSDHC_INT_SIGNAL_EN_DMAEIEN. */
#define BS_uSDHC_INT_SIGNAL_EN_DMAEIEN (1U) /*!< Bit field size in bits for uSDHC_INT_SIGNAL_EN_DMAEIEN. */

/*! @brief Read current value of the uSDHC_INT_SIGNAL_EN_DMAEIEN field. */
#define BR_uSDHC_INT_SIGNAL_EN_DMAEIEN(x) (HW_uSDHC_INT_SIGNAL_EN(x).B.DMAEIEN)

/*! @brief Format value for bitfield uSDHC_INT_SIGNAL_EN_DMAEIEN. */
#define BF_uSDHC_INT_SIGNAL_EN_DMAEIEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_INT_SIGNAL_EN_DMAEIEN) & BM_uSDHC_INT_SIGNAL_EN_DMAEIEN)

/*! @brief Set the DMAEIEN field to a new value. */
#define BW_uSDHC_INT_SIGNAL_EN_DMAEIEN(x, v) (HW_uSDHC_INT_SIGNAL_EN_WR(x, (HW_uSDHC_INT_SIGNAL_EN_RD(x) & ~BM_uSDHC_INT_SIGNAL_EN_DMAEIEN) | BF_uSDHC_INT_SIGNAL_EN_DMAEIEN(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_AUTOCMD12_ERR_STATUS - Auto CMD12 Error Status
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_AUTOCMD12_ERR_STATUS - Auto CMD12 Error Status (RW)
 *
 * Reset value: 0x00000000U
 *
 * When the Auto CMD12 Error Status bit in the Status register is set, the Host
 * Driver shall check this register to identify what kind of error the Auto CMD12
 * / CMD 23 indicated. Auto CMD23 errors are indicated in bit 04-01.This
 * register is valid only when the Auto CMD12 Error status bit is set. The table bwlow
 * shows the relationship between the Auto CMGD12 CRC Error and the Auto CMD12
 * Command Timeout Error. Relationship Between Command CRC Error and Command Timeout
 * Error for Auto CMD12 Auto CMD12 CRC Error Auto CMD12 Timeout Error Type of
 * Error 0 0 No Error 0 1 Response Timeout Error 1 0 Response CRC Error 1 1 CMD
 * line conflict Changes in Auto CMD12 Error Status register can be classified in
 * three scenarios: When the uSDHC is going to issue an Auto CMD12. Set bit 0 to 1
 * if the Auto CMD12 can't be issued due to an error in the previous command Set
 * bit 0 to 0 if the Auto CMD12 is issued At the end bit of an Auto CMD12
 * response. Check errors correspond to bits 1-4. Set bits 1-4 corresponding to detected
 * errors. Clear bits 1-4 corresponding to detected errors Before reading the
 * Auto CMD12 Error Status bit 7. Set bit 7 to 1 if there is a command that can't
 * be issued Clear bit 7 if there is no command to issue The timing for generating
 * the Auto CMD12 Error and writing to the Command register are asynchronous.
 * After that, bit 7 shall be sampled when the driver is not writing to the Command
 * register. So it is suggested to read this register only when the AC12E bit in
 * Interrupt Status register is set. An Auto CMD12 Error Interrupt is generated
 * when one of the error bits (0-4) is set to 1. The Command Not Issued By Auto
 * CMD12 Error does not generate an interrupt.
 */
typedef union _hw_usdhc_autocmd12_err_status
{
    uint32_t U;
    struct _hw_usdhc_autocmd12_err_status_bitfields
    {
        uint32_t AC12NE : 1;           /*!< [0] Auto CMD12 Not Executed */
        uint32_t AC12TOE : 1;          /*!< [1] Auto CMD12 / 23 Timeout Error */
        uint32_t AC12EBE : 1;          /*!< [2] Auto CMD12 / 23 End Bit Error */
        uint32_t AC12CE : 1;           /*!< [3] Auto CMD12 / 23 CRC Error */
        uint32_t AC12IE : 1;           /*!< [4] Auto CMD12 / 23 Index Error */
        uint32_t RESERVED0 : 2;        /*!< [6:5]  */
        uint32_t CNIBAC12E : 1;        /*!< [7] Command Not Issued By Auto CMD12
                                        * Error */
        uint32_t RESERVED1 : 14;       /*!< [21:8]  */
        uint32_t EXECUTE_TUNING : 1;   /*!< [22] Execute Tuning */
        uint32_t SMP_CLK_SEL : 1;      /*!< [23] Sample Clock Select */
        uint32_t RESERVED2 : 8;        /*!< [31:24]  */
    } B;
} hw_usdhc_autocmd12_err_status_t;

/*!
 * @name Constants and macros for entire uSDHC_AUTOCMD12_ERR_STATUS register
 */
/*@{*/
#define HW_uSDHC_AUTOCMD12_ERR_STATUS_ADDR(x) ((uintptr_t)(x) + 0x3CU)

#define HW_uSDHC_AUTOCMD12_ERR_STATUS(x) (*(__IO hw_usdhc_autocmd12_err_status_t *) HW_uSDHC_AUTOCMD12_ERR_STATUS_ADDR(x))
#define HW_uSDHC_AUTOCMD12_ERR_STATUS_RD(x) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).U)
#define HW_uSDHC_AUTOCMD12_ERR_STATUS_WR(x, v) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).U = (v))
#define HW_uSDHC_AUTOCMD12_ERR_STATUS_SET(x, v) (HW_uSDHC_AUTOCMD12_ERR_STATUS_WR(x, HW_uSDHC_AUTOCMD12_ERR_STATUS_RD(x) |  (v)))
#define HW_uSDHC_AUTOCMD12_ERR_STATUS_CLR(x, v) (HW_uSDHC_AUTOCMD12_ERR_STATUS_WR(x, HW_uSDHC_AUTOCMD12_ERR_STATUS_RD(x) & ~(v)))
#define HW_uSDHC_AUTOCMD12_ERR_STATUS_TOG(x, v) (HW_uSDHC_AUTOCMD12_ERR_STATUS_WR(x, HW_uSDHC_AUTOCMD12_ERR_STATUS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_AUTOCMD12_ERR_STATUS bitfields
 */

/*!
 * @name Register uSDHC_AUTOCMD12_ERR_STATUS, field AC12NE[0] (RO)
 *
 * If memory multiple block data transfer is not started, due to a command
 * error, this bit is not set because it is not necessary to issue an Auto CMD12.
 * Setting this bit to 1 means the uSDHC cannot issue the Auto CMD12 to stop a memory
 * multiple block data transfer due to some error. If this bit is set to 1,
 * other error status bits (1-4) have no meaning.
 *
 * Values:
 * - 1 - Not executed
 * - 0 - Executed
 */
/*@{*/
#define BP_uSDHC_AUTOCMD12_ERR_STATUS_AC12NE (0U) /*!< Bit position for uSDHC_AUTOCMD12_ERR_STATUS_AC12NE. */
#define BM_uSDHC_AUTOCMD12_ERR_STATUS_AC12NE (0x00000001U) /*!< Bit mask for uSDHC_AUTOCMD12_ERR_STATUS_AC12NE. */
#define BS_uSDHC_AUTOCMD12_ERR_STATUS_AC12NE (1U) /*!< Bit field size in bits for uSDHC_AUTOCMD12_ERR_STATUS_AC12NE. */

/*! @brief Read current value of the uSDHC_AUTOCMD12_ERR_STATUS_AC12NE field. */
#define BR_uSDHC_AUTOCMD12_ERR_STATUS_AC12NE(x) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).B.AC12NE)
/*@}*/

/*!
 * @name Register uSDHC_AUTOCMD12_ERR_STATUS, field AC12TOE[1] (RO)
 *
 * Occurs if no response is returned within 64 SDCLK cycles from the end bit of
 * the command. If this bit is set to1, the other error status bits (2-4) have no
 * meaning.
 *
 * Values:
 * - 1 - Time out
 * - 0 - No error
 */
/*@{*/
#define BP_uSDHC_AUTOCMD12_ERR_STATUS_AC12TOE (1U) /*!< Bit position for uSDHC_AUTOCMD12_ERR_STATUS_AC12TOE. */
#define BM_uSDHC_AUTOCMD12_ERR_STATUS_AC12TOE (0x00000002U) /*!< Bit mask for uSDHC_AUTOCMD12_ERR_STATUS_AC12TOE. */
#define BS_uSDHC_AUTOCMD12_ERR_STATUS_AC12TOE (1U) /*!< Bit field size in bits for uSDHC_AUTOCMD12_ERR_STATUS_AC12TOE. */

/*! @brief Read current value of the uSDHC_AUTOCMD12_ERR_STATUS_AC12TOE field. */
#define BR_uSDHC_AUTOCMD12_ERR_STATUS_AC12TOE(x) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).B.AC12TOE)
/*@}*/

/*!
 * @name Register uSDHC_AUTOCMD12_ERR_STATUS, field AC12EBE[2] (RO)
 *
 * Occurs when detecting that the end bit of command response is 0 which should
 * be 1.
 *
 * Values:
 * - 1 - End Bit Error Generated
 * - 0 - No error
 */
/*@{*/
#define BP_uSDHC_AUTOCMD12_ERR_STATUS_AC12EBE (2U) /*!< Bit position for uSDHC_AUTOCMD12_ERR_STATUS_AC12EBE. */
#define BM_uSDHC_AUTOCMD12_ERR_STATUS_AC12EBE (0x00000004U) /*!< Bit mask for uSDHC_AUTOCMD12_ERR_STATUS_AC12EBE. */
#define BS_uSDHC_AUTOCMD12_ERR_STATUS_AC12EBE (1U) /*!< Bit field size in bits for uSDHC_AUTOCMD12_ERR_STATUS_AC12EBE. */

/*! @brief Read current value of the uSDHC_AUTOCMD12_ERR_STATUS_AC12EBE field. */
#define BR_uSDHC_AUTOCMD12_ERR_STATUS_AC12EBE(x) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).B.AC12EBE)
/*@}*/

/*!
 * @name Register uSDHC_AUTOCMD12_ERR_STATUS, field AC12CE[3] (RO)
 *
 * Occurs when detecting a CRC error in the command response.
 *
 * Values:
 * - 1 - CRC Error Met in Auto CMD12/23 Response
 * - 0 - No CRC error
 */
/*@{*/
#define BP_uSDHC_AUTOCMD12_ERR_STATUS_AC12CE (3U) /*!< Bit position for uSDHC_AUTOCMD12_ERR_STATUS_AC12CE. */
#define BM_uSDHC_AUTOCMD12_ERR_STATUS_AC12CE (0x00000008U) /*!< Bit mask for uSDHC_AUTOCMD12_ERR_STATUS_AC12CE. */
#define BS_uSDHC_AUTOCMD12_ERR_STATUS_AC12CE (1U) /*!< Bit field size in bits for uSDHC_AUTOCMD12_ERR_STATUS_AC12CE. */

/*! @brief Read current value of the uSDHC_AUTOCMD12_ERR_STATUS_AC12CE field. */
#define BR_uSDHC_AUTOCMD12_ERR_STATUS_AC12CE(x) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).B.AC12CE)
/*@}*/

/*!
 * @name Register uSDHC_AUTOCMD12_ERR_STATUS, field AC12IE[4] (RO)
 *
 * Occurs if the Command Index error occurs in response to a command.
 *
 * Values:
 * - 1 - Error, the CMD index in response is not CMD12/23
 * - 0 - No error
 */
/*@{*/
#define BP_uSDHC_AUTOCMD12_ERR_STATUS_AC12IE (4U) /*!< Bit position for uSDHC_AUTOCMD12_ERR_STATUS_AC12IE. */
#define BM_uSDHC_AUTOCMD12_ERR_STATUS_AC12IE (0x00000010U) /*!< Bit mask for uSDHC_AUTOCMD12_ERR_STATUS_AC12IE. */
#define BS_uSDHC_AUTOCMD12_ERR_STATUS_AC12IE (1U) /*!< Bit field size in bits for uSDHC_AUTOCMD12_ERR_STATUS_AC12IE. */

/*! @brief Read current value of the uSDHC_AUTOCMD12_ERR_STATUS_AC12IE field. */
#define BR_uSDHC_AUTOCMD12_ERR_STATUS_AC12IE(x) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).B.AC12IE)
/*@}*/

/*!
 * @name Register uSDHC_AUTOCMD12_ERR_STATUS, field CNIBAC12E[7] (RO)
 *
 * Setting this bit to 1 means CMD_wo_DAT is not executed due to an Auto CMD12
 * Error (D04-D01) in this register.
 *
 * Values:
 * - 1 - Not Issued
 * - 0 - No error
 */
/*@{*/
#define BP_uSDHC_AUTOCMD12_ERR_STATUS_CNIBAC12E (7U) /*!< Bit position for uSDHC_AUTOCMD12_ERR_STATUS_CNIBAC12E. */
#define BM_uSDHC_AUTOCMD12_ERR_STATUS_CNIBAC12E (0x00000080U) /*!< Bit mask for uSDHC_AUTOCMD12_ERR_STATUS_CNIBAC12E. */
#define BS_uSDHC_AUTOCMD12_ERR_STATUS_CNIBAC12E (1U) /*!< Bit field size in bits for uSDHC_AUTOCMD12_ERR_STATUS_CNIBAC12E. */

/*! @brief Read current value of the uSDHC_AUTOCMD12_ERR_STATUS_CNIBAC12E field. */
#define BR_uSDHC_AUTOCMD12_ERR_STATUS_CNIBAC12E(x) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).B.CNIBAC12E)
/*@}*/

/*!
 * @name Register uSDHC_AUTOCMD12_ERR_STATUS, field EXECUTE_TUNING[22] (RW)
 *
 * When std_tuning_en bit is set, this bit is used to start tuning procedure.
 * Otherwise, this bit is reserved. This bit is set to start tuning procedure and
 * automatically cleared when runing procedure is completed. The result of tuning
 * is indicated to sam_clk_sel bit. Tuning procedure is aborted by writing 0.
 */
/*@{*/
#define BP_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING (22U) /*!< Bit position for uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING. */
#define BM_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING (0x00400000U) /*!< Bit mask for uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING. */
#define BS_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING (1U) /*!< Bit field size in bits for uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING. */

/*! @brief Read current value of the uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING field. */
#define BR_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING(x) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).B.EXECUTE_TUNING)

/*! @brief Format value for bitfield uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING. */
#define BF_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING) & BM_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING)

/*! @brief Set the EXECUTE_TUNING field to a new value. */
#define BW_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING(x, v) (HW_uSDHC_AUTOCMD12_ERR_STATUS_WR(x, (HW_uSDHC_AUTOCMD12_ERR_STATUS_RD(x) & ~BM_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING) | BF_uSDHC_AUTOCMD12_ERR_STATUS_EXECUTE_TUNING(v)))
/*@}*/

/*!
 * @name Register uSDHC_AUTOCMD12_ERR_STATUS, field SMP_CLK_SEL[23] (RW)
 *
 * When std_tuning_en bit is set, this bit is used to select sampling clock to
 * receive CMD and DATA. Otherwise, this bit is reserved. This bit is set by ty
 * tuning procedure and valid after the completion of tuning(When Execute Tuning is
 * cleared). Setting 1 means that tuning is completed successfully and setting 0
 * means that tuning is failed. Writing 1 to this bit is meaningless and
 * ignored. A tuning circuit is reset by writing to 0. This bit can be cleared with
 * setting Execute Tuning. Once the tuning circuit is reset, it will take time to
 * complete tuning sequence. Therefore, Host Driver should keep this bit to 1 to
 * perform re-tuning sequence to complete re-tuning sequence in a short time. Change
 * of this bit is not allowed while the Host controller us receiving response or
 * a read data block.
 *
 * Values:
 * - 1 - Tuned clock is used to sample data
 * - 0 - Fixed clock is used to sample data
 */
/*@{*/
#define BP_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL (23U) /*!< Bit position for uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL. */
#define BM_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL (0x00800000U) /*!< Bit mask for uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL. */
#define BS_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL (1U) /*!< Bit field size in bits for uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL. */

/*! @brief Read current value of the uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL field. */
#define BR_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL(x) (HW_uSDHC_AUTOCMD12_ERR_STATUS(x).B.SMP_CLK_SEL)

/*! @brief Format value for bitfield uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL. */
#define BF_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL) & BM_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL)

/*! @brief Set the SMP_CLK_SEL field to a new value. */
#define BW_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL(x, v) (HW_uSDHC_AUTOCMD12_ERR_STATUS_WR(x, (HW_uSDHC_AUTOCMD12_ERR_STATUS_RD(x) & ~BM_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL) | BF_uSDHC_AUTOCMD12_ERR_STATUS_SMP_CLK_SEL(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_HOST_CTRL_CAP - Host Controller Capabilities
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_HOST_CTRL_CAP - Host Controller Capabilities (RW)
 *
 * Reset value: 0x07F3B407U
 *
 * This register provides the Host Driver with information specific to the uSDHC
 * implementation. The value in this register is the power-on-reset value, and
 * does not change with a software reset.
 */
typedef union _hw_usdhc_host_ctrl_cap
{
    uint32_t U;
    struct _hw_usdhc_host_ctrl_cap_bitfields
    {
        uint32_t SDR50_SUPPORT : 1;    /*!< [0] SDR50 support */
        uint32_t SDR104_SUPPORT : 1;   /*!< [1] SDR104 support */
        uint32_t DDR50_SUPPORT : 1;    /*!< [2] DDR50 support */
        uint32_t RESERVED0 : 5;        /*!< [7:3]  */
        uint32_t TIME_COUNT_RETUNING : 4; /*!< [11:8] Time Counter for
                                        * Retuning */
        uint32_t RESERVED1 : 1;        /*!< [12]  */
        uint32_t USE_TUNING_SDR50 : 1; /*!< [13] Use Tuning for SDR50 */
        uint32_t RETUNING_MODE : 2;    /*!< [15:14] Retuning Mode */
        uint32_t MBL : 3;              /*!< [18:16] Max Block Length */
        uint32_t RESERVED2 : 1;        /*!< [19]  */
        uint32_t ADMAS : 1;            /*!< [20] ADMA Support */
        uint32_t HSS : 1;              /*!< [21] High Speed Support */
        uint32_t DMAS : 1;             /*!< [22] DMA Support */
        uint32_t SRS : 1;              /*!< [23] Suspend / Resume Support */
        uint32_t VS33 : 1;             /*!< [24] Voltage Support 3.3V */
        uint32_t VS30 : 1;             /*!< [25] Voltage Support 3.0 V */
        uint32_t VS18 : 1;             /*!< [26] Voltage Support 1.8 V */
        uint32_t RESERVED3 : 5;        /*!< [31:27]  */
    } B;
} hw_usdhc_host_ctrl_cap_t;

/*!
 * @name Constants and macros for entire uSDHC_HOST_CTRL_CAP register
 */
/*@{*/
#define HW_uSDHC_HOST_CTRL_CAP_ADDR(x) ((uintptr_t)(x) + 0x40U)

#define HW_uSDHC_HOST_CTRL_CAP(x) (*(__IO hw_usdhc_host_ctrl_cap_t *) HW_uSDHC_HOST_CTRL_CAP_ADDR(x))
#define HW_uSDHC_HOST_CTRL_CAP_RD(x) (HW_uSDHC_HOST_CTRL_CAP(x).U)
#define HW_uSDHC_HOST_CTRL_CAP_WR(x, v) (HW_uSDHC_HOST_CTRL_CAP(x).U = (v))
#define HW_uSDHC_HOST_CTRL_CAP_SET(x, v) (HW_uSDHC_HOST_CTRL_CAP_WR(x, HW_uSDHC_HOST_CTRL_CAP_RD(x) |  (v)))
#define HW_uSDHC_HOST_CTRL_CAP_CLR(x, v) (HW_uSDHC_HOST_CTRL_CAP_WR(x, HW_uSDHC_HOST_CTRL_CAP_RD(x) & ~(v)))
#define HW_uSDHC_HOST_CTRL_CAP_TOG(x, v) (HW_uSDHC_HOST_CTRL_CAP_WR(x, HW_uSDHC_HOST_CTRL_CAP_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_HOST_CTRL_CAP bitfields
 */

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field SDR50_SUPPORT[0] (RO)
 *
 * This bit indicates support of SDR50 mode.
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_SDR50_SUPPORT (0U) /*!< Bit position for uSDHC_HOST_CTRL_CAP_SDR50_SUPPORT. */
#define BM_uSDHC_HOST_CTRL_CAP_SDR50_SUPPORT (0x00000001U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_SDR50_SUPPORT. */
#define BS_uSDHC_HOST_CTRL_CAP_SDR50_SUPPORT (1U) /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_SDR50_SUPPORT. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_SDR50_SUPPORT field. */
#define BR_uSDHC_HOST_CTRL_CAP_SDR50_SUPPORT(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.SDR50_SUPPORT)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field SDR104_SUPPORT[1] (RO)
 *
 * This bit indicates support of SDR104 mode.
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_SDR104_SUPPORT (1U) /*!< Bit position for uSDHC_HOST_CTRL_CAP_SDR104_SUPPORT. */
#define BM_uSDHC_HOST_CTRL_CAP_SDR104_SUPPORT (0x00000002U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_SDR104_SUPPORT. */
#define BS_uSDHC_HOST_CTRL_CAP_SDR104_SUPPORT (1U) /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_SDR104_SUPPORT. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_SDR104_SUPPORT field. */
#define BR_uSDHC_HOST_CTRL_CAP_SDR104_SUPPORT(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.SDR104_SUPPORT)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field DDR50_SUPPORT[2] (RO)
 *
 * This bit indicates support of DDR50 mode.
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_DDR50_SUPPORT (2U) /*!< Bit position for uSDHC_HOST_CTRL_CAP_DDR50_SUPPORT. */
#define BM_uSDHC_HOST_CTRL_CAP_DDR50_SUPPORT (0x00000004U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_DDR50_SUPPORT. */
#define BS_uSDHC_HOST_CTRL_CAP_DDR50_SUPPORT (1U) /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_DDR50_SUPPORT. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_DDR50_SUPPORT field. */
#define BR_uSDHC_HOST_CTRL_CAP_DDR50_SUPPORT(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.DDR50_SUPPORT)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field TIME_COUNT_RETUNING[11:8] (RW)
 *
 * This bit indicates an initial value of the Retuning Timer for Re-Tuning Mode1
 * and 3.Setting to 0 disables Retuning Timer.
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING (8U) /*!< Bit position for uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING. */
#define BM_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING (0x00000F00U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING. */
#define BS_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING (4U) /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING field. */
#define BR_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.TIME_COUNT_RETUNING)

/*! @brief Format value for bitfield uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING. */
#define BF_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING) & BM_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING)

/*! @brief Set the TIME_COUNT_RETUNING field to a new value. */
#define BW_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING(x, v) (HW_uSDHC_HOST_CTRL_CAP_WR(x, (HW_uSDHC_HOST_CTRL_CAP_RD(x) & ~BM_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING) | BF_uSDHC_HOST_CTRL_CAP_TIME_COUNT_RETUNING(v)))
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field USE_TUNING_SDR50[13] (RW)
 *
 * This bit is set to 1. Host controller requires tuning to operate SDR50
 *
 * Values:
 * - 1 - SDR50 requires tuning
 * - 0 - SDR does not require tuning
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50 (13U) /*!< Bit position for uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50. */
#define BM_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50 (0x00002000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50. */
#define BS_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50 (1U) /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50 field. */
#define BR_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.USE_TUNING_SDR50)

/*! @brief Format value for bitfield uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50. */
#define BF_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50) & BM_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50)

/*! @brief Set the USE_TUNING_SDR50 field to a new value. */
#define BW_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50(x, v) (HW_uSDHC_HOST_CTRL_CAP_WR(x, (HW_uSDHC_HOST_CTRL_CAP_RD(x) & ~BM_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50) | BF_uSDHC_HOST_CTRL_CAP_USE_TUNING_SDR50(v)))
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field RETUNING_MODE[15:14] (RO)
 *
 * This bit selects retuning method.
 *
 * Values:
 * - 00 - Mode 1
 * - 01 - Mode 2
 * - 10 - Mode 3
 * - 11 - Reserved
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_RETUNING_MODE (14U) /*!< Bit position for uSDHC_HOST_CTRL_CAP_RETUNING_MODE. */
#define BM_uSDHC_HOST_CTRL_CAP_RETUNING_MODE (0x0000C000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_RETUNING_MODE. */
#define BS_uSDHC_HOST_CTRL_CAP_RETUNING_MODE (2U) /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_RETUNING_MODE. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_RETUNING_MODE field. */
#define BR_uSDHC_HOST_CTRL_CAP_RETUNING_MODE(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.RETUNING_MODE)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field MBL[18:16] (RO)
 *
 * This value indicates the maximum block size that the Host Driver can read and
 * write to the buffer in the uSDHC. The buffer shall transfer block size
 * without wait cycles.
 *
 * Values:
 * - 000 - 512 bytes
 * - 001 - 1024 bytes
 * - 010 - 2048 bytes
 * - 011 - 4096 bytes
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_MBL (16U)   /*!< Bit position for uSDHC_HOST_CTRL_CAP_MBL. */
#define BM_uSDHC_HOST_CTRL_CAP_MBL (0x00070000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_MBL. */
#define BS_uSDHC_HOST_CTRL_CAP_MBL (3U)    /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_MBL. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_MBL field. */
#define BR_uSDHC_HOST_CTRL_CAP_MBL(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.MBL)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field ADMAS[20] (RO)
 *
 * This bit indicates whether the uSDHC supports the ADMA feature.
 *
 * Values:
 * - 1 - Advanced DMA Supported
 * - 0 - Advanced DMA Not supported
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_ADMAS (20U) /*!< Bit position for uSDHC_HOST_CTRL_CAP_ADMAS. */
#define BM_uSDHC_HOST_CTRL_CAP_ADMAS (0x00100000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_ADMAS. */
#define BS_uSDHC_HOST_CTRL_CAP_ADMAS (1U)  /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_ADMAS. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_ADMAS field. */
#define BR_uSDHC_HOST_CTRL_CAP_ADMAS(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.ADMAS)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field HSS[21] (RO)
 *
 * This bit indicates whether the uSDHC supports High Speed mode and the Host
 * System can supply a SD Clock frequency from 25 MHz to 50 MHz.
 *
 * Values:
 * - 1 - High Speed Supported
 * - 0 - High Speed Not Supported
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_HSS (21U)   /*!< Bit position for uSDHC_HOST_CTRL_CAP_HSS. */
#define BM_uSDHC_HOST_CTRL_CAP_HSS (0x00200000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_HSS. */
#define BS_uSDHC_HOST_CTRL_CAP_HSS (1U)    /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_HSS. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_HSS field. */
#define BR_uSDHC_HOST_CTRL_CAP_HSS(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.HSS)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field DMAS[22] (RO)
 *
 * This bit indicates whether the uSDHC is capable of using the internal DMA to
 * transfer data between system memory and the data buffer directly.
 *
 * Values:
 * - 1 - DMA Supported
 * - 0 - DMA not supported
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_DMAS (22U)  /*!< Bit position for uSDHC_HOST_CTRL_CAP_DMAS. */
#define BM_uSDHC_HOST_CTRL_CAP_DMAS (0x00400000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_DMAS. */
#define BS_uSDHC_HOST_CTRL_CAP_DMAS (1U)   /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_DMAS. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_DMAS field. */
#define BR_uSDHC_HOST_CTRL_CAP_DMAS(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.DMAS)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field SRS[23] (RO)
 *
 * This bit indicates whether the uSDHC supports Suspend / Resume functionality.
 * If this bit is 0, the Suspend and Resume mechanism, as well as the Read Wait,
 * are not supported, and the Host Driver shall not issue either Suspend or
 * Resume commands.
 *
 * Values:
 * - 1 - Supported
 * - 0 - Not supported
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_SRS (23U)   /*!< Bit position for uSDHC_HOST_CTRL_CAP_SRS. */
#define BM_uSDHC_HOST_CTRL_CAP_SRS (0x00800000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_SRS. */
#define BS_uSDHC_HOST_CTRL_CAP_SRS (1U)    /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_SRS. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_SRS field. */
#define BR_uSDHC_HOST_CTRL_CAP_SRS(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.SRS)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field VS33[24] (RO)
 *
 * This bit shall depend on the Host System ability.
 *
 * Values:
 * - 1 - 3.3V supported
 * - 0 - 3.3V not supported
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_VS33 (24U)  /*!< Bit position for uSDHC_HOST_CTRL_CAP_VS33. */
#define BM_uSDHC_HOST_CTRL_CAP_VS33 (0x01000000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_VS33. */
#define BS_uSDHC_HOST_CTRL_CAP_VS33 (1U)   /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_VS33. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_VS33 field. */
#define BR_uSDHC_HOST_CTRL_CAP_VS33(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.VS33)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field VS30[25] (RO)
 *
 * This bit shall depend on the Host System ability.
 *
 * Values:
 * - 1 - 3.0V supported
 * - 0 - 3.0V not supported
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_VS30 (25U)  /*!< Bit position for uSDHC_HOST_CTRL_CAP_VS30. */
#define BM_uSDHC_HOST_CTRL_CAP_VS30 (0x02000000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_VS30. */
#define BS_uSDHC_HOST_CTRL_CAP_VS30 (1U)   /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_VS30. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_VS30 field. */
#define BR_uSDHC_HOST_CTRL_CAP_VS30(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.VS30)
/*@}*/

/*!
 * @name Register uSDHC_HOST_CTRL_CAP, field VS18[26] (RO)
 *
 * This bit shall depend on the Host System ability.
 *
 * Values:
 * - 1 - 1.8V supported
 * - 0 - 1.8V not supported
 */
/*@{*/
#define BP_uSDHC_HOST_CTRL_CAP_VS18 (26U)  /*!< Bit position for uSDHC_HOST_CTRL_CAP_VS18. */
#define BM_uSDHC_HOST_CTRL_CAP_VS18 (0x04000000U) /*!< Bit mask for uSDHC_HOST_CTRL_CAP_VS18. */
#define BS_uSDHC_HOST_CTRL_CAP_VS18 (1U)   /*!< Bit field size in bits for uSDHC_HOST_CTRL_CAP_VS18. */

/*! @brief Read current value of the uSDHC_HOST_CTRL_CAP_VS18 field. */
#define BR_uSDHC_HOST_CTRL_CAP_VS18(x) (HW_uSDHC_HOST_CTRL_CAP(x).B.VS18)
/*@}*/

/*******************************************************************************
 * HW_uSDHC_WTMK_LVL - Watermark Level
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_WTMK_LVL - Watermark Level (RW)
 *
 * Reset value: 0x08100810U
 *
 * Both write and read watermark levels (FIFO threshold) are configurable. There
 * value can range from 1 to 128 words. Both write and read burst lengths are
 * also Configurable. There value can range from 1 to 31 words.
 */
typedef union _hw_usdhc_wtmk_lvl
{
    uint32_t U;
    struct _hw_usdhc_wtmk_lvl_bitfields
    {
        uint32_t RD_WML : 8;           /*!< [7:0] Read Watermark Level */
        uint32_t RD_BRST_LEN : 5;      /*!< [12:8] Read Burst Length Due to system
                                        * restriction, the actual burst length may not exceed 16. */
        uint32_t RESERVED0 : 3;        /*!< [15:13]  */
        uint32_t WR_WML : 8;           /*!< [23:16] Write Watermark Level */
        uint32_t WR_BRST_LEN : 5;      /*!< [28:24] Write Burst Length Due to
                                        * system restriction, the actual burst length may not exceed 16. */
        uint32_t RESERVED1 : 3;        /*!< [31:29]  */
    } B;
} hw_usdhc_wtmk_lvl_t;

/*!
 * @name Constants and macros for entire uSDHC_WTMK_LVL register
 */
/*@{*/
#define HW_uSDHC_WTMK_LVL_ADDR(x) ((uintptr_t)(x) + 0x44U)

#define HW_uSDHC_WTMK_LVL(x)     (*(__IO hw_usdhc_wtmk_lvl_t *) HW_uSDHC_WTMK_LVL_ADDR(x))
#define HW_uSDHC_WTMK_LVL_RD(x)  (HW_uSDHC_WTMK_LVL(x).U)
#define HW_uSDHC_WTMK_LVL_WR(x, v) (HW_uSDHC_WTMK_LVL(x).U = (v))
#define HW_uSDHC_WTMK_LVL_SET(x, v) (HW_uSDHC_WTMK_LVL_WR(x, HW_uSDHC_WTMK_LVL_RD(x) |  (v)))
#define HW_uSDHC_WTMK_LVL_CLR(x, v) (HW_uSDHC_WTMK_LVL_WR(x, HW_uSDHC_WTMK_LVL_RD(x) & ~(v)))
#define HW_uSDHC_WTMK_LVL_TOG(x, v) (HW_uSDHC_WTMK_LVL_WR(x, HW_uSDHC_WTMK_LVL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_WTMK_LVL bitfields
 */

/*!
 * @name Register uSDHC_WTMK_LVL, field RD_WML[7:0] (RW)
 *
 * The number of words used as the watermark level (FIFO threshold) in a DMA
 * read operation. Also the number of words as a sequence of read bursts in
 * back-to-back mode. The maximum legal value for the read water mark level is 128.
 */
/*@{*/
#define BP_uSDHC_WTMK_LVL_RD_WML (0U)      /*!< Bit position for uSDHC_WTMK_LVL_RD_WML. */
#define BM_uSDHC_WTMK_LVL_RD_WML (0x000000FFU) /*!< Bit mask for uSDHC_WTMK_LVL_RD_WML. */
#define BS_uSDHC_WTMK_LVL_RD_WML (8U)      /*!< Bit field size in bits for uSDHC_WTMK_LVL_RD_WML. */

/*! @brief Read current value of the uSDHC_WTMK_LVL_RD_WML field. */
#define BR_uSDHC_WTMK_LVL_RD_WML(x) (HW_uSDHC_WTMK_LVL(x).B.RD_WML)

/*! @brief Format value for bitfield uSDHC_WTMK_LVL_RD_WML. */
#define BF_uSDHC_WTMK_LVL_RD_WML(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_WTMK_LVL_RD_WML) & BM_uSDHC_WTMK_LVL_RD_WML)

/*! @brief Set the RD_WML field to a new value. */
#define BW_uSDHC_WTMK_LVL_RD_WML(x, v) (HW_uSDHC_WTMK_LVL_WR(x, (HW_uSDHC_WTMK_LVL_RD(x) & ~BM_uSDHC_WTMK_LVL_RD_WML) | BF_uSDHC_WTMK_LVL_RD_WML(v)))
/*@}*/

/*!
 * @name Register uSDHC_WTMK_LVL, field RD_BRST_LEN[12:8] (RW)
 *
 * The number of words the uSDHC reads in a single burst. The read burst length
 * must be less than or equal to the read watermark level, and all bursts within
 * a watermark level transfer will be in back-to-back mode. On reset, this field
 * will be 8. Writing 0 to this field will result in '01000' (i.e. it is not able
 * to clear this field).
 */
/*@{*/
#define BP_uSDHC_WTMK_LVL_RD_BRST_LEN (8U) /*!< Bit position for uSDHC_WTMK_LVL_RD_BRST_LEN. */
#define BM_uSDHC_WTMK_LVL_RD_BRST_LEN (0x00001F00U) /*!< Bit mask for uSDHC_WTMK_LVL_RD_BRST_LEN. */
#define BS_uSDHC_WTMK_LVL_RD_BRST_LEN (5U) /*!< Bit field size in bits for uSDHC_WTMK_LVL_RD_BRST_LEN. */

/*! @brief Read current value of the uSDHC_WTMK_LVL_RD_BRST_LEN field. */
#define BR_uSDHC_WTMK_LVL_RD_BRST_LEN(x) (HW_uSDHC_WTMK_LVL(x).B.RD_BRST_LEN)

/*! @brief Format value for bitfield uSDHC_WTMK_LVL_RD_BRST_LEN. */
#define BF_uSDHC_WTMK_LVL_RD_BRST_LEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_WTMK_LVL_RD_BRST_LEN) & BM_uSDHC_WTMK_LVL_RD_BRST_LEN)

/*! @brief Set the RD_BRST_LEN field to a new value. */
#define BW_uSDHC_WTMK_LVL_RD_BRST_LEN(x, v) (HW_uSDHC_WTMK_LVL_WR(x, (HW_uSDHC_WTMK_LVL_RD(x) & ~BM_uSDHC_WTMK_LVL_RD_BRST_LEN) | BF_uSDHC_WTMK_LVL_RD_BRST_LEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_WTMK_LVL, field WR_WML[23:16] (RW)
 *
 * The number of words used as the watermark level (FIFO threshold) in a DMA
 * write operation. Also the number of words as a sequence of write bursts in
 * back-to-back mode. The maximum legal value for the write watermark level is 128.
 */
/*@{*/
#define BP_uSDHC_WTMK_LVL_WR_WML (16U)     /*!< Bit position for uSDHC_WTMK_LVL_WR_WML. */
#define BM_uSDHC_WTMK_LVL_WR_WML (0x00FF0000U) /*!< Bit mask for uSDHC_WTMK_LVL_WR_WML. */
#define BS_uSDHC_WTMK_LVL_WR_WML (8U)      /*!< Bit field size in bits for uSDHC_WTMK_LVL_WR_WML. */

/*! @brief Read current value of the uSDHC_WTMK_LVL_WR_WML field. */
#define BR_uSDHC_WTMK_LVL_WR_WML(x) (HW_uSDHC_WTMK_LVL(x).B.WR_WML)

/*! @brief Format value for bitfield uSDHC_WTMK_LVL_WR_WML. */
#define BF_uSDHC_WTMK_LVL_WR_WML(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_WTMK_LVL_WR_WML) & BM_uSDHC_WTMK_LVL_WR_WML)

/*! @brief Set the WR_WML field to a new value. */
#define BW_uSDHC_WTMK_LVL_WR_WML(x, v) (HW_uSDHC_WTMK_LVL_WR(x, (HW_uSDHC_WTMK_LVL_RD(x) & ~BM_uSDHC_WTMK_LVL_WR_WML) | BF_uSDHC_WTMK_LVL_WR_WML(v)))
/*@}*/

/*!
 * @name Register uSDHC_WTMK_LVL, field WR_BRST_LEN[28:24] (RW)
 *
 * The number of words the uSDHC writes in a single burst. The write burst
 * length must be less than or equal to the write watermark level, and all bursts
 * within a watermark level transfer will be in back-to-back mode. On reset, this
 * field will be 8. Writing 0 to this field will result in '01000' (i.e. it is not
 * able to clear this field).
 */
/*@{*/
#define BP_uSDHC_WTMK_LVL_WR_BRST_LEN (24U) /*!< Bit position for uSDHC_WTMK_LVL_WR_BRST_LEN. */
#define BM_uSDHC_WTMK_LVL_WR_BRST_LEN (0x1F000000U) /*!< Bit mask for uSDHC_WTMK_LVL_WR_BRST_LEN. */
#define BS_uSDHC_WTMK_LVL_WR_BRST_LEN (5U) /*!< Bit field size in bits for uSDHC_WTMK_LVL_WR_BRST_LEN. */

/*! @brief Read current value of the uSDHC_WTMK_LVL_WR_BRST_LEN field. */
#define BR_uSDHC_WTMK_LVL_WR_BRST_LEN(x) (HW_uSDHC_WTMK_LVL(x).B.WR_BRST_LEN)

/*! @brief Format value for bitfield uSDHC_WTMK_LVL_WR_BRST_LEN. */
#define BF_uSDHC_WTMK_LVL_WR_BRST_LEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_WTMK_LVL_WR_BRST_LEN) & BM_uSDHC_WTMK_LVL_WR_BRST_LEN)

/*! @brief Set the WR_BRST_LEN field to a new value. */
#define BW_uSDHC_WTMK_LVL_WR_BRST_LEN(x, v) (HW_uSDHC_WTMK_LVL_WR(x, (HW_uSDHC_WTMK_LVL_RD(x) & ~BM_uSDHC_WTMK_LVL_WR_BRST_LEN) | BF_uSDHC_WTMK_LVL_WR_BRST_LEN(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_MIX_CTRL - Mixer Control
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_MIX_CTRL - Mixer Control (RW)
 *
 * Reset value: 0x80000000U
 *
 * This register is used to DMA and data transfer. To prevent data loss, The
 * software should check if data transfer is active before writing this register.
 * These bits are DPSEL, MBSEL, DTDSEL, AC12EN, BCEN, and DMAEN. Transfer Type
 * Register Setting for Various Transfer Types Multi/Single Block Select Block Count
 * Enable Block Count Function 0 Don't Care Don't Care Single Transfer 1 0 Don't
 * Care Infinite Transfer 1 1 Positive Number Multiple Transfer 1 1 Zero No Data
 * Transfer
 */
typedef union _hw_usdhc_mix_ctrl
{
    uint32_t U;
    struct _hw_usdhc_mix_ctrl_bitfields
    {
        uint32_t DMAEN : 1;            /*!< [0] DMA Enable */
        uint32_t BCEN : 1;             /*!< [1] Block Count Enable */
        uint32_t AC12EN : 1;           /*!< [2] Auto CMD12 Enable */
        uint32_t DDR_EN : 1;           /*!< [3] Dual Data Rate mode selection */
        uint32_t DTDSEL : 1;           /*!< [4] Data Transfer Direction Select */
        uint32_t MSBSEL : 1;           /*!< [5] Multi / Single Block Select */
        uint32_t NIBBLE_POS : 1;       /*!< [6]  */
        uint32_t AC23EN : 1;           /*!< [7] Auto CMD23 Enable */
        uint32_t RESERVED0 : 14;       /*!< [21:8]  */
        uint32_t EXE_TUNE : 1;         /*!< [22] Execute Tuning: (Only used for
                                        * SD3.0, SDR104 mode) */
        uint32_t SMP_CLK_SEL : 1;      /*!< [23]  */
        uint32_t AUTO_TUNE_EN : 1;     /*!< [24] Auto Tuning Enable (Only used
                                        * for SD3.0, SDR104 mode) */
        uint32_t FBCLK_SEL : 1;        /*!< [25] Feedback Clock Source Selection
                                        * (Only used for SD3.0, SDR104 mode) */
        uint32_t HS400_MODE : 1;       /*!< [26] Enable HS400 Mode */
        uint32_t RESERVED1 : 5;        /*!< [31:27]  */
    } B;
} hw_usdhc_mix_ctrl_t;

/*!
 * @name Constants and macros for entire uSDHC_MIX_CTRL register
 */
/*@{*/
#define HW_uSDHC_MIX_CTRL_ADDR(x) ((uintptr_t)(x) + 0x48U)

#define HW_uSDHC_MIX_CTRL(x)     (*(__IO hw_usdhc_mix_ctrl_t *) HW_uSDHC_MIX_CTRL_ADDR(x))
#define HW_uSDHC_MIX_CTRL_RD(x)  (HW_uSDHC_MIX_CTRL(x).U)
#define HW_uSDHC_MIX_CTRL_WR(x, v) (HW_uSDHC_MIX_CTRL(x).U = (v))
#define HW_uSDHC_MIX_CTRL_SET(x, v) (HW_uSDHC_MIX_CTRL_WR(x, HW_uSDHC_MIX_CTRL_RD(x) |  (v)))
#define HW_uSDHC_MIX_CTRL_CLR(x, v) (HW_uSDHC_MIX_CTRL_WR(x, HW_uSDHC_MIX_CTRL_RD(x) & ~(v)))
#define HW_uSDHC_MIX_CTRL_TOG(x, v) (HW_uSDHC_MIX_CTRL_WR(x, HW_uSDHC_MIX_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_MIX_CTRL bitfields
 */

/*!
 * @name Register uSDHC_MIX_CTRL, field DMAEN[0] (RW)
 *
 * This bit enables DMA functionality. If this bit is set to 1, a DMA operation
 * shall begin when the Host Driver sets the DPSEL bit of this register. Whether
 * the Simple DMA or the Advanced DMA is active depends on the DMA Select field
 * of the Protocol Control register.
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_DMAEN (0U)       /*!< Bit position for uSDHC_MIX_CTRL_DMAEN. */
#define BM_uSDHC_MIX_CTRL_DMAEN (0x00000001U) /*!< Bit mask for uSDHC_MIX_CTRL_DMAEN. */
#define BS_uSDHC_MIX_CTRL_DMAEN (1U)       /*!< Bit field size in bits for uSDHC_MIX_CTRL_DMAEN. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_DMAEN field. */
#define BR_uSDHC_MIX_CTRL_DMAEN(x) (HW_uSDHC_MIX_CTRL(x).B.DMAEN)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_DMAEN. */
#define BF_uSDHC_MIX_CTRL_DMAEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_DMAEN) & BM_uSDHC_MIX_CTRL_DMAEN)

/*! @brief Set the DMAEN field to a new value. */
#define BW_uSDHC_MIX_CTRL_DMAEN(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_DMAEN) | BF_uSDHC_MIX_CTRL_DMAEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field BCEN[1] (RW)
 *
 * This bit is used to enable the Block Count register, which is only relevant
 * for multiple block transfers. When this bit is 0, the internal counter for
 * block is disabled, which is useful in executing an infinite transfer.
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_BCEN (1U)        /*!< Bit position for uSDHC_MIX_CTRL_BCEN. */
#define BM_uSDHC_MIX_CTRL_BCEN (0x00000002U) /*!< Bit mask for uSDHC_MIX_CTRL_BCEN. */
#define BS_uSDHC_MIX_CTRL_BCEN (1U)        /*!< Bit field size in bits for uSDHC_MIX_CTRL_BCEN. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_BCEN field. */
#define BR_uSDHC_MIX_CTRL_BCEN(x) (HW_uSDHC_MIX_CTRL(x).B.BCEN)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_BCEN. */
#define BF_uSDHC_MIX_CTRL_BCEN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_BCEN) & BM_uSDHC_MIX_CTRL_BCEN)

/*! @brief Set the BCEN field to a new value. */
#define BW_uSDHC_MIX_CTRL_BCEN(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_BCEN) | BF_uSDHC_MIX_CTRL_BCEN(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field AC12EN[2] (RW)
 *
 * Multiple block transfers for memory require a CMD12 to stop the transaction.
 * When this bit is set to 1, the uSDHC will issue a CMD12 automatically when the
 * last block transfer has completed. The Host Driver shall not set this bit to
 * issue commands that do not require CMD12 to stop a multiple block data
 * transfer. In particular, secure commands defined in File Security Specification (see
 * reference list) do not require CMD12. In single block transfer, the uSDHC will
 * ignore this bit no matter it is set or not.
 *
 * Values:
 * - 1 - Enable
 * - 0 - Disable
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_AC12EN (2U)      /*!< Bit position for uSDHC_MIX_CTRL_AC12EN. */
#define BM_uSDHC_MIX_CTRL_AC12EN (0x00000004U) /*!< Bit mask for uSDHC_MIX_CTRL_AC12EN. */
#define BS_uSDHC_MIX_CTRL_AC12EN (1U)      /*!< Bit field size in bits for uSDHC_MIX_CTRL_AC12EN. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_AC12EN field. */
#define BR_uSDHC_MIX_CTRL_AC12EN(x) (HW_uSDHC_MIX_CTRL(x).B.AC12EN)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_AC12EN. */
#define BF_uSDHC_MIX_CTRL_AC12EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_AC12EN) & BM_uSDHC_MIX_CTRL_AC12EN)

/*! @brief Set the AC12EN field to a new value. */
#define BW_uSDHC_MIX_CTRL_AC12EN(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_AC12EN) | BF_uSDHC_MIX_CTRL_AC12EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field DDR_EN[3] (RW)
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_DDR_EN (3U)      /*!< Bit position for uSDHC_MIX_CTRL_DDR_EN. */
#define BM_uSDHC_MIX_CTRL_DDR_EN (0x00000008U) /*!< Bit mask for uSDHC_MIX_CTRL_DDR_EN. */
#define BS_uSDHC_MIX_CTRL_DDR_EN (1U)      /*!< Bit field size in bits for uSDHC_MIX_CTRL_DDR_EN. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_DDR_EN field. */
#define BR_uSDHC_MIX_CTRL_DDR_EN(x) (HW_uSDHC_MIX_CTRL(x).B.DDR_EN)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_DDR_EN. */
#define BF_uSDHC_MIX_CTRL_DDR_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_DDR_EN) & BM_uSDHC_MIX_CTRL_DDR_EN)

/*! @brief Set the DDR_EN field to a new value. */
#define BW_uSDHC_MIX_CTRL_DDR_EN(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_DDR_EN) | BF_uSDHC_MIX_CTRL_DDR_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field DTDSEL[4] (RW)
 *
 * This bit defines the direction of DATA line data transfers. The bit is set to
 * 1 by the Host Driver to transfer data from the SD card to the uSDHC and is
 * set to 0 for all other commands.
 *
 * Values:
 * - 1 - Read (Card to Host)
 * - 0 - Write (Host to Card)
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_DTDSEL (4U)      /*!< Bit position for uSDHC_MIX_CTRL_DTDSEL. */
#define BM_uSDHC_MIX_CTRL_DTDSEL (0x00000010U) /*!< Bit mask for uSDHC_MIX_CTRL_DTDSEL. */
#define BS_uSDHC_MIX_CTRL_DTDSEL (1U)      /*!< Bit field size in bits for uSDHC_MIX_CTRL_DTDSEL. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_DTDSEL field. */
#define BR_uSDHC_MIX_CTRL_DTDSEL(x) (HW_uSDHC_MIX_CTRL(x).B.DTDSEL)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_DTDSEL. */
#define BF_uSDHC_MIX_CTRL_DTDSEL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_DTDSEL) & BM_uSDHC_MIX_CTRL_DTDSEL)

/*! @brief Set the DTDSEL field to a new value. */
#define BW_uSDHC_MIX_CTRL_DTDSEL(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_DTDSEL) | BF_uSDHC_MIX_CTRL_DTDSEL(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field MSBSEL[5] (RW)
 *
 * This bit enables multiple block DATA line data transfers. For any other
 * commands, this bit can be set to 0. If this bit is 0, it is not necessary to set
 * the Block Count register. (Refer to CMD_XFR_TYPCommand Transfer Type ).
 *
 * Values:
 * - 1 - Multiple Blocks
 * - 0 - Single Block
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_MSBSEL (5U)      /*!< Bit position for uSDHC_MIX_CTRL_MSBSEL. */
#define BM_uSDHC_MIX_CTRL_MSBSEL (0x00000020U) /*!< Bit mask for uSDHC_MIX_CTRL_MSBSEL. */
#define BS_uSDHC_MIX_CTRL_MSBSEL (1U)      /*!< Bit field size in bits for uSDHC_MIX_CTRL_MSBSEL. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_MSBSEL field. */
#define BR_uSDHC_MIX_CTRL_MSBSEL(x) (HW_uSDHC_MIX_CTRL(x).B.MSBSEL)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_MSBSEL. */
#define BF_uSDHC_MIX_CTRL_MSBSEL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_MSBSEL) & BM_uSDHC_MIX_CTRL_MSBSEL)

/*! @brief Set the MSBSEL field to a new value. */
#define BW_uSDHC_MIX_CTRL_MSBSEL(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_MSBSEL) | BF_uSDHC_MIX_CTRL_MSBSEL(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field NIBBLE_POS[6] (RW)
 *
 * In DDR 4-bit mode nibble position indictation. 0- the sequence is 'odd high
 * nibble -> even high nibble -> odd low nibble -> even low nibble'; 1- the
 * sequence is 'odd high nibble -> odd low nibble -> even high nibble -> even low
 * nibble'.
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_NIBBLE_POS (6U)  /*!< Bit position for uSDHC_MIX_CTRL_NIBBLE_POS. */
#define BM_uSDHC_MIX_CTRL_NIBBLE_POS (0x00000040U) /*!< Bit mask for uSDHC_MIX_CTRL_NIBBLE_POS. */
#define BS_uSDHC_MIX_CTRL_NIBBLE_POS (1U)  /*!< Bit field size in bits for uSDHC_MIX_CTRL_NIBBLE_POS. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_NIBBLE_POS field. */
#define BR_uSDHC_MIX_CTRL_NIBBLE_POS(x) (HW_uSDHC_MIX_CTRL(x).B.NIBBLE_POS)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_NIBBLE_POS. */
#define BF_uSDHC_MIX_CTRL_NIBBLE_POS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_NIBBLE_POS) & BM_uSDHC_MIX_CTRL_NIBBLE_POS)

/*! @brief Set the NIBBLE_POS field to a new value. */
#define BW_uSDHC_MIX_CTRL_NIBBLE_POS(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_NIBBLE_POS) | BF_uSDHC_MIX_CTRL_NIBBLE_POS(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field AC23EN[7] (RW)
 *
 * When this bit is set to 1, the Host Controller issues a CMD23 automatically
 * before issuing a command specified in the Command Register.
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_AC23EN (7U)      /*!< Bit position for uSDHC_MIX_CTRL_AC23EN. */
#define BM_uSDHC_MIX_CTRL_AC23EN (0x00000080U) /*!< Bit mask for uSDHC_MIX_CTRL_AC23EN. */
#define BS_uSDHC_MIX_CTRL_AC23EN (1U)      /*!< Bit field size in bits for uSDHC_MIX_CTRL_AC23EN. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_AC23EN field. */
#define BR_uSDHC_MIX_CTRL_AC23EN(x) (HW_uSDHC_MIX_CTRL(x).B.AC23EN)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_AC23EN. */
#define BF_uSDHC_MIX_CTRL_AC23EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_AC23EN) & BM_uSDHC_MIX_CTRL_AC23EN)

/*! @brief Set the AC23EN field to a new value. */
#define BW_uSDHC_MIX_CTRL_AC23EN(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_AC23EN) | BF_uSDHC_MIX_CTRL_AC23EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field EXE_TUNE[22] (RW)
 *
 * When STD_TUNING_EN is 0, this bit is set to 1 to indicate the Host Driver is
 * starting tuning procedure. Tuning procedure is aborted by writing 0.
 *
 * Values:
 * - 1 - Execute Tuning
 * - 0 - Not Tuned or Tuning Completed
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_EXE_TUNE (22U)   /*!< Bit position for uSDHC_MIX_CTRL_EXE_TUNE. */
#define BM_uSDHC_MIX_CTRL_EXE_TUNE (0x00400000U) /*!< Bit mask for uSDHC_MIX_CTRL_EXE_TUNE. */
#define BS_uSDHC_MIX_CTRL_EXE_TUNE (1U)    /*!< Bit field size in bits for uSDHC_MIX_CTRL_EXE_TUNE. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_EXE_TUNE field. */
#define BR_uSDHC_MIX_CTRL_EXE_TUNE(x) (HW_uSDHC_MIX_CTRL(x).B.EXE_TUNE)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_EXE_TUNE. */
#define BF_uSDHC_MIX_CTRL_EXE_TUNE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_EXE_TUNE) & BM_uSDHC_MIX_CTRL_EXE_TUNE)

/*! @brief Set the EXE_TUNE field to a new value. */
#define BW_uSDHC_MIX_CTRL_EXE_TUNE(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_EXE_TUNE) | BF_uSDHC_MIX_CTRL_EXE_TUNE(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field SMP_CLK_SEL[23] (RW)
 *
 * When STD_TUNING_EN is 0, this bit is used to select Tuned clock or Fixed
 * clock to sample data / cmd (Only used for SD3.0, SDR104 mode)
 *
 * Values:
 * - 1 - Tuned clock is used to sample data / cmd
 * - 0 - Fixed clock is used to sample data / cmd
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_SMP_CLK_SEL (23U) /*!< Bit position for uSDHC_MIX_CTRL_SMP_CLK_SEL. */
#define BM_uSDHC_MIX_CTRL_SMP_CLK_SEL (0x00800000U) /*!< Bit mask for uSDHC_MIX_CTRL_SMP_CLK_SEL. */
#define BS_uSDHC_MIX_CTRL_SMP_CLK_SEL (1U) /*!< Bit field size in bits for uSDHC_MIX_CTRL_SMP_CLK_SEL. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_SMP_CLK_SEL field. */
#define BR_uSDHC_MIX_CTRL_SMP_CLK_SEL(x) (HW_uSDHC_MIX_CTRL(x).B.SMP_CLK_SEL)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_SMP_CLK_SEL. */
#define BF_uSDHC_MIX_CTRL_SMP_CLK_SEL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_SMP_CLK_SEL) & BM_uSDHC_MIX_CTRL_SMP_CLK_SEL)

/*! @brief Set the SMP_CLK_SEL field to a new value. */
#define BW_uSDHC_MIX_CTRL_SMP_CLK_SEL(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_SMP_CLK_SEL) | BF_uSDHC_MIX_CTRL_SMP_CLK_SEL(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field AUTO_TUNE_EN[24] (RW)
 *
 * Values:
 * - 1 - Enable auto tuning
 * - 0 - Disable auto tuning
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_AUTO_TUNE_EN (24U) /*!< Bit position for uSDHC_MIX_CTRL_AUTO_TUNE_EN. */
#define BM_uSDHC_MIX_CTRL_AUTO_TUNE_EN (0x01000000U) /*!< Bit mask for uSDHC_MIX_CTRL_AUTO_TUNE_EN. */
#define BS_uSDHC_MIX_CTRL_AUTO_TUNE_EN (1U) /*!< Bit field size in bits for uSDHC_MIX_CTRL_AUTO_TUNE_EN. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_AUTO_TUNE_EN field. */
#define BR_uSDHC_MIX_CTRL_AUTO_TUNE_EN(x) (HW_uSDHC_MIX_CTRL(x).B.AUTO_TUNE_EN)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_AUTO_TUNE_EN. */
#define BF_uSDHC_MIX_CTRL_AUTO_TUNE_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_AUTO_TUNE_EN) & BM_uSDHC_MIX_CTRL_AUTO_TUNE_EN)

/*! @brief Set the AUTO_TUNE_EN field to a new value. */
#define BW_uSDHC_MIX_CTRL_AUTO_TUNE_EN(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_AUTO_TUNE_EN) | BF_uSDHC_MIX_CTRL_AUTO_TUNE_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field FBCLK_SEL[25] (RW)
 *
 * Values:
 * - 1 - Feedback clock comes from the ipp_card_clk_out
 * - 0 - Feedback clock comes from the loopback CLK
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_FBCLK_SEL (25U)  /*!< Bit position for uSDHC_MIX_CTRL_FBCLK_SEL. */
#define BM_uSDHC_MIX_CTRL_FBCLK_SEL (0x02000000U) /*!< Bit mask for uSDHC_MIX_CTRL_FBCLK_SEL. */
#define BS_uSDHC_MIX_CTRL_FBCLK_SEL (1U)   /*!< Bit field size in bits for uSDHC_MIX_CTRL_FBCLK_SEL. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_FBCLK_SEL field. */
#define BR_uSDHC_MIX_CTRL_FBCLK_SEL(x) (HW_uSDHC_MIX_CTRL(x).B.FBCLK_SEL)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_FBCLK_SEL. */
#define BF_uSDHC_MIX_CTRL_FBCLK_SEL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_FBCLK_SEL) & BM_uSDHC_MIX_CTRL_FBCLK_SEL)

/*! @brief Set the FBCLK_SEL field to a new value. */
#define BW_uSDHC_MIX_CTRL_FBCLK_SEL(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_FBCLK_SEL) | BF_uSDHC_MIX_CTRL_FBCLK_SEL(v)))
/*@}*/

/*!
 * @name Register uSDHC_MIX_CTRL, field HS400_MODE[26] (RW)
 *
 * HS400 Enable
 */
/*@{*/
#define BP_uSDHC_MIX_CTRL_HS400_MODE (26U) /*!< Bit position for uSDHC_MIX_CTRL_HS400_MODE. */
#define BM_uSDHC_MIX_CTRL_HS400_MODE (0x04000000U) /*!< Bit mask for uSDHC_MIX_CTRL_HS400_MODE. */
#define BS_uSDHC_MIX_CTRL_HS400_MODE (1U)  /*!< Bit field size in bits for uSDHC_MIX_CTRL_HS400_MODE. */

/*! @brief Read current value of the uSDHC_MIX_CTRL_HS400_MODE field. */
#define BR_uSDHC_MIX_CTRL_HS400_MODE(x) (HW_uSDHC_MIX_CTRL(x).B.HS400_MODE)

/*! @brief Format value for bitfield uSDHC_MIX_CTRL_HS400_MODE. */
#define BF_uSDHC_MIX_CTRL_HS400_MODE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MIX_CTRL_HS400_MODE) & BM_uSDHC_MIX_CTRL_HS400_MODE)

/*! @brief Set the HS400_MODE field to a new value. */
#define BW_uSDHC_MIX_CTRL_HS400_MODE(x, v) (HW_uSDHC_MIX_CTRL_WR(x, (HW_uSDHC_MIX_CTRL_RD(x) & ~BM_uSDHC_MIX_CTRL_HS400_MODE) | BF_uSDHC_MIX_CTRL_HS400_MODE(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_FORCE_EVENT - Force Event
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_FORCE_EVENT - Force Event (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Force Event Register is not a physically implemented register. Rather, it
 * is an address at which the Interrupt Status Register can be written if the
 * corresponding bit of the Interrupt Status Enable Register is set. This register
 * is a write only register and writing 0 to it has no effect. Writing 1 to this
 * register actually sets the corresponding bit of Interrupt Status Register. A
 * read from this register always results in 0's. In order to change the
 * corresponding status bits in the Interrupt Status Register, make sure to set IPGEN bit
 * in System Control Register so that IPG_CLK is always active. Forcing a card
 * interrupt will generate a short pulse on the DATA1 line, and the driver may
 * treat this interrupt as a normal interrupt. The interrupt service routine may skip
 * polling the card interrupt factor as the interrupt is self cleared.
 */
typedef union _hw_usdhc_force_event
{
    uint32_t U;
    struct _hw_usdhc_force_event_bitfields
    {
        uint32_t FEVTAC12NE : 1;       /*!< [0] Force Event Auto Command 12 Not
                                        * Executed */
        uint32_t FEVTAC12TOE : 1;      /*!< [1] Force Event Auto Command 12 Time
                                        * Out Error */
        uint32_t FEVTAC12CE : 1;       /*!< [2] Force Event Auto Command 12 CRC
                                        * Error */
        uint32_t FEVTAC12EBE : 1;      /*!< [3] Force Event Auto Command 12 End
                                        * Bit Error */
        uint32_t FEVTAC12IE : 1;       /*!< [4] Force Event Auto Command 12 Index
                                        * Error */
        uint32_t RESERVED0 : 2;        /*!< [6:5]  */
        uint32_t FEVTCNIBAC12E : 1;    /*!< [7] Force Event Command Not Executed
                                        * By Auto Command 12 Error */
        uint32_t RESERVED1 : 8;        /*!< [15:8]  */
        uint32_t FEVTCTOE : 1;         /*!< [16] Force Event Command Time Out Error */
        uint32_t FEVTCCE : 1;          /*!< [17] Force Event Command CRC Error */
        uint32_t FEVTCEBE : 1;         /*!< [18] Force Event Command End Bit Error */
        uint32_t FEVTCIE : 1;          /*!< [19] Force Event Command Index Error */
        uint32_t FEVTDTOE : 1;         /*!< [20] Force Event Data Time Out Error */
        uint32_t FEVTDCE : 1;          /*!< [21] Force Event Data CRC Error */
        uint32_t FEVTDEBE : 1;         /*!< [22] Force Event Data End Bit Error */
        uint32_t RESERVED2 : 1;        /*!< [23]  */
        uint32_t FEVTAC12E : 1;        /*!< [24] Force Event Auto Command 12 Error */
        uint32_t RESERVED3 : 1;        /*!< [25]  */
        uint32_t FEVTTNE : 1;          /*!< [26] Force Tuning Error */
        uint32_t RESERVED4 : 1;        /*!< [27]  */
        uint32_t FEVTDMAE : 1;         /*!< [28] Force Event DMA Error */
        uint32_t RESERVED5 : 2;        /*!< [30:29]  */
        uint32_t FEVTCINT : 1;         /*!< [31] Force Event Card Interrupt */
    } B;
} hw_usdhc_force_event_t;

/*!
 * @name Constants and macros for entire uSDHC_FORCE_EVENT register
 */
/*@{*/
#define HW_uSDHC_FORCE_EVENT_ADDR(x) ((uintptr_t)(x) + 0x50U)

#define HW_uSDHC_FORCE_EVENT(x)  (*(__IO hw_usdhc_force_event_t *) HW_uSDHC_FORCE_EVENT_ADDR(x))
#define HW_uSDHC_FORCE_EVENT_RD(x) (HW_uSDHC_FORCE_EVENT(x).U)
#define HW_uSDHC_FORCE_EVENT_WR(x, v) (HW_uSDHC_FORCE_EVENT(x).U = (v))
#define HW_uSDHC_FORCE_EVENT_SET(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, HW_uSDHC_FORCE_EVENT_RD(x) |  (v)))
#define HW_uSDHC_FORCE_EVENT_CLR(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, HW_uSDHC_FORCE_EVENT_RD(x) & ~(v)))
#define HW_uSDHC_FORCE_EVENT_TOG(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, HW_uSDHC_FORCE_EVENT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_FORCE_EVENT bitfields
 */

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTAC12NE[0] (WORZ)
 *
 * Forces the AC12NE bit in the Auto Command12 Error Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTAC12NE (0U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTAC12NE. */
#define BM_uSDHC_FORCE_EVENT_FEVTAC12NE (0x00000001U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTAC12NE. */
#define BS_uSDHC_FORCE_EVENT_FEVTAC12NE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTAC12NE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTAC12NE. */
#define BF_uSDHC_FORCE_EVENT_FEVTAC12NE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTAC12NE) & BM_uSDHC_FORCE_EVENT_FEVTAC12NE)

/*! @brief Set the FEVTAC12NE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTAC12NE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTAC12NE) | BF_uSDHC_FORCE_EVENT_FEVTAC12NE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTAC12TOE[1] (WORZ)
 *
 * Forces the AC12TOE bit in the Auto Command12 Error Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTAC12TOE (1U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTAC12TOE. */
#define BM_uSDHC_FORCE_EVENT_FEVTAC12TOE (0x00000002U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTAC12TOE. */
#define BS_uSDHC_FORCE_EVENT_FEVTAC12TOE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTAC12TOE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTAC12TOE. */
#define BF_uSDHC_FORCE_EVENT_FEVTAC12TOE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTAC12TOE) & BM_uSDHC_FORCE_EVENT_FEVTAC12TOE)

/*! @brief Set the FEVTAC12TOE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTAC12TOE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTAC12TOE) | BF_uSDHC_FORCE_EVENT_FEVTAC12TOE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTAC12CE[2] (WORZ)
 *
 * Forces the AC12CE bit in the Auto Command12 Error Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTAC12CE (2U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTAC12CE. */
#define BM_uSDHC_FORCE_EVENT_FEVTAC12CE (0x00000004U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTAC12CE. */
#define BS_uSDHC_FORCE_EVENT_FEVTAC12CE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTAC12CE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTAC12CE. */
#define BF_uSDHC_FORCE_EVENT_FEVTAC12CE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTAC12CE) & BM_uSDHC_FORCE_EVENT_FEVTAC12CE)

/*! @brief Set the FEVTAC12CE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTAC12CE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTAC12CE) | BF_uSDHC_FORCE_EVENT_FEVTAC12CE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTAC12EBE[3] (WORZ)
 *
 * Forces the AC12EBE bit in the Auto Command12 Error Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTAC12EBE (3U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTAC12EBE. */
#define BM_uSDHC_FORCE_EVENT_FEVTAC12EBE (0x00000008U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTAC12EBE. */
#define BS_uSDHC_FORCE_EVENT_FEVTAC12EBE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTAC12EBE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTAC12EBE. */
#define BF_uSDHC_FORCE_EVENT_FEVTAC12EBE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTAC12EBE) & BM_uSDHC_FORCE_EVENT_FEVTAC12EBE)

/*! @brief Set the FEVTAC12EBE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTAC12EBE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTAC12EBE) | BF_uSDHC_FORCE_EVENT_FEVTAC12EBE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTAC12IE[4] (WORZ)
 *
 * Forces the AC12IE bit in the Auto Command12 Error Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTAC12IE (4U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTAC12IE. */
#define BM_uSDHC_FORCE_EVENT_FEVTAC12IE (0x00000010U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTAC12IE. */
#define BS_uSDHC_FORCE_EVENT_FEVTAC12IE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTAC12IE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTAC12IE. */
#define BF_uSDHC_FORCE_EVENT_FEVTAC12IE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTAC12IE) & BM_uSDHC_FORCE_EVENT_FEVTAC12IE)

/*! @brief Set the FEVTAC12IE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTAC12IE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTAC12IE) | BF_uSDHC_FORCE_EVENT_FEVTAC12IE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTCNIBAC12E[7] (WORZ)
 *
 * Forces the CNIBAC12E bit in the Auto Command12 Error Status Register to be
 * set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTCNIBAC12E (7U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTCNIBAC12E. */
#define BM_uSDHC_FORCE_EVENT_FEVTCNIBAC12E (0x00000080U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTCNIBAC12E. */
#define BS_uSDHC_FORCE_EVENT_FEVTCNIBAC12E (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTCNIBAC12E. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTCNIBAC12E. */
#define BF_uSDHC_FORCE_EVENT_FEVTCNIBAC12E(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTCNIBAC12E) & BM_uSDHC_FORCE_EVENT_FEVTCNIBAC12E)

/*! @brief Set the FEVTCNIBAC12E field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTCNIBAC12E(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTCNIBAC12E) | BF_uSDHC_FORCE_EVENT_FEVTCNIBAC12E(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTCTOE[16] (WORZ)
 *
 * Forces the CTOE bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTCTOE (16U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTCTOE. */
#define BM_uSDHC_FORCE_EVENT_FEVTCTOE (0x00010000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTCTOE. */
#define BS_uSDHC_FORCE_EVENT_FEVTCTOE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTCTOE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTCTOE. */
#define BF_uSDHC_FORCE_EVENT_FEVTCTOE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTCTOE) & BM_uSDHC_FORCE_EVENT_FEVTCTOE)

/*! @brief Set the FEVTCTOE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTCTOE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTCTOE) | BF_uSDHC_FORCE_EVENT_FEVTCTOE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTCCE[17] (WORZ)
 *
 * Forces the CCE bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTCCE (17U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTCCE. */
#define BM_uSDHC_FORCE_EVENT_FEVTCCE (0x00020000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTCCE. */
#define BS_uSDHC_FORCE_EVENT_FEVTCCE (1U)  /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTCCE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTCCE. */
#define BF_uSDHC_FORCE_EVENT_FEVTCCE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTCCE) & BM_uSDHC_FORCE_EVENT_FEVTCCE)

/*! @brief Set the FEVTCCE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTCCE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTCCE) | BF_uSDHC_FORCE_EVENT_FEVTCCE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTCEBE[18] (WORZ)
 *
 * Forces the CEBE bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTCEBE (18U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTCEBE. */
#define BM_uSDHC_FORCE_EVENT_FEVTCEBE (0x00040000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTCEBE. */
#define BS_uSDHC_FORCE_EVENT_FEVTCEBE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTCEBE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTCEBE. */
#define BF_uSDHC_FORCE_EVENT_FEVTCEBE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTCEBE) & BM_uSDHC_FORCE_EVENT_FEVTCEBE)

/*! @brief Set the FEVTCEBE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTCEBE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTCEBE) | BF_uSDHC_FORCE_EVENT_FEVTCEBE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTCIE[19] (WORZ)
 *
 * Forces the CCE bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTCIE (19U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTCIE. */
#define BM_uSDHC_FORCE_EVENT_FEVTCIE (0x00080000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTCIE. */
#define BS_uSDHC_FORCE_EVENT_FEVTCIE (1U)  /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTCIE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTCIE. */
#define BF_uSDHC_FORCE_EVENT_FEVTCIE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTCIE) & BM_uSDHC_FORCE_EVENT_FEVTCIE)

/*! @brief Set the FEVTCIE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTCIE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTCIE) | BF_uSDHC_FORCE_EVENT_FEVTCIE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTDTOE[20] (WORZ)
 *
 * Force the DTOE bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTDTOE (20U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTDTOE. */
#define BM_uSDHC_FORCE_EVENT_FEVTDTOE (0x00100000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTDTOE. */
#define BS_uSDHC_FORCE_EVENT_FEVTDTOE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTDTOE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTDTOE. */
#define BF_uSDHC_FORCE_EVENT_FEVTDTOE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTDTOE) & BM_uSDHC_FORCE_EVENT_FEVTDTOE)

/*! @brief Set the FEVTDTOE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTDTOE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTDTOE) | BF_uSDHC_FORCE_EVENT_FEVTDTOE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTDCE[21] (WORZ)
 *
 * Forces the DCE bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTDCE (21U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTDCE. */
#define BM_uSDHC_FORCE_EVENT_FEVTDCE (0x00200000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTDCE. */
#define BS_uSDHC_FORCE_EVENT_FEVTDCE (1U)  /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTDCE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTDCE. */
#define BF_uSDHC_FORCE_EVENT_FEVTDCE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTDCE) & BM_uSDHC_FORCE_EVENT_FEVTDCE)

/*! @brief Set the FEVTDCE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTDCE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTDCE) | BF_uSDHC_FORCE_EVENT_FEVTDCE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTDEBE[22] (WORZ)
 *
 * Forces the DEBE bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTDEBE (22U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTDEBE. */
#define BM_uSDHC_FORCE_EVENT_FEVTDEBE (0x00400000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTDEBE. */
#define BS_uSDHC_FORCE_EVENT_FEVTDEBE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTDEBE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTDEBE. */
#define BF_uSDHC_FORCE_EVENT_FEVTDEBE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTDEBE) & BM_uSDHC_FORCE_EVENT_FEVTDEBE)

/*! @brief Set the FEVTDEBE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTDEBE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTDEBE) | BF_uSDHC_FORCE_EVENT_FEVTDEBE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTAC12E[24] (WORZ)
 *
 * Forces the AC12E bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTAC12E (24U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTAC12E. */
#define BM_uSDHC_FORCE_EVENT_FEVTAC12E (0x01000000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTAC12E. */
#define BS_uSDHC_FORCE_EVENT_FEVTAC12E (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTAC12E. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTAC12E. */
#define BF_uSDHC_FORCE_EVENT_FEVTAC12E(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTAC12E) & BM_uSDHC_FORCE_EVENT_FEVTAC12E)

/*! @brief Set the FEVTAC12E field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTAC12E(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTAC12E) | BF_uSDHC_FORCE_EVENT_FEVTAC12E(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTTNE[26] (WORZ)
 *
 * Forces the TNE bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTTNE (26U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTTNE. */
#define BM_uSDHC_FORCE_EVENT_FEVTTNE (0x04000000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTTNE. */
#define BS_uSDHC_FORCE_EVENT_FEVTTNE (1U)  /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTTNE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTTNE. */
#define BF_uSDHC_FORCE_EVENT_FEVTTNE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTTNE) & BM_uSDHC_FORCE_EVENT_FEVTTNE)

/*! @brief Set the FEVTTNE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTTNE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTTNE) | BF_uSDHC_FORCE_EVENT_FEVTTNE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTDMAE[28] (WORZ)
 *
 * Forces the DMAE bit of Interrupt Status Register to be set.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTDMAE (28U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTDMAE. */
#define BM_uSDHC_FORCE_EVENT_FEVTDMAE (0x10000000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTDMAE. */
#define BS_uSDHC_FORCE_EVENT_FEVTDMAE (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTDMAE. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTDMAE. */
#define BF_uSDHC_FORCE_EVENT_FEVTDMAE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTDMAE) & BM_uSDHC_FORCE_EVENT_FEVTDMAE)

/*! @brief Set the FEVTDMAE field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTDMAE(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTDMAE) | BF_uSDHC_FORCE_EVENT_FEVTDMAE(v)))
/*@}*/

/*!
 * @name Register uSDHC_FORCE_EVENT, field FEVTCINT[31] (WORZ)
 *
 * Writing 1 to this bit generates a short low-level pulse on the internal DATA1
 * line, as if a self clearing interrupt was received from the external card. If
 * enabled, the CINT bit will be set and the interrupt service routine may treat
 * this interrupt as a normal interrupt from the external card.
 */
/*@{*/
#define BP_uSDHC_FORCE_EVENT_FEVTCINT (31U) /*!< Bit position for uSDHC_FORCE_EVENT_FEVTCINT. */
#define BM_uSDHC_FORCE_EVENT_FEVTCINT (0x80000000U) /*!< Bit mask for uSDHC_FORCE_EVENT_FEVTCINT. */
#define BS_uSDHC_FORCE_EVENT_FEVTCINT (1U) /*!< Bit field size in bits for uSDHC_FORCE_EVENT_FEVTCINT. */

/*! @brief Format value for bitfield uSDHC_FORCE_EVENT_FEVTCINT. */
#define BF_uSDHC_FORCE_EVENT_FEVTCINT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_FORCE_EVENT_FEVTCINT) & BM_uSDHC_FORCE_EVENT_FEVTCINT)

/*! @brief Set the FEVTCINT field to a new value. */
#define BW_uSDHC_FORCE_EVENT_FEVTCINT(x, v) (HW_uSDHC_FORCE_EVENT_WR(x, (HW_uSDHC_FORCE_EVENT_RD(x) & ~BM_uSDHC_FORCE_EVENT_FEVTCINT) | BF_uSDHC_FORCE_EVENT_FEVTCINT(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_ADMA_ERR_STATUS - ADMA Error Status Register
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_ADMA_ERR_STATUS - ADMA Error Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * When an ADMA Error Interrupt has occurred, the ADMA Error States field in
 * this register holds the ADMA state and the ADMA System Address register holds the
 * address around the error descriptor. For recovering from this error, the Host
 * Driver requires the ADMA state to identify the error descriptor address as
 * follows: ST_STOP: Previous location set in the ADMA System Address register is
 * the error descriptor address. ST_FDS: Current location set in the ADMA System
 * Address register is the error descriptor address. ST_CADR: This state is never
 * set because it only increments the descriptor pointer and doesn't generate an
 * ADMA error. ST_TFR: Previous location set in the ADMA System Address register
 * is the error descriptor address. In case of a write operation, the Host Driver
 * should use the ACMD22 to get the number of the written block, rather than
 * using this information, since unwritten data may exist in the Host Controller.
 * The Host Controller generates the ADMA Error Interrupt when it detects invalid
 * descriptor data (Valid=0) in the ST_FDS state. The Host Driver can distinguish
 * this error by reading the Valid bit of the error descriptor. ADMA Error State
 * Coding D01-D00 ADMA Error State (when error has occurred) Contents of ADMA
 * System Address Register 00 ST_STOP (Stop DMA) Holds the address of the next
 * executable Descriptor command 01 ST_FDS (Fetch Descriptor) Holds the valid
 * Descriptor address 10 ST_CADR (Change Address) No ADMA Error is generated 11 ST_TFR
 * (Transfer Data) Holds the address of the next executable Descriptor command
 */
typedef union _hw_usdhc_adma_err_status
{
    uint32_t U;
    struct _hw_usdhc_adma_err_status_bitfields
    {
        uint32_t ADMAES : 2;           /*!< [1:0] ADMA Error State (when ADMA Error is
                                        * occurred) */
        uint32_t ADMALME : 1;          /*!< [2] ADMA Length Mismatch Error */
        uint32_t ADMADCE : 1;          /*!< [3] ADMA Descritor Error */
        uint32_t RESERVED0 : 28;       /*!< [31:4]  */
    } B;
} hw_usdhc_adma_err_status_t;

/*!
 * @name Constants and macros for entire uSDHC_ADMA_ERR_STATUS register
 */
/*@{*/
#define HW_uSDHC_ADMA_ERR_STATUS_ADDR(x) ((uintptr_t)(x) + 0x54U)

#define HW_uSDHC_ADMA_ERR_STATUS(x) (*(__I hw_usdhc_adma_err_status_t *) HW_uSDHC_ADMA_ERR_STATUS_ADDR(x))
#define HW_uSDHC_ADMA_ERR_STATUS_RD(x) (HW_uSDHC_ADMA_ERR_STATUS(x).U)
/*@}*/

/*
 * Constants & macros for individual uSDHC_ADMA_ERR_STATUS bitfields
 */

/*!
 * @name Register uSDHC_ADMA_ERR_STATUS, field ADMAES[1:0] (RO)
 *
 * This field indicates the state of the ADMA when an error has occurred during
 * an ADMA data transfer. Refer to ADMA_ERR_STATUSADMA Error Status Register for
 * more details.
 */
/*@{*/
#define BP_uSDHC_ADMA_ERR_STATUS_ADMAES (0U) /*!< Bit position for uSDHC_ADMA_ERR_STATUS_ADMAES. */
#define BM_uSDHC_ADMA_ERR_STATUS_ADMAES (0x00000003U) /*!< Bit mask for uSDHC_ADMA_ERR_STATUS_ADMAES. */
#define BS_uSDHC_ADMA_ERR_STATUS_ADMAES (2U) /*!< Bit field size in bits for uSDHC_ADMA_ERR_STATUS_ADMAES. */

/*! @brief Read current value of the uSDHC_ADMA_ERR_STATUS_ADMAES field. */
#define BR_uSDHC_ADMA_ERR_STATUS_ADMAES(x) (HW_uSDHC_ADMA_ERR_STATUS(x).B.ADMAES)
/*@}*/

/*!
 * @name Register uSDHC_ADMA_ERR_STATUS, field ADMALME[2] (RO)
 *
 * This error occurs in the following 2 cases: While the Block Count Enable is
 * being set, the total data length specified by the Descriptor table is different
 * from that specified by the Block Count and Block Length. Total data length
 * cannot be divided by the block length.
 *
 * Values:
 * - 1 - Error
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_ADMA_ERR_STATUS_ADMALME (2U) /*!< Bit position for uSDHC_ADMA_ERR_STATUS_ADMALME. */
#define BM_uSDHC_ADMA_ERR_STATUS_ADMALME (0x00000004U) /*!< Bit mask for uSDHC_ADMA_ERR_STATUS_ADMALME. */
#define BS_uSDHC_ADMA_ERR_STATUS_ADMALME (1U) /*!< Bit field size in bits for uSDHC_ADMA_ERR_STATUS_ADMALME. */

/*! @brief Read current value of the uSDHC_ADMA_ERR_STATUS_ADMALME field. */
#define BR_uSDHC_ADMA_ERR_STATUS_ADMALME(x) (HW_uSDHC_ADMA_ERR_STATUS(x).B.ADMALME)
/*@}*/

/*!
 * @name Register uSDHC_ADMA_ERR_STATUS, field ADMADCE[3] (RO)
 *
 * This error occurs when invalid descriptor fetched by ADMA.
 *
 * Values:
 * - 1 - Error
 * - 0 - No Error
 */
/*@{*/
#define BP_uSDHC_ADMA_ERR_STATUS_ADMADCE (3U) /*!< Bit position for uSDHC_ADMA_ERR_STATUS_ADMADCE. */
#define BM_uSDHC_ADMA_ERR_STATUS_ADMADCE (0x00000008U) /*!< Bit mask for uSDHC_ADMA_ERR_STATUS_ADMADCE. */
#define BS_uSDHC_ADMA_ERR_STATUS_ADMADCE (1U) /*!< Bit field size in bits for uSDHC_ADMA_ERR_STATUS_ADMADCE. */

/*! @brief Read current value of the uSDHC_ADMA_ERR_STATUS_ADMADCE field. */
#define BR_uSDHC_ADMA_ERR_STATUS_ADMADCE(x) (HW_uSDHC_ADMA_ERR_STATUS(x).B.ADMADCE)
/*@}*/

/*******************************************************************************
 * HW_uSDHC_ADMA_SYS_ADDR - ADMA System Address
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_ADMA_SYS_ADDR - ADMA System Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the physical system memory address used for ADMA
 * transfers.
 */
typedef union _hw_usdhc_adma_sys_addr
{
    uint32_t U;
    struct _hw_usdhc_adma_sys_addr_bitfields
    {
        uint32_t RESERVED0 : 2;        /*!< [1:0]  */
        uint32_t ADS_ADDR : 30;        /*!< [31:2] ADMA System Address */
    } B;
} hw_usdhc_adma_sys_addr_t;

/*!
 * @name Constants and macros for entire uSDHC_ADMA_SYS_ADDR register
 */
/*@{*/
#define HW_uSDHC_ADMA_SYS_ADDR_ADDR(x) ((uintptr_t)(x) + 0x58U)

#define HW_uSDHC_ADMA_SYS_ADDR(x) (*(__IO hw_usdhc_adma_sys_addr_t *) HW_uSDHC_ADMA_SYS_ADDR_ADDR(x))
#define HW_uSDHC_ADMA_SYS_ADDR_RD(x) (HW_uSDHC_ADMA_SYS_ADDR(x).U)
#define HW_uSDHC_ADMA_SYS_ADDR_WR(x, v) (HW_uSDHC_ADMA_SYS_ADDR(x).U = (v))
#define HW_uSDHC_ADMA_SYS_ADDR_SET(x, v) (HW_uSDHC_ADMA_SYS_ADDR_WR(x, HW_uSDHC_ADMA_SYS_ADDR_RD(x) |  (v)))
#define HW_uSDHC_ADMA_SYS_ADDR_CLR(x, v) (HW_uSDHC_ADMA_SYS_ADDR_WR(x, HW_uSDHC_ADMA_SYS_ADDR_RD(x) & ~(v)))
#define HW_uSDHC_ADMA_SYS_ADDR_TOG(x, v) (HW_uSDHC_ADMA_SYS_ADDR_WR(x, HW_uSDHC_ADMA_SYS_ADDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_ADMA_SYS_ADDR bitfields
 */

/*!
 * @name Register uSDHC_ADMA_SYS_ADDR, field ADS_ADDR[31:2] (RW)
 *
 * This register holds the word address of the executing command in the
 * Descriptor table. At the start of ADMA, the Host Driver shall set the start address of
 * the Descriptor table. The ADMA engine increments this register address
 * whenever fetching a Descriptor command. When the ADMA is stopped at the Block Gap,
 * this register indicates the address of the next executable Descriptor command.
 * When the ADMA Error Interrupt is generated, this register shall hold the valid
 * Descriptor address depending on the ADMA state. The lower 2 bits of this
 * register is tied to '0' so the ADMA address is always word aligned. Since this
 * register supports dynamic address reflecting, when TC bit is set, it
 * automatically alters the value of internal address counter, so SW cannot change this
 * register when TC bit is set. Such restriction is also listed in Software
 * Restrictions .
 */
/*@{*/
#define BP_uSDHC_ADMA_SYS_ADDR_ADS_ADDR (2U) /*!< Bit position for uSDHC_ADMA_SYS_ADDR_ADS_ADDR. */
#define BM_uSDHC_ADMA_SYS_ADDR_ADS_ADDR (0xFFFFFFFCU) /*!< Bit mask for uSDHC_ADMA_SYS_ADDR_ADS_ADDR. */
#define BS_uSDHC_ADMA_SYS_ADDR_ADS_ADDR (30U) /*!< Bit field size in bits for uSDHC_ADMA_SYS_ADDR_ADS_ADDR. */

/*! @brief Read current value of the uSDHC_ADMA_SYS_ADDR_ADS_ADDR field. */
#define BR_uSDHC_ADMA_SYS_ADDR_ADS_ADDR(x) (HW_uSDHC_ADMA_SYS_ADDR(x).B.ADS_ADDR)

/*! @brief Format value for bitfield uSDHC_ADMA_SYS_ADDR_ADS_ADDR. */
#define BF_uSDHC_ADMA_SYS_ADDR_ADS_ADDR(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_ADMA_SYS_ADDR_ADS_ADDR) & BM_uSDHC_ADMA_SYS_ADDR_ADS_ADDR)

/*! @brief Set the ADS_ADDR field to a new value. */
#define BW_uSDHC_ADMA_SYS_ADDR_ADS_ADDR(x, v) (HW_uSDHC_ADMA_SYS_ADDR_WR(x, (HW_uSDHC_ADMA_SYS_ADDR_RD(x) & ~BM_uSDHC_ADMA_SYS_ADDR_ADS_ADDR) | BF_uSDHC_ADMA_SYS_ADDR_ADS_ADDR(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_DLL_CTRL - DLL (Delay Line) Control
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_DLL_CTRL - DLL (Delay Line) Control (RW)
 *
 * Reset value: 0x00000200U
 *
 * This register contains control bits for DLL.
 */
typedef union _hw_usdhc_dll_ctrl
{
    uint32_t U;
    struct _hw_usdhc_dll_ctrl_bitfields
    {
        uint32_t DLL_CTRL_ENABLE : 1;  /*!< [0]  */
        uint32_t DLL_CTRL_RESET : 1;   /*!< [1]  */
        uint32_t DLL_CTRL_SLV_FORCE_UPD : 1; /*!< [2]  */
        uint32_t DLL_CTRL_SLV_DLY_TARGET0 : 4; /*!< [6:3]  */
        uint32_t DLL_CTRL_GATE_UPDATE : 1; /*!< [7]  */
        uint32_t DLL_CTRL_SLV_OVERRIDE : 1; /*!< [8]  */
        uint32_t DLL_CTRL_SLV_OVERRIDE_VAL : 7; /*!< [15:9]  */
        uint32_t DLL_CTRL_SLV_DLY_TARGET1 : 3; /*!< [18:16]  */
        uint32_t RESERVED0 : 1;        /*!< [19]  */
        uint32_t DLL_CTRL_SLV_UPDATE_INT : 8; /*!< [27:20]  */
        uint32_t DLL_CTRL_REF_UPDATE_INT : 4; /*!< [31:28]  */
    } B;
} hw_usdhc_dll_ctrl_t;

/*!
 * @name Constants and macros for entire uSDHC_DLL_CTRL register
 */
/*@{*/
#define HW_uSDHC_DLL_CTRL_ADDR(x) ((uintptr_t)(x) + 0x60U)

#define HW_uSDHC_DLL_CTRL(x)     (*(__IO hw_usdhc_dll_ctrl_t *) HW_uSDHC_DLL_CTRL_ADDR(x))
#define HW_uSDHC_DLL_CTRL_RD(x)  (HW_uSDHC_DLL_CTRL(x).U)
#define HW_uSDHC_DLL_CTRL_WR(x, v) (HW_uSDHC_DLL_CTRL(x).U = (v))
#define HW_uSDHC_DLL_CTRL_SET(x, v) (HW_uSDHC_DLL_CTRL_WR(x, HW_uSDHC_DLL_CTRL_RD(x) |  (v)))
#define HW_uSDHC_DLL_CTRL_CLR(x, v) (HW_uSDHC_DLL_CTRL_WR(x, HW_uSDHC_DLL_CTRL_RD(x) & ~(v)))
#define HW_uSDHC_DLL_CTRL_TOG(x, v) (HW_uSDHC_DLL_CTRL_WR(x, HW_uSDHC_DLL_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_DLL_CTRL bitfields
 */

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_ENABLE[0] (RW)
 *
 * Set this bit to 1 to enable the DLL and delay chain; otherwise; set to 0 to
 * bypasses DLL. Note that using the slave delay line override feature with
 * SLV_OVERRIDE and SLV_OVERRIDE VAL, the DLL does not need to be enabled.
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE (0U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_ENABLE. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE (0x00000001U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_ENABLE. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE (1U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_ENABLE. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_ENABLE field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_ENABLE)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_ENABLE. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE) & BM_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE)

/*! @brief Set the DLL_CTRL_ENABLE field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE) | BF_uSDHC_DLL_CTRL_DLL_CTRL_ENABLE(v)))
/*@}*/

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_RESET[1] (RW)
 *
 * Setting this bit to 1 force a reset on DLL. This will cause the DLL to lose
 * lock and re-calibrate to detect an REF_CLOCK half period phase shift. This
 * signal is used by the DLL as edge-sensitive, so in order to create a subsequent
 * reset, RESET must be taken low and then asserted again.
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_RESET (1U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_RESET. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_RESET (0x00000002U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_RESET. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_RESET (1U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_RESET. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_RESET field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_RESET(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_RESET)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_RESET. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_RESET(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_RESET) & BM_uSDHC_DLL_CTRL_DLL_CTRL_RESET)

/*! @brief Set the DLL_CTRL_RESET field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_RESET(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_RESET) | BF_uSDHC_DLL_CTRL_DLL_CTRL_RESET(v)))
/*@}*/

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_SLV_FORCE_UPD[2] (RW)
 *
 * Setting this bit to 1, forces the slave delay line to update to the DLL
 * calibrated value immediately. The slave delay line shall update automatically based
 * on the SLV_UPDATE_INT interval or when a DLL lock condition is sensed.
 * Subsequent forcing of the slave-line update can only occur if SLV_FORCE_UP is set
 * back to 0 and then asserted again (edge triggered). Be sure to use it when uSDHC
 * is idle. This function may not work when uSDHC is working on data / cmd /
 * response.
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD (2U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD (0x00000004U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD (1U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_SLV_FORCE_UPD)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD) & BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD)

/*! @brief Set the DLL_CTRL_SLV_FORCE_UPD field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD) | BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_FORCE_UPD(v)))
/*@}*/

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_SLV_DLY_TARGET0[6:3] (RW)
 *
 * The delay target for the uSDHC loopback read clock can be programmed in
 * 1/16th increments of an ref_clock half-period. The delay is
 * ((DLL_CTRL_SLV_DLY_TARGET1 +1)* REF_CLOCK / 2) / 16 So the input read-clock can be delayed relative
 * input data from (REF_CLOCK / 2) / 16 to REF_CLOCK * 4.
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0 (3U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0 (0x00000078U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0 (4U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0 field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_SLV_DLY_TARGET0)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0) & BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0)

/*! @brief Set the DLL_CTRL_SLV_DLY_TARGET0 field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0) | BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET0(v)))
/*@}*/

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_GATE_UPDATE[7] (RW)
 *
 * Set this bit to 1 to prevent the DLL from updating (since when clock_in
 * exists, glitches may appear during DLL updates). This bit may be used by software
 * if such a condition occurs. Clear the bit to 0 to allow the DLL to update
 * automatically.
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE (7U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE (0x00000080U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE (1U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_GATE_UPDATE)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE) & BM_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE)

/*! @brief Set the DLL_CTRL_GATE_UPDATE field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE) | BF_uSDHC_DLL_CTRL_DLL_CTRL_GATE_UPDATE(v)))
/*@}*/

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_SLV_OVERRIDE[8] (RW)
 *
 * Set this bit to 1 to Enable manual override for slave delay chain using
 * SLV_OVERRIDE_VAL; to set 0 to disable manual override. This feature does not
 * require the DLL to be enabled using the ENABLE bit. In fact to reduce power, if
 * SLV_OVERRIDE is used, it is recommended to disable the DLL with ENABLE = 0
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE (8U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE (0x00000100U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE (1U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_SLV_OVERRIDE)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE) & BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE)

/*! @brief Set the DLL_CTRL_SLV_OVERRIDE field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE) | BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_SLV_OVERRIDE_VAL[15:9] (RW)
 *
 * When SLV_OVERRIDE = 1 This field is used to select 1 of 128 physical taps
 * manually. A value of 0 selects tap 1, and a value of 0x7f selects tap 128.
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL (9U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL (0x0000FE00U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL (7U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_SLV_OVERRIDE_VAL)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL) & BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL)

/*! @brief Set the DLL_CTRL_SLV_OVERRIDE_VAL field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL) | BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_OVERRIDE_VAL(v)))
/*@}*/

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_SLV_DLY_TARGET1[18:16] (RW)
 *
 * Refer to DLL_CTRL_SLV_DLY_TARGET0 below.
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1 (16U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1 (0x00070000U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1 (3U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1 field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_SLV_DLY_TARGET1)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1) & BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1)

/*! @brief Set the DLL_CTRL_SLV_DLY_TARGET1 field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1) | BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_DLY_TARGET1(v)))
/*@}*/

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_SLV_UPDATE_INT[27:20] (RW)
 *
 * Slave delay line update interval. If default 0 is used, it means 256 cycles
 * of REF_CLOCK. A value of 0x0f results in 15 cycles and so on. Note that
 * software can always cause an update of the slave-delay line using the
 * SLV_FORCE_UPDATE register. Note that the slave delay line will also update automatically when
 * the reference DLL transitions to a locked state (from an un-locked state).
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT (20U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT (0x0FF00000U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT (8U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_SLV_UPDATE_INT)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT) & BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT)

/*! @brief Set the DLL_CTRL_SLV_UPDATE_INT field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT) | BF_uSDHC_DLL_CTRL_DLL_CTRL_SLV_UPDATE_INT(v)))
/*@}*/

/*!
 * @name Register uSDHC_DLL_CTRL, field DLL_CTRL_REF_UPDATE_INT[31:28] (RW)
 *
 * DLL control loop update interval. The interval cycle is (2 + REF_UPDATE_INT)
 * * REF_CLOCK. By default, the DLL control loop shall update every two REF_CLOCK
 * cycles. It should be noted that increasing the reference delay-line update
 * interval reduces the ability of the DLL to adjust to fast changes in conditions
 * that may effect the delay (such as voltage and temperature)
 */
/*@{*/
#define BP_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT (28U) /*!< Bit position for uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT. */
#define BM_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT (0xF0000000U) /*!< Bit mask for uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT. */
#define BS_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT (4U) /*!< Bit field size in bits for uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT. */

/*! @brief Read current value of the uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT field. */
#define BR_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT(x) (HW_uSDHC_DLL_CTRL(x).B.DLL_CTRL_REF_UPDATE_INT)

/*! @brief Format value for bitfield uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT. */
#define BF_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT) & BM_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT)

/*! @brief Set the DLL_CTRL_REF_UPDATE_INT field to a new value. */
#define BW_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT(x, v) (HW_uSDHC_DLL_CTRL_WR(x, (HW_uSDHC_DLL_CTRL_RD(x) & ~BM_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT) | BF_uSDHC_DLL_CTRL_DLL_CTRL_REF_UPDATE_INT(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_DLL_STATUS - DLL Status
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_DLL_STATUS - DLL Status (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the DLL status information. All bits are read only and
 * will read the same as the power-reset value.
 */
typedef union _hw_usdhc_dll_status
{
    uint32_t U;
    struct _hw_usdhc_dll_status_bitfields
    {
        uint32_t DLL_STS_SLV_LOCK : 1; /*!< [0]  */
        uint32_t DLL_STS_REF_LOCK : 1; /*!< [1]  */
        uint32_t DLL_STS_SLV_SEL : 7;  /*!< [8:2]  */
        uint32_t DLL_STS_REF_SEL : 7;  /*!< [15:9]  */
        uint32_t RESERVED0 : 16;       /*!< [31:16]  */
    } B;
} hw_usdhc_dll_status_t;

/*!
 * @name Constants and macros for entire uSDHC_DLL_STATUS register
 */
/*@{*/
#define HW_uSDHC_DLL_STATUS_ADDR(x) ((uintptr_t)(x) + 0x64U)

#define HW_uSDHC_DLL_STATUS(x)   (*(__I hw_usdhc_dll_status_t *) HW_uSDHC_DLL_STATUS_ADDR(x))
#define HW_uSDHC_DLL_STATUS_RD(x) (HW_uSDHC_DLL_STATUS(x).U)
/*@}*/

/*
 * Constants & macros for individual uSDHC_DLL_STATUS bitfields
 */

/*!
 * @name Register uSDHC_DLL_STATUS, field DLL_STS_SLV_LOCK[0] (RO)
 *
 * Slave delay-line lock status. This signifies that a valid calibration has
 * been set to the slave-delay line and that the slave-delay line is implementing
 * the programmed delay value
 */
/*@{*/
#define BP_uSDHC_DLL_STATUS_DLL_STS_SLV_LOCK (0U) /*!< Bit position for uSDHC_DLL_STATUS_DLL_STS_SLV_LOCK. */
#define BM_uSDHC_DLL_STATUS_DLL_STS_SLV_LOCK (0x00000001U) /*!< Bit mask for uSDHC_DLL_STATUS_DLL_STS_SLV_LOCK. */
#define BS_uSDHC_DLL_STATUS_DLL_STS_SLV_LOCK (1U) /*!< Bit field size in bits for uSDHC_DLL_STATUS_DLL_STS_SLV_LOCK. */

/*! @brief Read current value of the uSDHC_DLL_STATUS_DLL_STS_SLV_LOCK field. */
#define BR_uSDHC_DLL_STATUS_DLL_STS_SLV_LOCK(x) (HW_uSDHC_DLL_STATUS(x).B.DLL_STS_SLV_LOCK)
/*@}*/

/*!
 * @name Register uSDHC_DLL_STATUS, field DLL_STS_REF_LOCK[1] (RO)
 *
 * Reference DLL lock status. This signifies that the DLL has detected and
 * locked to a half-phase ref_clock shift, allowing the slave delay-line to perform
 * programmed clock delays
 */
/*@{*/
#define BP_uSDHC_DLL_STATUS_DLL_STS_REF_LOCK (1U) /*!< Bit position for uSDHC_DLL_STATUS_DLL_STS_REF_LOCK. */
#define BM_uSDHC_DLL_STATUS_DLL_STS_REF_LOCK (0x00000002U) /*!< Bit mask for uSDHC_DLL_STATUS_DLL_STS_REF_LOCK. */
#define BS_uSDHC_DLL_STATUS_DLL_STS_REF_LOCK (1U) /*!< Bit field size in bits for uSDHC_DLL_STATUS_DLL_STS_REF_LOCK. */

/*! @brief Read current value of the uSDHC_DLL_STATUS_DLL_STS_REF_LOCK field. */
#define BR_uSDHC_DLL_STATUS_DLL_STS_REF_LOCK(x) (HW_uSDHC_DLL_STATUS(x).B.DLL_STS_REF_LOCK)
/*@}*/

/*!
 * @name Register uSDHC_DLL_STATUS, field DLL_STS_SLV_SEL[8:2] (RO)
 *
 * Slave delay line select status. This is the instant value generated from
 * reference chain. Since the reference chain can only be updated when REF_CLOCK is
 * detected, this value should be the right value to be updated when the reference
 * is locked.
 */
/*@{*/
#define BP_uSDHC_DLL_STATUS_DLL_STS_SLV_SEL (2U) /*!< Bit position for uSDHC_DLL_STATUS_DLL_STS_SLV_SEL. */
#define BM_uSDHC_DLL_STATUS_DLL_STS_SLV_SEL (0x000001FCU) /*!< Bit mask for uSDHC_DLL_STATUS_DLL_STS_SLV_SEL. */
#define BS_uSDHC_DLL_STATUS_DLL_STS_SLV_SEL (7U) /*!< Bit field size in bits for uSDHC_DLL_STATUS_DLL_STS_SLV_SEL. */

/*! @brief Read current value of the uSDHC_DLL_STATUS_DLL_STS_SLV_SEL field. */
#define BR_uSDHC_DLL_STATUS_DLL_STS_SLV_SEL(x) (HW_uSDHC_DLL_STATUS(x).B.DLL_STS_SLV_SEL)
/*@}*/

/*!
 * @name Register uSDHC_DLL_STATUS, field DLL_STS_REF_SEL[15:9] (RO)
 *
 * Reference delay line select taps. This is encoded by 7 bits for 127 taps.
 */
/*@{*/
#define BP_uSDHC_DLL_STATUS_DLL_STS_REF_SEL (9U) /*!< Bit position for uSDHC_DLL_STATUS_DLL_STS_REF_SEL. */
#define BM_uSDHC_DLL_STATUS_DLL_STS_REF_SEL (0x0000FE00U) /*!< Bit mask for uSDHC_DLL_STATUS_DLL_STS_REF_SEL. */
#define BS_uSDHC_DLL_STATUS_DLL_STS_REF_SEL (7U) /*!< Bit field size in bits for uSDHC_DLL_STATUS_DLL_STS_REF_SEL. */

/*! @brief Read current value of the uSDHC_DLL_STATUS_DLL_STS_REF_SEL field. */
#define BR_uSDHC_DLL_STATUS_DLL_STS_REF_SEL(x) (HW_uSDHC_DLL_STATUS(x).B.DLL_STS_REF_SEL)
/*@}*/

/*******************************************************************************
 * HW_uSDHC_CLK_TUNE_CTRL_STATUS - CLK Tuning Control and Status
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_CLK_TUNE_CTRL_STATUS - CLK Tuning Control and Status (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the Clock Tuning Control status information. All bits
 * are read only and will read the same as the power-reset value. This register
 * is added to support SD3.0 UHS-I SDR104 mode.
 */
typedef union _hw_usdhc_clk_tune_ctrl_status
{
    uint32_t U;
    struct _hw_usdhc_clk_tune_ctrl_status_bitfields
    {
        uint32_t DLY_CELL_SET_POST : 4; /*!< [3:0]  */
        uint32_t DLY_CELL_SET_OUT : 4; /*!< [7:4]  */
        uint32_t DLY_CELL_SET_PRE : 7; /*!< [14:8]  */
        uint32_t NXT_ERR : 1;          /*!< [15]  */
        uint32_t TAP_SEL_POST : 4;     /*!< [19:16]  */
        uint32_t TAP_SEL_OUT : 4;      /*!< [23:20]  */
        uint32_t TAP_SEL_PRE : 7;      /*!< [30:24]  */
        uint32_t PRE_ERR : 1;          /*!< [31]  */
    } B;
} hw_usdhc_clk_tune_ctrl_status_t;

/*!
 * @name Constants and macros for entire uSDHC_CLK_TUNE_CTRL_STATUS register
 */
/*@{*/
#define HW_uSDHC_CLK_TUNE_CTRL_STATUS_ADDR(x) ((uintptr_t)(x) + 0x68U)

#define HW_uSDHC_CLK_TUNE_CTRL_STATUS(x) (*(__IO hw_usdhc_clk_tune_ctrl_status_t *) HW_uSDHC_CLK_TUNE_CTRL_STATUS_ADDR(x))
#define HW_uSDHC_CLK_TUNE_CTRL_STATUS_RD(x) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).U)
#define HW_uSDHC_CLK_TUNE_CTRL_STATUS_WR(x, v) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).U = (v))
#define HW_uSDHC_CLK_TUNE_CTRL_STATUS_SET(x, v) (HW_uSDHC_CLK_TUNE_CTRL_STATUS_WR(x, HW_uSDHC_CLK_TUNE_CTRL_STATUS_RD(x) |  (v)))
#define HW_uSDHC_CLK_TUNE_CTRL_STATUS_CLR(x, v) (HW_uSDHC_CLK_TUNE_CTRL_STATUS_WR(x, HW_uSDHC_CLK_TUNE_CTRL_STATUS_RD(x) & ~(v)))
#define HW_uSDHC_CLK_TUNE_CTRL_STATUS_TOG(x, v) (HW_uSDHC_CLK_TUNE_CTRL_STATUS_WR(x, HW_uSDHC_CLK_TUNE_CTRL_STATUS_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_CLK_TUNE_CTRL_STATUS bitfields
 */

/*!
 * @name Register uSDHC_CLK_TUNE_CTRL_STATUS, field DLY_CELL_SET_POST[3:0] (RW)
 *
 * Set the number of delay cells on the feedback clock between CLK_OUT and
 * CLK_POST.
 */
/*@{*/
#define BP_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST (0U) /*!< Bit position for uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST. */
#define BM_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST (0x0000000FU) /*!< Bit mask for uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST. */
#define BS_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST (4U) /*!< Bit field size in bits for uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST. */

/*! @brief Read current value of the uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST field. */
#define BR_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST(x) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).B.DLY_CELL_SET_POST)

/*! @brief Format value for bitfield uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST. */
#define BF_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST) & BM_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST)

/*! @brief Set the DLY_CELL_SET_POST field to a new value. */
#define BW_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST(x, v) (HW_uSDHC_CLK_TUNE_CTRL_STATUS_WR(x, (HW_uSDHC_CLK_TUNE_CTRL_STATUS_RD(x) & ~BM_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST) | BF_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_POST(v)))
/*@}*/

/*!
 * @name Register uSDHC_CLK_TUNE_CTRL_STATUS, field DLY_CELL_SET_OUT[7:4] (RW)
 *
 * Set the number of delay cells on the feedback clock between CLK_PRE and
 * CLK_OUT.
 */
/*@{*/
#define BP_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT (4U) /*!< Bit position for uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT. */
#define BM_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT (0x000000F0U) /*!< Bit mask for uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT. */
#define BS_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT (4U) /*!< Bit field size in bits for uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT. */

/*! @brief Read current value of the uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT field. */
#define BR_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT(x) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).B.DLY_CELL_SET_OUT)

/*! @brief Format value for bitfield uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT. */
#define BF_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT) & BM_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT)

/*! @brief Set the DLY_CELL_SET_OUT field to a new value. */
#define BW_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT(x, v) (HW_uSDHC_CLK_TUNE_CTRL_STATUS_WR(x, (HW_uSDHC_CLK_TUNE_CTRL_STATUS_RD(x) & ~BM_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT) | BF_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_OUT(v)))
/*@}*/

/*!
 * @name Register uSDHC_CLK_TUNE_CTRL_STATUS, field DLY_CELL_SET_PRE[14:8] (RW)
 *
 * Set the number of delay cells on the feedback clock between the feedback
 * clock and CLK_PRE.
 */
/*@{*/
#define BP_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE (8U) /*!< Bit position for uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE. */
#define BM_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE (0x00007F00U) /*!< Bit mask for uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE. */
#define BS_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE (7U) /*!< Bit field size in bits for uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE. */

/*! @brief Read current value of the uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE field. */
#define BR_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE(x) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).B.DLY_CELL_SET_PRE)

/*! @brief Format value for bitfield uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE. */
#define BF_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE) & BM_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE)

/*! @brief Set the DLY_CELL_SET_PRE field to a new value. */
#define BW_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE(x, v) (HW_uSDHC_CLK_TUNE_CTRL_STATUS_WR(x, (HW_uSDHC_CLK_TUNE_CTRL_STATUS_RD(x) & ~BM_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE) | BF_uSDHC_CLK_TUNE_CTRL_STATUS_DLY_CELL_SET_PRE(v)))
/*@}*/

/*!
 * @name Register uSDHC_CLK_TUNE_CTRL_STATUS, field NXT_ERR[15] (RO)
 *
 * NXT error which means the number of delay cells added on the feedback clock
 * is too large. It's valid only when SMP_CLK_SEL of Mix control register (bit23
 * of 0x48) is enabled.
 */
/*@{*/
#define BP_uSDHC_CLK_TUNE_CTRL_STATUS_NXT_ERR (15U) /*!< Bit position for uSDHC_CLK_TUNE_CTRL_STATUS_NXT_ERR. */
#define BM_uSDHC_CLK_TUNE_CTRL_STATUS_NXT_ERR (0x00008000U) /*!< Bit mask for uSDHC_CLK_TUNE_CTRL_STATUS_NXT_ERR. */
#define BS_uSDHC_CLK_TUNE_CTRL_STATUS_NXT_ERR (1U) /*!< Bit field size in bits for uSDHC_CLK_TUNE_CTRL_STATUS_NXT_ERR. */

/*! @brief Read current value of the uSDHC_CLK_TUNE_CTRL_STATUS_NXT_ERR field. */
#define BR_uSDHC_CLK_TUNE_CTRL_STATUS_NXT_ERR(x) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).B.NXT_ERR)
/*@}*/

/*!
 * @name Register uSDHC_CLK_TUNE_CTRL_STATUS, field TAP_SEL_POST[19:16] (RO)
 *
 * Reflect the number of delay cells added on the feedback clock between CLK_OUT
 * and CLK_POST.
 */
/*@{*/
#define BP_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST (16U) /*!< Bit position for uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST. */
#define BM_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST (0x000F0000U) /*!< Bit mask for uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST. */
#define BS_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST (4U) /*!< Bit field size in bits for uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST. */

/*! @brief Read current value of the uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST field. */
#define BR_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_POST(x) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).B.TAP_SEL_POST)
/*@}*/

/*!
 * @name Register uSDHC_CLK_TUNE_CTRL_STATUS, field TAP_SEL_OUT[23:20] (RO)
 *
 * Reflect the number of delay cells added on the feedback clock between CLK_PRE
 * and CLK_OUT.
 */
/*@{*/
#define BP_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT (20U) /*!< Bit position for uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT. */
#define BM_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT (0x00F00000U) /*!< Bit mask for uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT. */
#define BS_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT (4U) /*!< Bit field size in bits for uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT. */

/*! @brief Read current value of the uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT field. */
#define BR_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_OUT(x) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).B.TAP_SEL_OUT)
/*@}*/

/*!
 * @name Register uSDHC_CLK_TUNE_CTRL_STATUS, field TAP_SEL_PRE[30:24] (RO)
 *
 * Reflects the number of delay cells added on the feedback clock between the
 * feedback clock and CLK_PRE. When AUTO_TUNE_EN (bit24 of 0x48) is disabled,
 * TAP_SEL_PRE is always equal to DLY_CELL_SET_PRE. When AUTO_TUNE_EN (bit24 of 0x48)
 * is enabled, TAP_SEL_PRE will be updated automatically according to the status
 * of the auto tuning circuit to adjust the sample clock phase.
 */
/*@{*/
#define BP_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE (24U) /*!< Bit position for uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE. */
#define BM_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE (0x7F000000U) /*!< Bit mask for uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE. */
#define BS_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE (7U) /*!< Bit field size in bits for uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE. */

/*! @brief Read current value of the uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE field. */
#define BR_uSDHC_CLK_TUNE_CTRL_STATUS_TAP_SEL_PRE(x) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).B.TAP_SEL_PRE)
/*@}*/

/*!
 * @name Register uSDHC_CLK_TUNE_CTRL_STATUS, field PRE_ERR[31] (RO)
 *
 * PRE error which means the number of delay cells added on the feedback clock
 * is too small. It is valid only when SMP_CLK_SEL of Mix control register (bit23
 * of 0x48) is enabled.
 */
/*@{*/
#define BP_uSDHC_CLK_TUNE_CTRL_STATUS_PRE_ERR (31U) /*!< Bit position for uSDHC_CLK_TUNE_CTRL_STATUS_PRE_ERR. */
#define BM_uSDHC_CLK_TUNE_CTRL_STATUS_PRE_ERR (0x80000000U) /*!< Bit mask for uSDHC_CLK_TUNE_CTRL_STATUS_PRE_ERR. */
#define BS_uSDHC_CLK_TUNE_CTRL_STATUS_PRE_ERR (1U) /*!< Bit field size in bits for uSDHC_CLK_TUNE_CTRL_STATUS_PRE_ERR. */

/*! @brief Read current value of the uSDHC_CLK_TUNE_CTRL_STATUS_PRE_ERR field. */
#define BR_uSDHC_CLK_TUNE_CTRL_STATUS_PRE_ERR(x) (HW_uSDHC_CLK_TUNE_CTRL_STATUS(x).B.PRE_ERR)
/*@}*/

/*******************************************************************************
 * HW_uSDHC_STROBE_DLL_CTRL - Strobe DLL Control
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_STROBE_DLL_CTRL - Strobe DLL Control (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the strobe DLL Control information.
 */
typedef union _hw_usdhc_strobe_dll_ctrl
{
    uint32_t U;
    struct _hw_usdhc_strobe_dll_ctrl_bitfields
    {
        uint32_t STROBE_DLL_CTRL_ENABLE : 1; /*!< [0] Strobe DLL Control
                                        * Enable */
        uint32_t STROBE_DLL_CTRL_RESET : 1; /*!< [1] Strobe DLL Control Reset
                                        * */
        uint32_t STROBE_DLL_CTRL_SLV_FORCE_UPD : 1; /*!< [2] Strobe DLL
                                        * Control Slave Force Updated */
        uint32_t STROBE_DLL_CTRL_SLV_DLY_TARGET : 3; /*!< [5:3] Strobe DLL
                                        * Control Slave Delay Target */
        uint32_t STROBE_DLL_CTRL_GATE_UPDATE_0 : 1; /*!< [6] Strobe DLL
                                        * Control Gate Update */
        uint32_t STROBE_DLL_CTRL_GATE_UPDATE_1 : 1; /*!< [7] Strobe DLL
                                        * Control Gate Update */
        uint32_t STROBE_DLL_CTRL_SLV_OVERRIDE : 1; /*!< [8] Strobe DLL
                                        * Control Slave Override */
        uint32_t STROBE_DLL_CTRL_SLV_OVERRIDE_VAL : 7; /*!< [15:9] Strobe DLL
                                        * Control Slave Override Value */
        uint32_t RESERVED0 : 4;        /*!< [19:16] This field is reserved. */
        uint32_t STROBE_DLL_CTRL_SLV_UPDATE_INT : 8; /*!< [27:20] Strobe DLL
                                        * Control Slave Update Interval */
        uint32_t STROBE_DLL_CTRL_REF_UPDATE_INT : 4; /*!< [31:28] Strobe DLL
                                        * Control Reference Update Interval */
    } B;
} hw_usdhc_strobe_dll_ctrl_t;

/*!
 * @name Constants and macros for entire uSDHC_STROBE_DLL_CTRL register
 */
/*@{*/
#define HW_uSDHC_STROBE_DLL_CTRL_ADDR(x) ((uintptr_t)(x) + 0x70U)

#define HW_uSDHC_STROBE_DLL_CTRL(x) (*(__IO hw_usdhc_strobe_dll_ctrl_t *) HW_uSDHC_STROBE_DLL_CTRL_ADDR(x))
#define HW_uSDHC_STROBE_DLL_CTRL_RD(x) (HW_uSDHC_STROBE_DLL_CTRL(x).U)
#define HW_uSDHC_STROBE_DLL_CTRL_WR(x, v) (HW_uSDHC_STROBE_DLL_CTRL(x).U = (v))
#define HW_uSDHC_STROBE_DLL_CTRL_SET(x, v) (HW_uSDHC_STROBE_DLL_CTRL_WR(x, HW_uSDHC_STROBE_DLL_CTRL_RD(x) |  (v)))
#define HW_uSDHC_STROBE_DLL_CTRL_CLR(x, v) (HW_uSDHC_STROBE_DLL_CTRL_WR(x, HW_uSDHC_STROBE_DLL_CTRL_RD(x) & ~(v)))
#define HW_uSDHC_STROBE_DLL_CTRL_TOG(x, v) (HW_uSDHC_STROBE_DLL_CTRL_WR(x, HW_uSDHC_STROBE_DLL_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_STROBE_DLL_CTRL bitfields
 */

/*!
 * @name Register uSDHC_STROBE_DLL_CTRL, field STROBE_DLL_CTRL_ENABLE[0] (RW)
 *
 * Set this bit to 1 to enable the DLL and delay chain; otherwise, set to 0 to
 * bypasses DLL. Using the slave delay line override feature with
 * STROBE_SLV_OVERRIDE and STROBE_SLV_OVERRIDE VAL, the DLL does not need to be enabled.
 */
/*@{*/
#define BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_ENABLE (0U) /*!< Bit position for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_ENABLE. */
#define BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_ENABLE (0x00000001U) /*!< Bit mask for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_ENABLE. */
#define BS_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_ENABLE (1U) /*!< Bit field size in bits for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_ENABLE. */

/*! @brief Read current value of the uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_ENABLE field. */
#define BR_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_ENABLE(x) (HW_uSDHC_STROBE_DLL_CTRL(x).B.STROBE_DLL_CTRL_ENABLE)

/*! @brief Format value for bitfield uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_ENABLE. */
#define BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_ENABLE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_ENABLE) & BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_ENABLE)

/*! @brief Set the STROBE_DLL_CTRL_ENABLE field to a new value. */
#define BW_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_ENABLE(x, v) (HW_uSDHC_STROBE_DLL_CTRL_WR(x, (HW_uSDHC_STROBE_DLL_CTRL_RD(x) & ~BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_ENABLE) | BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_ENABLE(v)))
/*@}*/

/*!
 * @name Register uSDHC_STROBE_DLL_CTRL, field STROBE_DLL_CTRL_RESET[1] (RW)
 *
 * Setting this bit to 1 to force a reset on DLL. This will cause the DLL to
 * lose lock and re-calibrate to detect an REF_CLOCK half period phase shift. This
 * signal is used by the DLL as edge-sensitive, in order to create a subsequent
 * reset, RESET must be taken low and then asserted again.
 */
/*@{*/
#define BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_RESET (1U) /*!< Bit position for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_RESET. */
#define BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_RESET (0x00000002U) /*!< Bit mask for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_RESET. */
#define BS_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_RESET (1U) /*!< Bit field size in bits for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_RESET. */

/*! @brief Read current value of the uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_RESET field. */
#define BR_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_RESET(x) (HW_uSDHC_STROBE_DLL_CTRL(x).B.STROBE_DLL_CTRL_RESET)

/*! @brief Format value for bitfield uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_RESET. */
#define BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_RESET(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_RESET) & BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_RESET)

/*! @brief Set the STROBE_DLL_CTRL_RESET field to a new value. */
#define BW_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_RESET(x, v) (HW_uSDHC_STROBE_DLL_CTRL_WR(x, (HW_uSDHC_STROBE_DLL_CTRL_RD(x) & ~BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_RESET) | BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_RESET(v)))
/*@}*/

/*!
 * @name Register uSDHC_STROBE_DLL_CTRL, field STROBE_DLL_CTRL_SLV_FORCE_UPD[2] (RW)
 *
 * Setting this bit to 1, forces the slave delay line to update to the DLL
 * calibrated value immediately. The slave delay line should automatically update the
 * STROBE_SLV_UPDATE_INT interval or when a DLL lock condition is sensed.
 * Subsequent forcing of the slave-line update can only occur if STROBE_SLV_FORCE_UP is
 * set back to 0 and then asserted again (edge triggered). Be sure to use it when
 * uSDHC is idle. This function may not work when uSDHC is working on data / cmd
 * / response.
 */
/*@{*/
#define BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_FORCE_UPD (2U) /*!< Bit position for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_FORCE_UPD. */
#define BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_FORCE_UPD (0x00000004U) /*!< Bit mask for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_FORCE_UPD. */
#define BS_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_FORCE_UPD (1U) /*!< Bit field size in bits for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_FORCE_UPD. */

/*! @brief Read current value of the uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_FORCE_UPD field. */
#define BR_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_FORCE_UPD(x) (HW_uSDHC_STROBE_DLL_CTRL(x).B.STROBE_DLL_CTRL_SLV_FORCE_UPD)

/*! @brief Format value for bitfield uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_FORCE_UPD. */
#define BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_FORCE_UPD(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_FORCE_UPD) & BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_FORCE_UPD)

/*! @brief Set the STROBE_DLL_CTRL_SLV_FORCE_UPD field to a new value. */
#define BW_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_FORCE_UPD(x, v) (HW_uSDHC_STROBE_DLL_CTRL_WR(x, (HW_uSDHC_STROBE_DLL_CTRL_RD(x) & ~BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_FORCE_UPD) | BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_FORCE_UPD(v)))
/*@}*/

/*!
 * @name Register uSDHC_STROBE_DLL_CTRL, field STROBE_DLL_CTRL_SLV_DLY_TARGET[5:3] (RW)
 *
 * The delay target for the uSDHC loopback read clock can be programmed in
 * 1/16th increments of an STROBE_REF_CLOCK half-period. The delay is
 * ((STROBE_DLL_CTRL_SLV_DLY_TARGET + 1) * STROBE_REF_CLOCK / 2) / 16, So the input read-clock
 * can be delayed relative input data from (STROBE_REF_CLOCK / 2) / 16 to
 * (STROBE_REF_CLOCK *4)/16.
 */
/*@{*/
#define BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET (3U) /*!< Bit position for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET. */
#define BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET (0x00000038U) /*!< Bit mask for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET. */
#define BS_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET (3U) /*!< Bit field size in bits for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET. */

/*! @brief Read current value of the uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET field. */
#define BR_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET(x) (HW_uSDHC_STROBE_DLL_CTRL(x).B.STROBE_DLL_CTRL_SLV_DLY_TARGET)

/*! @brief Format value for bitfield uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET. */
#define BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET) & BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET)

/*! @brief Set the STROBE_DLL_CTRL_SLV_DLY_TARGET field to a new value. */
#define BW_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET(x, v) (HW_uSDHC_STROBE_DLL_CTRL_WR(x, (HW_uSDHC_STROBE_DLL_CTRL_RD(x) & ~BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET) | BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_DLY_TARGET(v)))
/*@}*/

/*!
 * @name Register uSDHC_STROBE_DLL_CTRL, field STROBE_DLL_CTRL_GATE_UPDATE_0[6] (RW)
 *
 * Set this bit to 1 to prevent the DLL from updating (since when
 * STROBE_CLOCK_IN exists, glitches may appear during DLL updates). This bit can be used by
 * software if such a condition occurs. Clear the bit to 0 to allow the DLL to
 * update automatically.
 */
/*@{*/
#define BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_0 (6U) /*!< Bit position for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_0. */
#define BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_0 (0x00000040U) /*!< Bit mask for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_0. */
#define BS_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_0 (1U) /*!< Bit field size in bits for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_0. */

/*! @brief Read current value of the uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_0 field. */
#define BR_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_0(x) (HW_uSDHC_STROBE_DLL_CTRL(x).B.STROBE_DLL_CTRL_GATE_UPDATE_0)

/*! @brief Format value for bitfield uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_0. */
#define BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_0(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_0) & BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_0)

/*! @brief Set the STROBE_DLL_CTRL_GATE_UPDATE_0 field to a new value. */
#define BW_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_0(x, v) (HW_uSDHC_STROBE_DLL_CTRL_WR(x, (HW_uSDHC_STROBE_DLL_CTRL_RD(x) & ~BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_0) | BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_0(v)))
/*@}*/

/*!
 * @name Register uSDHC_STROBE_DLL_CTRL, field STROBE_DLL_CTRL_GATE_UPDATE_1[7] (RW)
 *
 * Set this bit to 1 to prevent the DLL from updating (since when
 * STROBE_CLOCK_IN exists, glitches may appear during DLL updates). This bit can be used by
 * software if such a condition occurs. Clear the bit to 0 to allow the DLL to
 * update automatically.
 */
/*@{*/
#define BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_1 (7U) /*!< Bit position for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_1. */
#define BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_1 (0x00000080U) /*!< Bit mask for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_1. */
#define BS_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_1 (1U) /*!< Bit field size in bits for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_1. */

/*! @brief Read current value of the uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_1 field. */
#define BR_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_1(x) (HW_uSDHC_STROBE_DLL_CTRL(x).B.STROBE_DLL_CTRL_GATE_UPDATE_1)

/*! @brief Format value for bitfield uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_1. */
#define BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_1(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_1) & BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_1)

/*! @brief Set the STROBE_DLL_CTRL_GATE_UPDATE_1 field to a new value. */
#define BW_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_1(x, v) (HW_uSDHC_STROBE_DLL_CTRL_WR(x, (HW_uSDHC_STROBE_DLL_CTRL_RD(x) & ~BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_1) | BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_GATE_UPDATE_1(v)))
/*@}*/

/*!
 * @name Register uSDHC_STROBE_DLL_CTRL, field STROBE_DLL_CTRL_SLV_OVERRIDE[8] (RW)
 *
 * Set this bit to 1 to Enable manual override for slave delay chain using
 * STROBE_SLV_OVERRIDE_VAL; set this bit to 0 to disable manual override. This feature
 * does not require the DLL to be enabled using the ENABLE bit. In fact to
 * reduce power, if STROBE_SLV_OVERRIDE is used, it is recommended to disable the DLL
 * with ENABLE = 0.
 */
/*@{*/
#define BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE (8U) /*!< Bit position for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE. */
#define BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE (0x00000100U) /*!< Bit mask for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE. */
#define BS_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE (1U) /*!< Bit field size in bits for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE. */

/*! @brief Read current value of the uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE field. */
#define BR_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE(x) (HW_uSDHC_STROBE_DLL_CTRL(x).B.STROBE_DLL_CTRL_SLV_OVERRIDE)

/*! @brief Format value for bitfield uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE. */
#define BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE) & BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE)

/*! @brief Set the STROBE_DLL_CTRL_SLV_OVERRIDE field to a new value. */
#define BW_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE(x, v) (HW_uSDHC_STROBE_DLL_CTRL_WR(x, (HW_uSDHC_STROBE_DLL_CTRL_RD(x) & ~BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE) | BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE(v)))
/*@}*/

/*!
 * @name Register uSDHC_STROBE_DLL_CTRL, field STROBE_DLL_CTRL_SLV_OVERRIDE_VAL[15:9] (RW)
 *
 * When STROBE_SLV_OVERRIDE = 1, this field is used to manually select one of
 * 128 physical taps. A value of 0 selects tap 1, and a value of 0x7F selects tap
 * 128.
 */
/*@{*/
#define BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL (9U) /*!< Bit position for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL (0x0000FE00U) /*!< Bit mask for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BS_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL (7U) /*!< Bit field size in bits for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL. */

/*! @brief Read current value of the uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL field. */
#define BR_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL(x) (HW_uSDHC_STROBE_DLL_CTRL(x).B.STROBE_DLL_CTRL_SLV_OVERRIDE_VAL)

/*! @brief Format value for bitfield uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL. */
#define BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL) & BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL)

/*! @brief Set the STROBE_DLL_CTRL_SLV_OVERRIDE_VAL field to a new value. */
#define BW_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL(x, v) (HW_uSDHC_STROBE_DLL_CTRL_WR(x, (HW_uSDHC_STROBE_DLL_CTRL_RD(x) & ~BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL) | BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_OVERRIDE_VAL(v)))
/*@}*/

/*!
 * @name Register uSDHC_STROBE_DLL_CTRL, field STROBE_DLL_CTRL_SLV_UPDATE_INT[27:20] (RW)
 *
 * Slave delay line update interval. If default 0 is used, it means 256 cycles
 * of STROBE_REF_CLOCK. A value of 0x0F results in 15 cycles and so on. software
 * can always cause an update of the slave-delay line using the
 * STROBE_SLV_FORCE_UPDATE register. The slave delay line will also update automatically when the
 * reference DLL transitions to a locked state (from an un-locked state).
 */
/*@{*/
#define BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT (20U) /*!< Bit position for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT. */
#define BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT (0x0FF00000U) /*!< Bit mask for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT. */
#define BS_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT (8U) /*!< Bit field size in bits for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT. */

/*! @brief Read current value of the uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT field. */
#define BR_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT(x) (HW_uSDHC_STROBE_DLL_CTRL(x).B.STROBE_DLL_CTRL_SLV_UPDATE_INT)

/*! @brief Format value for bitfield uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT. */
#define BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT) & BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT)

/*! @brief Set the STROBE_DLL_CTRL_SLV_UPDATE_INT field to a new value. */
#define BW_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT(x, v) (HW_uSDHC_STROBE_DLL_CTRL_WR(x, (HW_uSDHC_STROBE_DLL_CTRL_RD(x) & ~BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT) | BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_SLV_UPDATE_INT(v)))
/*@}*/

/*!
 * @name Register uSDHC_STROBE_DLL_CTRL, field STROBE_DLL_CTRL_REF_UPDATE_INT[31:28] (RW)
 *
 * The interval cycle is (2 + STROBE_REF_UPDATE_INT) * STROBE_REF_CLOCK. By
 * default, the DLL control loop shall update every two STROBE_REF_CLOCK cycles.
 * Increasing the reference delay-line update interval reduces the ability of the DLL
 * to adjust to fast changes in conditions that may effect the delay (such as
 * voltage and temperature)
 */
/*@{*/
#define BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT (28U) /*!< Bit position for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT. */
#define BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT (0xF0000000U) /*!< Bit mask for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT. */
#define BS_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT (4U) /*!< Bit field size in bits for uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT. */

/*! @brief Read current value of the uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT field. */
#define BR_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT(x) (HW_uSDHC_STROBE_DLL_CTRL(x).B.STROBE_DLL_CTRL_REF_UPDATE_INT)

/*! @brief Format value for bitfield uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT. */
#define BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT) & BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT)

/*! @brief Set the STROBE_DLL_CTRL_REF_UPDATE_INT field to a new value. */
#define BW_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT(x, v) (HW_uSDHC_STROBE_DLL_CTRL_WR(x, (HW_uSDHC_STROBE_DLL_CTRL_RD(x) & ~BM_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT) | BF_uSDHC_STROBE_DLL_CTRL_STROBE_DLL_CTRL_REF_UPDATE_INT(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_STROBE_DLL_STATUS - Strobe DLL Status
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_STROBE_DLL_STATUS - Strobe DLL Status (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the strobe DLL status information. All bits are read
 * only and read the same as the power-reset value.
 */
typedef union _hw_usdhc_strobe_dll_status
{
    uint32_t U;
    struct _hw_usdhc_strobe_dll_status_bitfields
    {
        uint32_t STROBE_DLL_STS_SLV_LOCK : 1; /*!< [0] Strobe DLL Status
                                        * Slave Lock */
        uint32_t STROBE_DLL_STS_REF_LOCK : 1; /*!< [1] Strobe DLL Status
                                        * Reference Lock */
        uint32_t STROBE_DLL_STS_SLV_SEL : 7; /*!< [8:2] Strobe DLL Status
                                        * Slave Select */
        uint32_t STROBE_DLL_STS_REF_SEL : 7; /*!< [15:9] Strobe DLL Status
                                        * Reference Select */
        uint32_t RESERVED0 : 16;       /*!< [31:16] This field is reserved. */
    } B;
} hw_usdhc_strobe_dll_status_t;

/*!
 * @name Constants and macros for entire uSDHC_STROBE_DLL_STATUS register
 */
/*@{*/
#define HW_uSDHC_STROBE_DLL_STATUS_ADDR(x) ((uintptr_t)(x) + 0x74U)

#define HW_uSDHC_STROBE_DLL_STATUS(x) (*(__I hw_usdhc_strobe_dll_status_t *) HW_uSDHC_STROBE_DLL_STATUS_ADDR(x))
#define HW_uSDHC_STROBE_DLL_STATUS_RD(x) (HW_uSDHC_STROBE_DLL_STATUS(x).U)
/*@}*/

/*
 * Constants & macros for individual uSDHC_STROBE_DLL_STATUS bitfields
 */

/*!
 * @name Register uSDHC_STROBE_DLL_STATUS, field STROBE_DLL_STS_SLV_LOCK[0] (RO)
 *
 * Slave delay-line lock status. This signifies that a valid calibration has
 * been set to the slave-delay line, and the slave-delay line is implementing the
 * programmed delay value.
 */
/*@{*/
#define BP_uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_LOCK (0U) /*!< Bit position for uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_LOCK. */
#define BM_uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_LOCK (0x00000001U) /*!< Bit mask for uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_LOCK. */
#define BS_uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_LOCK (1U) /*!< Bit field size in bits for uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_LOCK. */

/*! @brief Read current value of the uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_LOCK field. */
#define BR_uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_LOCK(x) (HW_uSDHC_STROBE_DLL_STATUS(x).B.STROBE_DLL_STS_SLV_LOCK)
/*@}*/

/*!
 * @name Register uSDHC_STROBE_DLL_STATUS, field STROBE_DLL_STS_REF_LOCK[1] (RO)
 *
 * This signifies that the DLL has detected and locked to a half-phase REF_CLOCK
 * shift, it allows the slave delay-line to perform programmed clock delays.
 */
/*@{*/
#define BP_uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_LOCK (1U) /*!< Bit position for uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_LOCK. */
#define BM_uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_LOCK (0x00000002U) /*!< Bit mask for uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_LOCK. */
#define BS_uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_LOCK (1U) /*!< Bit field size in bits for uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_LOCK. */

/*! @brief Read current value of the uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_LOCK field. */
#define BR_uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_LOCK(x) (HW_uSDHC_STROBE_DLL_STATUS(x).B.STROBE_DLL_STS_REF_LOCK)
/*@}*/

/*!
 * @name Register uSDHC_STROBE_DLL_STATUS, field STROBE_DLL_STS_SLV_SEL[8:2] (RO)
 *
 * Slave delay line select status. This is the instant value generated from
 * reference chain. Since the reference chain can only be updated when
 * STROBE_REF_CLOCK is detected, this value can be updated with the right value when the
 * reference is locked.
 */
/*@{*/
#define BP_uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_SEL (2U) /*!< Bit position for uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_SEL. */
#define BM_uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_SEL (0x000001FCU) /*!< Bit mask for uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_SEL. */
#define BS_uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_SEL (7U) /*!< Bit field size in bits for uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_SEL. */

/*! @brief Read current value of the uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_SEL field. */
#define BR_uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_SLV_SEL(x) (HW_uSDHC_STROBE_DLL_STATUS(x).B.STROBE_DLL_STS_SLV_SEL)
/*@}*/

/*!
 * @name Register uSDHC_STROBE_DLL_STATUS, field STROBE_DLL_STS_REF_SEL[15:9] (RO)
 *
 * Reference delay line select taps. This is encoded by 7 bits for 127 taps.
 */
/*@{*/
#define BP_uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_SEL (9U) /*!< Bit position for uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_SEL. */
#define BM_uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_SEL (0x0000FE00U) /*!< Bit mask for uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_SEL. */
#define BS_uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_SEL (7U) /*!< Bit field size in bits for uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_SEL. */

/*! @brief Read current value of the uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_SEL field. */
#define BR_uSDHC_STROBE_DLL_STATUS_STROBE_DLL_STS_REF_SEL(x) (HW_uSDHC_STROBE_DLL_STATUS(x).B.STROBE_DLL_STS_REF_SEL)
/*@}*/

/*******************************************************************************
 * HW_uSDHC_VEND_SPEC - Vendor Specific Register
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_VEND_SPEC - Vendor Specific Register (RW)
 *
 * Reset value: 0x20007809U
 *
 * This register contains the vendor specific control / status register.
 */
typedef union _hw_usdhc_vend_spec
{
    uint32_t U;
    struct _hw_usdhc_vend_spec_bitfields
    {
        uint32_t EXT_DMA_EN : 1;       /*!< [0] External DMA Request Enable */
        uint32_t VSELECT : 1;          /*!< [1] Voltage Selection */
        uint32_t CONFLICT_CHK_EN : 1;  /*!< [2] Conflict check enable. */
        uint32_t AC12_WR_CHKBUSY_EN : 1; /*!< [3]  */
        uint32_t DAT3_CD_POL : 1;      /*!< [4]  */
        uint32_t CD_POL : 1;           /*!< [5]  */
        uint32_t WP_POL : 1;           /*!< [6]  */
        uint32_t CLKONJ_IN_ABORT : 1;  /*!< [7]  */
        uint32_t FRC_SDCLK_ON : 1;     /*!< [8]  */
        uint32_t RESERVED0 : 2;        /*!< [10:9]  */
        uint32_t IPG_CLK_SOFT_EN : 1;  /*!< [11] IPG_CLK Software Enable */
        uint32_t HCLK_SOFT_EN : 1;     /*!< [12] AHB Clock Software Enable */
        uint32_t IPG_PERCLK_SOFT_EN : 1; /*!< [13] IPG_PERCLK Software Enable
                                        * */
        uint32_t CARD_CLK_SOFT_EN : 1; /*!< [14] Card Clock Software Enable */
        uint32_t CRC_CHK_DIS : 1;      /*!< [15] CRC Check Disable */
        uint32_t INT_ST_VAL : 8;       /*!< [23:16] Internal State Value */
        uint32_t RESERVED1 : 7;        /*!< [30:24]  */
        uint32_t CMD_BYTE_EN : 1;      /*!< [31]  */
    } B;
} hw_usdhc_vend_spec_t;

/*!
 * @name Constants and macros for entire uSDHC_VEND_SPEC register
 */
/*@{*/
#define HW_uSDHC_VEND_SPEC_ADDR(x) ((uintptr_t)(x) + 0xC0U)

#define HW_uSDHC_VEND_SPEC(x)    (*(__IO hw_usdhc_vend_spec_t *) HW_uSDHC_VEND_SPEC_ADDR(x))
#define HW_uSDHC_VEND_SPEC_RD(x) (HW_uSDHC_VEND_SPEC(x).U)
#define HW_uSDHC_VEND_SPEC_WR(x, v) (HW_uSDHC_VEND_SPEC(x).U = (v))
#define HW_uSDHC_VEND_SPEC_SET(x, v) (HW_uSDHC_VEND_SPEC_WR(x, HW_uSDHC_VEND_SPEC_RD(x) |  (v)))
#define HW_uSDHC_VEND_SPEC_CLR(x, v) (HW_uSDHC_VEND_SPEC_WR(x, HW_uSDHC_VEND_SPEC_RD(x) & ~(v)))
#define HW_uSDHC_VEND_SPEC_TOG(x, v) (HW_uSDHC_VEND_SPEC_WR(x, HW_uSDHC_VEND_SPEC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_VEND_SPEC bitfields
 */

/*!
 * @name Register uSDHC_VEND_SPEC, field EXT_DMA_EN[0] (RW)
 *
 * Enable the request to external DMA. When the internal DMA (either Simple DMA
 * or Advanced DMA) is not in use, and this bit is set, uSDHC will send out DMA
 * request when the internal buffer is ready. This bit is particularly useful when
 * transferring data by ARM platform polling mode, and it is not allowed to send
 * out the external DMA request. By default, this bit is set.
 *
 * Values:
 * - 0 - In any scenario, uSDHC does not send out external DMA request.
 * - 1 - When internal DMA is not active, the external DMA request will be sent
 *     out.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_EXT_DMA_EN (0U) /*!< Bit position for uSDHC_VEND_SPEC_EXT_DMA_EN. */
#define BM_uSDHC_VEND_SPEC_EXT_DMA_EN (0x00000001U) /*!< Bit mask for uSDHC_VEND_SPEC_EXT_DMA_EN. */
#define BS_uSDHC_VEND_SPEC_EXT_DMA_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_EXT_DMA_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_EXT_DMA_EN field. */
#define BR_uSDHC_VEND_SPEC_EXT_DMA_EN(x) (HW_uSDHC_VEND_SPEC(x).B.EXT_DMA_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_EXT_DMA_EN. */
#define BF_uSDHC_VEND_SPEC_EXT_DMA_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_EXT_DMA_EN) & BM_uSDHC_VEND_SPEC_EXT_DMA_EN)

/*! @brief Set the EXT_DMA_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC_EXT_DMA_EN(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_EXT_DMA_EN) | BF_uSDHC_VEND_SPEC_EXT_DMA_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field VSELECT[1] (RW)
 *
 * Change the value of output signal VSELECT, to control the voltage on pads for
 * external card. There must be a control circuit out of uSDHC to change the
 * voltage on pads.
 *
 * Values:
 * - 1 - Change the voltage to low voltage range, around 1.8 V
 * - 0 - Change the voltage to high voltage range, around 3.0 V
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_VSELECT (1U)    /*!< Bit position for uSDHC_VEND_SPEC_VSELECT. */
#define BM_uSDHC_VEND_SPEC_VSELECT (0x00000002U) /*!< Bit mask for uSDHC_VEND_SPEC_VSELECT. */
#define BS_uSDHC_VEND_SPEC_VSELECT (1U)    /*!< Bit field size in bits for uSDHC_VEND_SPEC_VSELECT. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_VSELECT field. */
#define BR_uSDHC_VEND_SPEC_VSELECT(x) (HW_uSDHC_VEND_SPEC(x).B.VSELECT)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_VSELECT. */
#define BF_uSDHC_VEND_SPEC_VSELECT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_VSELECT) & BM_uSDHC_VEND_SPEC_VSELECT)

/*! @brief Set the VSELECT field to a new value. */
#define BW_uSDHC_VEND_SPEC_VSELECT(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_VSELECT) | BF_uSDHC_VEND_SPEC_VSELECT(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field CONFLICT_CHK_EN[2] (RW)
 *
 * It is not implemented in uSDHC IP.
 *
 * Values:
 * - 0 - Conflict check disable
 * - 1 - Conflict check enable
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_CONFLICT_CHK_EN (2U) /*!< Bit position for uSDHC_VEND_SPEC_CONFLICT_CHK_EN. */
#define BM_uSDHC_VEND_SPEC_CONFLICT_CHK_EN (0x00000004U) /*!< Bit mask for uSDHC_VEND_SPEC_CONFLICT_CHK_EN. */
#define BS_uSDHC_VEND_SPEC_CONFLICT_CHK_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_CONFLICT_CHK_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_CONFLICT_CHK_EN field. */
#define BR_uSDHC_VEND_SPEC_CONFLICT_CHK_EN(x) (HW_uSDHC_VEND_SPEC(x).B.CONFLICT_CHK_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_CONFLICT_CHK_EN. */
#define BF_uSDHC_VEND_SPEC_CONFLICT_CHK_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_CONFLICT_CHK_EN) & BM_uSDHC_VEND_SPEC_CONFLICT_CHK_EN)

/*! @brief Set the CONFLICT_CHK_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC_CONFLICT_CHK_EN(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_CONFLICT_CHK_EN) | BF_uSDHC_VEND_SPEC_CONFLICT_CHK_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field AC12_WR_CHKBUSY_EN[3] (RW)
 *
 * Check busy enable after auto CMD12 for write data packet
 *
 * Values:
 * - 0 - Do not check busy after auto CMD12 for write data packet
 * - 1 - Check busy after auto CMD12 for write data packet
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN (3U) /*!< Bit position for uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN. */
#define BM_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN (0x00000008U) /*!< Bit mask for uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN. */
#define BS_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN field. */
#define BR_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN(x) (HW_uSDHC_VEND_SPEC(x).B.AC12_WR_CHKBUSY_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN. */
#define BF_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN) & BM_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN)

/*! @brief Set the AC12_WR_CHKBUSY_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN) | BF_uSDHC_VEND_SPEC_AC12_WR_CHKBUSY_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field DAT3_CD_POL[4] (RW)
 *
 * Only for debug. Polarity of DATA3 pin when it is used as card detection.
 *
 * Values:
 * - 0 - Card detected when DATA3 is high.
 * - 1 - Card detected when DATA3 is low.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_DAT3_CD_POL (4U) /*!< Bit position for uSDHC_VEND_SPEC_DAT3_CD_POL. */
#define BM_uSDHC_VEND_SPEC_DAT3_CD_POL (0x00000010U) /*!< Bit mask for uSDHC_VEND_SPEC_DAT3_CD_POL. */
#define BS_uSDHC_VEND_SPEC_DAT3_CD_POL (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_DAT3_CD_POL. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_DAT3_CD_POL field. */
#define BR_uSDHC_VEND_SPEC_DAT3_CD_POL(x) (HW_uSDHC_VEND_SPEC(x).B.DAT3_CD_POL)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_DAT3_CD_POL. */
#define BF_uSDHC_VEND_SPEC_DAT3_CD_POL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_DAT3_CD_POL) & BM_uSDHC_VEND_SPEC_DAT3_CD_POL)

/*! @brief Set the DAT3_CD_POL field to a new value. */
#define BW_uSDHC_VEND_SPEC_DAT3_CD_POL(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_DAT3_CD_POL) | BF_uSDHC_VEND_SPEC_DAT3_CD_POL(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field CD_POL[5] (RW)
 *
 * Only for debug. Polarity of the CD_B pin:
 *
 * Values:
 * - 0 - CD_B pin is low active.
 * - 1 - CD_B pin is high active.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_CD_POL (5U)     /*!< Bit position for uSDHC_VEND_SPEC_CD_POL. */
#define BM_uSDHC_VEND_SPEC_CD_POL (0x00000020U) /*!< Bit mask for uSDHC_VEND_SPEC_CD_POL. */
#define BS_uSDHC_VEND_SPEC_CD_POL (1U)     /*!< Bit field size in bits for uSDHC_VEND_SPEC_CD_POL. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_CD_POL field. */
#define BR_uSDHC_VEND_SPEC_CD_POL(x) (HW_uSDHC_VEND_SPEC(x).B.CD_POL)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_CD_POL. */
#define BF_uSDHC_VEND_SPEC_CD_POL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_CD_POL) & BM_uSDHC_VEND_SPEC_CD_POL)

/*! @brief Set the CD_POL field to a new value. */
#define BW_uSDHC_VEND_SPEC_CD_POL(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_CD_POL) | BF_uSDHC_VEND_SPEC_CD_POL(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field WP_POL[6] (RW)
 *
 * Only for debug. Polarity of the WP pin:
 *
 * Values:
 * - 0 - WP pin is high active.
 * - 1 - WP pin is low active.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_WP_POL (6U)     /*!< Bit position for uSDHC_VEND_SPEC_WP_POL. */
#define BM_uSDHC_VEND_SPEC_WP_POL (0x00000040U) /*!< Bit mask for uSDHC_VEND_SPEC_WP_POL. */
#define BS_uSDHC_VEND_SPEC_WP_POL (1U)     /*!< Bit field size in bits for uSDHC_VEND_SPEC_WP_POL. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_WP_POL field. */
#define BR_uSDHC_VEND_SPEC_WP_POL(x) (HW_uSDHC_VEND_SPEC(x).B.WP_POL)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_WP_POL. */
#define BF_uSDHC_VEND_SPEC_WP_POL(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_WP_POL) & BM_uSDHC_VEND_SPEC_WP_POL)

/*! @brief Set the WP_POL field to a new value. */
#define BW_uSDHC_VEND_SPEC_WP_POL(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_WP_POL) | BF_uSDHC_VEND_SPEC_WP_POL(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field CLKONJ_IN_ABORT[7] (RW)
 *
 * Only for debug. Force CLK output active when sending Abort command:
 *
 * Values:
 * - 0 - The CLK output is active when sending abort command while data is
 *     transmitting even if the internal FIFO is full (for read) or empty (for write).
 * - 1 - The CLK output is inactive when sending abort command while data is
 *     transmitting if the internal FIFO is full (for read) or empty (for write).
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT (7U) /*!< Bit position for uSDHC_VEND_SPEC_CLKONJ_IN_ABORT. */
#define BM_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT (0x00000080U) /*!< Bit mask for uSDHC_VEND_SPEC_CLKONJ_IN_ABORT. */
#define BS_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_CLKONJ_IN_ABORT. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_CLKONJ_IN_ABORT field. */
#define BR_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT(x) (HW_uSDHC_VEND_SPEC(x).B.CLKONJ_IN_ABORT)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_CLKONJ_IN_ABORT. */
#define BF_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT) & BM_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT)

/*! @brief Set the CLKONJ_IN_ABORT field to a new value. */
#define BW_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT) | BF_uSDHC_VEND_SPEC_CLKONJ_IN_ABORT(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field FRC_SDCLK_ON[8] (RW)
 *
 * Force CLK output active
 *
 * Values:
 * - 0 - CLK active or inactive is fully controlled by the hardware.
 * - 1 - Force CLK active.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_FRC_SDCLK_ON (8U) /*!< Bit position for uSDHC_VEND_SPEC_FRC_SDCLK_ON. */
#define BM_uSDHC_VEND_SPEC_FRC_SDCLK_ON (0x00000100U) /*!< Bit mask for uSDHC_VEND_SPEC_FRC_SDCLK_ON. */
#define BS_uSDHC_VEND_SPEC_FRC_SDCLK_ON (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_FRC_SDCLK_ON. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_FRC_SDCLK_ON field. */
#define BR_uSDHC_VEND_SPEC_FRC_SDCLK_ON(x) (HW_uSDHC_VEND_SPEC(x).B.FRC_SDCLK_ON)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_FRC_SDCLK_ON. */
#define BF_uSDHC_VEND_SPEC_FRC_SDCLK_ON(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_FRC_SDCLK_ON) & BM_uSDHC_VEND_SPEC_FRC_SDCLK_ON)

/*! @brief Set the FRC_SDCLK_ON field to a new value. */
#define BW_uSDHC_VEND_SPEC_FRC_SDCLK_ON(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_FRC_SDCLK_ON) | BF_uSDHC_VEND_SPEC_FRC_SDCLK_ON(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field IPG_CLK_SOFT_EN[11] (RW)
 *
 * Values:
 * - 0 - Gate off the IPG_CLK
 * - 1 - Enable the IPG_CLK
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN (11U) /*!< Bit position for uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN. */
#define BM_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN (0x00000800U) /*!< Bit mask for uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN. */
#define BS_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN field. */
#define BR_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN(x) (HW_uSDHC_VEND_SPEC(x).B.IPG_CLK_SOFT_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN. */
#define BF_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN) & BM_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN)

/*! @brief Set the IPG_CLK_SOFT_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN) | BF_uSDHC_VEND_SPEC_IPG_CLK_SOFT_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field HCLK_SOFT_EN[12] (RW)
 *
 * Hardware auto-enables the AHB clock when the internal DMA is enabled even if
 * HCLK_SOFT_EN is 0.
 *
 * Values:
 * - 0 - Gate off the AHB clock.
 * - 1 - Enable the AHB clock.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_HCLK_SOFT_EN (12U) /*!< Bit position for uSDHC_VEND_SPEC_HCLK_SOFT_EN. */
#define BM_uSDHC_VEND_SPEC_HCLK_SOFT_EN (0x00001000U) /*!< Bit mask for uSDHC_VEND_SPEC_HCLK_SOFT_EN. */
#define BS_uSDHC_VEND_SPEC_HCLK_SOFT_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_HCLK_SOFT_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_HCLK_SOFT_EN field. */
#define BR_uSDHC_VEND_SPEC_HCLK_SOFT_EN(x) (HW_uSDHC_VEND_SPEC(x).B.HCLK_SOFT_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_HCLK_SOFT_EN. */
#define BF_uSDHC_VEND_SPEC_HCLK_SOFT_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_HCLK_SOFT_EN) & BM_uSDHC_VEND_SPEC_HCLK_SOFT_EN)

/*! @brief Set the HCLK_SOFT_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC_HCLK_SOFT_EN(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_HCLK_SOFT_EN) | BF_uSDHC_VEND_SPEC_HCLK_SOFT_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field IPG_PERCLK_SOFT_EN[13] (RW)
 *
 * Values:
 * - 0 - Gate off the IPG_PERCLK
 * - 1 - Enable the IPG_PERCLK
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN (13U) /*!< Bit position for uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN. */
#define BM_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN (0x00002000U) /*!< Bit mask for uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN. */
#define BS_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN field. */
#define BR_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN(x) (HW_uSDHC_VEND_SPEC(x).B.IPG_PERCLK_SOFT_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN. */
#define BF_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN) & BM_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN)

/*! @brief Set the IPG_PERCLK_SOFT_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN) | BF_uSDHC_VEND_SPEC_IPG_PERCLK_SOFT_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field CARD_CLK_SOFT_EN[14] (RW)
 *
 * Values:
 * - 0 - Gate off the sd_clk
 * - 1 - Enable the sd_clk
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN (14U) /*!< Bit position for uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN. */
#define BM_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN (0x00004000U) /*!< Bit mask for uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN. */
#define BS_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN field. */
#define BR_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN(x) (HW_uSDHC_VEND_SPEC(x).B.CARD_CLK_SOFT_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN. */
#define BF_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN) & BM_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN)

/*! @brief Set the CARD_CLK_SOFT_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN) | BF_uSDHC_VEND_SPEC_CARD_CLK_SOFT_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field CRC_CHK_DIS[15] (RW)
 *
 * Values:
 * - 0 - Check CRC16 for every read data packet and check CRC bits for every
 *     write data packet
 * - 1 - Ignore CRC16 check for every read data packet and ignore CRC bits check
 *     for every write data packet
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_CRC_CHK_DIS (15U) /*!< Bit position for uSDHC_VEND_SPEC_CRC_CHK_DIS. */
#define BM_uSDHC_VEND_SPEC_CRC_CHK_DIS (0x00008000U) /*!< Bit mask for uSDHC_VEND_SPEC_CRC_CHK_DIS. */
#define BS_uSDHC_VEND_SPEC_CRC_CHK_DIS (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_CRC_CHK_DIS. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_CRC_CHK_DIS field. */
#define BR_uSDHC_VEND_SPEC_CRC_CHK_DIS(x) (HW_uSDHC_VEND_SPEC(x).B.CRC_CHK_DIS)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_CRC_CHK_DIS. */
#define BF_uSDHC_VEND_SPEC_CRC_CHK_DIS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_CRC_CHK_DIS) & BM_uSDHC_VEND_SPEC_CRC_CHK_DIS)

/*! @brief Set the CRC_CHK_DIS field to a new value. */
#define BW_uSDHC_VEND_SPEC_CRC_CHK_DIS(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_CRC_CHK_DIS) | BF_uSDHC_VEND_SPEC_CRC_CHK_DIS(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field INT_ST_VAL[23:16] (RO)
 *
 * Internal state value, reflecting the corresponding state value selected by
 * Debug Select field. This field is read-only and write to this field does not
 * have effect.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_INT_ST_VAL (16U) /*!< Bit position for uSDHC_VEND_SPEC_INT_ST_VAL. */
#define BM_uSDHC_VEND_SPEC_INT_ST_VAL (0x00FF0000U) /*!< Bit mask for uSDHC_VEND_SPEC_INT_ST_VAL. */
#define BS_uSDHC_VEND_SPEC_INT_ST_VAL (8U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_INT_ST_VAL. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_INT_ST_VAL field. */
#define BR_uSDHC_VEND_SPEC_INT_ST_VAL(x) (HW_uSDHC_VEND_SPEC(x).B.INT_ST_VAL)
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC, field CMD_BYTE_EN[31] (RW)
 *
 * Byte access
 *
 * Values:
 * - 0 - Disable
 * - 1 - Enable
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC_CMD_BYTE_EN (31U) /*!< Bit position for uSDHC_VEND_SPEC_CMD_BYTE_EN. */
#define BM_uSDHC_VEND_SPEC_CMD_BYTE_EN (0x80000000U) /*!< Bit mask for uSDHC_VEND_SPEC_CMD_BYTE_EN. */
#define BS_uSDHC_VEND_SPEC_CMD_BYTE_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC_CMD_BYTE_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC_CMD_BYTE_EN field. */
#define BR_uSDHC_VEND_SPEC_CMD_BYTE_EN(x) (HW_uSDHC_VEND_SPEC(x).B.CMD_BYTE_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC_CMD_BYTE_EN. */
#define BF_uSDHC_VEND_SPEC_CMD_BYTE_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC_CMD_BYTE_EN) & BM_uSDHC_VEND_SPEC_CMD_BYTE_EN)

/*! @brief Set the CMD_BYTE_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC_CMD_BYTE_EN(x, v) (HW_uSDHC_VEND_SPEC_WR(x, (HW_uSDHC_VEND_SPEC_RD(x) & ~BM_uSDHC_VEND_SPEC_CMD_BYTE_EN) | BF_uSDHC_VEND_SPEC_CMD_BYTE_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_MMC_BOOT - MMC Boot Register
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_MMC_BOOT - MMC Boot Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains the MMC Fast Boot control register.
 */
typedef union _hw_usdhc_mmc_boot
{
    uint32_t U;
    struct _hw_usdhc_mmc_boot_bitfields
    {
        uint32_t DTOCV_ACK : 4;        /*!< [3:0]  */
        uint32_t BOOT_ACK : 1;         /*!< [4]  */
        uint32_t BOOT_MODE : 1;        /*!< [5]  */
        uint32_t BOOT_EN : 1;          /*!< [6]  */
        uint32_t AUTO_SABG_EN : 1;     /*!< [7]  */
        uint32_t DISABLE_TIME_OUT : 1; /*!< [8] Disable Time Out */
        uint32_t RESERVED0 : 7;        /*!< [15:9]  */
        uint32_t BOOT_BLK_CNT : 16;    /*!< [31:16]  */
    } B;
} hw_usdhc_mmc_boot_t;

/*!
 * @name Constants and macros for entire uSDHC_MMC_BOOT register
 */
/*@{*/
#define HW_uSDHC_MMC_BOOT_ADDR(x) ((uintptr_t)(x) + 0xC4U)

#define HW_uSDHC_MMC_BOOT(x)     (*(__IO hw_usdhc_mmc_boot_t *) HW_uSDHC_MMC_BOOT_ADDR(x))
#define HW_uSDHC_MMC_BOOT_RD(x)  (HW_uSDHC_MMC_BOOT(x).U)
#define HW_uSDHC_MMC_BOOT_WR(x, v) (HW_uSDHC_MMC_BOOT(x).U = (v))
#define HW_uSDHC_MMC_BOOT_SET(x, v) (HW_uSDHC_MMC_BOOT_WR(x, HW_uSDHC_MMC_BOOT_RD(x) |  (v)))
#define HW_uSDHC_MMC_BOOT_CLR(x, v) (HW_uSDHC_MMC_BOOT_WR(x, HW_uSDHC_MMC_BOOT_RD(x) & ~(v)))
#define HW_uSDHC_MMC_BOOT_TOG(x, v) (HW_uSDHC_MMC_BOOT_WR(x, HW_uSDHC_MMC_BOOT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_MMC_BOOT bitfields
 */

/*!
 * @name Register uSDHC_MMC_BOOT, field DTOCV_ACK[3:0] (RW)
 *
 * Boot ACK time out counter value.
 *
 * Values:
 * - 0000 - SDCLK x 2^13
 * - 0001 - SDCLK x 2^14
 * - 0010 - SDCLK x 2^15
 * - 0011 - SDCLK x 2^16
 * - 0100 - SDCLK x 2^17
 * - 0101 - SDCLK x 2^18
 * - 0110 - SDCLK x 2^19
 * - 0111 - SDCLK x 2^20
 * - 1110 - SDCLK x 2^27
 * - 1111 - SDCLK x 2^28
 */
/*@{*/
#define BP_uSDHC_MMC_BOOT_DTOCV_ACK (0U)   /*!< Bit position for uSDHC_MMC_BOOT_DTOCV_ACK. */
#define BM_uSDHC_MMC_BOOT_DTOCV_ACK (0x0000000FU) /*!< Bit mask for uSDHC_MMC_BOOT_DTOCV_ACK. */
#define BS_uSDHC_MMC_BOOT_DTOCV_ACK (4U)   /*!< Bit field size in bits for uSDHC_MMC_BOOT_DTOCV_ACK. */

/*! @brief Read current value of the uSDHC_MMC_BOOT_DTOCV_ACK field. */
#define BR_uSDHC_MMC_BOOT_DTOCV_ACK(x) (HW_uSDHC_MMC_BOOT(x).B.DTOCV_ACK)

/*! @brief Format value for bitfield uSDHC_MMC_BOOT_DTOCV_ACK. */
#define BF_uSDHC_MMC_BOOT_DTOCV_ACK(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MMC_BOOT_DTOCV_ACK) & BM_uSDHC_MMC_BOOT_DTOCV_ACK)

/*! @brief Set the DTOCV_ACK field to a new value. */
#define BW_uSDHC_MMC_BOOT_DTOCV_ACK(x, v) (HW_uSDHC_MMC_BOOT_WR(x, (HW_uSDHC_MMC_BOOT_RD(x) & ~BM_uSDHC_MMC_BOOT_DTOCV_ACK) | BF_uSDHC_MMC_BOOT_DTOCV_ACK(v)))
/*@}*/

/*!
 * @name Register uSDHC_MMC_BOOT, field BOOT_ACK[4] (RW)
 *
 * Boot ACK mode select
 *
 * Values:
 * - 0 - No ack
 * - 1 - Ack
 */
/*@{*/
#define BP_uSDHC_MMC_BOOT_BOOT_ACK (4U)    /*!< Bit position for uSDHC_MMC_BOOT_BOOT_ACK. */
#define BM_uSDHC_MMC_BOOT_BOOT_ACK (0x00000010U) /*!< Bit mask for uSDHC_MMC_BOOT_BOOT_ACK. */
#define BS_uSDHC_MMC_BOOT_BOOT_ACK (1U)    /*!< Bit field size in bits for uSDHC_MMC_BOOT_BOOT_ACK. */

/*! @brief Read current value of the uSDHC_MMC_BOOT_BOOT_ACK field. */
#define BR_uSDHC_MMC_BOOT_BOOT_ACK(x) (HW_uSDHC_MMC_BOOT(x).B.BOOT_ACK)

/*! @brief Format value for bitfield uSDHC_MMC_BOOT_BOOT_ACK. */
#define BF_uSDHC_MMC_BOOT_BOOT_ACK(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MMC_BOOT_BOOT_ACK) & BM_uSDHC_MMC_BOOT_BOOT_ACK)

/*! @brief Set the BOOT_ACK field to a new value. */
#define BW_uSDHC_MMC_BOOT_BOOT_ACK(x, v) (HW_uSDHC_MMC_BOOT_WR(x, (HW_uSDHC_MMC_BOOT_RD(x) & ~BM_uSDHC_MMC_BOOT_BOOT_ACK) | BF_uSDHC_MMC_BOOT_BOOT_ACK(v)))
/*@}*/

/*!
 * @name Register uSDHC_MMC_BOOT, field BOOT_MODE[5] (RW)
 *
 * Boot mode select
 *
 * Values:
 * - 0 - Normal boot
 * - 1 - Alternative boot
 */
/*@{*/
#define BP_uSDHC_MMC_BOOT_BOOT_MODE (5U)   /*!< Bit position for uSDHC_MMC_BOOT_BOOT_MODE. */
#define BM_uSDHC_MMC_BOOT_BOOT_MODE (0x00000020U) /*!< Bit mask for uSDHC_MMC_BOOT_BOOT_MODE. */
#define BS_uSDHC_MMC_BOOT_BOOT_MODE (1U)   /*!< Bit field size in bits for uSDHC_MMC_BOOT_BOOT_MODE. */

/*! @brief Read current value of the uSDHC_MMC_BOOT_BOOT_MODE field. */
#define BR_uSDHC_MMC_BOOT_BOOT_MODE(x) (HW_uSDHC_MMC_BOOT(x).B.BOOT_MODE)

/*! @brief Format value for bitfield uSDHC_MMC_BOOT_BOOT_MODE. */
#define BF_uSDHC_MMC_BOOT_BOOT_MODE(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MMC_BOOT_BOOT_MODE) & BM_uSDHC_MMC_BOOT_BOOT_MODE)

/*! @brief Set the BOOT_MODE field to a new value. */
#define BW_uSDHC_MMC_BOOT_BOOT_MODE(x, v) (HW_uSDHC_MMC_BOOT_WR(x, (HW_uSDHC_MMC_BOOT_RD(x) & ~BM_uSDHC_MMC_BOOT_BOOT_MODE) | BF_uSDHC_MMC_BOOT_BOOT_MODE(v)))
/*@}*/

/*!
 * @name Register uSDHC_MMC_BOOT, field BOOT_EN[6] (RW)
 *
 * Boot mode enable
 *
 * Values:
 * - 0 - Fast boot disable
 * - 1 - Fast boot enable
 */
/*@{*/
#define BP_uSDHC_MMC_BOOT_BOOT_EN (6U)     /*!< Bit position for uSDHC_MMC_BOOT_BOOT_EN. */
#define BM_uSDHC_MMC_BOOT_BOOT_EN (0x00000040U) /*!< Bit mask for uSDHC_MMC_BOOT_BOOT_EN. */
#define BS_uSDHC_MMC_BOOT_BOOT_EN (1U)     /*!< Bit field size in bits for uSDHC_MMC_BOOT_BOOT_EN. */

/*! @brief Read current value of the uSDHC_MMC_BOOT_BOOT_EN field. */
#define BR_uSDHC_MMC_BOOT_BOOT_EN(x) (HW_uSDHC_MMC_BOOT(x).B.BOOT_EN)

/*! @brief Format value for bitfield uSDHC_MMC_BOOT_BOOT_EN. */
#define BF_uSDHC_MMC_BOOT_BOOT_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MMC_BOOT_BOOT_EN) & BM_uSDHC_MMC_BOOT_BOOT_EN)

/*! @brief Set the BOOT_EN field to a new value. */
#define BW_uSDHC_MMC_BOOT_BOOT_EN(x, v) (HW_uSDHC_MMC_BOOT_WR(x, (HW_uSDHC_MMC_BOOT_RD(x) & ~BM_uSDHC_MMC_BOOT_BOOT_EN) | BF_uSDHC_MMC_BOOT_BOOT_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_MMC_BOOT, field AUTO_SABG_EN[7] (RW)
 *
 * During boot, enable auto stop at block gap function. This function will be
 * triggered, and host will stop at block gap when received card block cnt is equal
 * to (BLK_CNT - BOOT_BLK_CNT).
 */
/*@{*/
#define BP_uSDHC_MMC_BOOT_AUTO_SABG_EN (7U) /*!< Bit position for uSDHC_MMC_BOOT_AUTO_SABG_EN. */
#define BM_uSDHC_MMC_BOOT_AUTO_SABG_EN (0x00000080U) /*!< Bit mask for uSDHC_MMC_BOOT_AUTO_SABG_EN. */
#define BS_uSDHC_MMC_BOOT_AUTO_SABG_EN (1U) /*!< Bit field size in bits for uSDHC_MMC_BOOT_AUTO_SABG_EN. */

/*! @brief Read current value of the uSDHC_MMC_BOOT_AUTO_SABG_EN field. */
#define BR_uSDHC_MMC_BOOT_AUTO_SABG_EN(x) (HW_uSDHC_MMC_BOOT(x).B.AUTO_SABG_EN)

/*! @brief Format value for bitfield uSDHC_MMC_BOOT_AUTO_SABG_EN. */
#define BF_uSDHC_MMC_BOOT_AUTO_SABG_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MMC_BOOT_AUTO_SABG_EN) & BM_uSDHC_MMC_BOOT_AUTO_SABG_EN)

/*! @brief Set the AUTO_SABG_EN field to a new value. */
#define BW_uSDHC_MMC_BOOT_AUTO_SABG_EN(x, v) (HW_uSDHC_MMC_BOOT_WR(x, (HW_uSDHC_MMC_BOOT_RD(x) & ~BM_uSDHC_MMC_BOOT_AUTO_SABG_EN) | BF_uSDHC_MMC_BOOT_AUTO_SABG_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_MMC_BOOT, field DISABLE_TIME_OUT[8] (RW)
 *
 * When this bit is set, there is no timeout check no matter whether BOOT_EN is
 * set or not.
 *
 * Values:
 * - 0 - Enable time out
 * - 1 - Disable time out
 */
/*@{*/
#define BP_uSDHC_MMC_BOOT_DISABLE_TIME_OUT (8U) /*!< Bit position for uSDHC_MMC_BOOT_DISABLE_TIME_OUT. */
#define BM_uSDHC_MMC_BOOT_DISABLE_TIME_OUT (0x00000100U) /*!< Bit mask for uSDHC_MMC_BOOT_DISABLE_TIME_OUT. */
#define BS_uSDHC_MMC_BOOT_DISABLE_TIME_OUT (1U) /*!< Bit field size in bits for uSDHC_MMC_BOOT_DISABLE_TIME_OUT. */

/*! @brief Read current value of the uSDHC_MMC_BOOT_DISABLE_TIME_OUT field. */
#define BR_uSDHC_MMC_BOOT_DISABLE_TIME_OUT(x) (HW_uSDHC_MMC_BOOT(x).B.DISABLE_TIME_OUT)

/*! @brief Format value for bitfield uSDHC_MMC_BOOT_DISABLE_TIME_OUT. */
#define BF_uSDHC_MMC_BOOT_DISABLE_TIME_OUT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MMC_BOOT_DISABLE_TIME_OUT) & BM_uSDHC_MMC_BOOT_DISABLE_TIME_OUT)

/*! @brief Set the DISABLE_TIME_OUT field to a new value. */
#define BW_uSDHC_MMC_BOOT_DISABLE_TIME_OUT(x, v) (HW_uSDHC_MMC_BOOT_WR(x, (HW_uSDHC_MMC_BOOT_RD(x) & ~BM_uSDHC_MMC_BOOT_DISABLE_TIME_OUT) | BF_uSDHC_MMC_BOOT_DISABLE_TIME_OUT(v)))
/*@}*/

/*!
 * @name Register uSDHC_MMC_BOOT, field BOOT_BLK_CNT[31:16] (RW)
 *
 * The value defines the Stop At Block Gap value of automatic mode. When
 * received card block cnt is equal to (BLK_CNT - BOOT_BLK_CNT) and AUTO_SABG_EN is 1,
 * then Stop At Block Gap. Here, BLK_CNT is defined in the Block Atrributes
 * Register, bit31 - 16 of 0x04.
 */
/*@{*/
#define BP_uSDHC_MMC_BOOT_BOOT_BLK_CNT (16U) /*!< Bit position for uSDHC_MMC_BOOT_BOOT_BLK_CNT. */
#define BM_uSDHC_MMC_BOOT_BOOT_BLK_CNT (0xFFFF0000U) /*!< Bit mask for uSDHC_MMC_BOOT_BOOT_BLK_CNT. */
#define BS_uSDHC_MMC_BOOT_BOOT_BLK_CNT (16U) /*!< Bit field size in bits for uSDHC_MMC_BOOT_BOOT_BLK_CNT. */

/*! @brief Read current value of the uSDHC_MMC_BOOT_BOOT_BLK_CNT field. */
#define BR_uSDHC_MMC_BOOT_BOOT_BLK_CNT(x) (HW_uSDHC_MMC_BOOT(x).B.BOOT_BLK_CNT)

/*! @brief Format value for bitfield uSDHC_MMC_BOOT_BOOT_BLK_CNT. */
#define BF_uSDHC_MMC_BOOT_BOOT_BLK_CNT(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_MMC_BOOT_BOOT_BLK_CNT) & BM_uSDHC_MMC_BOOT_BOOT_BLK_CNT)

/*! @brief Set the BOOT_BLK_CNT field to a new value. */
#define BW_uSDHC_MMC_BOOT_BOOT_BLK_CNT(x, v) (HW_uSDHC_MMC_BOOT_WR(x, (HW_uSDHC_MMC_BOOT_RD(x) & ~BM_uSDHC_MMC_BOOT_BOOT_BLK_CNT) | BF_uSDHC_MMC_BOOT_BOOT_BLK_CNT(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_VEND_SPEC2 - Vendor Specific 2 Register
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_VEND_SPEC2 - Vendor Specific 2 Register (RW)
 *
 * Reset value: 0x00000006U
 *
 * This register contains the vendor specific control 2 register.
 */
typedef union _hw_usdhc_vend_spec2
{
    uint32_t U;
    struct _hw_usdhc_vend_spec2_bitfields
    {
        uint32_t SDR104_TIMING_DIS : 1; /*!< [0]  */
        uint32_t SDR104_OE_DIS : 1;    /*!< [1]  */
        uint32_t SDR104_NSD_DIS : 1;   /*!< [2]  */
        uint32_t CARD_INT_D3_TEST : 1; /*!< [3] Card Interrupt Detection Test
                                        * */
        uint32_t TUNING_8bit_EN : 1;   /*!< [4]  */
        uint32_t TUNING_1bit_EN : 1;   /*!< [5]  */
        uint32_t TUNING_CMD_EN : 1;    /*!< [6]  */
        uint32_t CARD_INT_AUTO_CLR_DIS : 1; /*!< [7]  */
        uint32_t RESERVED0 : 2;        /*!< [9:8]  */
        uint32_t HS400_WR_CLK_STOP_EN : 1; /*!< [10] HS400 Write Clock Stop
                                        * Enable */
        uint32_t HS400_RD_CLK_STOP_EN : 1; /*!< [11] HS400 Read Clock Stop
                                        * Enable */
        uint32_t RESERVED1 : 20;       /*!< [31:12]  */
    } B;
} hw_usdhc_vend_spec2_t;

/*!
 * @name Constants and macros for entire uSDHC_VEND_SPEC2 register
 */
/*@{*/
#define HW_uSDHC_VEND_SPEC2_ADDR(x) ((uintptr_t)(x) + 0xC8U)

#define HW_uSDHC_VEND_SPEC2(x)   (*(__IO hw_usdhc_vend_spec2_t *) HW_uSDHC_VEND_SPEC2_ADDR(x))
#define HW_uSDHC_VEND_SPEC2_RD(x) (HW_uSDHC_VEND_SPEC2(x).U)
#define HW_uSDHC_VEND_SPEC2_WR(x, v) (HW_uSDHC_VEND_SPEC2(x).U = (v))
#define HW_uSDHC_VEND_SPEC2_SET(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, HW_uSDHC_VEND_SPEC2_RD(x) |  (v)))
#define HW_uSDHC_VEND_SPEC2_CLR(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, HW_uSDHC_VEND_SPEC2_RD(x) & ~(v)))
#define HW_uSDHC_VEND_SPEC2_TOG(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, HW_uSDHC_VEND_SPEC2_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_VEND_SPEC2 bitfields
 */

/*!
 * @name Register uSDHC_VEND_SPEC2, field SDR104_TIMING_DIS[0] (RW)
 *
 * Timeout counter test. This bit only uses for debugging.
 *
 * Values:
 * - 0 - The timeout counter for Ncr changes to 80, Ncrc changes to 21.
 * - 1 - The timeout counter for Ncr changes to 72, Ncrc changes to 15.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS (0U) /*!< Bit position for uSDHC_VEND_SPEC2_SDR104_TIMING_DIS. */
#define BM_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS (0x00000001U) /*!< Bit mask for uSDHC_VEND_SPEC2_SDR104_TIMING_DIS. */
#define BS_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC2_SDR104_TIMING_DIS. */

/*! @brief Read current value of the uSDHC_VEND_SPEC2_SDR104_TIMING_DIS field. */
#define BR_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS(x) (HW_uSDHC_VEND_SPEC2(x).B.SDR104_TIMING_DIS)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC2_SDR104_TIMING_DIS. */
#define BF_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS) & BM_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS)

/*! @brief Set the SDR104_TIMING_DIS field to a new value. */
#define BW_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, (HW_uSDHC_VEND_SPEC2_RD(x) & ~BM_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS) | BF_uSDHC_VEND_SPEC2_SDR104_TIMING_DIS(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC2, field SDR104_OE_DIS[1] (RW)
 *
 * CMD_OE / DATA_OE logic generation test. This bit only uses for debugging.
 *
 * Values:
 * - 0 - Drive the CMD_OE / DATA_OE for one more clock cycle after the end bit.
 * - 1 - Stop to drive the CMD_OE / DATA_OE at once after driving the end bit.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC2_SDR104_OE_DIS (1U) /*!< Bit position for uSDHC_VEND_SPEC2_SDR104_OE_DIS. */
#define BM_uSDHC_VEND_SPEC2_SDR104_OE_DIS (0x00000002U) /*!< Bit mask for uSDHC_VEND_SPEC2_SDR104_OE_DIS. */
#define BS_uSDHC_VEND_SPEC2_SDR104_OE_DIS (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC2_SDR104_OE_DIS. */

/*! @brief Read current value of the uSDHC_VEND_SPEC2_SDR104_OE_DIS field. */
#define BR_uSDHC_VEND_SPEC2_SDR104_OE_DIS(x) (HW_uSDHC_VEND_SPEC2(x).B.SDR104_OE_DIS)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC2_SDR104_OE_DIS. */
#define BF_uSDHC_VEND_SPEC2_SDR104_OE_DIS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC2_SDR104_OE_DIS) & BM_uSDHC_VEND_SPEC2_SDR104_OE_DIS)

/*! @brief Set the SDR104_OE_DIS field to a new value. */
#define BW_uSDHC_VEND_SPEC2_SDR104_OE_DIS(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, (HW_uSDHC_VEND_SPEC2_RD(x) & ~BM_uSDHC_VEND_SPEC2_SDR104_OE_DIS) | BF_uSDHC_VEND_SPEC2_SDR104_OE_DIS(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC2, field SDR104_NSD_DIS[2] (RW)
 *
 * Interrupt window after abort command is sent. This bit only uses for
 * debugging.
 *
 * Values:
 * - 0 - Enable the interrupt window 9 cycles later after the end of the I/O
 *     abort command (or CMD12) is sent.
 * - 1 - Enable the interrupt window 5 cycles later after the end of the I/O
 *     abort command (or CMD12) is sent.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC2_SDR104_NSD_DIS (2U) /*!< Bit position for uSDHC_VEND_SPEC2_SDR104_NSD_DIS. */
#define BM_uSDHC_VEND_SPEC2_SDR104_NSD_DIS (0x00000004U) /*!< Bit mask for uSDHC_VEND_SPEC2_SDR104_NSD_DIS. */
#define BS_uSDHC_VEND_SPEC2_SDR104_NSD_DIS (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC2_SDR104_NSD_DIS. */

/*! @brief Read current value of the uSDHC_VEND_SPEC2_SDR104_NSD_DIS field. */
#define BR_uSDHC_VEND_SPEC2_SDR104_NSD_DIS(x) (HW_uSDHC_VEND_SPEC2(x).B.SDR104_NSD_DIS)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC2_SDR104_NSD_DIS. */
#define BF_uSDHC_VEND_SPEC2_SDR104_NSD_DIS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC2_SDR104_NSD_DIS) & BM_uSDHC_VEND_SPEC2_SDR104_NSD_DIS)

/*! @brief Set the SDR104_NSD_DIS field to a new value. */
#define BW_uSDHC_VEND_SPEC2_SDR104_NSD_DIS(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, (HW_uSDHC_VEND_SPEC2_RD(x) & ~BM_uSDHC_VEND_SPEC2_SDR104_NSD_DIS) | BF_uSDHC_VEND_SPEC2_SDR104_NSD_DIS(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC2, field CARD_INT_D3_TEST[3] (RW)
 *
 * This bit only uses for debugging.
 *
 * Values:
 * - 0 - Check the card interrupt only when DATA3 is high.
 * - 1 - Check the card interrupt by ignoring the status of DATA3.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST (3U) /*!< Bit position for uSDHC_VEND_SPEC2_CARD_INT_D3_TEST. */
#define BM_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST (0x00000008U) /*!< Bit mask for uSDHC_VEND_SPEC2_CARD_INT_D3_TEST. */
#define BS_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC2_CARD_INT_D3_TEST. */

/*! @brief Read current value of the uSDHC_VEND_SPEC2_CARD_INT_D3_TEST field. */
#define BR_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST(x) (HW_uSDHC_VEND_SPEC2(x).B.CARD_INT_D3_TEST)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC2_CARD_INT_D3_TEST. */
#define BF_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST) & BM_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST)

/*! @brief Set the CARD_INT_D3_TEST field to a new value. */
#define BW_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, (HW_uSDHC_VEND_SPEC2_RD(x) & ~BM_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST) | BF_uSDHC_VEND_SPEC2_CARD_INT_D3_TEST(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC2, field TUNING_8bit_EN[4] (RW)
 *
 * Enable the auto tuning circuit to check the DATA[7:0]. It is used with the
 * TUNING_1bit_EN together. The format of these two bits are
 * [TUNNING_8bit_EN:TUNNING_1bit_EN].
 *
 * Values:
 * - 00 - Tuning circuit only checks the DATA[3:0].
 * - 01 - Tuning circuit only checks the DATA0.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC2_TUNING_8bit_EN (4U) /*!< Bit position for uSDHC_VEND_SPEC2_TUNING_8bit_EN. */
#define BM_uSDHC_VEND_SPEC2_TUNING_8bit_EN (0x00000010U) /*!< Bit mask for uSDHC_VEND_SPEC2_TUNING_8bit_EN. */
#define BS_uSDHC_VEND_SPEC2_TUNING_8bit_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC2_TUNING_8bit_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC2_TUNING_8bit_EN field. */
#define BR_uSDHC_VEND_SPEC2_TUNING_8bit_EN(x) (HW_uSDHC_VEND_SPEC2(x).B.TUNING_8bit_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC2_TUNING_8bit_EN. */
#define BF_uSDHC_VEND_SPEC2_TUNING_8bit_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC2_TUNING_8bit_EN) & BM_uSDHC_VEND_SPEC2_TUNING_8bit_EN)

/*! @brief Set the TUNING_8bit_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC2_TUNING_8bit_EN(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, (HW_uSDHC_VEND_SPEC2_RD(x) & ~BM_uSDHC_VEND_SPEC2_TUNING_8bit_EN) | BF_uSDHC_VEND_SPEC2_TUNING_8bit_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC2, field TUNING_1bit_EN[5] (RW)
 *
 * Enable the auto tuning circuit to check the DATA0 only. It is used with the
 * TUNING_8bit_EN together.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC2_TUNING_1bit_EN (5U) /*!< Bit position for uSDHC_VEND_SPEC2_TUNING_1bit_EN. */
#define BM_uSDHC_VEND_SPEC2_TUNING_1bit_EN (0x00000020U) /*!< Bit mask for uSDHC_VEND_SPEC2_TUNING_1bit_EN. */
#define BS_uSDHC_VEND_SPEC2_TUNING_1bit_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC2_TUNING_1bit_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC2_TUNING_1bit_EN field. */
#define BR_uSDHC_VEND_SPEC2_TUNING_1bit_EN(x) (HW_uSDHC_VEND_SPEC2(x).B.TUNING_1bit_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC2_TUNING_1bit_EN. */
#define BF_uSDHC_VEND_SPEC2_TUNING_1bit_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC2_TUNING_1bit_EN) & BM_uSDHC_VEND_SPEC2_TUNING_1bit_EN)

/*! @brief Set the TUNING_1bit_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC2_TUNING_1bit_EN(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, (HW_uSDHC_VEND_SPEC2_RD(x) & ~BM_uSDHC_VEND_SPEC2_TUNING_1bit_EN) | BF_uSDHC_VEND_SPEC2_TUNING_1bit_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC2, field TUNING_CMD_EN[6] (RW)
 *
 * Enable the auto tuning circuit to check the CMD line.
 *
 * Values:
 * - 0 - Auto tuning circuit does not check the CMD line.
 * - 1 - Auto tuning circuit checks the CMD line.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC2_TUNING_CMD_EN (6U) /*!< Bit position for uSDHC_VEND_SPEC2_TUNING_CMD_EN. */
#define BM_uSDHC_VEND_SPEC2_TUNING_CMD_EN (0x00000040U) /*!< Bit mask for uSDHC_VEND_SPEC2_TUNING_CMD_EN. */
#define BS_uSDHC_VEND_SPEC2_TUNING_CMD_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC2_TUNING_CMD_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC2_TUNING_CMD_EN field. */
#define BR_uSDHC_VEND_SPEC2_TUNING_CMD_EN(x) (HW_uSDHC_VEND_SPEC2(x).B.TUNING_CMD_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC2_TUNING_CMD_EN. */
#define BF_uSDHC_VEND_SPEC2_TUNING_CMD_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC2_TUNING_CMD_EN) & BM_uSDHC_VEND_SPEC2_TUNING_CMD_EN)

/*! @brief Set the TUNING_CMD_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC2_TUNING_CMD_EN(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, (HW_uSDHC_VEND_SPEC2_RD(x) & ~BM_uSDHC_VEND_SPEC2_TUNING_CMD_EN) | BF_uSDHC_VEND_SPEC2_TUNING_CMD_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC2, field CARD_INT_AUTO_CLR_DIS[7] (RW)
 *
 * Disable the feature to clear the Card interrupt status bit when Card
 * Interrupt status enable bit is cleared. Only for debug.
 *
 * Values:
 * - 0 - Card interrupt status bit (CINT) can be cleared when Card Interrupt
 *     status enable bit is 0.
 * - 1 - Card interrupt status bit (CINT) can only be cleared by writting a 1 to
 *     CINT bit.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS (7U) /*!< Bit position for uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS. */
#define BM_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS (0x00000080U) /*!< Bit mask for uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS. */
#define BS_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS. */

/*! @brief Read current value of the uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS field. */
#define BR_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS(x) (HW_uSDHC_VEND_SPEC2(x).B.CARD_INT_AUTO_CLR_DIS)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS. */
#define BF_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS) & BM_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS)

/*! @brief Set the CARD_INT_AUTO_CLR_DIS field to a new value. */
#define BW_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, (HW_uSDHC_VEND_SPEC2_RD(x) & ~BM_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS) | BF_uSDHC_VEND_SPEC2_CARD_INT_AUTO_CLR_DIS(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC2, field HS400_WR_CLK_STOP_EN[10] (RW)
 *
 * Only stop clock at write block gap.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC2_HS400_WR_CLK_STOP_EN (10U) /*!< Bit position for uSDHC_VEND_SPEC2_HS400_WR_CLK_STOP_EN. */
#define BM_uSDHC_VEND_SPEC2_HS400_WR_CLK_STOP_EN (0x00000400U) /*!< Bit mask for uSDHC_VEND_SPEC2_HS400_WR_CLK_STOP_EN. */
#define BS_uSDHC_VEND_SPEC2_HS400_WR_CLK_STOP_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC2_HS400_WR_CLK_STOP_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC2_HS400_WR_CLK_STOP_EN field. */
#define BR_uSDHC_VEND_SPEC2_HS400_WR_CLK_STOP_EN(x) (HW_uSDHC_VEND_SPEC2(x).B.HS400_WR_CLK_STOP_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC2_HS400_WR_CLK_STOP_EN. */
#define BF_uSDHC_VEND_SPEC2_HS400_WR_CLK_STOP_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC2_HS400_WR_CLK_STOP_EN) & BM_uSDHC_VEND_SPEC2_HS400_WR_CLK_STOP_EN)

/*! @brief Set the HS400_WR_CLK_STOP_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC2_HS400_WR_CLK_STOP_EN(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, (HW_uSDHC_VEND_SPEC2_RD(x) & ~BM_uSDHC_VEND_SPEC2_HS400_WR_CLK_STOP_EN) | BF_uSDHC_VEND_SPEC2_HS400_WR_CLK_STOP_EN(v)))
/*@}*/

/*!
 * @name Register uSDHC_VEND_SPEC2, field HS400_RD_CLK_STOP_EN[11] (RW)
 *
 * Only stop clock at read block gap.
 */
/*@{*/
#define BP_uSDHC_VEND_SPEC2_HS400_RD_CLK_STOP_EN (11U) /*!< Bit position for uSDHC_VEND_SPEC2_HS400_RD_CLK_STOP_EN. */
#define BM_uSDHC_VEND_SPEC2_HS400_RD_CLK_STOP_EN (0x00000800U) /*!< Bit mask for uSDHC_VEND_SPEC2_HS400_RD_CLK_STOP_EN. */
#define BS_uSDHC_VEND_SPEC2_HS400_RD_CLK_STOP_EN (1U) /*!< Bit field size in bits for uSDHC_VEND_SPEC2_HS400_RD_CLK_STOP_EN. */

/*! @brief Read current value of the uSDHC_VEND_SPEC2_HS400_RD_CLK_STOP_EN field. */
#define BR_uSDHC_VEND_SPEC2_HS400_RD_CLK_STOP_EN(x) (HW_uSDHC_VEND_SPEC2(x).B.HS400_RD_CLK_STOP_EN)

/*! @brief Format value for bitfield uSDHC_VEND_SPEC2_HS400_RD_CLK_STOP_EN. */
#define BF_uSDHC_VEND_SPEC2_HS400_RD_CLK_STOP_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_VEND_SPEC2_HS400_RD_CLK_STOP_EN) & BM_uSDHC_VEND_SPEC2_HS400_RD_CLK_STOP_EN)

/*! @brief Set the HS400_RD_CLK_STOP_EN field to a new value. */
#define BW_uSDHC_VEND_SPEC2_HS400_RD_CLK_STOP_EN(x, v) (HW_uSDHC_VEND_SPEC2_WR(x, (HW_uSDHC_VEND_SPEC2_RD(x) & ~BM_uSDHC_VEND_SPEC2_HS400_RD_CLK_STOP_EN) | BF_uSDHC_VEND_SPEC2_HS400_RD_CLK_STOP_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_uSDHC_TUNING_CTRL - Tuning Control Register
 ******************************************************************************/

/*!
 * @brief HW_uSDHC_TUNING_CTRL - Tuning Control Register (RW)
 *
 * Reset value: 0x00212800U
 *
 * The register contains configuration of tuning circuit.
 */
typedef union _hw_usdhc_tuning_ctrl
{
    uint32_t U;
    struct _hw_usdhc_tuning_ctrl_bitfields
    {
        uint32_t TUNING_START_TAP : 8; /*!< [7:0]  */
        uint32_t TUNING_COUNTER : 8;   /*!< [15:8]  */
        uint32_t TUNING_STEP : 3;      /*!< [18:16]  */
        uint32_t RESERVED0 : 1;        /*!< [19]  */
        uint32_t TUNING_WINDOW : 3;    /*!< [22:20]  */
        uint32_t RESERVED1 : 1;        /*!< [23]  */
        uint32_t STD_TUNING_EN : 1;    /*!< [24]  */
        uint32_t RESERVED2 : 7;        /*!< [31:25]  */
    } B;
} hw_usdhc_tuning_ctrl_t;

/*!
 * @name Constants and macros for entire uSDHC_TUNING_CTRL register
 */
/*@{*/
#define HW_uSDHC_TUNING_CTRL_ADDR(x) ((uintptr_t)(x) + 0xCCU)

#define HW_uSDHC_TUNING_CTRL(x)  (*(__IO hw_usdhc_tuning_ctrl_t *) HW_uSDHC_TUNING_CTRL_ADDR(x))
#define HW_uSDHC_TUNING_CTRL_RD(x) (HW_uSDHC_TUNING_CTRL(x).U)
#define HW_uSDHC_TUNING_CTRL_WR(x, v) (HW_uSDHC_TUNING_CTRL(x).U = (v))
#define HW_uSDHC_TUNING_CTRL_SET(x, v) (HW_uSDHC_TUNING_CTRL_WR(x, HW_uSDHC_TUNING_CTRL_RD(x) |  (v)))
#define HW_uSDHC_TUNING_CTRL_CLR(x, v) (HW_uSDHC_TUNING_CTRL_WR(x, HW_uSDHC_TUNING_CTRL_RD(x) & ~(v)))
#define HW_uSDHC_TUNING_CTRL_TOG(x, v) (HW_uSDHC_TUNING_CTRL_WR(x, HW_uSDHC_TUNING_CTRL_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual uSDHC_TUNING_CTRL bitfields
 */

/*!
 * @name Register uSDHC_TUNING_CTRL, field TUNING_START_TAP[7:0] (RW)
 *
 * The start dealy cell point when send first CMD19 in tuning procedure.
 */
/*@{*/
#define BP_uSDHC_TUNING_CTRL_TUNING_START_TAP (0U) /*!< Bit position for uSDHC_TUNING_CTRL_TUNING_START_TAP. */
#define BM_uSDHC_TUNING_CTRL_TUNING_START_TAP (0x000000FFU) /*!< Bit mask for uSDHC_TUNING_CTRL_TUNING_START_TAP. */
#define BS_uSDHC_TUNING_CTRL_TUNING_START_TAP (8U) /*!< Bit field size in bits for uSDHC_TUNING_CTRL_TUNING_START_TAP. */

/*! @brief Read current value of the uSDHC_TUNING_CTRL_TUNING_START_TAP field. */
#define BR_uSDHC_TUNING_CTRL_TUNING_START_TAP(x) (HW_uSDHC_TUNING_CTRL(x).B.TUNING_START_TAP)

/*! @brief Format value for bitfield uSDHC_TUNING_CTRL_TUNING_START_TAP. */
#define BF_uSDHC_TUNING_CTRL_TUNING_START_TAP(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_TUNING_CTRL_TUNING_START_TAP) & BM_uSDHC_TUNING_CTRL_TUNING_START_TAP)

/*! @brief Set the TUNING_START_TAP field to a new value. */
#define BW_uSDHC_TUNING_CTRL_TUNING_START_TAP(x, v) (HW_uSDHC_TUNING_CTRL_WR(x, (HW_uSDHC_TUNING_CTRL_RD(x) & ~BM_uSDHC_TUNING_CTRL_TUNING_START_TAP) | BF_uSDHC_TUNING_CTRL_TUNING_START_TAP(v)))
/*@}*/

/*!
 * @name Register uSDHC_TUNING_CTRL, field TUNING_COUNTER[15:8] (RW)
 *
 * The MAX repeat CMD19 times in tuning procedure.
 */
/*@{*/
#define BP_uSDHC_TUNING_CTRL_TUNING_COUNTER (8U) /*!< Bit position for uSDHC_TUNING_CTRL_TUNING_COUNTER. */
#define BM_uSDHC_TUNING_CTRL_TUNING_COUNTER (0x0000FF00U) /*!< Bit mask for uSDHC_TUNING_CTRL_TUNING_COUNTER. */
#define BS_uSDHC_TUNING_CTRL_TUNING_COUNTER (8U) /*!< Bit field size in bits for uSDHC_TUNING_CTRL_TUNING_COUNTER. */

/*! @brief Read current value of the uSDHC_TUNING_CTRL_TUNING_COUNTER field. */
#define BR_uSDHC_TUNING_CTRL_TUNING_COUNTER(x) (HW_uSDHC_TUNING_CTRL(x).B.TUNING_COUNTER)

/*! @brief Format value for bitfield uSDHC_TUNING_CTRL_TUNING_COUNTER. */
#define BF_uSDHC_TUNING_CTRL_TUNING_COUNTER(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_TUNING_CTRL_TUNING_COUNTER) & BM_uSDHC_TUNING_CTRL_TUNING_COUNTER)

/*! @brief Set the TUNING_COUNTER field to a new value. */
#define BW_uSDHC_TUNING_CTRL_TUNING_COUNTER(x, v) (HW_uSDHC_TUNING_CTRL_WR(x, (HW_uSDHC_TUNING_CTRL_RD(x) & ~BM_uSDHC_TUNING_CTRL_TUNING_COUNTER) | BF_uSDHC_TUNING_CTRL_TUNING_COUNTER(v)))
/*@}*/

/*!
 * @name Register uSDHC_TUNING_CTRL, field TUNING_STEP[18:16] (RW)
 *
 * The increasing delay cell steps in tuning procedure.
 */
/*@{*/
#define BP_uSDHC_TUNING_CTRL_TUNING_STEP (16U) /*!< Bit position for uSDHC_TUNING_CTRL_TUNING_STEP. */
#define BM_uSDHC_TUNING_CTRL_TUNING_STEP (0x00070000U) /*!< Bit mask for uSDHC_TUNING_CTRL_TUNING_STEP. */
#define BS_uSDHC_TUNING_CTRL_TUNING_STEP (3U) /*!< Bit field size in bits for uSDHC_TUNING_CTRL_TUNING_STEP. */

/*! @brief Read current value of the uSDHC_TUNING_CTRL_TUNING_STEP field. */
#define BR_uSDHC_TUNING_CTRL_TUNING_STEP(x) (HW_uSDHC_TUNING_CTRL(x).B.TUNING_STEP)

/*! @brief Format value for bitfield uSDHC_TUNING_CTRL_TUNING_STEP. */
#define BF_uSDHC_TUNING_CTRL_TUNING_STEP(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_TUNING_CTRL_TUNING_STEP) & BM_uSDHC_TUNING_CTRL_TUNING_STEP)

/*! @brief Set the TUNING_STEP field to a new value. */
#define BW_uSDHC_TUNING_CTRL_TUNING_STEP(x, v) (HW_uSDHC_TUNING_CTRL_WR(x, (HW_uSDHC_TUNING_CTRL_RD(x) & ~BM_uSDHC_TUNING_CTRL_TUNING_STEP) | BF_uSDHC_TUNING_CTRL_TUNING_STEP(v)))
/*@}*/

/*!
 * @name Register uSDHC_TUNING_CTRL, field TUNING_WINDOW[22:20] (RW)
 *
 * Select data window value for auto tuning
 */
/*@{*/
#define BP_uSDHC_TUNING_CTRL_TUNING_WINDOW (20U) /*!< Bit position for uSDHC_TUNING_CTRL_TUNING_WINDOW. */
#define BM_uSDHC_TUNING_CTRL_TUNING_WINDOW (0x00700000U) /*!< Bit mask for uSDHC_TUNING_CTRL_TUNING_WINDOW. */
#define BS_uSDHC_TUNING_CTRL_TUNING_WINDOW (3U) /*!< Bit field size in bits for uSDHC_TUNING_CTRL_TUNING_WINDOW. */

/*! @brief Read current value of the uSDHC_TUNING_CTRL_TUNING_WINDOW field. */
#define BR_uSDHC_TUNING_CTRL_TUNING_WINDOW(x) (HW_uSDHC_TUNING_CTRL(x).B.TUNING_WINDOW)

/*! @brief Format value for bitfield uSDHC_TUNING_CTRL_TUNING_WINDOW. */
#define BF_uSDHC_TUNING_CTRL_TUNING_WINDOW(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_TUNING_CTRL_TUNING_WINDOW) & BM_uSDHC_TUNING_CTRL_TUNING_WINDOW)

/*! @brief Set the TUNING_WINDOW field to a new value. */
#define BW_uSDHC_TUNING_CTRL_TUNING_WINDOW(x, v) (HW_uSDHC_TUNING_CTRL_WR(x, (HW_uSDHC_TUNING_CTRL_RD(x) & ~BM_uSDHC_TUNING_CTRL_TUNING_WINDOW) | BF_uSDHC_TUNING_CTRL_TUNING_WINDOW(v)))
/*@}*/

/*!
 * @name Register uSDHC_TUNING_CTRL, field STD_TUNING_EN[24] (RW)
 *
 * Standard tuning circuit and procedure enable: This bit is used to enable
 * standard tuning circuit and procedure.
 */
/*@{*/
#define BP_uSDHC_TUNING_CTRL_STD_TUNING_EN (24U) /*!< Bit position for uSDHC_TUNING_CTRL_STD_TUNING_EN. */
#define BM_uSDHC_TUNING_CTRL_STD_TUNING_EN (0x01000000U) /*!< Bit mask for uSDHC_TUNING_CTRL_STD_TUNING_EN. */
#define BS_uSDHC_TUNING_CTRL_STD_TUNING_EN (1U) /*!< Bit field size in bits for uSDHC_TUNING_CTRL_STD_TUNING_EN. */

/*! @brief Read current value of the uSDHC_TUNING_CTRL_STD_TUNING_EN field. */
#define BR_uSDHC_TUNING_CTRL_STD_TUNING_EN(x) (HW_uSDHC_TUNING_CTRL(x).B.STD_TUNING_EN)

/*! @brief Format value for bitfield uSDHC_TUNING_CTRL_STD_TUNING_EN. */
#define BF_uSDHC_TUNING_CTRL_STD_TUNING_EN(v) ((uint32_t)((uint32_t)(v) << BP_uSDHC_TUNING_CTRL_STD_TUNING_EN) & BM_uSDHC_TUNING_CTRL_STD_TUNING_EN)

/*! @brief Set the STD_TUNING_EN field to a new value. */
#define BW_uSDHC_TUNING_CTRL_STD_TUNING_EN(x, v) (HW_uSDHC_TUNING_CTRL_WR(x, (HW_uSDHC_TUNING_CTRL_RD(x) & ~BM_uSDHC_TUNING_CTRL_STD_TUNING_EN) | BF_uSDHC_TUNING_CTRL_STD_TUNING_EN(v)))
/*@}*/

/*******************************************************************************
 * hw_usdhc_t - module struct
 ******************************************************************************/
/*!
 * @brief All uSDHC module registers.
 */
#pragma pack(1)
typedef struct _hw_usdhc
{
    __IO hw_usdhc_ds_addr_t DS_ADDR;       /*!< [0x0] DMA System Address */
    __IO hw_usdhc_blk_att_t BLK_ATT;       /*!< [0x4] Block Attributes */
    __IO hw_usdhc_cmd_arg_t CMD_ARG;       /*!< [0x8] Command Argument */
    __IO hw_usdhc_cmd_xfr_typ_t CMD_XFR_TYP; /*!< [0xC] Command Transfer Type */
    __I hw_usdhc_cmd_rsp0_t CMD_RSP0;      /*!< [0x10] Command Response0 */
    __I hw_usdhc_cmd_rsp1_t CMD_RSP1;      /*!< [0x14] Command Response1 */
    __I hw_usdhc_cmd_rsp2_t CMD_RSP2;      /*!< [0x18] Command Response2 */
    __I hw_usdhc_cmd_rsp3_t CMD_RSP3;      /*!< [0x1C] Command Response3 */
    __IO hw_usdhc_data_buff_acc_port_t DATA_BUFF_ACC_PORT; /*!< [0x20] Data Buffer Access Port */
    __I hw_usdhc_pres_state_t PRES_STATE;  /*!< [0x24] Present State */
    __IO hw_usdhc_prot_ctrl_t PROT_CTRL;   /*!< [0x28] Protocol Control */
    __IO hw_usdhc_sys_ctrl_t SYS_CTRL;     /*!< [0x2C] System Control */
    __IO hw_usdhc_int_status_t INT_STATUS; /*!< [0x30] Interrupt Status */
    __IO hw_usdhc_int_status_en_t INT_STATUS_EN; /*!< [0x34] Interrupt Status Enable */
    __IO hw_usdhc_int_signal_en_t INT_SIGNAL_EN; /*!< [0x38] Interrupt Signal Enable */
    __IO hw_usdhc_autocmd12_err_status_t AUTOCMD12_ERR_STATUS; /*!< [0x3C] Auto CMD12 Error Status */
    __IO hw_usdhc_host_ctrl_cap_t HOST_CTRL_CAP; /*!< [0x40] Host Controller Capabilities */
    __IO hw_usdhc_wtmk_lvl_t WTMK_LVL;     /*!< [0x44] Watermark Level */
    __IO hw_usdhc_mix_ctrl_t MIX_CTRL;     /*!< [0x48] Mixer Control */
    uint8_t _reserved0[4];
    __IO hw_usdhc_force_event_t FORCE_EVENT; /*!< [0x50] Force Event */
    __I hw_usdhc_adma_err_status_t ADMA_ERR_STATUS; /*!< [0x54] ADMA Error Status Register */
    __IO hw_usdhc_adma_sys_addr_t ADMA_SYS_ADDR; /*!< [0x58] ADMA System Address */
    uint8_t _reserved1[4];
    __IO hw_usdhc_dll_ctrl_t DLL_CTRL;     /*!< [0x60] DLL (Delay Line) Control */
    __I hw_usdhc_dll_status_t DLL_STATUS;  /*!< [0x64] DLL Status */
    __IO hw_usdhc_clk_tune_ctrl_status_t CLK_TUNE_CTRL_STATUS; /*!< [0x68] CLK Tuning Control and Status */
    uint8_t _reserved2[4];
    __IO hw_usdhc_strobe_dll_ctrl_t STROBE_DLL_CTRL; /*!< [0x70] Strobe DLL Control */
    __I hw_usdhc_strobe_dll_status_t STROBE_DLL_STATUS; /*!< [0x74] Strobe DLL Status */
    uint8_t _reserved3[72];
    __IO hw_usdhc_vend_spec_t VEND_SPEC;   /*!< [0xC0] Vendor Specific Register */
    __IO hw_usdhc_mmc_boot_t MMC_BOOT;     /*!< [0xC4] MMC Boot Register */
    __IO hw_usdhc_vend_spec2_t VEND_SPEC2; /*!< [0xC8] Vendor Specific 2 Register */
    __IO hw_usdhc_tuning_ctrl_t TUNING_CTRL; /*!< [0xCC] Tuning Control Register */
} hw_usdhc_t;
#pragma pack()

/*! @brief Macro to access all uSDHC registers. */
/*! @param x uSDHC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_uSDHC_REGS(uSDHC1_BASE)</code>. */
#define HW_uSDHC_REGS(x) (*(hw_usdhc_t *)(x))

#endif /* __HW_iMX7D_REGISTERS_H__ */
/* EOF */
